/*===---- riscv_vector.h - RISC-V V-extension RVVIntrinsics -------------------===
 *
 *
 * Part of the LLVM Project, under the Apache License v2.0 with LLVM Exceptions.
 * See https://llvm.org/LICENSE.txt for license information.
 * SPDX-License-Identifier: Apache-2.0 WITH LLVM-exception
 *
 *===-----------------------------------------------------------------------===
 */

#ifndef __RISCV_VECTOR_H
#define __RISCV_VECTOR_H

#include <stdint.h>
#include <stddef.h>

#ifndef __riscv_vector
#error "Vector intrinsics require the vector extension."
#endif

#ifdef __cplusplus
extern "C" {
#endif


#define VE_TAIL_UNDISTURBED 0
#define VE_TAIL_AGNOSTIC 1

#define vsetvl_e8mf8(avl) __builtin_rvv_vsetvli((size_t)(avl), 0, 5)
#define vsetvl_e8mf4(avl) __builtin_rvv_vsetvli((size_t)(avl), 0, 6)
#define vsetvl_e8mf2(avl) __builtin_rvv_vsetvli((size_t)(avl), 0, 7)
#define vsetvl_e8m1(avl) __builtin_rvv_vsetvli((size_t)(avl), 0, 0)
#define vsetvl_e8m2(avl) __builtin_rvv_vsetvli((size_t)(avl), 0, 1)
#define vsetvl_e8m4(avl) __builtin_rvv_vsetvli((size_t)(avl), 0, 2)
#define vsetvl_e8m8(avl) __builtin_rvv_vsetvli((size_t)(avl), 0, 3)

#define vsetvl_e16mf4(avl) __builtin_rvv_vsetvli((size_t)(avl), 1, 6)
#define vsetvl_e16mf2(avl) __builtin_rvv_vsetvli((size_t)(avl), 1, 7)
#define vsetvl_e16m1(avl) __builtin_rvv_vsetvli((size_t)(avl), 1, 0)
#define vsetvl_e16m2(avl) __builtin_rvv_vsetvli((size_t)(avl), 1, 1)
#define vsetvl_e16m4(avl) __builtin_rvv_vsetvli((size_t)(avl), 1, 2)
#define vsetvl_e16m8(avl) __builtin_rvv_vsetvli((size_t)(avl), 1, 3)

#define vsetvl_e32mf2(avl) __builtin_rvv_vsetvli((size_t)(avl), 2, 7)
#define vsetvl_e32m1(avl) __builtin_rvv_vsetvli((size_t)(avl), 2, 0)
#define vsetvl_e32m2(avl) __builtin_rvv_vsetvli((size_t)(avl), 2, 1)
#define vsetvl_e32m4(avl) __builtin_rvv_vsetvli((size_t)(avl), 2, 2)
#define vsetvl_e32m8(avl) __builtin_rvv_vsetvli((size_t)(avl), 2, 3)

#define vsetvl_e64m1(avl) __builtin_rvv_vsetvli((size_t)(avl), 3, 0)
#define vsetvl_e64m2(avl) __builtin_rvv_vsetvli((size_t)(avl), 3, 1)
#define vsetvl_e64m4(avl) __builtin_rvv_vsetvli((size_t)(avl), 3, 2)
#define vsetvl_e64m8(avl) __builtin_rvv_vsetvli((size_t)(avl), 3, 3)


#define vsetvlmax_e8mf8() __builtin_rvv_vsetvlimax(0, 5)
#define vsetvlmax_e8mf4() __builtin_rvv_vsetvlimax(0, 6)
#define vsetvlmax_e8mf2() __builtin_rvv_vsetvlimax(0, 7)
#define vsetvlmax_e8m1() __builtin_rvv_vsetvlimax(0, 0)
#define vsetvlmax_e8m2() __builtin_rvv_vsetvlimax(0, 1)
#define vsetvlmax_e8m4() __builtin_rvv_vsetvlimax(0, 2)
#define vsetvlmax_e8m8() __builtin_rvv_vsetvlimax(0, 3)

#define vsetvlmax_e16mf4() __builtin_rvv_vsetvlimax(1, 6)
#define vsetvlmax_e16mf2() __builtin_rvv_vsetvlimax(1, 7)
#define vsetvlmax_e16m1() __builtin_rvv_vsetvlimax(1, 0)
#define vsetvlmax_e16m2() __builtin_rvv_vsetvlimax(1, 1)
#define vsetvlmax_e16m4() __builtin_rvv_vsetvlimax(1, 2)
#define vsetvlmax_e16m8() __builtin_rvv_vsetvlimax(1, 3)

#define vsetvlmax_e32mf2() __builtin_rvv_vsetvlimax(2, 7)
#define vsetvlmax_e32m1() __builtin_rvv_vsetvlimax(2, 0)
#define vsetvlmax_e32m2() __builtin_rvv_vsetvlimax(2, 1)
#define vsetvlmax_e32m4() __builtin_rvv_vsetvlimax(2, 2)
#define vsetvlmax_e32m8() __builtin_rvv_vsetvlimax(2, 3)

#define vsetvlmax_e64m1() __builtin_rvv_vsetvlimax(3, 0)
#define vsetvlmax_e64m2() __builtin_rvv_vsetvlimax(3, 1)
#define vsetvlmax_e64m4() __builtin_rvv_vsetvlimax(3, 2)
#define vsetvlmax_e64m8() __builtin_rvv_vsetvlimax(3, 3)

typedef __rvv_bool64_t vbool64_t;
typedef __rvv_bool32_t vbool32_t;
typedef __rvv_bool16_t vbool16_t;
typedef __rvv_bool8_t vbool8_t;
typedef __rvv_bool4_t vbool4_t;
typedef __rvv_bool2_t vbool2_t;
typedef __rvv_bool1_t vbool1_t;
typedef __rvv_int8mf8_t vint8mf8_t;
typedef __rvv_uint8mf8_t vuint8mf8_t;
typedef __rvv_int8mf4_t vint8mf4_t;
typedef __rvv_uint8mf4_t vuint8mf4_t;
typedef __rvv_int8mf2_t vint8mf2_t;
typedef __rvv_uint8mf2_t vuint8mf2_t;
typedef __rvv_int8m1_t vint8m1_t;
typedef __rvv_uint8m1_t vuint8m1_t;
typedef __rvv_int8m2_t vint8m2_t;
typedef __rvv_uint8m2_t vuint8m2_t;
typedef __rvv_int8m4_t vint8m4_t;
typedef __rvv_uint8m4_t vuint8m4_t;
typedef __rvv_int8m8_t vint8m8_t;
typedef __rvv_uint8m8_t vuint8m8_t;
typedef __rvv_int16mf4_t vint16mf4_t;
typedef __rvv_uint16mf4_t vuint16mf4_t;
typedef __rvv_int16mf2_t vint16mf2_t;
typedef __rvv_uint16mf2_t vuint16mf2_t;
typedef __rvv_int16m1_t vint16m1_t;
typedef __rvv_uint16m1_t vuint16m1_t;
typedef __rvv_int16m2_t vint16m2_t;
typedef __rvv_uint16m2_t vuint16m2_t;
typedef __rvv_int16m4_t vint16m4_t;
typedef __rvv_uint16m4_t vuint16m4_t;
typedef __rvv_int16m8_t vint16m8_t;
typedef __rvv_uint16m8_t vuint16m8_t;
typedef __rvv_int32mf2_t vint32mf2_t;
typedef __rvv_uint32mf2_t vuint32mf2_t;
typedef __rvv_int32m1_t vint32m1_t;
typedef __rvv_uint32m1_t vuint32m1_t;
typedef __rvv_int32m2_t vint32m2_t;
typedef __rvv_uint32m2_t vuint32m2_t;
typedef __rvv_int32m4_t vint32m4_t;
typedef __rvv_uint32m4_t vuint32m4_t;
typedef __rvv_int32m8_t vint32m8_t;
typedef __rvv_uint32m8_t vuint32m8_t;
typedef __rvv_int64m1_t vint64m1_t;
typedef __rvv_uint64m1_t vuint64m1_t;
typedef __rvv_int64m2_t vint64m2_t;
typedef __rvv_uint64m2_t vuint64m2_t;
typedef __rvv_int64m4_t vint64m4_t;
typedef __rvv_uint64m4_t vuint64m4_t;
typedef __rvv_int64m8_t vint64m8_t;
typedef __rvv_uint64m8_t vuint64m8_t;
#if defined(__riscv_zfh)
typedef __rvv_float16mf4_t vfloat16mf4_t;
typedef __rvv_float16mf2_t vfloat16mf2_t;
typedef __rvv_float16m1_t vfloat16m1_t;
typedef __rvv_float16m2_t vfloat16m2_t;
typedef __rvv_float16m4_t vfloat16m4_t;
typedef __rvv_float16m8_t vfloat16m8_t;
#endif
#if defined(__riscv_f)
typedef __rvv_float32mf2_t vfloat32mf2_t;
typedef __rvv_float32m1_t vfloat32m1_t;
typedef __rvv_float32m2_t vfloat32m2_t;
typedef __rvv_float32m4_t vfloat32m4_t;
typedef __rvv_float32m8_t vfloat32m8_t;
#endif
#if defined(__riscv_d)
typedef __rvv_float64m1_t vfloat64m1_t;
typedef __rvv_float64m2_t vfloat64m2_t;
typedef __rvv_float64m4_t vfloat64m4_t;
typedef __rvv_float64m8_t vfloat64m8_t;
#endif

#define __rvv_ai static __inline__
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vadd_vv)))
vint8m1_t vadd_vv_i8m1(vint8m1_t, vint8m1_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vadd_vv_m)))
vint8m1_t vadd_vv_i8m1_m(vbool8_t, vint8m1_t, vint8m1_t, vint8m1_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vadd_vv)))
vint8m2_t vadd_vv_i8m2(vint8m2_t, vint8m2_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vadd_vv_m)))
vint8m2_t vadd_vv_i8m2_m(vbool4_t, vint8m2_t, vint8m2_t, vint8m2_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vadd_vv)))
vint8m4_t vadd_vv_i8m4(vint8m4_t, vint8m4_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vadd_vv_m)))
vint8m4_t vadd_vv_i8m4_m(vbool2_t, vint8m4_t, vint8m4_t, vint8m4_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vadd_vv)))
vint8m8_t vadd_vv_i8m8(vint8m8_t, vint8m8_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vadd_vv_m)))
vint8m8_t vadd_vv_i8m8_m(vbool1_t, vint8m8_t, vint8m8_t, vint8m8_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vadd_vv)))
vint8mf2_t vadd_vv_i8mf2(vint8mf2_t, vint8mf2_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vadd_vv_m)))
vint8mf2_t vadd_vv_i8mf2_m(vbool16_t, vint8mf2_t, vint8mf2_t, vint8mf2_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vadd_vv)))
vint8mf4_t vadd_vv_i8mf4(vint8mf4_t, vint8mf4_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vadd_vv_m)))
vint8mf4_t vadd_vv_i8mf4_m(vbool32_t, vint8mf4_t, vint8mf4_t, vint8mf4_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vadd_vv)))
vint8mf8_t vadd_vv_i8mf8(vint8mf8_t, vint8mf8_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vadd_vv_m)))
vint8mf8_t vadd_vv_i8mf8_m(vbool64_t, vint8mf8_t, vint8mf8_t, vint8mf8_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vadd_vv)))
vint16m1_t vadd_vv_i16m1(vint16m1_t, vint16m1_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vadd_vv_m)))
vint16m1_t vadd_vv_i16m1_m(vbool16_t, vint16m1_t, vint16m1_t, vint16m1_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vadd_vv)))
vint16m2_t vadd_vv_i16m2(vint16m2_t, vint16m2_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vadd_vv_m)))
vint16m2_t vadd_vv_i16m2_m(vbool8_t, vint16m2_t, vint16m2_t, vint16m2_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vadd_vv)))
vint16m4_t vadd_vv_i16m4(vint16m4_t, vint16m4_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vadd_vv_m)))
vint16m4_t vadd_vv_i16m4_m(vbool4_t, vint16m4_t, vint16m4_t, vint16m4_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vadd_vv)))
vint16m8_t vadd_vv_i16m8(vint16m8_t, vint16m8_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vadd_vv_m)))
vint16m8_t vadd_vv_i16m8_m(vbool2_t, vint16m8_t, vint16m8_t, vint16m8_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vadd_vv)))
vint16mf2_t vadd_vv_i16mf2(vint16mf2_t, vint16mf2_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vadd_vv_m)))
vint16mf2_t vadd_vv_i16mf2_m(vbool32_t, vint16mf2_t, vint16mf2_t, vint16mf2_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vadd_vv)))
vint16mf4_t vadd_vv_i16mf4(vint16mf4_t, vint16mf4_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vadd_vv_m)))
vint16mf4_t vadd_vv_i16mf4_m(vbool64_t, vint16mf4_t, vint16mf4_t, vint16mf4_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vadd_vv)))
vint32m1_t vadd_vv_i32m1(vint32m1_t, vint32m1_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vadd_vv_m)))
vint32m1_t vadd_vv_i32m1_m(vbool32_t, vint32m1_t, vint32m1_t, vint32m1_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vadd_vv)))
vint32m2_t vadd_vv_i32m2(vint32m2_t, vint32m2_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vadd_vv_m)))
vint32m2_t vadd_vv_i32m2_m(vbool16_t, vint32m2_t, vint32m2_t, vint32m2_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vadd_vv)))
vint32m4_t vadd_vv_i32m4(vint32m4_t, vint32m4_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vadd_vv_m)))
vint32m4_t vadd_vv_i32m4_m(vbool8_t, vint32m4_t, vint32m4_t, vint32m4_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vadd_vv)))
vint32m8_t vadd_vv_i32m8(vint32m8_t, vint32m8_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vadd_vv_m)))
vint32m8_t vadd_vv_i32m8_m(vbool4_t, vint32m8_t, vint32m8_t, vint32m8_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vadd_vv)))
vint32mf2_t vadd_vv_i32mf2(vint32mf2_t, vint32mf2_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vadd_vv_m)))
vint32mf2_t vadd_vv_i32mf2_m(vbool64_t, vint32mf2_t, vint32mf2_t, vint32mf2_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vwaddu_vv)))
vuint16mf4_t vwaddu_vv_u16mf4(vuint8mf8_t, vuint8mf8_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vwaddu_vv_m)))
vuint16mf4_t vwaddu_vv_u16mf4_m(vbool64_t, vuint16mf4_t, vuint8mf8_t, vuint8mf8_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vwaddu_vv)))
vuint16mf2_t vwaddu_vv_u16mf2(vuint8mf4_t, vuint8mf4_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vwaddu_vv_m)))
vuint16mf2_t vwaddu_vv_u16mf2_m(vbool32_t, vuint16mf2_t, vuint8mf4_t, vuint8mf4_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vwaddu_vv)))
vuint16m1_t vwaddu_vv_u16m1(vuint8mf2_t, vuint8mf2_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vwaddu_vv_m)))
vuint16m1_t vwaddu_vv_u16m1_m(vbool16_t, vuint16m1_t, vuint8mf2_t, vuint8mf2_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vwaddu_vv)))
vuint16m2_t vwaddu_vv_u16m2(vuint8m1_t, vuint8m1_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vwaddu_vv_m)))
vuint16m2_t vwaddu_vv_u16m2_m(vbool8_t, vuint16m2_t, vuint8m1_t, vuint8m1_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vwaddu_vv)))
vuint16m4_t vwaddu_vv_u16m4(vuint8m2_t, vuint8m2_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vwaddu_vv_m)))
vuint16m4_t vwaddu_vv_u16m4_m(vbool4_t, vuint16m4_t, vuint8m2_t, vuint8m2_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vwaddu_vv)))
vuint16m8_t vwaddu_vv_u16m8(vuint8m4_t, vuint8m4_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vwaddu_vv_m)))
vuint16m8_t vwaddu_vv_u16m8_m(vbool2_t, vuint16m8_t, vuint8m4_t, vuint8m4_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vwaddu_vv)))
vuint32mf2_t vwaddu_vv_u32mf2(vuint16mf4_t, vuint16mf4_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vwaddu_vv_m)))
vuint32mf2_t vwaddu_vv_u32mf2_m(vbool64_t, vuint32mf2_t, vuint16mf4_t, vuint16mf4_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vwaddu_vv)))
vuint32m1_t vwaddu_vv_u32m1(vuint16mf2_t, vuint16mf2_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vwaddu_vv_m)))
vuint32m1_t vwaddu_vv_u32m1_m(vbool32_t, vuint32m1_t, vuint16mf2_t, vuint16mf2_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vwaddu_vv)))
vuint32m2_t vwaddu_vv_u32m2(vuint16m1_t, vuint16m1_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vwaddu_vv_m)))
vuint32m2_t vwaddu_vv_u32m2_m(vbool16_t, vuint32m2_t, vuint16m1_t, vuint16m1_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vwaddu_vv)))
vuint32m4_t vwaddu_vv_u32m4(vuint16m2_t, vuint16m2_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vwaddu_vv_m)))
vuint32m4_t vwaddu_vv_u32m4_m(vbool8_t, vuint32m4_t, vuint16m2_t, vuint16m2_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vwaddu_vv)))
vuint32m8_t vwaddu_vv_u32m8(vuint16m4_t, vuint16m4_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vwaddu_vv_m)))
vuint32m8_t vwaddu_vv_u32m8_m(vbool4_t, vuint32m8_t, vuint16m4_t, vuint16m4_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vluxei8_v)))
vuint8m1_t vluxei8_v_u8m1(const uint8_t *, vuint8m1_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vluxei8_v_m)))
vuint8m1_t vluxei8_v_u8m1_m(vbool8_t, vuint8m1_t, const uint8_t *, vuint8m1_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vluxei8_v)))
vuint8m2_t vluxei8_v_u8m2(const uint8_t *, vuint8m2_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vluxei8_v_m)))
vuint8m2_t vluxei8_v_u8m2_m(vbool4_t, vuint8m2_t, const uint8_t *, vuint8m2_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vluxei8_v)))
vuint8m4_t vluxei8_v_u8m4(const uint8_t *, vuint8m4_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vluxei8_v_m)))
vuint8m4_t vluxei8_v_u8m4_m(vbool2_t, vuint8m4_t, const uint8_t *, vuint8m4_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vluxei8_v)))
vuint8m8_t vluxei8_v_u8m8(const uint8_t *, vuint8m8_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vluxei8_v_m)))
vuint8m8_t vluxei8_v_u8m8_m(vbool1_t, vuint8m8_t, const uint8_t *, vuint8m8_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vluxei8_v)))
vuint8mf2_t vluxei8_v_u8mf2(const uint8_t *, vuint8mf2_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vluxei8_v_m)))
vuint8mf2_t vluxei8_v_u8mf2_m(vbool16_t, vuint8mf2_t, const uint8_t *, vuint8mf2_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vluxei8_v)))
vuint8mf4_t vluxei8_v_u8mf4(const uint8_t *, vuint8mf4_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vluxei8_v_m)))
vuint8mf4_t vluxei8_v_u8mf4_m(vbool32_t, vuint8mf4_t, const uint8_t *, vuint8mf4_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vluxei8_v)))
vuint8mf8_t vluxei8_v_u8mf8(const uint8_t *, vuint8mf8_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vluxei8_v_m)))
vuint8mf8_t vluxei8_v_u8mf8_m(vbool64_t, vuint8mf8_t, const uint8_t *, vuint8mf8_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vsse16_v)))
void vsse16_v_i16m1(int16_t *, ptrdiff_t, vint16m1_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vsse16_v_m)))
void vsse16_v_i16m1_m(vbool16_t, int16_t *, ptrdiff_t, vint16m1_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vsse16_v)))
void vsse16_v_i16m2(int16_t *, ptrdiff_t, vint16m2_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vsse16_v_m)))
void vsse16_v_i16m2_m(vbool8_t, int16_t *, ptrdiff_t, vint16m2_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vsse16_v)))
void vsse16_v_i16m4(int16_t *, ptrdiff_t, vint16m4_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vsse16_v_m)))
void vsse16_v_i16m4_m(vbool4_t, int16_t *, ptrdiff_t, vint16m4_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vsse16_v)))
void vsse16_v_i16m8(int16_t *, ptrdiff_t, vint16m8_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vsse16_v_m)))
void vsse16_v_i16m8_m(vbool2_t, int16_t *, ptrdiff_t, vint16m8_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vsse16_v)))
void vsse16_v_i16mf2(int16_t *, ptrdiff_t, vint16mf2_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vsse16_v_m)))
void vsse16_v_i16mf2_m(vbool32_t, int16_t *, ptrdiff_t, vint16mf2_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vsse16_v)))
void vsse16_v_i16mf4(int16_t *, ptrdiff_t, vint16mf4_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vsse16_v_m)))
void vsse16_v_i16mf4_m(vbool64_t, int16_t *, ptrdiff_t, vint16mf4_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vsse16_v)))
void vsse16_v_u16m1(uint16_t *, ptrdiff_t, vuint16m1_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vsse16_v_m)))
void vsse16_v_u16m1_m(vbool16_t, uint16_t *, ptrdiff_t, vuint16m1_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vsse16_v)))
void vsse16_v_u16m2(uint16_t *, ptrdiff_t, vuint16m2_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vsse16_v_m)))
void vsse16_v_u16m2_m(vbool8_t, uint16_t *, ptrdiff_t, vuint16m2_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vsse16_v)))
void vsse16_v_u16m4(uint16_t *, ptrdiff_t, vuint16m4_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vsse16_v_m)))
void vsse16_v_u16m4_m(vbool4_t, uint16_t *, ptrdiff_t, vuint16m4_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vsse16_v)))
void vsse16_v_u16m8(uint16_t *, ptrdiff_t, vuint16m8_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vsse16_v_m)))
void vsse16_v_u16m8_m(vbool2_t, uint16_t *, ptrdiff_t, vuint16m8_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vsse16_v)))
void vsse16_v_u16mf2(uint16_t *, ptrdiff_t, vuint16mf2_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vsse16_v_m)))
void vsse16_v_u16mf2_m(vbool32_t, uint16_t *, ptrdiff_t, vuint16mf2_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vsse16_v)))
void vsse16_v_u16mf4(uint16_t *, ptrdiff_t, vuint16mf4_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vsse16_v_m)))
void vsse16_v_u16mf4_m(vbool64_t, uint16_t *, ptrdiff_t, vuint16mf4_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vsse32_v)))
void vsse32_v_i32m1(int32_t *, ptrdiff_t, vint32m1_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vsse32_v_m)))
void vsse32_v_i32m1_m(vbool32_t, int32_t *, ptrdiff_t, vint32m1_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vsse32_v)))
void vsse32_v_i32m2(int32_t *, ptrdiff_t, vint32m2_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vsse32_v_m)))
void vsse32_v_i32m2_m(vbool16_t, int32_t *, ptrdiff_t, vint32m2_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vsse32_v)))
void vsse32_v_i32m4(int32_t *, ptrdiff_t, vint32m4_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vsse32_v_m)))
void vsse32_v_i32m4_m(vbool8_t, int32_t *, ptrdiff_t, vint32m4_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vsse32_v)))
void vsse32_v_i32m8(int32_t *, ptrdiff_t, vint32m8_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vsse32_v_m)))
void vsse32_v_i32m8_m(vbool4_t, int32_t *, ptrdiff_t, vint32m8_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vsse32_v)))
void vsse32_v_i32mf2(int32_t *, ptrdiff_t, vint32mf2_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vsse32_v_m)))
void vsse32_v_i32mf2_m(vbool64_t, int32_t *, ptrdiff_t, vint32mf2_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vsse32_v)))
void vsse32_v_u32m1(uint32_t *, ptrdiff_t, vuint32m1_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vsse32_v_m)))
void vsse32_v_u32m1_m(vbool32_t, uint32_t *, ptrdiff_t, vuint32m1_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vsse32_v)))
void vsse32_v_u32m2(uint32_t *, ptrdiff_t, vuint32m2_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vsse32_v_m)))
void vsse32_v_u32m2_m(vbool16_t, uint32_t *, ptrdiff_t, vuint32m2_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vsse32_v)))
void vsse32_v_u32m4(uint32_t *, ptrdiff_t, vuint32m4_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vsse32_v_m)))
void vsse32_v_u32m4_m(vbool8_t, uint32_t *, ptrdiff_t, vuint32m4_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vsse32_v)))
void vsse32_v_u32m8(uint32_t *, ptrdiff_t, vuint32m8_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vsse32_v_m)))
void vsse32_v_u32m8_m(vbool4_t, uint32_t *, ptrdiff_t, vuint32m8_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vsse32_v)))
void vsse32_v_u32mf2(uint32_t *, ptrdiff_t, vuint32mf2_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vsse32_v_m)))
void vsse32_v_u32mf2_m(vbool64_t, uint32_t *, ptrdiff_t, vuint32mf2_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vsseg3e8_v)))
void vsseg3e8_v_i8m1(int8_t *, vint8m1_t, vint8m1_t, vint8m1_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vsseg3e8_v_m)))
void vsseg3e8_v_i8m1_m(vbool8_t, int8_t *, vint8m1_t, vint8m1_t, vint8m1_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vsseg3e8_v)))
void vsseg3e8_v_i8m2(int8_t *, vint8m2_t, vint8m2_t, vint8m2_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vsseg3e8_v_m)))
void vsseg3e8_v_i8m2_m(vbool4_t, int8_t *, vint8m2_t, vint8m2_t, vint8m2_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vsseg3e8_v)))
void vsseg3e8_v_i8mf2(int8_t *, vint8mf2_t, vint8mf2_t, vint8mf2_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vsseg3e8_v_m)))
void vsseg3e8_v_i8mf2_m(vbool16_t, int8_t *, vint8mf2_t, vint8mf2_t, vint8mf2_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vsseg3e8_v)))
void vsseg3e8_v_i8mf4(int8_t *, vint8mf4_t, vint8mf4_t, vint8mf4_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vsseg3e8_v_m)))
void vsseg3e8_v_i8mf4_m(vbool32_t, int8_t *, vint8mf4_t, vint8mf4_t, vint8mf4_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vsseg3e8_v)))
void vsseg3e8_v_i8mf8(int8_t *, vint8mf8_t, vint8mf8_t, vint8mf8_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vsseg3e8_v_m)))
void vsseg3e8_v_i8mf8_m(vbool64_t, int8_t *, vint8mf8_t, vint8mf8_t, vint8mf8_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vluxei16_v)))
vint8m1_t vluxei16_v_i8m1(const int8_t *, vuint16m2_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vluxei16_v_m)))
vint8m1_t vluxei16_v_i8m1_m(vbool8_t, vint8m1_t, const int8_t *, vuint16m2_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vluxei16_v)))
vint8m2_t vluxei16_v_i8m2(const int8_t *, vuint16m4_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vluxei16_v_m)))
vint8m2_t vluxei16_v_i8m2_m(vbool4_t, vint8m2_t, const int8_t *, vuint16m4_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vluxei16_v)))
vint8m4_t vluxei16_v_i8m4(const int8_t *, vuint16m8_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vluxei16_v_m)))
vint8m4_t vluxei16_v_i8m4_m(vbool2_t, vint8m4_t, const int8_t *, vuint16m8_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vluxei16_v)))
vint8mf2_t vluxei16_v_i8mf2(const int8_t *, vuint16m1_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vluxei16_v_m)))
vint8mf2_t vluxei16_v_i8mf2_m(vbool16_t, vint8mf2_t, const int8_t *, vuint16m1_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vluxei16_v)))
vint8mf4_t vluxei16_v_i8mf4(const int8_t *, vuint16mf2_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vluxei16_v_m)))
vint8mf4_t vluxei16_v_i8mf4_m(vbool32_t, vint8mf4_t, const int8_t *, vuint16mf2_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vluxei16_v)))
vint8mf8_t vluxei16_v_i8mf8(const int8_t *, vuint16mf4_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vluxei16_v_m)))
vint8mf8_t vluxei16_v_i8mf8_m(vbool64_t, vint8mf8_t, const int8_t *, vuint16mf4_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vsseg3e8_v)))
void vsseg3e8_v_u8m1(uint8_t *, vuint8m1_t, vuint8m1_t, vuint8m1_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vsseg3e8_v_m)))
void vsseg3e8_v_u8m1_m(vbool8_t, uint8_t *, vuint8m1_t, vuint8m1_t, vuint8m1_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vsseg3e8_v)))
void vsseg3e8_v_u8m2(uint8_t *, vuint8m2_t, vuint8m2_t, vuint8m2_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vsseg3e8_v_m)))
void vsseg3e8_v_u8m2_m(vbool4_t, uint8_t *, vuint8m2_t, vuint8m2_t, vuint8m2_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vsseg3e8_v)))
void vsseg3e8_v_u8mf2(uint8_t *, vuint8mf2_t, vuint8mf2_t, vuint8mf2_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vsseg3e8_v_m)))
void vsseg3e8_v_u8mf2_m(vbool16_t, uint8_t *, vuint8mf2_t, vuint8mf2_t, vuint8mf2_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vsseg3e8_v)))
void vsseg3e8_v_u8mf4(uint8_t *, vuint8mf4_t, vuint8mf4_t, vuint8mf4_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vsseg3e8_v_m)))
void vsseg3e8_v_u8mf4_m(vbool32_t, uint8_t *, vuint8mf4_t, vuint8mf4_t, vuint8mf4_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vsseg3e8_v)))
void vsseg3e8_v_u8mf8(uint8_t *, vuint8mf8_t, vuint8mf8_t, vuint8mf8_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vsseg3e8_v_m)))
void vsseg3e8_v_u8mf8_m(vbool64_t, uint8_t *, vuint8mf8_t, vuint8mf8_t, vuint8mf8_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vsseg4e8_v)))
void vsseg4e8_v_i8m1(int8_t *, vint8m1_t, vint8m1_t, vint8m1_t, vint8m1_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vsseg4e8_v_m)))
void vsseg4e8_v_i8m1_m(vbool8_t, int8_t *, vint8m1_t, vint8m1_t, vint8m1_t, vint8m1_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vsseg4e8_v)))
void vsseg4e8_v_i8m2(int8_t *, vint8m2_t, vint8m2_t, vint8m2_t, vint8m2_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vsseg4e8_v_m)))
void vsseg4e8_v_i8m2_m(vbool4_t, int8_t *, vint8m2_t, vint8m2_t, vint8m2_t, vint8m2_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vsseg4e8_v)))
void vsseg4e8_v_i8mf2(int8_t *, vint8mf2_t, vint8mf2_t, vint8mf2_t, vint8mf2_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vsseg4e8_v_m)))
void vsseg4e8_v_i8mf2_m(vbool16_t, int8_t *, vint8mf2_t, vint8mf2_t, vint8mf2_t, vint8mf2_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vsseg4e8_v)))
void vsseg4e8_v_i8mf4(int8_t *, vint8mf4_t, vint8mf4_t, vint8mf4_t, vint8mf4_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vsseg4e8_v_m)))
void vsseg4e8_v_i8mf4_m(vbool32_t, int8_t *, vint8mf4_t, vint8mf4_t, vint8mf4_t, vint8mf4_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vsseg4e8_v)))
void vsseg4e8_v_i8mf8(int8_t *, vint8mf8_t, vint8mf8_t, vint8mf8_t, vint8mf8_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vsseg4e8_v_m)))
void vsseg4e8_v_i8mf8_m(vbool64_t, int8_t *, vint8mf8_t, vint8mf8_t, vint8mf8_t, vint8mf8_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vsseg4e8_v)))
void vsseg4e8_v_u8m1(uint8_t *, vuint8m1_t, vuint8m1_t, vuint8m1_t, vuint8m1_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vsseg4e8_v_m)))
void vsseg4e8_v_u8m1_m(vbool8_t, uint8_t *, vuint8m1_t, vuint8m1_t, vuint8m1_t, vuint8m1_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vsseg4e8_v)))
void vsseg4e8_v_u8m2(uint8_t *, vuint8m2_t, vuint8m2_t, vuint8m2_t, vuint8m2_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vsseg4e8_v_m)))
void vsseg4e8_v_u8m2_m(vbool4_t, uint8_t *, vuint8m2_t, vuint8m2_t, vuint8m2_t, vuint8m2_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vsseg4e8_v)))
void vsseg4e8_v_u8mf2(uint8_t *, vuint8mf2_t, vuint8mf2_t, vuint8mf2_t, vuint8mf2_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vsseg4e8_v_m)))
void vsseg4e8_v_u8mf2_m(vbool16_t, uint8_t *, vuint8mf2_t, vuint8mf2_t, vuint8mf2_t, vuint8mf2_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vsseg4e8_v)))
void vsseg4e8_v_u8mf4(uint8_t *, vuint8mf4_t, vuint8mf4_t, vuint8mf4_t, vuint8mf4_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vsseg4e8_v_m)))
void vsseg4e8_v_u8mf4_m(vbool32_t, uint8_t *, vuint8mf4_t, vuint8mf4_t, vuint8mf4_t, vuint8mf4_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vsseg4e8_v)))
void vsseg4e8_v_u8mf8(uint8_t *, vuint8mf8_t, vuint8mf8_t, vuint8mf8_t, vuint8mf8_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vsseg4e8_v_m)))
void vsseg4e8_v_u8mf8_m(vbool64_t, uint8_t *, vuint8mf8_t, vuint8mf8_t, vuint8mf8_t, vuint8mf8_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vsseg5e8_v)))
void vsseg5e8_v_i8m1(int8_t *, vint8m1_t, vint8m1_t, vint8m1_t, vint8m1_t, vint8m1_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vsseg5e8_v_m)))
void vsseg5e8_v_i8m1_m(vbool8_t, int8_t *, vint8m1_t, vint8m1_t, vint8m1_t, vint8m1_t, vint8m1_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vsseg5e8_v)))
void vsseg5e8_v_i8mf2(int8_t *, vint8mf2_t, vint8mf2_t, vint8mf2_t, vint8mf2_t, vint8mf2_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vsseg5e8_v_m)))
void vsseg5e8_v_i8mf2_m(vbool16_t, int8_t *, vint8mf2_t, vint8mf2_t, vint8mf2_t, vint8mf2_t, vint8mf2_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vsseg5e8_v)))
void vsseg5e8_v_i8mf4(int8_t *, vint8mf4_t, vint8mf4_t, vint8mf4_t, vint8mf4_t, vint8mf4_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vsseg5e8_v_m)))
void vsseg5e8_v_i8mf4_m(vbool32_t, int8_t *, vint8mf4_t, vint8mf4_t, vint8mf4_t, vint8mf4_t, vint8mf4_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vsseg5e8_v)))
void vsseg5e8_v_i8mf8(int8_t *, vint8mf8_t, vint8mf8_t, vint8mf8_t, vint8mf8_t, vint8mf8_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vsseg5e8_v_m)))
void vsseg5e8_v_i8mf8_m(vbool64_t, int8_t *, vint8mf8_t, vint8mf8_t, vint8mf8_t, vint8mf8_t, vint8mf8_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vsseg5e8_v)))
void vsseg5e8_v_u8m1(uint8_t *, vuint8m1_t, vuint8m1_t, vuint8m1_t, vuint8m1_t, vuint8m1_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vsseg5e8_v_m)))
void vsseg5e8_v_u8m1_m(vbool8_t, uint8_t *, vuint8m1_t, vuint8m1_t, vuint8m1_t, vuint8m1_t, vuint8m1_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vsseg5e8_v)))
void vsseg5e8_v_u8mf2(uint8_t *, vuint8mf2_t, vuint8mf2_t, vuint8mf2_t, vuint8mf2_t, vuint8mf2_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vsseg5e8_v_m)))
void vsseg5e8_v_u8mf2_m(vbool16_t, uint8_t *, vuint8mf2_t, vuint8mf2_t, vuint8mf2_t, vuint8mf2_t, vuint8mf2_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vsseg5e8_v)))
void vsseg5e8_v_u8mf4(uint8_t *, vuint8mf4_t, vuint8mf4_t, vuint8mf4_t, vuint8mf4_t, vuint8mf4_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vsseg5e8_v_m)))
void vsseg5e8_v_u8mf4_m(vbool32_t, uint8_t *, vuint8mf4_t, vuint8mf4_t, vuint8mf4_t, vuint8mf4_t, vuint8mf4_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vsseg5e8_v)))
void vsseg5e8_v_u8mf8(uint8_t *, vuint8mf8_t, vuint8mf8_t, vuint8mf8_t, vuint8mf8_t, vuint8mf8_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vsseg5e8_v_m)))
void vsseg5e8_v_u8mf8_m(vbool64_t, uint8_t *, vuint8mf8_t, vuint8mf8_t, vuint8mf8_t, vuint8mf8_t, vuint8mf8_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vsseg6e8_v)))
void vsseg6e8_v_i8m1(int8_t *, vint8m1_t, vint8m1_t, vint8m1_t, vint8m1_t, vint8m1_t, vint8m1_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vsseg6e8_v_m)))
void vsseg6e8_v_i8m1_m(vbool8_t, int8_t *, vint8m1_t, vint8m1_t, vint8m1_t, vint8m1_t, vint8m1_t, vint8m1_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vsseg6e8_v)))
void vsseg6e8_v_i8mf2(int8_t *, vint8mf2_t, vint8mf2_t, vint8mf2_t, vint8mf2_t, vint8mf2_t, vint8mf2_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vsseg6e8_v_m)))
void vsseg6e8_v_i8mf2_m(vbool16_t, int8_t *, vint8mf2_t, vint8mf2_t, vint8mf2_t, vint8mf2_t, vint8mf2_t, vint8mf2_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vsseg6e8_v)))
void vsseg6e8_v_i8mf4(int8_t *, vint8mf4_t, vint8mf4_t, vint8mf4_t, vint8mf4_t, vint8mf4_t, vint8mf4_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vsseg6e8_v_m)))
void vsseg6e8_v_i8mf4_m(vbool32_t, int8_t *, vint8mf4_t, vint8mf4_t, vint8mf4_t, vint8mf4_t, vint8mf4_t, vint8mf4_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vsseg6e8_v)))
void vsseg6e8_v_i8mf8(int8_t *, vint8mf8_t, vint8mf8_t, vint8mf8_t, vint8mf8_t, vint8mf8_t, vint8mf8_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vsseg6e8_v_m)))
void vsseg6e8_v_i8mf8_m(vbool64_t, int8_t *, vint8mf8_t, vint8mf8_t, vint8mf8_t, vint8mf8_t, vint8mf8_t, vint8mf8_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vsseg6e8_v)))
void vsseg6e8_v_u8m1(uint8_t *, vuint8m1_t, vuint8m1_t, vuint8m1_t, vuint8m1_t, vuint8m1_t, vuint8m1_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vsseg6e8_v_m)))
void vsseg6e8_v_u8m1_m(vbool8_t, uint8_t *, vuint8m1_t, vuint8m1_t, vuint8m1_t, vuint8m1_t, vuint8m1_t, vuint8m1_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vsseg6e8_v)))
void vsseg6e8_v_u8mf2(uint8_t *, vuint8mf2_t, vuint8mf2_t, vuint8mf2_t, vuint8mf2_t, vuint8mf2_t, vuint8mf2_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vsseg6e8_v_m)))
void vsseg6e8_v_u8mf2_m(vbool16_t, uint8_t *, vuint8mf2_t, vuint8mf2_t, vuint8mf2_t, vuint8mf2_t, vuint8mf2_t, vuint8mf2_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vsseg6e8_v)))
void vsseg6e8_v_u8mf4(uint8_t *, vuint8mf4_t, vuint8mf4_t, vuint8mf4_t, vuint8mf4_t, vuint8mf4_t, vuint8mf4_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vsseg6e8_v_m)))
void vsseg6e8_v_u8mf4_m(vbool32_t, uint8_t *, vuint8mf4_t, vuint8mf4_t, vuint8mf4_t, vuint8mf4_t, vuint8mf4_t, vuint8mf4_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vsseg6e8_v)))
void vsseg6e8_v_u8mf8(uint8_t *, vuint8mf8_t, vuint8mf8_t, vuint8mf8_t, vuint8mf8_t, vuint8mf8_t, vuint8mf8_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vsseg6e8_v_m)))
void vsseg6e8_v_u8mf8_m(vbool64_t, uint8_t *, vuint8mf8_t, vuint8mf8_t, vuint8mf8_t, vuint8mf8_t, vuint8mf8_t, vuint8mf8_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vsseg7e8_v)))
void vsseg7e8_v_i8m1(int8_t *, vint8m1_t, vint8m1_t, vint8m1_t, vint8m1_t, vint8m1_t, vint8m1_t, vint8m1_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vsseg7e8_v_m)))
void vsseg7e8_v_i8m1_m(vbool8_t, int8_t *, vint8m1_t, vint8m1_t, vint8m1_t, vint8m1_t, vint8m1_t, vint8m1_t, vint8m1_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vsseg7e8_v)))
void vsseg7e8_v_i8mf2(int8_t *, vint8mf2_t, vint8mf2_t, vint8mf2_t, vint8mf2_t, vint8mf2_t, vint8mf2_t, vint8mf2_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vsseg7e8_v_m)))
void vsseg7e8_v_i8mf2_m(vbool16_t, int8_t *, vint8mf2_t, vint8mf2_t, vint8mf2_t, vint8mf2_t, vint8mf2_t, vint8mf2_t, vint8mf2_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vsseg7e8_v)))
void vsseg7e8_v_i8mf4(int8_t *, vint8mf4_t, vint8mf4_t, vint8mf4_t, vint8mf4_t, vint8mf4_t, vint8mf4_t, vint8mf4_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vsseg7e8_v_m)))
void vsseg7e8_v_i8mf4_m(vbool32_t, int8_t *, vint8mf4_t, vint8mf4_t, vint8mf4_t, vint8mf4_t, vint8mf4_t, vint8mf4_t, vint8mf4_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vsseg7e8_v)))
void vsseg7e8_v_i8mf8(int8_t *, vint8mf8_t, vint8mf8_t, vint8mf8_t, vint8mf8_t, vint8mf8_t, vint8mf8_t, vint8mf8_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vsseg7e8_v_m)))
void vsseg7e8_v_i8mf8_m(vbool64_t, int8_t *, vint8mf8_t, vint8mf8_t, vint8mf8_t, vint8mf8_t, vint8mf8_t, vint8mf8_t, vint8mf8_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vsseg7e8_v)))
void vsseg7e8_v_u8m1(uint8_t *, vuint8m1_t, vuint8m1_t, vuint8m1_t, vuint8m1_t, vuint8m1_t, vuint8m1_t, vuint8m1_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vsseg7e8_v_m)))
void vsseg7e8_v_u8m1_m(vbool8_t, uint8_t *, vuint8m1_t, vuint8m1_t, vuint8m1_t, vuint8m1_t, vuint8m1_t, vuint8m1_t, vuint8m1_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vsseg7e8_v)))
void vsseg7e8_v_u8mf2(uint8_t *, vuint8mf2_t, vuint8mf2_t, vuint8mf2_t, vuint8mf2_t, vuint8mf2_t, vuint8mf2_t, vuint8mf2_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vsseg7e8_v_m)))
void vsseg7e8_v_u8mf2_m(vbool16_t, uint8_t *, vuint8mf2_t, vuint8mf2_t, vuint8mf2_t, vuint8mf2_t, vuint8mf2_t, vuint8mf2_t, vuint8mf2_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vsseg7e8_v)))
void vsseg7e8_v_u8mf4(uint8_t *, vuint8mf4_t, vuint8mf4_t, vuint8mf4_t, vuint8mf4_t, vuint8mf4_t, vuint8mf4_t, vuint8mf4_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vsseg7e8_v_m)))
void vsseg7e8_v_u8mf4_m(vbool32_t, uint8_t *, vuint8mf4_t, vuint8mf4_t, vuint8mf4_t, vuint8mf4_t, vuint8mf4_t, vuint8mf4_t, vuint8mf4_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vsseg7e8_v)))
void vsseg7e8_v_u8mf8(uint8_t *, vuint8mf8_t, vuint8mf8_t, vuint8mf8_t, vuint8mf8_t, vuint8mf8_t, vuint8mf8_t, vuint8mf8_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vsseg7e8_v_m)))
void vsseg7e8_v_u8mf8_m(vbool64_t, uint8_t *, vuint8mf8_t, vuint8mf8_t, vuint8mf8_t, vuint8mf8_t, vuint8mf8_t, vuint8mf8_t, vuint8mf8_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vsseg8e8_v)))
void vsseg8e8_v_i8m1(int8_t *, vint8m1_t, vint8m1_t, vint8m1_t, vint8m1_t, vint8m1_t, vint8m1_t, vint8m1_t, vint8m1_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vsseg8e8_v_m)))
void vsseg8e8_v_i8m1_m(vbool8_t, int8_t *, vint8m1_t, vint8m1_t, vint8m1_t, vint8m1_t, vint8m1_t, vint8m1_t, vint8m1_t, vint8m1_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vsseg8e8_v)))
void vsseg8e8_v_i8mf2(int8_t *, vint8mf2_t, vint8mf2_t, vint8mf2_t, vint8mf2_t, vint8mf2_t, vint8mf2_t, vint8mf2_t, vint8mf2_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vsseg8e8_v_m)))
void vsseg8e8_v_i8mf2_m(vbool16_t, int8_t *, vint8mf2_t, vint8mf2_t, vint8mf2_t, vint8mf2_t, vint8mf2_t, vint8mf2_t, vint8mf2_t, vint8mf2_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vsseg8e8_v)))
void vsseg8e8_v_i8mf4(int8_t *, vint8mf4_t, vint8mf4_t, vint8mf4_t, vint8mf4_t, vint8mf4_t, vint8mf4_t, vint8mf4_t, vint8mf4_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vsseg8e8_v_m)))
void vsseg8e8_v_i8mf4_m(vbool32_t, int8_t *, vint8mf4_t, vint8mf4_t, vint8mf4_t, vint8mf4_t, vint8mf4_t, vint8mf4_t, vint8mf4_t, vint8mf4_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vsseg8e8_v)))
void vsseg8e8_v_i8mf8(int8_t *, vint8mf8_t, vint8mf8_t, vint8mf8_t, vint8mf8_t, vint8mf8_t, vint8mf8_t, vint8mf8_t, vint8mf8_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vsseg8e8_v_m)))
void vsseg8e8_v_i8mf8_m(vbool64_t, int8_t *, vint8mf8_t, vint8mf8_t, vint8mf8_t, vint8mf8_t, vint8mf8_t, vint8mf8_t, vint8mf8_t, vint8mf8_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vluxei16_v)))
vuint8m1_t vluxei16_v_u8m1(const uint8_t *, vuint16m2_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vluxei16_v_m)))
vuint8m1_t vluxei16_v_u8m1_m(vbool8_t, vuint8m1_t, const uint8_t *, vuint16m2_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vluxei16_v)))
vuint8m2_t vluxei16_v_u8m2(const uint8_t *, vuint16m4_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vluxei16_v_m)))
vuint8m2_t vluxei16_v_u8m2_m(vbool4_t, vuint8m2_t, const uint8_t *, vuint16m4_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vluxei16_v)))
vuint8m4_t vluxei16_v_u8m4(const uint8_t *, vuint16m8_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vluxei16_v_m)))
vuint8m4_t vluxei16_v_u8m4_m(vbool2_t, vuint8m4_t, const uint8_t *, vuint16m8_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vluxei16_v)))
vuint8mf2_t vluxei16_v_u8mf2(const uint8_t *, vuint16m1_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vluxei16_v_m)))
vuint8mf2_t vluxei16_v_u8mf2_m(vbool16_t, vuint8mf2_t, const uint8_t *, vuint16m1_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vluxei16_v)))
vuint8mf4_t vluxei16_v_u8mf4(const uint8_t *, vuint16mf2_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vluxei16_v_m)))
vuint8mf4_t vluxei16_v_u8mf4_m(vbool32_t, vuint8mf4_t, const uint8_t *, vuint16mf2_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vluxei16_v)))
vuint8mf8_t vluxei16_v_u8mf8(const uint8_t *, vuint16mf4_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vluxei16_v_m)))
vuint8mf8_t vluxei16_v_u8mf8_m(vbool64_t, vuint8mf8_t, const uint8_t *, vuint16mf4_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vsseg8e8_v)))
void vsseg8e8_v_u8m1(uint8_t *, vuint8m1_t, vuint8m1_t, vuint8m1_t, vuint8m1_t, vuint8m1_t, vuint8m1_t, vuint8m1_t, vuint8m1_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vsseg8e8_v_m)))
void vsseg8e8_v_u8m1_m(vbool8_t, uint8_t *, vuint8m1_t, vuint8m1_t, vuint8m1_t, vuint8m1_t, vuint8m1_t, vuint8m1_t, vuint8m1_t, vuint8m1_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vsseg8e8_v)))
void vsseg8e8_v_u8mf2(uint8_t *, vuint8mf2_t, vuint8mf2_t, vuint8mf2_t, vuint8mf2_t, vuint8mf2_t, vuint8mf2_t, vuint8mf2_t, vuint8mf2_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vsseg8e8_v_m)))
void vsseg8e8_v_u8mf2_m(vbool16_t, uint8_t *, vuint8mf2_t, vuint8mf2_t, vuint8mf2_t, vuint8mf2_t, vuint8mf2_t, vuint8mf2_t, vuint8mf2_t, vuint8mf2_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vsseg8e8_v)))
void vsseg8e8_v_u8mf4(uint8_t *, vuint8mf4_t, vuint8mf4_t, vuint8mf4_t, vuint8mf4_t, vuint8mf4_t, vuint8mf4_t, vuint8mf4_t, vuint8mf4_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vsseg8e8_v_m)))
void vsseg8e8_v_u8mf4_m(vbool32_t, uint8_t *, vuint8mf4_t, vuint8mf4_t, vuint8mf4_t, vuint8mf4_t, vuint8mf4_t, vuint8mf4_t, vuint8mf4_t, vuint8mf4_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vsseg8e8_v)))
void vsseg8e8_v_u8mf8(uint8_t *, vuint8mf8_t, vuint8mf8_t, vuint8mf8_t, vuint8mf8_t, vuint8mf8_t, vuint8mf8_t, vuint8mf8_t, vuint8mf8_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vsseg8e8_v_m)))
void vsseg8e8_v_u8mf8_m(vbool64_t, uint8_t *, vuint8mf8_t, vuint8mf8_t, vuint8mf8_t, vuint8mf8_t, vuint8mf8_t, vuint8mf8_t, vuint8mf8_t, vuint8mf8_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vsseg2e16_v)))
void vsseg2e16_v_i16m1(int16_t *, vint16m1_t, vint16m1_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vsseg2e16_v_m)))
void vsseg2e16_v_i16m1_m(vbool16_t, int16_t *, vint16m1_t, vint16m1_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vsseg2e16_v)))
void vsseg2e16_v_i16m2(int16_t *, vint16m2_t, vint16m2_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vsseg2e16_v_m)))
void vsseg2e16_v_i16m2_m(vbool8_t, int16_t *, vint16m2_t, vint16m2_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vsseg2e16_v)))
void vsseg2e16_v_i16m4(int16_t *, vint16m4_t, vint16m4_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vsseg2e16_v_m)))
void vsseg2e16_v_i16m4_m(vbool4_t, int16_t *, vint16m4_t, vint16m4_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vsseg2e16_v)))
void vsseg2e16_v_i16mf2(int16_t *, vint16mf2_t, vint16mf2_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vsseg2e16_v_m)))
void vsseg2e16_v_i16mf2_m(vbool32_t, int16_t *, vint16mf2_t, vint16mf2_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vsseg2e16_v)))
void vsseg2e16_v_i16mf4(int16_t *, vint16mf4_t, vint16mf4_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vsseg2e16_v_m)))
void vsseg2e16_v_i16mf4_m(vbool64_t, int16_t *, vint16mf4_t, vint16mf4_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vsseg2e16_v)))
void vsseg2e16_v_u16m1(uint16_t *, vuint16m1_t, vuint16m1_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vsseg2e16_v_m)))
void vsseg2e16_v_u16m1_m(vbool16_t, uint16_t *, vuint16m1_t, vuint16m1_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vsseg2e16_v)))
void vsseg2e16_v_u16m2(uint16_t *, vuint16m2_t, vuint16m2_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vsseg2e16_v_m)))
void vsseg2e16_v_u16m2_m(vbool8_t, uint16_t *, vuint16m2_t, vuint16m2_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vsseg2e16_v)))
void vsseg2e16_v_u16m4(uint16_t *, vuint16m4_t, vuint16m4_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vsseg2e16_v_m)))
void vsseg2e16_v_u16m4_m(vbool4_t, uint16_t *, vuint16m4_t, vuint16m4_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vsseg2e16_v)))
void vsseg2e16_v_u16mf2(uint16_t *, vuint16mf2_t, vuint16mf2_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vsseg2e16_v_m)))
void vsseg2e16_v_u16mf2_m(vbool32_t, uint16_t *, vuint16mf2_t, vuint16mf2_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vsseg2e16_v)))
void vsseg2e16_v_u16mf4(uint16_t *, vuint16mf4_t, vuint16mf4_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vsseg2e16_v_m)))
void vsseg2e16_v_u16mf4_m(vbool64_t, uint16_t *, vuint16mf4_t, vuint16mf4_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vsseg3e16_v)))
void vsseg3e16_v_i16m1(int16_t *, vint16m1_t, vint16m1_t, vint16m1_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vsseg3e16_v_m)))
void vsseg3e16_v_i16m1_m(vbool16_t, int16_t *, vint16m1_t, vint16m1_t, vint16m1_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vsseg3e16_v)))
void vsseg3e16_v_i16m2(int16_t *, vint16m2_t, vint16m2_t, vint16m2_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vsseg3e16_v_m)))
void vsseg3e16_v_i16m2_m(vbool8_t, int16_t *, vint16m2_t, vint16m2_t, vint16m2_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vsseg3e16_v)))
void vsseg3e16_v_i16mf2(int16_t *, vint16mf2_t, vint16mf2_t, vint16mf2_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vsseg3e16_v_m)))
void vsseg3e16_v_i16mf2_m(vbool32_t, int16_t *, vint16mf2_t, vint16mf2_t, vint16mf2_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vsseg3e16_v)))
void vsseg3e16_v_i16mf4(int16_t *, vint16mf4_t, vint16mf4_t, vint16mf4_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vsseg3e16_v_m)))
void vsseg3e16_v_i16mf4_m(vbool64_t, int16_t *, vint16mf4_t, vint16mf4_t, vint16mf4_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vsseg3e16_v)))
void vsseg3e16_v_u16m1(uint16_t *, vuint16m1_t, vuint16m1_t, vuint16m1_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vsseg3e16_v_m)))
void vsseg3e16_v_u16m1_m(vbool16_t, uint16_t *, vuint16m1_t, vuint16m1_t, vuint16m1_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vsseg3e16_v)))
void vsseg3e16_v_u16m2(uint16_t *, vuint16m2_t, vuint16m2_t, vuint16m2_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vsseg3e16_v_m)))
void vsseg3e16_v_u16m2_m(vbool8_t, uint16_t *, vuint16m2_t, vuint16m2_t, vuint16m2_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vsseg3e16_v)))
void vsseg3e16_v_u16mf2(uint16_t *, vuint16mf2_t, vuint16mf2_t, vuint16mf2_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vsseg3e16_v_m)))
void vsseg3e16_v_u16mf2_m(vbool32_t, uint16_t *, vuint16mf2_t, vuint16mf2_t, vuint16mf2_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vsseg3e16_v)))
void vsseg3e16_v_u16mf4(uint16_t *, vuint16mf4_t, vuint16mf4_t, vuint16mf4_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vsseg3e16_v_m)))
void vsseg3e16_v_u16mf4_m(vbool64_t, uint16_t *, vuint16mf4_t, vuint16mf4_t, vuint16mf4_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vsseg4e16_v)))
void vsseg4e16_v_i16m1(int16_t *, vint16m1_t, vint16m1_t, vint16m1_t, vint16m1_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vsseg4e16_v_m)))
void vsseg4e16_v_i16m1_m(vbool16_t, int16_t *, vint16m1_t, vint16m1_t, vint16m1_t, vint16m1_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vsseg4e16_v)))
void vsseg4e16_v_i16m2(int16_t *, vint16m2_t, vint16m2_t, vint16m2_t, vint16m2_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vsseg4e16_v_m)))
void vsseg4e16_v_i16m2_m(vbool8_t, int16_t *, vint16m2_t, vint16m2_t, vint16m2_t, vint16m2_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vsseg4e16_v)))
void vsseg4e16_v_i16mf2(int16_t *, vint16mf2_t, vint16mf2_t, vint16mf2_t, vint16mf2_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vsseg4e16_v_m)))
void vsseg4e16_v_i16mf2_m(vbool32_t, int16_t *, vint16mf2_t, vint16mf2_t, vint16mf2_t, vint16mf2_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vsseg4e16_v)))
void vsseg4e16_v_i16mf4(int16_t *, vint16mf4_t, vint16mf4_t, vint16mf4_t, vint16mf4_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vsseg4e16_v_m)))
void vsseg4e16_v_i16mf4_m(vbool64_t, int16_t *, vint16mf4_t, vint16mf4_t, vint16mf4_t, vint16mf4_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vsseg4e16_v)))
void vsseg4e16_v_u16m1(uint16_t *, vuint16m1_t, vuint16m1_t, vuint16m1_t, vuint16m1_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vsseg4e16_v_m)))
void vsseg4e16_v_u16m1_m(vbool16_t, uint16_t *, vuint16m1_t, vuint16m1_t, vuint16m1_t, vuint16m1_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vsseg4e16_v)))
void vsseg4e16_v_u16m2(uint16_t *, vuint16m2_t, vuint16m2_t, vuint16m2_t, vuint16m2_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vsseg4e16_v_m)))
void vsseg4e16_v_u16m2_m(vbool8_t, uint16_t *, vuint16m2_t, vuint16m2_t, vuint16m2_t, vuint16m2_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vsseg4e16_v)))
void vsseg4e16_v_u16mf2(uint16_t *, vuint16mf2_t, vuint16mf2_t, vuint16mf2_t, vuint16mf2_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vsseg4e16_v_m)))
void vsseg4e16_v_u16mf2_m(vbool32_t, uint16_t *, vuint16mf2_t, vuint16mf2_t, vuint16mf2_t, vuint16mf2_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vsseg4e16_v)))
void vsseg4e16_v_u16mf4(uint16_t *, vuint16mf4_t, vuint16mf4_t, vuint16mf4_t, vuint16mf4_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vsseg4e16_v_m)))
void vsseg4e16_v_u16mf4_m(vbool64_t, uint16_t *, vuint16mf4_t, vuint16mf4_t, vuint16mf4_t, vuint16mf4_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vsseg5e16_v)))
void vsseg5e16_v_i16m1(int16_t *, vint16m1_t, vint16m1_t, vint16m1_t, vint16m1_t, vint16m1_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vsseg5e16_v_m)))
void vsseg5e16_v_i16m1_m(vbool16_t, int16_t *, vint16m1_t, vint16m1_t, vint16m1_t, vint16m1_t, vint16m1_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vsseg5e16_v)))
void vsseg5e16_v_i16mf2(int16_t *, vint16mf2_t, vint16mf2_t, vint16mf2_t, vint16mf2_t, vint16mf2_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vsseg5e16_v_m)))
void vsseg5e16_v_i16mf2_m(vbool32_t, int16_t *, vint16mf2_t, vint16mf2_t, vint16mf2_t, vint16mf2_t, vint16mf2_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vsseg5e16_v)))
void vsseg5e16_v_i16mf4(int16_t *, vint16mf4_t, vint16mf4_t, vint16mf4_t, vint16mf4_t, vint16mf4_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vsseg5e16_v_m)))
void vsseg5e16_v_i16mf4_m(vbool64_t, int16_t *, vint16mf4_t, vint16mf4_t, vint16mf4_t, vint16mf4_t, vint16mf4_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vsseg5e16_v)))
void vsseg5e16_v_u16m1(uint16_t *, vuint16m1_t, vuint16m1_t, vuint16m1_t, vuint16m1_t, vuint16m1_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vsseg5e16_v_m)))
void vsseg5e16_v_u16m1_m(vbool16_t, uint16_t *, vuint16m1_t, vuint16m1_t, vuint16m1_t, vuint16m1_t, vuint16m1_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vsseg5e16_v)))
void vsseg5e16_v_u16mf2(uint16_t *, vuint16mf2_t, vuint16mf2_t, vuint16mf2_t, vuint16mf2_t, vuint16mf2_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vsseg5e16_v_m)))
void vsseg5e16_v_u16mf2_m(vbool32_t, uint16_t *, vuint16mf2_t, vuint16mf2_t, vuint16mf2_t, vuint16mf2_t, vuint16mf2_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vsseg5e16_v)))
void vsseg5e16_v_u16mf4(uint16_t *, vuint16mf4_t, vuint16mf4_t, vuint16mf4_t, vuint16mf4_t, vuint16mf4_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vsseg5e16_v_m)))
void vsseg5e16_v_u16mf4_m(vbool64_t, uint16_t *, vuint16mf4_t, vuint16mf4_t, vuint16mf4_t, vuint16mf4_t, vuint16mf4_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vsseg6e16_v)))
void vsseg6e16_v_i16m1(int16_t *, vint16m1_t, vint16m1_t, vint16m1_t, vint16m1_t, vint16m1_t, vint16m1_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vsseg6e16_v_m)))
void vsseg6e16_v_i16m1_m(vbool16_t, int16_t *, vint16m1_t, vint16m1_t, vint16m1_t, vint16m1_t, vint16m1_t, vint16m1_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vsseg6e16_v)))
void vsseg6e16_v_i16mf2(int16_t *, vint16mf2_t, vint16mf2_t, vint16mf2_t, vint16mf2_t, vint16mf2_t, vint16mf2_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vsseg6e16_v_m)))
void vsseg6e16_v_i16mf2_m(vbool32_t, int16_t *, vint16mf2_t, vint16mf2_t, vint16mf2_t, vint16mf2_t, vint16mf2_t, vint16mf2_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vsseg6e16_v)))
void vsseg6e16_v_i16mf4(int16_t *, vint16mf4_t, vint16mf4_t, vint16mf4_t, vint16mf4_t, vint16mf4_t, vint16mf4_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vsseg6e16_v_m)))
void vsseg6e16_v_i16mf4_m(vbool64_t, int16_t *, vint16mf4_t, vint16mf4_t, vint16mf4_t, vint16mf4_t, vint16mf4_t, vint16mf4_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vluxei32_v)))
vint8m1_t vluxei32_v_i8m1(const int8_t *, vuint32m4_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vluxei32_v_m)))
vint8m1_t vluxei32_v_i8m1_m(vbool8_t, vint8m1_t, const int8_t *, vuint32m4_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vluxei32_v)))
vint8m2_t vluxei32_v_i8m2(const int8_t *, vuint32m8_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vluxei32_v_m)))
vint8m2_t vluxei32_v_i8m2_m(vbool4_t, vint8m2_t, const int8_t *, vuint32m8_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vluxei32_v)))
vint8mf2_t vluxei32_v_i8mf2(const int8_t *, vuint32m2_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vluxei32_v_m)))
vint8mf2_t vluxei32_v_i8mf2_m(vbool16_t, vint8mf2_t, const int8_t *, vuint32m2_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vluxei32_v)))
vint8mf4_t vluxei32_v_i8mf4(const int8_t *, vuint32m1_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vluxei32_v_m)))
vint8mf4_t vluxei32_v_i8mf4_m(vbool32_t, vint8mf4_t, const int8_t *, vuint32m1_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vluxei32_v)))
vint8mf8_t vluxei32_v_i8mf8(const int8_t *, vuint32mf2_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vluxei32_v_m)))
vint8mf8_t vluxei32_v_i8mf8_m(vbool64_t, vint8mf8_t, const int8_t *, vuint32mf2_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vsseg6e16_v)))
void vsseg6e16_v_u16m1(uint16_t *, vuint16m1_t, vuint16m1_t, vuint16m1_t, vuint16m1_t, vuint16m1_t, vuint16m1_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vsseg6e16_v_m)))
void vsseg6e16_v_u16m1_m(vbool16_t, uint16_t *, vuint16m1_t, vuint16m1_t, vuint16m1_t, vuint16m1_t, vuint16m1_t, vuint16m1_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vsseg6e16_v)))
void vsseg6e16_v_u16mf2(uint16_t *, vuint16mf2_t, vuint16mf2_t, vuint16mf2_t, vuint16mf2_t, vuint16mf2_t, vuint16mf2_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vsseg6e16_v_m)))
void vsseg6e16_v_u16mf2_m(vbool32_t, uint16_t *, vuint16mf2_t, vuint16mf2_t, vuint16mf2_t, vuint16mf2_t, vuint16mf2_t, vuint16mf2_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vsseg6e16_v)))
void vsseg6e16_v_u16mf4(uint16_t *, vuint16mf4_t, vuint16mf4_t, vuint16mf4_t, vuint16mf4_t, vuint16mf4_t, vuint16mf4_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vsseg6e16_v_m)))
void vsseg6e16_v_u16mf4_m(vbool64_t, uint16_t *, vuint16mf4_t, vuint16mf4_t, vuint16mf4_t, vuint16mf4_t, vuint16mf4_t, vuint16mf4_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vsseg7e16_v)))
void vsseg7e16_v_i16m1(int16_t *, vint16m1_t, vint16m1_t, vint16m1_t, vint16m1_t, vint16m1_t, vint16m1_t, vint16m1_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vsseg7e16_v_m)))
void vsseg7e16_v_i16m1_m(vbool16_t, int16_t *, vint16m1_t, vint16m1_t, vint16m1_t, vint16m1_t, vint16m1_t, vint16m1_t, vint16m1_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vsseg7e16_v)))
void vsseg7e16_v_i16mf2(int16_t *, vint16mf2_t, vint16mf2_t, vint16mf2_t, vint16mf2_t, vint16mf2_t, vint16mf2_t, vint16mf2_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vsseg7e16_v_m)))
void vsseg7e16_v_i16mf2_m(vbool32_t, int16_t *, vint16mf2_t, vint16mf2_t, vint16mf2_t, vint16mf2_t, vint16mf2_t, vint16mf2_t, vint16mf2_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vsseg7e16_v)))
void vsseg7e16_v_i16mf4(int16_t *, vint16mf4_t, vint16mf4_t, vint16mf4_t, vint16mf4_t, vint16mf4_t, vint16mf4_t, vint16mf4_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vsseg7e16_v_m)))
void vsseg7e16_v_i16mf4_m(vbool64_t, int16_t *, vint16mf4_t, vint16mf4_t, vint16mf4_t, vint16mf4_t, vint16mf4_t, vint16mf4_t, vint16mf4_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vsseg7e16_v)))
void vsseg7e16_v_u16m1(uint16_t *, vuint16m1_t, vuint16m1_t, vuint16m1_t, vuint16m1_t, vuint16m1_t, vuint16m1_t, vuint16m1_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vsseg7e16_v_m)))
void vsseg7e16_v_u16m1_m(vbool16_t, uint16_t *, vuint16m1_t, vuint16m1_t, vuint16m1_t, vuint16m1_t, vuint16m1_t, vuint16m1_t, vuint16m1_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vsseg7e16_v)))
void vsseg7e16_v_u16mf2(uint16_t *, vuint16mf2_t, vuint16mf2_t, vuint16mf2_t, vuint16mf2_t, vuint16mf2_t, vuint16mf2_t, vuint16mf2_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vsseg7e16_v_m)))
void vsseg7e16_v_u16mf2_m(vbool32_t, uint16_t *, vuint16mf2_t, vuint16mf2_t, vuint16mf2_t, vuint16mf2_t, vuint16mf2_t, vuint16mf2_t, vuint16mf2_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vsseg7e16_v)))
void vsseg7e16_v_u16mf4(uint16_t *, vuint16mf4_t, vuint16mf4_t, vuint16mf4_t, vuint16mf4_t, vuint16mf4_t, vuint16mf4_t, vuint16mf4_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vsseg7e16_v_m)))
void vsseg7e16_v_u16mf4_m(vbool64_t, uint16_t *, vuint16mf4_t, vuint16mf4_t, vuint16mf4_t, vuint16mf4_t, vuint16mf4_t, vuint16mf4_t, vuint16mf4_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vsseg8e16_v)))
void vsseg8e16_v_i16m1(int16_t *, vint16m1_t, vint16m1_t, vint16m1_t, vint16m1_t, vint16m1_t, vint16m1_t, vint16m1_t, vint16m1_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vsseg8e16_v_m)))
void vsseg8e16_v_i16m1_m(vbool16_t, int16_t *, vint16m1_t, vint16m1_t, vint16m1_t, vint16m1_t, vint16m1_t, vint16m1_t, vint16m1_t, vint16m1_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vsseg8e16_v)))
void vsseg8e16_v_i16mf2(int16_t *, vint16mf2_t, vint16mf2_t, vint16mf2_t, vint16mf2_t, vint16mf2_t, vint16mf2_t, vint16mf2_t, vint16mf2_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vsseg8e16_v_m)))
void vsseg8e16_v_i16mf2_m(vbool32_t, int16_t *, vint16mf2_t, vint16mf2_t, vint16mf2_t, vint16mf2_t, vint16mf2_t, vint16mf2_t, vint16mf2_t, vint16mf2_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vsseg8e16_v)))
void vsseg8e16_v_i16mf4(int16_t *, vint16mf4_t, vint16mf4_t, vint16mf4_t, vint16mf4_t, vint16mf4_t, vint16mf4_t, vint16mf4_t, vint16mf4_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vsseg8e16_v_m)))
void vsseg8e16_v_i16mf4_m(vbool64_t, int16_t *, vint16mf4_t, vint16mf4_t, vint16mf4_t, vint16mf4_t, vint16mf4_t, vint16mf4_t, vint16mf4_t, vint16mf4_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vsseg8e16_v)))
void vsseg8e16_v_u16m1(uint16_t *, vuint16m1_t, vuint16m1_t, vuint16m1_t, vuint16m1_t, vuint16m1_t, vuint16m1_t, vuint16m1_t, vuint16m1_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vsseg8e16_v_m)))
void vsseg8e16_v_u16m1_m(vbool16_t, uint16_t *, vuint16m1_t, vuint16m1_t, vuint16m1_t, vuint16m1_t, vuint16m1_t, vuint16m1_t, vuint16m1_t, vuint16m1_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vsseg8e16_v)))
void vsseg8e16_v_u16mf2(uint16_t *, vuint16mf2_t, vuint16mf2_t, vuint16mf2_t, vuint16mf2_t, vuint16mf2_t, vuint16mf2_t, vuint16mf2_t, vuint16mf2_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vsseg8e16_v_m)))
void vsseg8e16_v_u16mf2_m(vbool32_t, uint16_t *, vuint16mf2_t, vuint16mf2_t, vuint16mf2_t, vuint16mf2_t, vuint16mf2_t, vuint16mf2_t, vuint16mf2_t, vuint16mf2_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vsseg8e16_v)))
void vsseg8e16_v_u16mf4(uint16_t *, vuint16mf4_t, vuint16mf4_t, vuint16mf4_t, vuint16mf4_t, vuint16mf4_t, vuint16mf4_t, vuint16mf4_t, vuint16mf4_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vsseg8e16_v_m)))
void vsseg8e16_v_u16mf4_m(vbool64_t, uint16_t *, vuint16mf4_t, vuint16mf4_t, vuint16mf4_t, vuint16mf4_t, vuint16mf4_t, vuint16mf4_t, vuint16mf4_t, vuint16mf4_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vsseg2e32_v)))
void vsseg2e32_v_i32m1(int32_t *, vint32m1_t, vint32m1_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vsseg2e32_v_m)))
void vsseg2e32_v_i32m1_m(vbool32_t, int32_t *, vint32m1_t, vint32m1_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vsseg2e32_v)))
void vsseg2e32_v_i32m2(int32_t *, vint32m2_t, vint32m2_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vsseg2e32_v_m)))
void vsseg2e32_v_i32m2_m(vbool16_t, int32_t *, vint32m2_t, vint32m2_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vsseg2e32_v)))
void vsseg2e32_v_i32m4(int32_t *, vint32m4_t, vint32m4_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vsseg2e32_v_m)))
void vsseg2e32_v_i32m4_m(vbool8_t, int32_t *, vint32m4_t, vint32m4_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vsseg2e32_v)))
void vsseg2e32_v_i32mf2(int32_t *, vint32mf2_t, vint32mf2_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vsseg2e32_v_m)))
void vsseg2e32_v_i32mf2_m(vbool64_t, int32_t *, vint32mf2_t, vint32mf2_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vsseg2e32_v)))
void vsseg2e32_v_u32m1(uint32_t *, vuint32m1_t, vuint32m1_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vsseg2e32_v_m)))
void vsseg2e32_v_u32m1_m(vbool32_t, uint32_t *, vuint32m1_t, vuint32m1_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vsseg2e32_v)))
void vsseg2e32_v_u32m2(uint32_t *, vuint32m2_t, vuint32m2_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vsseg2e32_v_m)))
void vsseg2e32_v_u32m2_m(vbool16_t, uint32_t *, vuint32m2_t, vuint32m2_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vsseg2e32_v)))
void vsseg2e32_v_u32m4(uint32_t *, vuint32m4_t, vuint32m4_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vsseg2e32_v_m)))
void vsseg2e32_v_u32m4_m(vbool8_t, uint32_t *, vuint32m4_t, vuint32m4_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vsseg2e32_v)))
void vsseg2e32_v_u32mf2(uint32_t *, vuint32mf2_t, vuint32mf2_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vsseg2e32_v_m)))
void vsseg2e32_v_u32mf2_m(vbool64_t, uint32_t *, vuint32mf2_t, vuint32mf2_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vsseg3e32_v)))
void vsseg3e32_v_i32m1(int32_t *, vint32m1_t, vint32m1_t, vint32m1_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vsseg3e32_v_m)))
void vsseg3e32_v_i32m1_m(vbool32_t, int32_t *, vint32m1_t, vint32m1_t, vint32m1_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vsseg3e32_v)))
void vsseg3e32_v_i32m2(int32_t *, vint32m2_t, vint32m2_t, vint32m2_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vsseg3e32_v_m)))
void vsseg3e32_v_i32m2_m(vbool16_t, int32_t *, vint32m2_t, vint32m2_t, vint32m2_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vsseg3e32_v)))
void vsseg3e32_v_i32mf2(int32_t *, vint32mf2_t, vint32mf2_t, vint32mf2_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vsseg3e32_v_m)))
void vsseg3e32_v_i32mf2_m(vbool64_t, int32_t *, vint32mf2_t, vint32mf2_t, vint32mf2_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vsseg3e32_v)))
void vsseg3e32_v_u32m1(uint32_t *, vuint32m1_t, vuint32m1_t, vuint32m1_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vsseg3e32_v_m)))
void vsseg3e32_v_u32m1_m(vbool32_t, uint32_t *, vuint32m1_t, vuint32m1_t, vuint32m1_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vsseg3e32_v)))
void vsseg3e32_v_u32m2(uint32_t *, vuint32m2_t, vuint32m2_t, vuint32m2_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vsseg3e32_v_m)))
void vsseg3e32_v_u32m2_m(vbool16_t, uint32_t *, vuint32m2_t, vuint32m2_t, vuint32m2_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vsseg3e32_v)))
void vsseg3e32_v_u32mf2(uint32_t *, vuint32mf2_t, vuint32mf2_t, vuint32mf2_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vsseg3e32_v_m)))
void vsseg3e32_v_u32mf2_m(vbool64_t, uint32_t *, vuint32mf2_t, vuint32mf2_t, vuint32mf2_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vsseg4e32_v)))
void vsseg4e32_v_i32m1(int32_t *, vint32m1_t, vint32m1_t, vint32m1_t, vint32m1_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vsseg4e32_v_m)))
void vsseg4e32_v_i32m1_m(vbool32_t, int32_t *, vint32m1_t, vint32m1_t, vint32m1_t, vint32m1_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vsseg4e32_v)))
void vsseg4e32_v_i32m2(int32_t *, vint32m2_t, vint32m2_t, vint32m2_t, vint32m2_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vsseg4e32_v_m)))
void vsseg4e32_v_i32m2_m(vbool16_t, int32_t *, vint32m2_t, vint32m2_t, vint32m2_t, vint32m2_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vsseg4e32_v)))
void vsseg4e32_v_i32mf2(int32_t *, vint32mf2_t, vint32mf2_t, vint32mf2_t, vint32mf2_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vsseg4e32_v_m)))
void vsseg4e32_v_i32mf2_m(vbool64_t, int32_t *, vint32mf2_t, vint32mf2_t, vint32mf2_t, vint32mf2_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vluxei32_v)))
vuint8m1_t vluxei32_v_u8m1(const uint8_t *, vuint32m4_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vluxei32_v_m)))
vuint8m1_t vluxei32_v_u8m1_m(vbool8_t, vuint8m1_t, const uint8_t *, vuint32m4_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vluxei32_v)))
vuint8m2_t vluxei32_v_u8m2(const uint8_t *, vuint32m8_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vluxei32_v_m)))
vuint8m2_t vluxei32_v_u8m2_m(vbool4_t, vuint8m2_t, const uint8_t *, vuint32m8_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vluxei32_v)))
vuint8mf2_t vluxei32_v_u8mf2(const uint8_t *, vuint32m2_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vluxei32_v_m)))
vuint8mf2_t vluxei32_v_u8mf2_m(vbool16_t, vuint8mf2_t, const uint8_t *, vuint32m2_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vluxei32_v)))
vuint8mf4_t vluxei32_v_u8mf4(const uint8_t *, vuint32m1_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vluxei32_v_m)))
vuint8mf4_t vluxei32_v_u8mf4_m(vbool32_t, vuint8mf4_t, const uint8_t *, vuint32m1_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vluxei32_v)))
vuint8mf8_t vluxei32_v_u8mf8(const uint8_t *, vuint32mf2_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vluxei32_v_m)))
vuint8mf8_t vluxei32_v_u8mf8_m(vbool64_t, vuint8mf8_t, const uint8_t *, vuint32mf2_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vsseg4e32_v)))
void vsseg4e32_v_u32m1(uint32_t *, vuint32m1_t, vuint32m1_t, vuint32m1_t, vuint32m1_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vsseg4e32_v_m)))
void vsseg4e32_v_u32m1_m(vbool32_t, uint32_t *, vuint32m1_t, vuint32m1_t, vuint32m1_t, vuint32m1_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vsseg4e32_v)))
void vsseg4e32_v_u32m2(uint32_t *, vuint32m2_t, vuint32m2_t, vuint32m2_t, vuint32m2_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vsseg4e32_v_m)))
void vsseg4e32_v_u32m2_m(vbool16_t, uint32_t *, vuint32m2_t, vuint32m2_t, vuint32m2_t, vuint32m2_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vsseg4e32_v)))
void vsseg4e32_v_u32mf2(uint32_t *, vuint32mf2_t, vuint32mf2_t, vuint32mf2_t, vuint32mf2_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vsseg4e32_v_m)))
void vsseg4e32_v_u32mf2_m(vbool64_t, uint32_t *, vuint32mf2_t, vuint32mf2_t, vuint32mf2_t, vuint32mf2_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vsseg5e32_v)))
void vsseg5e32_v_i32m1(int32_t *, vint32m1_t, vint32m1_t, vint32m1_t, vint32m1_t, vint32m1_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vsseg5e32_v_m)))
void vsseg5e32_v_i32m1_m(vbool32_t, int32_t *, vint32m1_t, vint32m1_t, vint32m1_t, vint32m1_t, vint32m1_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vsseg5e32_v)))
void vsseg5e32_v_i32mf2(int32_t *, vint32mf2_t, vint32mf2_t, vint32mf2_t, vint32mf2_t, vint32mf2_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vsseg5e32_v_m)))
void vsseg5e32_v_i32mf2_m(vbool64_t, int32_t *, vint32mf2_t, vint32mf2_t, vint32mf2_t, vint32mf2_t, vint32mf2_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vsseg5e32_v)))
void vsseg5e32_v_u32m1(uint32_t *, vuint32m1_t, vuint32m1_t, vuint32m1_t, vuint32m1_t, vuint32m1_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vsseg5e32_v_m)))
void vsseg5e32_v_u32m1_m(vbool32_t, uint32_t *, vuint32m1_t, vuint32m1_t, vuint32m1_t, vuint32m1_t, vuint32m1_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vsseg5e32_v)))
void vsseg5e32_v_u32mf2(uint32_t *, vuint32mf2_t, vuint32mf2_t, vuint32mf2_t, vuint32mf2_t, vuint32mf2_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vsseg5e32_v_m)))
void vsseg5e32_v_u32mf2_m(vbool64_t, uint32_t *, vuint32mf2_t, vuint32mf2_t, vuint32mf2_t, vuint32mf2_t, vuint32mf2_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vsseg6e32_v)))
void vsseg6e32_v_i32m1(int32_t *, vint32m1_t, vint32m1_t, vint32m1_t, vint32m1_t, vint32m1_t, vint32m1_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vsseg6e32_v_m)))
void vsseg6e32_v_i32m1_m(vbool32_t, int32_t *, vint32m1_t, vint32m1_t, vint32m1_t, vint32m1_t, vint32m1_t, vint32m1_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vsseg6e32_v)))
void vsseg6e32_v_i32mf2(int32_t *, vint32mf2_t, vint32mf2_t, vint32mf2_t, vint32mf2_t, vint32mf2_t, vint32mf2_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vsseg6e32_v_m)))
void vsseg6e32_v_i32mf2_m(vbool64_t, int32_t *, vint32mf2_t, vint32mf2_t, vint32mf2_t, vint32mf2_t, vint32mf2_t, vint32mf2_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vsseg6e32_v)))
void vsseg6e32_v_u32m1(uint32_t *, vuint32m1_t, vuint32m1_t, vuint32m1_t, vuint32m1_t, vuint32m1_t, vuint32m1_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vsseg6e32_v_m)))
void vsseg6e32_v_u32m1_m(vbool32_t, uint32_t *, vuint32m1_t, vuint32m1_t, vuint32m1_t, vuint32m1_t, vuint32m1_t, vuint32m1_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vsseg6e32_v)))
void vsseg6e32_v_u32mf2(uint32_t *, vuint32mf2_t, vuint32mf2_t, vuint32mf2_t, vuint32mf2_t, vuint32mf2_t, vuint32mf2_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vsseg6e32_v_m)))
void vsseg6e32_v_u32mf2_m(vbool64_t, uint32_t *, vuint32mf2_t, vuint32mf2_t, vuint32mf2_t, vuint32mf2_t, vuint32mf2_t, vuint32mf2_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vsseg7e32_v)))
void vsseg7e32_v_i32m1(int32_t *, vint32m1_t, vint32m1_t, vint32m1_t, vint32m1_t, vint32m1_t, vint32m1_t, vint32m1_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vsseg7e32_v_m)))
void vsseg7e32_v_i32m1_m(vbool32_t, int32_t *, vint32m1_t, vint32m1_t, vint32m1_t, vint32m1_t, vint32m1_t, vint32m1_t, vint32m1_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vsseg7e32_v)))
void vsseg7e32_v_i32mf2(int32_t *, vint32mf2_t, vint32mf2_t, vint32mf2_t, vint32mf2_t, vint32mf2_t, vint32mf2_t, vint32mf2_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vsseg7e32_v_m)))
void vsseg7e32_v_i32mf2_m(vbool64_t, int32_t *, vint32mf2_t, vint32mf2_t, vint32mf2_t, vint32mf2_t, vint32mf2_t, vint32mf2_t, vint32mf2_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vsseg7e32_v)))
void vsseg7e32_v_u32m1(uint32_t *, vuint32m1_t, vuint32m1_t, vuint32m1_t, vuint32m1_t, vuint32m1_t, vuint32m1_t, vuint32m1_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vsseg7e32_v_m)))
void vsseg7e32_v_u32m1_m(vbool32_t, uint32_t *, vuint32m1_t, vuint32m1_t, vuint32m1_t, vuint32m1_t, vuint32m1_t, vuint32m1_t, vuint32m1_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vsseg7e32_v)))
void vsseg7e32_v_u32mf2(uint32_t *, vuint32mf2_t, vuint32mf2_t, vuint32mf2_t, vuint32mf2_t, vuint32mf2_t, vuint32mf2_t, vuint32mf2_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vsseg7e32_v_m)))
void vsseg7e32_v_u32mf2_m(vbool64_t, uint32_t *, vuint32mf2_t, vuint32mf2_t, vuint32mf2_t, vuint32mf2_t, vuint32mf2_t, vuint32mf2_t, vuint32mf2_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vsseg8e32_v)))
void vsseg8e32_v_i32m1(int32_t *, vint32m1_t, vint32m1_t, vint32m1_t, vint32m1_t, vint32m1_t, vint32m1_t, vint32m1_t, vint32m1_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vsseg8e32_v_m)))
void vsseg8e32_v_i32m1_m(vbool32_t, int32_t *, vint32m1_t, vint32m1_t, vint32m1_t, vint32m1_t, vint32m1_t, vint32m1_t, vint32m1_t, vint32m1_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vsseg8e32_v)))
void vsseg8e32_v_i32mf2(int32_t *, vint32mf2_t, vint32mf2_t, vint32mf2_t, vint32mf2_t, vint32mf2_t, vint32mf2_t, vint32mf2_t, vint32mf2_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vsseg8e32_v_m)))
void vsseg8e32_v_i32mf2_m(vbool64_t, int32_t *, vint32mf2_t, vint32mf2_t, vint32mf2_t, vint32mf2_t, vint32mf2_t, vint32mf2_t, vint32mf2_t, vint32mf2_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vsseg8e32_v)))
void vsseg8e32_v_u32m1(uint32_t *, vuint32m1_t, vuint32m1_t, vuint32m1_t, vuint32m1_t, vuint32m1_t, vuint32m1_t, vuint32m1_t, vuint32m1_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vsseg8e32_v_m)))
void vsseg8e32_v_u32m1_m(vbool32_t, uint32_t *, vuint32m1_t, vuint32m1_t, vuint32m1_t, vuint32m1_t, vuint32m1_t, vuint32m1_t, vuint32m1_t, vuint32m1_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vsseg8e32_v)))
void vsseg8e32_v_u32mf2(uint32_t *, vuint32mf2_t, vuint32mf2_t, vuint32mf2_t, vuint32mf2_t, vuint32mf2_t, vuint32mf2_t, vuint32mf2_t, vuint32mf2_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vsseg8e32_v_m)))
void vsseg8e32_v_u32mf2_m(vbool64_t, uint32_t *, vuint32mf2_t, vuint32mf2_t, vuint32mf2_t, vuint32mf2_t, vuint32mf2_t, vuint32mf2_t, vuint32mf2_t, vuint32mf2_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vluxei8_v)))
vint16m1_t vluxei8_v_i16m1(const int16_t *, vuint8mf2_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vluxei8_v_m)))
vint16m1_t vluxei8_v_i16m1_m(vbool16_t, vint16m1_t, const int16_t *, vuint8mf2_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vluxei8_v)))
vint16m2_t vluxei8_v_i16m2(const int16_t *, vuint8m1_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vluxei8_v_m)))
vint16m2_t vluxei8_v_i16m2_m(vbool8_t, vint16m2_t, const int16_t *, vuint8m1_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vluxei8_v)))
vint16m4_t vluxei8_v_i16m4(const int16_t *, vuint8m2_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vluxei8_v_m)))
vint16m4_t vluxei8_v_i16m4_m(vbool4_t, vint16m4_t, const int16_t *, vuint8m2_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vluxei8_v)))
vint16m8_t vluxei8_v_i16m8(const int16_t *, vuint8m4_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vluxei8_v_m)))
vint16m8_t vluxei8_v_i16m8_m(vbool2_t, vint16m8_t, const int16_t *, vuint8m4_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vluxei8_v)))
vint16mf2_t vluxei8_v_i16mf2(const int16_t *, vuint8mf4_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vluxei8_v_m)))
vint16mf2_t vluxei8_v_i16mf2_m(vbool32_t, vint16mf2_t, const int16_t *, vuint8mf4_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vluxei8_v)))
vint16mf4_t vluxei8_v_i16mf4(const int16_t *, vuint8mf8_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vluxei8_v_m)))
vint16mf4_t vluxei8_v_i16mf4_m(vbool64_t, vint16mf4_t, const int16_t *, vuint8mf8_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vluxei8_v)))
vuint16m1_t vluxei8_v_u16m1(const uint16_t *, vuint8mf2_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vluxei8_v_m)))
vuint16m1_t vluxei8_v_u16m1_m(vbool16_t, vuint16m1_t, const uint16_t *, vuint8mf2_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vluxei8_v)))
vuint16m2_t vluxei8_v_u16m2(const uint16_t *, vuint8m1_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vluxei8_v_m)))
vuint16m2_t vluxei8_v_u16m2_m(vbool8_t, vuint16m2_t, const uint16_t *, vuint8m1_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vluxei8_v)))
vuint16m4_t vluxei8_v_u16m4(const uint16_t *, vuint8m2_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vluxei8_v_m)))
vuint16m4_t vluxei8_v_u16m4_m(vbool4_t, vuint16m4_t, const uint16_t *, vuint8m2_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vluxei8_v)))
vuint16m8_t vluxei8_v_u16m8(const uint16_t *, vuint8m4_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vluxei8_v_m)))
vuint16m8_t vluxei8_v_u16m8_m(vbool2_t, vuint16m8_t, const uint16_t *, vuint8m4_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vluxei8_v)))
vuint16mf2_t vluxei8_v_u16mf2(const uint16_t *, vuint8mf4_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vluxei8_v_m)))
vuint16mf2_t vluxei8_v_u16mf2_m(vbool32_t, vuint16mf2_t, const uint16_t *, vuint8mf4_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vluxei8_v)))
vuint16mf4_t vluxei8_v_u16mf4(const uint16_t *, vuint8mf8_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vluxei8_v_m)))
vuint16mf4_t vluxei8_v_u16mf4_m(vbool64_t, vuint16mf4_t, const uint16_t *, vuint8mf8_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vluxei16_v)))
vint16m1_t vluxei16_v_i16m1(const int16_t *, vuint16m1_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vluxei16_v_m)))
vint16m1_t vluxei16_v_i16m1_m(vbool16_t, vint16m1_t, const int16_t *, vuint16m1_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vluxei16_v)))
vint16m2_t vluxei16_v_i16m2(const int16_t *, vuint16m2_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vluxei16_v_m)))
vint16m2_t vluxei16_v_i16m2_m(vbool8_t, vint16m2_t, const int16_t *, vuint16m2_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vluxei16_v)))
vint16m4_t vluxei16_v_i16m4(const int16_t *, vuint16m4_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vluxei16_v_m)))
vint16m4_t vluxei16_v_i16m4_m(vbool4_t, vint16m4_t, const int16_t *, vuint16m4_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vluxei16_v)))
vint16m8_t vluxei16_v_i16m8(const int16_t *, vuint16m8_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vluxei16_v_m)))
vint16m8_t vluxei16_v_i16m8_m(vbool2_t, vint16m8_t, const int16_t *, vuint16m8_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vluxei16_v)))
vint16mf2_t vluxei16_v_i16mf2(const int16_t *, vuint16mf2_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vluxei16_v_m)))
vint16mf2_t vluxei16_v_i16mf2_m(vbool32_t, vint16mf2_t, const int16_t *, vuint16mf2_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vluxei16_v)))
vint16mf4_t vluxei16_v_i16mf4(const int16_t *, vuint16mf4_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vluxei16_v_m)))
vint16mf4_t vluxei16_v_i16mf4_m(vbool64_t, vint16mf4_t, const int16_t *, vuint16mf4_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vluxei16_v)))
vuint16m1_t vluxei16_v_u16m1(const uint16_t *, vuint16m1_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vluxei16_v_m)))
vuint16m1_t vluxei16_v_u16m1_m(vbool16_t, vuint16m1_t, const uint16_t *, vuint16m1_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vluxei16_v)))
vuint16m2_t vluxei16_v_u16m2(const uint16_t *, vuint16m2_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vluxei16_v_m)))
vuint16m2_t vluxei16_v_u16m2_m(vbool8_t, vuint16m2_t, const uint16_t *, vuint16m2_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vluxei16_v)))
vuint16m4_t vluxei16_v_u16m4(const uint16_t *, vuint16m4_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vluxei16_v_m)))
vuint16m4_t vluxei16_v_u16m4_m(vbool4_t, vuint16m4_t, const uint16_t *, vuint16m4_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vluxei16_v)))
vuint16m8_t vluxei16_v_u16m8(const uint16_t *, vuint16m8_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vluxei16_v_m)))
vuint16m8_t vluxei16_v_u16m8_m(vbool2_t, vuint16m8_t, const uint16_t *, vuint16m8_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vluxei16_v)))
vuint16mf2_t vluxei16_v_u16mf2(const uint16_t *, vuint16mf2_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vluxei16_v_m)))
vuint16mf2_t vluxei16_v_u16mf2_m(vbool32_t, vuint16mf2_t, const uint16_t *, vuint16mf2_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vluxei16_v)))
vuint16mf4_t vluxei16_v_u16mf4(const uint16_t *, vuint16mf4_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vluxei16_v_m)))
vuint16mf4_t vluxei16_v_u16mf4_m(vbool64_t, vuint16mf4_t, const uint16_t *, vuint16mf4_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vssseg3e8_v)))
void vssseg3e8_v_i8m1(int8_t *, ptrdiff_t, vint8m1_t, vint8m1_t, vint8m1_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vssseg3e8_v_m)))
void vssseg3e8_v_i8m1_m(vbool8_t, int8_t *, ptrdiff_t, vint8m1_t, vint8m1_t, vint8m1_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vssseg3e8_v)))
void vssseg3e8_v_i8m2(int8_t *, ptrdiff_t, vint8m2_t, vint8m2_t, vint8m2_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vssseg3e8_v_m)))
void vssseg3e8_v_i8m2_m(vbool4_t, int8_t *, ptrdiff_t, vint8m2_t, vint8m2_t, vint8m2_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vssseg3e8_v)))
void vssseg3e8_v_i8mf2(int8_t *, ptrdiff_t, vint8mf2_t, vint8mf2_t, vint8mf2_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vssseg3e8_v_m)))
void vssseg3e8_v_i8mf2_m(vbool16_t, int8_t *, ptrdiff_t, vint8mf2_t, vint8mf2_t, vint8mf2_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vssseg3e8_v)))
void vssseg3e8_v_i8mf4(int8_t *, ptrdiff_t, vint8mf4_t, vint8mf4_t, vint8mf4_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vssseg3e8_v_m)))
void vssseg3e8_v_i8mf4_m(vbool32_t, int8_t *, ptrdiff_t, vint8mf4_t, vint8mf4_t, vint8mf4_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vssseg3e8_v)))
void vssseg3e8_v_i8mf8(int8_t *, ptrdiff_t, vint8mf8_t, vint8mf8_t, vint8mf8_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vssseg3e8_v_m)))
void vssseg3e8_v_i8mf8_m(vbool64_t, int8_t *, ptrdiff_t, vint8mf8_t, vint8mf8_t, vint8mf8_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vssseg3e8_v)))
void vssseg3e8_v_u8m1(uint8_t *, ptrdiff_t, vuint8m1_t, vuint8m1_t, vuint8m1_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vssseg3e8_v_m)))
void vssseg3e8_v_u8m1_m(vbool8_t, uint8_t *, ptrdiff_t, vuint8m1_t, vuint8m1_t, vuint8m1_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vssseg3e8_v)))
void vssseg3e8_v_u8m2(uint8_t *, ptrdiff_t, vuint8m2_t, vuint8m2_t, vuint8m2_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vssseg3e8_v_m)))
void vssseg3e8_v_u8m2_m(vbool4_t, uint8_t *, ptrdiff_t, vuint8m2_t, vuint8m2_t, vuint8m2_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vssseg3e8_v)))
void vssseg3e8_v_u8mf2(uint8_t *, ptrdiff_t, vuint8mf2_t, vuint8mf2_t, vuint8mf2_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vssseg3e8_v_m)))
void vssseg3e8_v_u8mf2_m(vbool16_t, uint8_t *, ptrdiff_t, vuint8mf2_t, vuint8mf2_t, vuint8mf2_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vssseg3e8_v)))
void vssseg3e8_v_u8mf4(uint8_t *, ptrdiff_t, vuint8mf4_t, vuint8mf4_t, vuint8mf4_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vssseg3e8_v_m)))
void vssseg3e8_v_u8mf4_m(vbool32_t, uint8_t *, ptrdiff_t, vuint8mf4_t, vuint8mf4_t, vuint8mf4_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vssseg3e8_v)))
void vssseg3e8_v_u8mf8(uint8_t *, ptrdiff_t, vuint8mf8_t, vuint8mf8_t, vuint8mf8_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vssseg3e8_v_m)))
void vssseg3e8_v_u8mf8_m(vbool64_t, uint8_t *, ptrdiff_t, vuint8mf8_t, vuint8mf8_t, vuint8mf8_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vssseg4e8_v)))
void vssseg4e8_v_i8m1(int8_t *, ptrdiff_t, vint8m1_t, vint8m1_t, vint8m1_t, vint8m1_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vssseg4e8_v_m)))
void vssseg4e8_v_i8m1_m(vbool8_t, int8_t *, ptrdiff_t, vint8m1_t, vint8m1_t, vint8m1_t, vint8m1_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vssseg4e8_v)))
void vssseg4e8_v_i8m2(int8_t *, ptrdiff_t, vint8m2_t, vint8m2_t, vint8m2_t, vint8m2_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vssseg4e8_v_m)))
void vssseg4e8_v_i8m2_m(vbool4_t, int8_t *, ptrdiff_t, vint8m2_t, vint8m2_t, vint8m2_t, vint8m2_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vssseg4e8_v)))
void vssseg4e8_v_i8mf2(int8_t *, ptrdiff_t, vint8mf2_t, vint8mf2_t, vint8mf2_t, vint8mf2_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vssseg4e8_v_m)))
void vssseg4e8_v_i8mf2_m(vbool16_t, int8_t *, ptrdiff_t, vint8mf2_t, vint8mf2_t, vint8mf2_t, vint8mf2_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vssseg4e8_v)))
void vssseg4e8_v_i8mf4(int8_t *, ptrdiff_t, vint8mf4_t, vint8mf4_t, vint8mf4_t, vint8mf4_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vssseg4e8_v_m)))
void vssseg4e8_v_i8mf4_m(vbool32_t, int8_t *, ptrdiff_t, vint8mf4_t, vint8mf4_t, vint8mf4_t, vint8mf4_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vssseg4e8_v)))
void vssseg4e8_v_i8mf8(int8_t *, ptrdiff_t, vint8mf8_t, vint8mf8_t, vint8mf8_t, vint8mf8_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vssseg4e8_v_m)))
void vssseg4e8_v_i8mf8_m(vbool64_t, int8_t *, ptrdiff_t, vint8mf8_t, vint8mf8_t, vint8mf8_t, vint8mf8_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vssseg4e8_v)))
void vssseg4e8_v_u8m1(uint8_t *, ptrdiff_t, vuint8m1_t, vuint8m1_t, vuint8m1_t, vuint8m1_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vssseg4e8_v_m)))
void vssseg4e8_v_u8m1_m(vbool8_t, uint8_t *, ptrdiff_t, vuint8m1_t, vuint8m1_t, vuint8m1_t, vuint8m1_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vssseg4e8_v)))
void vssseg4e8_v_u8m2(uint8_t *, ptrdiff_t, vuint8m2_t, vuint8m2_t, vuint8m2_t, vuint8m2_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vssseg4e8_v_m)))
void vssseg4e8_v_u8m2_m(vbool4_t, uint8_t *, ptrdiff_t, vuint8m2_t, vuint8m2_t, vuint8m2_t, vuint8m2_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vssseg4e8_v)))
void vssseg4e8_v_u8mf2(uint8_t *, ptrdiff_t, vuint8mf2_t, vuint8mf2_t, vuint8mf2_t, vuint8mf2_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vssseg4e8_v_m)))
void vssseg4e8_v_u8mf2_m(vbool16_t, uint8_t *, ptrdiff_t, vuint8mf2_t, vuint8mf2_t, vuint8mf2_t, vuint8mf2_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vssseg4e8_v)))
void vssseg4e8_v_u8mf4(uint8_t *, ptrdiff_t, vuint8mf4_t, vuint8mf4_t, vuint8mf4_t, vuint8mf4_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vssseg4e8_v_m)))
void vssseg4e8_v_u8mf4_m(vbool32_t, uint8_t *, ptrdiff_t, vuint8mf4_t, vuint8mf4_t, vuint8mf4_t, vuint8mf4_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vssseg4e8_v)))
void vssseg4e8_v_u8mf8(uint8_t *, ptrdiff_t, vuint8mf8_t, vuint8mf8_t, vuint8mf8_t, vuint8mf8_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vssseg4e8_v_m)))
void vssseg4e8_v_u8mf8_m(vbool64_t, uint8_t *, ptrdiff_t, vuint8mf8_t, vuint8mf8_t, vuint8mf8_t, vuint8mf8_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vssseg5e8_v)))
void vssseg5e8_v_i8m1(int8_t *, ptrdiff_t, vint8m1_t, vint8m1_t, vint8m1_t, vint8m1_t, vint8m1_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vssseg5e8_v_m)))
void vssseg5e8_v_i8m1_m(vbool8_t, int8_t *, ptrdiff_t, vint8m1_t, vint8m1_t, vint8m1_t, vint8m1_t, vint8m1_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vssseg5e8_v)))
void vssseg5e8_v_i8mf2(int8_t *, ptrdiff_t, vint8mf2_t, vint8mf2_t, vint8mf2_t, vint8mf2_t, vint8mf2_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vssseg5e8_v_m)))
void vssseg5e8_v_i8mf2_m(vbool16_t, int8_t *, ptrdiff_t, vint8mf2_t, vint8mf2_t, vint8mf2_t, vint8mf2_t, vint8mf2_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vssseg5e8_v)))
void vssseg5e8_v_i8mf4(int8_t *, ptrdiff_t, vint8mf4_t, vint8mf4_t, vint8mf4_t, vint8mf4_t, vint8mf4_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vssseg5e8_v_m)))
void vssseg5e8_v_i8mf4_m(vbool32_t, int8_t *, ptrdiff_t, vint8mf4_t, vint8mf4_t, vint8mf4_t, vint8mf4_t, vint8mf4_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vssseg5e8_v)))
void vssseg5e8_v_i8mf8(int8_t *, ptrdiff_t, vint8mf8_t, vint8mf8_t, vint8mf8_t, vint8mf8_t, vint8mf8_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vssseg5e8_v_m)))
void vssseg5e8_v_i8mf8_m(vbool64_t, int8_t *, ptrdiff_t, vint8mf8_t, vint8mf8_t, vint8mf8_t, vint8mf8_t, vint8mf8_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vluxei32_v)))
vint16m1_t vluxei32_v_i16m1(const int16_t *, vuint32m2_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vluxei32_v_m)))
vint16m1_t vluxei32_v_i16m1_m(vbool16_t, vint16m1_t, const int16_t *, vuint32m2_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vluxei32_v)))
vint16m2_t vluxei32_v_i16m2(const int16_t *, vuint32m4_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vluxei32_v_m)))
vint16m2_t vluxei32_v_i16m2_m(vbool8_t, vint16m2_t, const int16_t *, vuint32m4_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vluxei32_v)))
vint16m4_t vluxei32_v_i16m4(const int16_t *, vuint32m8_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vluxei32_v_m)))
vint16m4_t vluxei32_v_i16m4_m(vbool4_t, vint16m4_t, const int16_t *, vuint32m8_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vluxei32_v)))
vint16mf2_t vluxei32_v_i16mf2(const int16_t *, vuint32m1_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vluxei32_v_m)))
vint16mf2_t vluxei32_v_i16mf2_m(vbool32_t, vint16mf2_t, const int16_t *, vuint32m1_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vluxei32_v)))
vint16mf4_t vluxei32_v_i16mf4(const int16_t *, vuint32mf2_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vluxei32_v_m)))
vint16mf4_t vluxei32_v_i16mf4_m(vbool64_t, vint16mf4_t, const int16_t *, vuint32mf2_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vssseg5e8_v)))
void vssseg5e8_v_u8m1(uint8_t *, ptrdiff_t, vuint8m1_t, vuint8m1_t, vuint8m1_t, vuint8m1_t, vuint8m1_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vssseg5e8_v_m)))
void vssseg5e8_v_u8m1_m(vbool8_t, uint8_t *, ptrdiff_t, vuint8m1_t, vuint8m1_t, vuint8m1_t, vuint8m1_t, vuint8m1_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vssseg5e8_v)))
void vssseg5e8_v_u8mf2(uint8_t *, ptrdiff_t, vuint8mf2_t, vuint8mf2_t, vuint8mf2_t, vuint8mf2_t, vuint8mf2_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vssseg5e8_v_m)))
void vssseg5e8_v_u8mf2_m(vbool16_t, uint8_t *, ptrdiff_t, vuint8mf2_t, vuint8mf2_t, vuint8mf2_t, vuint8mf2_t, vuint8mf2_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vssseg5e8_v)))
void vssseg5e8_v_u8mf4(uint8_t *, ptrdiff_t, vuint8mf4_t, vuint8mf4_t, vuint8mf4_t, vuint8mf4_t, vuint8mf4_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vssseg5e8_v_m)))
void vssseg5e8_v_u8mf4_m(vbool32_t, uint8_t *, ptrdiff_t, vuint8mf4_t, vuint8mf4_t, vuint8mf4_t, vuint8mf4_t, vuint8mf4_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vssseg5e8_v)))
void vssseg5e8_v_u8mf8(uint8_t *, ptrdiff_t, vuint8mf8_t, vuint8mf8_t, vuint8mf8_t, vuint8mf8_t, vuint8mf8_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vssseg5e8_v_m)))
void vssseg5e8_v_u8mf8_m(vbool64_t, uint8_t *, ptrdiff_t, vuint8mf8_t, vuint8mf8_t, vuint8mf8_t, vuint8mf8_t, vuint8mf8_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vssseg6e8_v)))
void vssseg6e8_v_i8m1(int8_t *, ptrdiff_t, vint8m1_t, vint8m1_t, vint8m1_t, vint8m1_t, vint8m1_t, vint8m1_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vssseg6e8_v_m)))
void vssseg6e8_v_i8m1_m(vbool8_t, int8_t *, ptrdiff_t, vint8m1_t, vint8m1_t, vint8m1_t, vint8m1_t, vint8m1_t, vint8m1_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vssseg6e8_v)))
void vssseg6e8_v_i8mf2(int8_t *, ptrdiff_t, vint8mf2_t, vint8mf2_t, vint8mf2_t, vint8mf2_t, vint8mf2_t, vint8mf2_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vssseg6e8_v_m)))
void vssseg6e8_v_i8mf2_m(vbool16_t, int8_t *, ptrdiff_t, vint8mf2_t, vint8mf2_t, vint8mf2_t, vint8mf2_t, vint8mf2_t, vint8mf2_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vssseg6e8_v)))
void vssseg6e8_v_i8mf4(int8_t *, ptrdiff_t, vint8mf4_t, vint8mf4_t, vint8mf4_t, vint8mf4_t, vint8mf4_t, vint8mf4_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vssseg6e8_v_m)))
void vssseg6e8_v_i8mf4_m(vbool32_t, int8_t *, ptrdiff_t, vint8mf4_t, vint8mf4_t, vint8mf4_t, vint8mf4_t, vint8mf4_t, vint8mf4_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vssseg6e8_v)))
void vssseg6e8_v_i8mf8(int8_t *, ptrdiff_t, vint8mf8_t, vint8mf8_t, vint8mf8_t, vint8mf8_t, vint8mf8_t, vint8mf8_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vssseg6e8_v_m)))
void vssseg6e8_v_i8mf8_m(vbool64_t, int8_t *, ptrdiff_t, vint8mf8_t, vint8mf8_t, vint8mf8_t, vint8mf8_t, vint8mf8_t, vint8mf8_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vssseg6e8_v)))
void vssseg6e8_v_u8m1(uint8_t *, ptrdiff_t, vuint8m1_t, vuint8m1_t, vuint8m1_t, vuint8m1_t, vuint8m1_t, vuint8m1_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vssseg6e8_v_m)))
void vssseg6e8_v_u8m1_m(vbool8_t, uint8_t *, ptrdiff_t, vuint8m1_t, vuint8m1_t, vuint8m1_t, vuint8m1_t, vuint8m1_t, vuint8m1_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vssseg6e8_v)))
void vssseg6e8_v_u8mf2(uint8_t *, ptrdiff_t, vuint8mf2_t, vuint8mf2_t, vuint8mf2_t, vuint8mf2_t, vuint8mf2_t, vuint8mf2_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vssseg6e8_v_m)))
void vssseg6e8_v_u8mf2_m(vbool16_t, uint8_t *, ptrdiff_t, vuint8mf2_t, vuint8mf2_t, vuint8mf2_t, vuint8mf2_t, vuint8mf2_t, vuint8mf2_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vssseg6e8_v)))
void vssseg6e8_v_u8mf4(uint8_t *, ptrdiff_t, vuint8mf4_t, vuint8mf4_t, vuint8mf4_t, vuint8mf4_t, vuint8mf4_t, vuint8mf4_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vssseg6e8_v_m)))
void vssseg6e8_v_u8mf4_m(vbool32_t, uint8_t *, ptrdiff_t, vuint8mf4_t, vuint8mf4_t, vuint8mf4_t, vuint8mf4_t, vuint8mf4_t, vuint8mf4_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vssseg6e8_v)))
void vssseg6e8_v_u8mf8(uint8_t *, ptrdiff_t, vuint8mf8_t, vuint8mf8_t, vuint8mf8_t, vuint8mf8_t, vuint8mf8_t, vuint8mf8_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vssseg6e8_v_m)))
void vssseg6e8_v_u8mf8_m(vbool64_t, uint8_t *, ptrdiff_t, vuint8mf8_t, vuint8mf8_t, vuint8mf8_t, vuint8mf8_t, vuint8mf8_t, vuint8mf8_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vssseg7e8_v)))
void vssseg7e8_v_i8m1(int8_t *, ptrdiff_t, vint8m1_t, vint8m1_t, vint8m1_t, vint8m1_t, vint8m1_t, vint8m1_t, vint8m1_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vssseg7e8_v_m)))
void vssseg7e8_v_i8m1_m(vbool8_t, int8_t *, ptrdiff_t, vint8m1_t, vint8m1_t, vint8m1_t, vint8m1_t, vint8m1_t, vint8m1_t, vint8m1_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vssseg7e8_v)))
void vssseg7e8_v_i8mf2(int8_t *, ptrdiff_t, vint8mf2_t, vint8mf2_t, vint8mf2_t, vint8mf2_t, vint8mf2_t, vint8mf2_t, vint8mf2_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vssseg7e8_v_m)))
void vssseg7e8_v_i8mf2_m(vbool16_t, int8_t *, ptrdiff_t, vint8mf2_t, vint8mf2_t, vint8mf2_t, vint8mf2_t, vint8mf2_t, vint8mf2_t, vint8mf2_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vssseg7e8_v)))
void vssseg7e8_v_i8mf4(int8_t *, ptrdiff_t, vint8mf4_t, vint8mf4_t, vint8mf4_t, vint8mf4_t, vint8mf4_t, vint8mf4_t, vint8mf4_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vssseg7e8_v_m)))
void vssseg7e8_v_i8mf4_m(vbool32_t, int8_t *, ptrdiff_t, vint8mf4_t, vint8mf4_t, vint8mf4_t, vint8mf4_t, vint8mf4_t, vint8mf4_t, vint8mf4_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vssseg7e8_v)))
void vssseg7e8_v_i8mf8(int8_t *, ptrdiff_t, vint8mf8_t, vint8mf8_t, vint8mf8_t, vint8mf8_t, vint8mf8_t, vint8mf8_t, vint8mf8_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vssseg7e8_v_m)))
void vssseg7e8_v_i8mf8_m(vbool64_t, int8_t *, ptrdiff_t, vint8mf8_t, vint8mf8_t, vint8mf8_t, vint8mf8_t, vint8mf8_t, vint8mf8_t, vint8mf8_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vssseg7e8_v)))
void vssseg7e8_v_u8m1(uint8_t *, ptrdiff_t, vuint8m1_t, vuint8m1_t, vuint8m1_t, vuint8m1_t, vuint8m1_t, vuint8m1_t, vuint8m1_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vssseg7e8_v_m)))
void vssseg7e8_v_u8m1_m(vbool8_t, uint8_t *, ptrdiff_t, vuint8m1_t, vuint8m1_t, vuint8m1_t, vuint8m1_t, vuint8m1_t, vuint8m1_t, vuint8m1_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vssseg7e8_v)))
void vssseg7e8_v_u8mf2(uint8_t *, ptrdiff_t, vuint8mf2_t, vuint8mf2_t, vuint8mf2_t, vuint8mf2_t, vuint8mf2_t, vuint8mf2_t, vuint8mf2_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vssseg7e8_v_m)))
void vssseg7e8_v_u8mf2_m(vbool16_t, uint8_t *, ptrdiff_t, vuint8mf2_t, vuint8mf2_t, vuint8mf2_t, vuint8mf2_t, vuint8mf2_t, vuint8mf2_t, vuint8mf2_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vssseg7e8_v)))
void vssseg7e8_v_u8mf4(uint8_t *, ptrdiff_t, vuint8mf4_t, vuint8mf4_t, vuint8mf4_t, vuint8mf4_t, vuint8mf4_t, vuint8mf4_t, vuint8mf4_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vssseg7e8_v_m)))
void vssseg7e8_v_u8mf4_m(vbool32_t, uint8_t *, ptrdiff_t, vuint8mf4_t, vuint8mf4_t, vuint8mf4_t, vuint8mf4_t, vuint8mf4_t, vuint8mf4_t, vuint8mf4_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vssseg7e8_v)))
void vssseg7e8_v_u8mf8(uint8_t *, ptrdiff_t, vuint8mf8_t, vuint8mf8_t, vuint8mf8_t, vuint8mf8_t, vuint8mf8_t, vuint8mf8_t, vuint8mf8_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vssseg7e8_v_m)))
void vssseg7e8_v_u8mf8_m(vbool64_t, uint8_t *, ptrdiff_t, vuint8mf8_t, vuint8mf8_t, vuint8mf8_t, vuint8mf8_t, vuint8mf8_t, vuint8mf8_t, vuint8mf8_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vssseg8e8_v)))
void vssseg8e8_v_i8m1(int8_t *, ptrdiff_t, vint8m1_t, vint8m1_t, vint8m1_t, vint8m1_t, vint8m1_t, vint8m1_t, vint8m1_t, vint8m1_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vssseg8e8_v_m)))
void vssseg8e8_v_i8m1_m(vbool8_t, int8_t *, ptrdiff_t, vint8m1_t, vint8m1_t, vint8m1_t, vint8m1_t, vint8m1_t, vint8m1_t, vint8m1_t, vint8m1_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vssseg8e8_v)))
void vssseg8e8_v_i8mf2(int8_t *, ptrdiff_t, vint8mf2_t, vint8mf2_t, vint8mf2_t, vint8mf2_t, vint8mf2_t, vint8mf2_t, vint8mf2_t, vint8mf2_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vssseg8e8_v_m)))
void vssseg8e8_v_i8mf2_m(vbool16_t, int8_t *, ptrdiff_t, vint8mf2_t, vint8mf2_t, vint8mf2_t, vint8mf2_t, vint8mf2_t, vint8mf2_t, vint8mf2_t, vint8mf2_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vssseg8e8_v)))
void vssseg8e8_v_i8mf4(int8_t *, ptrdiff_t, vint8mf4_t, vint8mf4_t, vint8mf4_t, vint8mf4_t, vint8mf4_t, vint8mf4_t, vint8mf4_t, vint8mf4_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vssseg8e8_v_m)))
void vssseg8e8_v_i8mf4_m(vbool32_t, int8_t *, ptrdiff_t, vint8mf4_t, vint8mf4_t, vint8mf4_t, vint8mf4_t, vint8mf4_t, vint8mf4_t, vint8mf4_t, vint8mf4_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vssseg8e8_v)))
void vssseg8e8_v_i8mf8(int8_t *, ptrdiff_t, vint8mf8_t, vint8mf8_t, vint8mf8_t, vint8mf8_t, vint8mf8_t, vint8mf8_t, vint8mf8_t, vint8mf8_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vssseg8e8_v_m)))
void vssseg8e8_v_i8mf8_m(vbool64_t, int8_t *, ptrdiff_t, vint8mf8_t, vint8mf8_t, vint8mf8_t, vint8mf8_t, vint8mf8_t, vint8mf8_t, vint8mf8_t, vint8mf8_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vssseg8e8_v)))
void vssseg8e8_v_u8m1(uint8_t *, ptrdiff_t, vuint8m1_t, vuint8m1_t, vuint8m1_t, vuint8m1_t, vuint8m1_t, vuint8m1_t, vuint8m1_t, vuint8m1_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vssseg8e8_v_m)))
void vssseg8e8_v_u8m1_m(vbool8_t, uint8_t *, ptrdiff_t, vuint8m1_t, vuint8m1_t, vuint8m1_t, vuint8m1_t, vuint8m1_t, vuint8m1_t, vuint8m1_t, vuint8m1_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vssseg8e8_v)))
void vssseg8e8_v_u8mf2(uint8_t *, ptrdiff_t, vuint8mf2_t, vuint8mf2_t, vuint8mf2_t, vuint8mf2_t, vuint8mf2_t, vuint8mf2_t, vuint8mf2_t, vuint8mf2_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vssseg8e8_v_m)))
void vssseg8e8_v_u8mf2_m(vbool16_t, uint8_t *, ptrdiff_t, vuint8mf2_t, vuint8mf2_t, vuint8mf2_t, vuint8mf2_t, vuint8mf2_t, vuint8mf2_t, vuint8mf2_t, vuint8mf2_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vssseg8e8_v)))
void vssseg8e8_v_u8mf4(uint8_t *, ptrdiff_t, vuint8mf4_t, vuint8mf4_t, vuint8mf4_t, vuint8mf4_t, vuint8mf4_t, vuint8mf4_t, vuint8mf4_t, vuint8mf4_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vssseg8e8_v_m)))
void vssseg8e8_v_u8mf4_m(vbool32_t, uint8_t *, ptrdiff_t, vuint8mf4_t, vuint8mf4_t, vuint8mf4_t, vuint8mf4_t, vuint8mf4_t, vuint8mf4_t, vuint8mf4_t, vuint8mf4_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vssseg8e8_v)))
void vssseg8e8_v_u8mf8(uint8_t *, ptrdiff_t, vuint8mf8_t, vuint8mf8_t, vuint8mf8_t, vuint8mf8_t, vuint8mf8_t, vuint8mf8_t, vuint8mf8_t, vuint8mf8_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vssseg8e8_v_m)))
void vssseg8e8_v_u8mf8_m(vbool64_t, uint8_t *, ptrdiff_t, vuint8mf8_t, vuint8mf8_t, vuint8mf8_t, vuint8mf8_t, vuint8mf8_t, vuint8mf8_t, vuint8mf8_t, vuint8mf8_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vssseg2e16_v)))
void vssseg2e16_v_i16m1(int16_t *, ptrdiff_t, vint16m1_t, vint16m1_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vssseg2e16_v_m)))
void vssseg2e16_v_i16m1_m(vbool16_t, int16_t *, ptrdiff_t, vint16m1_t, vint16m1_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vssseg2e16_v)))
void vssseg2e16_v_i16m2(int16_t *, ptrdiff_t, vint16m2_t, vint16m2_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vssseg2e16_v_m)))
void vssseg2e16_v_i16m2_m(vbool8_t, int16_t *, ptrdiff_t, vint16m2_t, vint16m2_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vssseg2e16_v)))
void vssseg2e16_v_i16m4(int16_t *, ptrdiff_t, vint16m4_t, vint16m4_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vssseg2e16_v_m)))
void vssseg2e16_v_i16m4_m(vbool4_t, int16_t *, ptrdiff_t, vint16m4_t, vint16m4_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vssseg2e16_v)))
void vssseg2e16_v_i16mf2(int16_t *, ptrdiff_t, vint16mf2_t, vint16mf2_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vssseg2e16_v_m)))
void vssseg2e16_v_i16mf2_m(vbool32_t, int16_t *, ptrdiff_t, vint16mf2_t, vint16mf2_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vssseg2e16_v)))
void vssseg2e16_v_i16mf4(int16_t *, ptrdiff_t, vint16mf4_t, vint16mf4_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vssseg2e16_v_m)))
void vssseg2e16_v_i16mf4_m(vbool64_t, int16_t *, ptrdiff_t, vint16mf4_t, vint16mf4_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vssseg2e16_v)))
void vssseg2e16_v_u16m1(uint16_t *, ptrdiff_t, vuint16m1_t, vuint16m1_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vssseg2e16_v_m)))
void vssseg2e16_v_u16m1_m(vbool16_t, uint16_t *, ptrdiff_t, vuint16m1_t, vuint16m1_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vssseg2e16_v)))
void vssseg2e16_v_u16m2(uint16_t *, ptrdiff_t, vuint16m2_t, vuint16m2_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vssseg2e16_v_m)))
void vssseg2e16_v_u16m2_m(vbool8_t, uint16_t *, ptrdiff_t, vuint16m2_t, vuint16m2_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vssseg2e16_v)))
void vssseg2e16_v_u16m4(uint16_t *, ptrdiff_t, vuint16m4_t, vuint16m4_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vssseg2e16_v_m)))
void vssseg2e16_v_u16m4_m(vbool4_t, uint16_t *, ptrdiff_t, vuint16m4_t, vuint16m4_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vssseg2e16_v)))
void vssseg2e16_v_u16mf2(uint16_t *, ptrdiff_t, vuint16mf2_t, vuint16mf2_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vssseg2e16_v_m)))
void vssseg2e16_v_u16mf2_m(vbool32_t, uint16_t *, ptrdiff_t, vuint16mf2_t, vuint16mf2_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vssseg2e16_v)))
void vssseg2e16_v_u16mf4(uint16_t *, ptrdiff_t, vuint16mf4_t, vuint16mf4_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vssseg2e16_v_m)))
void vssseg2e16_v_u16mf4_m(vbool64_t, uint16_t *, ptrdiff_t, vuint16mf4_t, vuint16mf4_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vssseg3e16_v)))
void vssseg3e16_v_i16m1(int16_t *, ptrdiff_t, vint16m1_t, vint16m1_t, vint16m1_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vssseg3e16_v_m)))
void vssseg3e16_v_i16m1_m(vbool16_t, int16_t *, ptrdiff_t, vint16m1_t, vint16m1_t, vint16m1_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vssseg3e16_v)))
void vssseg3e16_v_i16m2(int16_t *, ptrdiff_t, vint16m2_t, vint16m2_t, vint16m2_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vssseg3e16_v_m)))
void vssseg3e16_v_i16m2_m(vbool8_t, int16_t *, ptrdiff_t, vint16m2_t, vint16m2_t, vint16m2_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vssseg3e16_v)))
void vssseg3e16_v_i16mf2(int16_t *, ptrdiff_t, vint16mf2_t, vint16mf2_t, vint16mf2_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vssseg3e16_v_m)))
void vssseg3e16_v_i16mf2_m(vbool32_t, int16_t *, ptrdiff_t, vint16mf2_t, vint16mf2_t, vint16mf2_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vssseg3e16_v)))
void vssseg3e16_v_i16mf4(int16_t *, ptrdiff_t, vint16mf4_t, vint16mf4_t, vint16mf4_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vssseg3e16_v_m)))
void vssseg3e16_v_i16mf4_m(vbool64_t, int16_t *, ptrdiff_t, vint16mf4_t, vint16mf4_t, vint16mf4_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vluxei32_v)))
vuint16m1_t vluxei32_v_u16m1(const uint16_t *, vuint32m2_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vluxei32_v_m)))
vuint16m1_t vluxei32_v_u16m1_m(vbool16_t, vuint16m1_t, const uint16_t *, vuint32m2_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vluxei32_v)))
vuint16m2_t vluxei32_v_u16m2(const uint16_t *, vuint32m4_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vluxei32_v_m)))
vuint16m2_t vluxei32_v_u16m2_m(vbool8_t, vuint16m2_t, const uint16_t *, vuint32m4_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vluxei32_v)))
vuint16m4_t vluxei32_v_u16m4(const uint16_t *, vuint32m8_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vluxei32_v_m)))
vuint16m4_t vluxei32_v_u16m4_m(vbool4_t, vuint16m4_t, const uint16_t *, vuint32m8_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vluxei32_v)))
vuint16mf2_t vluxei32_v_u16mf2(const uint16_t *, vuint32m1_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vluxei32_v_m)))
vuint16mf2_t vluxei32_v_u16mf2_m(vbool32_t, vuint16mf2_t, const uint16_t *, vuint32m1_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vluxei32_v)))
vuint16mf4_t vluxei32_v_u16mf4(const uint16_t *, vuint32mf2_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vluxei32_v_m)))
vuint16mf4_t vluxei32_v_u16mf4_m(vbool64_t, vuint16mf4_t, const uint16_t *, vuint32mf2_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vssseg3e16_v)))
void vssseg3e16_v_u16m1(uint16_t *, ptrdiff_t, vuint16m1_t, vuint16m1_t, vuint16m1_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vssseg3e16_v_m)))
void vssseg3e16_v_u16m1_m(vbool16_t, uint16_t *, ptrdiff_t, vuint16m1_t, vuint16m1_t, vuint16m1_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vssseg3e16_v)))
void vssseg3e16_v_u16m2(uint16_t *, ptrdiff_t, vuint16m2_t, vuint16m2_t, vuint16m2_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vssseg3e16_v_m)))
void vssseg3e16_v_u16m2_m(vbool8_t, uint16_t *, ptrdiff_t, vuint16m2_t, vuint16m2_t, vuint16m2_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vssseg3e16_v)))
void vssseg3e16_v_u16mf2(uint16_t *, ptrdiff_t, vuint16mf2_t, vuint16mf2_t, vuint16mf2_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vssseg3e16_v_m)))
void vssseg3e16_v_u16mf2_m(vbool32_t, uint16_t *, ptrdiff_t, vuint16mf2_t, vuint16mf2_t, vuint16mf2_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vssseg3e16_v)))
void vssseg3e16_v_u16mf4(uint16_t *, ptrdiff_t, vuint16mf4_t, vuint16mf4_t, vuint16mf4_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vssseg3e16_v_m)))
void vssseg3e16_v_u16mf4_m(vbool64_t, uint16_t *, ptrdiff_t, vuint16mf4_t, vuint16mf4_t, vuint16mf4_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vssseg4e16_v)))
void vssseg4e16_v_i16m1(int16_t *, ptrdiff_t, vint16m1_t, vint16m1_t, vint16m1_t, vint16m1_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vssseg4e16_v_m)))
void vssseg4e16_v_i16m1_m(vbool16_t, int16_t *, ptrdiff_t, vint16m1_t, vint16m1_t, vint16m1_t, vint16m1_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vssseg4e16_v)))
void vssseg4e16_v_i16m2(int16_t *, ptrdiff_t, vint16m2_t, vint16m2_t, vint16m2_t, vint16m2_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vssseg4e16_v_m)))
void vssseg4e16_v_i16m2_m(vbool8_t, int16_t *, ptrdiff_t, vint16m2_t, vint16m2_t, vint16m2_t, vint16m2_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vssseg4e16_v)))
void vssseg4e16_v_i16mf2(int16_t *, ptrdiff_t, vint16mf2_t, vint16mf2_t, vint16mf2_t, vint16mf2_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vssseg4e16_v_m)))
void vssseg4e16_v_i16mf2_m(vbool32_t, int16_t *, ptrdiff_t, vint16mf2_t, vint16mf2_t, vint16mf2_t, vint16mf2_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vssseg4e16_v)))
void vssseg4e16_v_i16mf4(int16_t *, ptrdiff_t, vint16mf4_t, vint16mf4_t, vint16mf4_t, vint16mf4_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vssseg4e16_v_m)))
void vssseg4e16_v_i16mf4_m(vbool64_t, int16_t *, ptrdiff_t, vint16mf4_t, vint16mf4_t, vint16mf4_t, vint16mf4_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vssseg4e16_v)))
void vssseg4e16_v_u16m1(uint16_t *, ptrdiff_t, vuint16m1_t, vuint16m1_t, vuint16m1_t, vuint16m1_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vssseg4e16_v_m)))
void vssseg4e16_v_u16m1_m(vbool16_t, uint16_t *, ptrdiff_t, vuint16m1_t, vuint16m1_t, vuint16m1_t, vuint16m1_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vssseg4e16_v)))
void vssseg4e16_v_u16m2(uint16_t *, ptrdiff_t, vuint16m2_t, vuint16m2_t, vuint16m2_t, vuint16m2_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vssseg4e16_v_m)))
void vssseg4e16_v_u16m2_m(vbool8_t, uint16_t *, ptrdiff_t, vuint16m2_t, vuint16m2_t, vuint16m2_t, vuint16m2_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vssseg4e16_v)))
void vssseg4e16_v_u16mf2(uint16_t *, ptrdiff_t, vuint16mf2_t, vuint16mf2_t, vuint16mf2_t, vuint16mf2_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vssseg4e16_v_m)))
void vssseg4e16_v_u16mf2_m(vbool32_t, uint16_t *, ptrdiff_t, vuint16mf2_t, vuint16mf2_t, vuint16mf2_t, vuint16mf2_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vssseg4e16_v)))
void vssseg4e16_v_u16mf4(uint16_t *, ptrdiff_t, vuint16mf4_t, vuint16mf4_t, vuint16mf4_t, vuint16mf4_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vssseg4e16_v_m)))
void vssseg4e16_v_u16mf4_m(vbool64_t, uint16_t *, ptrdiff_t, vuint16mf4_t, vuint16mf4_t, vuint16mf4_t, vuint16mf4_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vssseg5e16_v)))
void vssseg5e16_v_i16m1(int16_t *, ptrdiff_t, vint16m1_t, vint16m1_t, vint16m1_t, vint16m1_t, vint16m1_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vssseg5e16_v_m)))
void vssseg5e16_v_i16m1_m(vbool16_t, int16_t *, ptrdiff_t, vint16m1_t, vint16m1_t, vint16m1_t, vint16m1_t, vint16m1_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vssseg5e16_v)))
void vssseg5e16_v_i16mf2(int16_t *, ptrdiff_t, vint16mf2_t, vint16mf2_t, vint16mf2_t, vint16mf2_t, vint16mf2_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vssseg5e16_v_m)))
void vssseg5e16_v_i16mf2_m(vbool32_t, int16_t *, ptrdiff_t, vint16mf2_t, vint16mf2_t, vint16mf2_t, vint16mf2_t, vint16mf2_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vssseg5e16_v)))
void vssseg5e16_v_i16mf4(int16_t *, ptrdiff_t, vint16mf4_t, vint16mf4_t, vint16mf4_t, vint16mf4_t, vint16mf4_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vssseg5e16_v_m)))
void vssseg5e16_v_i16mf4_m(vbool64_t, int16_t *, ptrdiff_t, vint16mf4_t, vint16mf4_t, vint16mf4_t, vint16mf4_t, vint16mf4_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vssseg5e16_v)))
void vssseg5e16_v_u16m1(uint16_t *, ptrdiff_t, vuint16m1_t, vuint16m1_t, vuint16m1_t, vuint16m1_t, vuint16m1_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vssseg5e16_v_m)))
void vssseg5e16_v_u16m1_m(vbool16_t, uint16_t *, ptrdiff_t, vuint16m1_t, vuint16m1_t, vuint16m1_t, vuint16m1_t, vuint16m1_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vssseg5e16_v)))
void vssseg5e16_v_u16mf2(uint16_t *, ptrdiff_t, vuint16mf2_t, vuint16mf2_t, vuint16mf2_t, vuint16mf2_t, vuint16mf2_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vssseg5e16_v_m)))
void vssseg5e16_v_u16mf2_m(vbool32_t, uint16_t *, ptrdiff_t, vuint16mf2_t, vuint16mf2_t, vuint16mf2_t, vuint16mf2_t, vuint16mf2_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vssseg5e16_v)))
void vssseg5e16_v_u16mf4(uint16_t *, ptrdiff_t, vuint16mf4_t, vuint16mf4_t, vuint16mf4_t, vuint16mf4_t, vuint16mf4_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vssseg5e16_v_m)))
void vssseg5e16_v_u16mf4_m(vbool64_t, uint16_t *, ptrdiff_t, vuint16mf4_t, vuint16mf4_t, vuint16mf4_t, vuint16mf4_t, vuint16mf4_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vssseg6e16_v)))
void vssseg6e16_v_i16m1(int16_t *, ptrdiff_t, vint16m1_t, vint16m1_t, vint16m1_t, vint16m1_t, vint16m1_t, vint16m1_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vssseg6e16_v_m)))
void vssseg6e16_v_i16m1_m(vbool16_t, int16_t *, ptrdiff_t, vint16m1_t, vint16m1_t, vint16m1_t, vint16m1_t, vint16m1_t, vint16m1_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vssseg6e16_v)))
void vssseg6e16_v_i16mf2(int16_t *, ptrdiff_t, vint16mf2_t, vint16mf2_t, vint16mf2_t, vint16mf2_t, vint16mf2_t, vint16mf2_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vssseg6e16_v_m)))
void vssseg6e16_v_i16mf2_m(vbool32_t, int16_t *, ptrdiff_t, vint16mf2_t, vint16mf2_t, vint16mf2_t, vint16mf2_t, vint16mf2_t, vint16mf2_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vssseg6e16_v)))
void vssseg6e16_v_i16mf4(int16_t *, ptrdiff_t, vint16mf4_t, vint16mf4_t, vint16mf4_t, vint16mf4_t, vint16mf4_t, vint16mf4_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vssseg6e16_v_m)))
void vssseg6e16_v_i16mf4_m(vbool64_t, int16_t *, ptrdiff_t, vint16mf4_t, vint16mf4_t, vint16mf4_t, vint16mf4_t, vint16mf4_t, vint16mf4_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vssseg6e16_v)))
void vssseg6e16_v_u16m1(uint16_t *, ptrdiff_t, vuint16m1_t, vuint16m1_t, vuint16m1_t, vuint16m1_t, vuint16m1_t, vuint16m1_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vssseg6e16_v_m)))
void vssseg6e16_v_u16m1_m(vbool16_t, uint16_t *, ptrdiff_t, vuint16m1_t, vuint16m1_t, vuint16m1_t, vuint16m1_t, vuint16m1_t, vuint16m1_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vssseg6e16_v)))
void vssseg6e16_v_u16mf2(uint16_t *, ptrdiff_t, vuint16mf2_t, vuint16mf2_t, vuint16mf2_t, vuint16mf2_t, vuint16mf2_t, vuint16mf2_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vssseg6e16_v_m)))
void vssseg6e16_v_u16mf2_m(vbool32_t, uint16_t *, ptrdiff_t, vuint16mf2_t, vuint16mf2_t, vuint16mf2_t, vuint16mf2_t, vuint16mf2_t, vuint16mf2_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vssseg6e16_v)))
void vssseg6e16_v_u16mf4(uint16_t *, ptrdiff_t, vuint16mf4_t, vuint16mf4_t, vuint16mf4_t, vuint16mf4_t, vuint16mf4_t, vuint16mf4_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vssseg6e16_v_m)))
void vssseg6e16_v_u16mf4_m(vbool64_t, uint16_t *, ptrdiff_t, vuint16mf4_t, vuint16mf4_t, vuint16mf4_t, vuint16mf4_t, vuint16mf4_t, vuint16mf4_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vssseg7e16_v)))
void vssseg7e16_v_i16m1(int16_t *, ptrdiff_t, vint16m1_t, vint16m1_t, vint16m1_t, vint16m1_t, vint16m1_t, vint16m1_t, vint16m1_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vssseg7e16_v_m)))
void vssseg7e16_v_i16m1_m(vbool16_t, int16_t *, ptrdiff_t, vint16m1_t, vint16m1_t, vint16m1_t, vint16m1_t, vint16m1_t, vint16m1_t, vint16m1_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vssseg7e16_v)))
void vssseg7e16_v_i16mf2(int16_t *, ptrdiff_t, vint16mf2_t, vint16mf2_t, vint16mf2_t, vint16mf2_t, vint16mf2_t, vint16mf2_t, vint16mf2_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vssseg7e16_v_m)))
void vssseg7e16_v_i16mf2_m(vbool32_t, int16_t *, ptrdiff_t, vint16mf2_t, vint16mf2_t, vint16mf2_t, vint16mf2_t, vint16mf2_t, vint16mf2_t, vint16mf2_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vssseg7e16_v)))
void vssseg7e16_v_i16mf4(int16_t *, ptrdiff_t, vint16mf4_t, vint16mf4_t, vint16mf4_t, vint16mf4_t, vint16mf4_t, vint16mf4_t, vint16mf4_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vssseg7e16_v_m)))
void vssseg7e16_v_i16mf4_m(vbool64_t, int16_t *, ptrdiff_t, vint16mf4_t, vint16mf4_t, vint16mf4_t, vint16mf4_t, vint16mf4_t, vint16mf4_t, vint16mf4_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vssseg7e16_v)))
void vssseg7e16_v_u16m1(uint16_t *, ptrdiff_t, vuint16m1_t, vuint16m1_t, vuint16m1_t, vuint16m1_t, vuint16m1_t, vuint16m1_t, vuint16m1_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vssseg7e16_v_m)))
void vssseg7e16_v_u16m1_m(vbool16_t, uint16_t *, ptrdiff_t, vuint16m1_t, vuint16m1_t, vuint16m1_t, vuint16m1_t, vuint16m1_t, vuint16m1_t, vuint16m1_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vssseg7e16_v)))
void vssseg7e16_v_u16mf2(uint16_t *, ptrdiff_t, vuint16mf2_t, vuint16mf2_t, vuint16mf2_t, vuint16mf2_t, vuint16mf2_t, vuint16mf2_t, vuint16mf2_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vssseg7e16_v_m)))
void vssseg7e16_v_u16mf2_m(vbool32_t, uint16_t *, ptrdiff_t, vuint16mf2_t, vuint16mf2_t, vuint16mf2_t, vuint16mf2_t, vuint16mf2_t, vuint16mf2_t, vuint16mf2_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vssseg7e16_v)))
void vssseg7e16_v_u16mf4(uint16_t *, ptrdiff_t, vuint16mf4_t, vuint16mf4_t, vuint16mf4_t, vuint16mf4_t, vuint16mf4_t, vuint16mf4_t, vuint16mf4_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vssseg7e16_v_m)))
void vssseg7e16_v_u16mf4_m(vbool64_t, uint16_t *, ptrdiff_t, vuint16mf4_t, vuint16mf4_t, vuint16mf4_t, vuint16mf4_t, vuint16mf4_t, vuint16mf4_t, vuint16mf4_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vssseg8e16_v)))
void vssseg8e16_v_i16m1(int16_t *, ptrdiff_t, vint16m1_t, vint16m1_t, vint16m1_t, vint16m1_t, vint16m1_t, vint16m1_t, vint16m1_t, vint16m1_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vssseg8e16_v_m)))
void vssseg8e16_v_i16m1_m(vbool16_t, int16_t *, ptrdiff_t, vint16m1_t, vint16m1_t, vint16m1_t, vint16m1_t, vint16m1_t, vint16m1_t, vint16m1_t, vint16m1_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vssseg8e16_v)))
void vssseg8e16_v_i16mf2(int16_t *, ptrdiff_t, vint16mf2_t, vint16mf2_t, vint16mf2_t, vint16mf2_t, vint16mf2_t, vint16mf2_t, vint16mf2_t, vint16mf2_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vssseg8e16_v_m)))
void vssseg8e16_v_i16mf2_m(vbool32_t, int16_t *, ptrdiff_t, vint16mf2_t, vint16mf2_t, vint16mf2_t, vint16mf2_t, vint16mf2_t, vint16mf2_t, vint16mf2_t, vint16mf2_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vssseg8e16_v)))
void vssseg8e16_v_i16mf4(int16_t *, ptrdiff_t, vint16mf4_t, vint16mf4_t, vint16mf4_t, vint16mf4_t, vint16mf4_t, vint16mf4_t, vint16mf4_t, vint16mf4_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vssseg8e16_v_m)))
void vssseg8e16_v_i16mf4_m(vbool64_t, int16_t *, ptrdiff_t, vint16mf4_t, vint16mf4_t, vint16mf4_t, vint16mf4_t, vint16mf4_t, vint16mf4_t, vint16mf4_t, vint16mf4_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vssseg8e16_v)))
void vssseg8e16_v_u16m1(uint16_t *, ptrdiff_t, vuint16m1_t, vuint16m1_t, vuint16m1_t, vuint16m1_t, vuint16m1_t, vuint16m1_t, vuint16m1_t, vuint16m1_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vssseg8e16_v_m)))
void vssseg8e16_v_u16m1_m(vbool16_t, uint16_t *, ptrdiff_t, vuint16m1_t, vuint16m1_t, vuint16m1_t, vuint16m1_t, vuint16m1_t, vuint16m1_t, vuint16m1_t, vuint16m1_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vssseg8e16_v)))
void vssseg8e16_v_u16mf2(uint16_t *, ptrdiff_t, vuint16mf2_t, vuint16mf2_t, vuint16mf2_t, vuint16mf2_t, vuint16mf2_t, vuint16mf2_t, vuint16mf2_t, vuint16mf2_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vssseg8e16_v_m)))
void vssseg8e16_v_u16mf2_m(vbool32_t, uint16_t *, ptrdiff_t, vuint16mf2_t, vuint16mf2_t, vuint16mf2_t, vuint16mf2_t, vuint16mf2_t, vuint16mf2_t, vuint16mf2_t, vuint16mf2_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vssseg8e16_v)))
void vssseg8e16_v_u16mf4(uint16_t *, ptrdiff_t, vuint16mf4_t, vuint16mf4_t, vuint16mf4_t, vuint16mf4_t, vuint16mf4_t, vuint16mf4_t, vuint16mf4_t, vuint16mf4_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vssseg8e16_v_m)))
void vssseg8e16_v_u16mf4_m(vbool64_t, uint16_t *, ptrdiff_t, vuint16mf4_t, vuint16mf4_t, vuint16mf4_t, vuint16mf4_t, vuint16mf4_t, vuint16mf4_t, vuint16mf4_t, vuint16mf4_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vssseg2e32_v)))
void vssseg2e32_v_i32m1(int32_t *, ptrdiff_t, vint32m1_t, vint32m1_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vssseg2e32_v_m)))
void vssseg2e32_v_i32m1_m(vbool32_t, int32_t *, ptrdiff_t, vint32m1_t, vint32m1_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vssseg2e32_v)))
void vssseg2e32_v_i32m2(int32_t *, ptrdiff_t, vint32m2_t, vint32m2_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vssseg2e32_v_m)))
void vssseg2e32_v_i32m2_m(vbool16_t, int32_t *, ptrdiff_t, vint32m2_t, vint32m2_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vssseg2e32_v)))
void vssseg2e32_v_i32m4(int32_t *, ptrdiff_t, vint32m4_t, vint32m4_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vssseg2e32_v_m)))
void vssseg2e32_v_i32m4_m(vbool8_t, int32_t *, ptrdiff_t, vint32m4_t, vint32m4_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vssseg2e32_v)))
void vssseg2e32_v_i32mf2(int32_t *, ptrdiff_t, vint32mf2_t, vint32mf2_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vssseg2e32_v_m)))
void vssseg2e32_v_i32mf2_m(vbool64_t, int32_t *, ptrdiff_t, vint32mf2_t, vint32mf2_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vssseg2e32_v)))
void vssseg2e32_v_u32m1(uint32_t *, ptrdiff_t, vuint32m1_t, vuint32m1_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vssseg2e32_v_m)))
void vssseg2e32_v_u32m1_m(vbool32_t, uint32_t *, ptrdiff_t, vuint32m1_t, vuint32m1_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vssseg2e32_v)))
void vssseg2e32_v_u32m2(uint32_t *, ptrdiff_t, vuint32m2_t, vuint32m2_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vssseg2e32_v_m)))
void vssseg2e32_v_u32m2_m(vbool16_t, uint32_t *, ptrdiff_t, vuint32m2_t, vuint32m2_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vssseg2e32_v)))
void vssseg2e32_v_u32m4(uint32_t *, ptrdiff_t, vuint32m4_t, vuint32m4_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vssseg2e32_v_m)))
void vssseg2e32_v_u32m4_m(vbool8_t, uint32_t *, ptrdiff_t, vuint32m4_t, vuint32m4_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vssseg2e32_v)))
void vssseg2e32_v_u32mf2(uint32_t *, ptrdiff_t, vuint32mf2_t, vuint32mf2_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vssseg2e32_v_m)))
void vssseg2e32_v_u32mf2_m(vbool64_t, uint32_t *, ptrdiff_t, vuint32mf2_t, vuint32mf2_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vssseg3e32_v)))
void vssseg3e32_v_i32m1(int32_t *, ptrdiff_t, vint32m1_t, vint32m1_t, vint32m1_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vssseg3e32_v_m)))
void vssseg3e32_v_i32m1_m(vbool32_t, int32_t *, ptrdiff_t, vint32m1_t, vint32m1_t, vint32m1_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vssseg3e32_v)))
void vssseg3e32_v_i32m2(int32_t *, ptrdiff_t, vint32m2_t, vint32m2_t, vint32m2_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vssseg3e32_v_m)))
void vssseg3e32_v_i32m2_m(vbool16_t, int32_t *, ptrdiff_t, vint32m2_t, vint32m2_t, vint32m2_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vssseg3e32_v)))
void vssseg3e32_v_i32mf2(int32_t *, ptrdiff_t, vint32mf2_t, vint32mf2_t, vint32mf2_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vssseg3e32_v_m)))
void vssseg3e32_v_i32mf2_m(vbool64_t, int32_t *, ptrdiff_t, vint32mf2_t, vint32mf2_t, vint32mf2_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vssseg3e32_v)))
void vssseg3e32_v_u32m1(uint32_t *, ptrdiff_t, vuint32m1_t, vuint32m1_t, vuint32m1_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vssseg3e32_v_m)))
void vssseg3e32_v_u32m1_m(vbool32_t, uint32_t *, ptrdiff_t, vuint32m1_t, vuint32m1_t, vuint32m1_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vssseg3e32_v)))
void vssseg3e32_v_u32m2(uint32_t *, ptrdiff_t, vuint32m2_t, vuint32m2_t, vuint32m2_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vssseg3e32_v_m)))
void vssseg3e32_v_u32m2_m(vbool16_t, uint32_t *, ptrdiff_t, vuint32m2_t, vuint32m2_t, vuint32m2_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vssseg3e32_v)))
void vssseg3e32_v_u32mf2(uint32_t *, ptrdiff_t, vuint32mf2_t, vuint32mf2_t, vuint32mf2_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vssseg3e32_v_m)))
void vssseg3e32_v_u32mf2_m(vbool64_t, uint32_t *, ptrdiff_t, vuint32mf2_t, vuint32mf2_t, vuint32mf2_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vssseg4e32_v)))
void vssseg4e32_v_i32m1(int32_t *, ptrdiff_t, vint32m1_t, vint32m1_t, vint32m1_t, vint32m1_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vssseg4e32_v_m)))
void vssseg4e32_v_i32m1_m(vbool32_t, int32_t *, ptrdiff_t, vint32m1_t, vint32m1_t, vint32m1_t, vint32m1_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vssseg4e32_v)))
void vssseg4e32_v_i32m2(int32_t *, ptrdiff_t, vint32m2_t, vint32m2_t, vint32m2_t, vint32m2_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vssseg4e32_v_m)))
void vssseg4e32_v_i32m2_m(vbool16_t, int32_t *, ptrdiff_t, vint32m2_t, vint32m2_t, vint32m2_t, vint32m2_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vssseg4e32_v)))
void vssseg4e32_v_i32mf2(int32_t *, ptrdiff_t, vint32mf2_t, vint32mf2_t, vint32mf2_t, vint32mf2_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vssseg4e32_v_m)))
void vssseg4e32_v_i32mf2_m(vbool64_t, int32_t *, ptrdiff_t, vint32mf2_t, vint32mf2_t, vint32mf2_t, vint32mf2_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vssseg4e32_v)))
void vssseg4e32_v_u32m1(uint32_t *, ptrdiff_t, vuint32m1_t, vuint32m1_t, vuint32m1_t, vuint32m1_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vssseg4e32_v_m)))
void vssseg4e32_v_u32m1_m(vbool32_t, uint32_t *, ptrdiff_t, vuint32m1_t, vuint32m1_t, vuint32m1_t, vuint32m1_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vssseg4e32_v)))
void vssseg4e32_v_u32m2(uint32_t *, ptrdiff_t, vuint32m2_t, vuint32m2_t, vuint32m2_t, vuint32m2_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vssseg4e32_v_m)))
void vssseg4e32_v_u32m2_m(vbool16_t, uint32_t *, ptrdiff_t, vuint32m2_t, vuint32m2_t, vuint32m2_t, vuint32m2_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vssseg4e32_v)))
void vssseg4e32_v_u32mf2(uint32_t *, ptrdiff_t, vuint32mf2_t, vuint32mf2_t, vuint32mf2_t, vuint32mf2_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vssseg4e32_v_m)))
void vssseg4e32_v_u32mf2_m(vbool64_t, uint32_t *, ptrdiff_t, vuint32mf2_t, vuint32mf2_t, vuint32mf2_t, vuint32mf2_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vssseg5e32_v)))
void vssseg5e32_v_i32m1(int32_t *, ptrdiff_t, vint32m1_t, vint32m1_t, vint32m1_t, vint32m1_t, vint32m1_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vssseg5e32_v_m)))
void vssseg5e32_v_i32m1_m(vbool32_t, int32_t *, ptrdiff_t, vint32m1_t, vint32m1_t, vint32m1_t, vint32m1_t, vint32m1_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vssseg5e32_v)))
void vssseg5e32_v_i32mf2(int32_t *, ptrdiff_t, vint32mf2_t, vint32mf2_t, vint32mf2_t, vint32mf2_t, vint32mf2_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vssseg5e32_v_m)))
void vssseg5e32_v_i32mf2_m(vbool64_t, int32_t *, ptrdiff_t, vint32mf2_t, vint32mf2_t, vint32mf2_t, vint32mf2_t, vint32mf2_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vssseg5e32_v)))
void vssseg5e32_v_u32m1(uint32_t *, ptrdiff_t, vuint32m1_t, vuint32m1_t, vuint32m1_t, vuint32m1_t, vuint32m1_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vssseg5e32_v_m)))
void vssseg5e32_v_u32m1_m(vbool32_t, uint32_t *, ptrdiff_t, vuint32m1_t, vuint32m1_t, vuint32m1_t, vuint32m1_t, vuint32m1_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vssseg5e32_v)))
void vssseg5e32_v_u32mf2(uint32_t *, ptrdiff_t, vuint32mf2_t, vuint32mf2_t, vuint32mf2_t, vuint32mf2_t, vuint32mf2_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vssseg5e32_v_m)))
void vssseg5e32_v_u32mf2_m(vbool64_t, uint32_t *, ptrdiff_t, vuint32mf2_t, vuint32mf2_t, vuint32mf2_t, vuint32mf2_t, vuint32mf2_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vssseg6e32_v)))
void vssseg6e32_v_i32m1(int32_t *, ptrdiff_t, vint32m1_t, vint32m1_t, vint32m1_t, vint32m1_t, vint32m1_t, vint32m1_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vssseg6e32_v_m)))
void vssseg6e32_v_i32m1_m(vbool32_t, int32_t *, ptrdiff_t, vint32m1_t, vint32m1_t, vint32m1_t, vint32m1_t, vint32m1_t, vint32m1_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vssseg6e32_v)))
void vssseg6e32_v_i32mf2(int32_t *, ptrdiff_t, vint32mf2_t, vint32mf2_t, vint32mf2_t, vint32mf2_t, vint32mf2_t, vint32mf2_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vssseg6e32_v_m)))
void vssseg6e32_v_i32mf2_m(vbool64_t, int32_t *, ptrdiff_t, vint32mf2_t, vint32mf2_t, vint32mf2_t, vint32mf2_t, vint32mf2_t, vint32mf2_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vssseg6e32_v)))
void vssseg6e32_v_u32m1(uint32_t *, ptrdiff_t, vuint32m1_t, vuint32m1_t, vuint32m1_t, vuint32m1_t, vuint32m1_t, vuint32m1_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vssseg6e32_v_m)))
void vssseg6e32_v_u32m1_m(vbool32_t, uint32_t *, ptrdiff_t, vuint32m1_t, vuint32m1_t, vuint32m1_t, vuint32m1_t, vuint32m1_t, vuint32m1_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vssseg6e32_v)))
void vssseg6e32_v_u32mf2(uint32_t *, ptrdiff_t, vuint32mf2_t, vuint32mf2_t, vuint32mf2_t, vuint32mf2_t, vuint32mf2_t, vuint32mf2_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vssseg6e32_v_m)))
void vssseg6e32_v_u32mf2_m(vbool64_t, uint32_t *, ptrdiff_t, vuint32mf2_t, vuint32mf2_t, vuint32mf2_t, vuint32mf2_t, vuint32mf2_t, vuint32mf2_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vssseg7e32_v)))
void vssseg7e32_v_i32m1(int32_t *, ptrdiff_t, vint32m1_t, vint32m1_t, vint32m1_t, vint32m1_t, vint32m1_t, vint32m1_t, vint32m1_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vssseg7e32_v_m)))
void vssseg7e32_v_i32m1_m(vbool32_t, int32_t *, ptrdiff_t, vint32m1_t, vint32m1_t, vint32m1_t, vint32m1_t, vint32m1_t, vint32m1_t, vint32m1_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vssseg7e32_v)))
void vssseg7e32_v_i32mf2(int32_t *, ptrdiff_t, vint32mf2_t, vint32mf2_t, vint32mf2_t, vint32mf2_t, vint32mf2_t, vint32mf2_t, vint32mf2_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vssseg7e32_v_m)))
void vssseg7e32_v_i32mf2_m(vbool64_t, int32_t *, ptrdiff_t, vint32mf2_t, vint32mf2_t, vint32mf2_t, vint32mf2_t, vint32mf2_t, vint32mf2_t, vint32mf2_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vssseg7e32_v)))
void vssseg7e32_v_u32m1(uint32_t *, ptrdiff_t, vuint32m1_t, vuint32m1_t, vuint32m1_t, vuint32m1_t, vuint32m1_t, vuint32m1_t, vuint32m1_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vssseg7e32_v_m)))
void vssseg7e32_v_u32m1_m(vbool32_t, uint32_t *, ptrdiff_t, vuint32m1_t, vuint32m1_t, vuint32m1_t, vuint32m1_t, vuint32m1_t, vuint32m1_t, vuint32m1_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vssseg7e32_v)))
void vssseg7e32_v_u32mf2(uint32_t *, ptrdiff_t, vuint32mf2_t, vuint32mf2_t, vuint32mf2_t, vuint32mf2_t, vuint32mf2_t, vuint32mf2_t, vuint32mf2_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vssseg7e32_v_m)))
void vssseg7e32_v_u32mf2_m(vbool64_t, uint32_t *, ptrdiff_t, vuint32mf2_t, vuint32mf2_t, vuint32mf2_t, vuint32mf2_t, vuint32mf2_t, vuint32mf2_t, vuint32mf2_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vssseg8e32_v)))
void vssseg8e32_v_i32m1(int32_t *, ptrdiff_t, vint32m1_t, vint32m1_t, vint32m1_t, vint32m1_t, vint32m1_t, vint32m1_t, vint32m1_t, vint32m1_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vssseg8e32_v_m)))
void vssseg8e32_v_i32m1_m(vbool32_t, int32_t *, ptrdiff_t, vint32m1_t, vint32m1_t, vint32m1_t, vint32m1_t, vint32m1_t, vint32m1_t, vint32m1_t, vint32m1_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vssseg8e32_v)))
void vssseg8e32_v_i32mf2(int32_t *, ptrdiff_t, vint32mf2_t, vint32mf2_t, vint32mf2_t, vint32mf2_t, vint32mf2_t, vint32mf2_t, vint32mf2_t, vint32mf2_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vssseg8e32_v_m)))
void vssseg8e32_v_i32mf2_m(vbool64_t, int32_t *, ptrdiff_t, vint32mf2_t, vint32mf2_t, vint32mf2_t, vint32mf2_t, vint32mf2_t, vint32mf2_t, vint32mf2_t, vint32mf2_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vssseg8e32_v)))
void vssseg8e32_v_u32m1(uint32_t *, ptrdiff_t, vuint32m1_t, vuint32m1_t, vuint32m1_t, vuint32m1_t, vuint32m1_t, vuint32m1_t, vuint32m1_t, vuint32m1_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vssseg8e32_v_m)))
void vssseg8e32_v_u32m1_m(vbool32_t, uint32_t *, ptrdiff_t, vuint32m1_t, vuint32m1_t, vuint32m1_t, vuint32m1_t, vuint32m1_t, vuint32m1_t, vuint32m1_t, vuint32m1_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vssseg8e32_v)))
void vssseg8e32_v_u32mf2(uint32_t *, ptrdiff_t, vuint32mf2_t, vuint32mf2_t, vuint32mf2_t, vuint32mf2_t, vuint32mf2_t, vuint32mf2_t, vuint32mf2_t, vuint32mf2_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vssseg8e32_v_m)))
void vssseg8e32_v_u32mf2_m(vbool64_t, uint32_t *, ptrdiff_t, vuint32mf2_t, vuint32mf2_t, vuint32mf2_t, vuint32mf2_t, vuint32mf2_t, vuint32mf2_t, vuint32mf2_t, vuint32mf2_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vluxei8_v)))
vint32m1_t vluxei8_v_i32m1(const int32_t *, vuint8mf4_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vluxei8_v_m)))
vint32m1_t vluxei8_v_i32m1_m(vbool32_t, vint32m1_t, const int32_t *, vuint8mf4_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vluxei8_v)))
vint32m2_t vluxei8_v_i32m2(const int32_t *, vuint8mf2_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vluxei8_v_m)))
vint32m2_t vluxei8_v_i32m2_m(vbool16_t, vint32m2_t, const int32_t *, vuint8mf2_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vluxei8_v)))
vint32m4_t vluxei8_v_i32m4(const int32_t *, vuint8m1_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vluxei8_v_m)))
vint32m4_t vluxei8_v_i32m4_m(vbool8_t, vint32m4_t, const int32_t *, vuint8m1_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vluxei8_v)))
vint32m8_t vluxei8_v_i32m8(const int32_t *, vuint8m2_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vluxei8_v_m)))
vint32m8_t vluxei8_v_i32m8_m(vbool4_t, vint32m8_t, const int32_t *, vuint8m2_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vluxei8_v)))
vint32mf2_t vluxei8_v_i32mf2(const int32_t *, vuint8mf8_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vluxei8_v_m)))
vint32mf2_t vluxei8_v_i32mf2_m(vbool64_t, vint32mf2_t, const int32_t *, vuint8mf8_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vluxei8_v)))
vuint32m1_t vluxei8_v_u32m1(const uint32_t *, vuint8mf4_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vluxei8_v_m)))
vuint32m1_t vluxei8_v_u32m1_m(vbool32_t, vuint32m1_t, const uint32_t *, vuint8mf4_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vluxei8_v)))
vuint32m2_t vluxei8_v_u32m2(const uint32_t *, vuint8mf2_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vluxei8_v_m)))
vuint32m2_t vluxei8_v_u32m2_m(vbool16_t, vuint32m2_t, const uint32_t *, vuint8mf2_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vluxei8_v)))
vuint32m4_t vluxei8_v_u32m4(const uint32_t *, vuint8m1_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vluxei8_v_m)))
vuint32m4_t vluxei8_v_u32m4_m(vbool8_t, vuint32m4_t, const uint32_t *, vuint8m1_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vluxei8_v)))
vuint32m8_t vluxei8_v_u32m8(const uint32_t *, vuint8m2_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vluxei8_v_m)))
vuint32m8_t vluxei8_v_u32m8_m(vbool4_t, vuint32m8_t, const uint32_t *, vuint8m2_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vluxei8_v)))
vuint32mf2_t vluxei8_v_u32mf2(const uint32_t *, vuint8mf8_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vluxei8_v_m)))
vuint32mf2_t vluxei8_v_u32mf2_m(vbool64_t, vuint32mf2_t, const uint32_t *, vuint8mf8_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vluxei16_v)))
vint32m1_t vluxei16_v_i32m1(const int32_t *, vuint16mf2_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vluxei16_v_m)))
vint32m1_t vluxei16_v_i32m1_m(vbool32_t, vint32m1_t, const int32_t *, vuint16mf2_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vluxei16_v)))
vint32m2_t vluxei16_v_i32m2(const int32_t *, vuint16m1_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vluxei16_v_m)))
vint32m2_t vluxei16_v_i32m2_m(vbool16_t, vint32m2_t, const int32_t *, vuint16m1_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vluxei16_v)))
vint32m4_t vluxei16_v_i32m4(const int32_t *, vuint16m2_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vluxei16_v_m)))
vint32m4_t vluxei16_v_i32m4_m(vbool8_t, vint32m4_t, const int32_t *, vuint16m2_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vluxei16_v)))
vint32m8_t vluxei16_v_i32m8(const int32_t *, vuint16m4_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vluxei16_v_m)))
vint32m8_t vluxei16_v_i32m8_m(vbool4_t, vint32m8_t, const int32_t *, vuint16m4_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vluxei16_v)))
vint32mf2_t vluxei16_v_i32mf2(const int32_t *, vuint16mf4_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vluxei16_v_m)))
vint32mf2_t vluxei16_v_i32mf2_m(vbool64_t, vint32mf2_t, const int32_t *, vuint16mf4_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vluxei16_v)))
vuint32m1_t vluxei16_v_u32m1(const uint32_t *, vuint16mf2_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vluxei16_v_m)))
vuint32m1_t vluxei16_v_u32m1_m(vbool32_t, vuint32m1_t, const uint32_t *, vuint16mf2_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vluxei16_v)))
vuint32m2_t vluxei16_v_u32m2(const uint32_t *, vuint16m1_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vluxei16_v_m)))
vuint32m2_t vluxei16_v_u32m2_m(vbool16_t, vuint32m2_t, const uint32_t *, vuint16m1_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vluxei16_v)))
vuint32m4_t vluxei16_v_u32m4(const uint32_t *, vuint16m2_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vluxei16_v_m)))
vuint32m4_t vluxei16_v_u32m4_m(vbool8_t, vuint32m4_t, const uint32_t *, vuint16m2_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vluxei16_v)))
vuint32m8_t vluxei16_v_u32m8(const uint32_t *, vuint16m4_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vluxei16_v_m)))
vuint32m8_t vluxei16_v_u32m8_m(vbool4_t, vuint32m8_t, const uint32_t *, vuint16m4_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vluxei16_v)))
vuint32mf2_t vluxei16_v_u32mf2(const uint32_t *, vuint16mf4_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vluxei16_v_m)))
vuint32mf2_t vluxei16_v_u32mf2_m(vbool64_t, vuint32mf2_t, const uint32_t *, vuint16mf4_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vsuxseg3ei8_v)))
void vsuxseg3ei8_v_i8m1(int8_t *, vuint8m1_t, vint8m1_t, vint8m1_t, vint8m1_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vsuxseg3ei8_v_m)))
void vsuxseg3ei8_v_i8m1_m(vbool8_t, int8_t *, vuint8m1_t, vint8m1_t, vint8m1_t, vint8m1_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vsuxseg3ei8_v)))
void vsuxseg3ei8_v_i8m2(int8_t *, vuint8m2_t, vint8m2_t, vint8m2_t, vint8m2_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vsuxseg3ei8_v_m)))
void vsuxseg3ei8_v_i8m2_m(vbool4_t, int8_t *, vuint8m2_t, vint8m2_t, vint8m2_t, vint8m2_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vsuxseg3ei8_v)))
void vsuxseg3ei8_v_i8mf2(int8_t *, vuint8mf2_t, vint8mf2_t, vint8mf2_t, vint8mf2_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vsuxseg3ei8_v_m)))
void vsuxseg3ei8_v_i8mf2_m(vbool16_t, int8_t *, vuint8mf2_t, vint8mf2_t, vint8mf2_t, vint8mf2_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vsuxseg3ei8_v)))
void vsuxseg3ei8_v_i8mf4(int8_t *, vuint8mf4_t, vint8mf4_t, vint8mf4_t, vint8mf4_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vsuxseg3ei8_v_m)))
void vsuxseg3ei8_v_i8mf4_m(vbool32_t, int8_t *, vuint8mf4_t, vint8mf4_t, vint8mf4_t, vint8mf4_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vsuxseg3ei8_v)))
void vsuxseg3ei8_v_i8mf8(int8_t *, vuint8mf8_t, vint8mf8_t, vint8mf8_t, vint8mf8_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vsuxseg3ei8_v_m)))
void vsuxseg3ei8_v_i8mf8_m(vbool64_t, int8_t *, vuint8mf8_t, vint8mf8_t, vint8mf8_t, vint8mf8_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vsuxseg3ei8_v)))
void vsuxseg3ei8_v_u8m1(uint8_t *, vuint8m1_t, vuint8m1_t, vuint8m1_t, vuint8m1_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vsuxseg3ei8_v_m)))
void vsuxseg3ei8_v_u8m1_m(vbool8_t, uint8_t *, vuint8m1_t, vuint8m1_t, vuint8m1_t, vuint8m1_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vsuxseg3ei8_v)))
void vsuxseg3ei8_v_u8m2(uint8_t *, vuint8m2_t, vuint8m2_t, vuint8m2_t, vuint8m2_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vsuxseg3ei8_v_m)))
void vsuxseg3ei8_v_u8m2_m(vbool4_t, uint8_t *, vuint8m2_t, vuint8m2_t, vuint8m2_t, vuint8m2_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vsuxseg3ei8_v)))
void vsuxseg3ei8_v_u8mf2(uint8_t *, vuint8mf2_t, vuint8mf2_t, vuint8mf2_t, vuint8mf2_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vsuxseg3ei8_v_m)))
void vsuxseg3ei8_v_u8mf2_m(vbool16_t, uint8_t *, vuint8mf2_t, vuint8mf2_t, vuint8mf2_t, vuint8mf2_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vsuxseg3ei8_v)))
void vsuxseg3ei8_v_u8mf4(uint8_t *, vuint8mf4_t, vuint8mf4_t, vuint8mf4_t, vuint8mf4_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vsuxseg3ei8_v_m)))
void vsuxseg3ei8_v_u8mf4_m(vbool32_t, uint8_t *, vuint8mf4_t, vuint8mf4_t, vuint8mf4_t, vuint8mf4_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vsuxseg3ei8_v)))
void vsuxseg3ei8_v_u8mf8(uint8_t *, vuint8mf8_t, vuint8mf8_t, vuint8mf8_t, vuint8mf8_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vsuxseg3ei8_v_m)))
void vsuxseg3ei8_v_u8mf8_m(vbool64_t, uint8_t *, vuint8mf8_t, vuint8mf8_t, vuint8mf8_t, vuint8mf8_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vsuxseg4ei8_v)))
void vsuxseg4ei8_v_i8m1(int8_t *, vuint8m1_t, vint8m1_t, vint8m1_t, vint8m1_t, vint8m1_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vsuxseg4ei8_v_m)))
void vsuxseg4ei8_v_i8m1_m(vbool8_t, int8_t *, vuint8m1_t, vint8m1_t, vint8m1_t, vint8m1_t, vint8m1_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vsuxseg4ei8_v)))
void vsuxseg4ei8_v_i8m2(int8_t *, vuint8m2_t, vint8m2_t, vint8m2_t, vint8m2_t, vint8m2_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vsuxseg4ei8_v_m)))
void vsuxseg4ei8_v_i8m2_m(vbool4_t, int8_t *, vuint8m2_t, vint8m2_t, vint8m2_t, vint8m2_t, vint8m2_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vsuxseg4ei8_v)))
void vsuxseg4ei8_v_i8mf2(int8_t *, vuint8mf2_t, vint8mf2_t, vint8mf2_t, vint8mf2_t, vint8mf2_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vsuxseg4ei8_v_m)))
void vsuxseg4ei8_v_i8mf2_m(vbool16_t, int8_t *, vuint8mf2_t, vint8mf2_t, vint8mf2_t, vint8mf2_t, vint8mf2_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vsuxseg4ei8_v)))
void vsuxseg4ei8_v_i8mf4(int8_t *, vuint8mf4_t, vint8mf4_t, vint8mf4_t, vint8mf4_t, vint8mf4_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vsuxseg4ei8_v_m)))
void vsuxseg4ei8_v_i8mf4_m(vbool32_t, int8_t *, vuint8mf4_t, vint8mf4_t, vint8mf4_t, vint8mf4_t, vint8mf4_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vsuxseg4ei8_v)))
void vsuxseg4ei8_v_i8mf8(int8_t *, vuint8mf8_t, vint8mf8_t, vint8mf8_t, vint8mf8_t, vint8mf8_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vsuxseg4ei8_v_m)))
void vsuxseg4ei8_v_i8mf8_m(vbool64_t, int8_t *, vuint8mf8_t, vint8mf8_t, vint8mf8_t, vint8mf8_t, vint8mf8_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vsuxseg4ei8_v)))
void vsuxseg4ei8_v_u8m1(uint8_t *, vuint8m1_t, vuint8m1_t, vuint8m1_t, vuint8m1_t, vuint8m1_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vsuxseg4ei8_v_m)))
void vsuxseg4ei8_v_u8m1_m(vbool8_t, uint8_t *, vuint8m1_t, vuint8m1_t, vuint8m1_t, vuint8m1_t, vuint8m1_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vsuxseg4ei8_v)))
void vsuxseg4ei8_v_u8m2(uint8_t *, vuint8m2_t, vuint8m2_t, vuint8m2_t, vuint8m2_t, vuint8m2_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vsuxseg4ei8_v_m)))
void vsuxseg4ei8_v_u8m2_m(vbool4_t, uint8_t *, vuint8m2_t, vuint8m2_t, vuint8m2_t, vuint8m2_t, vuint8m2_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vsuxseg4ei8_v)))
void vsuxseg4ei8_v_u8mf2(uint8_t *, vuint8mf2_t, vuint8mf2_t, vuint8mf2_t, vuint8mf2_t, vuint8mf2_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vsuxseg4ei8_v_m)))
void vsuxseg4ei8_v_u8mf2_m(vbool16_t, uint8_t *, vuint8mf2_t, vuint8mf2_t, vuint8mf2_t, vuint8mf2_t, vuint8mf2_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vsuxseg4ei8_v)))
void vsuxseg4ei8_v_u8mf4(uint8_t *, vuint8mf4_t, vuint8mf4_t, vuint8mf4_t, vuint8mf4_t, vuint8mf4_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vsuxseg4ei8_v_m)))
void vsuxseg4ei8_v_u8mf4_m(vbool32_t, uint8_t *, vuint8mf4_t, vuint8mf4_t, vuint8mf4_t, vuint8mf4_t, vuint8mf4_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vsuxseg4ei8_v)))
void vsuxseg4ei8_v_u8mf8(uint8_t *, vuint8mf8_t, vuint8mf8_t, vuint8mf8_t, vuint8mf8_t, vuint8mf8_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vsuxseg4ei8_v_m)))
void vsuxseg4ei8_v_u8mf8_m(vbool64_t, uint8_t *, vuint8mf8_t, vuint8mf8_t, vuint8mf8_t, vuint8mf8_t, vuint8mf8_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vsuxseg5ei8_v)))
void vsuxseg5ei8_v_i8m1(int8_t *, vuint8m1_t, vint8m1_t, vint8m1_t, vint8m1_t, vint8m1_t, vint8m1_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vsuxseg5ei8_v_m)))
void vsuxseg5ei8_v_i8m1_m(vbool8_t, int8_t *, vuint8m1_t, vint8m1_t, vint8m1_t, vint8m1_t, vint8m1_t, vint8m1_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vsuxseg5ei8_v)))
void vsuxseg5ei8_v_i8mf2(int8_t *, vuint8mf2_t, vint8mf2_t, vint8mf2_t, vint8mf2_t, vint8mf2_t, vint8mf2_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vsuxseg5ei8_v_m)))
void vsuxseg5ei8_v_i8mf2_m(vbool16_t, int8_t *, vuint8mf2_t, vint8mf2_t, vint8mf2_t, vint8mf2_t, vint8mf2_t, vint8mf2_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vsuxseg5ei8_v)))
void vsuxseg5ei8_v_i8mf4(int8_t *, vuint8mf4_t, vint8mf4_t, vint8mf4_t, vint8mf4_t, vint8mf4_t, vint8mf4_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vsuxseg5ei8_v_m)))
void vsuxseg5ei8_v_i8mf4_m(vbool32_t, int8_t *, vuint8mf4_t, vint8mf4_t, vint8mf4_t, vint8mf4_t, vint8mf4_t, vint8mf4_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vsuxseg5ei8_v)))
void vsuxseg5ei8_v_i8mf8(int8_t *, vuint8mf8_t, vint8mf8_t, vint8mf8_t, vint8mf8_t, vint8mf8_t, vint8mf8_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vsuxseg5ei8_v_m)))
void vsuxseg5ei8_v_i8mf8_m(vbool64_t, int8_t *, vuint8mf8_t, vint8mf8_t, vint8mf8_t, vint8mf8_t, vint8mf8_t, vint8mf8_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vsuxseg5ei8_v)))
void vsuxseg5ei8_v_u8m1(uint8_t *, vuint8m1_t, vuint8m1_t, vuint8m1_t, vuint8m1_t, vuint8m1_t, vuint8m1_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vsuxseg5ei8_v_m)))
void vsuxseg5ei8_v_u8m1_m(vbool8_t, uint8_t *, vuint8m1_t, vuint8m1_t, vuint8m1_t, vuint8m1_t, vuint8m1_t, vuint8m1_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vsuxseg5ei8_v)))
void vsuxseg5ei8_v_u8mf2(uint8_t *, vuint8mf2_t, vuint8mf2_t, vuint8mf2_t, vuint8mf2_t, vuint8mf2_t, vuint8mf2_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vsuxseg5ei8_v_m)))
void vsuxseg5ei8_v_u8mf2_m(vbool16_t, uint8_t *, vuint8mf2_t, vuint8mf2_t, vuint8mf2_t, vuint8mf2_t, vuint8mf2_t, vuint8mf2_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vsuxseg5ei8_v)))
void vsuxseg5ei8_v_u8mf4(uint8_t *, vuint8mf4_t, vuint8mf4_t, vuint8mf4_t, vuint8mf4_t, vuint8mf4_t, vuint8mf4_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vsuxseg5ei8_v_m)))
void vsuxseg5ei8_v_u8mf4_m(vbool32_t, uint8_t *, vuint8mf4_t, vuint8mf4_t, vuint8mf4_t, vuint8mf4_t, vuint8mf4_t, vuint8mf4_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vsuxseg5ei8_v)))
void vsuxseg5ei8_v_u8mf8(uint8_t *, vuint8mf8_t, vuint8mf8_t, vuint8mf8_t, vuint8mf8_t, vuint8mf8_t, vuint8mf8_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vsuxseg5ei8_v_m)))
void vsuxseg5ei8_v_u8mf8_m(vbool64_t, uint8_t *, vuint8mf8_t, vuint8mf8_t, vuint8mf8_t, vuint8mf8_t, vuint8mf8_t, vuint8mf8_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vsuxseg6ei8_v)))
void vsuxseg6ei8_v_i8m1(int8_t *, vuint8m1_t, vint8m1_t, vint8m1_t, vint8m1_t, vint8m1_t, vint8m1_t, vint8m1_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vsuxseg6ei8_v_m)))
void vsuxseg6ei8_v_i8m1_m(vbool8_t, int8_t *, vuint8m1_t, vint8m1_t, vint8m1_t, vint8m1_t, vint8m1_t, vint8m1_t, vint8m1_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vsuxseg6ei8_v)))
void vsuxseg6ei8_v_i8mf2(int8_t *, vuint8mf2_t, vint8mf2_t, vint8mf2_t, vint8mf2_t, vint8mf2_t, vint8mf2_t, vint8mf2_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vsuxseg6ei8_v_m)))
void vsuxseg6ei8_v_i8mf2_m(vbool16_t, int8_t *, vuint8mf2_t, vint8mf2_t, vint8mf2_t, vint8mf2_t, vint8mf2_t, vint8mf2_t, vint8mf2_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vsuxseg6ei8_v)))
void vsuxseg6ei8_v_i8mf4(int8_t *, vuint8mf4_t, vint8mf4_t, vint8mf4_t, vint8mf4_t, vint8mf4_t, vint8mf4_t, vint8mf4_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vsuxseg6ei8_v_m)))
void vsuxseg6ei8_v_i8mf4_m(vbool32_t, int8_t *, vuint8mf4_t, vint8mf4_t, vint8mf4_t, vint8mf4_t, vint8mf4_t, vint8mf4_t, vint8mf4_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vsuxseg6ei8_v)))
void vsuxseg6ei8_v_i8mf8(int8_t *, vuint8mf8_t, vint8mf8_t, vint8mf8_t, vint8mf8_t, vint8mf8_t, vint8mf8_t, vint8mf8_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vsuxseg6ei8_v_m)))
void vsuxseg6ei8_v_i8mf8_m(vbool64_t, int8_t *, vuint8mf8_t, vint8mf8_t, vint8mf8_t, vint8mf8_t, vint8mf8_t, vint8mf8_t, vint8mf8_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vsuxseg6ei8_v)))
void vsuxseg6ei8_v_u8m1(uint8_t *, vuint8m1_t, vuint8m1_t, vuint8m1_t, vuint8m1_t, vuint8m1_t, vuint8m1_t, vuint8m1_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vsuxseg6ei8_v_m)))
void vsuxseg6ei8_v_u8m1_m(vbool8_t, uint8_t *, vuint8m1_t, vuint8m1_t, vuint8m1_t, vuint8m1_t, vuint8m1_t, vuint8m1_t, vuint8m1_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vsuxseg6ei8_v)))
void vsuxseg6ei8_v_u8mf2(uint8_t *, vuint8mf2_t, vuint8mf2_t, vuint8mf2_t, vuint8mf2_t, vuint8mf2_t, vuint8mf2_t, vuint8mf2_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vsuxseg6ei8_v_m)))
void vsuxseg6ei8_v_u8mf2_m(vbool16_t, uint8_t *, vuint8mf2_t, vuint8mf2_t, vuint8mf2_t, vuint8mf2_t, vuint8mf2_t, vuint8mf2_t, vuint8mf2_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vsuxseg6ei8_v)))
void vsuxseg6ei8_v_u8mf4(uint8_t *, vuint8mf4_t, vuint8mf4_t, vuint8mf4_t, vuint8mf4_t, vuint8mf4_t, vuint8mf4_t, vuint8mf4_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vsuxseg6ei8_v_m)))
void vsuxseg6ei8_v_u8mf4_m(vbool32_t, uint8_t *, vuint8mf4_t, vuint8mf4_t, vuint8mf4_t, vuint8mf4_t, vuint8mf4_t, vuint8mf4_t, vuint8mf4_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vsuxseg6ei8_v)))
void vsuxseg6ei8_v_u8mf8(uint8_t *, vuint8mf8_t, vuint8mf8_t, vuint8mf8_t, vuint8mf8_t, vuint8mf8_t, vuint8mf8_t, vuint8mf8_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vsuxseg6ei8_v_m)))
void vsuxseg6ei8_v_u8mf8_m(vbool64_t, uint8_t *, vuint8mf8_t, vuint8mf8_t, vuint8mf8_t, vuint8mf8_t, vuint8mf8_t, vuint8mf8_t, vuint8mf8_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vsuxseg7ei8_v)))
void vsuxseg7ei8_v_i8m1(int8_t *, vuint8m1_t, vint8m1_t, vint8m1_t, vint8m1_t, vint8m1_t, vint8m1_t, vint8m1_t, vint8m1_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vsuxseg7ei8_v_m)))
void vsuxseg7ei8_v_i8m1_m(vbool8_t, int8_t *, vuint8m1_t, vint8m1_t, vint8m1_t, vint8m1_t, vint8m1_t, vint8m1_t, vint8m1_t, vint8m1_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vsuxseg7ei8_v)))
void vsuxseg7ei8_v_i8mf2(int8_t *, vuint8mf2_t, vint8mf2_t, vint8mf2_t, vint8mf2_t, vint8mf2_t, vint8mf2_t, vint8mf2_t, vint8mf2_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vsuxseg7ei8_v_m)))
void vsuxseg7ei8_v_i8mf2_m(vbool16_t, int8_t *, vuint8mf2_t, vint8mf2_t, vint8mf2_t, vint8mf2_t, vint8mf2_t, vint8mf2_t, vint8mf2_t, vint8mf2_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vsuxseg7ei8_v)))
void vsuxseg7ei8_v_i8mf4(int8_t *, vuint8mf4_t, vint8mf4_t, vint8mf4_t, vint8mf4_t, vint8mf4_t, vint8mf4_t, vint8mf4_t, vint8mf4_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vsuxseg7ei8_v_m)))
void vsuxseg7ei8_v_i8mf4_m(vbool32_t, int8_t *, vuint8mf4_t, vint8mf4_t, vint8mf4_t, vint8mf4_t, vint8mf4_t, vint8mf4_t, vint8mf4_t, vint8mf4_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vsuxseg7ei8_v)))
void vsuxseg7ei8_v_i8mf8(int8_t *, vuint8mf8_t, vint8mf8_t, vint8mf8_t, vint8mf8_t, vint8mf8_t, vint8mf8_t, vint8mf8_t, vint8mf8_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vsuxseg7ei8_v_m)))
void vsuxseg7ei8_v_i8mf8_m(vbool64_t, int8_t *, vuint8mf8_t, vint8mf8_t, vint8mf8_t, vint8mf8_t, vint8mf8_t, vint8mf8_t, vint8mf8_t, vint8mf8_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vluxei32_v)))
vint32m1_t vluxei32_v_i32m1(const int32_t *, vuint32m1_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vluxei32_v_m)))
vint32m1_t vluxei32_v_i32m1_m(vbool32_t, vint32m1_t, const int32_t *, vuint32m1_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vluxei32_v)))
vint32m2_t vluxei32_v_i32m2(const int32_t *, vuint32m2_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vluxei32_v_m)))
vint32m2_t vluxei32_v_i32m2_m(vbool16_t, vint32m2_t, const int32_t *, vuint32m2_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vluxei32_v)))
vint32m4_t vluxei32_v_i32m4(const int32_t *, vuint32m4_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vluxei32_v_m)))
vint32m4_t vluxei32_v_i32m4_m(vbool8_t, vint32m4_t, const int32_t *, vuint32m4_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vluxei32_v)))
vint32m8_t vluxei32_v_i32m8(const int32_t *, vuint32m8_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vluxei32_v_m)))
vint32m8_t vluxei32_v_i32m8_m(vbool4_t, vint32m8_t, const int32_t *, vuint32m8_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vluxei32_v)))
vint32mf2_t vluxei32_v_i32mf2(const int32_t *, vuint32mf2_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vluxei32_v_m)))
vint32mf2_t vluxei32_v_i32mf2_m(vbool64_t, vint32mf2_t, const int32_t *, vuint32mf2_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vsuxseg7ei8_v)))
void vsuxseg7ei8_v_u8m1(uint8_t *, vuint8m1_t, vuint8m1_t, vuint8m1_t, vuint8m1_t, vuint8m1_t, vuint8m1_t, vuint8m1_t, vuint8m1_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vsuxseg7ei8_v_m)))
void vsuxseg7ei8_v_u8m1_m(vbool8_t, uint8_t *, vuint8m1_t, vuint8m1_t, vuint8m1_t, vuint8m1_t, vuint8m1_t, vuint8m1_t, vuint8m1_t, vuint8m1_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vsuxseg7ei8_v)))
void vsuxseg7ei8_v_u8mf2(uint8_t *, vuint8mf2_t, vuint8mf2_t, vuint8mf2_t, vuint8mf2_t, vuint8mf2_t, vuint8mf2_t, vuint8mf2_t, vuint8mf2_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vsuxseg7ei8_v_m)))
void vsuxseg7ei8_v_u8mf2_m(vbool16_t, uint8_t *, vuint8mf2_t, vuint8mf2_t, vuint8mf2_t, vuint8mf2_t, vuint8mf2_t, vuint8mf2_t, vuint8mf2_t, vuint8mf2_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vsuxseg7ei8_v)))
void vsuxseg7ei8_v_u8mf4(uint8_t *, vuint8mf4_t, vuint8mf4_t, vuint8mf4_t, vuint8mf4_t, vuint8mf4_t, vuint8mf4_t, vuint8mf4_t, vuint8mf4_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vsuxseg7ei8_v_m)))
void vsuxseg7ei8_v_u8mf4_m(vbool32_t, uint8_t *, vuint8mf4_t, vuint8mf4_t, vuint8mf4_t, vuint8mf4_t, vuint8mf4_t, vuint8mf4_t, vuint8mf4_t, vuint8mf4_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vsuxseg7ei8_v)))
void vsuxseg7ei8_v_u8mf8(uint8_t *, vuint8mf8_t, vuint8mf8_t, vuint8mf8_t, vuint8mf8_t, vuint8mf8_t, vuint8mf8_t, vuint8mf8_t, vuint8mf8_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vsuxseg7ei8_v_m)))
void vsuxseg7ei8_v_u8mf8_m(vbool64_t, uint8_t *, vuint8mf8_t, vuint8mf8_t, vuint8mf8_t, vuint8mf8_t, vuint8mf8_t, vuint8mf8_t, vuint8mf8_t, vuint8mf8_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vsuxseg8ei8_v)))
void vsuxseg8ei8_v_i8m1(int8_t *, vuint8m1_t, vint8m1_t, vint8m1_t, vint8m1_t, vint8m1_t, vint8m1_t, vint8m1_t, vint8m1_t, vint8m1_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vsuxseg8ei8_v_m)))
void vsuxseg8ei8_v_i8m1_m(vbool8_t, int8_t *, vuint8m1_t, vint8m1_t, vint8m1_t, vint8m1_t, vint8m1_t, vint8m1_t, vint8m1_t, vint8m1_t, vint8m1_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vsuxseg8ei8_v)))
void vsuxseg8ei8_v_i8mf2(int8_t *, vuint8mf2_t, vint8mf2_t, vint8mf2_t, vint8mf2_t, vint8mf2_t, vint8mf2_t, vint8mf2_t, vint8mf2_t, vint8mf2_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vsuxseg8ei8_v_m)))
void vsuxseg8ei8_v_i8mf2_m(vbool16_t, int8_t *, vuint8mf2_t, vint8mf2_t, vint8mf2_t, vint8mf2_t, vint8mf2_t, vint8mf2_t, vint8mf2_t, vint8mf2_t, vint8mf2_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vsuxseg8ei8_v)))
void vsuxseg8ei8_v_i8mf4(int8_t *, vuint8mf4_t, vint8mf4_t, vint8mf4_t, vint8mf4_t, vint8mf4_t, vint8mf4_t, vint8mf4_t, vint8mf4_t, vint8mf4_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vsuxseg8ei8_v_m)))
void vsuxseg8ei8_v_i8mf4_m(vbool32_t, int8_t *, vuint8mf4_t, vint8mf4_t, vint8mf4_t, vint8mf4_t, vint8mf4_t, vint8mf4_t, vint8mf4_t, vint8mf4_t, vint8mf4_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vsuxseg8ei8_v)))
void vsuxseg8ei8_v_i8mf8(int8_t *, vuint8mf8_t, vint8mf8_t, vint8mf8_t, vint8mf8_t, vint8mf8_t, vint8mf8_t, vint8mf8_t, vint8mf8_t, vint8mf8_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vsuxseg8ei8_v_m)))
void vsuxseg8ei8_v_i8mf8_m(vbool64_t, int8_t *, vuint8mf8_t, vint8mf8_t, vint8mf8_t, vint8mf8_t, vint8mf8_t, vint8mf8_t, vint8mf8_t, vint8mf8_t, vint8mf8_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vsuxseg8ei8_v)))
void vsuxseg8ei8_v_u8m1(uint8_t *, vuint8m1_t, vuint8m1_t, vuint8m1_t, vuint8m1_t, vuint8m1_t, vuint8m1_t, vuint8m1_t, vuint8m1_t, vuint8m1_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vsuxseg8ei8_v_m)))
void vsuxseg8ei8_v_u8m1_m(vbool8_t, uint8_t *, vuint8m1_t, vuint8m1_t, vuint8m1_t, vuint8m1_t, vuint8m1_t, vuint8m1_t, vuint8m1_t, vuint8m1_t, vuint8m1_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vsuxseg8ei8_v)))
void vsuxseg8ei8_v_u8mf2(uint8_t *, vuint8mf2_t, vuint8mf2_t, vuint8mf2_t, vuint8mf2_t, vuint8mf2_t, vuint8mf2_t, vuint8mf2_t, vuint8mf2_t, vuint8mf2_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vsuxseg8ei8_v_m)))
void vsuxseg8ei8_v_u8mf2_m(vbool16_t, uint8_t *, vuint8mf2_t, vuint8mf2_t, vuint8mf2_t, vuint8mf2_t, vuint8mf2_t, vuint8mf2_t, vuint8mf2_t, vuint8mf2_t, vuint8mf2_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vsuxseg8ei8_v)))
void vsuxseg8ei8_v_u8mf4(uint8_t *, vuint8mf4_t, vuint8mf4_t, vuint8mf4_t, vuint8mf4_t, vuint8mf4_t, vuint8mf4_t, vuint8mf4_t, vuint8mf4_t, vuint8mf4_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vsuxseg8ei8_v_m)))
void vsuxseg8ei8_v_u8mf4_m(vbool32_t, uint8_t *, vuint8mf4_t, vuint8mf4_t, vuint8mf4_t, vuint8mf4_t, vuint8mf4_t, vuint8mf4_t, vuint8mf4_t, vuint8mf4_t, vuint8mf4_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vsuxseg8ei8_v)))
void vsuxseg8ei8_v_u8mf8(uint8_t *, vuint8mf8_t, vuint8mf8_t, vuint8mf8_t, vuint8mf8_t, vuint8mf8_t, vuint8mf8_t, vuint8mf8_t, vuint8mf8_t, vuint8mf8_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vsuxseg8ei8_v_m)))
void vsuxseg8ei8_v_u8mf8_m(vbool64_t, uint8_t *, vuint8mf8_t, vuint8mf8_t, vuint8mf8_t, vuint8mf8_t, vuint8mf8_t, vuint8mf8_t, vuint8mf8_t, vuint8mf8_t, vuint8mf8_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vsuxseg2ei16_v)))
void vsuxseg2ei16_v_i8m1(int8_t *, vuint16m2_t, vint8m1_t, vint8m1_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vsuxseg2ei16_v_m)))
void vsuxseg2ei16_v_i8m1_m(vbool8_t, int8_t *, vuint16m2_t, vint8m1_t, vint8m1_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vsuxseg2ei16_v)))
void vsuxseg2ei16_v_i8m2(int8_t *, vuint16m4_t, vint8m2_t, vint8m2_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vsuxseg2ei16_v_m)))
void vsuxseg2ei16_v_i8m2_m(vbool4_t, int8_t *, vuint16m4_t, vint8m2_t, vint8m2_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vsuxseg2ei16_v)))
void vsuxseg2ei16_v_i8m4(int8_t *, vuint16m8_t, vint8m4_t, vint8m4_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vsuxseg2ei16_v_m)))
void vsuxseg2ei16_v_i8m4_m(vbool2_t, int8_t *, vuint16m8_t, vint8m4_t, vint8m4_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vsuxseg2ei16_v)))
void vsuxseg2ei16_v_i8mf2(int8_t *, vuint16m1_t, vint8mf2_t, vint8mf2_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vsuxseg2ei16_v_m)))
void vsuxseg2ei16_v_i8mf2_m(vbool16_t, int8_t *, vuint16m1_t, vint8mf2_t, vint8mf2_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vsuxseg2ei16_v)))
void vsuxseg2ei16_v_i8mf4(int8_t *, vuint16mf2_t, vint8mf4_t, vint8mf4_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vsuxseg2ei16_v_m)))
void vsuxseg2ei16_v_i8mf4_m(vbool32_t, int8_t *, vuint16mf2_t, vint8mf4_t, vint8mf4_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vsuxseg2ei16_v)))
void vsuxseg2ei16_v_i8mf8(int8_t *, vuint16mf4_t, vint8mf8_t, vint8mf8_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vsuxseg2ei16_v_m)))
void vsuxseg2ei16_v_i8mf8_m(vbool64_t, int8_t *, vuint16mf4_t, vint8mf8_t, vint8mf8_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vsuxseg2ei16_v)))
void vsuxseg2ei16_v_u8m1(uint8_t *, vuint16m2_t, vuint8m1_t, vuint8m1_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vsuxseg2ei16_v_m)))
void vsuxseg2ei16_v_u8m1_m(vbool8_t, uint8_t *, vuint16m2_t, vuint8m1_t, vuint8m1_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vsuxseg2ei16_v)))
void vsuxseg2ei16_v_u8m2(uint8_t *, vuint16m4_t, vuint8m2_t, vuint8m2_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vsuxseg2ei16_v_m)))
void vsuxseg2ei16_v_u8m2_m(vbool4_t, uint8_t *, vuint16m4_t, vuint8m2_t, vuint8m2_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vsuxseg2ei16_v)))
void vsuxseg2ei16_v_u8m4(uint8_t *, vuint16m8_t, vuint8m4_t, vuint8m4_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vsuxseg2ei16_v_m)))
void vsuxseg2ei16_v_u8m4_m(vbool2_t, uint8_t *, vuint16m8_t, vuint8m4_t, vuint8m4_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vsuxseg2ei16_v)))
void vsuxseg2ei16_v_u8mf2(uint8_t *, vuint16m1_t, vuint8mf2_t, vuint8mf2_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vsuxseg2ei16_v_m)))
void vsuxseg2ei16_v_u8mf2_m(vbool16_t, uint8_t *, vuint16m1_t, vuint8mf2_t, vuint8mf2_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vsuxseg2ei16_v)))
void vsuxseg2ei16_v_u8mf4(uint8_t *, vuint16mf2_t, vuint8mf4_t, vuint8mf4_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vsuxseg2ei16_v_m)))
void vsuxseg2ei16_v_u8mf4_m(vbool32_t, uint8_t *, vuint16mf2_t, vuint8mf4_t, vuint8mf4_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vsuxseg2ei16_v)))
void vsuxseg2ei16_v_u8mf8(uint8_t *, vuint16mf4_t, vuint8mf8_t, vuint8mf8_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vsuxseg2ei16_v_m)))
void vsuxseg2ei16_v_u8mf8_m(vbool64_t, uint8_t *, vuint16mf4_t, vuint8mf8_t, vuint8mf8_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vsuxseg3ei16_v)))
void vsuxseg3ei16_v_i8m1(int8_t *, vuint16m2_t, vint8m1_t, vint8m1_t, vint8m1_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vsuxseg3ei16_v_m)))
void vsuxseg3ei16_v_i8m1_m(vbool8_t, int8_t *, vuint16m2_t, vint8m1_t, vint8m1_t, vint8m1_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vsuxseg3ei16_v)))
void vsuxseg3ei16_v_i8m2(int8_t *, vuint16m4_t, vint8m2_t, vint8m2_t, vint8m2_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vsuxseg3ei16_v_m)))
void vsuxseg3ei16_v_i8m2_m(vbool4_t, int8_t *, vuint16m4_t, vint8m2_t, vint8m2_t, vint8m2_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vsuxseg3ei16_v)))
void vsuxseg3ei16_v_i8mf2(int8_t *, vuint16m1_t, vint8mf2_t, vint8mf2_t, vint8mf2_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vsuxseg3ei16_v_m)))
void vsuxseg3ei16_v_i8mf2_m(vbool16_t, int8_t *, vuint16m1_t, vint8mf2_t, vint8mf2_t, vint8mf2_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vsuxseg3ei16_v)))
void vsuxseg3ei16_v_i8mf4(int8_t *, vuint16mf2_t, vint8mf4_t, vint8mf4_t, vint8mf4_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vsuxseg3ei16_v_m)))
void vsuxseg3ei16_v_i8mf4_m(vbool32_t, int8_t *, vuint16mf2_t, vint8mf4_t, vint8mf4_t, vint8mf4_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vsuxseg3ei16_v)))
void vsuxseg3ei16_v_i8mf8(int8_t *, vuint16mf4_t, vint8mf8_t, vint8mf8_t, vint8mf8_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vsuxseg3ei16_v_m)))
void vsuxseg3ei16_v_i8mf8_m(vbool64_t, int8_t *, vuint16mf4_t, vint8mf8_t, vint8mf8_t, vint8mf8_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vsuxseg3ei16_v)))
void vsuxseg3ei16_v_u8m1(uint8_t *, vuint16m2_t, vuint8m1_t, vuint8m1_t, vuint8m1_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vsuxseg3ei16_v_m)))
void vsuxseg3ei16_v_u8m1_m(vbool8_t, uint8_t *, vuint16m2_t, vuint8m1_t, vuint8m1_t, vuint8m1_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vsuxseg3ei16_v)))
void vsuxseg3ei16_v_u8m2(uint8_t *, vuint16m4_t, vuint8m2_t, vuint8m2_t, vuint8m2_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vsuxseg3ei16_v_m)))
void vsuxseg3ei16_v_u8m2_m(vbool4_t, uint8_t *, vuint16m4_t, vuint8m2_t, vuint8m2_t, vuint8m2_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vsuxseg3ei16_v)))
void vsuxseg3ei16_v_u8mf2(uint8_t *, vuint16m1_t, vuint8mf2_t, vuint8mf2_t, vuint8mf2_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vsuxseg3ei16_v_m)))
void vsuxseg3ei16_v_u8mf2_m(vbool16_t, uint8_t *, vuint16m1_t, vuint8mf2_t, vuint8mf2_t, vuint8mf2_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vsuxseg3ei16_v)))
void vsuxseg3ei16_v_u8mf4(uint8_t *, vuint16mf2_t, vuint8mf4_t, vuint8mf4_t, vuint8mf4_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vsuxseg3ei16_v_m)))
void vsuxseg3ei16_v_u8mf4_m(vbool32_t, uint8_t *, vuint16mf2_t, vuint8mf4_t, vuint8mf4_t, vuint8mf4_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vsuxseg3ei16_v)))
void vsuxseg3ei16_v_u8mf8(uint8_t *, vuint16mf4_t, vuint8mf8_t, vuint8mf8_t, vuint8mf8_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vsuxseg3ei16_v_m)))
void vsuxseg3ei16_v_u8mf8_m(vbool64_t, uint8_t *, vuint16mf4_t, vuint8mf8_t, vuint8mf8_t, vuint8mf8_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vsuxseg4ei16_v)))
void vsuxseg4ei16_v_i8m1(int8_t *, vuint16m2_t, vint8m1_t, vint8m1_t, vint8m1_t, vint8m1_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vsuxseg4ei16_v_m)))
void vsuxseg4ei16_v_i8m1_m(vbool8_t, int8_t *, vuint16m2_t, vint8m1_t, vint8m1_t, vint8m1_t, vint8m1_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vsuxseg4ei16_v)))
void vsuxseg4ei16_v_i8m2(int8_t *, vuint16m4_t, vint8m2_t, vint8m2_t, vint8m2_t, vint8m2_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vsuxseg4ei16_v_m)))
void vsuxseg4ei16_v_i8m2_m(vbool4_t, int8_t *, vuint16m4_t, vint8m2_t, vint8m2_t, vint8m2_t, vint8m2_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vsuxseg4ei16_v)))
void vsuxseg4ei16_v_i8mf2(int8_t *, vuint16m1_t, vint8mf2_t, vint8mf2_t, vint8mf2_t, vint8mf2_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vsuxseg4ei16_v_m)))
void vsuxseg4ei16_v_i8mf2_m(vbool16_t, int8_t *, vuint16m1_t, vint8mf2_t, vint8mf2_t, vint8mf2_t, vint8mf2_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vsuxseg4ei16_v)))
void vsuxseg4ei16_v_i8mf4(int8_t *, vuint16mf2_t, vint8mf4_t, vint8mf4_t, vint8mf4_t, vint8mf4_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vsuxseg4ei16_v_m)))
void vsuxseg4ei16_v_i8mf4_m(vbool32_t, int8_t *, vuint16mf2_t, vint8mf4_t, vint8mf4_t, vint8mf4_t, vint8mf4_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vsuxseg4ei16_v)))
void vsuxseg4ei16_v_i8mf8(int8_t *, vuint16mf4_t, vint8mf8_t, vint8mf8_t, vint8mf8_t, vint8mf8_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vsuxseg4ei16_v_m)))
void vsuxseg4ei16_v_i8mf8_m(vbool64_t, int8_t *, vuint16mf4_t, vint8mf8_t, vint8mf8_t, vint8mf8_t, vint8mf8_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vsuxseg4ei16_v)))
void vsuxseg4ei16_v_u8m1(uint8_t *, vuint16m2_t, vuint8m1_t, vuint8m1_t, vuint8m1_t, vuint8m1_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vsuxseg4ei16_v_m)))
void vsuxseg4ei16_v_u8m1_m(vbool8_t, uint8_t *, vuint16m2_t, vuint8m1_t, vuint8m1_t, vuint8m1_t, vuint8m1_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vsuxseg4ei16_v)))
void vsuxseg4ei16_v_u8m2(uint8_t *, vuint16m4_t, vuint8m2_t, vuint8m2_t, vuint8m2_t, vuint8m2_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vsuxseg4ei16_v_m)))
void vsuxseg4ei16_v_u8m2_m(vbool4_t, uint8_t *, vuint16m4_t, vuint8m2_t, vuint8m2_t, vuint8m2_t, vuint8m2_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vsuxseg4ei16_v)))
void vsuxseg4ei16_v_u8mf2(uint8_t *, vuint16m1_t, vuint8mf2_t, vuint8mf2_t, vuint8mf2_t, vuint8mf2_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vsuxseg4ei16_v_m)))
void vsuxseg4ei16_v_u8mf2_m(vbool16_t, uint8_t *, vuint16m1_t, vuint8mf2_t, vuint8mf2_t, vuint8mf2_t, vuint8mf2_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vsuxseg4ei16_v)))
void vsuxseg4ei16_v_u8mf4(uint8_t *, vuint16mf2_t, vuint8mf4_t, vuint8mf4_t, vuint8mf4_t, vuint8mf4_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vsuxseg4ei16_v_m)))
void vsuxseg4ei16_v_u8mf4_m(vbool32_t, uint8_t *, vuint16mf2_t, vuint8mf4_t, vuint8mf4_t, vuint8mf4_t, vuint8mf4_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vsuxseg4ei16_v)))
void vsuxseg4ei16_v_u8mf8(uint8_t *, vuint16mf4_t, vuint8mf8_t, vuint8mf8_t, vuint8mf8_t, vuint8mf8_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vsuxseg4ei16_v_m)))
void vsuxseg4ei16_v_u8mf8_m(vbool64_t, uint8_t *, vuint16mf4_t, vuint8mf8_t, vuint8mf8_t, vuint8mf8_t, vuint8mf8_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vsuxseg5ei16_v)))
void vsuxseg5ei16_v_i8m1(int8_t *, vuint16m2_t, vint8m1_t, vint8m1_t, vint8m1_t, vint8m1_t, vint8m1_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vsuxseg5ei16_v_m)))
void vsuxseg5ei16_v_i8m1_m(vbool8_t, int8_t *, vuint16m2_t, vint8m1_t, vint8m1_t, vint8m1_t, vint8m1_t, vint8m1_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vsuxseg5ei16_v)))
void vsuxseg5ei16_v_i8mf2(int8_t *, vuint16m1_t, vint8mf2_t, vint8mf2_t, vint8mf2_t, vint8mf2_t, vint8mf2_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vsuxseg5ei16_v_m)))
void vsuxseg5ei16_v_i8mf2_m(vbool16_t, int8_t *, vuint16m1_t, vint8mf2_t, vint8mf2_t, vint8mf2_t, vint8mf2_t, vint8mf2_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vsuxseg5ei16_v)))
void vsuxseg5ei16_v_i8mf4(int8_t *, vuint16mf2_t, vint8mf4_t, vint8mf4_t, vint8mf4_t, vint8mf4_t, vint8mf4_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vsuxseg5ei16_v_m)))
void vsuxseg5ei16_v_i8mf4_m(vbool32_t, int8_t *, vuint16mf2_t, vint8mf4_t, vint8mf4_t, vint8mf4_t, vint8mf4_t, vint8mf4_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vsuxseg5ei16_v)))
void vsuxseg5ei16_v_i8mf8(int8_t *, vuint16mf4_t, vint8mf8_t, vint8mf8_t, vint8mf8_t, vint8mf8_t, vint8mf8_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vsuxseg5ei16_v_m)))
void vsuxseg5ei16_v_i8mf8_m(vbool64_t, int8_t *, vuint16mf4_t, vint8mf8_t, vint8mf8_t, vint8mf8_t, vint8mf8_t, vint8mf8_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vluxei32_v)))
vuint32m1_t vluxei32_v_u32m1(const uint32_t *, vuint32m1_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vluxei32_v_m)))
vuint32m1_t vluxei32_v_u32m1_m(vbool32_t, vuint32m1_t, const uint32_t *, vuint32m1_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vluxei32_v)))
vuint32m2_t vluxei32_v_u32m2(const uint32_t *, vuint32m2_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vluxei32_v_m)))
vuint32m2_t vluxei32_v_u32m2_m(vbool16_t, vuint32m2_t, const uint32_t *, vuint32m2_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vluxei32_v)))
vuint32m4_t vluxei32_v_u32m4(const uint32_t *, vuint32m4_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vluxei32_v_m)))
vuint32m4_t vluxei32_v_u32m4_m(vbool8_t, vuint32m4_t, const uint32_t *, vuint32m4_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vluxei32_v)))
vuint32m8_t vluxei32_v_u32m8(const uint32_t *, vuint32m8_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vluxei32_v_m)))
vuint32m8_t vluxei32_v_u32m8_m(vbool4_t, vuint32m8_t, const uint32_t *, vuint32m8_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vluxei32_v)))
vuint32mf2_t vluxei32_v_u32mf2(const uint32_t *, vuint32mf2_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vluxei32_v_m)))
vuint32mf2_t vluxei32_v_u32mf2_m(vbool64_t, vuint32mf2_t, const uint32_t *, vuint32mf2_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vsuxseg5ei16_v)))
void vsuxseg5ei16_v_u8m1(uint8_t *, vuint16m2_t, vuint8m1_t, vuint8m1_t, vuint8m1_t, vuint8m1_t, vuint8m1_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vsuxseg5ei16_v_m)))
void vsuxseg5ei16_v_u8m1_m(vbool8_t, uint8_t *, vuint16m2_t, vuint8m1_t, vuint8m1_t, vuint8m1_t, vuint8m1_t, vuint8m1_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vsuxseg5ei16_v)))
void vsuxseg5ei16_v_u8mf2(uint8_t *, vuint16m1_t, vuint8mf2_t, vuint8mf2_t, vuint8mf2_t, vuint8mf2_t, vuint8mf2_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vsuxseg5ei16_v_m)))
void vsuxseg5ei16_v_u8mf2_m(vbool16_t, uint8_t *, vuint16m1_t, vuint8mf2_t, vuint8mf2_t, vuint8mf2_t, vuint8mf2_t, vuint8mf2_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vsuxseg5ei16_v)))
void vsuxseg5ei16_v_u8mf4(uint8_t *, vuint16mf2_t, vuint8mf4_t, vuint8mf4_t, vuint8mf4_t, vuint8mf4_t, vuint8mf4_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vsuxseg5ei16_v_m)))
void vsuxseg5ei16_v_u8mf4_m(vbool32_t, uint8_t *, vuint16mf2_t, vuint8mf4_t, vuint8mf4_t, vuint8mf4_t, vuint8mf4_t, vuint8mf4_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vsuxseg5ei16_v)))
void vsuxseg5ei16_v_u8mf8(uint8_t *, vuint16mf4_t, vuint8mf8_t, vuint8mf8_t, vuint8mf8_t, vuint8mf8_t, vuint8mf8_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vsuxseg5ei16_v_m)))
void vsuxseg5ei16_v_u8mf8_m(vbool64_t, uint8_t *, vuint16mf4_t, vuint8mf8_t, vuint8mf8_t, vuint8mf8_t, vuint8mf8_t, vuint8mf8_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vsuxseg6ei16_v)))
void vsuxseg6ei16_v_i8m1(int8_t *, vuint16m2_t, vint8m1_t, vint8m1_t, vint8m1_t, vint8m1_t, vint8m1_t, vint8m1_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vsuxseg6ei16_v_m)))
void vsuxseg6ei16_v_i8m1_m(vbool8_t, int8_t *, vuint16m2_t, vint8m1_t, vint8m1_t, vint8m1_t, vint8m1_t, vint8m1_t, vint8m1_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vsuxseg6ei16_v)))
void vsuxseg6ei16_v_i8mf2(int8_t *, vuint16m1_t, vint8mf2_t, vint8mf2_t, vint8mf2_t, vint8mf2_t, vint8mf2_t, vint8mf2_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vsuxseg6ei16_v_m)))
void vsuxseg6ei16_v_i8mf2_m(vbool16_t, int8_t *, vuint16m1_t, vint8mf2_t, vint8mf2_t, vint8mf2_t, vint8mf2_t, vint8mf2_t, vint8mf2_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vsuxseg6ei16_v)))
void vsuxseg6ei16_v_i8mf4(int8_t *, vuint16mf2_t, vint8mf4_t, vint8mf4_t, vint8mf4_t, vint8mf4_t, vint8mf4_t, vint8mf4_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vsuxseg6ei16_v_m)))
void vsuxseg6ei16_v_i8mf4_m(vbool32_t, int8_t *, vuint16mf2_t, vint8mf4_t, vint8mf4_t, vint8mf4_t, vint8mf4_t, vint8mf4_t, vint8mf4_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vsuxseg6ei16_v)))
void vsuxseg6ei16_v_i8mf8(int8_t *, vuint16mf4_t, vint8mf8_t, vint8mf8_t, vint8mf8_t, vint8mf8_t, vint8mf8_t, vint8mf8_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vsuxseg6ei16_v_m)))
void vsuxseg6ei16_v_i8mf8_m(vbool64_t, int8_t *, vuint16mf4_t, vint8mf8_t, vint8mf8_t, vint8mf8_t, vint8mf8_t, vint8mf8_t, vint8mf8_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vsuxseg6ei16_v)))
void vsuxseg6ei16_v_u8m1(uint8_t *, vuint16m2_t, vuint8m1_t, vuint8m1_t, vuint8m1_t, vuint8m1_t, vuint8m1_t, vuint8m1_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vsuxseg6ei16_v_m)))
void vsuxseg6ei16_v_u8m1_m(vbool8_t, uint8_t *, vuint16m2_t, vuint8m1_t, vuint8m1_t, vuint8m1_t, vuint8m1_t, vuint8m1_t, vuint8m1_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vsuxseg6ei16_v)))
void vsuxseg6ei16_v_u8mf2(uint8_t *, vuint16m1_t, vuint8mf2_t, vuint8mf2_t, vuint8mf2_t, vuint8mf2_t, vuint8mf2_t, vuint8mf2_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vsuxseg6ei16_v_m)))
void vsuxseg6ei16_v_u8mf2_m(vbool16_t, uint8_t *, vuint16m1_t, vuint8mf2_t, vuint8mf2_t, vuint8mf2_t, vuint8mf2_t, vuint8mf2_t, vuint8mf2_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vsuxseg6ei16_v)))
void vsuxseg6ei16_v_u8mf4(uint8_t *, vuint16mf2_t, vuint8mf4_t, vuint8mf4_t, vuint8mf4_t, vuint8mf4_t, vuint8mf4_t, vuint8mf4_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vsuxseg6ei16_v_m)))
void vsuxseg6ei16_v_u8mf4_m(vbool32_t, uint8_t *, vuint16mf2_t, vuint8mf4_t, vuint8mf4_t, vuint8mf4_t, vuint8mf4_t, vuint8mf4_t, vuint8mf4_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vsuxseg6ei16_v)))
void vsuxseg6ei16_v_u8mf8(uint8_t *, vuint16mf4_t, vuint8mf8_t, vuint8mf8_t, vuint8mf8_t, vuint8mf8_t, vuint8mf8_t, vuint8mf8_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vsuxseg6ei16_v_m)))
void vsuxseg6ei16_v_u8mf8_m(vbool64_t, uint8_t *, vuint16mf4_t, vuint8mf8_t, vuint8mf8_t, vuint8mf8_t, vuint8mf8_t, vuint8mf8_t, vuint8mf8_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vsuxseg7ei16_v)))
void vsuxseg7ei16_v_i8m1(int8_t *, vuint16m2_t, vint8m1_t, vint8m1_t, vint8m1_t, vint8m1_t, vint8m1_t, vint8m1_t, vint8m1_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vsuxseg7ei16_v_m)))
void vsuxseg7ei16_v_i8m1_m(vbool8_t, int8_t *, vuint16m2_t, vint8m1_t, vint8m1_t, vint8m1_t, vint8m1_t, vint8m1_t, vint8m1_t, vint8m1_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vsuxseg7ei16_v)))
void vsuxseg7ei16_v_i8mf2(int8_t *, vuint16m1_t, vint8mf2_t, vint8mf2_t, vint8mf2_t, vint8mf2_t, vint8mf2_t, vint8mf2_t, vint8mf2_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vsuxseg7ei16_v_m)))
void vsuxseg7ei16_v_i8mf2_m(vbool16_t, int8_t *, vuint16m1_t, vint8mf2_t, vint8mf2_t, vint8mf2_t, vint8mf2_t, vint8mf2_t, vint8mf2_t, vint8mf2_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vsuxseg7ei16_v)))
void vsuxseg7ei16_v_i8mf4(int8_t *, vuint16mf2_t, vint8mf4_t, vint8mf4_t, vint8mf4_t, vint8mf4_t, vint8mf4_t, vint8mf4_t, vint8mf4_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vsuxseg7ei16_v_m)))
void vsuxseg7ei16_v_i8mf4_m(vbool32_t, int8_t *, vuint16mf2_t, vint8mf4_t, vint8mf4_t, vint8mf4_t, vint8mf4_t, vint8mf4_t, vint8mf4_t, vint8mf4_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vsuxseg7ei16_v)))
void vsuxseg7ei16_v_i8mf8(int8_t *, vuint16mf4_t, vint8mf8_t, vint8mf8_t, vint8mf8_t, vint8mf8_t, vint8mf8_t, vint8mf8_t, vint8mf8_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vsuxseg7ei16_v_m)))
void vsuxseg7ei16_v_i8mf8_m(vbool64_t, int8_t *, vuint16mf4_t, vint8mf8_t, vint8mf8_t, vint8mf8_t, vint8mf8_t, vint8mf8_t, vint8mf8_t, vint8mf8_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vsuxseg7ei16_v)))
void vsuxseg7ei16_v_u8m1(uint8_t *, vuint16m2_t, vuint8m1_t, vuint8m1_t, vuint8m1_t, vuint8m1_t, vuint8m1_t, vuint8m1_t, vuint8m1_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vsuxseg7ei16_v_m)))
void vsuxseg7ei16_v_u8m1_m(vbool8_t, uint8_t *, vuint16m2_t, vuint8m1_t, vuint8m1_t, vuint8m1_t, vuint8m1_t, vuint8m1_t, vuint8m1_t, vuint8m1_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vsuxseg7ei16_v)))
void vsuxseg7ei16_v_u8mf2(uint8_t *, vuint16m1_t, vuint8mf2_t, vuint8mf2_t, vuint8mf2_t, vuint8mf2_t, vuint8mf2_t, vuint8mf2_t, vuint8mf2_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vsuxseg7ei16_v_m)))
void vsuxseg7ei16_v_u8mf2_m(vbool16_t, uint8_t *, vuint16m1_t, vuint8mf2_t, vuint8mf2_t, vuint8mf2_t, vuint8mf2_t, vuint8mf2_t, vuint8mf2_t, vuint8mf2_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vsuxseg7ei16_v)))
void vsuxseg7ei16_v_u8mf4(uint8_t *, vuint16mf2_t, vuint8mf4_t, vuint8mf4_t, vuint8mf4_t, vuint8mf4_t, vuint8mf4_t, vuint8mf4_t, vuint8mf4_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vsuxseg7ei16_v_m)))
void vsuxseg7ei16_v_u8mf4_m(vbool32_t, uint8_t *, vuint16mf2_t, vuint8mf4_t, vuint8mf4_t, vuint8mf4_t, vuint8mf4_t, vuint8mf4_t, vuint8mf4_t, vuint8mf4_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vsuxseg7ei16_v)))
void vsuxseg7ei16_v_u8mf8(uint8_t *, vuint16mf4_t, vuint8mf8_t, vuint8mf8_t, vuint8mf8_t, vuint8mf8_t, vuint8mf8_t, vuint8mf8_t, vuint8mf8_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vsuxseg7ei16_v_m)))
void vsuxseg7ei16_v_u8mf8_m(vbool64_t, uint8_t *, vuint16mf4_t, vuint8mf8_t, vuint8mf8_t, vuint8mf8_t, vuint8mf8_t, vuint8mf8_t, vuint8mf8_t, vuint8mf8_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vsuxseg8ei16_v)))
void vsuxseg8ei16_v_i8m1(int8_t *, vuint16m2_t, vint8m1_t, vint8m1_t, vint8m1_t, vint8m1_t, vint8m1_t, vint8m1_t, vint8m1_t, vint8m1_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vsuxseg8ei16_v_m)))
void vsuxseg8ei16_v_i8m1_m(vbool8_t, int8_t *, vuint16m2_t, vint8m1_t, vint8m1_t, vint8m1_t, vint8m1_t, vint8m1_t, vint8m1_t, vint8m1_t, vint8m1_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vsuxseg8ei16_v)))
void vsuxseg8ei16_v_i8mf2(int8_t *, vuint16m1_t, vint8mf2_t, vint8mf2_t, vint8mf2_t, vint8mf2_t, vint8mf2_t, vint8mf2_t, vint8mf2_t, vint8mf2_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vsuxseg8ei16_v_m)))
void vsuxseg8ei16_v_i8mf2_m(vbool16_t, int8_t *, vuint16m1_t, vint8mf2_t, vint8mf2_t, vint8mf2_t, vint8mf2_t, vint8mf2_t, vint8mf2_t, vint8mf2_t, vint8mf2_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vsuxseg8ei16_v)))
void vsuxseg8ei16_v_i8mf4(int8_t *, vuint16mf2_t, vint8mf4_t, vint8mf4_t, vint8mf4_t, vint8mf4_t, vint8mf4_t, vint8mf4_t, vint8mf4_t, vint8mf4_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vsuxseg8ei16_v_m)))
void vsuxseg8ei16_v_i8mf4_m(vbool32_t, int8_t *, vuint16mf2_t, vint8mf4_t, vint8mf4_t, vint8mf4_t, vint8mf4_t, vint8mf4_t, vint8mf4_t, vint8mf4_t, vint8mf4_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vsuxseg8ei16_v)))
void vsuxseg8ei16_v_i8mf8(int8_t *, vuint16mf4_t, vint8mf8_t, vint8mf8_t, vint8mf8_t, vint8mf8_t, vint8mf8_t, vint8mf8_t, vint8mf8_t, vint8mf8_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vsuxseg8ei16_v_m)))
void vsuxseg8ei16_v_i8mf8_m(vbool64_t, int8_t *, vuint16mf4_t, vint8mf8_t, vint8mf8_t, vint8mf8_t, vint8mf8_t, vint8mf8_t, vint8mf8_t, vint8mf8_t, vint8mf8_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vsuxseg8ei16_v)))
void vsuxseg8ei16_v_u8m1(uint8_t *, vuint16m2_t, vuint8m1_t, vuint8m1_t, vuint8m1_t, vuint8m1_t, vuint8m1_t, vuint8m1_t, vuint8m1_t, vuint8m1_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vsuxseg8ei16_v_m)))
void vsuxseg8ei16_v_u8m1_m(vbool8_t, uint8_t *, vuint16m2_t, vuint8m1_t, vuint8m1_t, vuint8m1_t, vuint8m1_t, vuint8m1_t, vuint8m1_t, vuint8m1_t, vuint8m1_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vsuxseg8ei16_v)))
void vsuxseg8ei16_v_u8mf2(uint8_t *, vuint16m1_t, vuint8mf2_t, vuint8mf2_t, vuint8mf2_t, vuint8mf2_t, vuint8mf2_t, vuint8mf2_t, vuint8mf2_t, vuint8mf2_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vsuxseg8ei16_v_m)))
void vsuxseg8ei16_v_u8mf2_m(vbool16_t, uint8_t *, vuint16m1_t, vuint8mf2_t, vuint8mf2_t, vuint8mf2_t, vuint8mf2_t, vuint8mf2_t, vuint8mf2_t, vuint8mf2_t, vuint8mf2_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vsuxseg8ei16_v)))
void vsuxseg8ei16_v_u8mf4(uint8_t *, vuint16mf2_t, vuint8mf4_t, vuint8mf4_t, vuint8mf4_t, vuint8mf4_t, vuint8mf4_t, vuint8mf4_t, vuint8mf4_t, vuint8mf4_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vsuxseg8ei16_v_m)))
void vsuxseg8ei16_v_u8mf4_m(vbool32_t, uint8_t *, vuint16mf2_t, vuint8mf4_t, vuint8mf4_t, vuint8mf4_t, vuint8mf4_t, vuint8mf4_t, vuint8mf4_t, vuint8mf4_t, vuint8mf4_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vsuxseg8ei16_v)))
void vsuxseg8ei16_v_u8mf8(uint8_t *, vuint16mf4_t, vuint8mf8_t, vuint8mf8_t, vuint8mf8_t, vuint8mf8_t, vuint8mf8_t, vuint8mf8_t, vuint8mf8_t, vuint8mf8_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vsuxseg8ei16_v_m)))
void vsuxseg8ei16_v_u8mf8_m(vbool64_t, uint8_t *, vuint16mf4_t, vuint8mf8_t, vuint8mf8_t, vuint8mf8_t, vuint8mf8_t, vuint8mf8_t, vuint8mf8_t, vuint8mf8_t, vuint8mf8_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vsuxseg2ei32_v)))
void vsuxseg2ei32_v_i8m1(int8_t *, vuint32m4_t, vint8m1_t, vint8m1_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vsuxseg2ei32_v_m)))
void vsuxseg2ei32_v_i8m1_m(vbool8_t, int8_t *, vuint32m4_t, vint8m1_t, vint8m1_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vsuxseg2ei32_v)))
void vsuxseg2ei32_v_i8m2(int8_t *, vuint32m8_t, vint8m2_t, vint8m2_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vsuxseg2ei32_v_m)))
void vsuxseg2ei32_v_i8m2_m(vbool4_t, int8_t *, vuint32m8_t, vint8m2_t, vint8m2_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vsuxseg2ei32_v)))
void vsuxseg2ei32_v_i8mf2(int8_t *, vuint32m2_t, vint8mf2_t, vint8mf2_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vsuxseg2ei32_v_m)))
void vsuxseg2ei32_v_i8mf2_m(vbool16_t, int8_t *, vuint32m2_t, vint8mf2_t, vint8mf2_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vsuxseg2ei32_v)))
void vsuxseg2ei32_v_i8mf4(int8_t *, vuint32m1_t, vint8mf4_t, vint8mf4_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vsuxseg2ei32_v_m)))
void vsuxseg2ei32_v_i8mf4_m(vbool32_t, int8_t *, vuint32m1_t, vint8mf4_t, vint8mf4_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vsuxseg2ei32_v)))
void vsuxseg2ei32_v_i8mf8(int8_t *, vuint32mf2_t, vint8mf8_t, vint8mf8_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vsuxseg2ei32_v_m)))
void vsuxseg2ei32_v_i8mf8_m(vbool64_t, int8_t *, vuint32mf2_t, vint8mf8_t, vint8mf8_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vsuxseg2ei32_v)))
void vsuxseg2ei32_v_u8m1(uint8_t *, vuint32m4_t, vuint8m1_t, vuint8m1_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vsuxseg2ei32_v_m)))
void vsuxseg2ei32_v_u8m1_m(vbool8_t, uint8_t *, vuint32m4_t, vuint8m1_t, vuint8m1_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vsuxseg2ei32_v)))
void vsuxseg2ei32_v_u8m2(uint8_t *, vuint32m8_t, vuint8m2_t, vuint8m2_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vsuxseg2ei32_v_m)))
void vsuxseg2ei32_v_u8m2_m(vbool4_t, uint8_t *, vuint32m8_t, vuint8m2_t, vuint8m2_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vsuxseg2ei32_v)))
void vsuxseg2ei32_v_u8mf2(uint8_t *, vuint32m2_t, vuint8mf2_t, vuint8mf2_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vsuxseg2ei32_v_m)))
void vsuxseg2ei32_v_u8mf2_m(vbool16_t, uint8_t *, vuint32m2_t, vuint8mf2_t, vuint8mf2_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vsuxseg2ei32_v)))
void vsuxseg2ei32_v_u8mf4(uint8_t *, vuint32m1_t, vuint8mf4_t, vuint8mf4_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vsuxseg2ei32_v_m)))
void vsuxseg2ei32_v_u8mf4_m(vbool32_t, uint8_t *, vuint32m1_t, vuint8mf4_t, vuint8mf4_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vsuxseg2ei32_v)))
void vsuxseg2ei32_v_u8mf8(uint8_t *, vuint32mf2_t, vuint8mf8_t, vuint8mf8_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vsuxseg2ei32_v_m)))
void vsuxseg2ei32_v_u8mf8_m(vbool64_t, uint8_t *, vuint32mf2_t, vuint8mf8_t, vuint8mf8_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vsuxseg3ei32_v)))
void vsuxseg3ei32_v_i8m1(int8_t *, vuint32m4_t, vint8m1_t, vint8m1_t, vint8m1_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vsuxseg3ei32_v_m)))
void vsuxseg3ei32_v_i8m1_m(vbool8_t, int8_t *, vuint32m4_t, vint8m1_t, vint8m1_t, vint8m1_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vsuxseg3ei32_v)))
void vsuxseg3ei32_v_i8m2(int8_t *, vuint32m8_t, vint8m2_t, vint8m2_t, vint8m2_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vsuxseg3ei32_v_m)))
void vsuxseg3ei32_v_i8m2_m(vbool4_t, int8_t *, vuint32m8_t, vint8m2_t, vint8m2_t, vint8m2_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vsuxseg3ei32_v)))
void vsuxseg3ei32_v_i8mf2(int8_t *, vuint32m2_t, vint8mf2_t, vint8mf2_t, vint8mf2_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vsuxseg3ei32_v_m)))
void vsuxseg3ei32_v_i8mf2_m(vbool16_t, int8_t *, vuint32m2_t, vint8mf2_t, vint8mf2_t, vint8mf2_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vsuxseg3ei32_v)))
void vsuxseg3ei32_v_i8mf4(int8_t *, vuint32m1_t, vint8mf4_t, vint8mf4_t, vint8mf4_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vsuxseg3ei32_v_m)))
void vsuxseg3ei32_v_i8mf4_m(vbool32_t, int8_t *, vuint32m1_t, vint8mf4_t, vint8mf4_t, vint8mf4_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vsuxseg3ei32_v)))
void vsuxseg3ei32_v_i8mf8(int8_t *, vuint32mf2_t, vint8mf8_t, vint8mf8_t, vint8mf8_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vsuxseg3ei32_v_m)))
void vsuxseg3ei32_v_i8mf8_m(vbool64_t, int8_t *, vuint32mf2_t, vint8mf8_t, vint8mf8_t, vint8mf8_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vsuxseg3ei32_v)))
void vsuxseg3ei32_v_u8m1(uint8_t *, vuint32m4_t, vuint8m1_t, vuint8m1_t, vuint8m1_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vsuxseg3ei32_v_m)))
void vsuxseg3ei32_v_u8m1_m(vbool8_t, uint8_t *, vuint32m4_t, vuint8m1_t, vuint8m1_t, vuint8m1_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vsuxseg3ei32_v)))
void vsuxseg3ei32_v_u8m2(uint8_t *, vuint32m8_t, vuint8m2_t, vuint8m2_t, vuint8m2_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vsuxseg3ei32_v_m)))
void vsuxseg3ei32_v_u8m2_m(vbool4_t, uint8_t *, vuint32m8_t, vuint8m2_t, vuint8m2_t, vuint8m2_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vsuxseg3ei32_v)))
void vsuxseg3ei32_v_u8mf2(uint8_t *, vuint32m2_t, vuint8mf2_t, vuint8mf2_t, vuint8mf2_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vsuxseg3ei32_v_m)))
void vsuxseg3ei32_v_u8mf2_m(vbool16_t, uint8_t *, vuint32m2_t, vuint8mf2_t, vuint8mf2_t, vuint8mf2_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vsuxseg3ei32_v)))
void vsuxseg3ei32_v_u8mf4(uint8_t *, vuint32m1_t, vuint8mf4_t, vuint8mf4_t, vuint8mf4_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vsuxseg3ei32_v_m)))
void vsuxseg3ei32_v_u8mf4_m(vbool32_t, uint8_t *, vuint32m1_t, vuint8mf4_t, vuint8mf4_t, vuint8mf4_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vsuxseg3ei32_v)))
void vsuxseg3ei32_v_u8mf8(uint8_t *, vuint32mf2_t, vuint8mf8_t, vuint8mf8_t, vuint8mf8_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vsuxseg3ei32_v_m)))
void vsuxseg3ei32_v_u8mf8_m(vbool64_t, uint8_t *, vuint32mf2_t, vuint8mf8_t, vuint8mf8_t, vuint8mf8_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vsuxseg4ei32_v)))
void vsuxseg4ei32_v_i8m1(int8_t *, vuint32m4_t, vint8m1_t, vint8m1_t, vint8m1_t, vint8m1_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vsuxseg4ei32_v_m)))
void vsuxseg4ei32_v_i8m1_m(vbool8_t, int8_t *, vuint32m4_t, vint8m1_t, vint8m1_t, vint8m1_t, vint8m1_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vsuxseg4ei32_v)))
void vsuxseg4ei32_v_i8m2(int8_t *, vuint32m8_t, vint8m2_t, vint8m2_t, vint8m2_t, vint8m2_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vsuxseg4ei32_v_m)))
void vsuxseg4ei32_v_i8m2_m(vbool4_t, int8_t *, vuint32m8_t, vint8m2_t, vint8m2_t, vint8m2_t, vint8m2_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vsuxseg4ei32_v)))
void vsuxseg4ei32_v_i8mf2(int8_t *, vuint32m2_t, vint8mf2_t, vint8mf2_t, vint8mf2_t, vint8mf2_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vsuxseg4ei32_v_m)))
void vsuxseg4ei32_v_i8mf2_m(vbool16_t, int8_t *, vuint32m2_t, vint8mf2_t, vint8mf2_t, vint8mf2_t, vint8mf2_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vsuxseg4ei32_v)))
void vsuxseg4ei32_v_i8mf4(int8_t *, vuint32m1_t, vint8mf4_t, vint8mf4_t, vint8mf4_t, vint8mf4_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vsuxseg4ei32_v_m)))
void vsuxseg4ei32_v_i8mf4_m(vbool32_t, int8_t *, vuint32m1_t, vint8mf4_t, vint8mf4_t, vint8mf4_t, vint8mf4_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vsuxseg4ei32_v)))
void vsuxseg4ei32_v_i8mf8(int8_t *, vuint32mf2_t, vint8mf8_t, vint8mf8_t, vint8mf8_t, vint8mf8_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vsuxseg4ei32_v_m)))
void vsuxseg4ei32_v_i8mf8_m(vbool64_t, int8_t *, vuint32mf2_t, vint8mf8_t, vint8mf8_t, vint8mf8_t, vint8mf8_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vsuxseg4ei32_v)))
void vsuxseg4ei32_v_u8m1(uint8_t *, vuint32m4_t, vuint8m1_t, vuint8m1_t, vuint8m1_t, vuint8m1_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vsuxseg4ei32_v_m)))
void vsuxseg4ei32_v_u8m1_m(vbool8_t, uint8_t *, vuint32m4_t, vuint8m1_t, vuint8m1_t, vuint8m1_t, vuint8m1_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vsuxseg4ei32_v)))
void vsuxseg4ei32_v_u8m2(uint8_t *, vuint32m8_t, vuint8m2_t, vuint8m2_t, vuint8m2_t, vuint8m2_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vsuxseg4ei32_v_m)))
void vsuxseg4ei32_v_u8m2_m(vbool4_t, uint8_t *, vuint32m8_t, vuint8m2_t, vuint8m2_t, vuint8m2_t, vuint8m2_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vsuxseg4ei32_v)))
void vsuxseg4ei32_v_u8mf2(uint8_t *, vuint32m2_t, vuint8mf2_t, vuint8mf2_t, vuint8mf2_t, vuint8mf2_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vsuxseg4ei32_v_m)))
void vsuxseg4ei32_v_u8mf2_m(vbool16_t, uint8_t *, vuint32m2_t, vuint8mf2_t, vuint8mf2_t, vuint8mf2_t, vuint8mf2_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vsuxseg4ei32_v)))
void vsuxseg4ei32_v_u8mf4(uint8_t *, vuint32m1_t, vuint8mf4_t, vuint8mf4_t, vuint8mf4_t, vuint8mf4_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vsuxseg4ei32_v_m)))
void vsuxseg4ei32_v_u8mf4_m(vbool32_t, uint8_t *, vuint32m1_t, vuint8mf4_t, vuint8mf4_t, vuint8mf4_t, vuint8mf4_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vsuxseg4ei32_v)))
void vsuxseg4ei32_v_u8mf8(uint8_t *, vuint32mf2_t, vuint8mf8_t, vuint8mf8_t, vuint8mf8_t, vuint8mf8_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vsuxseg4ei32_v_m)))
void vsuxseg4ei32_v_u8mf8_m(vbool64_t, uint8_t *, vuint32mf2_t, vuint8mf8_t, vuint8mf8_t, vuint8mf8_t, vuint8mf8_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vsuxseg5ei32_v)))
void vsuxseg5ei32_v_i8m1(int8_t *, vuint32m4_t, vint8m1_t, vint8m1_t, vint8m1_t, vint8m1_t, vint8m1_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vsuxseg5ei32_v_m)))
void vsuxseg5ei32_v_i8m1_m(vbool8_t, int8_t *, vuint32m4_t, vint8m1_t, vint8m1_t, vint8m1_t, vint8m1_t, vint8m1_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vsuxseg5ei32_v)))
void vsuxseg5ei32_v_i8mf2(int8_t *, vuint32m2_t, vint8mf2_t, vint8mf2_t, vint8mf2_t, vint8mf2_t, vint8mf2_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vsuxseg5ei32_v_m)))
void vsuxseg5ei32_v_i8mf2_m(vbool16_t, int8_t *, vuint32m2_t, vint8mf2_t, vint8mf2_t, vint8mf2_t, vint8mf2_t, vint8mf2_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vsuxseg5ei32_v)))
void vsuxseg5ei32_v_i8mf4(int8_t *, vuint32m1_t, vint8mf4_t, vint8mf4_t, vint8mf4_t, vint8mf4_t, vint8mf4_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vsuxseg5ei32_v_m)))
void vsuxseg5ei32_v_i8mf4_m(vbool32_t, int8_t *, vuint32m1_t, vint8mf4_t, vint8mf4_t, vint8mf4_t, vint8mf4_t, vint8mf4_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vsuxseg5ei32_v)))
void vsuxseg5ei32_v_i8mf8(int8_t *, vuint32mf2_t, vint8mf8_t, vint8mf8_t, vint8mf8_t, vint8mf8_t, vint8mf8_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vsuxseg5ei32_v_m)))
void vsuxseg5ei32_v_i8mf8_m(vbool64_t, int8_t *, vuint32mf2_t, vint8mf8_t, vint8mf8_t, vint8mf8_t, vint8mf8_t, vint8mf8_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vsuxseg5ei32_v)))
void vsuxseg5ei32_v_u8m1(uint8_t *, vuint32m4_t, vuint8m1_t, vuint8m1_t, vuint8m1_t, vuint8m1_t, vuint8m1_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vsuxseg5ei32_v_m)))
void vsuxseg5ei32_v_u8m1_m(vbool8_t, uint8_t *, vuint32m4_t, vuint8m1_t, vuint8m1_t, vuint8m1_t, vuint8m1_t, vuint8m1_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vsuxseg5ei32_v)))
void vsuxseg5ei32_v_u8mf2(uint8_t *, vuint32m2_t, vuint8mf2_t, vuint8mf2_t, vuint8mf2_t, vuint8mf2_t, vuint8mf2_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vsuxseg5ei32_v_m)))
void vsuxseg5ei32_v_u8mf2_m(vbool16_t, uint8_t *, vuint32m2_t, vuint8mf2_t, vuint8mf2_t, vuint8mf2_t, vuint8mf2_t, vuint8mf2_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vsuxseg5ei32_v)))
void vsuxseg5ei32_v_u8mf4(uint8_t *, vuint32m1_t, vuint8mf4_t, vuint8mf4_t, vuint8mf4_t, vuint8mf4_t, vuint8mf4_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vsuxseg5ei32_v_m)))
void vsuxseg5ei32_v_u8mf4_m(vbool32_t, uint8_t *, vuint32m1_t, vuint8mf4_t, vuint8mf4_t, vuint8mf4_t, vuint8mf4_t, vuint8mf4_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vsuxseg5ei32_v)))
void vsuxseg5ei32_v_u8mf8(uint8_t *, vuint32mf2_t, vuint8mf8_t, vuint8mf8_t, vuint8mf8_t, vuint8mf8_t, vuint8mf8_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vsuxseg5ei32_v_m)))
void vsuxseg5ei32_v_u8mf8_m(vbool64_t, uint8_t *, vuint32mf2_t, vuint8mf8_t, vuint8mf8_t, vuint8mf8_t, vuint8mf8_t, vuint8mf8_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vsuxseg6ei32_v)))
void vsuxseg6ei32_v_i8m1(int8_t *, vuint32m4_t, vint8m1_t, vint8m1_t, vint8m1_t, vint8m1_t, vint8m1_t, vint8m1_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vsuxseg6ei32_v_m)))
void vsuxseg6ei32_v_i8m1_m(vbool8_t, int8_t *, vuint32m4_t, vint8m1_t, vint8m1_t, vint8m1_t, vint8m1_t, vint8m1_t, vint8m1_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vsuxseg6ei32_v)))
void vsuxseg6ei32_v_i8mf2(int8_t *, vuint32m2_t, vint8mf2_t, vint8mf2_t, vint8mf2_t, vint8mf2_t, vint8mf2_t, vint8mf2_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vsuxseg6ei32_v_m)))
void vsuxseg6ei32_v_i8mf2_m(vbool16_t, int8_t *, vuint32m2_t, vint8mf2_t, vint8mf2_t, vint8mf2_t, vint8mf2_t, vint8mf2_t, vint8mf2_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vsuxseg6ei32_v)))
void vsuxseg6ei32_v_i8mf4(int8_t *, vuint32m1_t, vint8mf4_t, vint8mf4_t, vint8mf4_t, vint8mf4_t, vint8mf4_t, vint8mf4_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vsuxseg6ei32_v_m)))
void vsuxseg6ei32_v_i8mf4_m(vbool32_t, int8_t *, vuint32m1_t, vint8mf4_t, vint8mf4_t, vint8mf4_t, vint8mf4_t, vint8mf4_t, vint8mf4_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vsuxseg6ei32_v)))
void vsuxseg6ei32_v_i8mf8(int8_t *, vuint32mf2_t, vint8mf8_t, vint8mf8_t, vint8mf8_t, vint8mf8_t, vint8mf8_t, vint8mf8_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vsuxseg6ei32_v_m)))
void vsuxseg6ei32_v_i8mf8_m(vbool64_t, int8_t *, vuint32mf2_t, vint8mf8_t, vint8mf8_t, vint8mf8_t, vint8mf8_t, vint8mf8_t, vint8mf8_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vsuxseg6ei32_v)))
void vsuxseg6ei32_v_u8m1(uint8_t *, vuint32m4_t, vuint8m1_t, vuint8m1_t, vuint8m1_t, vuint8m1_t, vuint8m1_t, vuint8m1_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vsuxseg6ei32_v_m)))
void vsuxseg6ei32_v_u8m1_m(vbool8_t, uint8_t *, vuint32m4_t, vuint8m1_t, vuint8m1_t, vuint8m1_t, vuint8m1_t, vuint8m1_t, vuint8m1_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vsuxseg6ei32_v)))
void vsuxseg6ei32_v_u8mf2(uint8_t *, vuint32m2_t, vuint8mf2_t, vuint8mf2_t, vuint8mf2_t, vuint8mf2_t, vuint8mf2_t, vuint8mf2_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vsuxseg6ei32_v_m)))
void vsuxseg6ei32_v_u8mf2_m(vbool16_t, uint8_t *, vuint32m2_t, vuint8mf2_t, vuint8mf2_t, vuint8mf2_t, vuint8mf2_t, vuint8mf2_t, vuint8mf2_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vsuxseg6ei32_v)))
void vsuxseg6ei32_v_u8mf4(uint8_t *, vuint32m1_t, vuint8mf4_t, vuint8mf4_t, vuint8mf4_t, vuint8mf4_t, vuint8mf4_t, vuint8mf4_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vsuxseg6ei32_v_m)))
void vsuxseg6ei32_v_u8mf4_m(vbool32_t, uint8_t *, vuint32m1_t, vuint8mf4_t, vuint8mf4_t, vuint8mf4_t, vuint8mf4_t, vuint8mf4_t, vuint8mf4_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vsuxseg6ei32_v)))
void vsuxseg6ei32_v_u8mf8(uint8_t *, vuint32mf2_t, vuint8mf8_t, vuint8mf8_t, vuint8mf8_t, vuint8mf8_t, vuint8mf8_t, vuint8mf8_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vsuxseg6ei32_v_m)))
void vsuxseg6ei32_v_u8mf8_m(vbool64_t, uint8_t *, vuint32mf2_t, vuint8mf8_t, vuint8mf8_t, vuint8mf8_t, vuint8mf8_t, vuint8mf8_t, vuint8mf8_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vsuxseg7ei32_v)))
void vsuxseg7ei32_v_i8m1(int8_t *, vuint32m4_t, vint8m1_t, vint8m1_t, vint8m1_t, vint8m1_t, vint8m1_t, vint8m1_t, vint8m1_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vsuxseg7ei32_v_m)))
void vsuxseg7ei32_v_i8m1_m(vbool8_t, int8_t *, vuint32m4_t, vint8m1_t, vint8m1_t, vint8m1_t, vint8m1_t, vint8m1_t, vint8m1_t, vint8m1_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vsuxseg7ei32_v)))
void vsuxseg7ei32_v_i8mf2(int8_t *, vuint32m2_t, vint8mf2_t, vint8mf2_t, vint8mf2_t, vint8mf2_t, vint8mf2_t, vint8mf2_t, vint8mf2_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vsuxseg7ei32_v_m)))
void vsuxseg7ei32_v_i8mf2_m(vbool16_t, int8_t *, vuint32m2_t, vint8mf2_t, vint8mf2_t, vint8mf2_t, vint8mf2_t, vint8mf2_t, vint8mf2_t, vint8mf2_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vsuxseg7ei32_v)))
void vsuxseg7ei32_v_i8mf4(int8_t *, vuint32m1_t, vint8mf4_t, vint8mf4_t, vint8mf4_t, vint8mf4_t, vint8mf4_t, vint8mf4_t, vint8mf4_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vsuxseg7ei32_v_m)))
void vsuxseg7ei32_v_i8mf4_m(vbool32_t, int8_t *, vuint32m1_t, vint8mf4_t, vint8mf4_t, vint8mf4_t, vint8mf4_t, vint8mf4_t, vint8mf4_t, vint8mf4_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vsuxseg7ei32_v)))
void vsuxseg7ei32_v_i8mf8(int8_t *, vuint32mf2_t, vint8mf8_t, vint8mf8_t, vint8mf8_t, vint8mf8_t, vint8mf8_t, vint8mf8_t, vint8mf8_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vsuxseg7ei32_v_m)))
void vsuxseg7ei32_v_i8mf8_m(vbool64_t, int8_t *, vuint32mf2_t, vint8mf8_t, vint8mf8_t, vint8mf8_t, vint8mf8_t, vint8mf8_t, vint8mf8_t, vint8mf8_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vsuxseg7ei32_v)))
void vsuxseg7ei32_v_u8m1(uint8_t *, vuint32m4_t, vuint8m1_t, vuint8m1_t, vuint8m1_t, vuint8m1_t, vuint8m1_t, vuint8m1_t, vuint8m1_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vsuxseg7ei32_v_m)))
void vsuxseg7ei32_v_u8m1_m(vbool8_t, uint8_t *, vuint32m4_t, vuint8m1_t, vuint8m1_t, vuint8m1_t, vuint8m1_t, vuint8m1_t, vuint8m1_t, vuint8m1_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vsuxseg7ei32_v)))
void vsuxseg7ei32_v_u8mf2(uint8_t *, vuint32m2_t, vuint8mf2_t, vuint8mf2_t, vuint8mf2_t, vuint8mf2_t, vuint8mf2_t, vuint8mf2_t, vuint8mf2_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vsuxseg7ei32_v_m)))
void vsuxseg7ei32_v_u8mf2_m(vbool16_t, uint8_t *, vuint32m2_t, vuint8mf2_t, vuint8mf2_t, vuint8mf2_t, vuint8mf2_t, vuint8mf2_t, vuint8mf2_t, vuint8mf2_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vsuxseg7ei32_v)))
void vsuxseg7ei32_v_u8mf4(uint8_t *, vuint32m1_t, vuint8mf4_t, vuint8mf4_t, vuint8mf4_t, vuint8mf4_t, vuint8mf4_t, vuint8mf4_t, vuint8mf4_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vsuxseg7ei32_v_m)))
void vsuxseg7ei32_v_u8mf4_m(vbool32_t, uint8_t *, vuint32m1_t, vuint8mf4_t, vuint8mf4_t, vuint8mf4_t, vuint8mf4_t, vuint8mf4_t, vuint8mf4_t, vuint8mf4_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vsuxseg7ei32_v)))
void vsuxseg7ei32_v_u8mf8(uint8_t *, vuint32mf2_t, vuint8mf8_t, vuint8mf8_t, vuint8mf8_t, vuint8mf8_t, vuint8mf8_t, vuint8mf8_t, vuint8mf8_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vsuxseg7ei32_v_m)))
void vsuxseg7ei32_v_u8mf8_m(vbool64_t, uint8_t *, vuint32mf2_t, vuint8mf8_t, vuint8mf8_t, vuint8mf8_t, vuint8mf8_t, vuint8mf8_t, vuint8mf8_t, vuint8mf8_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vsuxseg8ei32_v)))
void vsuxseg8ei32_v_i8m1(int8_t *, vuint32m4_t, vint8m1_t, vint8m1_t, vint8m1_t, vint8m1_t, vint8m1_t, vint8m1_t, vint8m1_t, vint8m1_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vsuxseg8ei32_v_m)))
void vsuxseg8ei32_v_i8m1_m(vbool8_t, int8_t *, vuint32m4_t, vint8m1_t, vint8m1_t, vint8m1_t, vint8m1_t, vint8m1_t, vint8m1_t, vint8m1_t, vint8m1_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vsuxseg8ei32_v)))
void vsuxseg8ei32_v_i8mf2(int8_t *, vuint32m2_t, vint8mf2_t, vint8mf2_t, vint8mf2_t, vint8mf2_t, vint8mf2_t, vint8mf2_t, vint8mf2_t, vint8mf2_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vsuxseg8ei32_v_m)))
void vsuxseg8ei32_v_i8mf2_m(vbool16_t, int8_t *, vuint32m2_t, vint8mf2_t, vint8mf2_t, vint8mf2_t, vint8mf2_t, vint8mf2_t, vint8mf2_t, vint8mf2_t, vint8mf2_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vsuxseg8ei32_v)))
void vsuxseg8ei32_v_i8mf4(int8_t *, vuint32m1_t, vint8mf4_t, vint8mf4_t, vint8mf4_t, vint8mf4_t, vint8mf4_t, vint8mf4_t, vint8mf4_t, vint8mf4_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vsuxseg8ei32_v_m)))
void vsuxseg8ei32_v_i8mf4_m(vbool32_t, int8_t *, vuint32m1_t, vint8mf4_t, vint8mf4_t, vint8mf4_t, vint8mf4_t, vint8mf4_t, vint8mf4_t, vint8mf4_t, vint8mf4_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vsuxseg8ei32_v)))
void vsuxseg8ei32_v_i8mf8(int8_t *, vuint32mf2_t, vint8mf8_t, vint8mf8_t, vint8mf8_t, vint8mf8_t, vint8mf8_t, vint8mf8_t, vint8mf8_t, vint8mf8_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vsuxseg8ei32_v_m)))
void vsuxseg8ei32_v_i8mf8_m(vbool64_t, int8_t *, vuint32mf2_t, vint8mf8_t, vint8mf8_t, vint8mf8_t, vint8mf8_t, vint8mf8_t, vint8mf8_t, vint8mf8_t, vint8mf8_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vsuxseg8ei32_v)))
void vsuxseg8ei32_v_u8m1(uint8_t *, vuint32m4_t, vuint8m1_t, vuint8m1_t, vuint8m1_t, vuint8m1_t, vuint8m1_t, vuint8m1_t, vuint8m1_t, vuint8m1_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vsuxseg8ei32_v_m)))
void vsuxseg8ei32_v_u8m1_m(vbool8_t, uint8_t *, vuint32m4_t, vuint8m1_t, vuint8m1_t, vuint8m1_t, vuint8m1_t, vuint8m1_t, vuint8m1_t, vuint8m1_t, vuint8m1_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vsuxseg8ei32_v)))
void vsuxseg8ei32_v_u8mf2(uint8_t *, vuint32m2_t, vuint8mf2_t, vuint8mf2_t, vuint8mf2_t, vuint8mf2_t, vuint8mf2_t, vuint8mf2_t, vuint8mf2_t, vuint8mf2_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vsuxseg8ei32_v_m)))
void vsuxseg8ei32_v_u8mf2_m(vbool16_t, uint8_t *, vuint32m2_t, vuint8mf2_t, vuint8mf2_t, vuint8mf2_t, vuint8mf2_t, vuint8mf2_t, vuint8mf2_t, vuint8mf2_t, vuint8mf2_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vsuxseg8ei32_v)))
void vsuxseg8ei32_v_u8mf4(uint8_t *, vuint32m1_t, vuint8mf4_t, vuint8mf4_t, vuint8mf4_t, vuint8mf4_t, vuint8mf4_t, vuint8mf4_t, vuint8mf4_t, vuint8mf4_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vsuxseg8ei32_v_m)))
void vsuxseg8ei32_v_u8mf4_m(vbool32_t, uint8_t *, vuint32m1_t, vuint8mf4_t, vuint8mf4_t, vuint8mf4_t, vuint8mf4_t, vuint8mf4_t, vuint8mf4_t, vuint8mf4_t, vuint8mf4_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vsuxseg8ei32_v)))
void vsuxseg8ei32_v_u8mf8(uint8_t *, vuint32mf2_t, vuint8mf8_t, vuint8mf8_t, vuint8mf8_t, vuint8mf8_t, vuint8mf8_t, vuint8mf8_t, vuint8mf8_t, vuint8mf8_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vsuxseg8ei32_v_m)))
void vsuxseg8ei32_v_u8mf8_m(vbool64_t, uint8_t *, vuint32mf2_t, vuint8mf8_t, vuint8mf8_t, vuint8mf8_t, vuint8mf8_t, vuint8mf8_t, vuint8mf8_t, vuint8mf8_t, vuint8mf8_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vsuxseg2ei8_v)))
void vsuxseg2ei8_v_i16m1(int16_t *, vuint8mf2_t, vint16m1_t, vint16m1_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vsuxseg2ei8_v_m)))
void vsuxseg2ei8_v_i16m1_m(vbool16_t, int16_t *, vuint8mf2_t, vint16m1_t, vint16m1_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vsuxseg2ei8_v)))
void vsuxseg2ei8_v_i16m2(int16_t *, vuint8m1_t, vint16m2_t, vint16m2_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vsuxseg2ei8_v_m)))
void vsuxseg2ei8_v_i16m2_m(vbool8_t, int16_t *, vuint8m1_t, vint16m2_t, vint16m2_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vsuxseg2ei8_v)))
void vsuxseg2ei8_v_i16m4(int16_t *, vuint8m2_t, vint16m4_t, vint16m4_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vsuxseg2ei8_v_m)))
void vsuxseg2ei8_v_i16m4_m(vbool4_t, int16_t *, vuint8m2_t, vint16m4_t, vint16m4_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vsuxseg2ei8_v)))
void vsuxseg2ei8_v_i16mf2(int16_t *, vuint8mf4_t, vint16mf2_t, vint16mf2_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vsuxseg2ei8_v_m)))
void vsuxseg2ei8_v_i16mf2_m(vbool32_t, int16_t *, vuint8mf4_t, vint16mf2_t, vint16mf2_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vsuxseg2ei8_v)))
void vsuxseg2ei8_v_i16mf4(int16_t *, vuint8mf8_t, vint16mf4_t, vint16mf4_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vsuxseg2ei8_v_m)))
void vsuxseg2ei8_v_i16mf4_m(vbool64_t, int16_t *, vuint8mf8_t, vint16mf4_t, vint16mf4_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vsuxseg2ei8_v)))
void vsuxseg2ei8_v_u16m1(uint16_t *, vuint8mf2_t, vuint16m1_t, vuint16m1_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vsuxseg2ei8_v_m)))
void vsuxseg2ei8_v_u16m1_m(vbool16_t, uint16_t *, vuint8mf2_t, vuint16m1_t, vuint16m1_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vsuxseg2ei8_v)))
void vsuxseg2ei8_v_u16m2(uint16_t *, vuint8m1_t, vuint16m2_t, vuint16m2_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vsuxseg2ei8_v_m)))
void vsuxseg2ei8_v_u16m2_m(vbool8_t, uint16_t *, vuint8m1_t, vuint16m2_t, vuint16m2_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vsuxseg2ei8_v)))
void vsuxseg2ei8_v_u16m4(uint16_t *, vuint8m2_t, vuint16m4_t, vuint16m4_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vsuxseg2ei8_v_m)))
void vsuxseg2ei8_v_u16m4_m(vbool4_t, uint16_t *, vuint8m2_t, vuint16m4_t, vuint16m4_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vsuxseg2ei8_v)))
void vsuxseg2ei8_v_u16mf2(uint16_t *, vuint8mf4_t, vuint16mf2_t, vuint16mf2_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vsuxseg2ei8_v_m)))
void vsuxseg2ei8_v_u16mf2_m(vbool32_t, uint16_t *, vuint8mf4_t, vuint16mf2_t, vuint16mf2_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vsuxseg2ei8_v)))
void vsuxseg2ei8_v_u16mf4(uint16_t *, vuint8mf8_t, vuint16mf4_t, vuint16mf4_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vsuxseg2ei8_v_m)))
void vsuxseg2ei8_v_u16mf4_m(vbool64_t, uint16_t *, vuint8mf8_t, vuint16mf4_t, vuint16mf4_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vsuxseg3ei8_v)))
void vsuxseg3ei8_v_i16m1(int16_t *, vuint8mf2_t, vint16m1_t, vint16m1_t, vint16m1_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vsuxseg3ei8_v_m)))
void vsuxseg3ei8_v_i16m1_m(vbool16_t, int16_t *, vuint8mf2_t, vint16m1_t, vint16m1_t, vint16m1_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vsuxseg3ei8_v)))
void vsuxseg3ei8_v_i16m2(int16_t *, vuint8m1_t, vint16m2_t, vint16m2_t, vint16m2_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vsuxseg3ei8_v_m)))
void vsuxseg3ei8_v_i16m2_m(vbool8_t, int16_t *, vuint8m1_t, vint16m2_t, vint16m2_t, vint16m2_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vsuxseg3ei8_v)))
void vsuxseg3ei8_v_i16mf2(int16_t *, vuint8mf4_t, vint16mf2_t, vint16mf2_t, vint16mf2_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vsuxseg3ei8_v_m)))
void vsuxseg3ei8_v_i16mf2_m(vbool32_t, int16_t *, vuint8mf4_t, vint16mf2_t, vint16mf2_t, vint16mf2_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vsuxseg3ei8_v)))
void vsuxseg3ei8_v_i16mf4(int16_t *, vuint8mf8_t, vint16mf4_t, vint16mf4_t, vint16mf4_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vsuxseg3ei8_v_m)))
void vsuxseg3ei8_v_i16mf4_m(vbool64_t, int16_t *, vuint8mf8_t, vint16mf4_t, vint16mf4_t, vint16mf4_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vsuxseg3ei8_v)))
void vsuxseg3ei8_v_u16m1(uint16_t *, vuint8mf2_t, vuint16m1_t, vuint16m1_t, vuint16m1_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vsuxseg3ei8_v_m)))
void vsuxseg3ei8_v_u16m1_m(vbool16_t, uint16_t *, vuint8mf2_t, vuint16m1_t, vuint16m1_t, vuint16m1_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vsuxseg3ei8_v)))
void vsuxseg3ei8_v_u16m2(uint16_t *, vuint8m1_t, vuint16m2_t, vuint16m2_t, vuint16m2_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vsuxseg3ei8_v_m)))
void vsuxseg3ei8_v_u16m2_m(vbool8_t, uint16_t *, vuint8m1_t, vuint16m2_t, vuint16m2_t, vuint16m2_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vsuxseg3ei8_v)))
void vsuxseg3ei8_v_u16mf2(uint16_t *, vuint8mf4_t, vuint16mf2_t, vuint16mf2_t, vuint16mf2_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vsuxseg3ei8_v_m)))
void vsuxseg3ei8_v_u16mf2_m(vbool32_t, uint16_t *, vuint8mf4_t, vuint16mf2_t, vuint16mf2_t, vuint16mf2_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vsuxseg3ei8_v)))
void vsuxseg3ei8_v_u16mf4(uint16_t *, vuint8mf8_t, vuint16mf4_t, vuint16mf4_t, vuint16mf4_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vsuxseg3ei8_v_m)))
void vsuxseg3ei8_v_u16mf4_m(vbool64_t, uint16_t *, vuint8mf8_t, vuint16mf4_t, vuint16mf4_t, vuint16mf4_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vsuxseg4ei8_v)))
void vsuxseg4ei8_v_i16m1(int16_t *, vuint8mf2_t, vint16m1_t, vint16m1_t, vint16m1_t, vint16m1_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vsuxseg4ei8_v_m)))
void vsuxseg4ei8_v_i16m1_m(vbool16_t, int16_t *, vuint8mf2_t, vint16m1_t, vint16m1_t, vint16m1_t, vint16m1_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vsuxseg4ei8_v)))
void vsuxseg4ei8_v_i16m2(int16_t *, vuint8m1_t, vint16m2_t, vint16m2_t, vint16m2_t, vint16m2_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vsuxseg4ei8_v_m)))
void vsuxseg4ei8_v_i16m2_m(vbool8_t, int16_t *, vuint8m1_t, vint16m2_t, vint16m2_t, vint16m2_t, vint16m2_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vsuxseg4ei8_v)))
void vsuxseg4ei8_v_i16mf2(int16_t *, vuint8mf4_t, vint16mf2_t, vint16mf2_t, vint16mf2_t, vint16mf2_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vsuxseg4ei8_v_m)))
void vsuxseg4ei8_v_i16mf2_m(vbool32_t, int16_t *, vuint8mf4_t, vint16mf2_t, vint16mf2_t, vint16mf2_t, vint16mf2_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vsuxseg4ei8_v)))
void vsuxseg4ei8_v_i16mf4(int16_t *, vuint8mf8_t, vint16mf4_t, vint16mf4_t, vint16mf4_t, vint16mf4_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vsuxseg4ei8_v_m)))
void vsuxseg4ei8_v_i16mf4_m(vbool64_t, int16_t *, vuint8mf8_t, vint16mf4_t, vint16mf4_t, vint16mf4_t, vint16mf4_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vsuxseg4ei8_v)))
void vsuxseg4ei8_v_u16m1(uint16_t *, vuint8mf2_t, vuint16m1_t, vuint16m1_t, vuint16m1_t, vuint16m1_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vsuxseg4ei8_v_m)))
void vsuxseg4ei8_v_u16m1_m(vbool16_t, uint16_t *, vuint8mf2_t, vuint16m1_t, vuint16m1_t, vuint16m1_t, vuint16m1_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vsuxseg4ei8_v)))
void vsuxseg4ei8_v_u16m2(uint16_t *, vuint8m1_t, vuint16m2_t, vuint16m2_t, vuint16m2_t, vuint16m2_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vsuxseg4ei8_v_m)))
void vsuxseg4ei8_v_u16m2_m(vbool8_t, uint16_t *, vuint8m1_t, vuint16m2_t, vuint16m2_t, vuint16m2_t, vuint16m2_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vsuxseg4ei8_v)))
void vsuxseg4ei8_v_u16mf2(uint16_t *, vuint8mf4_t, vuint16mf2_t, vuint16mf2_t, vuint16mf2_t, vuint16mf2_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vsuxseg4ei8_v_m)))
void vsuxseg4ei8_v_u16mf2_m(vbool32_t, uint16_t *, vuint8mf4_t, vuint16mf2_t, vuint16mf2_t, vuint16mf2_t, vuint16mf2_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vsuxseg4ei8_v)))
void vsuxseg4ei8_v_u16mf4(uint16_t *, vuint8mf8_t, vuint16mf4_t, vuint16mf4_t, vuint16mf4_t, vuint16mf4_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vsuxseg4ei8_v_m)))
void vsuxseg4ei8_v_u16mf4_m(vbool64_t, uint16_t *, vuint8mf8_t, vuint16mf4_t, vuint16mf4_t, vuint16mf4_t, vuint16mf4_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vsuxseg5ei8_v)))
void vsuxseg5ei8_v_i16m1(int16_t *, vuint8mf2_t, vint16m1_t, vint16m1_t, vint16m1_t, vint16m1_t, vint16m1_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vsuxseg5ei8_v_m)))
void vsuxseg5ei8_v_i16m1_m(vbool16_t, int16_t *, vuint8mf2_t, vint16m1_t, vint16m1_t, vint16m1_t, vint16m1_t, vint16m1_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vsuxseg5ei8_v)))
void vsuxseg5ei8_v_i16mf2(int16_t *, vuint8mf4_t, vint16mf2_t, vint16mf2_t, vint16mf2_t, vint16mf2_t, vint16mf2_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vsuxseg5ei8_v_m)))
void vsuxseg5ei8_v_i16mf2_m(vbool32_t, int16_t *, vuint8mf4_t, vint16mf2_t, vint16mf2_t, vint16mf2_t, vint16mf2_t, vint16mf2_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vsuxseg5ei8_v)))
void vsuxseg5ei8_v_i16mf4(int16_t *, vuint8mf8_t, vint16mf4_t, vint16mf4_t, vint16mf4_t, vint16mf4_t, vint16mf4_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vsuxseg5ei8_v_m)))
void vsuxseg5ei8_v_i16mf4_m(vbool64_t, int16_t *, vuint8mf8_t, vint16mf4_t, vint16mf4_t, vint16mf4_t, vint16mf4_t, vint16mf4_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vsuxseg5ei8_v)))
void vsuxseg5ei8_v_u16m1(uint16_t *, vuint8mf2_t, vuint16m1_t, vuint16m1_t, vuint16m1_t, vuint16m1_t, vuint16m1_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vsuxseg5ei8_v_m)))
void vsuxseg5ei8_v_u16m1_m(vbool16_t, uint16_t *, vuint8mf2_t, vuint16m1_t, vuint16m1_t, vuint16m1_t, vuint16m1_t, vuint16m1_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vsuxseg5ei8_v)))
void vsuxseg5ei8_v_u16mf2(uint16_t *, vuint8mf4_t, vuint16mf2_t, vuint16mf2_t, vuint16mf2_t, vuint16mf2_t, vuint16mf2_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vsuxseg5ei8_v_m)))
void vsuxseg5ei8_v_u16mf2_m(vbool32_t, uint16_t *, vuint8mf4_t, vuint16mf2_t, vuint16mf2_t, vuint16mf2_t, vuint16mf2_t, vuint16mf2_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vsuxseg5ei8_v)))
void vsuxseg5ei8_v_u16mf4(uint16_t *, vuint8mf8_t, vuint16mf4_t, vuint16mf4_t, vuint16mf4_t, vuint16mf4_t, vuint16mf4_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vsuxseg5ei8_v_m)))
void vsuxseg5ei8_v_u16mf4_m(vbool64_t, uint16_t *, vuint8mf8_t, vuint16mf4_t, vuint16mf4_t, vuint16mf4_t, vuint16mf4_t, vuint16mf4_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vsuxseg6ei8_v)))
void vsuxseg6ei8_v_i16m1(int16_t *, vuint8mf2_t, vint16m1_t, vint16m1_t, vint16m1_t, vint16m1_t, vint16m1_t, vint16m1_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vsuxseg6ei8_v_m)))
void vsuxseg6ei8_v_i16m1_m(vbool16_t, int16_t *, vuint8mf2_t, vint16m1_t, vint16m1_t, vint16m1_t, vint16m1_t, vint16m1_t, vint16m1_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vsuxseg6ei8_v)))
void vsuxseg6ei8_v_i16mf2(int16_t *, vuint8mf4_t, vint16mf2_t, vint16mf2_t, vint16mf2_t, vint16mf2_t, vint16mf2_t, vint16mf2_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vsuxseg6ei8_v_m)))
void vsuxseg6ei8_v_i16mf2_m(vbool32_t, int16_t *, vuint8mf4_t, vint16mf2_t, vint16mf2_t, vint16mf2_t, vint16mf2_t, vint16mf2_t, vint16mf2_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vsuxseg6ei8_v)))
void vsuxseg6ei8_v_i16mf4(int16_t *, vuint8mf8_t, vint16mf4_t, vint16mf4_t, vint16mf4_t, vint16mf4_t, vint16mf4_t, vint16mf4_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vsuxseg6ei8_v_m)))
void vsuxseg6ei8_v_i16mf4_m(vbool64_t, int16_t *, vuint8mf8_t, vint16mf4_t, vint16mf4_t, vint16mf4_t, vint16mf4_t, vint16mf4_t, vint16mf4_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vsuxseg6ei8_v)))
void vsuxseg6ei8_v_u16m1(uint16_t *, vuint8mf2_t, vuint16m1_t, vuint16m1_t, vuint16m1_t, vuint16m1_t, vuint16m1_t, vuint16m1_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vsuxseg6ei8_v_m)))
void vsuxseg6ei8_v_u16m1_m(vbool16_t, uint16_t *, vuint8mf2_t, vuint16m1_t, vuint16m1_t, vuint16m1_t, vuint16m1_t, vuint16m1_t, vuint16m1_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vsuxseg6ei8_v)))
void vsuxseg6ei8_v_u16mf2(uint16_t *, vuint8mf4_t, vuint16mf2_t, vuint16mf2_t, vuint16mf2_t, vuint16mf2_t, vuint16mf2_t, vuint16mf2_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vsuxseg6ei8_v_m)))
void vsuxseg6ei8_v_u16mf2_m(vbool32_t, uint16_t *, vuint8mf4_t, vuint16mf2_t, vuint16mf2_t, vuint16mf2_t, vuint16mf2_t, vuint16mf2_t, vuint16mf2_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vsuxseg6ei8_v)))
void vsuxseg6ei8_v_u16mf4(uint16_t *, vuint8mf8_t, vuint16mf4_t, vuint16mf4_t, vuint16mf4_t, vuint16mf4_t, vuint16mf4_t, vuint16mf4_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vsuxseg6ei8_v_m)))
void vsuxseg6ei8_v_u16mf4_m(vbool64_t, uint16_t *, vuint8mf8_t, vuint16mf4_t, vuint16mf4_t, vuint16mf4_t, vuint16mf4_t, vuint16mf4_t, vuint16mf4_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vsuxseg7ei8_v)))
void vsuxseg7ei8_v_i16m1(int16_t *, vuint8mf2_t, vint16m1_t, vint16m1_t, vint16m1_t, vint16m1_t, vint16m1_t, vint16m1_t, vint16m1_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vsuxseg7ei8_v_m)))
void vsuxseg7ei8_v_i16m1_m(vbool16_t, int16_t *, vuint8mf2_t, vint16m1_t, vint16m1_t, vint16m1_t, vint16m1_t, vint16m1_t, vint16m1_t, vint16m1_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vsuxseg7ei8_v)))
void vsuxseg7ei8_v_i16mf2(int16_t *, vuint8mf4_t, vint16mf2_t, vint16mf2_t, vint16mf2_t, vint16mf2_t, vint16mf2_t, vint16mf2_t, vint16mf2_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vsuxseg7ei8_v_m)))
void vsuxseg7ei8_v_i16mf2_m(vbool32_t, int16_t *, vuint8mf4_t, vint16mf2_t, vint16mf2_t, vint16mf2_t, vint16mf2_t, vint16mf2_t, vint16mf2_t, vint16mf2_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vsuxseg7ei8_v)))
void vsuxseg7ei8_v_i16mf4(int16_t *, vuint8mf8_t, vint16mf4_t, vint16mf4_t, vint16mf4_t, vint16mf4_t, vint16mf4_t, vint16mf4_t, vint16mf4_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vsuxseg7ei8_v_m)))
void vsuxseg7ei8_v_i16mf4_m(vbool64_t, int16_t *, vuint8mf8_t, vint16mf4_t, vint16mf4_t, vint16mf4_t, vint16mf4_t, vint16mf4_t, vint16mf4_t, vint16mf4_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vsuxseg7ei8_v)))
void vsuxseg7ei8_v_u16m1(uint16_t *, vuint8mf2_t, vuint16m1_t, vuint16m1_t, vuint16m1_t, vuint16m1_t, vuint16m1_t, vuint16m1_t, vuint16m1_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vsuxseg7ei8_v_m)))
void vsuxseg7ei8_v_u16m1_m(vbool16_t, uint16_t *, vuint8mf2_t, vuint16m1_t, vuint16m1_t, vuint16m1_t, vuint16m1_t, vuint16m1_t, vuint16m1_t, vuint16m1_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vsuxseg7ei8_v)))
void vsuxseg7ei8_v_u16mf2(uint16_t *, vuint8mf4_t, vuint16mf2_t, vuint16mf2_t, vuint16mf2_t, vuint16mf2_t, vuint16mf2_t, vuint16mf2_t, vuint16mf2_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vsuxseg7ei8_v_m)))
void vsuxseg7ei8_v_u16mf2_m(vbool32_t, uint16_t *, vuint8mf4_t, vuint16mf2_t, vuint16mf2_t, vuint16mf2_t, vuint16mf2_t, vuint16mf2_t, vuint16mf2_t, vuint16mf2_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vsuxseg7ei8_v)))
void vsuxseg7ei8_v_u16mf4(uint16_t *, vuint8mf8_t, vuint16mf4_t, vuint16mf4_t, vuint16mf4_t, vuint16mf4_t, vuint16mf4_t, vuint16mf4_t, vuint16mf4_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vsuxseg7ei8_v_m)))
void vsuxseg7ei8_v_u16mf4_m(vbool64_t, uint16_t *, vuint8mf8_t, vuint16mf4_t, vuint16mf4_t, vuint16mf4_t, vuint16mf4_t, vuint16mf4_t, vuint16mf4_t, vuint16mf4_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vsuxseg8ei8_v)))
void vsuxseg8ei8_v_i16m1(int16_t *, vuint8mf2_t, vint16m1_t, vint16m1_t, vint16m1_t, vint16m1_t, vint16m1_t, vint16m1_t, vint16m1_t, vint16m1_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vsuxseg8ei8_v_m)))
void vsuxseg8ei8_v_i16m1_m(vbool16_t, int16_t *, vuint8mf2_t, vint16m1_t, vint16m1_t, vint16m1_t, vint16m1_t, vint16m1_t, vint16m1_t, vint16m1_t, vint16m1_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vsuxseg8ei8_v)))
void vsuxseg8ei8_v_i16mf2(int16_t *, vuint8mf4_t, vint16mf2_t, vint16mf2_t, vint16mf2_t, vint16mf2_t, vint16mf2_t, vint16mf2_t, vint16mf2_t, vint16mf2_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vsuxseg8ei8_v_m)))
void vsuxseg8ei8_v_i16mf2_m(vbool32_t, int16_t *, vuint8mf4_t, vint16mf2_t, vint16mf2_t, vint16mf2_t, vint16mf2_t, vint16mf2_t, vint16mf2_t, vint16mf2_t, vint16mf2_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vsuxseg8ei8_v)))
void vsuxseg8ei8_v_i16mf4(int16_t *, vuint8mf8_t, vint16mf4_t, vint16mf4_t, vint16mf4_t, vint16mf4_t, vint16mf4_t, vint16mf4_t, vint16mf4_t, vint16mf4_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vsuxseg8ei8_v_m)))
void vsuxseg8ei8_v_i16mf4_m(vbool64_t, int16_t *, vuint8mf8_t, vint16mf4_t, vint16mf4_t, vint16mf4_t, vint16mf4_t, vint16mf4_t, vint16mf4_t, vint16mf4_t, vint16mf4_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vsuxseg8ei8_v)))
void vsuxseg8ei8_v_u16m1(uint16_t *, vuint8mf2_t, vuint16m1_t, vuint16m1_t, vuint16m1_t, vuint16m1_t, vuint16m1_t, vuint16m1_t, vuint16m1_t, vuint16m1_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vsuxseg8ei8_v_m)))
void vsuxseg8ei8_v_u16m1_m(vbool16_t, uint16_t *, vuint8mf2_t, vuint16m1_t, vuint16m1_t, vuint16m1_t, vuint16m1_t, vuint16m1_t, vuint16m1_t, vuint16m1_t, vuint16m1_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vsuxseg8ei8_v)))
void vsuxseg8ei8_v_u16mf2(uint16_t *, vuint8mf4_t, vuint16mf2_t, vuint16mf2_t, vuint16mf2_t, vuint16mf2_t, vuint16mf2_t, vuint16mf2_t, vuint16mf2_t, vuint16mf2_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vsuxseg8ei8_v_m)))
void vsuxseg8ei8_v_u16mf2_m(vbool32_t, uint16_t *, vuint8mf4_t, vuint16mf2_t, vuint16mf2_t, vuint16mf2_t, vuint16mf2_t, vuint16mf2_t, vuint16mf2_t, vuint16mf2_t, vuint16mf2_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vsuxseg8ei8_v)))
void vsuxseg8ei8_v_u16mf4(uint16_t *, vuint8mf8_t, vuint16mf4_t, vuint16mf4_t, vuint16mf4_t, vuint16mf4_t, vuint16mf4_t, vuint16mf4_t, vuint16mf4_t, vuint16mf4_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vsuxseg8ei8_v_m)))
void vsuxseg8ei8_v_u16mf4_m(vbool64_t, uint16_t *, vuint8mf8_t, vuint16mf4_t, vuint16mf4_t, vuint16mf4_t, vuint16mf4_t, vuint16mf4_t, vuint16mf4_t, vuint16mf4_t, vuint16mf4_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vsuxseg2ei16_v)))
void vsuxseg2ei16_v_i16m1(int16_t *, vuint16m1_t, vint16m1_t, vint16m1_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vsuxseg2ei16_v_m)))
void vsuxseg2ei16_v_i16m1_m(vbool16_t, int16_t *, vuint16m1_t, vint16m1_t, vint16m1_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vsuxseg2ei16_v)))
void vsuxseg2ei16_v_i16m2(int16_t *, vuint16m2_t, vint16m2_t, vint16m2_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vsuxseg2ei16_v_m)))
void vsuxseg2ei16_v_i16m2_m(vbool8_t, int16_t *, vuint16m2_t, vint16m2_t, vint16m2_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vsuxseg2ei16_v)))
void vsuxseg2ei16_v_i16m4(int16_t *, vuint16m4_t, vint16m4_t, vint16m4_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vsuxseg2ei16_v_m)))
void vsuxseg2ei16_v_i16m4_m(vbool4_t, int16_t *, vuint16m4_t, vint16m4_t, vint16m4_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vsuxseg2ei16_v)))
void vsuxseg2ei16_v_i16mf2(int16_t *, vuint16mf2_t, vint16mf2_t, vint16mf2_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vsuxseg2ei16_v_m)))
void vsuxseg2ei16_v_i16mf2_m(vbool32_t, int16_t *, vuint16mf2_t, vint16mf2_t, vint16mf2_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vsuxseg2ei16_v)))
void vsuxseg2ei16_v_i16mf4(int16_t *, vuint16mf4_t, vint16mf4_t, vint16mf4_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vsuxseg2ei16_v_m)))
void vsuxseg2ei16_v_i16mf4_m(vbool64_t, int16_t *, vuint16mf4_t, vint16mf4_t, vint16mf4_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vsuxseg2ei16_v)))
void vsuxseg2ei16_v_u16m1(uint16_t *, vuint16m1_t, vuint16m1_t, vuint16m1_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vsuxseg2ei16_v_m)))
void vsuxseg2ei16_v_u16m1_m(vbool16_t, uint16_t *, vuint16m1_t, vuint16m1_t, vuint16m1_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vsuxseg2ei16_v)))
void vsuxseg2ei16_v_u16m2(uint16_t *, vuint16m2_t, vuint16m2_t, vuint16m2_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vsuxseg2ei16_v_m)))
void vsuxseg2ei16_v_u16m2_m(vbool8_t, uint16_t *, vuint16m2_t, vuint16m2_t, vuint16m2_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vsuxseg2ei16_v)))
void vsuxseg2ei16_v_u16m4(uint16_t *, vuint16m4_t, vuint16m4_t, vuint16m4_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vsuxseg2ei16_v_m)))
void vsuxseg2ei16_v_u16m4_m(vbool4_t, uint16_t *, vuint16m4_t, vuint16m4_t, vuint16m4_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vsuxseg2ei16_v)))
void vsuxseg2ei16_v_u16mf2(uint16_t *, vuint16mf2_t, vuint16mf2_t, vuint16mf2_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vsuxseg2ei16_v_m)))
void vsuxseg2ei16_v_u16mf2_m(vbool32_t, uint16_t *, vuint16mf2_t, vuint16mf2_t, vuint16mf2_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vsuxseg2ei16_v)))
void vsuxseg2ei16_v_u16mf4(uint16_t *, vuint16mf4_t, vuint16mf4_t, vuint16mf4_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vsuxseg2ei16_v_m)))
void vsuxseg2ei16_v_u16mf4_m(vbool64_t, uint16_t *, vuint16mf4_t, vuint16mf4_t, vuint16mf4_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vsuxseg3ei16_v)))
void vsuxseg3ei16_v_i16m1(int16_t *, vuint16m1_t, vint16m1_t, vint16m1_t, vint16m1_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vsuxseg3ei16_v_m)))
void vsuxseg3ei16_v_i16m1_m(vbool16_t, int16_t *, vuint16m1_t, vint16m1_t, vint16m1_t, vint16m1_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vsuxseg3ei16_v)))
void vsuxseg3ei16_v_i16m2(int16_t *, vuint16m2_t, vint16m2_t, vint16m2_t, vint16m2_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vsuxseg3ei16_v_m)))
void vsuxseg3ei16_v_i16m2_m(vbool8_t, int16_t *, vuint16m2_t, vint16m2_t, vint16m2_t, vint16m2_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vsuxseg3ei16_v)))
void vsuxseg3ei16_v_i16mf2(int16_t *, vuint16mf2_t, vint16mf2_t, vint16mf2_t, vint16mf2_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vsuxseg3ei16_v_m)))
void vsuxseg3ei16_v_i16mf2_m(vbool32_t, int16_t *, vuint16mf2_t, vint16mf2_t, vint16mf2_t, vint16mf2_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vsuxseg3ei16_v)))
void vsuxseg3ei16_v_i16mf4(int16_t *, vuint16mf4_t, vint16mf4_t, vint16mf4_t, vint16mf4_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vsuxseg3ei16_v_m)))
void vsuxseg3ei16_v_i16mf4_m(vbool64_t, int16_t *, vuint16mf4_t, vint16mf4_t, vint16mf4_t, vint16mf4_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vsuxseg3ei16_v)))
void vsuxseg3ei16_v_u16m1(uint16_t *, vuint16m1_t, vuint16m1_t, vuint16m1_t, vuint16m1_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vsuxseg3ei16_v_m)))
void vsuxseg3ei16_v_u16m1_m(vbool16_t, uint16_t *, vuint16m1_t, vuint16m1_t, vuint16m1_t, vuint16m1_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vsuxseg3ei16_v)))
void vsuxseg3ei16_v_u16m2(uint16_t *, vuint16m2_t, vuint16m2_t, vuint16m2_t, vuint16m2_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vsuxseg3ei16_v_m)))
void vsuxseg3ei16_v_u16m2_m(vbool8_t, uint16_t *, vuint16m2_t, vuint16m2_t, vuint16m2_t, vuint16m2_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vsuxseg3ei16_v)))
void vsuxseg3ei16_v_u16mf2(uint16_t *, vuint16mf2_t, vuint16mf2_t, vuint16mf2_t, vuint16mf2_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vsuxseg3ei16_v_m)))
void vsuxseg3ei16_v_u16mf2_m(vbool32_t, uint16_t *, vuint16mf2_t, vuint16mf2_t, vuint16mf2_t, vuint16mf2_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vsuxseg3ei16_v)))
void vsuxseg3ei16_v_u16mf4(uint16_t *, vuint16mf4_t, vuint16mf4_t, vuint16mf4_t, vuint16mf4_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vsuxseg3ei16_v_m)))
void vsuxseg3ei16_v_u16mf4_m(vbool64_t, uint16_t *, vuint16mf4_t, vuint16mf4_t, vuint16mf4_t, vuint16mf4_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vsuxseg4ei16_v)))
void vsuxseg4ei16_v_i16m1(int16_t *, vuint16m1_t, vint16m1_t, vint16m1_t, vint16m1_t, vint16m1_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vsuxseg4ei16_v_m)))
void vsuxseg4ei16_v_i16m1_m(vbool16_t, int16_t *, vuint16m1_t, vint16m1_t, vint16m1_t, vint16m1_t, vint16m1_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vsuxseg4ei16_v)))
void vsuxseg4ei16_v_i16m2(int16_t *, vuint16m2_t, vint16m2_t, vint16m2_t, vint16m2_t, vint16m2_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vsuxseg4ei16_v_m)))
void vsuxseg4ei16_v_i16m2_m(vbool8_t, int16_t *, vuint16m2_t, vint16m2_t, vint16m2_t, vint16m2_t, vint16m2_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vsuxseg4ei16_v)))
void vsuxseg4ei16_v_i16mf2(int16_t *, vuint16mf2_t, vint16mf2_t, vint16mf2_t, vint16mf2_t, vint16mf2_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vsuxseg4ei16_v_m)))
void vsuxseg4ei16_v_i16mf2_m(vbool32_t, int16_t *, vuint16mf2_t, vint16mf2_t, vint16mf2_t, vint16mf2_t, vint16mf2_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vsuxseg4ei16_v)))
void vsuxseg4ei16_v_i16mf4(int16_t *, vuint16mf4_t, vint16mf4_t, vint16mf4_t, vint16mf4_t, vint16mf4_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vsuxseg4ei16_v_m)))
void vsuxseg4ei16_v_i16mf4_m(vbool64_t, int16_t *, vuint16mf4_t, vint16mf4_t, vint16mf4_t, vint16mf4_t, vint16mf4_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vsuxseg4ei16_v)))
void vsuxseg4ei16_v_u16m1(uint16_t *, vuint16m1_t, vuint16m1_t, vuint16m1_t, vuint16m1_t, vuint16m1_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vsuxseg4ei16_v_m)))
void vsuxseg4ei16_v_u16m1_m(vbool16_t, uint16_t *, vuint16m1_t, vuint16m1_t, vuint16m1_t, vuint16m1_t, vuint16m1_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vsuxseg4ei16_v)))
void vsuxseg4ei16_v_u16m2(uint16_t *, vuint16m2_t, vuint16m2_t, vuint16m2_t, vuint16m2_t, vuint16m2_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vsuxseg4ei16_v_m)))
void vsuxseg4ei16_v_u16m2_m(vbool8_t, uint16_t *, vuint16m2_t, vuint16m2_t, vuint16m2_t, vuint16m2_t, vuint16m2_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vsuxseg4ei16_v)))
void vsuxseg4ei16_v_u16mf2(uint16_t *, vuint16mf2_t, vuint16mf2_t, vuint16mf2_t, vuint16mf2_t, vuint16mf2_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vsuxseg4ei16_v_m)))
void vsuxseg4ei16_v_u16mf2_m(vbool32_t, uint16_t *, vuint16mf2_t, vuint16mf2_t, vuint16mf2_t, vuint16mf2_t, vuint16mf2_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vsuxseg4ei16_v)))
void vsuxseg4ei16_v_u16mf4(uint16_t *, vuint16mf4_t, vuint16mf4_t, vuint16mf4_t, vuint16mf4_t, vuint16mf4_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vsuxseg4ei16_v_m)))
void vsuxseg4ei16_v_u16mf4_m(vbool64_t, uint16_t *, vuint16mf4_t, vuint16mf4_t, vuint16mf4_t, vuint16mf4_t, vuint16mf4_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vsuxseg5ei16_v)))
void vsuxseg5ei16_v_i16m1(int16_t *, vuint16m1_t, vint16m1_t, vint16m1_t, vint16m1_t, vint16m1_t, vint16m1_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vsuxseg5ei16_v_m)))
void vsuxseg5ei16_v_i16m1_m(vbool16_t, int16_t *, vuint16m1_t, vint16m1_t, vint16m1_t, vint16m1_t, vint16m1_t, vint16m1_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vsuxseg5ei16_v)))
void vsuxseg5ei16_v_i16mf2(int16_t *, vuint16mf2_t, vint16mf2_t, vint16mf2_t, vint16mf2_t, vint16mf2_t, vint16mf2_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vsuxseg5ei16_v_m)))
void vsuxseg5ei16_v_i16mf2_m(vbool32_t, int16_t *, vuint16mf2_t, vint16mf2_t, vint16mf2_t, vint16mf2_t, vint16mf2_t, vint16mf2_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vsuxseg5ei16_v)))
void vsuxseg5ei16_v_i16mf4(int16_t *, vuint16mf4_t, vint16mf4_t, vint16mf4_t, vint16mf4_t, vint16mf4_t, vint16mf4_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vsuxseg5ei16_v_m)))
void vsuxseg5ei16_v_i16mf4_m(vbool64_t, int16_t *, vuint16mf4_t, vint16mf4_t, vint16mf4_t, vint16mf4_t, vint16mf4_t, vint16mf4_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vsuxseg5ei16_v)))
void vsuxseg5ei16_v_u16m1(uint16_t *, vuint16m1_t, vuint16m1_t, vuint16m1_t, vuint16m1_t, vuint16m1_t, vuint16m1_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vsuxseg5ei16_v_m)))
void vsuxseg5ei16_v_u16m1_m(vbool16_t, uint16_t *, vuint16m1_t, vuint16m1_t, vuint16m1_t, vuint16m1_t, vuint16m1_t, vuint16m1_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vsuxseg5ei16_v)))
void vsuxseg5ei16_v_u16mf2(uint16_t *, vuint16mf2_t, vuint16mf2_t, vuint16mf2_t, vuint16mf2_t, vuint16mf2_t, vuint16mf2_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vsuxseg5ei16_v_m)))
void vsuxseg5ei16_v_u16mf2_m(vbool32_t, uint16_t *, vuint16mf2_t, vuint16mf2_t, vuint16mf2_t, vuint16mf2_t, vuint16mf2_t, vuint16mf2_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vsuxseg5ei16_v)))
void vsuxseg5ei16_v_u16mf4(uint16_t *, vuint16mf4_t, vuint16mf4_t, vuint16mf4_t, vuint16mf4_t, vuint16mf4_t, vuint16mf4_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vsuxseg5ei16_v_m)))
void vsuxseg5ei16_v_u16mf4_m(vbool64_t, uint16_t *, vuint16mf4_t, vuint16mf4_t, vuint16mf4_t, vuint16mf4_t, vuint16mf4_t, vuint16mf4_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vsuxseg6ei16_v)))
void vsuxseg6ei16_v_i16m1(int16_t *, vuint16m1_t, vint16m1_t, vint16m1_t, vint16m1_t, vint16m1_t, vint16m1_t, vint16m1_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vsuxseg6ei16_v_m)))
void vsuxseg6ei16_v_i16m1_m(vbool16_t, int16_t *, vuint16m1_t, vint16m1_t, vint16m1_t, vint16m1_t, vint16m1_t, vint16m1_t, vint16m1_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vsuxseg6ei16_v)))
void vsuxseg6ei16_v_i16mf2(int16_t *, vuint16mf2_t, vint16mf2_t, vint16mf2_t, vint16mf2_t, vint16mf2_t, vint16mf2_t, vint16mf2_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vsuxseg6ei16_v_m)))
void vsuxseg6ei16_v_i16mf2_m(vbool32_t, int16_t *, vuint16mf2_t, vint16mf2_t, vint16mf2_t, vint16mf2_t, vint16mf2_t, vint16mf2_t, vint16mf2_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vsuxseg6ei16_v)))
void vsuxseg6ei16_v_i16mf4(int16_t *, vuint16mf4_t, vint16mf4_t, vint16mf4_t, vint16mf4_t, vint16mf4_t, vint16mf4_t, vint16mf4_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vsuxseg6ei16_v_m)))
void vsuxseg6ei16_v_i16mf4_m(vbool64_t, int16_t *, vuint16mf4_t, vint16mf4_t, vint16mf4_t, vint16mf4_t, vint16mf4_t, vint16mf4_t, vint16mf4_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vsuxseg6ei16_v)))
void vsuxseg6ei16_v_u16m1(uint16_t *, vuint16m1_t, vuint16m1_t, vuint16m1_t, vuint16m1_t, vuint16m1_t, vuint16m1_t, vuint16m1_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vsuxseg6ei16_v_m)))
void vsuxseg6ei16_v_u16m1_m(vbool16_t, uint16_t *, vuint16m1_t, vuint16m1_t, vuint16m1_t, vuint16m1_t, vuint16m1_t, vuint16m1_t, vuint16m1_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vsuxseg6ei16_v)))
void vsuxseg6ei16_v_u16mf2(uint16_t *, vuint16mf2_t, vuint16mf2_t, vuint16mf2_t, vuint16mf2_t, vuint16mf2_t, vuint16mf2_t, vuint16mf2_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vsuxseg6ei16_v_m)))
void vsuxseg6ei16_v_u16mf2_m(vbool32_t, uint16_t *, vuint16mf2_t, vuint16mf2_t, vuint16mf2_t, vuint16mf2_t, vuint16mf2_t, vuint16mf2_t, vuint16mf2_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vsuxseg6ei16_v)))
void vsuxseg6ei16_v_u16mf4(uint16_t *, vuint16mf4_t, vuint16mf4_t, vuint16mf4_t, vuint16mf4_t, vuint16mf4_t, vuint16mf4_t, vuint16mf4_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vsuxseg6ei16_v_m)))
void vsuxseg6ei16_v_u16mf4_m(vbool64_t, uint16_t *, vuint16mf4_t, vuint16mf4_t, vuint16mf4_t, vuint16mf4_t, vuint16mf4_t, vuint16mf4_t, vuint16mf4_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vsuxseg7ei16_v)))
void vsuxseg7ei16_v_i16m1(int16_t *, vuint16m1_t, vint16m1_t, vint16m1_t, vint16m1_t, vint16m1_t, vint16m1_t, vint16m1_t, vint16m1_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vsuxseg7ei16_v_m)))
void vsuxseg7ei16_v_i16m1_m(vbool16_t, int16_t *, vuint16m1_t, vint16m1_t, vint16m1_t, vint16m1_t, vint16m1_t, vint16m1_t, vint16m1_t, vint16m1_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vsuxseg7ei16_v)))
void vsuxseg7ei16_v_i16mf2(int16_t *, vuint16mf2_t, vint16mf2_t, vint16mf2_t, vint16mf2_t, vint16mf2_t, vint16mf2_t, vint16mf2_t, vint16mf2_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vsuxseg7ei16_v_m)))
void vsuxseg7ei16_v_i16mf2_m(vbool32_t, int16_t *, vuint16mf2_t, vint16mf2_t, vint16mf2_t, vint16mf2_t, vint16mf2_t, vint16mf2_t, vint16mf2_t, vint16mf2_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vsuxseg7ei16_v)))
void vsuxseg7ei16_v_i16mf4(int16_t *, vuint16mf4_t, vint16mf4_t, vint16mf4_t, vint16mf4_t, vint16mf4_t, vint16mf4_t, vint16mf4_t, vint16mf4_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vsuxseg7ei16_v_m)))
void vsuxseg7ei16_v_i16mf4_m(vbool64_t, int16_t *, vuint16mf4_t, vint16mf4_t, vint16mf4_t, vint16mf4_t, vint16mf4_t, vint16mf4_t, vint16mf4_t, vint16mf4_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vsuxseg7ei16_v)))
void vsuxseg7ei16_v_u16m1(uint16_t *, vuint16m1_t, vuint16m1_t, vuint16m1_t, vuint16m1_t, vuint16m1_t, vuint16m1_t, vuint16m1_t, vuint16m1_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vsuxseg7ei16_v_m)))
void vsuxseg7ei16_v_u16m1_m(vbool16_t, uint16_t *, vuint16m1_t, vuint16m1_t, vuint16m1_t, vuint16m1_t, vuint16m1_t, vuint16m1_t, vuint16m1_t, vuint16m1_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vsuxseg7ei16_v)))
void vsuxseg7ei16_v_u16mf2(uint16_t *, vuint16mf2_t, vuint16mf2_t, vuint16mf2_t, vuint16mf2_t, vuint16mf2_t, vuint16mf2_t, vuint16mf2_t, vuint16mf2_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vsuxseg7ei16_v_m)))
void vsuxseg7ei16_v_u16mf2_m(vbool32_t, uint16_t *, vuint16mf2_t, vuint16mf2_t, vuint16mf2_t, vuint16mf2_t, vuint16mf2_t, vuint16mf2_t, vuint16mf2_t, vuint16mf2_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vsuxseg7ei16_v)))
void vsuxseg7ei16_v_u16mf4(uint16_t *, vuint16mf4_t, vuint16mf4_t, vuint16mf4_t, vuint16mf4_t, vuint16mf4_t, vuint16mf4_t, vuint16mf4_t, vuint16mf4_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vsuxseg7ei16_v_m)))
void vsuxseg7ei16_v_u16mf4_m(vbool64_t, uint16_t *, vuint16mf4_t, vuint16mf4_t, vuint16mf4_t, vuint16mf4_t, vuint16mf4_t, vuint16mf4_t, vuint16mf4_t, vuint16mf4_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vsuxseg8ei16_v)))
void vsuxseg8ei16_v_i16m1(int16_t *, vuint16m1_t, vint16m1_t, vint16m1_t, vint16m1_t, vint16m1_t, vint16m1_t, vint16m1_t, vint16m1_t, vint16m1_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vsuxseg8ei16_v_m)))
void vsuxseg8ei16_v_i16m1_m(vbool16_t, int16_t *, vuint16m1_t, vint16m1_t, vint16m1_t, vint16m1_t, vint16m1_t, vint16m1_t, vint16m1_t, vint16m1_t, vint16m1_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vsuxseg8ei16_v)))
void vsuxseg8ei16_v_i16mf2(int16_t *, vuint16mf2_t, vint16mf2_t, vint16mf2_t, vint16mf2_t, vint16mf2_t, vint16mf2_t, vint16mf2_t, vint16mf2_t, vint16mf2_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vsuxseg8ei16_v_m)))
void vsuxseg8ei16_v_i16mf2_m(vbool32_t, int16_t *, vuint16mf2_t, vint16mf2_t, vint16mf2_t, vint16mf2_t, vint16mf2_t, vint16mf2_t, vint16mf2_t, vint16mf2_t, vint16mf2_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vsuxseg8ei16_v)))
void vsuxseg8ei16_v_i16mf4(int16_t *, vuint16mf4_t, vint16mf4_t, vint16mf4_t, vint16mf4_t, vint16mf4_t, vint16mf4_t, vint16mf4_t, vint16mf4_t, vint16mf4_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vsuxseg8ei16_v_m)))
void vsuxseg8ei16_v_i16mf4_m(vbool64_t, int16_t *, vuint16mf4_t, vint16mf4_t, vint16mf4_t, vint16mf4_t, vint16mf4_t, vint16mf4_t, vint16mf4_t, vint16mf4_t, vint16mf4_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vsuxseg8ei16_v)))
void vsuxseg8ei16_v_u16m1(uint16_t *, vuint16m1_t, vuint16m1_t, vuint16m1_t, vuint16m1_t, vuint16m1_t, vuint16m1_t, vuint16m1_t, vuint16m1_t, vuint16m1_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vsuxseg8ei16_v_m)))
void vsuxseg8ei16_v_u16m1_m(vbool16_t, uint16_t *, vuint16m1_t, vuint16m1_t, vuint16m1_t, vuint16m1_t, vuint16m1_t, vuint16m1_t, vuint16m1_t, vuint16m1_t, vuint16m1_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vsuxseg8ei16_v)))
void vsuxseg8ei16_v_u16mf2(uint16_t *, vuint16mf2_t, vuint16mf2_t, vuint16mf2_t, vuint16mf2_t, vuint16mf2_t, vuint16mf2_t, vuint16mf2_t, vuint16mf2_t, vuint16mf2_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vsuxseg8ei16_v_m)))
void vsuxseg8ei16_v_u16mf2_m(vbool32_t, uint16_t *, vuint16mf2_t, vuint16mf2_t, vuint16mf2_t, vuint16mf2_t, vuint16mf2_t, vuint16mf2_t, vuint16mf2_t, vuint16mf2_t, vuint16mf2_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vsuxseg8ei16_v)))
void vsuxseg8ei16_v_u16mf4(uint16_t *, vuint16mf4_t, vuint16mf4_t, vuint16mf4_t, vuint16mf4_t, vuint16mf4_t, vuint16mf4_t, vuint16mf4_t, vuint16mf4_t, vuint16mf4_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vsuxseg8ei16_v_m)))
void vsuxseg8ei16_v_u16mf4_m(vbool64_t, uint16_t *, vuint16mf4_t, vuint16mf4_t, vuint16mf4_t, vuint16mf4_t, vuint16mf4_t, vuint16mf4_t, vuint16mf4_t, vuint16mf4_t, vuint16mf4_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vsuxseg2ei32_v)))
void vsuxseg2ei32_v_i16m1(int16_t *, vuint32m2_t, vint16m1_t, vint16m1_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vsuxseg2ei32_v_m)))
void vsuxseg2ei32_v_i16m1_m(vbool16_t, int16_t *, vuint32m2_t, vint16m1_t, vint16m1_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vsuxseg2ei32_v)))
void vsuxseg2ei32_v_i16m2(int16_t *, vuint32m4_t, vint16m2_t, vint16m2_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vsuxseg2ei32_v_m)))
void vsuxseg2ei32_v_i16m2_m(vbool8_t, int16_t *, vuint32m4_t, vint16m2_t, vint16m2_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vsuxseg2ei32_v)))
void vsuxseg2ei32_v_i16m4(int16_t *, vuint32m8_t, vint16m4_t, vint16m4_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vsuxseg2ei32_v_m)))
void vsuxseg2ei32_v_i16m4_m(vbool4_t, int16_t *, vuint32m8_t, vint16m4_t, vint16m4_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vsuxseg2ei32_v)))
void vsuxseg2ei32_v_i16mf2(int16_t *, vuint32m1_t, vint16mf2_t, vint16mf2_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vsuxseg2ei32_v_m)))
void vsuxseg2ei32_v_i16mf2_m(vbool32_t, int16_t *, vuint32m1_t, vint16mf2_t, vint16mf2_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vsuxseg2ei32_v)))
void vsuxseg2ei32_v_i16mf4(int16_t *, vuint32mf2_t, vint16mf4_t, vint16mf4_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vsuxseg2ei32_v_m)))
void vsuxseg2ei32_v_i16mf4_m(vbool64_t, int16_t *, vuint32mf2_t, vint16mf4_t, vint16mf4_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vsuxseg2ei32_v)))
void vsuxseg2ei32_v_u16m1(uint16_t *, vuint32m2_t, vuint16m1_t, vuint16m1_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vsuxseg2ei32_v_m)))
void vsuxseg2ei32_v_u16m1_m(vbool16_t, uint16_t *, vuint32m2_t, vuint16m1_t, vuint16m1_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vsuxseg2ei32_v)))
void vsuxseg2ei32_v_u16m2(uint16_t *, vuint32m4_t, vuint16m2_t, vuint16m2_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vsuxseg2ei32_v_m)))
void vsuxseg2ei32_v_u16m2_m(vbool8_t, uint16_t *, vuint32m4_t, vuint16m2_t, vuint16m2_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vsuxseg2ei32_v)))
void vsuxseg2ei32_v_u16m4(uint16_t *, vuint32m8_t, vuint16m4_t, vuint16m4_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vsuxseg2ei32_v_m)))
void vsuxseg2ei32_v_u16m4_m(vbool4_t, uint16_t *, vuint32m8_t, vuint16m4_t, vuint16m4_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vsuxseg2ei32_v)))
void vsuxseg2ei32_v_u16mf2(uint16_t *, vuint32m1_t, vuint16mf2_t, vuint16mf2_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vsuxseg2ei32_v_m)))
void vsuxseg2ei32_v_u16mf2_m(vbool32_t, uint16_t *, vuint32m1_t, vuint16mf2_t, vuint16mf2_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vsuxseg2ei32_v)))
void vsuxseg2ei32_v_u16mf4(uint16_t *, vuint32mf2_t, vuint16mf4_t, vuint16mf4_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vsuxseg2ei32_v_m)))
void vsuxseg2ei32_v_u16mf4_m(vbool64_t, uint16_t *, vuint32mf2_t, vuint16mf4_t, vuint16mf4_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vsuxseg3ei32_v)))
void vsuxseg3ei32_v_i16m1(int16_t *, vuint32m2_t, vint16m1_t, vint16m1_t, vint16m1_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vsuxseg3ei32_v_m)))
void vsuxseg3ei32_v_i16m1_m(vbool16_t, int16_t *, vuint32m2_t, vint16m1_t, vint16m1_t, vint16m1_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vsuxseg3ei32_v)))
void vsuxseg3ei32_v_i16m2(int16_t *, vuint32m4_t, vint16m2_t, vint16m2_t, vint16m2_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vsuxseg3ei32_v_m)))
void vsuxseg3ei32_v_i16m2_m(vbool8_t, int16_t *, vuint32m4_t, vint16m2_t, vint16m2_t, vint16m2_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vsuxseg3ei32_v)))
void vsuxseg3ei32_v_i16mf2(int16_t *, vuint32m1_t, vint16mf2_t, vint16mf2_t, vint16mf2_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vsuxseg3ei32_v_m)))
void vsuxseg3ei32_v_i16mf2_m(vbool32_t, int16_t *, vuint32m1_t, vint16mf2_t, vint16mf2_t, vint16mf2_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vsuxseg3ei32_v)))
void vsuxseg3ei32_v_i16mf4(int16_t *, vuint32mf2_t, vint16mf4_t, vint16mf4_t, vint16mf4_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vsuxseg3ei32_v_m)))
void vsuxseg3ei32_v_i16mf4_m(vbool64_t, int16_t *, vuint32mf2_t, vint16mf4_t, vint16mf4_t, vint16mf4_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vsuxseg3ei32_v)))
void vsuxseg3ei32_v_u16m1(uint16_t *, vuint32m2_t, vuint16m1_t, vuint16m1_t, vuint16m1_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vsuxseg3ei32_v_m)))
void vsuxseg3ei32_v_u16m1_m(vbool16_t, uint16_t *, vuint32m2_t, vuint16m1_t, vuint16m1_t, vuint16m1_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vsuxseg3ei32_v)))
void vsuxseg3ei32_v_u16m2(uint16_t *, vuint32m4_t, vuint16m2_t, vuint16m2_t, vuint16m2_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vsuxseg3ei32_v_m)))
void vsuxseg3ei32_v_u16m2_m(vbool8_t, uint16_t *, vuint32m4_t, vuint16m2_t, vuint16m2_t, vuint16m2_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vsuxseg3ei32_v)))
void vsuxseg3ei32_v_u16mf2(uint16_t *, vuint32m1_t, vuint16mf2_t, vuint16mf2_t, vuint16mf2_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vsuxseg3ei32_v_m)))
void vsuxseg3ei32_v_u16mf2_m(vbool32_t, uint16_t *, vuint32m1_t, vuint16mf2_t, vuint16mf2_t, vuint16mf2_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vsuxseg3ei32_v)))
void vsuxseg3ei32_v_u16mf4(uint16_t *, vuint32mf2_t, vuint16mf4_t, vuint16mf4_t, vuint16mf4_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vsuxseg3ei32_v_m)))
void vsuxseg3ei32_v_u16mf4_m(vbool64_t, uint16_t *, vuint32mf2_t, vuint16mf4_t, vuint16mf4_t, vuint16mf4_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vsuxseg4ei32_v)))
void vsuxseg4ei32_v_i16m1(int16_t *, vuint32m2_t, vint16m1_t, vint16m1_t, vint16m1_t, vint16m1_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vsuxseg4ei32_v_m)))
void vsuxseg4ei32_v_i16m1_m(vbool16_t, int16_t *, vuint32m2_t, vint16m1_t, vint16m1_t, vint16m1_t, vint16m1_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vsuxseg4ei32_v)))
void vsuxseg4ei32_v_i16m2(int16_t *, vuint32m4_t, vint16m2_t, vint16m2_t, vint16m2_t, vint16m2_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vsuxseg4ei32_v_m)))
void vsuxseg4ei32_v_i16m2_m(vbool8_t, int16_t *, vuint32m4_t, vint16m2_t, vint16m2_t, vint16m2_t, vint16m2_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vsuxseg4ei32_v)))
void vsuxseg4ei32_v_i16mf2(int16_t *, vuint32m1_t, vint16mf2_t, vint16mf2_t, vint16mf2_t, vint16mf2_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vsuxseg4ei32_v_m)))
void vsuxseg4ei32_v_i16mf2_m(vbool32_t, int16_t *, vuint32m1_t, vint16mf2_t, vint16mf2_t, vint16mf2_t, vint16mf2_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vsuxseg4ei32_v)))
void vsuxseg4ei32_v_i16mf4(int16_t *, vuint32mf2_t, vint16mf4_t, vint16mf4_t, vint16mf4_t, vint16mf4_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vsuxseg4ei32_v_m)))
void vsuxseg4ei32_v_i16mf4_m(vbool64_t, int16_t *, vuint32mf2_t, vint16mf4_t, vint16mf4_t, vint16mf4_t, vint16mf4_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vsuxseg4ei32_v)))
void vsuxseg4ei32_v_u16m1(uint16_t *, vuint32m2_t, vuint16m1_t, vuint16m1_t, vuint16m1_t, vuint16m1_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vsuxseg4ei32_v_m)))
void vsuxseg4ei32_v_u16m1_m(vbool16_t, uint16_t *, vuint32m2_t, vuint16m1_t, vuint16m1_t, vuint16m1_t, vuint16m1_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vsuxseg4ei32_v)))
void vsuxseg4ei32_v_u16m2(uint16_t *, vuint32m4_t, vuint16m2_t, vuint16m2_t, vuint16m2_t, vuint16m2_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vsuxseg4ei32_v_m)))
void vsuxseg4ei32_v_u16m2_m(vbool8_t, uint16_t *, vuint32m4_t, vuint16m2_t, vuint16m2_t, vuint16m2_t, vuint16m2_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vsuxseg4ei32_v)))
void vsuxseg4ei32_v_u16mf2(uint16_t *, vuint32m1_t, vuint16mf2_t, vuint16mf2_t, vuint16mf2_t, vuint16mf2_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vsuxseg4ei32_v_m)))
void vsuxseg4ei32_v_u16mf2_m(vbool32_t, uint16_t *, vuint32m1_t, vuint16mf2_t, vuint16mf2_t, vuint16mf2_t, vuint16mf2_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vsuxseg4ei32_v)))
void vsuxseg4ei32_v_u16mf4(uint16_t *, vuint32mf2_t, vuint16mf4_t, vuint16mf4_t, vuint16mf4_t, vuint16mf4_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vsuxseg4ei32_v_m)))
void vsuxseg4ei32_v_u16mf4_m(vbool64_t, uint16_t *, vuint32mf2_t, vuint16mf4_t, vuint16mf4_t, vuint16mf4_t, vuint16mf4_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vsuxseg5ei32_v)))
void vsuxseg5ei32_v_i16m1(int16_t *, vuint32m2_t, vint16m1_t, vint16m1_t, vint16m1_t, vint16m1_t, vint16m1_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vsuxseg5ei32_v_m)))
void vsuxseg5ei32_v_i16m1_m(vbool16_t, int16_t *, vuint32m2_t, vint16m1_t, vint16m1_t, vint16m1_t, vint16m1_t, vint16m1_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vsuxseg5ei32_v)))
void vsuxseg5ei32_v_i16mf2(int16_t *, vuint32m1_t, vint16mf2_t, vint16mf2_t, vint16mf2_t, vint16mf2_t, vint16mf2_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vsuxseg5ei32_v_m)))
void vsuxseg5ei32_v_i16mf2_m(vbool32_t, int16_t *, vuint32m1_t, vint16mf2_t, vint16mf2_t, vint16mf2_t, vint16mf2_t, vint16mf2_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vsuxseg5ei32_v)))
void vsuxseg5ei32_v_i16mf4(int16_t *, vuint32mf2_t, vint16mf4_t, vint16mf4_t, vint16mf4_t, vint16mf4_t, vint16mf4_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vsuxseg5ei32_v_m)))
void vsuxseg5ei32_v_i16mf4_m(vbool64_t, int16_t *, vuint32mf2_t, vint16mf4_t, vint16mf4_t, vint16mf4_t, vint16mf4_t, vint16mf4_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vsuxseg5ei32_v)))
void vsuxseg5ei32_v_u16m1(uint16_t *, vuint32m2_t, vuint16m1_t, vuint16m1_t, vuint16m1_t, vuint16m1_t, vuint16m1_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vsuxseg5ei32_v_m)))
void vsuxseg5ei32_v_u16m1_m(vbool16_t, uint16_t *, vuint32m2_t, vuint16m1_t, vuint16m1_t, vuint16m1_t, vuint16m1_t, vuint16m1_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vsuxseg5ei32_v)))
void vsuxseg5ei32_v_u16mf2(uint16_t *, vuint32m1_t, vuint16mf2_t, vuint16mf2_t, vuint16mf2_t, vuint16mf2_t, vuint16mf2_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vsuxseg5ei32_v_m)))
void vsuxseg5ei32_v_u16mf2_m(vbool32_t, uint16_t *, vuint32m1_t, vuint16mf2_t, vuint16mf2_t, vuint16mf2_t, vuint16mf2_t, vuint16mf2_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vsuxseg5ei32_v)))
void vsuxseg5ei32_v_u16mf4(uint16_t *, vuint32mf2_t, vuint16mf4_t, vuint16mf4_t, vuint16mf4_t, vuint16mf4_t, vuint16mf4_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vsuxseg5ei32_v_m)))
void vsuxseg5ei32_v_u16mf4_m(vbool64_t, uint16_t *, vuint32mf2_t, vuint16mf4_t, vuint16mf4_t, vuint16mf4_t, vuint16mf4_t, vuint16mf4_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vsuxseg6ei32_v)))
void vsuxseg6ei32_v_i16m1(int16_t *, vuint32m2_t, vint16m1_t, vint16m1_t, vint16m1_t, vint16m1_t, vint16m1_t, vint16m1_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vsuxseg6ei32_v_m)))
void vsuxseg6ei32_v_i16m1_m(vbool16_t, int16_t *, vuint32m2_t, vint16m1_t, vint16m1_t, vint16m1_t, vint16m1_t, vint16m1_t, vint16m1_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vsuxseg6ei32_v)))
void vsuxseg6ei32_v_i16mf2(int16_t *, vuint32m1_t, vint16mf2_t, vint16mf2_t, vint16mf2_t, vint16mf2_t, vint16mf2_t, vint16mf2_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vsuxseg6ei32_v_m)))
void vsuxseg6ei32_v_i16mf2_m(vbool32_t, int16_t *, vuint32m1_t, vint16mf2_t, vint16mf2_t, vint16mf2_t, vint16mf2_t, vint16mf2_t, vint16mf2_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vsuxseg6ei32_v)))
void vsuxseg6ei32_v_i16mf4(int16_t *, vuint32mf2_t, vint16mf4_t, vint16mf4_t, vint16mf4_t, vint16mf4_t, vint16mf4_t, vint16mf4_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vsuxseg6ei32_v_m)))
void vsuxseg6ei32_v_i16mf4_m(vbool64_t, int16_t *, vuint32mf2_t, vint16mf4_t, vint16mf4_t, vint16mf4_t, vint16mf4_t, vint16mf4_t, vint16mf4_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vsuxseg6ei32_v)))
void vsuxseg6ei32_v_u16m1(uint16_t *, vuint32m2_t, vuint16m1_t, vuint16m1_t, vuint16m1_t, vuint16m1_t, vuint16m1_t, vuint16m1_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vsuxseg6ei32_v_m)))
void vsuxseg6ei32_v_u16m1_m(vbool16_t, uint16_t *, vuint32m2_t, vuint16m1_t, vuint16m1_t, vuint16m1_t, vuint16m1_t, vuint16m1_t, vuint16m1_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vsuxseg6ei32_v)))
void vsuxseg6ei32_v_u16mf2(uint16_t *, vuint32m1_t, vuint16mf2_t, vuint16mf2_t, vuint16mf2_t, vuint16mf2_t, vuint16mf2_t, vuint16mf2_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vsuxseg6ei32_v_m)))
void vsuxseg6ei32_v_u16mf2_m(vbool32_t, uint16_t *, vuint32m1_t, vuint16mf2_t, vuint16mf2_t, vuint16mf2_t, vuint16mf2_t, vuint16mf2_t, vuint16mf2_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vsuxseg6ei32_v)))
void vsuxseg6ei32_v_u16mf4(uint16_t *, vuint32mf2_t, vuint16mf4_t, vuint16mf4_t, vuint16mf4_t, vuint16mf4_t, vuint16mf4_t, vuint16mf4_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vsuxseg6ei32_v_m)))
void vsuxseg6ei32_v_u16mf4_m(vbool64_t, uint16_t *, vuint32mf2_t, vuint16mf4_t, vuint16mf4_t, vuint16mf4_t, vuint16mf4_t, vuint16mf4_t, vuint16mf4_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vsuxseg7ei32_v)))
void vsuxseg7ei32_v_i16m1(int16_t *, vuint32m2_t, vint16m1_t, vint16m1_t, vint16m1_t, vint16m1_t, vint16m1_t, vint16m1_t, vint16m1_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vsuxseg7ei32_v_m)))
void vsuxseg7ei32_v_i16m1_m(vbool16_t, int16_t *, vuint32m2_t, vint16m1_t, vint16m1_t, vint16m1_t, vint16m1_t, vint16m1_t, vint16m1_t, vint16m1_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vsuxseg7ei32_v)))
void vsuxseg7ei32_v_i16mf2(int16_t *, vuint32m1_t, vint16mf2_t, vint16mf2_t, vint16mf2_t, vint16mf2_t, vint16mf2_t, vint16mf2_t, vint16mf2_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vsuxseg7ei32_v_m)))
void vsuxseg7ei32_v_i16mf2_m(vbool32_t, int16_t *, vuint32m1_t, vint16mf2_t, vint16mf2_t, vint16mf2_t, vint16mf2_t, vint16mf2_t, vint16mf2_t, vint16mf2_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vsuxseg7ei32_v)))
void vsuxseg7ei32_v_i16mf4(int16_t *, vuint32mf2_t, vint16mf4_t, vint16mf4_t, vint16mf4_t, vint16mf4_t, vint16mf4_t, vint16mf4_t, vint16mf4_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vsuxseg7ei32_v_m)))
void vsuxseg7ei32_v_i16mf4_m(vbool64_t, int16_t *, vuint32mf2_t, vint16mf4_t, vint16mf4_t, vint16mf4_t, vint16mf4_t, vint16mf4_t, vint16mf4_t, vint16mf4_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vsuxseg7ei32_v)))
void vsuxseg7ei32_v_u16m1(uint16_t *, vuint32m2_t, vuint16m1_t, vuint16m1_t, vuint16m1_t, vuint16m1_t, vuint16m1_t, vuint16m1_t, vuint16m1_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vsuxseg7ei32_v_m)))
void vsuxseg7ei32_v_u16m1_m(vbool16_t, uint16_t *, vuint32m2_t, vuint16m1_t, vuint16m1_t, vuint16m1_t, vuint16m1_t, vuint16m1_t, vuint16m1_t, vuint16m1_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vsuxseg7ei32_v)))
void vsuxseg7ei32_v_u16mf2(uint16_t *, vuint32m1_t, vuint16mf2_t, vuint16mf2_t, vuint16mf2_t, vuint16mf2_t, vuint16mf2_t, vuint16mf2_t, vuint16mf2_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vsuxseg7ei32_v_m)))
void vsuxseg7ei32_v_u16mf2_m(vbool32_t, uint16_t *, vuint32m1_t, vuint16mf2_t, vuint16mf2_t, vuint16mf2_t, vuint16mf2_t, vuint16mf2_t, vuint16mf2_t, vuint16mf2_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vsuxseg7ei32_v)))
void vsuxseg7ei32_v_u16mf4(uint16_t *, vuint32mf2_t, vuint16mf4_t, vuint16mf4_t, vuint16mf4_t, vuint16mf4_t, vuint16mf4_t, vuint16mf4_t, vuint16mf4_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vsuxseg7ei32_v_m)))
void vsuxseg7ei32_v_u16mf4_m(vbool64_t, uint16_t *, vuint32mf2_t, vuint16mf4_t, vuint16mf4_t, vuint16mf4_t, vuint16mf4_t, vuint16mf4_t, vuint16mf4_t, vuint16mf4_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vsuxseg8ei32_v)))
void vsuxseg8ei32_v_i16m1(int16_t *, vuint32m2_t, vint16m1_t, vint16m1_t, vint16m1_t, vint16m1_t, vint16m1_t, vint16m1_t, vint16m1_t, vint16m1_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vsuxseg8ei32_v_m)))
void vsuxseg8ei32_v_i16m1_m(vbool16_t, int16_t *, vuint32m2_t, vint16m1_t, vint16m1_t, vint16m1_t, vint16m1_t, vint16m1_t, vint16m1_t, vint16m1_t, vint16m1_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vsuxseg8ei32_v)))
void vsuxseg8ei32_v_i16mf2(int16_t *, vuint32m1_t, vint16mf2_t, vint16mf2_t, vint16mf2_t, vint16mf2_t, vint16mf2_t, vint16mf2_t, vint16mf2_t, vint16mf2_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vsuxseg8ei32_v_m)))
void vsuxseg8ei32_v_i16mf2_m(vbool32_t, int16_t *, vuint32m1_t, vint16mf2_t, vint16mf2_t, vint16mf2_t, vint16mf2_t, vint16mf2_t, vint16mf2_t, vint16mf2_t, vint16mf2_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vsuxseg8ei32_v)))
void vsuxseg8ei32_v_i16mf4(int16_t *, vuint32mf2_t, vint16mf4_t, vint16mf4_t, vint16mf4_t, vint16mf4_t, vint16mf4_t, vint16mf4_t, vint16mf4_t, vint16mf4_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vsuxseg8ei32_v_m)))
void vsuxseg8ei32_v_i16mf4_m(vbool64_t, int16_t *, vuint32mf2_t, vint16mf4_t, vint16mf4_t, vint16mf4_t, vint16mf4_t, vint16mf4_t, vint16mf4_t, vint16mf4_t, vint16mf4_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vsuxseg8ei32_v)))
void vsuxseg8ei32_v_u16m1(uint16_t *, vuint32m2_t, vuint16m1_t, vuint16m1_t, vuint16m1_t, vuint16m1_t, vuint16m1_t, vuint16m1_t, vuint16m1_t, vuint16m1_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vsuxseg8ei32_v_m)))
void vsuxseg8ei32_v_u16m1_m(vbool16_t, uint16_t *, vuint32m2_t, vuint16m1_t, vuint16m1_t, vuint16m1_t, vuint16m1_t, vuint16m1_t, vuint16m1_t, vuint16m1_t, vuint16m1_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vsuxseg8ei32_v)))
void vsuxseg8ei32_v_u16mf2(uint16_t *, vuint32m1_t, vuint16mf2_t, vuint16mf2_t, vuint16mf2_t, vuint16mf2_t, vuint16mf2_t, vuint16mf2_t, vuint16mf2_t, vuint16mf2_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vsuxseg8ei32_v_m)))
void vsuxseg8ei32_v_u16mf2_m(vbool32_t, uint16_t *, vuint32m1_t, vuint16mf2_t, vuint16mf2_t, vuint16mf2_t, vuint16mf2_t, vuint16mf2_t, vuint16mf2_t, vuint16mf2_t, vuint16mf2_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vsuxseg8ei32_v)))
void vsuxseg8ei32_v_u16mf4(uint16_t *, vuint32mf2_t, vuint16mf4_t, vuint16mf4_t, vuint16mf4_t, vuint16mf4_t, vuint16mf4_t, vuint16mf4_t, vuint16mf4_t, vuint16mf4_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vsuxseg8ei32_v_m)))
void vsuxseg8ei32_v_u16mf4_m(vbool64_t, uint16_t *, vuint32mf2_t, vuint16mf4_t, vuint16mf4_t, vuint16mf4_t, vuint16mf4_t, vuint16mf4_t, vuint16mf4_t, vuint16mf4_t, vuint16mf4_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vsuxseg2ei8_v)))
void vsuxseg2ei8_v_i32m1(int32_t *, vuint8mf4_t, vint32m1_t, vint32m1_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vsuxseg2ei8_v_m)))
void vsuxseg2ei8_v_i32m1_m(vbool32_t, int32_t *, vuint8mf4_t, vint32m1_t, vint32m1_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vsuxseg2ei8_v)))
void vsuxseg2ei8_v_i32m2(int32_t *, vuint8mf2_t, vint32m2_t, vint32m2_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vsuxseg2ei8_v_m)))
void vsuxseg2ei8_v_i32m2_m(vbool16_t, int32_t *, vuint8mf2_t, vint32m2_t, vint32m2_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vsuxseg2ei8_v)))
void vsuxseg2ei8_v_i32m4(int32_t *, vuint8m1_t, vint32m4_t, vint32m4_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vsuxseg2ei8_v_m)))
void vsuxseg2ei8_v_i32m4_m(vbool8_t, int32_t *, vuint8m1_t, vint32m4_t, vint32m4_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vsuxseg2ei8_v)))
void vsuxseg2ei8_v_i32mf2(int32_t *, vuint8mf8_t, vint32mf2_t, vint32mf2_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vsuxseg2ei8_v_m)))
void vsuxseg2ei8_v_i32mf2_m(vbool64_t, int32_t *, vuint8mf8_t, vint32mf2_t, vint32mf2_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vsuxseg2ei8_v)))
void vsuxseg2ei8_v_u32m1(uint32_t *, vuint8mf4_t, vuint32m1_t, vuint32m1_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vsuxseg2ei8_v_m)))
void vsuxseg2ei8_v_u32m1_m(vbool32_t, uint32_t *, vuint8mf4_t, vuint32m1_t, vuint32m1_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vsuxseg2ei8_v)))
void vsuxseg2ei8_v_u32m2(uint32_t *, vuint8mf2_t, vuint32m2_t, vuint32m2_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vsuxseg2ei8_v_m)))
void vsuxseg2ei8_v_u32m2_m(vbool16_t, uint32_t *, vuint8mf2_t, vuint32m2_t, vuint32m2_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vsuxseg2ei8_v)))
void vsuxseg2ei8_v_u32m4(uint32_t *, vuint8m1_t, vuint32m4_t, vuint32m4_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vsuxseg2ei8_v_m)))
void vsuxseg2ei8_v_u32m4_m(vbool8_t, uint32_t *, vuint8m1_t, vuint32m4_t, vuint32m4_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vsuxseg2ei8_v)))
void vsuxseg2ei8_v_u32mf2(uint32_t *, vuint8mf8_t, vuint32mf2_t, vuint32mf2_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vsuxseg2ei8_v_m)))
void vsuxseg2ei8_v_u32mf2_m(vbool64_t, uint32_t *, vuint8mf8_t, vuint32mf2_t, vuint32mf2_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vsuxseg3ei8_v)))
void vsuxseg3ei8_v_i32m1(int32_t *, vuint8mf4_t, vint32m1_t, vint32m1_t, vint32m1_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vsuxseg3ei8_v_m)))
void vsuxseg3ei8_v_i32m1_m(vbool32_t, int32_t *, vuint8mf4_t, vint32m1_t, vint32m1_t, vint32m1_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vsuxseg3ei8_v)))
void vsuxseg3ei8_v_i32m2(int32_t *, vuint8mf2_t, vint32m2_t, vint32m2_t, vint32m2_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vsuxseg3ei8_v_m)))
void vsuxseg3ei8_v_i32m2_m(vbool16_t, int32_t *, vuint8mf2_t, vint32m2_t, vint32m2_t, vint32m2_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vsuxseg3ei8_v)))
void vsuxseg3ei8_v_i32mf2(int32_t *, vuint8mf8_t, vint32mf2_t, vint32mf2_t, vint32mf2_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vsuxseg3ei8_v_m)))
void vsuxseg3ei8_v_i32mf2_m(vbool64_t, int32_t *, vuint8mf8_t, vint32mf2_t, vint32mf2_t, vint32mf2_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vsuxseg3ei8_v)))
void vsuxseg3ei8_v_u32m1(uint32_t *, vuint8mf4_t, vuint32m1_t, vuint32m1_t, vuint32m1_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vsuxseg3ei8_v_m)))
void vsuxseg3ei8_v_u32m1_m(vbool32_t, uint32_t *, vuint8mf4_t, vuint32m1_t, vuint32m1_t, vuint32m1_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vsuxseg3ei8_v)))
void vsuxseg3ei8_v_u32m2(uint32_t *, vuint8mf2_t, vuint32m2_t, vuint32m2_t, vuint32m2_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vsuxseg3ei8_v_m)))
void vsuxseg3ei8_v_u32m2_m(vbool16_t, uint32_t *, vuint8mf2_t, vuint32m2_t, vuint32m2_t, vuint32m2_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vsuxseg3ei8_v)))
void vsuxseg3ei8_v_u32mf2(uint32_t *, vuint8mf8_t, vuint32mf2_t, vuint32mf2_t, vuint32mf2_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vsuxseg3ei8_v_m)))
void vsuxseg3ei8_v_u32mf2_m(vbool64_t, uint32_t *, vuint8mf8_t, vuint32mf2_t, vuint32mf2_t, vuint32mf2_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vsuxseg4ei8_v)))
void vsuxseg4ei8_v_i32m1(int32_t *, vuint8mf4_t, vint32m1_t, vint32m1_t, vint32m1_t, vint32m1_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vsuxseg4ei8_v_m)))
void vsuxseg4ei8_v_i32m1_m(vbool32_t, int32_t *, vuint8mf4_t, vint32m1_t, vint32m1_t, vint32m1_t, vint32m1_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vsuxseg4ei8_v)))
void vsuxseg4ei8_v_i32m2(int32_t *, vuint8mf2_t, vint32m2_t, vint32m2_t, vint32m2_t, vint32m2_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vsuxseg4ei8_v_m)))
void vsuxseg4ei8_v_i32m2_m(vbool16_t, int32_t *, vuint8mf2_t, vint32m2_t, vint32m2_t, vint32m2_t, vint32m2_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vsuxseg4ei8_v)))
void vsuxseg4ei8_v_i32mf2(int32_t *, vuint8mf8_t, vint32mf2_t, vint32mf2_t, vint32mf2_t, vint32mf2_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vsuxseg4ei8_v_m)))
void vsuxseg4ei8_v_i32mf2_m(vbool64_t, int32_t *, vuint8mf8_t, vint32mf2_t, vint32mf2_t, vint32mf2_t, vint32mf2_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vsuxseg4ei8_v)))
void vsuxseg4ei8_v_u32m1(uint32_t *, vuint8mf4_t, vuint32m1_t, vuint32m1_t, vuint32m1_t, vuint32m1_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vsuxseg4ei8_v_m)))
void vsuxseg4ei8_v_u32m1_m(vbool32_t, uint32_t *, vuint8mf4_t, vuint32m1_t, vuint32m1_t, vuint32m1_t, vuint32m1_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vsuxseg4ei8_v)))
void vsuxseg4ei8_v_u32m2(uint32_t *, vuint8mf2_t, vuint32m2_t, vuint32m2_t, vuint32m2_t, vuint32m2_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vsuxseg4ei8_v_m)))
void vsuxseg4ei8_v_u32m2_m(vbool16_t, uint32_t *, vuint8mf2_t, vuint32m2_t, vuint32m2_t, vuint32m2_t, vuint32m2_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vsuxseg4ei8_v)))
void vsuxseg4ei8_v_u32mf2(uint32_t *, vuint8mf8_t, vuint32mf2_t, vuint32mf2_t, vuint32mf2_t, vuint32mf2_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vsuxseg4ei8_v_m)))
void vsuxseg4ei8_v_u32mf2_m(vbool64_t, uint32_t *, vuint8mf8_t, vuint32mf2_t, vuint32mf2_t, vuint32mf2_t, vuint32mf2_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vsuxseg5ei8_v)))
void vsuxseg5ei8_v_i32m1(int32_t *, vuint8mf4_t, vint32m1_t, vint32m1_t, vint32m1_t, vint32m1_t, vint32m1_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vsuxseg5ei8_v_m)))
void vsuxseg5ei8_v_i32m1_m(vbool32_t, int32_t *, vuint8mf4_t, vint32m1_t, vint32m1_t, vint32m1_t, vint32m1_t, vint32m1_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vsuxseg5ei8_v)))
void vsuxseg5ei8_v_i32mf2(int32_t *, vuint8mf8_t, vint32mf2_t, vint32mf2_t, vint32mf2_t, vint32mf2_t, vint32mf2_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vsuxseg5ei8_v_m)))
void vsuxseg5ei8_v_i32mf2_m(vbool64_t, int32_t *, vuint8mf8_t, vint32mf2_t, vint32mf2_t, vint32mf2_t, vint32mf2_t, vint32mf2_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vsuxseg5ei8_v)))
void vsuxseg5ei8_v_u32m1(uint32_t *, vuint8mf4_t, vuint32m1_t, vuint32m1_t, vuint32m1_t, vuint32m1_t, vuint32m1_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vsuxseg5ei8_v_m)))
void vsuxseg5ei8_v_u32m1_m(vbool32_t, uint32_t *, vuint8mf4_t, vuint32m1_t, vuint32m1_t, vuint32m1_t, vuint32m1_t, vuint32m1_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vsuxseg5ei8_v)))
void vsuxseg5ei8_v_u32mf2(uint32_t *, vuint8mf8_t, vuint32mf2_t, vuint32mf2_t, vuint32mf2_t, vuint32mf2_t, vuint32mf2_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vsuxseg5ei8_v_m)))
void vsuxseg5ei8_v_u32mf2_m(vbool64_t, uint32_t *, vuint8mf8_t, vuint32mf2_t, vuint32mf2_t, vuint32mf2_t, vuint32mf2_t, vuint32mf2_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vsuxseg6ei8_v)))
void vsuxseg6ei8_v_i32m1(int32_t *, vuint8mf4_t, vint32m1_t, vint32m1_t, vint32m1_t, vint32m1_t, vint32m1_t, vint32m1_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vsuxseg6ei8_v_m)))
void vsuxseg6ei8_v_i32m1_m(vbool32_t, int32_t *, vuint8mf4_t, vint32m1_t, vint32m1_t, vint32m1_t, vint32m1_t, vint32m1_t, vint32m1_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vsuxseg6ei8_v)))
void vsuxseg6ei8_v_i32mf2(int32_t *, vuint8mf8_t, vint32mf2_t, vint32mf2_t, vint32mf2_t, vint32mf2_t, vint32mf2_t, vint32mf2_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vsuxseg6ei8_v_m)))
void vsuxseg6ei8_v_i32mf2_m(vbool64_t, int32_t *, vuint8mf8_t, vint32mf2_t, vint32mf2_t, vint32mf2_t, vint32mf2_t, vint32mf2_t, vint32mf2_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vsuxseg6ei8_v)))
void vsuxseg6ei8_v_u32m1(uint32_t *, vuint8mf4_t, vuint32m1_t, vuint32m1_t, vuint32m1_t, vuint32m1_t, vuint32m1_t, vuint32m1_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vsuxseg6ei8_v_m)))
void vsuxseg6ei8_v_u32m1_m(vbool32_t, uint32_t *, vuint8mf4_t, vuint32m1_t, vuint32m1_t, vuint32m1_t, vuint32m1_t, vuint32m1_t, vuint32m1_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vsuxseg6ei8_v)))
void vsuxseg6ei8_v_u32mf2(uint32_t *, vuint8mf8_t, vuint32mf2_t, vuint32mf2_t, vuint32mf2_t, vuint32mf2_t, vuint32mf2_t, vuint32mf2_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vsuxseg6ei8_v_m)))
void vsuxseg6ei8_v_u32mf2_m(vbool64_t, uint32_t *, vuint8mf8_t, vuint32mf2_t, vuint32mf2_t, vuint32mf2_t, vuint32mf2_t, vuint32mf2_t, vuint32mf2_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vsuxseg7ei8_v)))
void vsuxseg7ei8_v_i32m1(int32_t *, vuint8mf4_t, vint32m1_t, vint32m1_t, vint32m1_t, vint32m1_t, vint32m1_t, vint32m1_t, vint32m1_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vsuxseg7ei8_v_m)))
void vsuxseg7ei8_v_i32m1_m(vbool32_t, int32_t *, vuint8mf4_t, vint32m1_t, vint32m1_t, vint32m1_t, vint32m1_t, vint32m1_t, vint32m1_t, vint32m1_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vsuxseg7ei8_v)))
void vsuxseg7ei8_v_i32mf2(int32_t *, vuint8mf8_t, vint32mf2_t, vint32mf2_t, vint32mf2_t, vint32mf2_t, vint32mf2_t, vint32mf2_t, vint32mf2_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vsuxseg7ei8_v_m)))
void vsuxseg7ei8_v_i32mf2_m(vbool64_t, int32_t *, vuint8mf8_t, vint32mf2_t, vint32mf2_t, vint32mf2_t, vint32mf2_t, vint32mf2_t, vint32mf2_t, vint32mf2_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vsuxseg7ei8_v)))
void vsuxseg7ei8_v_u32m1(uint32_t *, vuint8mf4_t, vuint32m1_t, vuint32m1_t, vuint32m1_t, vuint32m1_t, vuint32m1_t, vuint32m1_t, vuint32m1_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vsuxseg7ei8_v_m)))
void vsuxseg7ei8_v_u32m1_m(vbool32_t, uint32_t *, vuint8mf4_t, vuint32m1_t, vuint32m1_t, vuint32m1_t, vuint32m1_t, vuint32m1_t, vuint32m1_t, vuint32m1_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vsuxseg7ei8_v)))
void vsuxseg7ei8_v_u32mf2(uint32_t *, vuint8mf8_t, vuint32mf2_t, vuint32mf2_t, vuint32mf2_t, vuint32mf2_t, vuint32mf2_t, vuint32mf2_t, vuint32mf2_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vsuxseg7ei8_v_m)))
void vsuxseg7ei8_v_u32mf2_m(vbool64_t, uint32_t *, vuint8mf8_t, vuint32mf2_t, vuint32mf2_t, vuint32mf2_t, vuint32mf2_t, vuint32mf2_t, vuint32mf2_t, vuint32mf2_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vsuxseg8ei8_v)))
void vsuxseg8ei8_v_i32m1(int32_t *, vuint8mf4_t, vint32m1_t, vint32m1_t, vint32m1_t, vint32m1_t, vint32m1_t, vint32m1_t, vint32m1_t, vint32m1_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vsuxseg8ei8_v_m)))
void vsuxseg8ei8_v_i32m1_m(vbool32_t, int32_t *, vuint8mf4_t, vint32m1_t, vint32m1_t, vint32m1_t, vint32m1_t, vint32m1_t, vint32m1_t, vint32m1_t, vint32m1_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vsuxseg8ei8_v)))
void vsuxseg8ei8_v_i32mf2(int32_t *, vuint8mf8_t, vint32mf2_t, vint32mf2_t, vint32mf2_t, vint32mf2_t, vint32mf2_t, vint32mf2_t, vint32mf2_t, vint32mf2_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vsuxseg8ei8_v_m)))
void vsuxseg8ei8_v_i32mf2_m(vbool64_t, int32_t *, vuint8mf8_t, vint32mf2_t, vint32mf2_t, vint32mf2_t, vint32mf2_t, vint32mf2_t, vint32mf2_t, vint32mf2_t, vint32mf2_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vsuxseg8ei8_v)))
void vsuxseg8ei8_v_u32m1(uint32_t *, vuint8mf4_t, vuint32m1_t, vuint32m1_t, vuint32m1_t, vuint32m1_t, vuint32m1_t, vuint32m1_t, vuint32m1_t, vuint32m1_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vsuxseg8ei8_v_m)))
void vsuxseg8ei8_v_u32m1_m(vbool32_t, uint32_t *, vuint8mf4_t, vuint32m1_t, vuint32m1_t, vuint32m1_t, vuint32m1_t, vuint32m1_t, vuint32m1_t, vuint32m1_t, vuint32m1_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vsuxseg8ei8_v)))
void vsuxseg8ei8_v_u32mf2(uint32_t *, vuint8mf8_t, vuint32mf2_t, vuint32mf2_t, vuint32mf2_t, vuint32mf2_t, vuint32mf2_t, vuint32mf2_t, vuint32mf2_t, vuint32mf2_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vsuxseg8ei8_v_m)))
void vsuxseg8ei8_v_u32mf2_m(vbool64_t, uint32_t *, vuint8mf8_t, vuint32mf2_t, vuint32mf2_t, vuint32mf2_t, vuint32mf2_t, vuint32mf2_t, vuint32mf2_t, vuint32mf2_t, vuint32mf2_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vsuxseg2ei16_v)))
void vsuxseg2ei16_v_i32m1(int32_t *, vuint16mf2_t, vint32m1_t, vint32m1_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vsuxseg2ei16_v_m)))
void vsuxseg2ei16_v_i32m1_m(vbool32_t, int32_t *, vuint16mf2_t, vint32m1_t, vint32m1_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vsuxseg2ei16_v)))
void vsuxseg2ei16_v_i32m2(int32_t *, vuint16m1_t, vint32m2_t, vint32m2_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vsuxseg2ei16_v_m)))
void vsuxseg2ei16_v_i32m2_m(vbool16_t, int32_t *, vuint16m1_t, vint32m2_t, vint32m2_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vsuxseg2ei16_v)))
void vsuxseg2ei16_v_i32m4(int32_t *, vuint16m2_t, vint32m4_t, vint32m4_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vsuxseg2ei16_v_m)))
void vsuxseg2ei16_v_i32m4_m(vbool8_t, int32_t *, vuint16m2_t, vint32m4_t, vint32m4_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vsuxseg2ei16_v)))
void vsuxseg2ei16_v_i32mf2(int32_t *, vuint16mf4_t, vint32mf2_t, vint32mf2_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vsuxseg2ei16_v_m)))
void vsuxseg2ei16_v_i32mf2_m(vbool64_t, int32_t *, vuint16mf4_t, vint32mf2_t, vint32mf2_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vsuxseg2ei16_v)))
void vsuxseg2ei16_v_u32m1(uint32_t *, vuint16mf2_t, vuint32m1_t, vuint32m1_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vsuxseg2ei16_v_m)))
void vsuxseg2ei16_v_u32m1_m(vbool32_t, uint32_t *, vuint16mf2_t, vuint32m1_t, vuint32m1_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vsuxseg2ei16_v)))
void vsuxseg2ei16_v_u32m2(uint32_t *, vuint16m1_t, vuint32m2_t, vuint32m2_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vsuxseg2ei16_v_m)))
void vsuxseg2ei16_v_u32m2_m(vbool16_t, uint32_t *, vuint16m1_t, vuint32m2_t, vuint32m2_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vsuxseg2ei16_v)))
void vsuxseg2ei16_v_u32m4(uint32_t *, vuint16m2_t, vuint32m4_t, vuint32m4_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vsuxseg2ei16_v_m)))
void vsuxseg2ei16_v_u32m4_m(vbool8_t, uint32_t *, vuint16m2_t, vuint32m4_t, vuint32m4_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vsuxseg2ei16_v)))
void vsuxseg2ei16_v_u32mf2(uint32_t *, vuint16mf4_t, vuint32mf2_t, vuint32mf2_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vsuxseg2ei16_v_m)))
void vsuxseg2ei16_v_u32mf2_m(vbool64_t, uint32_t *, vuint16mf4_t, vuint32mf2_t, vuint32mf2_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vsuxseg3ei16_v)))
void vsuxseg3ei16_v_i32m1(int32_t *, vuint16mf2_t, vint32m1_t, vint32m1_t, vint32m1_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vsuxseg3ei16_v_m)))
void vsuxseg3ei16_v_i32m1_m(vbool32_t, int32_t *, vuint16mf2_t, vint32m1_t, vint32m1_t, vint32m1_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vsuxseg3ei16_v)))
void vsuxseg3ei16_v_i32m2(int32_t *, vuint16m1_t, vint32m2_t, vint32m2_t, vint32m2_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vsuxseg3ei16_v_m)))
void vsuxseg3ei16_v_i32m2_m(vbool16_t, int32_t *, vuint16m1_t, vint32m2_t, vint32m2_t, vint32m2_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vsuxseg3ei16_v)))
void vsuxseg3ei16_v_i32mf2(int32_t *, vuint16mf4_t, vint32mf2_t, vint32mf2_t, vint32mf2_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vsuxseg3ei16_v_m)))
void vsuxseg3ei16_v_i32mf2_m(vbool64_t, int32_t *, vuint16mf4_t, vint32mf2_t, vint32mf2_t, vint32mf2_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vsuxseg3ei16_v)))
void vsuxseg3ei16_v_u32m1(uint32_t *, vuint16mf2_t, vuint32m1_t, vuint32m1_t, vuint32m1_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vsuxseg3ei16_v_m)))
void vsuxseg3ei16_v_u32m1_m(vbool32_t, uint32_t *, vuint16mf2_t, vuint32m1_t, vuint32m1_t, vuint32m1_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vsuxseg3ei16_v)))
void vsuxseg3ei16_v_u32m2(uint32_t *, vuint16m1_t, vuint32m2_t, vuint32m2_t, vuint32m2_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vsuxseg3ei16_v_m)))
void vsuxseg3ei16_v_u32m2_m(vbool16_t, uint32_t *, vuint16m1_t, vuint32m2_t, vuint32m2_t, vuint32m2_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vsuxseg3ei16_v)))
void vsuxseg3ei16_v_u32mf2(uint32_t *, vuint16mf4_t, vuint32mf2_t, vuint32mf2_t, vuint32mf2_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vsuxseg3ei16_v_m)))
void vsuxseg3ei16_v_u32mf2_m(vbool64_t, uint32_t *, vuint16mf4_t, vuint32mf2_t, vuint32mf2_t, vuint32mf2_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vsuxseg4ei16_v)))
void vsuxseg4ei16_v_i32m1(int32_t *, vuint16mf2_t, vint32m1_t, vint32m1_t, vint32m1_t, vint32m1_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vsuxseg4ei16_v_m)))
void vsuxseg4ei16_v_i32m1_m(vbool32_t, int32_t *, vuint16mf2_t, vint32m1_t, vint32m1_t, vint32m1_t, vint32m1_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vsuxseg4ei16_v)))
void vsuxseg4ei16_v_i32m2(int32_t *, vuint16m1_t, vint32m2_t, vint32m2_t, vint32m2_t, vint32m2_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vsuxseg4ei16_v_m)))
void vsuxseg4ei16_v_i32m2_m(vbool16_t, int32_t *, vuint16m1_t, vint32m2_t, vint32m2_t, vint32m2_t, vint32m2_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vsuxseg4ei16_v)))
void vsuxseg4ei16_v_i32mf2(int32_t *, vuint16mf4_t, vint32mf2_t, vint32mf2_t, vint32mf2_t, vint32mf2_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vsuxseg4ei16_v_m)))
void vsuxseg4ei16_v_i32mf2_m(vbool64_t, int32_t *, vuint16mf4_t, vint32mf2_t, vint32mf2_t, vint32mf2_t, vint32mf2_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vsuxseg4ei16_v)))
void vsuxseg4ei16_v_u32m1(uint32_t *, vuint16mf2_t, vuint32m1_t, vuint32m1_t, vuint32m1_t, vuint32m1_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vsuxseg4ei16_v_m)))
void vsuxseg4ei16_v_u32m1_m(vbool32_t, uint32_t *, vuint16mf2_t, vuint32m1_t, vuint32m1_t, vuint32m1_t, vuint32m1_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vsuxseg4ei16_v)))
void vsuxseg4ei16_v_u32m2(uint32_t *, vuint16m1_t, vuint32m2_t, vuint32m2_t, vuint32m2_t, vuint32m2_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vsuxseg4ei16_v_m)))
void vsuxseg4ei16_v_u32m2_m(vbool16_t, uint32_t *, vuint16m1_t, vuint32m2_t, vuint32m2_t, vuint32m2_t, vuint32m2_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vsuxseg4ei16_v)))
void vsuxseg4ei16_v_u32mf2(uint32_t *, vuint16mf4_t, vuint32mf2_t, vuint32mf2_t, vuint32mf2_t, vuint32mf2_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vsuxseg4ei16_v_m)))
void vsuxseg4ei16_v_u32mf2_m(vbool64_t, uint32_t *, vuint16mf4_t, vuint32mf2_t, vuint32mf2_t, vuint32mf2_t, vuint32mf2_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vsuxseg5ei16_v)))
void vsuxseg5ei16_v_i32m1(int32_t *, vuint16mf2_t, vint32m1_t, vint32m1_t, vint32m1_t, vint32m1_t, vint32m1_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vsuxseg5ei16_v_m)))
void vsuxseg5ei16_v_i32m1_m(vbool32_t, int32_t *, vuint16mf2_t, vint32m1_t, vint32m1_t, vint32m1_t, vint32m1_t, vint32m1_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vsuxseg5ei16_v)))
void vsuxseg5ei16_v_i32mf2(int32_t *, vuint16mf4_t, vint32mf2_t, vint32mf2_t, vint32mf2_t, vint32mf2_t, vint32mf2_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vsuxseg5ei16_v_m)))
void vsuxseg5ei16_v_i32mf2_m(vbool64_t, int32_t *, vuint16mf4_t, vint32mf2_t, vint32mf2_t, vint32mf2_t, vint32mf2_t, vint32mf2_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vsuxseg5ei16_v)))
void vsuxseg5ei16_v_u32m1(uint32_t *, vuint16mf2_t, vuint32m1_t, vuint32m1_t, vuint32m1_t, vuint32m1_t, vuint32m1_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vsuxseg5ei16_v_m)))
void vsuxseg5ei16_v_u32m1_m(vbool32_t, uint32_t *, vuint16mf2_t, vuint32m1_t, vuint32m1_t, vuint32m1_t, vuint32m1_t, vuint32m1_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vsuxseg5ei16_v)))
void vsuxseg5ei16_v_u32mf2(uint32_t *, vuint16mf4_t, vuint32mf2_t, vuint32mf2_t, vuint32mf2_t, vuint32mf2_t, vuint32mf2_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vsuxseg5ei16_v_m)))
void vsuxseg5ei16_v_u32mf2_m(vbool64_t, uint32_t *, vuint16mf4_t, vuint32mf2_t, vuint32mf2_t, vuint32mf2_t, vuint32mf2_t, vuint32mf2_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vsuxseg6ei16_v)))
void vsuxseg6ei16_v_i32m1(int32_t *, vuint16mf2_t, vint32m1_t, vint32m1_t, vint32m1_t, vint32m1_t, vint32m1_t, vint32m1_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vsuxseg6ei16_v_m)))
void vsuxseg6ei16_v_i32m1_m(vbool32_t, int32_t *, vuint16mf2_t, vint32m1_t, vint32m1_t, vint32m1_t, vint32m1_t, vint32m1_t, vint32m1_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vsuxseg6ei16_v)))
void vsuxseg6ei16_v_i32mf2(int32_t *, vuint16mf4_t, vint32mf2_t, vint32mf2_t, vint32mf2_t, vint32mf2_t, vint32mf2_t, vint32mf2_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vsuxseg6ei16_v_m)))
void vsuxseg6ei16_v_i32mf2_m(vbool64_t, int32_t *, vuint16mf4_t, vint32mf2_t, vint32mf2_t, vint32mf2_t, vint32mf2_t, vint32mf2_t, vint32mf2_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vsuxseg6ei16_v)))
void vsuxseg6ei16_v_u32m1(uint32_t *, vuint16mf2_t, vuint32m1_t, vuint32m1_t, vuint32m1_t, vuint32m1_t, vuint32m1_t, vuint32m1_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vsuxseg6ei16_v_m)))
void vsuxseg6ei16_v_u32m1_m(vbool32_t, uint32_t *, vuint16mf2_t, vuint32m1_t, vuint32m1_t, vuint32m1_t, vuint32m1_t, vuint32m1_t, vuint32m1_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vsuxseg6ei16_v)))
void vsuxseg6ei16_v_u32mf2(uint32_t *, vuint16mf4_t, vuint32mf2_t, vuint32mf2_t, vuint32mf2_t, vuint32mf2_t, vuint32mf2_t, vuint32mf2_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vsuxseg6ei16_v_m)))
void vsuxseg6ei16_v_u32mf2_m(vbool64_t, uint32_t *, vuint16mf4_t, vuint32mf2_t, vuint32mf2_t, vuint32mf2_t, vuint32mf2_t, vuint32mf2_t, vuint32mf2_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vsuxseg7ei16_v)))
void vsuxseg7ei16_v_i32m1(int32_t *, vuint16mf2_t, vint32m1_t, vint32m1_t, vint32m1_t, vint32m1_t, vint32m1_t, vint32m1_t, vint32m1_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vsuxseg7ei16_v_m)))
void vsuxseg7ei16_v_i32m1_m(vbool32_t, int32_t *, vuint16mf2_t, vint32m1_t, vint32m1_t, vint32m1_t, vint32m1_t, vint32m1_t, vint32m1_t, vint32m1_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vsuxseg7ei16_v)))
void vsuxseg7ei16_v_i32mf2(int32_t *, vuint16mf4_t, vint32mf2_t, vint32mf2_t, vint32mf2_t, vint32mf2_t, vint32mf2_t, vint32mf2_t, vint32mf2_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vsuxseg7ei16_v_m)))
void vsuxseg7ei16_v_i32mf2_m(vbool64_t, int32_t *, vuint16mf4_t, vint32mf2_t, vint32mf2_t, vint32mf2_t, vint32mf2_t, vint32mf2_t, vint32mf2_t, vint32mf2_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vsuxseg7ei16_v)))
void vsuxseg7ei16_v_u32m1(uint32_t *, vuint16mf2_t, vuint32m1_t, vuint32m1_t, vuint32m1_t, vuint32m1_t, vuint32m1_t, vuint32m1_t, vuint32m1_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vsuxseg7ei16_v_m)))
void vsuxseg7ei16_v_u32m1_m(vbool32_t, uint32_t *, vuint16mf2_t, vuint32m1_t, vuint32m1_t, vuint32m1_t, vuint32m1_t, vuint32m1_t, vuint32m1_t, vuint32m1_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vsuxseg7ei16_v)))
void vsuxseg7ei16_v_u32mf2(uint32_t *, vuint16mf4_t, vuint32mf2_t, vuint32mf2_t, vuint32mf2_t, vuint32mf2_t, vuint32mf2_t, vuint32mf2_t, vuint32mf2_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vsuxseg7ei16_v_m)))
void vsuxseg7ei16_v_u32mf2_m(vbool64_t, uint32_t *, vuint16mf4_t, vuint32mf2_t, vuint32mf2_t, vuint32mf2_t, vuint32mf2_t, vuint32mf2_t, vuint32mf2_t, vuint32mf2_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vsuxseg8ei16_v)))
void vsuxseg8ei16_v_i32m1(int32_t *, vuint16mf2_t, vint32m1_t, vint32m1_t, vint32m1_t, vint32m1_t, vint32m1_t, vint32m1_t, vint32m1_t, vint32m1_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vsuxseg8ei16_v_m)))
void vsuxseg8ei16_v_i32m1_m(vbool32_t, int32_t *, vuint16mf2_t, vint32m1_t, vint32m1_t, vint32m1_t, vint32m1_t, vint32m1_t, vint32m1_t, vint32m1_t, vint32m1_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vsuxseg8ei16_v)))
void vsuxseg8ei16_v_i32mf2(int32_t *, vuint16mf4_t, vint32mf2_t, vint32mf2_t, vint32mf2_t, vint32mf2_t, vint32mf2_t, vint32mf2_t, vint32mf2_t, vint32mf2_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vsuxseg8ei16_v_m)))
void vsuxseg8ei16_v_i32mf2_m(vbool64_t, int32_t *, vuint16mf4_t, vint32mf2_t, vint32mf2_t, vint32mf2_t, vint32mf2_t, vint32mf2_t, vint32mf2_t, vint32mf2_t, vint32mf2_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vsuxseg8ei16_v)))
void vsuxseg8ei16_v_u32m1(uint32_t *, vuint16mf2_t, vuint32m1_t, vuint32m1_t, vuint32m1_t, vuint32m1_t, vuint32m1_t, vuint32m1_t, vuint32m1_t, vuint32m1_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vsuxseg8ei16_v_m)))
void vsuxseg8ei16_v_u32m1_m(vbool32_t, uint32_t *, vuint16mf2_t, vuint32m1_t, vuint32m1_t, vuint32m1_t, vuint32m1_t, vuint32m1_t, vuint32m1_t, vuint32m1_t, vuint32m1_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vsuxseg8ei16_v)))
void vsuxseg8ei16_v_u32mf2(uint32_t *, vuint16mf4_t, vuint32mf2_t, vuint32mf2_t, vuint32mf2_t, vuint32mf2_t, vuint32mf2_t, vuint32mf2_t, vuint32mf2_t, vuint32mf2_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vsuxseg8ei16_v_m)))
void vsuxseg8ei16_v_u32mf2_m(vbool64_t, uint32_t *, vuint16mf4_t, vuint32mf2_t, vuint32mf2_t, vuint32mf2_t, vuint32mf2_t, vuint32mf2_t, vuint32mf2_t, vuint32mf2_t, vuint32mf2_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vsuxseg2ei32_v)))
void vsuxseg2ei32_v_i32m1(int32_t *, vuint32m1_t, vint32m1_t, vint32m1_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vsuxseg2ei32_v_m)))
void vsuxseg2ei32_v_i32m1_m(vbool32_t, int32_t *, vuint32m1_t, vint32m1_t, vint32m1_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vsuxseg2ei32_v)))
void vsuxseg2ei32_v_i32m2(int32_t *, vuint32m2_t, vint32m2_t, vint32m2_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vsuxseg2ei32_v_m)))
void vsuxseg2ei32_v_i32m2_m(vbool16_t, int32_t *, vuint32m2_t, vint32m2_t, vint32m2_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vsuxseg2ei32_v)))
void vsuxseg2ei32_v_i32m4(int32_t *, vuint32m4_t, vint32m4_t, vint32m4_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vsuxseg2ei32_v_m)))
void vsuxseg2ei32_v_i32m4_m(vbool8_t, int32_t *, vuint32m4_t, vint32m4_t, vint32m4_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vsuxseg2ei32_v)))
void vsuxseg2ei32_v_i32mf2(int32_t *, vuint32mf2_t, vint32mf2_t, vint32mf2_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vsuxseg2ei32_v_m)))
void vsuxseg2ei32_v_i32mf2_m(vbool64_t, int32_t *, vuint32mf2_t, vint32mf2_t, vint32mf2_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vsuxseg2ei32_v)))
void vsuxseg2ei32_v_u32m1(uint32_t *, vuint32m1_t, vuint32m1_t, vuint32m1_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vsuxseg2ei32_v_m)))
void vsuxseg2ei32_v_u32m1_m(vbool32_t, uint32_t *, vuint32m1_t, vuint32m1_t, vuint32m1_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vsuxseg2ei32_v)))
void vsuxseg2ei32_v_u32m2(uint32_t *, vuint32m2_t, vuint32m2_t, vuint32m2_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vsuxseg2ei32_v_m)))
void vsuxseg2ei32_v_u32m2_m(vbool16_t, uint32_t *, vuint32m2_t, vuint32m2_t, vuint32m2_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vsuxseg2ei32_v)))
void vsuxseg2ei32_v_u32m4(uint32_t *, vuint32m4_t, vuint32m4_t, vuint32m4_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vsuxseg2ei32_v_m)))
void vsuxseg2ei32_v_u32m4_m(vbool8_t, uint32_t *, vuint32m4_t, vuint32m4_t, vuint32m4_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vsuxseg2ei32_v)))
void vsuxseg2ei32_v_u32mf2(uint32_t *, vuint32mf2_t, vuint32mf2_t, vuint32mf2_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vsuxseg2ei32_v_m)))
void vsuxseg2ei32_v_u32mf2_m(vbool64_t, uint32_t *, vuint32mf2_t, vuint32mf2_t, vuint32mf2_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vsuxseg3ei32_v)))
void vsuxseg3ei32_v_i32m1(int32_t *, vuint32m1_t, vint32m1_t, vint32m1_t, vint32m1_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vsuxseg3ei32_v_m)))
void vsuxseg3ei32_v_i32m1_m(vbool32_t, int32_t *, vuint32m1_t, vint32m1_t, vint32m1_t, vint32m1_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vsuxseg3ei32_v)))
void vsuxseg3ei32_v_i32m2(int32_t *, vuint32m2_t, vint32m2_t, vint32m2_t, vint32m2_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vsuxseg3ei32_v_m)))
void vsuxseg3ei32_v_i32m2_m(vbool16_t, int32_t *, vuint32m2_t, vint32m2_t, vint32m2_t, vint32m2_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vsuxseg3ei32_v)))
void vsuxseg3ei32_v_i32mf2(int32_t *, vuint32mf2_t, vint32mf2_t, vint32mf2_t, vint32mf2_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vsuxseg3ei32_v_m)))
void vsuxseg3ei32_v_i32mf2_m(vbool64_t, int32_t *, vuint32mf2_t, vint32mf2_t, vint32mf2_t, vint32mf2_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vsuxseg3ei32_v)))
void vsuxseg3ei32_v_u32m1(uint32_t *, vuint32m1_t, vuint32m1_t, vuint32m1_t, vuint32m1_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vsuxseg3ei32_v_m)))
void vsuxseg3ei32_v_u32m1_m(vbool32_t, uint32_t *, vuint32m1_t, vuint32m1_t, vuint32m1_t, vuint32m1_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vsuxseg3ei32_v)))
void vsuxseg3ei32_v_u32m2(uint32_t *, vuint32m2_t, vuint32m2_t, vuint32m2_t, vuint32m2_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vsuxseg3ei32_v_m)))
void vsuxseg3ei32_v_u32m2_m(vbool16_t, uint32_t *, vuint32m2_t, vuint32m2_t, vuint32m2_t, vuint32m2_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vsuxseg3ei32_v)))
void vsuxseg3ei32_v_u32mf2(uint32_t *, vuint32mf2_t, vuint32mf2_t, vuint32mf2_t, vuint32mf2_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vsuxseg3ei32_v_m)))
void vsuxseg3ei32_v_u32mf2_m(vbool64_t, uint32_t *, vuint32mf2_t, vuint32mf2_t, vuint32mf2_t, vuint32mf2_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vsuxseg4ei32_v)))
void vsuxseg4ei32_v_i32m1(int32_t *, vuint32m1_t, vint32m1_t, vint32m1_t, vint32m1_t, vint32m1_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vsuxseg4ei32_v_m)))
void vsuxseg4ei32_v_i32m1_m(vbool32_t, int32_t *, vuint32m1_t, vint32m1_t, vint32m1_t, vint32m1_t, vint32m1_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vsuxseg4ei32_v)))
void vsuxseg4ei32_v_i32m2(int32_t *, vuint32m2_t, vint32m2_t, vint32m2_t, vint32m2_t, vint32m2_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vsuxseg4ei32_v_m)))
void vsuxseg4ei32_v_i32m2_m(vbool16_t, int32_t *, vuint32m2_t, vint32m2_t, vint32m2_t, vint32m2_t, vint32m2_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vsuxseg4ei32_v)))
void vsuxseg4ei32_v_i32mf2(int32_t *, vuint32mf2_t, vint32mf2_t, vint32mf2_t, vint32mf2_t, vint32mf2_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vsuxseg4ei32_v_m)))
void vsuxseg4ei32_v_i32mf2_m(vbool64_t, int32_t *, vuint32mf2_t, vint32mf2_t, vint32mf2_t, vint32mf2_t, vint32mf2_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vsuxseg4ei32_v)))
void vsuxseg4ei32_v_u32m1(uint32_t *, vuint32m1_t, vuint32m1_t, vuint32m1_t, vuint32m1_t, vuint32m1_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vsuxseg4ei32_v_m)))
void vsuxseg4ei32_v_u32m1_m(vbool32_t, uint32_t *, vuint32m1_t, vuint32m1_t, vuint32m1_t, vuint32m1_t, vuint32m1_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vsuxseg4ei32_v)))
void vsuxseg4ei32_v_u32m2(uint32_t *, vuint32m2_t, vuint32m2_t, vuint32m2_t, vuint32m2_t, vuint32m2_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vsuxseg4ei32_v_m)))
void vsuxseg4ei32_v_u32m2_m(vbool16_t, uint32_t *, vuint32m2_t, vuint32m2_t, vuint32m2_t, vuint32m2_t, vuint32m2_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vsuxseg4ei32_v)))
void vsuxseg4ei32_v_u32mf2(uint32_t *, vuint32mf2_t, vuint32mf2_t, vuint32mf2_t, vuint32mf2_t, vuint32mf2_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vsuxseg4ei32_v_m)))
void vsuxseg4ei32_v_u32mf2_m(vbool64_t, uint32_t *, vuint32mf2_t, vuint32mf2_t, vuint32mf2_t, vuint32mf2_t, vuint32mf2_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vsuxseg5ei32_v)))
void vsuxseg5ei32_v_i32m1(int32_t *, vuint32m1_t, vint32m1_t, vint32m1_t, vint32m1_t, vint32m1_t, vint32m1_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vsuxseg5ei32_v_m)))
void vsuxseg5ei32_v_i32m1_m(vbool32_t, int32_t *, vuint32m1_t, vint32m1_t, vint32m1_t, vint32m1_t, vint32m1_t, vint32m1_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vsuxseg5ei32_v)))
void vsuxseg5ei32_v_i32mf2(int32_t *, vuint32mf2_t, vint32mf2_t, vint32mf2_t, vint32mf2_t, vint32mf2_t, vint32mf2_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vsuxseg5ei32_v_m)))
void vsuxseg5ei32_v_i32mf2_m(vbool64_t, int32_t *, vuint32mf2_t, vint32mf2_t, vint32mf2_t, vint32mf2_t, vint32mf2_t, vint32mf2_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vsuxseg5ei32_v)))
void vsuxseg5ei32_v_u32m1(uint32_t *, vuint32m1_t, vuint32m1_t, vuint32m1_t, vuint32m1_t, vuint32m1_t, vuint32m1_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vsuxseg5ei32_v_m)))
void vsuxseg5ei32_v_u32m1_m(vbool32_t, uint32_t *, vuint32m1_t, vuint32m1_t, vuint32m1_t, vuint32m1_t, vuint32m1_t, vuint32m1_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vsuxseg5ei32_v)))
void vsuxseg5ei32_v_u32mf2(uint32_t *, vuint32mf2_t, vuint32mf2_t, vuint32mf2_t, vuint32mf2_t, vuint32mf2_t, vuint32mf2_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vsuxseg5ei32_v_m)))
void vsuxseg5ei32_v_u32mf2_m(vbool64_t, uint32_t *, vuint32mf2_t, vuint32mf2_t, vuint32mf2_t, vuint32mf2_t, vuint32mf2_t, vuint32mf2_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vsuxseg6ei32_v)))
void vsuxseg6ei32_v_i32m1(int32_t *, vuint32m1_t, vint32m1_t, vint32m1_t, vint32m1_t, vint32m1_t, vint32m1_t, vint32m1_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vsuxseg6ei32_v_m)))
void vsuxseg6ei32_v_i32m1_m(vbool32_t, int32_t *, vuint32m1_t, vint32m1_t, vint32m1_t, vint32m1_t, vint32m1_t, vint32m1_t, vint32m1_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vsuxseg6ei32_v)))
void vsuxseg6ei32_v_i32mf2(int32_t *, vuint32mf2_t, vint32mf2_t, vint32mf2_t, vint32mf2_t, vint32mf2_t, vint32mf2_t, vint32mf2_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vsuxseg6ei32_v_m)))
void vsuxseg6ei32_v_i32mf2_m(vbool64_t, int32_t *, vuint32mf2_t, vint32mf2_t, vint32mf2_t, vint32mf2_t, vint32mf2_t, vint32mf2_t, vint32mf2_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vsuxseg6ei32_v)))
void vsuxseg6ei32_v_u32m1(uint32_t *, vuint32m1_t, vuint32m1_t, vuint32m1_t, vuint32m1_t, vuint32m1_t, vuint32m1_t, vuint32m1_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vsuxseg6ei32_v_m)))
void vsuxseg6ei32_v_u32m1_m(vbool32_t, uint32_t *, vuint32m1_t, vuint32m1_t, vuint32m1_t, vuint32m1_t, vuint32m1_t, vuint32m1_t, vuint32m1_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vsuxseg6ei32_v)))
void vsuxseg6ei32_v_u32mf2(uint32_t *, vuint32mf2_t, vuint32mf2_t, vuint32mf2_t, vuint32mf2_t, vuint32mf2_t, vuint32mf2_t, vuint32mf2_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vsuxseg6ei32_v_m)))
void vsuxseg6ei32_v_u32mf2_m(vbool64_t, uint32_t *, vuint32mf2_t, vuint32mf2_t, vuint32mf2_t, vuint32mf2_t, vuint32mf2_t, vuint32mf2_t, vuint32mf2_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vsuxseg7ei32_v)))
void vsuxseg7ei32_v_i32m1(int32_t *, vuint32m1_t, vint32m1_t, vint32m1_t, vint32m1_t, vint32m1_t, vint32m1_t, vint32m1_t, vint32m1_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vsuxseg7ei32_v_m)))
void vsuxseg7ei32_v_i32m1_m(vbool32_t, int32_t *, vuint32m1_t, vint32m1_t, vint32m1_t, vint32m1_t, vint32m1_t, vint32m1_t, vint32m1_t, vint32m1_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vsuxseg7ei32_v)))
void vsuxseg7ei32_v_i32mf2(int32_t *, vuint32mf2_t, vint32mf2_t, vint32mf2_t, vint32mf2_t, vint32mf2_t, vint32mf2_t, vint32mf2_t, vint32mf2_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vsuxseg7ei32_v_m)))
void vsuxseg7ei32_v_i32mf2_m(vbool64_t, int32_t *, vuint32mf2_t, vint32mf2_t, vint32mf2_t, vint32mf2_t, vint32mf2_t, vint32mf2_t, vint32mf2_t, vint32mf2_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vsuxseg7ei32_v)))
void vsuxseg7ei32_v_u32m1(uint32_t *, vuint32m1_t, vuint32m1_t, vuint32m1_t, vuint32m1_t, vuint32m1_t, vuint32m1_t, vuint32m1_t, vuint32m1_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vsuxseg7ei32_v_m)))
void vsuxseg7ei32_v_u32m1_m(vbool32_t, uint32_t *, vuint32m1_t, vuint32m1_t, vuint32m1_t, vuint32m1_t, vuint32m1_t, vuint32m1_t, vuint32m1_t, vuint32m1_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vsuxseg7ei32_v)))
void vsuxseg7ei32_v_u32mf2(uint32_t *, vuint32mf2_t, vuint32mf2_t, vuint32mf2_t, vuint32mf2_t, vuint32mf2_t, vuint32mf2_t, vuint32mf2_t, vuint32mf2_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vsuxseg7ei32_v_m)))
void vsuxseg7ei32_v_u32mf2_m(vbool64_t, uint32_t *, vuint32mf2_t, vuint32mf2_t, vuint32mf2_t, vuint32mf2_t, vuint32mf2_t, vuint32mf2_t, vuint32mf2_t, vuint32mf2_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vsuxseg8ei32_v)))
void vsuxseg8ei32_v_i32m1(int32_t *, vuint32m1_t, vint32m1_t, vint32m1_t, vint32m1_t, vint32m1_t, vint32m1_t, vint32m1_t, vint32m1_t, vint32m1_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vsuxseg8ei32_v_m)))
void vsuxseg8ei32_v_i32m1_m(vbool32_t, int32_t *, vuint32m1_t, vint32m1_t, vint32m1_t, vint32m1_t, vint32m1_t, vint32m1_t, vint32m1_t, vint32m1_t, vint32m1_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vsuxseg8ei32_v)))
void vsuxseg8ei32_v_i32mf2(int32_t *, vuint32mf2_t, vint32mf2_t, vint32mf2_t, vint32mf2_t, vint32mf2_t, vint32mf2_t, vint32mf2_t, vint32mf2_t, vint32mf2_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vsuxseg8ei32_v_m)))
void vsuxseg8ei32_v_i32mf2_m(vbool64_t, int32_t *, vuint32mf2_t, vint32mf2_t, vint32mf2_t, vint32mf2_t, vint32mf2_t, vint32mf2_t, vint32mf2_t, vint32mf2_t, vint32mf2_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vsuxseg8ei32_v)))
void vsuxseg8ei32_v_u32m1(uint32_t *, vuint32m1_t, vuint32m1_t, vuint32m1_t, vuint32m1_t, vuint32m1_t, vuint32m1_t, vuint32m1_t, vuint32m1_t, vuint32m1_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vsuxseg8ei32_v_m)))
void vsuxseg8ei32_v_u32m1_m(vbool32_t, uint32_t *, vuint32m1_t, vuint32m1_t, vuint32m1_t, vuint32m1_t, vuint32m1_t, vuint32m1_t, vuint32m1_t, vuint32m1_t, vuint32m1_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vsuxseg8ei32_v)))
void vsuxseg8ei32_v_u32mf2(uint32_t *, vuint32mf2_t, vuint32mf2_t, vuint32mf2_t, vuint32mf2_t, vuint32mf2_t, vuint32mf2_t, vuint32mf2_t, vuint32mf2_t, vuint32mf2_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vsuxseg8ei32_v_m)))
void vsuxseg8ei32_v_u32mf2_m(vbool64_t, uint32_t *, vuint32mf2_t, vuint32mf2_t, vuint32mf2_t, vuint32mf2_t, vuint32mf2_t, vuint32mf2_t, vuint32mf2_t, vuint32mf2_t, vuint32mf2_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vloxei8_v)))
vint8m1_t vloxei8_v_i8m1(const int8_t *, vuint8m1_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vloxei8_v_m)))
vint8m1_t vloxei8_v_i8m1_m(vbool8_t, vint8m1_t, const int8_t *, vuint8m1_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vloxei8_v)))
vint8m2_t vloxei8_v_i8m2(const int8_t *, vuint8m2_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vloxei8_v_m)))
vint8m2_t vloxei8_v_i8m2_m(vbool4_t, vint8m2_t, const int8_t *, vuint8m2_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vloxei8_v)))
vint8m4_t vloxei8_v_i8m4(const int8_t *, vuint8m4_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vloxei8_v_m)))
vint8m4_t vloxei8_v_i8m4_m(vbool2_t, vint8m4_t, const int8_t *, vuint8m4_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vloxei8_v)))
vint8m8_t vloxei8_v_i8m8(const int8_t *, vuint8m8_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vloxei8_v_m)))
vint8m8_t vloxei8_v_i8m8_m(vbool1_t, vint8m8_t, const int8_t *, vuint8m8_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vloxei8_v)))
vint8mf2_t vloxei8_v_i8mf2(const int8_t *, vuint8mf2_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vloxei8_v_m)))
vint8mf2_t vloxei8_v_i8mf2_m(vbool16_t, vint8mf2_t, const int8_t *, vuint8mf2_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vloxei8_v)))
vint8mf4_t vloxei8_v_i8mf4(const int8_t *, vuint8mf4_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vloxei8_v_m)))
vint8mf4_t vloxei8_v_i8mf4_m(vbool32_t, vint8mf4_t, const int8_t *, vuint8mf4_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vloxei8_v)))
vint8mf8_t vloxei8_v_i8mf8(const int8_t *, vuint8mf8_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vloxei8_v_m)))
vint8mf8_t vloxei8_v_i8mf8_m(vbool64_t, vint8mf8_t, const int8_t *, vuint8mf8_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vloxei8_v)))
vuint8m1_t vloxei8_v_u8m1(const uint8_t *, vuint8m1_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vloxei8_v_m)))
vuint8m1_t vloxei8_v_u8m1_m(vbool8_t, vuint8m1_t, const uint8_t *, vuint8m1_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vloxei8_v)))
vuint8m2_t vloxei8_v_u8m2(const uint8_t *, vuint8m2_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vloxei8_v_m)))
vuint8m2_t vloxei8_v_u8m2_m(vbool4_t, vuint8m2_t, const uint8_t *, vuint8m2_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vloxei8_v)))
vuint8m4_t vloxei8_v_u8m4(const uint8_t *, vuint8m4_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vloxei8_v_m)))
vuint8m4_t vloxei8_v_u8m4_m(vbool2_t, vuint8m4_t, const uint8_t *, vuint8m4_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vloxei8_v)))
vuint8m8_t vloxei8_v_u8m8(const uint8_t *, vuint8m8_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vloxei8_v_m)))
vuint8m8_t vloxei8_v_u8m8_m(vbool1_t, vuint8m8_t, const uint8_t *, vuint8m8_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vloxei8_v)))
vuint8mf2_t vloxei8_v_u8mf2(const uint8_t *, vuint8mf2_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vloxei8_v_m)))
vuint8mf2_t vloxei8_v_u8mf2_m(vbool16_t, vuint8mf2_t, const uint8_t *, vuint8mf2_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vloxei8_v)))
vuint8mf4_t vloxei8_v_u8mf4(const uint8_t *, vuint8mf4_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vloxei8_v_m)))
vuint8mf4_t vloxei8_v_u8mf4_m(vbool32_t, vuint8mf4_t, const uint8_t *, vuint8mf4_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vloxei8_v)))
vuint8mf8_t vloxei8_v_u8mf8(const uint8_t *, vuint8mf8_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vloxei8_v_m)))
vuint8mf8_t vloxei8_v_u8mf8_m(vbool64_t, vuint8mf8_t, const uint8_t *, vuint8mf8_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vloxei16_v)))
vint8m1_t vloxei16_v_i8m1(const int8_t *, vuint16m2_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vloxei16_v_m)))
vint8m1_t vloxei16_v_i8m1_m(vbool8_t, vint8m1_t, const int8_t *, vuint16m2_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vloxei16_v)))
vint8m2_t vloxei16_v_i8m2(const int8_t *, vuint16m4_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vloxei16_v_m)))
vint8m2_t vloxei16_v_i8m2_m(vbool4_t, vint8m2_t, const int8_t *, vuint16m4_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vloxei16_v)))
vint8m4_t vloxei16_v_i8m4(const int8_t *, vuint16m8_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vloxei16_v_m)))
vint8m4_t vloxei16_v_i8m4_m(vbool2_t, vint8m4_t, const int8_t *, vuint16m8_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vloxei16_v)))
vint8mf2_t vloxei16_v_i8mf2(const int8_t *, vuint16m1_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vloxei16_v_m)))
vint8mf2_t vloxei16_v_i8mf2_m(vbool16_t, vint8mf2_t, const int8_t *, vuint16m1_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vloxei16_v)))
vint8mf4_t vloxei16_v_i8mf4(const int8_t *, vuint16mf2_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vloxei16_v_m)))
vint8mf4_t vloxei16_v_i8mf4_m(vbool32_t, vint8mf4_t, const int8_t *, vuint16mf2_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vloxei16_v)))
vint8mf8_t vloxei16_v_i8mf8(const int8_t *, vuint16mf4_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vloxei16_v_m)))
vint8mf8_t vloxei16_v_i8mf8_m(vbool64_t, vint8mf8_t, const int8_t *, vuint16mf4_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vloxei16_v)))
vuint8m1_t vloxei16_v_u8m1(const uint8_t *, vuint16m2_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vloxei16_v_m)))
vuint8m1_t vloxei16_v_u8m1_m(vbool8_t, vuint8m1_t, const uint8_t *, vuint16m2_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vloxei16_v)))
vuint8m2_t vloxei16_v_u8m2(const uint8_t *, vuint16m4_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vloxei16_v_m)))
vuint8m2_t vloxei16_v_u8m2_m(vbool4_t, vuint8m2_t, const uint8_t *, vuint16m4_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vloxei16_v)))
vuint8m4_t vloxei16_v_u8m4(const uint8_t *, vuint16m8_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vloxei16_v_m)))
vuint8m4_t vloxei16_v_u8m4_m(vbool2_t, vuint8m4_t, const uint8_t *, vuint16m8_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vloxei16_v)))
vuint8mf2_t vloxei16_v_u8mf2(const uint8_t *, vuint16m1_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vloxei16_v_m)))
vuint8mf2_t vloxei16_v_u8mf2_m(vbool16_t, vuint8mf2_t, const uint8_t *, vuint16m1_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vloxei16_v)))
vuint8mf4_t vloxei16_v_u8mf4(const uint8_t *, vuint16mf2_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vloxei16_v_m)))
vuint8mf4_t vloxei16_v_u8mf4_m(vbool32_t, vuint8mf4_t, const uint8_t *, vuint16mf2_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vloxei16_v)))
vuint8mf8_t vloxei16_v_u8mf8(const uint8_t *, vuint16mf4_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vloxei16_v_m)))
vuint8mf8_t vloxei16_v_u8mf8_m(vbool64_t, vuint8mf8_t, const uint8_t *, vuint16mf4_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vloxei32_v)))
vint8m1_t vloxei32_v_i8m1(const int8_t *, vuint32m4_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vloxei32_v_m)))
vint8m1_t vloxei32_v_i8m1_m(vbool8_t, vint8m1_t, const int8_t *, vuint32m4_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vloxei32_v)))
vint8m2_t vloxei32_v_i8m2(const int8_t *, vuint32m8_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vloxei32_v_m)))
vint8m2_t vloxei32_v_i8m2_m(vbool4_t, vint8m2_t, const int8_t *, vuint32m8_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vloxei32_v)))
vint8mf2_t vloxei32_v_i8mf2(const int8_t *, vuint32m2_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vloxei32_v_m)))
vint8mf2_t vloxei32_v_i8mf2_m(vbool16_t, vint8mf2_t, const int8_t *, vuint32m2_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vloxei32_v)))
vint8mf4_t vloxei32_v_i8mf4(const int8_t *, vuint32m1_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vloxei32_v_m)))
vint8mf4_t vloxei32_v_i8mf4_m(vbool32_t, vint8mf4_t, const int8_t *, vuint32m1_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vloxei32_v)))
vint8mf8_t vloxei32_v_i8mf8(const int8_t *, vuint32mf2_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vloxei32_v_m)))
vint8mf8_t vloxei32_v_i8mf8_m(vbool64_t, vint8mf8_t, const int8_t *, vuint32mf2_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vsoxseg2ei8_v)))
void vsoxseg2ei8_v_i8m1(int8_t *, vuint8m1_t, vint8m1_t, vint8m1_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vsoxseg2ei8_v_m)))
void vsoxseg2ei8_v_i8m1_m(vbool8_t, int8_t *, vuint8m1_t, vint8m1_t, vint8m1_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vsoxseg2ei8_v)))
void vsoxseg2ei8_v_i8m2(int8_t *, vuint8m2_t, vint8m2_t, vint8m2_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vsoxseg2ei8_v_m)))
void vsoxseg2ei8_v_i8m2_m(vbool4_t, int8_t *, vuint8m2_t, vint8m2_t, vint8m2_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vsoxseg2ei8_v)))
void vsoxseg2ei8_v_i8m4(int8_t *, vuint8m4_t, vint8m4_t, vint8m4_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vsoxseg2ei8_v_m)))
void vsoxseg2ei8_v_i8m4_m(vbool2_t, int8_t *, vuint8m4_t, vint8m4_t, vint8m4_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vsoxseg2ei8_v)))
void vsoxseg2ei8_v_i8mf2(int8_t *, vuint8mf2_t, vint8mf2_t, vint8mf2_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vsoxseg2ei8_v_m)))
void vsoxseg2ei8_v_i8mf2_m(vbool16_t, int8_t *, vuint8mf2_t, vint8mf2_t, vint8mf2_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vsoxseg2ei8_v)))
void vsoxseg2ei8_v_i8mf4(int8_t *, vuint8mf4_t, vint8mf4_t, vint8mf4_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vsoxseg2ei8_v_m)))
void vsoxseg2ei8_v_i8mf4_m(vbool32_t, int8_t *, vuint8mf4_t, vint8mf4_t, vint8mf4_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vsoxseg2ei8_v)))
void vsoxseg2ei8_v_i8mf8(int8_t *, vuint8mf8_t, vint8mf8_t, vint8mf8_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vsoxseg2ei8_v_m)))
void vsoxseg2ei8_v_i8mf8_m(vbool64_t, int8_t *, vuint8mf8_t, vint8mf8_t, vint8mf8_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vsoxseg2ei8_v)))
void vsoxseg2ei8_v_u8m1(uint8_t *, vuint8m1_t, vuint8m1_t, vuint8m1_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vsoxseg2ei8_v_m)))
void vsoxseg2ei8_v_u8m1_m(vbool8_t, uint8_t *, vuint8m1_t, vuint8m1_t, vuint8m1_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vsoxseg2ei8_v)))
void vsoxseg2ei8_v_u8m2(uint8_t *, vuint8m2_t, vuint8m2_t, vuint8m2_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vsoxseg2ei8_v_m)))
void vsoxseg2ei8_v_u8m2_m(vbool4_t, uint8_t *, vuint8m2_t, vuint8m2_t, vuint8m2_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vsoxseg2ei8_v)))
void vsoxseg2ei8_v_u8m4(uint8_t *, vuint8m4_t, vuint8m4_t, vuint8m4_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vsoxseg2ei8_v_m)))
void vsoxseg2ei8_v_u8m4_m(vbool2_t, uint8_t *, vuint8m4_t, vuint8m4_t, vuint8m4_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vsoxseg2ei8_v)))
void vsoxseg2ei8_v_u8mf2(uint8_t *, vuint8mf2_t, vuint8mf2_t, vuint8mf2_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vsoxseg2ei8_v_m)))
void vsoxseg2ei8_v_u8mf2_m(vbool16_t, uint8_t *, vuint8mf2_t, vuint8mf2_t, vuint8mf2_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vsoxseg2ei8_v)))
void vsoxseg2ei8_v_u8mf4(uint8_t *, vuint8mf4_t, vuint8mf4_t, vuint8mf4_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vsoxseg2ei8_v_m)))
void vsoxseg2ei8_v_u8mf4_m(vbool32_t, uint8_t *, vuint8mf4_t, vuint8mf4_t, vuint8mf4_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vsoxseg2ei8_v)))
void vsoxseg2ei8_v_u8mf8(uint8_t *, vuint8mf8_t, vuint8mf8_t, vuint8mf8_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vsoxseg2ei8_v_m)))
void vsoxseg2ei8_v_u8mf8_m(vbool64_t, uint8_t *, vuint8mf8_t, vuint8mf8_t, vuint8mf8_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vloxei32_v)))
vuint8m1_t vloxei32_v_u8m1(const uint8_t *, vuint32m4_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vloxei32_v_m)))
vuint8m1_t vloxei32_v_u8m1_m(vbool8_t, vuint8m1_t, const uint8_t *, vuint32m4_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vloxei32_v)))
vuint8m2_t vloxei32_v_u8m2(const uint8_t *, vuint32m8_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vloxei32_v_m)))
vuint8m2_t vloxei32_v_u8m2_m(vbool4_t, vuint8m2_t, const uint8_t *, vuint32m8_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vloxei32_v)))
vuint8mf2_t vloxei32_v_u8mf2(const uint8_t *, vuint32m2_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vloxei32_v_m)))
vuint8mf2_t vloxei32_v_u8mf2_m(vbool16_t, vuint8mf2_t, const uint8_t *, vuint32m2_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vloxei32_v)))
vuint8mf4_t vloxei32_v_u8mf4(const uint8_t *, vuint32m1_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vloxei32_v_m)))
vuint8mf4_t vloxei32_v_u8mf4_m(vbool32_t, vuint8mf4_t, const uint8_t *, vuint32m1_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vloxei32_v)))
vuint8mf8_t vloxei32_v_u8mf8(const uint8_t *, vuint32mf2_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vloxei32_v_m)))
vuint8mf8_t vloxei32_v_u8mf8_m(vbool64_t, vuint8mf8_t, const uint8_t *, vuint32mf2_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vsoxseg3ei8_v)))
void vsoxseg3ei8_v_i8m1(int8_t *, vuint8m1_t, vint8m1_t, vint8m1_t, vint8m1_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vsoxseg3ei8_v_m)))
void vsoxseg3ei8_v_i8m1_m(vbool8_t, int8_t *, vuint8m1_t, vint8m1_t, vint8m1_t, vint8m1_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vsoxseg3ei8_v)))
void vsoxseg3ei8_v_i8m2(int8_t *, vuint8m2_t, vint8m2_t, vint8m2_t, vint8m2_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vsoxseg3ei8_v_m)))
void vsoxseg3ei8_v_i8m2_m(vbool4_t, int8_t *, vuint8m2_t, vint8m2_t, vint8m2_t, vint8m2_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vsoxseg3ei8_v)))
void vsoxseg3ei8_v_i8mf2(int8_t *, vuint8mf2_t, vint8mf2_t, vint8mf2_t, vint8mf2_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vsoxseg3ei8_v_m)))
void vsoxseg3ei8_v_i8mf2_m(vbool16_t, int8_t *, vuint8mf2_t, vint8mf2_t, vint8mf2_t, vint8mf2_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vsoxseg3ei8_v)))
void vsoxseg3ei8_v_i8mf4(int8_t *, vuint8mf4_t, vint8mf4_t, vint8mf4_t, vint8mf4_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vsoxseg3ei8_v_m)))
void vsoxseg3ei8_v_i8mf4_m(vbool32_t, int8_t *, vuint8mf4_t, vint8mf4_t, vint8mf4_t, vint8mf4_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vsoxseg3ei8_v)))
void vsoxseg3ei8_v_i8mf8(int8_t *, vuint8mf8_t, vint8mf8_t, vint8mf8_t, vint8mf8_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vsoxseg3ei8_v_m)))
void vsoxseg3ei8_v_i8mf8_m(vbool64_t, int8_t *, vuint8mf8_t, vint8mf8_t, vint8mf8_t, vint8mf8_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vsoxseg3ei8_v)))
void vsoxseg3ei8_v_u8m1(uint8_t *, vuint8m1_t, vuint8m1_t, vuint8m1_t, vuint8m1_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vsoxseg3ei8_v_m)))
void vsoxseg3ei8_v_u8m1_m(vbool8_t, uint8_t *, vuint8m1_t, vuint8m1_t, vuint8m1_t, vuint8m1_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vsoxseg3ei8_v)))
void vsoxseg3ei8_v_u8m2(uint8_t *, vuint8m2_t, vuint8m2_t, vuint8m2_t, vuint8m2_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vsoxseg3ei8_v_m)))
void vsoxseg3ei8_v_u8m2_m(vbool4_t, uint8_t *, vuint8m2_t, vuint8m2_t, vuint8m2_t, vuint8m2_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vsoxseg3ei8_v)))
void vsoxseg3ei8_v_u8mf2(uint8_t *, vuint8mf2_t, vuint8mf2_t, vuint8mf2_t, vuint8mf2_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vsoxseg3ei8_v_m)))
void vsoxseg3ei8_v_u8mf2_m(vbool16_t, uint8_t *, vuint8mf2_t, vuint8mf2_t, vuint8mf2_t, vuint8mf2_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vsoxseg3ei8_v)))
void vsoxseg3ei8_v_u8mf4(uint8_t *, vuint8mf4_t, vuint8mf4_t, vuint8mf4_t, vuint8mf4_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vsoxseg3ei8_v_m)))
void vsoxseg3ei8_v_u8mf4_m(vbool32_t, uint8_t *, vuint8mf4_t, vuint8mf4_t, vuint8mf4_t, vuint8mf4_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vsoxseg3ei8_v)))
void vsoxseg3ei8_v_u8mf8(uint8_t *, vuint8mf8_t, vuint8mf8_t, vuint8mf8_t, vuint8mf8_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vsoxseg3ei8_v_m)))
void vsoxseg3ei8_v_u8mf8_m(vbool64_t, uint8_t *, vuint8mf8_t, vuint8mf8_t, vuint8mf8_t, vuint8mf8_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vsoxseg4ei8_v)))
void vsoxseg4ei8_v_i8m1(int8_t *, vuint8m1_t, vint8m1_t, vint8m1_t, vint8m1_t, vint8m1_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vsoxseg4ei8_v_m)))
void vsoxseg4ei8_v_i8m1_m(vbool8_t, int8_t *, vuint8m1_t, vint8m1_t, vint8m1_t, vint8m1_t, vint8m1_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vsoxseg4ei8_v)))
void vsoxseg4ei8_v_i8m2(int8_t *, vuint8m2_t, vint8m2_t, vint8m2_t, vint8m2_t, vint8m2_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vsoxseg4ei8_v_m)))
void vsoxseg4ei8_v_i8m2_m(vbool4_t, int8_t *, vuint8m2_t, vint8m2_t, vint8m2_t, vint8m2_t, vint8m2_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vsoxseg4ei8_v)))
void vsoxseg4ei8_v_i8mf2(int8_t *, vuint8mf2_t, vint8mf2_t, vint8mf2_t, vint8mf2_t, vint8mf2_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vsoxseg4ei8_v_m)))
void vsoxseg4ei8_v_i8mf2_m(vbool16_t, int8_t *, vuint8mf2_t, vint8mf2_t, vint8mf2_t, vint8mf2_t, vint8mf2_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vsoxseg4ei8_v)))
void vsoxseg4ei8_v_i8mf4(int8_t *, vuint8mf4_t, vint8mf4_t, vint8mf4_t, vint8mf4_t, vint8mf4_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vsoxseg4ei8_v_m)))
void vsoxseg4ei8_v_i8mf4_m(vbool32_t, int8_t *, vuint8mf4_t, vint8mf4_t, vint8mf4_t, vint8mf4_t, vint8mf4_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vsoxseg4ei8_v)))
void vsoxseg4ei8_v_i8mf8(int8_t *, vuint8mf8_t, vint8mf8_t, vint8mf8_t, vint8mf8_t, vint8mf8_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vsoxseg4ei8_v_m)))
void vsoxseg4ei8_v_i8mf8_m(vbool64_t, int8_t *, vuint8mf8_t, vint8mf8_t, vint8mf8_t, vint8mf8_t, vint8mf8_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vsoxseg4ei8_v)))
void vsoxseg4ei8_v_u8m1(uint8_t *, vuint8m1_t, vuint8m1_t, vuint8m1_t, vuint8m1_t, vuint8m1_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vsoxseg4ei8_v_m)))
void vsoxseg4ei8_v_u8m1_m(vbool8_t, uint8_t *, vuint8m1_t, vuint8m1_t, vuint8m1_t, vuint8m1_t, vuint8m1_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vsoxseg4ei8_v)))
void vsoxseg4ei8_v_u8m2(uint8_t *, vuint8m2_t, vuint8m2_t, vuint8m2_t, vuint8m2_t, vuint8m2_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vsoxseg4ei8_v_m)))
void vsoxseg4ei8_v_u8m2_m(vbool4_t, uint8_t *, vuint8m2_t, vuint8m2_t, vuint8m2_t, vuint8m2_t, vuint8m2_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vsoxseg4ei8_v)))
void vsoxseg4ei8_v_u8mf2(uint8_t *, vuint8mf2_t, vuint8mf2_t, vuint8mf2_t, vuint8mf2_t, vuint8mf2_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vsoxseg4ei8_v_m)))
void vsoxseg4ei8_v_u8mf2_m(vbool16_t, uint8_t *, vuint8mf2_t, vuint8mf2_t, vuint8mf2_t, vuint8mf2_t, vuint8mf2_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vsoxseg4ei8_v)))
void vsoxseg4ei8_v_u8mf4(uint8_t *, vuint8mf4_t, vuint8mf4_t, vuint8mf4_t, vuint8mf4_t, vuint8mf4_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vsoxseg4ei8_v_m)))
void vsoxseg4ei8_v_u8mf4_m(vbool32_t, uint8_t *, vuint8mf4_t, vuint8mf4_t, vuint8mf4_t, vuint8mf4_t, vuint8mf4_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vsoxseg4ei8_v)))
void vsoxseg4ei8_v_u8mf8(uint8_t *, vuint8mf8_t, vuint8mf8_t, vuint8mf8_t, vuint8mf8_t, vuint8mf8_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vsoxseg4ei8_v_m)))
void vsoxseg4ei8_v_u8mf8_m(vbool64_t, uint8_t *, vuint8mf8_t, vuint8mf8_t, vuint8mf8_t, vuint8mf8_t, vuint8mf8_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vsoxseg5ei8_v)))
void vsoxseg5ei8_v_i8m1(int8_t *, vuint8m1_t, vint8m1_t, vint8m1_t, vint8m1_t, vint8m1_t, vint8m1_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vsoxseg5ei8_v_m)))
void vsoxseg5ei8_v_i8m1_m(vbool8_t, int8_t *, vuint8m1_t, vint8m1_t, vint8m1_t, vint8m1_t, vint8m1_t, vint8m1_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vsoxseg5ei8_v)))
void vsoxseg5ei8_v_i8mf2(int8_t *, vuint8mf2_t, vint8mf2_t, vint8mf2_t, vint8mf2_t, vint8mf2_t, vint8mf2_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vsoxseg5ei8_v_m)))
void vsoxseg5ei8_v_i8mf2_m(vbool16_t, int8_t *, vuint8mf2_t, vint8mf2_t, vint8mf2_t, vint8mf2_t, vint8mf2_t, vint8mf2_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vsoxseg5ei8_v)))
void vsoxseg5ei8_v_i8mf4(int8_t *, vuint8mf4_t, vint8mf4_t, vint8mf4_t, vint8mf4_t, vint8mf4_t, vint8mf4_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vsoxseg5ei8_v_m)))
void vsoxseg5ei8_v_i8mf4_m(vbool32_t, int8_t *, vuint8mf4_t, vint8mf4_t, vint8mf4_t, vint8mf4_t, vint8mf4_t, vint8mf4_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vsoxseg5ei8_v)))
void vsoxseg5ei8_v_i8mf8(int8_t *, vuint8mf8_t, vint8mf8_t, vint8mf8_t, vint8mf8_t, vint8mf8_t, vint8mf8_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vsoxseg5ei8_v_m)))
void vsoxseg5ei8_v_i8mf8_m(vbool64_t, int8_t *, vuint8mf8_t, vint8mf8_t, vint8mf8_t, vint8mf8_t, vint8mf8_t, vint8mf8_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vsoxseg5ei8_v)))
void vsoxseg5ei8_v_u8m1(uint8_t *, vuint8m1_t, vuint8m1_t, vuint8m1_t, vuint8m1_t, vuint8m1_t, vuint8m1_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vsoxseg5ei8_v_m)))
void vsoxseg5ei8_v_u8m1_m(vbool8_t, uint8_t *, vuint8m1_t, vuint8m1_t, vuint8m1_t, vuint8m1_t, vuint8m1_t, vuint8m1_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vsoxseg5ei8_v)))
void vsoxseg5ei8_v_u8mf2(uint8_t *, vuint8mf2_t, vuint8mf2_t, vuint8mf2_t, vuint8mf2_t, vuint8mf2_t, vuint8mf2_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vsoxseg5ei8_v_m)))
void vsoxseg5ei8_v_u8mf2_m(vbool16_t, uint8_t *, vuint8mf2_t, vuint8mf2_t, vuint8mf2_t, vuint8mf2_t, vuint8mf2_t, vuint8mf2_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vsoxseg5ei8_v)))
void vsoxseg5ei8_v_u8mf4(uint8_t *, vuint8mf4_t, vuint8mf4_t, vuint8mf4_t, vuint8mf4_t, vuint8mf4_t, vuint8mf4_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vsoxseg5ei8_v_m)))
void vsoxseg5ei8_v_u8mf4_m(vbool32_t, uint8_t *, vuint8mf4_t, vuint8mf4_t, vuint8mf4_t, vuint8mf4_t, vuint8mf4_t, vuint8mf4_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vsoxseg5ei8_v)))
void vsoxseg5ei8_v_u8mf8(uint8_t *, vuint8mf8_t, vuint8mf8_t, vuint8mf8_t, vuint8mf8_t, vuint8mf8_t, vuint8mf8_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vsoxseg5ei8_v_m)))
void vsoxseg5ei8_v_u8mf8_m(vbool64_t, uint8_t *, vuint8mf8_t, vuint8mf8_t, vuint8mf8_t, vuint8mf8_t, vuint8mf8_t, vuint8mf8_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vsoxseg6ei8_v)))
void vsoxseg6ei8_v_i8m1(int8_t *, vuint8m1_t, vint8m1_t, vint8m1_t, vint8m1_t, vint8m1_t, vint8m1_t, vint8m1_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vsoxseg6ei8_v_m)))
void vsoxseg6ei8_v_i8m1_m(vbool8_t, int8_t *, vuint8m1_t, vint8m1_t, vint8m1_t, vint8m1_t, vint8m1_t, vint8m1_t, vint8m1_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vsoxseg6ei8_v)))
void vsoxseg6ei8_v_i8mf2(int8_t *, vuint8mf2_t, vint8mf2_t, vint8mf2_t, vint8mf2_t, vint8mf2_t, vint8mf2_t, vint8mf2_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vsoxseg6ei8_v_m)))
void vsoxseg6ei8_v_i8mf2_m(vbool16_t, int8_t *, vuint8mf2_t, vint8mf2_t, vint8mf2_t, vint8mf2_t, vint8mf2_t, vint8mf2_t, vint8mf2_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vsoxseg6ei8_v)))
void vsoxseg6ei8_v_i8mf4(int8_t *, vuint8mf4_t, vint8mf4_t, vint8mf4_t, vint8mf4_t, vint8mf4_t, vint8mf4_t, vint8mf4_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vsoxseg6ei8_v_m)))
void vsoxseg6ei8_v_i8mf4_m(vbool32_t, int8_t *, vuint8mf4_t, vint8mf4_t, vint8mf4_t, vint8mf4_t, vint8mf4_t, vint8mf4_t, vint8mf4_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vsoxseg6ei8_v)))
void vsoxseg6ei8_v_i8mf8(int8_t *, vuint8mf8_t, vint8mf8_t, vint8mf8_t, vint8mf8_t, vint8mf8_t, vint8mf8_t, vint8mf8_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vsoxseg6ei8_v_m)))
void vsoxseg6ei8_v_i8mf8_m(vbool64_t, int8_t *, vuint8mf8_t, vint8mf8_t, vint8mf8_t, vint8mf8_t, vint8mf8_t, vint8mf8_t, vint8mf8_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vsoxseg6ei8_v)))
void vsoxseg6ei8_v_u8m1(uint8_t *, vuint8m1_t, vuint8m1_t, vuint8m1_t, vuint8m1_t, vuint8m1_t, vuint8m1_t, vuint8m1_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vsoxseg6ei8_v_m)))
void vsoxseg6ei8_v_u8m1_m(vbool8_t, uint8_t *, vuint8m1_t, vuint8m1_t, vuint8m1_t, vuint8m1_t, vuint8m1_t, vuint8m1_t, vuint8m1_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vsoxseg6ei8_v)))
void vsoxseg6ei8_v_u8mf2(uint8_t *, vuint8mf2_t, vuint8mf2_t, vuint8mf2_t, vuint8mf2_t, vuint8mf2_t, vuint8mf2_t, vuint8mf2_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vsoxseg6ei8_v_m)))
void vsoxseg6ei8_v_u8mf2_m(vbool16_t, uint8_t *, vuint8mf2_t, vuint8mf2_t, vuint8mf2_t, vuint8mf2_t, vuint8mf2_t, vuint8mf2_t, vuint8mf2_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vsoxseg6ei8_v)))
void vsoxseg6ei8_v_u8mf4(uint8_t *, vuint8mf4_t, vuint8mf4_t, vuint8mf4_t, vuint8mf4_t, vuint8mf4_t, vuint8mf4_t, vuint8mf4_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vsoxseg6ei8_v_m)))
void vsoxseg6ei8_v_u8mf4_m(vbool32_t, uint8_t *, vuint8mf4_t, vuint8mf4_t, vuint8mf4_t, vuint8mf4_t, vuint8mf4_t, vuint8mf4_t, vuint8mf4_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vsoxseg6ei8_v)))
void vsoxseg6ei8_v_u8mf8(uint8_t *, vuint8mf8_t, vuint8mf8_t, vuint8mf8_t, vuint8mf8_t, vuint8mf8_t, vuint8mf8_t, vuint8mf8_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vsoxseg6ei8_v_m)))
void vsoxseg6ei8_v_u8mf8_m(vbool64_t, uint8_t *, vuint8mf8_t, vuint8mf8_t, vuint8mf8_t, vuint8mf8_t, vuint8mf8_t, vuint8mf8_t, vuint8mf8_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vsoxseg7ei8_v)))
void vsoxseg7ei8_v_i8m1(int8_t *, vuint8m1_t, vint8m1_t, vint8m1_t, vint8m1_t, vint8m1_t, vint8m1_t, vint8m1_t, vint8m1_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vsoxseg7ei8_v_m)))
void vsoxseg7ei8_v_i8m1_m(vbool8_t, int8_t *, vuint8m1_t, vint8m1_t, vint8m1_t, vint8m1_t, vint8m1_t, vint8m1_t, vint8m1_t, vint8m1_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vsoxseg7ei8_v)))
void vsoxseg7ei8_v_i8mf2(int8_t *, vuint8mf2_t, vint8mf2_t, vint8mf2_t, vint8mf2_t, vint8mf2_t, vint8mf2_t, vint8mf2_t, vint8mf2_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vsoxseg7ei8_v_m)))
void vsoxseg7ei8_v_i8mf2_m(vbool16_t, int8_t *, vuint8mf2_t, vint8mf2_t, vint8mf2_t, vint8mf2_t, vint8mf2_t, vint8mf2_t, vint8mf2_t, vint8mf2_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vsoxseg7ei8_v)))
void vsoxseg7ei8_v_i8mf4(int8_t *, vuint8mf4_t, vint8mf4_t, vint8mf4_t, vint8mf4_t, vint8mf4_t, vint8mf4_t, vint8mf4_t, vint8mf4_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vsoxseg7ei8_v_m)))
void vsoxseg7ei8_v_i8mf4_m(vbool32_t, int8_t *, vuint8mf4_t, vint8mf4_t, vint8mf4_t, vint8mf4_t, vint8mf4_t, vint8mf4_t, vint8mf4_t, vint8mf4_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vsoxseg7ei8_v)))
void vsoxseg7ei8_v_i8mf8(int8_t *, vuint8mf8_t, vint8mf8_t, vint8mf8_t, vint8mf8_t, vint8mf8_t, vint8mf8_t, vint8mf8_t, vint8mf8_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vsoxseg7ei8_v_m)))
void vsoxseg7ei8_v_i8mf8_m(vbool64_t, int8_t *, vuint8mf8_t, vint8mf8_t, vint8mf8_t, vint8mf8_t, vint8mf8_t, vint8mf8_t, vint8mf8_t, vint8mf8_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vsoxseg7ei8_v)))
void vsoxseg7ei8_v_u8m1(uint8_t *, vuint8m1_t, vuint8m1_t, vuint8m1_t, vuint8m1_t, vuint8m1_t, vuint8m1_t, vuint8m1_t, vuint8m1_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vsoxseg7ei8_v_m)))
void vsoxseg7ei8_v_u8m1_m(vbool8_t, uint8_t *, vuint8m1_t, vuint8m1_t, vuint8m1_t, vuint8m1_t, vuint8m1_t, vuint8m1_t, vuint8m1_t, vuint8m1_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vsoxseg7ei8_v)))
void vsoxseg7ei8_v_u8mf2(uint8_t *, vuint8mf2_t, vuint8mf2_t, vuint8mf2_t, vuint8mf2_t, vuint8mf2_t, vuint8mf2_t, vuint8mf2_t, vuint8mf2_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vsoxseg7ei8_v_m)))
void vsoxseg7ei8_v_u8mf2_m(vbool16_t, uint8_t *, vuint8mf2_t, vuint8mf2_t, vuint8mf2_t, vuint8mf2_t, vuint8mf2_t, vuint8mf2_t, vuint8mf2_t, vuint8mf2_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vsoxseg7ei8_v)))
void vsoxseg7ei8_v_u8mf4(uint8_t *, vuint8mf4_t, vuint8mf4_t, vuint8mf4_t, vuint8mf4_t, vuint8mf4_t, vuint8mf4_t, vuint8mf4_t, vuint8mf4_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vsoxseg7ei8_v_m)))
void vsoxseg7ei8_v_u8mf4_m(vbool32_t, uint8_t *, vuint8mf4_t, vuint8mf4_t, vuint8mf4_t, vuint8mf4_t, vuint8mf4_t, vuint8mf4_t, vuint8mf4_t, vuint8mf4_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vsoxseg7ei8_v)))
void vsoxseg7ei8_v_u8mf8(uint8_t *, vuint8mf8_t, vuint8mf8_t, vuint8mf8_t, vuint8mf8_t, vuint8mf8_t, vuint8mf8_t, vuint8mf8_t, vuint8mf8_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vsoxseg7ei8_v_m)))
void vsoxseg7ei8_v_u8mf8_m(vbool64_t, uint8_t *, vuint8mf8_t, vuint8mf8_t, vuint8mf8_t, vuint8mf8_t, vuint8mf8_t, vuint8mf8_t, vuint8mf8_t, vuint8mf8_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vsoxseg8ei8_v)))
void vsoxseg8ei8_v_i8m1(int8_t *, vuint8m1_t, vint8m1_t, vint8m1_t, vint8m1_t, vint8m1_t, vint8m1_t, vint8m1_t, vint8m1_t, vint8m1_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vsoxseg8ei8_v_m)))
void vsoxseg8ei8_v_i8m1_m(vbool8_t, int8_t *, vuint8m1_t, vint8m1_t, vint8m1_t, vint8m1_t, vint8m1_t, vint8m1_t, vint8m1_t, vint8m1_t, vint8m1_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vsoxseg8ei8_v)))
void vsoxseg8ei8_v_i8mf2(int8_t *, vuint8mf2_t, vint8mf2_t, vint8mf2_t, vint8mf2_t, vint8mf2_t, vint8mf2_t, vint8mf2_t, vint8mf2_t, vint8mf2_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vsoxseg8ei8_v_m)))
void vsoxseg8ei8_v_i8mf2_m(vbool16_t, int8_t *, vuint8mf2_t, vint8mf2_t, vint8mf2_t, vint8mf2_t, vint8mf2_t, vint8mf2_t, vint8mf2_t, vint8mf2_t, vint8mf2_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vsoxseg8ei8_v)))
void vsoxseg8ei8_v_i8mf4(int8_t *, vuint8mf4_t, vint8mf4_t, vint8mf4_t, vint8mf4_t, vint8mf4_t, vint8mf4_t, vint8mf4_t, vint8mf4_t, vint8mf4_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vsoxseg8ei8_v_m)))
void vsoxseg8ei8_v_i8mf4_m(vbool32_t, int8_t *, vuint8mf4_t, vint8mf4_t, vint8mf4_t, vint8mf4_t, vint8mf4_t, vint8mf4_t, vint8mf4_t, vint8mf4_t, vint8mf4_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vsoxseg8ei8_v)))
void vsoxseg8ei8_v_i8mf8(int8_t *, vuint8mf8_t, vint8mf8_t, vint8mf8_t, vint8mf8_t, vint8mf8_t, vint8mf8_t, vint8mf8_t, vint8mf8_t, vint8mf8_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vsoxseg8ei8_v_m)))
void vsoxseg8ei8_v_i8mf8_m(vbool64_t, int8_t *, vuint8mf8_t, vint8mf8_t, vint8mf8_t, vint8mf8_t, vint8mf8_t, vint8mf8_t, vint8mf8_t, vint8mf8_t, vint8mf8_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vsoxseg8ei8_v)))
void vsoxseg8ei8_v_u8m1(uint8_t *, vuint8m1_t, vuint8m1_t, vuint8m1_t, vuint8m1_t, vuint8m1_t, vuint8m1_t, vuint8m1_t, vuint8m1_t, vuint8m1_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vsoxseg8ei8_v_m)))
void vsoxseg8ei8_v_u8m1_m(vbool8_t, uint8_t *, vuint8m1_t, vuint8m1_t, vuint8m1_t, vuint8m1_t, vuint8m1_t, vuint8m1_t, vuint8m1_t, vuint8m1_t, vuint8m1_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vsoxseg8ei8_v)))
void vsoxseg8ei8_v_u8mf2(uint8_t *, vuint8mf2_t, vuint8mf2_t, vuint8mf2_t, vuint8mf2_t, vuint8mf2_t, vuint8mf2_t, vuint8mf2_t, vuint8mf2_t, vuint8mf2_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vsoxseg8ei8_v_m)))
void vsoxseg8ei8_v_u8mf2_m(vbool16_t, uint8_t *, vuint8mf2_t, vuint8mf2_t, vuint8mf2_t, vuint8mf2_t, vuint8mf2_t, vuint8mf2_t, vuint8mf2_t, vuint8mf2_t, vuint8mf2_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vsoxseg8ei8_v)))
void vsoxseg8ei8_v_u8mf4(uint8_t *, vuint8mf4_t, vuint8mf4_t, vuint8mf4_t, vuint8mf4_t, vuint8mf4_t, vuint8mf4_t, vuint8mf4_t, vuint8mf4_t, vuint8mf4_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vsoxseg8ei8_v_m)))
void vsoxseg8ei8_v_u8mf4_m(vbool32_t, uint8_t *, vuint8mf4_t, vuint8mf4_t, vuint8mf4_t, vuint8mf4_t, vuint8mf4_t, vuint8mf4_t, vuint8mf4_t, vuint8mf4_t, vuint8mf4_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vsoxseg8ei8_v)))
void vsoxseg8ei8_v_u8mf8(uint8_t *, vuint8mf8_t, vuint8mf8_t, vuint8mf8_t, vuint8mf8_t, vuint8mf8_t, vuint8mf8_t, vuint8mf8_t, vuint8mf8_t, vuint8mf8_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vsoxseg8ei8_v_m)))
void vsoxseg8ei8_v_u8mf8_m(vbool64_t, uint8_t *, vuint8mf8_t, vuint8mf8_t, vuint8mf8_t, vuint8mf8_t, vuint8mf8_t, vuint8mf8_t, vuint8mf8_t, vuint8mf8_t, vuint8mf8_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vsoxseg2ei16_v)))
void vsoxseg2ei16_v_i8m1(int8_t *, vuint16m2_t, vint8m1_t, vint8m1_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vsoxseg2ei16_v_m)))
void vsoxseg2ei16_v_i8m1_m(vbool8_t, int8_t *, vuint16m2_t, vint8m1_t, vint8m1_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vsoxseg2ei16_v)))
void vsoxseg2ei16_v_i8m2(int8_t *, vuint16m4_t, vint8m2_t, vint8m2_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vsoxseg2ei16_v_m)))
void vsoxseg2ei16_v_i8m2_m(vbool4_t, int8_t *, vuint16m4_t, vint8m2_t, vint8m2_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vsoxseg2ei16_v)))
void vsoxseg2ei16_v_i8m4(int8_t *, vuint16m8_t, vint8m4_t, vint8m4_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vsoxseg2ei16_v_m)))
void vsoxseg2ei16_v_i8m4_m(vbool2_t, int8_t *, vuint16m8_t, vint8m4_t, vint8m4_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vsoxseg2ei16_v)))
void vsoxseg2ei16_v_i8mf2(int8_t *, vuint16m1_t, vint8mf2_t, vint8mf2_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vsoxseg2ei16_v_m)))
void vsoxseg2ei16_v_i8mf2_m(vbool16_t, int8_t *, vuint16m1_t, vint8mf2_t, vint8mf2_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vsoxseg2ei16_v)))
void vsoxseg2ei16_v_i8mf4(int8_t *, vuint16mf2_t, vint8mf4_t, vint8mf4_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vsoxseg2ei16_v_m)))
void vsoxseg2ei16_v_i8mf4_m(vbool32_t, int8_t *, vuint16mf2_t, vint8mf4_t, vint8mf4_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vsoxseg2ei16_v)))
void vsoxseg2ei16_v_i8mf8(int8_t *, vuint16mf4_t, vint8mf8_t, vint8mf8_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vsoxseg2ei16_v_m)))
void vsoxseg2ei16_v_i8mf8_m(vbool64_t, int8_t *, vuint16mf4_t, vint8mf8_t, vint8mf8_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vsoxseg2ei16_v)))
void vsoxseg2ei16_v_u8m1(uint8_t *, vuint16m2_t, vuint8m1_t, vuint8m1_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vsoxseg2ei16_v_m)))
void vsoxseg2ei16_v_u8m1_m(vbool8_t, uint8_t *, vuint16m2_t, vuint8m1_t, vuint8m1_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vsoxseg2ei16_v)))
void vsoxseg2ei16_v_u8m2(uint8_t *, vuint16m4_t, vuint8m2_t, vuint8m2_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vsoxseg2ei16_v_m)))
void vsoxseg2ei16_v_u8m2_m(vbool4_t, uint8_t *, vuint16m4_t, vuint8m2_t, vuint8m2_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vsoxseg2ei16_v)))
void vsoxseg2ei16_v_u8m4(uint8_t *, vuint16m8_t, vuint8m4_t, vuint8m4_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vsoxseg2ei16_v_m)))
void vsoxseg2ei16_v_u8m4_m(vbool2_t, uint8_t *, vuint16m8_t, vuint8m4_t, vuint8m4_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vsoxseg2ei16_v)))
void vsoxseg2ei16_v_u8mf2(uint8_t *, vuint16m1_t, vuint8mf2_t, vuint8mf2_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vsoxseg2ei16_v_m)))
void vsoxseg2ei16_v_u8mf2_m(vbool16_t, uint8_t *, vuint16m1_t, vuint8mf2_t, vuint8mf2_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vsoxseg2ei16_v)))
void vsoxseg2ei16_v_u8mf4(uint8_t *, vuint16mf2_t, vuint8mf4_t, vuint8mf4_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vsoxseg2ei16_v_m)))
void vsoxseg2ei16_v_u8mf4_m(vbool32_t, uint8_t *, vuint16mf2_t, vuint8mf4_t, vuint8mf4_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vsoxseg2ei16_v)))
void vsoxseg2ei16_v_u8mf8(uint8_t *, vuint16mf4_t, vuint8mf8_t, vuint8mf8_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vsoxseg2ei16_v_m)))
void vsoxseg2ei16_v_u8mf8_m(vbool64_t, uint8_t *, vuint16mf4_t, vuint8mf8_t, vuint8mf8_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vsoxseg3ei16_v)))
void vsoxseg3ei16_v_i8m1(int8_t *, vuint16m2_t, vint8m1_t, vint8m1_t, vint8m1_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vsoxseg3ei16_v_m)))
void vsoxseg3ei16_v_i8m1_m(vbool8_t, int8_t *, vuint16m2_t, vint8m1_t, vint8m1_t, vint8m1_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vsoxseg3ei16_v)))
void vsoxseg3ei16_v_i8m2(int8_t *, vuint16m4_t, vint8m2_t, vint8m2_t, vint8m2_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vsoxseg3ei16_v_m)))
void vsoxseg3ei16_v_i8m2_m(vbool4_t, int8_t *, vuint16m4_t, vint8m2_t, vint8m2_t, vint8m2_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vsoxseg3ei16_v)))
void vsoxseg3ei16_v_i8mf2(int8_t *, vuint16m1_t, vint8mf2_t, vint8mf2_t, vint8mf2_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vsoxseg3ei16_v_m)))
void vsoxseg3ei16_v_i8mf2_m(vbool16_t, int8_t *, vuint16m1_t, vint8mf2_t, vint8mf2_t, vint8mf2_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vsoxseg3ei16_v)))
void vsoxseg3ei16_v_i8mf4(int8_t *, vuint16mf2_t, vint8mf4_t, vint8mf4_t, vint8mf4_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vsoxseg3ei16_v_m)))
void vsoxseg3ei16_v_i8mf4_m(vbool32_t, int8_t *, vuint16mf2_t, vint8mf4_t, vint8mf4_t, vint8mf4_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vsoxseg3ei16_v)))
void vsoxseg3ei16_v_i8mf8(int8_t *, vuint16mf4_t, vint8mf8_t, vint8mf8_t, vint8mf8_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vsoxseg3ei16_v_m)))
void vsoxseg3ei16_v_i8mf8_m(vbool64_t, int8_t *, vuint16mf4_t, vint8mf8_t, vint8mf8_t, vint8mf8_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vsoxseg3ei16_v)))
void vsoxseg3ei16_v_u8m1(uint8_t *, vuint16m2_t, vuint8m1_t, vuint8m1_t, vuint8m1_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vsoxseg3ei16_v_m)))
void vsoxseg3ei16_v_u8m1_m(vbool8_t, uint8_t *, vuint16m2_t, vuint8m1_t, vuint8m1_t, vuint8m1_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vsoxseg3ei16_v)))
void vsoxseg3ei16_v_u8m2(uint8_t *, vuint16m4_t, vuint8m2_t, vuint8m2_t, vuint8m2_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vsoxseg3ei16_v_m)))
void vsoxseg3ei16_v_u8m2_m(vbool4_t, uint8_t *, vuint16m4_t, vuint8m2_t, vuint8m2_t, vuint8m2_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vsoxseg3ei16_v)))
void vsoxseg3ei16_v_u8mf2(uint8_t *, vuint16m1_t, vuint8mf2_t, vuint8mf2_t, vuint8mf2_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vsoxseg3ei16_v_m)))
void vsoxseg3ei16_v_u8mf2_m(vbool16_t, uint8_t *, vuint16m1_t, vuint8mf2_t, vuint8mf2_t, vuint8mf2_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vsoxseg3ei16_v)))
void vsoxseg3ei16_v_u8mf4(uint8_t *, vuint16mf2_t, vuint8mf4_t, vuint8mf4_t, vuint8mf4_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vsoxseg3ei16_v_m)))
void vsoxseg3ei16_v_u8mf4_m(vbool32_t, uint8_t *, vuint16mf2_t, vuint8mf4_t, vuint8mf4_t, vuint8mf4_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vsoxseg3ei16_v)))
void vsoxseg3ei16_v_u8mf8(uint8_t *, vuint16mf4_t, vuint8mf8_t, vuint8mf8_t, vuint8mf8_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vsoxseg3ei16_v_m)))
void vsoxseg3ei16_v_u8mf8_m(vbool64_t, uint8_t *, vuint16mf4_t, vuint8mf8_t, vuint8mf8_t, vuint8mf8_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vsoxseg4ei16_v)))
void vsoxseg4ei16_v_i8m1(int8_t *, vuint16m2_t, vint8m1_t, vint8m1_t, vint8m1_t, vint8m1_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vsoxseg4ei16_v_m)))
void vsoxseg4ei16_v_i8m1_m(vbool8_t, int8_t *, vuint16m2_t, vint8m1_t, vint8m1_t, vint8m1_t, vint8m1_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vsoxseg4ei16_v)))
void vsoxseg4ei16_v_i8m2(int8_t *, vuint16m4_t, vint8m2_t, vint8m2_t, vint8m2_t, vint8m2_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vsoxseg4ei16_v_m)))
void vsoxseg4ei16_v_i8m2_m(vbool4_t, int8_t *, vuint16m4_t, vint8m2_t, vint8m2_t, vint8m2_t, vint8m2_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vsoxseg4ei16_v)))
void vsoxseg4ei16_v_i8mf2(int8_t *, vuint16m1_t, vint8mf2_t, vint8mf2_t, vint8mf2_t, vint8mf2_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vsoxseg4ei16_v_m)))
void vsoxseg4ei16_v_i8mf2_m(vbool16_t, int8_t *, vuint16m1_t, vint8mf2_t, vint8mf2_t, vint8mf2_t, vint8mf2_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vsoxseg4ei16_v)))
void vsoxseg4ei16_v_i8mf4(int8_t *, vuint16mf2_t, vint8mf4_t, vint8mf4_t, vint8mf4_t, vint8mf4_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vsoxseg4ei16_v_m)))
void vsoxseg4ei16_v_i8mf4_m(vbool32_t, int8_t *, vuint16mf2_t, vint8mf4_t, vint8mf4_t, vint8mf4_t, vint8mf4_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vsoxseg4ei16_v)))
void vsoxseg4ei16_v_i8mf8(int8_t *, vuint16mf4_t, vint8mf8_t, vint8mf8_t, vint8mf8_t, vint8mf8_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vsoxseg4ei16_v_m)))
void vsoxseg4ei16_v_i8mf8_m(vbool64_t, int8_t *, vuint16mf4_t, vint8mf8_t, vint8mf8_t, vint8mf8_t, vint8mf8_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vsoxseg4ei16_v)))
void vsoxseg4ei16_v_u8m1(uint8_t *, vuint16m2_t, vuint8m1_t, vuint8m1_t, vuint8m1_t, vuint8m1_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vsoxseg4ei16_v_m)))
void vsoxseg4ei16_v_u8m1_m(vbool8_t, uint8_t *, vuint16m2_t, vuint8m1_t, vuint8m1_t, vuint8m1_t, vuint8m1_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vsoxseg4ei16_v)))
void vsoxseg4ei16_v_u8m2(uint8_t *, vuint16m4_t, vuint8m2_t, vuint8m2_t, vuint8m2_t, vuint8m2_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vsoxseg4ei16_v_m)))
void vsoxseg4ei16_v_u8m2_m(vbool4_t, uint8_t *, vuint16m4_t, vuint8m2_t, vuint8m2_t, vuint8m2_t, vuint8m2_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vsoxseg4ei16_v)))
void vsoxseg4ei16_v_u8mf2(uint8_t *, vuint16m1_t, vuint8mf2_t, vuint8mf2_t, vuint8mf2_t, vuint8mf2_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vsoxseg4ei16_v_m)))
void vsoxseg4ei16_v_u8mf2_m(vbool16_t, uint8_t *, vuint16m1_t, vuint8mf2_t, vuint8mf2_t, vuint8mf2_t, vuint8mf2_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vsoxseg4ei16_v)))
void vsoxseg4ei16_v_u8mf4(uint8_t *, vuint16mf2_t, vuint8mf4_t, vuint8mf4_t, vuint8mf4_t, vuint8mf4_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vsoxseg4ei16_v_m)))
void vsoxseg4ei16_v_u8mf4_m(vbool32_t, uint8_t *, vuint16mf2_t, vuint8mf4_t, vuint8mf4_t, vuint8mf4_t, vuint8mf4_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vsoxseg4ei16_v)))
void vsoxseg4ei16_v_u8mf8(uint8_t *, vuint16mf4_t, vuint8mf8_t, vuint8mf8_t, vuint8mf8_t, vuint8mf8_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vsoxseg4ei16_v_m)))
void vsoxseg4ei16_v_u8mf8_m(vbool64_t, uint8_t *, vuint16mf4_t, vuint8mf8_t, vuint8mf8_t, vuint8mf8_t, vuint8mf8_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vsoxseg5ei16_v)))
void vsoxseg5ei16_v_i8m1(int8_t *, vuint16m2_t, vint8m1_t, vint8m1_t, vint8m1_t, vint8m1_t, vint8m1_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vsoxseg5ei16_v_m)))
void vsoxseg5ei16_v_i8m1_m(vbool8_t, int8_t *, vuint16m2_t, vint8m1_t, vint8m1_t, vint8m1_t, vint8m1_t, vint8m1_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vsoxseg5ei16_v)))
void vsoxseg5ei16_v_i8mf2(int8_t *, vuint16m1_t, vint8mf2_t, vint8mf2_t, vint8mf2_t, vint8mf2_t, vint8mf2_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vsoxseg5ei16_v_m)))
void vsoxseg5ei16_v_i8mf2_m(vbool16_t, int8_t *, vuint16m1_t, vint8mf2_t, vint8mf2_t, vint8mf2_t, vint8mf2_t, vint8mf2_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vsoxseg5ei16_v)))
void vsoxseg5ei16_v_i8mf4(int8_t *, vuint16mf2_t, vint8mf4_t, vint8mf4_t, vint8mf4_t, vint8mf4_t, vint8mf4_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vsoxseg5ei16_v_m)))
void vsoxseg5ei16_v_i8mf4_m(vbool32_t, int8_t *, vuint16mf2_t, vint8mf4_t, vint8mf4_t, vint8mf4_t, vint8mf4_t, vint8mf4_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vsoxseg5ei16_v)))
void vsoxseg5ei16_v_i8mf8(int8_t *, vuint16mf4_t, vint8mf8_t, vint8mf8_t, vint8mf8_t, vint8mf8_t, vint8mf8_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vsoxseg5ei16_v_m)))
void vsoxseg5ei16_v_i8mf8_m(vbool64_t, int8_t *, vuint16mf4_t, vint8mf8_t, vint8mf8_t, vint8mf8_t, vint8mf8_t, vint8mf8_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vsoxseg5ei16_v)))
void vsoxseg5ei16_v_u8m1(uint8_t *, vuint16m2_t, vuint8m1_t, vuint8m1_t, vuint8m1_t, vuint8m1_t, vuint8m1_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vsoxseg5ei16_v_m)))
void vsoxseg5ei16_v_u8m1_m(vbool8_t, uint8_t *, vuint16m2_t, vuint8m1_t, vuint8m1_t, vuint8m1_t, vuint8m1_t, vuint8m1_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vsoxseg5ei16_v)))
void vsoxseg5ei16_v_u8mf2(uint8_t *, vuint16m1_t, vuint8mf2_t, vuint8mf2_t, vuint8mf2_t, vuint8mf2_t, vuint8mf2_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vsoxseg5ei16_v_m)))
void vsoxseg5ei16_v_u8mf2_m(vbool16_t, uint8_t *, vuint16m1_t, vuint8mf2_t, vuint8mf2_t, vuint8mf2_t, vuint8mf2_t, vuint8mf2_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vsoxseg5ei16_v)))
void vsoxseg5ei16_v_u8mf4(uint8_t *, vuint16mf2_t, vuint8mf4_t, vuint8mf4_t, vuint8mf4_t, vuint8mf4_t, vuint8mf4_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vsoxseg5ei16_v_m)))
void vsoxseg5ei16_v_u8mf4_m(vbool32_t, uint8_t *, vuint16mf2_t, vuint8mf4_t, vuint8mf4_t, vuint8mf4_t, vuint8mf4_t, vuint8mf4_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vsoxseg5ei16_v)))
void vsoxseg5ei16_v_u8mf8(uint8_t *, vuint16mf4_t, vuint8mf8_t, vuint8mf8_t, vuint8mf8_t, vuint8mf8_t, vuint8mf8_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vsoxseg5ei16_v_m)))
void vsoxseg5ei16_v_u8mf8_m(vbool64_t, uint8_t *, vuint16mf4_t, vuint8mf8_t, vuint8mf8_t, vuint8mf8_t, vuint8mf8_t, vuint8mf8_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vsoxseg6ei16_v)))
void vsoxseg6ei16_v_i8m1(int8_t *, vuint16m2_t, vint8m1_t, vint8m1_t, vint8m1_t, vint8m1_t, vint8m1_t, vint8m1_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vsoxseg6ei16_v_m)))
void vsoxseg6ei16_v_i8m1_m(vbool8_t, int8_t *, vuint16m2_t, vint8m1_t, vint8m1_t, vint8m1_t, vint8m1_t, vint8m1_t, vint8m1_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vsoxseg6ei16_v)))
void vsoxseg6ei16_v_i8mf2(int8_t *, vuint16m1_t, vint8mf2_t, vint8mf2_t, vint8mf2_t, vint8mf2_t, vint8mf2_t, vint8mf2_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vsoxseg6ei16_v_m)))
void vsoxseg6ei16_v_i8mf2_m(vbool16_t, int8_t *, vuint16m1_t, vint8mf2_t, vint8mf2_t, vint8mf2_t, vint8mf2_t, vint8mf2_t, vint8mf2_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vsoxseg6ei16_v)))
void vsoxseg6ei16_v_i8mf4(int8_t *, vuint16mf2_t, vint8mf4_t, vint8mf4_t, vint8mf4_t, vint8mf4_t, vint8mf4_t, vint8mf4_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vsoxseg6ei16_v_m)))
void vsoxseg6ei16_v_i8mf4_m(vbool32_t, int8_t *, vuint16mf2_t, vint8mf4_t, vint8mf4_t, vint8mf4_t, vint8mf4_t, vint8mf4_t, vint8mf4_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vsoxseg6ei16_v)))
void vsoxseg6ei16_v_i8mf8(int8_t *, vuint16mf4_t, vint8mf8_t, vint8mf8_t, vint8mf8_t, vint8mf8_t, vint8mf8_t, vint8mf8_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vsoxseg6ei16_v_m)))
void vsoxseg6ei16_v_i8mf8_m(vbool64_t, int8_t *, vuint16mf4_t, vint8mf8_t, vint8mf8_t, vint8mf8_t, vint8mf8_t, vint8mf8_t, vint8mf8_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vsoxseg6ei16_v)))
void vsoxseg6ei16_v_u8m1(uint8_t *, vuint16m2_t, vuint8m1_t, vuint8m1_t, vuint8m1_t, vuint8m1_t, vuint8m1_t, vuint8m1_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vsoxseg6ei16_v_m)))
void vsoxseg6ei16_v_u8m1_m(vbool8_t, uint8_t *, vuint16m2_t, vuint8m1_t, vuint8m1_t, vuint8m1_t, vuint8m1_t, vuint8m1_t, vuint8m1_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vsoxseg6ei16_v)))
void vsoxseg6ei16_v_u8mf2(uint8_t *, vuint16m1_t, vuint8mf2_t, vuint8mf2_t, vuint8mf2_t, vuint8mf2_t, vuint8mf2_t, vuint8mf2_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vsoxseg6ei16_v_m)))
void vsoxseg6ei16_v_u8mf2_m(vbool16_t, uint8_t *, vuint16m1_t, vuint8mf2_t, vuint8mf2_t, vuint8mf2_t, vuint8mf2_t, vuint8mf2_t, vuint8mf2_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vsoxseg6ei16_v)))
void vsoxseg6ei16_v_u8mf4(uint8_t *, vuint16mf2_t, vuint8mf4_t, vuint8mf4_t, vuint8mf4_t, vuint8mf4_t, vuint8mf4_t, vuint8mf4_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vsoxseg6ei16_v_m)))
void vsoxseg6ei16_v_u8mf4_m(vbool32_t, uint8_t *, vuint16mf2_t, vuint8mf4_t, vuint8mf4_t, vuint8mf4_t, vuint8mf4_t, vuint8mf4_t, vuint8mf4_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vsoxseg6ei16_v)))
void vsoxseg6ei16_v_u8mf8(uint8_t *, vuint16mf4_t, vuint8mf8_t, vuint8mf8_t, vuint8mf8_t, vuint8mf8_t, vuint8mf8_t, vuint8mf8_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vsoxseg6ei16_v_m)))
void vsoxseg6ei16_v_u8mf8_m(vbool64_t, uint8_t *, vuint16mf4_t, vuint8mf8_t, vuint8mf8_t, vuint8mf8_t, vuint8mf8_t, vuint8mf8_t, vuint8mf8_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vsoxseg7ei16_v)))
void vsoxseg7ei16_v_i8m1(int8_t *, vuint16m2_t, vint8m1_t, vint8m1_t, vint8m1_t, vint8m1_t, vint8m1_t, vint8m1_t, vint8m1_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vsoxseg7ei16_v_m)))
void vsoxseg7ei16_v_i8m1_m(vbool8_t, int8_t *, vuint16m2_t, vint8m1_t, vint8m1_t, vint8m1_t, vint8m1_t, vint8m1_t, vint8m1_t, vint8m1_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vsoxseg7ei16_v)))
void vsoxseg7ei16_v_i8mf2(int8_t *, vuint16m1_t, vint8mf2_t, vint8mf2_t, vint8mf2_t, vint8mf2_t, vint8mf2_t, vint8mf2_t, vint8mf2_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vsoxseg7ei16_v_m)))
void vsoxseg7ei16_v_i8mf2_m(vbool16_t, int8_t *, vuint16m1_t, vint8mf2_t, vint8mf2_t, vint8mf2_t, vint8mf2_t, vint8mf2_t, vint8mf2_t, vint8mf2_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vsoxseg7ei16_v)))
void vsoxseg7ei16_v_i8mf4(int8_t *, vuint16mf2_t, vint8mf4_t, vint8mf4_t, vint8mf4_t, vint8mf4_t, vint8mf4_t, vint8mf4_t, vint8mf4_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vsoxseg7ei16_v_m)))
void vsoxseg7ei16_v_i8mf4_m(vbool32_t, int8_t *, vuint16mf2_t, vint8mf4_t, vint8mf4_t, vint8mf4_t, vint8mf4_t, vint8mf4_t, vint8mf4_t, vint8mf4_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vsoxseg7ei16_v)))
void vsoxseg7ei16_v_i8mf8(int8_t *, vuint16mf4_t, vint8mf8_t, vint8mf8_t, vint8mf8_t, vint8mf8_t, vint8mf8_t, vint8mf8_t, vint8mf8_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vsoxseg7ei16_v_m)))
void vsoxseg7ei16_v_i8mf8_m(vbool64_t, int8_t *, vuint16mf4_t, vint8mf8_t, vint8mf8_t, vint8mf8_t, vint8mf8_t, vint8mf8_t, vint8mf8_t, vint8mf8_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vsoxseg7ei16_v)))
void vsoxseg7ei16_v_u8m1(uint8_t *, vuint16m2_t, vuint8m1_t, vuint8m1_t, vuint8m1_t, vuint8m1_t, vuint8m1_t, vuint8m1_t, vuint8m1_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vsoxseg7ei16_v_m)))
void vsoxseg7ei16_v_u8m1_m(vbool8_t, uint8_t *, vuint16m2_t, vuint8m1_t, vuint8m1_t, vuint8m1_t, vuint8m1_t, vuint8m1_t, vuint8m1_t, vuint8m1_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vsoxseg7ei16_v)))
void vsoxseg7ei16_v_u8mf2(uint8_t *, vuint16m1_t, vuint8mf2_t, vuint8mf2_t, vuint8mf2_t, vuint8mf2_t, vuint8mf2_t, vuint8mf2_t, vuint8mf2_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vsoxseg7ei16_v_m)))
void vsoxseg7ei16_v_u8mf2_m(vbool16_t, uint8_t *, vuint16m1_t, vuint8mf2_t, vuint8mf2_t, vuint8mf2_t, vuint8mf2_t, vuint8mf2_t, vuint8mf2_t, vuint8mf2_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vsoxseg7ei16_v)))
void vsoxseg7ei16_v_u8mf4(uint8_t *, vuint16mf2_t, vuint8mf4_t, vuint8mf4_t, vuint8mf4_t, vuint8mf4_t, vuint8mf4_t, vuint8mf4_t, vuint8mf4_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vsoxseg7ei16_v_m)))
void vsoxseg7ei16_v_u8mf4_m(vbool32_t, uint8_t *, vuint16mf2_t, vuint8mf4_t, vuint8mf4_t, vuint8mf4_t, vuint8mf4_t, vuint8mf4_t, vuint8mf4_t, vuint8mf4_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vsoxseg7ei16_v)))
void vsoxseg7ei16_v_u8mf8(uint8_t *, vuint16mf4_t, vuint8mf8_t, vuint8mf8_t, vuint8mf8_t, vuint8mf8_t, vuint8mf8_t, vuint8mf8_t, vuint8mf8_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vsoxseg7ei16_v_m)))
void vsoxseg7ei16_v_u8mf8_m(vbool64_t, uint8_t *, vuint16mf4_t, vuint8mf8_t, vuint8mf8_t, vuint8mf8_t, vuint8mf8_t, vuint8mf8_t, vuint8mf8_t, vuint8mf8_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vsoxseg8ei16_v)))
void vsoxseg8ei16_v_i8m1(int8_t *, vuint16m2_t, vint8m1_t, vint8m1_t, vint8m1_t, vint8m1_t, vint8m1_t, vint8m1_t, vint8m1_t, vint8m1_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vsoxseg8ei16_v_m)))
void vsoxseg8ei16_v_i8m1_m(vbool8_t, int8_t *, vuint16m2_t, vint8m1_t, vint8m1_t, vint8m1_t, vint8m1_t, vint8m1_t, vint8m1_t, vint8m1_t, vint8m1_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vsoxseg8ei16_v)))
void vsoxseg8ei16_v_i8mf2(int8_t *, vuint16m1_t, vint8mf2_t, vint8mf2_t, vint8mf2_t, vint8mf2_t, vint8mf2_t, vint8mf2_t, vint8mf2_t, vint8mf2_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vsoxseg8ei16_v_m)))
void vsoxseg8ei16_v_i8mf2_m(vbool16_t, int8_t *, vuint16m1_t, vint8mf2_t, vint8mf2_t, vint8mf2_t, vint8mf2_t, vint8mf2_t, vint8mf2_t, vint8mf2_t, vint8mf2_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vsoxseg8ei16_v)))
void vsoxseg8ei16_v_i8mf4(int8_t *, vuint16mf2_t, vint8mf4_t, vint8mf4_t, vint8mf4_t, vint8mf4_t, vint8mf4_t, vint8mf4_t, vint8mf4_t, vint8mf4_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vsoxseg8ei16_v_m)))
void vsoxseg8ei16_v_i8mf4_m(vbool32_t, int8_t *, vuint16mf2_t, vint8mf4_t, vint8mf4_t, vint8mf4_t, vint8mf4_t, vint8mf4_t, vint8mf4_t, vint8mf4_t, vint8mf4_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vsoxseg8ei16_v)))
void vsoxseg8ei16_v_i8mf8(int8_t *, vuint16mf4_t, vint8mf8_t, vint8mf8_t, vint8mf8_t, vint8mf8_t, vint8mf8_t, vint8mf8_t, vint8mf8_t, vint8mf8_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vsoxseg8ei16_v_m)))
void vsoxseg8ei16_v_i8mf8_m(vbool64_t, int8_t *, vuint16mf4_t, vint8mf8_t, vint8mf8_t, vint8mf8_t, vint8mf8_t, vint8mf8_t, vint8mf8_t, vint8mf8_t, vint8mf8_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vsoxseg8ei16_v)))
void vsoxseg8ei16_v_u8m1(uint8_t *, vuint16m2_t, vuint8m1_t, vuint8m1_t, vuint8m1_t, vuint8m1_t, vuint8m1_t, vuint8m1_t, vuint8m1_t, vuint8m1_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vsoxseg8ei16_v_m)))
void vsoxseg8ei16_v_u8m1_m(vbool8_t, uint8_t *, vuint16m2_t, vuint8m1_t, vuint8m1_t, vuint8m1_t, vuint8m1_t, vuint8m1_t, vuint8m1_t, vuint8m1_t, vuint8m1_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vsoxseg8ei16_v)))
void vsoxseg8ei16_v_u8mf2(uint8_t *, vuint16m1_t, vuint8mf2_t, vuint8mf2_t, vuint8mf2_t, vuint8mf2_t, vuint8mf2_t, vuint8mf2_t, vuint8mf2_t, vuint8mf2_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vsoxseg8ei16_v_m)))
void vsoxseg8ei16_v_u8mf2_m(vbool16_t, uint8_t *, vuint16m1_t, vuint8mf2_t, vuint8mf2_t, vuint8mf2_t, vuint8mf2_t, vuint8mf2_t, vuint8mf2_t, vuint8mf2_t, vuint8mf2_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vsoxseg8ei16_v)))
void vsoxseg8ei16_v_u8mf4(uint8_t *, vuint16mf2_t, vuint8mf4_t, vuint8mf4_t, vuint8mf4_t, vuint8mf4_t, vuint8mf4_t, vuint8mf4_t, vuint8mf4_t, vuint8mf4_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vsoxseg8ei16_v_m)))
void vsoxseg8ei16_v_u8mf4_m(vbool32_t, uint8_t *, vuint16mf2_t, vuint8mf4_t, vuint8mf4_t, vuint8mf4_t, vuint8mf4_t, vuint8mf4_t, vuint8mf4_t, vuint8mf4_t, vuint8mf4_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vsoxseg8ei16_v)))
void vsoxseg8ei16_v_u8mf8(uint8_t *, vuint16mf4_t, vuint8mf8_t, vuint8mf8_t, vuint8mf8_t, vuint8mf8_t, vuint8mf8_t, vuint8mf8_t, vuint8mf8_t, vuint8mf8_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vsoxseg8ei16_v_m)))
void vsoxseg8ei16_v_u8mf8_m(vbool64_t, uint8_t *, vuint16mf4_t, vuint8mf8_t, vuint8mf8_t, vuint8mf8_t, vuint8mf8_t, vuint8mf8_t, vuint8mf8_t, vuint8mf8_t, vuint8mf8_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vsoxseg2ei32_v)))
void vsoxseg2ei32_v_i8m1(int8_t *, vuint32m4_t, vint8m1_t, vint8m1_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vsoxseg2ei32_v_m)))
void vsoxseg2ei32_v_i8m1_m(vbool8_t, int8_t *, vuint32m4_t, vint8m1_t, vint8m1_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vsoxseg2ei32_v)))
void vsoxseg2ei32_v_i8m2(int8_t *, vuint32m8_t, vint8m2_t, vint8m2_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vsoxseg2ei32_v_m)))
void vsoxseg2ei32_v_i8m2_m(vbool4_t, int8_t *, vuint32m8_t, vint8m2_t, vint8m2_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vsoxseg2ei32_v)))
void vsoxseg2ei32_v_i8mf2(int8_t *, vuint32m2_t, vint8mf2_t, vint8mf2_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vsoxseg2ei32_v_m)))
void vsoxseg2ei32_v_i8mf2_m(vbool16_t, int8_t *, vuint32m2_t, vint8mf2_t, vint8mf2_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vsoxseg2ei32_v)))
void vsoxseg2ei32_v_i8mf4(int8_t *, vuint32m1_t, vint8mf4_t, vint8mf4_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vsoxseg2ei32_v_m)))
void vsoxseg2ei32_v_i8mf4_m(vbool32_t, int8_t *, vuint32m1_t, vint8mf4_t, vint8mf4_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vsoxseg2ei32_v)))
void vsoxseg2ei32_v_i8mf8(int8_t *, vuint32mf2_t, vint8mf8_t, vint8mf8_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vsoxseg2ei32_v_m)))
void vsoxseg2ei32_v_i8mf8_m(vbool64_t, int8_t *, vuint32mf2_t, vint8mf8_t, vint8mf8_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vsoxseg2ei32_v)))
void vsoxseg2ei32_v_u8m1(uint8_t *, vuint32m4_t, vuint8m1_t, vuint8m1_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vsoxseg2ei32_v_m)))
void vsoxseg2ei32_v_u8m1_m(vbool8_t, uint8_t *, vuint32m4_t, vuint8m1_t, vuint8m1_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vsoxseg2ei32_v)))
void vsoxseg2ei32_v_u8m2(uint8_t *, vuint32m8_t, vuint8m2_t, vuint8m2_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vsoxseg2ei32_v_m)))
void vsoxseg2ei32_v_u8m2_m(vbool4_t, uint8_t *, vuint32m8_t, vuint8m2_t, vuint8m2_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vsoxseg2ei32_v)))
void vsoxseg2ei32_v_u8mf2(uint8_t *, vuint32m2_t, vuint8mf2_t, vuint8mf2_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vsoxseg2ei32_v_m)))
void vsoxseg2ei32_v_u8mf2_m(vbool16_t, uint8_t *, vuint32m2_t, vuint8mf2_t, vuint8mf2_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vsoxseg2ei32_v)))
void vsoxseg2ei32_v_u8mf4(uint8_t *, vuint32m1_t, vuint8mf4_t, vuint8mf4_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vsoxseg2ei32_v_m)))
void vsoxseg2ei32_v_u8mf4_m(vbool32_t, uint8_t *, vuint32m1_t, vuint8mf4_t, vuint8mf4_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vsoxseg2ei32_v)))
void vsoxseg2ei32_v_u8mf8(uint8_t *, vuint32mf2_t, vuint8mf8_t, vuint8mf8_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vsoxseg2ei32_v_m)))
void vsoxseg2ei32_v_u8mf8_m(vbool64_t, uint8_t *, vuint32mf2_t, vuint8mf8_t, vuint8mf8_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vsoxseg3ei32_v)))
void vsoxseg3ei32_v_i8m1(int8_t *, vuint32m4_t, vint8m1_t, vint8m1_t, vint8m1_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vsoxseg3ei32_v_m)))
void vsoxseg3ei32_v_i8m1_m(vbool8_t, int8_t *, vuint32m4_t, vint8m1_t, vint8m1_t, vint8m1_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vsoxseg3ei32_v)))
void vsoxseg3ei32_v_i8m2(int8_t *, vuint32m8_t, vint8m2_t, vint8m2_t, vint8m2_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vsoxseg3ei32_v_m)))
void vsoxseg3ei32_v_i8m2_m(vbool4_t, int8_t *, vuint32m8_t, vint8m2_t, vint8m2_t, vint8m2_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vsoxseg3ei32_v)))
void vsoxseg3ei32_v_i8mf2(int8_t *, vuint32m2_t, vint8mf2_t, vint8mf2_t, vint8mf2_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vsoxseg3ei32_v_m)))
void vsoxseg3ei32_v_i8mf2_m(vbool16_t, int8_t *, vuint32m2_t, vint8mf2_t, vint8mf2_t, vint8mf2_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vsoxseg3ei32_v)))
void vsoxseg3ei32_v_i8mf4(int8_t *, vuint32m1_t, vint8mf4_t, vint8mf4_t, vint8mf4_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vsoxseg3ei32_v_m)))
void vsoxseg3ei32_v_i8mf4_m(vbool32_t, int8_t *, vuint32m1_t, vint8mf4_t, vint8mf4_t, vint8mf4_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vsoxseg3ei32_v)))
void vsoxseg3ei32_v_i8mf8(int8_t *, vuint32mf2_t, vint8mf8_t, vint8mf8_t, vint8mf8_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vsoxseg3ei32_v_m)))
void vsoxseg3ei32_v_i8mf8_m(vbool64_t, int8_t *, vuint32mf2_t, vint8mf8_t, vint8mf8_t, vint8mf8_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vsoxseg3ei32_v)))
void vsoxseg3ei32_v_u8m1(uint8_t *, vuint32m4_t, vuint8m1_t, vuint8m1_t, vuint8m1_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vsoxseg3ei32_v_m)))
void vsoxseg3ei32_v_u8m1_m(vbool8_t, uint8_t *, vuint32m4_t, vuint8m1_t, vuint8m1_t, vuint8m1_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vsoxseg3ei32_v)))
void vsoxseg3ei32_v_u8m2(uint8_t *, vuint32m8_t, vuint8m2_t, vuint8m2_t, vuint8m2_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vsoxseg3ei32_v_m)))
void vsoxseg3ei32_v_u8m2_m(vbool4_t, uint8_t *, vuint32m8_t, vuint8m2_t, vuint8m2_t, vuint8m2_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vsoxseg3ei32_v)))
void vsoxseg3ei32_v_u8mf2(uint8_t *, vuint32m2_t, vuint8mf2_t, vuint8mf2_t, vuint8mf2_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vsoxseg3ei32_v_m)))
void vsoxseg3ei32_v_u8mf2_m(vbool16_t, uint8_t *, vuint32m2_t, vuint8mf2_t, vuint8mf2_t, vuint8mf2_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vsoxseg3ei32_v)))
void vsoxseg3ei32_v_u8mf4(uint8_t *, vuint32m1_t, vuint8mf4_t, vuint8mf4_t, vuint8mf4_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vsoxseg3ei32_v_m)))
void vsoxseg3ei32_v_u8mf4_m(vbool32_t, uint8_t *, vuint32m1_t, vuint8mf4_t, vuint8mf4_t, vuint8mf4_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vsoxseg3ei32_v)))
void vsoxseg3ei32_v_u8mf8(uint8_t *, vuint32mf2_t, vuint8mf8_t, vuint8mf8_t, vuint8mf8_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vsoxseg3ei32_v_m)))
void vsoxseg3ei32_v_u8mf8_m(vbool64_t, uint8_t *, vuint32mf2_t, vuint8mf8_t, vuint8mf8_t, vuint8mf8_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vloxei8_v)))
vint16m1_t vloxei8_v_i16m1(const int16_t *, vuint8mf2_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vloxei8_v_m)))
vint16m1_t vloxei8_v_i16m1_m(vbool16_t, vint16m1_t, const int16_t *, vuint8mf2_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vloxei8_v)))
vint16m2_t vloxei8_v_i16m2(const int16_t *, vuint8m1_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vloxei8_v_m)))
vint16m2_t vloxei8_v_i16m2_m(vbool8_t, vint16m2_t, const int16_t *, vuint8m1_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vloxei8_v)))
vint16m4_t vloxei8_v_i16m4(const int16_t *, vuint8m2_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vloxei8_v_m)))
vint16m4_t vloxei8_v_i16m4_m(vbool4_t, vint16m4_t, const int16_t *, vuint8m2_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vloxei8_v)))
vint16m8_t vloxei8_v_i16m8(const int16_t *, vuint8m4_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vloxei8_v_m)))
vint16m8_t vloxei8_v_i16m8_m(vbool2_t, vint16m8_t, const int16_t *, vuint8m4_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vloxei8_v)))
vint16mf2_t vloxei8_v_i16mf2(const int16_t *, vuint8mf4_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vloxei8_v_m)))
vint16mf2_t vloxei8_v_i16mf2_m(vbool32_t, vint16mf2_t, const int16_t *, vuint8mf4_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vloxei8_v)))
vint16mf4_t vloxei8_v_i16mf4(const int16_t *, vuint8mf8_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vloxei8_v_m)))
vint16mf4_t vloxei8_v_i16mf4_m(vbool64_t, vint16mf4_t, const int16_t *, vuint8mf8_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vsoxseg4ei32_v)))
void vsoxseg4ei32_v_i8m1(int8_t *, vuint32m4_t, vint8m1_t, vint8m1_t, vint8m1_t, vint8m1_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vsoxseg4ei32_v_m)))
void vsoxseg4ei32_v_i8m1_m(vbool8_t, int8_t *, vuint32m4_t, vint8m1_t, vint8m1_t, vint8m1_t, vint8m1_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vsoxseg4ei32_v)))
void vsoxseg4ei32_v_i8m2(int8_t *, vuint32m8_t, vint8m2_t, vint8m2_t, vint8m2_t, vint8m2_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vsoxseg4ei32_v_m)))
void vsoxseg4ei32_v_i8m2_m(vbool4_t, int8_t *, vuint32m8_t, vint8m2_t, vint8m2_t, vint8m2_t, vint8m2_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vsoxseg4ei32_v)))
void vsoxseg4ei32_v_i8mf2(int8_t *, vuint32m2_t, vint8mf2_t, vint8mf2_t, vint8mf2_t, vint8mf2_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vsoxseg4ei32_v_m)))
void vsoxseg4ei32_v_i8mf2_m(vbool16_t, int8_t *, vuint32m2_t, vint8mf2_t, vint8mf2_t, vint8mf2_t, vint8mf2_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vsoxseg4ei32_v)))
void vsoxseg4ei32_v_i8mf4(int8_t *, vuint32m1_t, vint8mf4_t, vint8mf4_t, vint8mf4_t, vint8mf4_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vsoxseg4ei32_v_m)))
void vsoxseg4ei32_v_i8mf4_m(vbool32_t, int8_t *, vuint32m1_t, vint8mf4_t, vint8mf4_t, vint8mf4_t, vint8mf4_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vsoxseg4ei32_v)))
void vsoxseg4ei32_v_i8mf8(int8_t *, vuint32mf2_t, vint8mf8_t, vint8mf8_t, vint8mf8_t, vint8mf8_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vsoxseg4ei32_v_m)))
void vsoxseg4ei32_v_i8mf8_m(vbool64_t, int8_t *, vuint32mf2_t, vint8mf8_t, vint8mf8_t, vint8mf8_t, vint8mf8_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vsoxseg4ei32_v)))
void vsoxseg4ei32_v_u8m1(uint8_t *, vuint32m4_t, vuint8m1_t, vuint8m1_t, vuint8m1_t, vuint8m1_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vsoxseg4ei32_v_m)))
void vsoxseg4ei32_v_u8m1_m(vbool8_t, uint8_t *, vuint32m4_t, vuint8m1_t, vuint8m1_t, vuint8m1_t, vuint8m1_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vsoxseg4ei32_v)))
void vsoxseg4ei32_v_u8m2(uint8_t *, vuint32m8_t, vuint8m2_t, vuint8m2_t, vuint8m2_t, vuint8m2_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vsoxseg4ei32_v_m)))
void vsoxseg4ei32_v_u8m2_m(vbool4_t, uint8_t *, vuint32m8_t, vuint8m2_t, vuint8m2_t, vuint8m2_t, vuint8m2_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vsoxseg4ei32_v)))
void vsoxseg4ei32_v_u8mf2(uint8_t *, vuint32m2_t, vuint8mf2_t, vuint8mf2_t, vuint8mf2_t, vuint8mf2_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vsoxseg4ei32_v_m)))
void vsoxseg4ei32_v_u8mf2_m(vbool16_t, uint8_t *, vuint32m2_t, vuint8mf2_t, vuint8mf2_t, vuint8mf2_t, vuint8mf2_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vsoxseg4ei32_v)))
void vsoxseg4ei32_v_u8mf4(uint8_t *, vuint32m1_t, vuint8mf4_t, vuint8mf4_t, vuint8mf4_t, vuint8mf4_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vsoxseg4ei32_v_m)))
void vsoxseg4ei32_v_u8mf4_m(vbool32_t, uint8_t *, vuint32m1_t, vuint8mf4_t, vuint8mf4_t, vuint8mf4_t, vuint8mf4_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vsoxseg4ei32_v)))
void vsoxseg4ei32_v_u8mf8(uint8_t *, vuint32mf2_t, vuint8mf8_t, vuint8mf8_t, vuint8mf8_t, vuint8mf8_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vsoxseg4ei32_v_m)))
void vsoxseg4ei32_v_u8mf8_m(vbool64_t, uint8_t *, vuint32mf2_t, vuint8mf8_t, vuint8mf8_t, vuint8mf8_t, vuint8mf8_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vsoxseg5ei32_v)))
void vsoxseg5ei32_v_i8m1(int8_t *, vuint32m4_t, vint8m1_t, vint8m1_t, vint8m1_t, vint8m1_t, vint8m1_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vsoxseg5ei32_v_m)))
void vsoxseg5ei32_v_i8m1_m(vbool8_t, int8_t *, vuint32m4_t, vint8m1_t, vint8m1_t, vint8m1_t, vint8m1_t, vint8m1_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vsoxseg5ei32_v)))
void vsoxseg5ei32_v_i8mf2(int8_t *, vuint32m2_t, vint8mf2_t, vint8mf2_t, vint8mf2_t, vint8mf2_t, vint8mf2_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vsoxseg5ei32_v_m)))
void vsoxseg5ei32_v_i8mf2_m(vbool16_t, int8_t *, vuint32m2_t, vint8mf2_t, vint8mf2_t, vint8mf2_t, vint8mf2_t, vint8mf2_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vsoxseg5ei32_v)))
void vsoxseg5ei32_v_i8mf4(int8_t *, vuint32m1_t, vint8mf4_t, vint8mf4_t, vint8mf4_t, vint8mf4_t, vint8mf4_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vsoxseg5ei32_v_m)))
void vsoxseg5ei32_v_i8mf4_m(vbool32_t, int8_t *, vuint32m1_t, vint8mf4_t, vint8mf4_t, vint8mf4_t, vint8mf4_t, vint8mf4_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vsoxseg5ei32_v)))
void vsoxseg5ei32_v_i8mf8(int8_t *, vuint32mf2_t, vint8mf8_t, vint8mf8_t, vint8mf8_t, vint8mf8_t, vint8mf8_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vsoxseg5ei32_v_m)))
void vsoxseg5ei32_v_i8mf8_m(vbool64_t, int8_t *, vuint32mf2_t, vint8mf8_t, vint8mf8_t, vint8mf8_t, vint8mf8_t, vint8mf8_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vsoxseg5ei32_v)))
void vsoxseg5ei32_v_u8m1(uint8_t *, vuint32m4_t, vuint8m1_t, vuint8m1_t, vuint8m1_t, vuint8m1_t, vuint8m1_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vsoxseg5ei32_v_m)))
void vsoxseg5ei32_v_u8m1_m(vbool8_t, uint8_t *, vuint32m4_t, vuint8m1_t, vuint8m1_t, vuint8m1_t, vuint8m1_t, vuint8m1_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vsoxseg5ei32_v)))
void vsoxseg5ei32_v_u8mf2(uint8_t *, vuint32m2_t, vuint8mf2_t, vuint8mf2_t, vuint8mf2_t, vuint8mf2_t, vuint8mf2_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vsoxseg5ei32_v_m)))
void vsoxseg5ei32_v_u8mf2_m(vbool16_t, uint8_t *, vuint32m2_t, vuint8mf2_t, vuint8mf2_t, vuint8mf2_t, vuint8mf2_t, vuint8mf2_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vsoxseg5ei32_v)))
void vsoxseg5ei32_v_u8mf4(uint8_t *, vuint32m1_t, vuint8mf4_t, vuint8mf4_t, vuint8mf4_t, vuint8mf4_t, vuint8mf4_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vsoxseg5ei32_v_m)))
void vsoxseg5ei32_v_u8mf4_m(vbool32_t, uint8_t *, vuint32m1_t, vuint8mf4_t, vuint8mf4_t, vuint8mf4_t, vuint8mf4_t, vuint8mf4_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vsoxseg5ei32_v)))
void vsoxseg5ei32_v_u8mf8(uint8_t *, vuint32mf2_t, vuint8mf8_t, vuint8mf8_t, vuint8mf8_t, vuint8mf8_t, vuint8mf8_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vsoxseg5ei32_v_m)))
void vsoxseg5ei32_v_u8mf8_m(vbool64_t, uint8_t *, vuint32mf2_t, vuint8mf8_t, vuint8mf8_t, vuint8mf8_t, vuint8mf8_t, vuint8mf8_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vsoxseg6ei32_v)))
void vsoxseg6ei32_v_i8m1(int8_t *, vuint32m4_t, vint8m1_t, vint8m1_t, vint8m1_t, vint8m1_t, vint8m1_t, vint8m1_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vsoxseg6ei32_v_m)))
void vsoxseg6ei32_v_i8m1_m(vbool8_t, int8_t *, vuint32m4_t, vint8m1_t, vint8m1_t, vint8m1_t, vint8m1_t, vint8m1_t, vint8m1_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vsoxseg6ei32_v)))
void vsoxseg6ei32_v_i8mf2(int8_t *, vuint32m2_t, vint8mf2_t, vint8mf2_t, vint8mf2_t, vint8mf2_t, vint8mf2_t, vint8mf2_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vsoxseg6ei32_v_m)))
void vsoxseg6ei32_v_i8mf2_m(vbool16_t, int8_t *, vuint32m2_t, vint8mf2_t, vint8mf2_t, vint8mf2_t, vint8mf2_t, vint8mf2_t, vint8mf2_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vsoxseg6ei32_v)))
void vsoxseg6ei32_v_i8mf4(int8_t *, vuint32m1_t, vint8mf4_t, vint8mf4_t, vint8mf4_t, vint8mf4_t, vint8mf4_t, vint8mf4_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vsoxseg6ei32_v_m)))
void vsoxseg6ei32_v_i8mf4_m(vbool32_t, int8_t *, vuint32m1_t, vint8mf4_t, vint8mf4_t, vint8mf4_t, vint8mf4_t, vint8mf4_t, vint8mf4_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vsoxseg6ei32_v)))
void vsoxseg6ei32_v_i8mf8(int8_t *, vuint32mf2_t, vint8mf8_t, vint8mf8_t, vint8mf8_t, vint8mf8_t, vint8mf8_t, vint8mf8_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vsoxseg6ei32_v_m)))
void vsoxseg6ei32_v_i8mf8_m(vbool64_t, int8_t *, vuint32mf2_t, vint8mf8_t, vint8mf8_t, vint8mf8_t, vint8mf8_t, vint8mf8_t, vint8mf8_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vsoxseg6ei32_v)))
void vsoxseg6ei32_v_u8m1(uint8_t *, vuint32m4_t, vuint8m1_t, vuint8m1_t, vuint8m1_t, vuint8m1_t, vuint8m1_t, vuint8m1_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vsoxseg6ei32_v_m)))
void vsoxseg6ei32_v_u8m1_m(vbool8_t, uint8_t *, vuint32m4_t, vuint8m1_t, vuint8m1_t, vuint8m1_t, vuint8m1_t, vuint8m1_t, vuint8m1_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vsoxseg6ei32_v)))
void vsoxseg6ei32_v_u8mf2(uint8_t *, vuint32m2_t, vuint8mf2_t, vuint8mf2_t, vuint8mf2_t, vuint8mf2_t, vuint8mf2_t, vuint8mf2_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vsoxseg6ei32_v_m)))
void vsoxseg6ei32_v_u8mf2_m(vbool16_t, uint8_t *, vuint32m2_t, vuint8mf2_t, vuint8mf2_t, vuint8mf2_t, vuint8mf2_t, vuint8mf2_t, vuint8mf2_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vsoxseg6ei32_v)))
void vsoxseg6ei32_v_u8mf4(uint8_t *, vuint32m1_t, vuint8mf4_t, vuint8mf4_t, vuint8mf4_t, vuint8mf4_t, vuint8mf4_t, vuint8mf4_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vsoxseg6ei32_v_m)))
void vsoxseg6ei32_v_u8mf4_m(vbool32_t, uint8_t *, vuint32m1_t, vuint8mf4_t, vuint8mf4_t, vuint8mf4_t, vuint8mf4_t, vuint8mf4_t, vuint8mf4_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vsoxseg6ei32_v)))
void vsoxseg6ei32_v_u8mf8(uint8_t *, vuint32mf2_t, vuint8mf8_t, vuint8mf8_t, vuint8mf8_t, vuint8mf8_t, vuint8mf8_t, vuint8mf8_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vsoxseg6ei32_v_m)))
void vsoxseg6ei32_v_u8mf8_m(vbool64_t, uint8_t *, vuint32mf2_t, vuint8mf8_t, vuint8mf8_t, vuint8mf8_t, vuint8mf8_t, vuint8mf8_t, vuint8mf8_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vsoxseg7ei32_v)))
void vsoxseg7ei32_v_i8m1(int8_t *, vuint32m4_t, vint8m1_t, vint8m1_t, vint8m1_t, vint8m1_t, vint8m1_t, vint8m1_t, vint8m1_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vsoxseg7ei32_v_m)))
void vsoxseg7ei32_v_i8m1_m(vbool8_t, int8_t *, vuint32m4_t, vint8m1_t, vint8m1_t, vint8m1_t, vint8m1_t, vint8m1_t, vint8m1_t, vint8m1_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vsoxseg7ei32_v)))
void vsoxseg7ei32_v_i8mf2(int8_t *, vuint32m2_t, vint8mf2_t, vint8mf2_t, vint8mf2_t, vint8mf2_t, vint8mf2_t, vint8mf2_t, vint8mf2_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vsoxseg7ei32_v_m)))
void vsoxseg7ei32_v_i8mf2_m(vbool16_t, int8_t *, vuint32m2_t, vint8mf2_t, vint8mf2_t, vint8mf2_t, vint8mf2_t, vint8mf2_t, vint8mf2_t, vint8mf2_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vsoxseg7ei32_v)))
void vsoxseg7ei32_v_i8mf4(int8_t *, vuint32m1_t, vint8mf4_t, vint8mf4_t, vint8mf4_t, vint8mf4_t, vint8mf4_t, vint8mf4_t, vint8mf4_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vsoxseg7ei32_v_m)))
void vsoxseg7ei32_v_i8mf4_m(vbool32_t, int8_t *, vuint32m1_t, vint8mf4_t, vint8mf4_t, vint8mf4_t, vint8mf4_t, vint8mf4_t, vint8mf4_t, vint8mf4_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vsoxseg7ei32_v)))
void vsoxseg7ei32_v_i8mf8(int8_t *, vuint32mf2_t, vint8mf8_t, vint8mf8_t, vint8mf8_t, vint8mf8_t, vint8mf8_t, vint8mf8_t, vint8mf8_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vsoxseg7ei32_v_m)))
void vsoxseg7ei32_v_i8mf8_m(vbool64_t, int8_t *, vuint32mf2_t, vint8mf8_t, vint8mf8_t, vint8mf8_t, vint8mf8_t, vint8mf8_t, vint8mf8_t, vint8mf8_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vsoxseg7ei32_v)))
void vsoxseg7ei32_v_u8m1(uint8_t *, vuint32m4_t, vuint8m1_t, vuint8m1_t, vuint8m1_t, vuint8m1_t, vuint8m1_t, vuint8m1_t, vuint8m1_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vsoxseg7ei32_v_m)))
void vsoxseg7ei32_v_u8m1_m(vbool8_t, uint8_t *, vuint32m4_t, vuint8m1_t, vuint8m1_t, vuint8m1_t, vuint8m1_t, vuint8m1_t, vuint8m1_t, vuint8m1_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vsoxseg7ei32_v)))
void vsoxseg7ei32_v_u8mf2(uint8_t *, vuint32m2_t, vuint8mf2_t, vuint8mf2_t, vuint8mf2_t, vuint8mf2_t, vuint8mf2_t, vuint8mf2_t, vuint8mf2_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vsoxseg7ei32_v_m)))
void vsoxseg7ei32_v_u8mf2_m(vbool16_t, uint8_t *, vuint32m2_t, vuint8mf2_t, vuint8mf2_t, vuint8mf2_t, vuint8mf2_t, vuint8mf2_t, vuint8mf2_t, vuint8mf2_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vsoxseg7ei32_v)))
void vsoxseg7ei32_v_u8mf4(uint8_t *, vuint32m1_t, vuint8mf4_t, vuint8mf4_t, vuint8mf4_t, vuint8mf4_t, vuint8mf4_t, vuint8mf4_t, vuint8mf4_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vsoxseg7ei32_v_m)))
void vsoxseg7ei32_v_u8mf4_m(vbool32_t, uint8_t *, vuint32m1_t, vuint8mf4_t, vuint8mf4_t, vuint8mf4_t, vuint8mf4_t, vuint8mf4_t, vuint8mf4_t, vuint8mf4_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vsoxseg7ei32_v)))
void vsoxseg7ei32_v_u8mf8(uint8_t *, vuint32mf2_t, vuint8mf8_t, vuint8mf8_t, vuint8mf8_t, vuint8mf8_t, vuint8mf8_t, vuint8mf8_t, vuint8mf8_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vsoxseg7ei32_v_m)))
void vsoxseg7ei32_v_u8mf8_m(vbool64_t, uint8_t *, vuint32mf2_t, vuint8mf8_t, vuint8mf8_t, vuint8mf8_t, vuint8mf8_t, vuint8mf8_t, vuint8mf8_t, vuint8mf8_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vsoxseg8ei32_v)))
void vsoxseg8ei32_v_i8m1(int8_t *, vuint32m4_t, vint8m1_t, vint8m1_t, vint8m1_t, vint8m1_t, vint8m1_t, vint8m1_t, vint8m1_t, vint8m1_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vsoxseg8ei32_v_m)))
void vsoxseg8ei32_v_i8m1_m(vbool8_t, int8_t *, vuint32m4_t, vint8m1_t, vint8m1_t, vint8m1_t, vint8m1_t, vint8m1_t, vint8m1_t, vint8m1_t, vint8m1_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vsoxseg8ei32_v)))
void vsoxseg8ei32_v_i8mf2(int8_t *, vuint32m2_t, vint8mf2_t, vint8mf2_t, vint8mf2_t, vint8mf2_t, vint8mf2_t, vint8mf2_t, vint8mf2_t, vint8mf2_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vsoxseg8ei32_v_m)))
void vsoxseg8ei32_v_i8mf2_m(vbool16_t, int8_t *, vuint32m2_t, vint8mf2_t, vint8mf2_t, vint8mf2_t, vint8mf2_t, vint8mf2_t, vint8mf2_t, vint8mf2_t, vint8mf2_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vsoxseg8ei32_v)))
void vsoxseg8ei32_v_i8mf4(int8_t *, vuint32m1_t, vint8mf4_t, vint8mf4_t, vint8mf4_t, vint8mf4_t, vint8mf4_t, vint8mf4_t, vint8mf4_t, vint8mf4_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vsoxseg8ei32_v_m)))
void vsoxseg8ei32_v_i8mf4_m(vbool32_t, int8_t *, vuint32m1_t, vint8mf4_t, vint8mf4_t, vint8mf4_t, vint8mf4_t, vint8mf4_t, vint8mf4_t, vint8mf4_t, vint8mf4_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vsoxseg8ei32_v)))
void vsoxseg8ei32_v_i8mf8(int8_t *, vuint32mf2_t, vint8mf8_t, vint8mf8_t, vint8mf8_t, vint8mf8_t, vint8mf8_t, vint8mf8_t, vint8mf8_t, vint8mf8_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vsoxseg8ei32_v_m)))
void vsoxseg8ei32_v_i8mf8_m(vbool64_t, int8_t *, vuint32mf2_t, vint8mf8_t, vint8mf8_t, vint8mf8_t, vint8mf8_t, vint8mf8_t, vint8mf8_t, vint8mf8_t, vint8mf8_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vsoxseg8ei32_v)))
void vsoxseg8ei32_v_u8m1(uint8_t *, vuint32m4_t, vuint8m1_t, vuint8m1_t, vuint8m1_t, vuint8m1_t, vuint8m1_t, vuint8m1_t, vuint8m1_t, vuint8m1_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vsoxseg8ei32_v_m)))
void vsoxseg8ei32_v_u8m1_m(vbool8_t, uint8_t *, vuint32m4_t, vuint8m1_t, vuint8m1_t, vuint8m1_t, vuint8m1_t, vuint8m1_t, vuint8m1_t, vuint8m1_t, vuint8m1_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vsoxseg8ei32_v)))
void vsoxseg8ei32_v_u8mf2(uint8_t *, vuint32m2_t, vuint8mf2_t, vuint8mf2_t, vuint8mf2_t, vuint8mf2_t, vuint8mf2_t, vuint8mf2_t, vuint8mf2_t, vuint8mf2_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vsoxseg8ei32_v_m)))
void vsoxseg8ei32_v_u8mf2_m(vbool16_t, uint8_t *, vuint32m2_t, vuint8mf2_t, vuint8mf2_t, vuint8mf2_t, vuint8mf2_t, vuint8mf2_t, vuint8mf2_t, vuint8mf2_t, vuint8mf2_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vsoxseg8ei32_v)))
void vsoxseg8ei32_v_u8mf4(uint8_t *, vuint32m1_t, vuint8mf4_t, vuint8mf4_t, vuint8mf4_t, vuint8mf4_t, vuint8mf4_t, vuint8mf4_t, vuint8mf4_t, vuint8mf4_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vsoxseg8ei32_v_m)))
void vsoxseg8ei32_v_u8mf4_m(vbool32_t, uint8_t *, vuint32m1_t, vuint8mf4_t, vuint8mf4_t, vuint8mf4_t, vuint8mf4_t, vuint8mf4_t, vuint8mf4_t, vuint8mf4_t, vuint8mf4_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vsoxseg8ei32_v)))
void vsoxseg8ei32_v_u8mf8(uint8_t *, vuint32mf2_t, vuint8mf8_t, vuint8mf8_t, vuint8mf8_t, vuint8mf8_t, vuint8mf8_t, vuint8mf8_t, vuint8mf8_t, vuint8mf8_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vsoxseg8ei32_v_m)))
void vsoxseg8ei32_v_u8mf8_m(vbool64_t, uint8_t *, vuint32mf2_t, vuint8mf8_t, vuint8mf8_t, vuint8mf8_t, vuint8mf8_t, vuint8mf8_t, vuint8mf8_t, vuint8mf8_t, vuint8mf8_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vloxei8_v)))
vuint16m1_t vloxei8_v_u16m1(const uint16_t *, vuint8mf2_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vloxei8_v_m)))
vuint16m1_t vloxei8_v_u16m1_m(vbool16_t, vuint16m1_t, const uint16_t *, vuint8mf2_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vloxei8_v)))
vuint16m2_t vloxei8_v_u16m2(const uint16_t *, vuint8m1_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vloxei8_v_m)))
vuint16m2_t vloxei8_v_u16m2_m(vbool8_t, vuint16m2_t, const uint16_t *, vuint8m1_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vloxei8_v)))
vuint16m4_t vloxei8_v_u16m4(const uint16_t *, vuint8m2_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vloxei8_v_m)))
vuint16m4_t vloxei8_v_u16m4_m(vbool4_t, vuint16m4_t, const uint16_t *, vuint8m2_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vloxei8_v)))
vuint16m8_t vloxei8_v_u16m8(const uint16_t *, vuint8m4_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vloxei8_v_m)))
vuint16m8_t vloxei8_v_u16m8_m(vbool2_t, vuint16m8_t, const uint16_t *, vuint8m4_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vloxei8_v)))
vuint16mf2_t vloxei8_v_u16mf2(const uint16_t *, vuint8mf4_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vloxei8_v_m)))
vuint16mf2_t vloxei8_v_u16mf2_m(vbool32_t, vuint16mf2_t, const uint16_t *, vuint8mf4_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vloxei8_v)))
vuint16mf4_t vloxei8_v_u16mf4(const uint16_t *, vuint8mf8_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vloxei8_v_m)))
vuint16mf4_t vloxei8_v_u16mf4_m(vbool64_t, vuint16mf4_t, const uint16_t *, vuint8mf8_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vloxei16_v)))
vint16m1_t vloxei16_v_i16m1(const int16_t *, vuint16m1_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vloxei16_v_m)))
vint16m1_t vloxei16_v_i16m1_m(vbool16_t, vint16m1_t, const int16_t *, vuint16m1_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vloxei16_v)))
vint16m2_t vloxei16_v_i16m2(const int16_t *, vuint16m2_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vloxei16_v_m)))
vint16m2_t vloxei16_v_i16m2_m(vbool8_t, vint16m2_t, const int16_t *, vuint16m2_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vloxei16_v)))
vint16m4_t vloxei16_v_i16m4(const int16_t *, vuint16m4_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vloxei16_v_m)))
vint16m4_t vloxei16_v_i16m4_m(vbool4_t, vint16m4_t, const int16_t *, vuint16m4_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vloxei16_v)))
vint16m8_t vloxei16_v_i16m8(const int16_t *, vuint16m8_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vloxei16_v_m)))
vint16m8_t vloxei16_v_i16m8_m(vbool2_t, vint16m8_t, const int16_t *, vuint16m8_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vloxei16_v)))
vint16mf2_t vloxei16_v_i16mf2(const int16_t *, vuint16mf2_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vloxei16_v_m)))
vint16mf2_t vloxei16_v_i16mf2_m(vbool32_t, vint16mf2_t, const int16_t *, vuint16mf2_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vloxei16_v)))
vint16mf4_t vloxei16_v_i16mf4(const int16_t *, vuint16mf4_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vloxei16_v_m)))
vint16mf4_t vloxei16_v_i16mf4_m(vbool64_t, vint16mf4_t, const int16_t *, vuint16mf4_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vsoxseg2ei8_v)))
void vsoxseg2ei8_v_i16m1(int16_t *, vuint8mf2_t, vint16m1_t, vint16m1_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vsoxseg2ei8_v_m)))
void vsoxseg2ei8_v_i16m1_m(vbool16_t, int16_t *, vuint8mf2_t, vint16m1_t, vint16m1_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vsoxseg2ei8_v)))
void vsoxseg2ei8_v_i16m2(int16_t *, vuint8m1_t, vint16m2_t, vint16m2_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vsoxseg2ei8_v_m)))
void vsoxseg2ei8_v_i16m2_m(vbool8_t, int16_t *, vuint8m1_t, vint16m2_t, vint16m2_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vsoxseg2ei8_v)))
void vsoxseg2ei8_v_i16m4(int16_t *, vuint8m2_t, vint16m4_t, vint16m4_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vsoxseg2ei8_v_m)))
void vsoxseg2ei8_v_i16m4_m(vbool4_t, int16_t *, vuint8m2_t, vint16m4_t, vint16m4_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vsoxseg2ei8_v)))
void vsoxseg2ei8_v_i16mf2(int16_t *, vuint8mf4_t, vint16mf2_t, vint16mf2_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vsoxseg2ei8_v_m)))
void vsoxseg2ei8_v_i16mf2_m(vbool32_t, int16_t *, vuint8mf4_t, vint16mf2_t, vint16mf2_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vsoxseg2ei8_v)))
void vsoxseg2ei8_v_i16mf4(int16_t *, vuint8mf8_t, vint16mf4_t, vint16mf4_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vsoxseg2ei8_v_m)))
void vsoxseg2ei8_v_i16mf4_m(vbool64_t, int16_t *, vuint8mf8_t, vint16mf4_t, vint16mf4_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vsoxseg2ei8_v)))
void vsoxseg2ei8_v_u16m1(uint16_t *, vuint8mf2_t, vuint16m1_t, vuint16m1_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vsoxseg2ei8_v_m)))
void vsoxseg2ei8_v_u16m1_m(vbool16_t, uint16_t *, vuint8mf2_t, vuint16m1_t, vuint16m1_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vsoxseg2ei8_v)))
void vsoxseg2ei8_v_u16m2(uint16_t *, vuint8m1_t, vuint16m2_t, vuint16m2_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vsoxseg2ei8_v_m)))
void vsoxseg2ei8_v_u16m2_m(vbool8_t, uint16_t *, vuint8m1_t, vuint16m2_t, vuint16m2_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vsoxseg2ei8_v)))
void vsoxseg2ei8_v_u16m4(uint16_t *, vuint8m2_t, vuint16m4_t, vuint16m4_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vsoxseg2ei8_v_m)))
void vsoxseg2ei8_v_u16m4_m(vbool4_t, uint16_t *, vuint8m2_t, vuint16m4_t, vuint16m4_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vsoxseg2ei8_v)))
void vsoxseg2ei8_v_u16mf2(uint16_t *, vuint8mf4_t, vuint16mf2_t, vuint16mf2_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vsoxseg2ei8_v_m)))
void vsoxseg2ei8_v_u16mf2_m(vbool32_t, uint16_t *, vuint8mf4_t, vuint16mf2_t, vuint16mf2_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vsoxseg2ei8_v)))
void vsoxseg2ei8_v_u16mf4(uint16_t *, vuint8mf8_t, vuint16mf4_t, vuint16mf4_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vsoxseg2ei8_v_m)))
void vsoxseg2ei8_v_u16mf4_m(vbool64_t, uint16_t *, vuint8mf8_t, vuint16mf4_t, vuint16mf4_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vsoxseg3ei8_v)))
void vsoxseg3ei8_v_i16m1(int16_t *, vuint8mf2_t, vint16m1_t, vint16m1_t, vint16m1_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vsoxseg3ei8_v_m)))
void vsoxseg3ei8_v_i16m1_m(vbool16_t, int16_t *, vuint8mf2_t, vint16m1_t, vint16m1_t, vint16m1_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vsoxseg3ei8_v)))
void vsoxseg3ei8_v_i16m2(int16_t *, vuint8m1_t, vint16m2_t, vint16m2_t, vint16m2_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vsoxseg3ei8_v_m)))
void vsoxseg3ei8_v_i16m2_m(vbool8_t, int16_t *, vuint8m1_t, vint16m2_t, vint16m2_t, vint16m2_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vsoxseg3ei8_v)))
void vsoxseg3ei8_v_i16mf2(int16_t *, vuint8mf4_t, vint16mf2_t, vint16mf2_t, vint16mf2_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vsoxseg3ei8_v_m)))
void vsoxseg3ei8_v_i16mf2_m(vbool32_t, int16_t *, vuint8mf4_t, vint16mf2_t, vint16mf2_t, vint16mf2_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vsoxseg3ei8_v)))
void vsoxseg3ei8_v_i16mf4(int16_t *, vuint8mf8_t, vint16mf4_t, vint16mf4_t, vint16mf4_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vsoxseg3ei8_v_m)))
void vsoxseg3ei8_v_i16mf4_m(vbool64_t, int16_t *, vuint8mf8_t, vint16mf4_t, vint16mf4_t, vint16mf4_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vsoxseg3ei8_v)))
void vsoxseg3ei8_v_u16m1(uint16_t *, vuint8mf2_t, vuint16m1_t, vuint16m1_t, vuint16m1_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vsoxseg3ei8_v_m)))
void vsoxseg3ei8_v_u16m1_m(vbool16_t, uint16_t *, vuint8mf2_t, vuint16m1_t, vuint16m1_t, vuint16m1_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vsoxseg3ei8_v)))
void vsoxseg3ei8_v_u16m2(uint16_t *, vuint8m1_t, vuint16m2_t, vuint16m2_t, vuint16m2_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vsoxseg3ei8_v_m)))
void vsoxseg3ei8_v_u16m2_m(vbool8_t, uint16_t *, vuint8m1_t, vuint16m2_t, vuint16m2_t, vuint16m2_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vsoxseg3ei8_v)))
void vsoxseg3ei8_v_u16mf2(uint16_t *, vuint8mf4_t, vuint16mf2_t, vuint16mf2_t, vuint16mf2_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vsoxseg3ei8_v_m)))
void vsoxseg3ei8_v_u16mf2_m(vbool32_t, uint16_t *, vuint8mf4_t, vuint16mf2_t, vuint16mf2_t, vuint16mf2_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vsoxseg3ei8_v)))
void vsoxseg3ei8_v_u16mf4(uint16_t *, vuint8mf8_t, vuint16mf4_t, vuint16mf4_t, vuint16mf4_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vsoxseg3ei8_v_m)))
void vsoxseg3ei8_v_u16mf4_m(vbool64_t, uint16_t *, vuint8mf8_t, vuint16mf4_t, vuint16mf4_t, vuint16mf4_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vsoxseg4ei8_v)))
void vsoxseg4ei8_v_i16m1(int16_t *, vuint8mf2_t, vint16m1_t, vint16m1_t, vint16m1_t, vint16m1_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vsoxseg4ei8_v_m)))
void vsoxseg4ei8_v_i16m1_m(vbool16_t, int16_t *, vuint8mf2_t, vint16m1_t, vint16m1_t, vint16m1_t, vint16m1_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vsoxseg4ei8_v)))
void vsoxseg4ei8_v_i16m2(int16_t *, vuint8m1_t, vint16m2_t, vint16m2_t, vint16m2_t, vint16m2_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vsoxseg4ei8_v_m)))
void vsoxseg4ei8_v_i16m2_m(vbool8_t, int16_t *, vuint8m1_t, vint16m2_t, vint16m2_t, vint16m2_t, vint16m2_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vsoxseg4ei8_v)))
void vsoxseg4ei8_v_i16mf2(int16_t *, vuint8mf4_t, vint16mf2_t, vint16mf2_t, vint16mf2_t, vint16mf2_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vsoxseg4ei8_v_m)))
void vsoxseg4ei8_v_i16mf2_m(vbool32_t, int16_t *, vuint8mf4_t, vint16mf2_t, vint16mf2_t, vint16mf2_t, vint16mf2_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vsoxseg4ei8_v)))
void vsoxseg4ei8_v_i16mf4(int16_t *, vuint8mf8_t, vint16mf4_t, vint16mf4_t, vint16mf4_t, vint16mf4_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vsoxseg4ei8_v_m)))
void vsoxseg4ei8_v_i16mf4_m(vbool64_t, int16_t *, vuint8mf8_t, vint16mf4_t, vint16mf4_t, vint16mf4_t, vint16mf4_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vsoxseg4ei8_v)))
void vsoxseg4ei8_v_u16m1(uint16_t *, vuint8mf2_t, vuint16m1_t, vuint16m1_t, vuint16m1_t, vuint16m1_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vsoxseg4ei8_v_m)))
void vsoxseg4ei8_v_u16m1_m(vbool16_t, uint16_t *, vuint8mf2_t, vuint16m1_t, vuint16m1_t, vuint16m1_t, vuint16m1_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vsoxseg4ei8_v)))
void vsoxseg4ei8_v_u16m2(uint16_t *, vuint8m1_t, vuint16m2_t, vuint16m2_t, vuint16m2_t, vuint16m2_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vsoxseg4ei8_v_m)))
void vsoxseg4ei8_v_u16m2_m(vbool8_t, uint16_t *, vuint8m1_t, vuint16m2_t, vuint16m2_t, vuint16m2_t, vuint16m2_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vsoxseg4ei8_v)))
void vsoxseg4ei8_v_u16mf2(uint16_t *, vuint8mf4_t, vuint16mf2_t, vuint16mf2_t, vuint16mf2_t, vuint16mf2_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vsoxseg4ei8_v_m)))
void vsoxseg4ei8_v_u16mf2_m(vbool32_t, uint16_t *, vuint8mf4_t, vuint16mf2_t, vuint16mf2_t, vuint16mf2_t, vuint16mf2_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vsoxseg4ei8_v)))
void vsoxseg4ei8_v_u16mf4(uint16_t *, vuint8mf8_t, vuint16mf4_t, vuint16mf4_t, vuint16mf4_t, vuint16mf4_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vsoxseg4ei8_v_m)))
void vsoxseg4ei8_v_u16mf4_m(vbool64_t, uint16_t *, vuint8mf8_t, vuint16mf4_t, vuint16mf4_t, vuint16mf4_t, vuint16mf4_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vloxei16_v)))
vuint16m1_t vloxei16_v_u16m1(const uint16_t *, vuint16m1_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vloxei16_v_m)))
vuint16m1_t vloxei16_v_u16m1_m(vbool16_t, vuint16m1_t, const uint16_t *, vuint16m1_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vloxei16_v)))
vuint16m2_t vloxei16_v_u16m2(const uint16_t *, vuint16m2_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vloxei16_v_m)))
vuint16m2_t vloxei16_v_u16m2_m(vbool8_t, vuint16m2_t, const uint16_t *, vuint16m2_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vloxei16_v)))
vuint16m4_t vloxei16_v_u16m4(const uint16_t *, vuint16m4_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vloxei16_v_m)))
vuint16m4_t vloxei16_v_u16m4_m(vbool4_t, vuint16m4_t, const uint16_t *, vuint16m4_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vloxei16_v)))
vuint16m8_t vloxei16_v_u16m8(const uint16_t *, vuint16m8_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vloxei16_v_m)))
vuint16m8_t vloxei16_v_u16m8_m(vbool2_t, vuint16m8_t, const uint16_t *, vuint16m8_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vloxei16_v)))
vuint16mf2_t vloxei16_v_u16mf2(const uint16_t *, vuint16mf2_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vloxei16_v_m)))
vuint16mf2_t vloxei16_v_u16mf2_m(vbool32_t, vuint16mf2_t, const uint16_t *, vuint16mf2_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vloxei16_v)))
vuint16mf4_t vloxei16_v_u16mf4(const uint16_t *, vuint16mf4_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vloxei16_v_m)))
vuint16mf4_t vloxei16_v_u16mf4_m(vbool64_t, vuint16mf4_t, const uint16_t *, vuint16mf4_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vsoxseg5ei8_v)))
void vsoxseg5ei8_v_i16m1(int16_t *, vuint8mf2_t, vint16m1_t, vint16m1_t, vint16m1_t, vint16m1_t, vint16m1_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vsoxseg5ei8_v_m)))
void vsoxseg5ei8_v_i16m1_m(vbool16_t, int16_t *, vuint8mf2_t, vint16m1_t, vint16m1_t, vint16m1_t, vint16m1_t, vint16m1_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vsoxseg5ei8_v)))
void vsoxseg5ei8_v_i16mf2(int16_t *, vuint8mf4_t, vint16mf2_t, vint16mf2_t, vint16mf2_t, vint16mf2_t, vint16mf2_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vsoxseg5ei8_v_m)))
void vsoxseg5ei8_v_i16mf2_m(vbool32_t, int16_t *, vuint8mf4_t, vint16mf2_t, vint16mf2_t, vint16mf2_t, vint16mf2_t, vint16mf2_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vsoxseg5ei8_v)))
void vsoxseg5ei8_v_i16mf4(int16_t *, vuint8mf8_t, vint16mf4_t, vint16mf4_t, vint16mf4_t, vint16mf4_t, vint16mf4_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vsoxseg5ei8_v_m)))
void vsoxseg5ei8_v_i16mf4_m(vbool64_t, int16_t *, vuint8mf8_t, vint16mf4_t, vint16mf4_t, vint16mf4_t, vint16mf4_t, vint16mf4_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vsoxseg5ei8_v)))
void vsoxseg5ei8_v_u16m1(uint16_t *, vuint8mf2_t, vuint16m1_t, vuint16m1_t, vuint16m1_t, vuint16m1_t, vuint16m1_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vsoxseg5ei8_v_m)))
void vsoxseg5ei8_v_u16m1_m(vbool16_t, uint16_t *, vuint8mf2_t, vuint16m1_t, vuint16m1_t, vuint16m1_t, vuint16m1_t, vuint16m1_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vsoxseg5ei8_v)))
void vsoxseg5ei8_v_u16mf2(uint16_t *, vuint8mf4_t, vuint16mf2_t, vuint16mf2_t, vuint16mf2_t, vuint16mf2_t, vuint16mf2_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vsoxseg5ei8_v_m)))
void vsoxseg5ei8_v_u16mf2_m(vbool32_t, uint16_t *, vuint8mf4_t, vuint16mf2_t, vuint16mf2_t, vuint16mf2_t, vuint16mf2_t, vuint16mf2_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vsoxseg5ei8_v)))
void vsoxseg5ei8_v_u16mf4(uint16_t *, vuint8mf8_t, vuint16mf4_t, vuint16mf4_t, vuint16mf4_t, vuint16mf4_t, vuint16mf4_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vsoxseg5ei8_v_m)))
void vsoxseg5ei8_v_u16mf4_m(vbool64_t, uint16_t *, vuint8mf8_t, vuint16mf4_t, vuint16mf4_t, vuint16mf4_t, vuint16mf4_t, vuint16mf4_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vsoxseg6ei8_v)))
void vsoxseg6ei8_v_i16m1(int16_t *, vuint8mf2_t, vint16m1_t, vint16m1_t, vint16m1_t, vint16m1_t, vint16m1_t, vint16m1_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vsoxseg6ei8_v_m)))
void vsoxseg6ei8_v_i16m1_m(vbool16_t, int16_t *, vuint8mf2_t, vint16m1_t, vint16m1_t, vint16m1_t, vint16m1_t, vint16m1_t, vint16m1_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vsoxseg6ei8_v)))
void vsoxseg6ei8_v_i16mf2(int16_t *, vuint8mf4_t, vint16mf2_t, vint16mf2_t, vint16mf2_t, vint16mf2_t, vint16mf2_t, vint16mf2_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vsoxseg6ei8_v_m)))
void vsoxseg6ei8_v_i16mf2_m(vbool32_t, int16_t *, vuint8mf4_t, vint16mf2_t, vint16mf2_t, vint16mf2_t, vint16mf2_t, vint16mf2_t, vint16mf2_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vsoxseg6ei8_v)))
void vsoxseg6ei8_v_i16mf4(int16_t *, vuint8mf8_t, vint16mf4_t, vint16mf4_t, vint16mf4_t, vint16mf4_t, vint16mf4_t, vint16mf4_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vsoxseg6ei8_v_m)))
void vsoxseg6ei8_v_i16mf4_m(vbool64_t, int16_t *, vuint8mf8_t, vint16mf4_t, vint16mf4_t, vint16mf4_t, vint16mf4_t, vint16mf4_t, vint16mf4_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vsoxseg6ei8_v)))
void vsoxseg6ei8_v_u16m1(uint16_t *, vuint8mf2_t, vuint16m1_t, vuint16m1_t, vuint16m1_t, vuint16m1_t, vuint16m1_t, vuint16m1_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vsoxseg6ei8_v_m)))
void vsoxseg6ei8_v_u16m1_m(vbool16_t, uint16_t *, vuint8mf2_t, vuint16m1_t, vuint16m1_t, vuint16m1_t, vuint16m1_t, vuint16m1_t, vuint16m1_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vsoxseg6ei8_v)))
void vsoxseg6ei8_v_u16mf2(uint16_t *, vuint8mf4_t, vuint16mf2_t, vuint16mf2_t, vuint16mf2_t, vuint16mf2_t, vuint16mf2_t, vuint16mf2_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vsoxseg6ei8_v_m)))
void vsoxseg6ei8_v_u16mf2_m(vbool32_t, uint16_t *, vuint8mf4_t, vuint16mf2_t, vuint16mf2_t, vuint16mf2_t, vuint16mf2_t, vuint16mf2_t, vuint16mf2_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vsoxseg6ei8_v)))
void vsoxseg6ei8_v_u16mf4(uint16_t *, vuint8mf8_t, vuint16mf4_t, vuint16mf4_t, vuint16mf4_t, vuint16mf4_t, vuint16mf4_t, vuint16mf4_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vsoxseg6ei8_v_m)))
void vsoxseg6ei8_v_u16mf4_m(vbool64_t, uint16_t *, vuint8mf8_t, vuint16mf4_t, vuint16mf4_t, vuint16mf4_t, vuint16mf4_t, vuint16mf4_t, vuint16mf4_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vsoxseg7ei8_v)))
void vsoxseg7ei8_v_i16m1(int16_t *, vuint8mf2_t, vint16m1_t, vint16m1_t, vint16m1_t, vint16m1_t, vint16m1_t, vint16m1_t, vint16m1_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vsoxseg7ei8_v_m)))
void vsoxseg7ei8_v_i16m1_m(vbool16_t, int16_t *, vuint8mf2_t, vint16m1_t, vint16m1_t, vint16m1_t, vint16m1_t, vint16m1_t, vint16m1_t, vint16m1_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vsoxseg7ei8_v)))
void vsoxseg7ei8_v_i16mf2(int16_t *, vuint8mf4_t, vint16mf2_t, vint16mf2_t, vint16mf2_t, vint16mf2_t, vint16mf2_t, vint16mf2_t, vint16mf2_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vsoxseg7ei8_v_m)))
void vsoxseg7ei8_v_i16mf2_m(vbool32_t, int16_t *, vuint8mf4_t, vint16mf2_t, vint16mf2_t, vint16mf2_t, vint16mf2_t, vint16mf2_t, vint16mf2_t, vint16mf2_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vsoxseg7ei8_v)))
void vsoxseg7ei8_v_i16mf4(int16_t *, vuint8mf8_t, vint16mf4_t, vint16mf4_t, vint16mf4_t, vint16mf4_t, vint16mf4_t, vint16mf4_t, vint16mf4_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vsoxseg7ei8_v_m)))
void vsoxseg7ei8_v_i16mf4_m(vbool64_t, int16_t *, vuint8mf8_t, vint16mf4_t, vint16mf4_t, vint16mf4_t, vint16mf4_t, vint16mf4_t, vint16mf4_t, vint16mf4_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vsoxseg7ei8_v)))
void vsoxseg7ei8_v_u16m1(uint16_t *, vuint8mf2_t, vuint16m1_t, vuint16m1_t, vuint16m1_t, vuint16m1_t, vuint16m1_t, vuint16m1_t, vuint16m1_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vsoxseg7ei8_v_m)))
void vsoxseg7ei8_v_u16m1_m(vbool16_t, uint16_t *, vuint8mf2_t, vuint16m1_t, vuint16m1_t, vuint16m1_t, vuint16m1_t, vuint16m1_t, vuint16m1_t, vuint16m1_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vsoxseg7ei8_v)))
void vsoxseg7ei8_v_u16mf2(uint16_t *, vuint8mf4_t, vuint16mf2_t, vuint16mf2_t, vuint16mf2_t, vuint16mf2_t, vuint16mf2_t, vuint16mf2_t, vuint16mf2_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vsoxseg7ei8_v_m)))
void vsoxseg7ei8_v_u16mf2_m(vbool32_t, uint16_t *, vuint8mf4_t, vuint16mf2_t, vuint16mf2_t, vuint16mf2_t, vuint16mf2_t, vuint16mf2_t, vuint16mf2_t, vuint16mf2_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vsoxseg7ei8_v)))
void vsoxseg7ei8_v_u16mf4(uint16_t *, vuint8mf8_t, vuint16mf4_t, vuint16mf4_t, vuint16mf4_t, vuint16mf4_t, vuint16mf4_t, vuint16mf4_t, vuint16mf4_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vsoxseg7ei8_v_m)))
void vsoxseg7ei8_v_u16mf4_m(vbool64_t, uint16_t *, vuint8mf8_t, vuint16mf4_t, vuint16mf4_t, vuint16mf4_t, vuint16mf4_t, vuint16mf4_t, vuint16mf4_t, vuint16mf4_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vsoxseg8ei8_v)))
void vsoxseg8ei8_v_i16m1(int16_t *, vuint8mf2_t, vint16m1_t, vint16m1_t, vint16m1_t, vint16m1_t, vint16m1_t, vint16m1_t, vint16m1_t, vint16m1_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vsoxseg8ei8_v_m)))
void vsoxseg8ei8_v_i16m1_m(vbool16_t, int16_t *, vuint8mf2_t, vint16m1_t, vint16m1_t, vint16m1_t, vint16m1_t, vint16m1_t, vint16m1_t, vint16m1_t, vint16m1_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vsoxseg8ei8_v)))
void vsoxseg8ei8_v_i16mf2(int16_t *, vuint8mf4_t, vint16mf2_t, vint16mf2_t, vint16mf2_t, vint16mf2_t, vint16mf2_t, vint16mf2_t, vint16mf2_t, vint16mf2_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vsoxseg8ei8_v_m)))
void vsoxseg8ei8_v_i16mf2_m(vbool32_t, int16_t *, vuint8mf4_t, vint16mf2_t, vint16mf2_t, vint16mf2_t, vint16mf2_t, vint16mf2_t, vint16mf2_t, vint16mf2_t, vint16mf2_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vsoxseg8ei8_v)))
void vsoxseg8ei8_v_i16mf4(int16_t *, vuint8mf8_t, vint16mf4_t, vint16mf4_t, vint16mf4_t, vint16mf4_t, vint16mf4_t, vint16mf4_t, vint16mf4_t, vint16mf4_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vsoxseg8ei8_v_m)))
void vsoxseg8ei8_v_i16mf4_m(vbool64_t, int16_t *, vuint8mf8_t, vint16mf4_t, vint16mf4_t, vint16mf4_t, vint16mf4_t, vint16mf4_t, vint16mf4_t, vint16mf4_t, vint16mf4_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vsoxseg8ei8_v)))
void vsoxseg8ei8_v_u16m1(uint16_t *, vuint8mf2_t, vuint16m1_t, vuint16m1_t, vuint16m1_t, vuint16m1_t, vuint16m1_t, vuint16m1_t, vuint16m1_t, vuint16m1_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vsoxseg8ei8_v_m)))
void vsoxseg8ei8_v_u16m1_m(vbool16_t, uint16_t *, vuint8mf2_t, vuint16m1_t, vuint16m1_t, vuint16m1_t, vuint16m1_t, vuint16m1_t, vuint16m1_t, vuint16m1_t, vuint16m1_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vsoxseg8ei8_v)))
void vsoxseg8ei8_v_u16mf2(uint16_t *, vuint8mf4_t, vuint16mf2_t, vuint16mf2_t, vuint16mf2_t, vuint16mf2_t, vuint16mf2_t, vuint16mf2_t, vuint16mf2_t, vuint16mf2_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vsoxseg8ei8_v_m)))
void vsoxseg8ei8_v_u16mf2_m(vbool32_t, uint16_t *, vuint8mf4_t, vuint16mf2_t, vuint16mf2_t, vuint16mf2_t, vuint16mf2_t, vuint16mf2_t, vuint16mf2_t, vuint16mf2_t, vuint16mf2_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vsoxseg8ei8_v)))
void vsoxseg8ei8_v_u16mf4(uint16_t *, vuint8mf8_t, vuint16mf4_t, vuint16mf4_t, vuint16mf4_t, vuint16mf4_t, vuint16mf4_t, vuint16mf4_t, vuint16mf4_t, vuint16mf4_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vsoxseg8ei8_v_m)))
void vsoxseg8ei8_v_u16mf4_m(vbool64_t, uint16_t *, vuint8mf8_t, vuint16mf4_t, vuint16mf4_t, vuint16mf4_t, vuint16mf4_t, vuint16mf4_t, vuint16mf4_t, vuint16mf4_t, vuint16mf4_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vsoxseg2ei16_v)))
void vsoxseg2ei16_v_i16m1(int16_t *, vuint16m1_t, vint16m1_t, vint16m1_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vsoxseg2ei16_v_m)))
void vsoxseg2ei16_v_i16m1_m(vbool16_t, int16_t *, vuint16m1_t, vint16m1_t, vint16m1_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vsoxseg2ei16_v)))
void vsoxseg2ei16_v_i16m2(int16_t *, vuint16m2_t, vint16m2_t, vint16m2_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vsoxseg2ei16_v_m)))
void vsoxseg2ei16_v_i16m2_m(vbool8_t, int16_t *, vuint16m2_t, vint16m2_t, vint16m2_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vsoxseg2ei16_v)))
void vsoxseg2ei16_v_i16m4(int16_t *, vuint16m4_t, vint16m4_t, vint16m4_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vsoxseg2ei16_v_m)))
void vsoxseg2ei16_v_i16m4_m(vbool4_t, int16_t *, vuint16m4_t, vint16m4_t, vint16m4_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vsoxseg2ei16_v)))
void vsoxseg2ei16_v_i16mf2(int16_t *, vuint16mf2_t, vint16mf2_t, vint16mf2_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vsoxseg2ei16_v_m)))
void vsoxseg2ei16_v_i16mf2_m(vbool32_t, int16_t *, vuint16mf2_t, vint16mf2_t, vint16mf2_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vsoxseg2ei16_v)))
void vsoxseg2ei16_v_i16mf4(int16_t *, vuint16mf4_t, vint16mf4_t, vint16mf4_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vsoxseg2ei16_v_m)))
void vsoxseg2ei16_v_i16mf4_m(vbool64_t, int16_t *, vuint16mf4_t, vint16mf4_t, vint16mf4_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vsoxseg2ei16_v)))
void vsoxseg2ei16_v_u16m1(uint16_t *, vuint16m1_t, vuint16m1_t, vuint16m1_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vsoxseg2ei16_v_m)))
void vsoxseg2ei16_v_u16m1_m(vbool16_t, uint16_t *, vuint16m1_t, vuint16m1_t, vuint16m1_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vsoxseg2ei16_v)))
void vsoxseg2ei16_v_u16m2(uint16_t *, vuint16m2_t, vuint16m2_t, vuint16m2_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vsoxseg2ei16_v_m)))
void vsoxseg2ei16_v_u16m2_m(vbool8_t, uint16_t *, vuint16m2_t, vuint16m2_t, vuint16m2_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vsoxseg2ei16_v)))
void vsoxseg2ei16_v_u16m4(uint16_t *, vuint16m4_t, vuint16m4_t, vuint16m4_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vsoxseg2ei16_v_m)))
void vsoxseg2ei16_v_u16m4_m(vbool4_t, uint16_t *, vuint16m4_t, vuint16m4_t, vuint16m4_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vsoxseg2ei16_v)))
void vsoxseg2ei16_v_u16mf2(uint16_t *, vuint16mf2_t, vuint16mf2_t, vuint16mf2_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vsoxseg2ei16_v_m)))
void vsoxseg2ei16_v_u16mf2_m(vbool32_t, uint16_t *, vuint16mf2_t, vuint16mf2_t, vuint16mf2_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vsoxseg2ei16_v)))
void vsoxseg2ei16_v_u16mf4(uint16_t *, vuint16mf4_t, vuint16mf4_t, vuint16mf4_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vsoxseg2ei16_v_m)))
void vsoxseg2ei16_v_u16mf4_m(vbool64_t, uint16_t *, vuint16mf4_t, vuint16mf4_t, vuint16mf4_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vloxei32_v)))
vint16m1_t vloxei32_v_i16m1(const int16_t *, vuint32m2_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vloxei32_v_m)))
vint16m1_t vloxei32_v_i16m1_m(vbool16_t, vint16m1_t, const int16_t *, vuint32m2_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vloxei32_v)))
vint16m2_t vloxei32_v_i16m2(const int16_t *, vuint32m4_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vloxei32_v_m)))
vint16m2_t vloxei32_v_i16m2_m(vbool8_t, vint16m2_t, const int16_t *, vuint32m4_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vloxei32_v)))
vint16m4_t vloxei32_v_i16m4(const int16_t *, vuint32m8_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vloxei32_v_m)))
vint16m4_t vloxei32_v_i16m4_m(vbool4_t, vint16m4_t, const int16_t *, vuint32m8_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vloxei32_v)))
vint16mf2_t vloxei32_v_i16mf2(const int16_t *, vuint32m1_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vloxei32_v_m)))
vint16mf2_t vloxei32_v_i16mf2_m(vbool32_t, vint16mf2_t, const int16_t *, vuint32m1_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vloxei32_v)))
vint16mf4_t vloxei32_v_i16mf4(const int16_t *, vuint32mf2_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vloxei32_v_m)))
vint16mf4_t vloxei32_v_i16mf4_m(vbool64_t, vint16mf4_t, const int16_t *, vuint32mf2_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vsoxseg3ei16_v)))
void vsoxseg3ei16_v_i16m1(int16_t *, vuint16m1_t, vint16m1_t, vint16m1_t, vint16m1_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vsoxseg3ei16_v_m)))
void vsoxseg3ei16_v_i16m1_m(vbool16_t, int16_t *, vuint16m1_t, vint16m1_t, vint16m1_t, vint16m1_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vsoxseg3ei16_v)))
void vsoxseg3ei16_v_i16m2(int16_t *, vuint16m2_t, vint16m2_t, vint16m2_t, vint16m2_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vsoxseg3ei16_v_m)))
void vsoxseg3ei16_v_i16m2_m(vbool8_t, int16_t *, vuint16m2_t, vint16m2_t, vint16m2_t, vint16m2_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vsoxseg3ei16_v)))
void vsoxseg3ei16_v_i16mf2(int16_t *, vuint16mf2_t, vint16mf2_t, vint16mf2_t, vint16mf2_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vsoxseg3ei16_v_m)))
void vsoxseg3ei16_v_i16mf2_m(vbool32_t, int16_t *, vuint16mf2_t, vint16mf2_t, vint16mf2_t, vint16mf2_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vsoxseg3ei16_v)))
void vsoxseg3ei16_v_i16mf4(int16_t *, vuint16mf4_t, vint16mf4_t, vint16mf4_t, vint16mf4_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vsoxseg3ei16_v_m)))
void vsoxseg3ei16_v_i16mf4_m(vbool64_t, int16_t *, vuint16mf4_t, vint16mf4_t, vint16mf4_t, vint16mf4_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vsoxseg3ei16_v)))
void vsoxseg3ei16_v_u16m1(uint16_t *, vuint16m1_t, vuint16m1_t, vuint16m1_t, vuint16m1_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vsoxseg3ei16_v_m)))
void vsoxseg3ei16_v_u16m1_m(vbool16_t, uint16_t *, vuint16m1_t, vuint16m1_t, vuint16m1_t, vuint16m1_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vsoxseg3ei16_v)))
void vsoxseg3ei16_v_u16m2(uint16_t *, vuint16m2_t, vuint16m2_t, vuint16m2_t, vuint16m2_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vsoxseg3ei16_v_m)))
void vsoxseg3ei16_v_u16m2_m(vbool8_t, uint16_t *, vuint16m2_t, vuint16m2_t, vuint16m2_t, vuint16m2_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vsoxseg3ei16_v)))
void vsoxseg3ei16_v_u16mf2(uint16_t *, vuint16mf2_t, vuint16mf2_t, vuint16mf2_t, vuint16mf2_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vsoxseg3ei16_v_m)))
void vsoxseg3ei16_v_u16mf2_m(vbool32_t, uint16_t *, vuint16mf2_t, vuint16mf2_t, vuint16mf2_t, vuint16mf2_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vsoxseg3ei16_v)))
void vsoxseg3ei16_v_u16mf4(uint16_t *, vuint16mf4_t, vuint16mf4_t, vuint16mf4_t, vuint16mf4_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vsoxseg3ei16_v_m)))
void vsoxseg3ei16_v_u16mf4_m(vbool64_t, uint16_t *, vuint16mf4_t, vuint16mf4_t, vuint16mf4_t, vuint16mf4_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vsoxseg4ei16_v)))
void vsoxseg4ei16_v_i16m1(int16_t *, vuint16m1_t, vint16m1_t, vint16m1_t, vint16m1_t, vint16m1_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vsoxseg4ei16_v_m)))
void vsoxseg4ei16_v_i16m1_m(vbool16_t, int16_t *, vuint16m1_t, vint16m1_t, vint16m1_t, vint16m1_t, vint16m1_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vsoxseg4ei16_v)))
void vsoxseg4ei16_v_i16m2(int16_t *, vuint16m2_t, vint16m2_t, vint16m2_t, vint16m2_t, vint16m2_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vsoxseg4ei16_v_m)))
void vsoxseg4ei16_v_i16m2_m(vbool8_t, int16_t *, vuint16m2_t, vint16m2_t, vint16m2_t, vint16m2_t, vint16m2_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vsoxseg4ei16_v)))
void vsoxseg4ei16_v_i16mf2(int16_t *, vuint16mf2_t, vint16mf2_t, vint16mf2_t, vint16mf2_t, vint16mf2_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vsoxseg4ei16_v_m)))
void vsoxseg4ei16_v_i16mf2_m(vbool32_t, int16_t *, vuint16mf2_t, vint16mf2_t, vint16mf2_t, vint16mf2_t, vint16mf2_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vsoxseg4ei16_v)))
void vsoxseg4ei16_v_i16mf4(int16_t *, vuint16mf4_t, vint16mf4_t, vint16mf4_t, vint16mf4_t, vint16mf4_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vsoxseg4ei16_v_m)))
void vsoxseg4ei16_v_i16mf4_m(vbool64_t, int16_t *, vuint16mf4_t, vint16mf4_t, vint16mf4_t, vint16mf4_t, vint16mf4_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vsoxseg4ei16_v)))
void vsoxseg4ei16_v_u16m1(uint16_t *, vuint16m1_t, vuint16m1_t, vuint16m1_t, vuint16m1_t, vuint16m1_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vsoxseg4ei16_v_m)))
void vsoxseg4ei16_v_u16m1_m(vbool16_t, uint16_t *, vuint16m1_t, vuint16m1_t, vuint16m1_t, vuint16m1_t, vuint16m1_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vsoxseg4ei16_v)))
void vsoxseg4ei16_v_u16m2(uint16_t *, vuint16m2_t, vuint16m2_t, vuint16m2_t, vuint16m2_t, vuint16m2_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vsoxseg4ei16_v_m)))
void vsoxseg4ei16_v_u16m2_m(vbool8_t, uint16_t *, vuint16m2_t, vuint16m2_t, vuint16m2_t, vuint16m2_t, vuint16m2_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vsoxseg4ei16_v)))
void vsoxseg4ei16_v_u16mf2(uint16_t *, vuint16mf2_t, vuint16mf2_t, vuint16mf2_t, vuint16mf2_t, vuint16mf2_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vsoxseg4ei16_v_m)))
void vsoxseg4ei16_v_u16mf2_m(vbool32_t, uint16_t *, vuint16mf2_t, vuint16mf2_t, vuint16mf2_t, vuint16mf2_t, vuint16mf2_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vsoxseg4ei16_v)))
void vsoxseg4ei16_v_u16mf4(uint16_t *, vuint16mf4_t, vuint16mf4_t, vuint16mf4_t, vuint16mf4_t, vuint16mf4_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vsoxseg4ei16_v_m)))
void vsoxseg4ei16_v_u16mf4_m(vbool64_t, uint16_t *, vuint16mf4_t, vuint16mf4_t, vuint16mf4_t, vuint16mf4_t, vuint16mf4_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vsoxseg5ei16_v)))
void vsoxseg5ei16_v_i16m1(int16_t *, vuint16m1_t, vint16m1_t, vint16m1_t, vint16m1_t, vint16m1_t, vint16m1_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vsoxseg5ei16_v_m)))
void vsoxseg5ei16_v_i16m1_m(vbool16_t, int16_t *, vuint16m1_t, vint16m1_t, vint16m1_t, vint16m1_t, vint16m1_t, vint16m1_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vsoxseg5ei16_v)))
void vsoxseg5ei16_v_i16mf2(int16_t *, vuint16mf2_t, vint16mf2_t, vint16mf2_t, vint16mf2_t, vint16mf2_t, vint16mf2_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vsoxseg5ei16_v_m)))
void vsoxseg5ei16_v_i16mf2_m(vbool32_t, int16_t *, vuint16mf2_t, vint16mf2_t, vint16mf2_t, vint16mf2_t, vint16mf2_t, vint16mf2_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vsoxseg5ei16_v)))
void vsoxseg5ei16_v_i16mf4(int16_t *, vuint16mf4_t, vint16mf4_t, vint16mf4_t, vint16mf4_t, vint16mf4_t, vint16mf4_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vsoxseg5ei16_v_m)))
void vsoxseg5ei16_v_i16mf4_m(vbool64_t, int16_t *, vuint16mf4_t, vint16mf4_t, vint16mf4_t, vint16mf4_t, vint16mf4_t, vint16mf4_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vsoxseg5ei16_v)))
void vsoxseg5ei16_v_u16m1(uint16_t *, vuint16m1_t, vuint16m1_t, vuint16m1_t, vuint16m1_t, vuint16m1_t, vuint16m1_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vsoxseg5ei16_v_m)))
void vsoxseg5ei16_v_u16m1_m(vbool16_t, uint16_t *, vuint16m1_t, vuint16m1_t, vuint16m1_t, vuint16m1_t, vuint16m1_t, vuint16m1_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vsoxseg5ei16_v)))
void vsoxseg5ei16_v_u16mf2(uint16_t *, vuint16mf2_t, vuint16mf2_t, vuint16mf2_t, vuint16mf2_t, vuint16mf2_t, vuint16mf2_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vsoxseg5ei16_v_m)))
void vsoxseg5ei16_v_u16mf2_m(vbool32_t, uint16_t *, vuint16mf2_t, vuint16mf2_t, vuint16mf2_t, vuint16mf2_t, vuint16mf2_t, vuint16mf2_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vsoxseg5ei16_v)))
void vsoxseg5ei16_v_u16mf4(uint16_t *, vuint16mf4_t, vuint16mf4_t, vuint16mf4_t, vuint16mf4_t, vuint16mf4_t, vuint16mf4_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vsoxseg5ei16_v_m)))
void vsoxseg5ei16_v_u16mf4_m(vbool64_t, uint16_t *, vuint16mf4_t, vuint16mf4_t, vuint16mf4_t, vuint16mf4_t, vuint16mf4_t, vuint16mf4_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vsoxseg6ei16_v)))
void vsoxseg6ei16_v_i16m1(int16_t *, vuint16m1_t, vint16m1_t, vint16m1_t, vint16m1_t, vint16m1_t, vint16m1_t, vint16m1_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vsoxseg6ei16_v_m)))
void vsoxseg6ei16_v_i16m1_m(vbool16_t, int16_t *, vuint16m1_t, vint16m1_t, vint16m1_t, vint16m1_t, vint16m1_t, vint16m1_t, vint16m1_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vsoxseg6ei16_v)))
void vsoxseg6ei16_v_i16mf2(int16_t *, vuint16mf2_t, vint16mf2_t, vint16mf2_t, vint16mf2_t, vint16mf2_t, vint16mf2_t, vint16mf2_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vsoxseg6ei16_v_m)))
void vsoxseg6ei16_v_i16mf2_m(vbool32_t, int16_t *, vuint16mf2_t, vint16mf2_t, vint16mf2_t, vint16mf2_t, vint16mf2_t, vint16mf2_t, vint16mf2_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vsoxseg6ei16_v)))
void vsoxseg6ei16_v_i16mf4(int16_t *, vuint16mf4_t, vint16mf4_t, vint16mf4_t, vint16mf4_t, vint16mf4_t, vint16mf4_t, vint16mf4_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vsoxseg6ei16_v_m)))
void vsoxseg6ei16_v_i16mf4_m(vbool64_t, int16_t *, vuint16mf4_t, vint16mf4_t, vint16mf4_t, vint16mf4_t, vint16mf4_t, vint16mf4_t, vint16mf4_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vsoxseg6ei16_v)))
void vsoxseg6ei16_v_u16m1(uint16_t *, vuint16m1_t, vuint16m1_t, vuint16m1_t, vuint16m1_t, vuint16m1_t, vuint16m1_t, vuint16m1_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vsoxseg6ei16_v_m)))
void vsoxseg6ei16_v_u16m1_m(vbool16_t, uint16_t *, vuint16m1_t, vuint16m1_t, vuint16m1_t, vuint16m1_t, vuint16m1_t, vuint16m1_t, vuint16m1_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vsoxseg6ei16_v)))
void vsoxseg6ei16_v_u16mf2(uint16_t *, vuint16mf2_t, vuint16mf2_t, vuint16mf2_t, vuint16mf2_t, vuint16mf2_t, vuint16mf2_t, vuint16mf2_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vsoxseg6ei16_v_m)))
void vsoxseg6ei16_v_u16mf2_m(vbool32_t, uint16_t *, vuint16mf2_t, vuint16mf2_t, vuint16mf2_t, vuint16mf2_t, vuint16mf2_t, vuint16mf2_t, vuint16mf2_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vsoxseg6ei16_v)))
void vsoxseg6ei16_v_u16mf4(uint16_t *, vuint16mf4_t, vuint16mf4_t, vuint16mf4_t, vuint16mf4_t, vuint16mf4_t, vuint16mf4_t, vuint16mf4_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vsoxseg6ei16_v_m)))
void vsoxseg6ei16_v_u16mf4_m(vbool64_t, uint16_t *, vuint16mf4_t, vuint16mf4_t, vuint16mf4_t, vuint16mf4_t, vuint16mf4_t, vuint16mf4_t, vuint16mf4_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vsoxseg7ei16_v)))
void vsoxseg7ei16_v_i16m1(int16_t *, vuint16m1_t, vint16m1_t, vint16m1_t, vint16m1_t, vint16m1_t, vint16m1_t, vint16m1_t, vint16m1_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vsoxseg7ei16_v_m)))
void vsoxseg7ei16_v_i16m1_m(vbool16_t, int16_t *, vuint16m1_t, vint16m1_t, vint16m1_t, vint16m1_t, vint16m1_t, vint16m1_t, vint16m1_t, vint16m1_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vsoxseg7ei16_v)))
void vsoxseg7ei16_v_i16mf2(int16_t *, vuint16mf2_t, vint16mf2_t, vint16mf2_t, vint16mf2_t, vint16mf2_t, vint16mf2_t, vint16mf2_t, vint16mf2_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vsoxseg7ei16_v_m)))
void vsoxseg7ei16_v_i16mf2_m(vbool32_t, int16_t *, vuint16mf2_t, vint16mf2_t, vint16mf2_t, vint16mf2_t, vint16mf2_t, vint16mf2_t, vint16mf2_t, vint16mf2_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vsoxseg7ei16_v)))
void vsoxseg7ei16_v_i16mf4(int16_t *, vuint16mf4_t, vint16mf4_t, vint16mf4_t, vint16mf4_t, vint16mf4_t, vint16mf4_t, vint16mf4_t, vint16mf4_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vsoxseg7ei16_v_m)))
void vsoxseg7ei16_v_i16mf4_m(vbool64_t, int16_t *, vuint16mf4_t, vint16mf4_t, vint16mf4_t, vint16mf4_t, vint16mf4_t, vint16mf4_t, vint16mf4_t, vint16mf4_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vsoxseg7ei16_v)))
void vsoxseg7ei16_v_u16m1(uint16_t *, vuint16m1_t, vuint16m1_t, vuint16m1_t, vuint16m1_t, vuint16m1_t, vuint16m1_t, vuint16m1_t, vuint16m1_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vsoxseg7ei16_v_m)))
void vsoxseg7ei16_v_u16m1_m(vbool16_t, uint16_t *, vuint16m1_t, vuint16m1_t, vuint16m1_t, vuint16m1_t, vuint16m1_t, vuint16m1_t, vuint16m1_t, vuint16m1_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vsoxseg7ei16_v)))
void vsoxseg7ei16_v_u16mf2(uint16_t *, vuint16mf2_t, vuint16mf2_t, vuint16mf2_t, vuint16mf2_t, vuint16mf2_t, vuint16mf2_t, vuint16mf2_t, vuint16mf2_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vsoxseg7ei16_v_m)))
void vsoxseg7ei16_v_u16mf2_m(vbool32_t, uint16_t *, vuint16mf2_t, vuint16mf2_t, vuint16mf2_t, vuint16mf2_t, vuint16mf2_t, vuint16mf2_t, vuint16mf2_t, vuint16mf2_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vsoxseg7ei16_v)))
void vsoxseg7ei16_v_u16mf4(uint16_t *, vuint16mf4_t, vuint16mf4_t, vuint16mf4_t, vuint16mf4_t, vuint16mf4_t, vuint16mf4_t, vuint16mf4_t, vuint16mf4_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vsoxseg7ei16_v_m)))
void vsoxseg7ei16_v_u16mf4_m(vbool64_t, uint16_t *, vuint16mf4_t, vuint16mf4_t, vuint16mf4_t, vuint16mf4_t, vuint16mf4_t, vuint16mf4_t, vuint16mf4_t, vuint16mf4_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vloxei32_v)))
vuint16m1_t vloxei32_v_u16m1(const uint16_t *, vuint32m2_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vloxei32_v_m)))
vuint16m1_t vloxei32_v_u16m1_m(vbool16_t, vuint16m1_t, const uint16_t *, vuint32m2_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vloxei32_v)))
vuint16m2_t vloxei32_v_u16m2(const uint16_t *, vuint32m4_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vloxei32_v_m)))
vuint16m2_t vloxei32_v_u16m2_m(vbool8_t, vuint16m2_t, const uint16_t *, vuint32m4_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vloxei32_v)))
vuint16m4_t vloxei32_v_u16m4(const uint16_t *, vuint32m8_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vloxei32_v_m)))
vuint16m4_t vloxei32_v_u16m4_m(vbool4_t, vuint16m4_t, const uint16_t *, vuint32m8_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vloxei32_v)))
vuint16mf2_t vloxei32_v_u16mf2(const uint16_t *, vuint32m1_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vloxei32_v_m)))
vuint16mf2_t vloxei32_v_u16mf2_m(vbool32_t, vuint16mf2_t, const uint16_t *, vuint32m1_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vloxei32_v)))
vuint16mf4_t vloxei32_v_u16mf4(const uint16_t *, vuint32mf2_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vloxei32_v_m)))
vuint16mf4_t vloxei32_v_u16mf4_m(vbool64_t, vuint16mf4_t, const uint16_t *, vuint32mf2_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vsoxseg8ei16_v)))
void vsoxseg8ei16_v_i16m1(int16_t *, vuint16m1_t, vint16m1_t, vint16m1_t, vint16m1_t, vint16m1_t, vint16m1_t, vint16m1_t, vint16m1_t, vint16m1_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vsoxseg8ei16_v_m)))
void vsoxseg8ei16_v_i16m1_m(vbool16_t, int16_t *, vuint16m1_t, vint16m1_t, vint16m1_t, vint16m1_t, vint16m1_t, vint16m1_t, vint16m1_t, vint16m1_t, vint16m1_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vsoxseg8ei16_v)))
void vsoxseg8ei16_v_i16mf2(int16_t *, vuint16mf2_t, vint16mf2_t, vint16mf2_t, vint16mf2_t, vint16mf2_t, vint16mf2_t, vint16mf2_t, vint16mf2_t, vint16mf2_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vsoxseg8ei16_v_m)))
void vsoxseg8ei16_v_i16mf2_m(vbool32_t, int16_t *, vuint16mf2_t, vint16mf2_t, vint16mf2_t, vint16mf2_t, vint16mf2_t, vint16mf2_t, vint16mf2_t, vint16mf2_t, vint16mf2_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vsoxseg8ei16_v)))
void vsoxseg8ei16_v_i16mf4(int16_t *, vuint16mf4_t, vint16mf4_t, vint16mf4_t, vint16mf4_t, vint16mf4_t, vint16mf4_t, vint16mf4_t, vint16mf4_t, vint16mf4_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vsoxseg8ei16_v_m)))
void vsoxseg8ei16_v_i16mf4_m(vbool64_t, int16_t *, vuint16mf4_t, vint16mf4_t, vint16mf4_t, vint16mf4_t, vint16mf4_t, vint16mf4_t, vint16mf4_t, vint16mf4_t, vint16mf4_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vsoxseg8ei16_v)))
void vsoxseg8ei16_v_u16m1(uint16_t *, vuint16m1_t, vuint16m1_t, vuint16m1_t, vuint16m1_t, vuint16m1_t, vuint16m1_t, vuint16m1_t, vuint16m1_t, vuint16m1_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vsoxseg8ei16_v_m)))
void vsoxseg8ei16_v_u16m1_m(vbool16_t, uint16_t *, vuint16m1_t, vuint16m1_t, vuint16m1_t, vuint16m1_t, vuint16m1_t, vuint16m1_t, vuint16m1_t, vuint16m1_t, vuint16m1_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vsoxseg8ei16_v)))
void vsoxseg8ei16_v_u16mf2(uint16_t *, vuint16mf2_t, vuint16mf2_t, vuint16mf2_t, vuint16mf2_t, vuint16mf2_t, vuint16mf2_t, vuint16mf2_t, vuint16mf2_t, vuint16mf2_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vsoxseg8ei16_v_m)))
void vsoxseg8ei16_v_u16mf2_m(vbool32_t, uint16_t *, vuint16mf2_t, vuint16mf2_t, vuint16mf2_t, vuint16mf2_t, vuint16mf2_t, vuint16mf2_t, vuint16mf2_t, vuint16mf2_t, vuint16mf2_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vsoxseg8ei16_v)))
void vsoxseg8ei16_v_u16mf4(uint16_t *, vuint16mf4_t, vuint16mf4_t, vuint16mf4_t, vuint16mf4_t, vuint16mf4_t, vuint16mf4_t, vuint16mf4_t, vuint16mf4_t, vuint16mf4_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vsoxseg8ei16_v_m)))
void vsoxseg8ei16_v_u16mf4_m(vbool64_t, uint16_t *, vuint16mf4_t, vuint16mf4_t, vuint16mf4_t, vuint16mf4_t, vuint16mf4_t, vuint16mf4_t, vuint16mf4_t, vuint16mf4_t, vuint16mf4_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vsoxseg2ei32_v)))
void vsoxseg2ei32_v_i16m1(int16_t *, vuint32m2_t, vint16m1_t, vint16m1_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vsoxseg2ei32_v_m)))
void vsoxseg2ei32_v_i16m1_m(vbool16_t, int16_t *, vuint32m2_t, vint16m1_t, vint16m1_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vsoxseg2ei32_v)))
void vsoxseg2ei32_v_i16m2(int16_t *, vuint32m4_t, vint16m2_t, vint16m2_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vsoxseg2ei32_v_m)))
void vsoxseg2ei32_v_i16m2_m(vbool8_t, int16_t *, vuint32m4_t, vint16m2_t, vint16m2_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vsoxseg2ei32_v)))
void vsoxseg2ei32_v_i16m4(int16_t *, vuint32m8_t, vint16m4_t, vint16m4_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vsoxseg2ei32_v_m)))
void vsoxseg2ei32_v_i16m4_m(vbool4_t, int16_t *, vuint32m8_t, vint16m4_t, vint16m4_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vsoxseg2ei32_v)))
void vsoxseg2ei32_v_i16mf2(int16_t *, vuint32m1_t, vint16mf2_t, vint16mf2_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vsoxseg2ei32_v_m)))
void vsoxseg2ei32_v_i16mf2_m(vbool32_t, int16_t *, vuint32m1_t, vint16mf2_t, vint16mf2_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vsoxseg2ei32_v)))
void vsoxseg2ei32_v_i16mf4(int16_t *, vuint32mf2_t, vint16mf4_t, vint16mf4_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vsoxseg2ei32_v_m)))
void vsoxseg2ei32_v_i16mf4_m(vbool64_t, int16_t *, vuint32mf2_t, vint16mf4_t, vint16mf4_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vsoxseg2ei32_v)))
void vsoxseg2ei32_v_u16m1(uint16_t *, vuint32m2_t, vuint16m1_t, vuint16m1_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vsoxseg2ei32_v_m)))
void vsoxseg2ei32_v_u16m1_m(vbool16_t, uint16_t *, vuint32m2_t, vuint16m1_t, vuint16m1_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vsoxseg2ei32_v)))
void vsoxseg2ei32_v_u16m2(uint16_t *, vuint32m4_t, vuint16m2_t, vuint16m2_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vsoxseg2ei32_v_m)))
void vsoxseg2ei32_v_u16m2_m(vbool8_t, uint16_t *, vuint32m4_t, vuint16m2_t, vuint16m2_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vsoxseg2ei32_v)))
void vsoxseg2ei32_v_u16m4(uint16_t *, vuint32m8_t, vuint16m4_t, vuint16m4_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vsoxseg2ei32_v_m)))
void vsoxseg2ei32_v_u16m4_m(vbool4_t, uint16_t *, vuint32m8_t, vuint16m4_t, vuint16m4_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vsoxseg2ei32_v)))
void vsoxseg2ei32_v_u16mf2(uint16_t *, vuint32m1_t, vuint16mf2_t, vuint16mf2_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vsoxseg2ei32_v_m)))
void vsoxseg2ei32_v_u16mf2_m(vbool32_t, uint16_t *, vuint32m1_t, vuint16mf2_t, vuint16mf2_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vsoxseg2ei32_v)))
void vsoxseg2ei32_v_u16mf4(uint16_t *, vuint32mf2_t, vuint16mf4_t, vuint16mf4_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vsoxseg2ei32_v_m)))
void vsoxseg2ei32_v_u16mf4_m(vbool64_t, uint16_t *, vuint32mf2_t, vuint16mf4_t, vuint16mf4_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vsoxseg3ei32_v)))
void vsoxseg3ei32_v_i16m1(int16_t *, vuint32m2_t, vint16m1_t, vint16m1_t, vint16m1_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vsoxseg3ei32_v_m)))
void vsoxseg3ei32_v_i16m1_m(vbool16_t, int16_t *, vuint32m2_t, vint16m1_t, vint16m1_t, vint16m1_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vsoxseg3ei32_v)))
void vsoxseg3ei32_v_i16m2(int16_t *, vuint32m4_t, vint16m2_t, vint16m2_t, vint16m2_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vsoxseg3ei32_v_m)))
void vsoxseg3ei32_v_i16m2_m(vbool8_t, int16_t *, vuint32m4_t, vint16m2_t, vint16m2_t, vint16m2_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vsoxseg3ei32_v)))
void vsoxseg3ei32_v_i16mf2(int16_t *, vuint32m1_t, vint16mf2_t, vint16mf2_t, vint16mf2_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vsoxseg3ei32_v_m)))
void vsoxseg3ei32_v_i16mf2_m(vbool32_t, int16_t *, vuint32m1_t, vint16mf2_t, vint16mf2_t, vint16mf2_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vsoxseg3ei32_v)))
void vsoxseg3ei32_v_i16mf4(int16_t *, vuint32mf2_t, vint16mf4_t, vint16mf4_t, vint16mf4_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vsoxseg3ei32_v_m)))
void vsoxseg3ei32_v_i16mf4_m(vbool64_t, int16_t *, vuint32mf2_t, vint16mf4_t, vint16mf4_t, vint16mf4_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vsoxseg3ei32_v)))
void vsoxseg3ei32_v_u16m1(uint16_t *, vuint32m2_t, vuint16m1_t, vuint16m1_t, vuint16m1_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vsoxseg3ei32_v_m)))
void vsoxseg3ei32_v_u16m1_m(vbool16_t, uint16_t *, vuint32m2_t, vuint16m1_t, vuint16m1_t, vuint16m1_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vsoxseg3ei32_v)))
void vsoxseg3ei32_v_u16m2(uint16_t *, vuint32m4_t, vuint16m2_t, vuint16m2_t, vuint16m2_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vsoxseg3ei32_v_m)))
void vsoxseg3ei32_v_u16m2_m(vbool8_t, uint16_t *, vuint32m4_t, vuint16m2_t, vuint16m2_t, vuint16m2_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vsoxseg3ei32_v)))
void vsoxseg3ei32_v_u16mf2(uint16_t *, vuint32m1_t, vuint16mf2_t, vuint16mf2_t, vuint16mf2_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vsoxseg3ei32_v_m)))
void vsoxseg3ei32_v_u16mf2_m(vbool32_t, uint16_t *, vuint32m1_t, vuint16mf2_t, vuint16mf2_t, vuint16mf2_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vsoxseg3ei32_v)))
void vsoxseg3ei32_v_u16mf4(uint16_t *, vuint32mf2_t, vuint16mf4_t, vuint16mf4_t, vuint16mf4_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vsoxseg3ei32_v_m)))
void vsoxseg3ei32_v_u16mf4_m(vbool64_t, uint16_t *, vuint32mf2_t, vuint16mf4_t, vuint16mf4_t, vuint16mf4_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vsoxseg4ei32_v)))
void vsoxseg4ei32_v_i16m1(int16_t *, vuint32m2_t, vint16m1_t, vint16m1_t, vint16m1_t, vint16m1_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vsoxseg4ei32_v_m)))
void vsoxseg4ei32_v_i16m1_m(vbool16_t, int16_t *, vuint32m2_t, vint16m1_t, vint16m1_t, vint16m1_t, vint16m1_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vsoxseg4ei32_v)))
void vsoxseg4ei32_v_i16m2(int16_t *, vuint32m4_t, vint16m2_t, vint16m2_t, vint16m2_t, vint16m2_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vsoxseg4ei32_v_m)))
void vsoxseg4ei32_v_i16m2_m(vbool8_t, int16_t *, vuint32m4_t, vint16m2_t, vint16m2_t, vint16m2_t, vint16m2_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vsoxseg4ei32_v)))
void vsoxseg4ei32_v_i16mf2(int16_t *, vuint32m1_t, vint16mf2_t, vint16mf2_t, vint16mf2_t, vint16mf2_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vsoxseg4ei32_v_m)))
void vsoxseg4ei32_v_i16mf2_m(vbool32_t, int16_t *, vuint32m1_t, vint16mf2_t, vint16mf2_t, vint16mf2_t, vint16mf2_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vsoxseg4ei32_v)))
void vsoxseg4ei32_v_i16mf4(int16_t *, vuint32mf2_t, vint16mf4_t, vint16mf4_t, vint16mf4_t, vint16mf4_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vsoxseg4ei32_v_m)))
void vsoxseg4ei32_v_i16mf4_m(vbool64_t, int16_t *, vuint32mf2_t, vint16mf4_t, vint16mf4_t, vint16mf4_t, vint16mf4_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vsoxseg4ei32_v)))
void vsoxseg4ei32_v_u16m1(uint16_t *, vuint32m2_t, vuint16m1_t, vuint16m1_t, vuint16m1_t, vuint16m1_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vsoxseg4ei32_v_m)))
void vsoxseg4ei32_v_u16m1_m(vbool16_t, uint16_t *, vuint32m2_t, vuint16m1_t, vuint16m1_t, vuint16m1_t, vuint16m1_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vsoxseg4ei32_v)))
void vsoxseg4ei32_v_u16m2(uint16_t *, vuint32m4_t, vuint16m2_t, vuint16m2_t, vuint16m2_t, vuint16m2_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vsoxseg4ei32_v_m)))
void vsoxseg4ei32_v_u16m2_m(vbool8_t, uint16_t *, vuint32m4_t, vuint16m2_t, vuint16m2_t, vuint16m2_t, vuint16m2_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vsoxseg4ei32_v)))
void vsoxseg4ei32_v_u16mf2(uint16_t *, vuint32m1_t, vuint16mf2_t, vuint16mf2_t, vuint16mf2_t, vuint16mf2_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vsoxseg4ei32_v_m)))
void vsoxseg4ei32_v_u16mf2_m(vbool32_t, uint16_t *, vuint32m1_t, vuint16mf2_t, vuint16mf2_t, vuint16mf2_t, vuint16mf2_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vsoxseg4ei32_v)))
void vsoxseg4ei32_v_u16mf4(uint16_t *, vuint32mf2_t, vuint16mf4_t, vuint16mf4_t, vuint16mf4_t, vuint16mf4_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vsoxseg4ei32_v_m)))
void vsoxseg4ei32_v_u16mf4_m(vbool64_t, uint16_t *, vuint32mf2_t, vuint16mf4_t, vuint16mf4_t, vuint16mf4_t, vuint16mf4_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vsoxseg5ei32_v)))
void vsoxseg5ei32_v_i16m1(int16_t *, vuint32m2_t, vint16m1_t, vint16m1_t, vint16m1_t, vint16m1_t, vint16m1_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vsoxseg5ei32_v_m)))
void vsoxseg5ei32_v_i16m1_m(vbool16_t, int16_t *, vuint32m2_t, vint16m1_t, vint16m1_t, vint16m1_t, vint16m1_t, vint16m1_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vsoxseg5ei32_v)))
void vsoxseg5ei32_v_i16mf2(int16_t *, vuint32m1_t, vint16mf2_t, vint16mf2_t, vint16mf2_t, vint16mf2_t, vint16mf2_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vsoxseg5ei32_v_m)))
void vsoxseg5ei32_v_i16mf2_m(vbool32_t, int16_t *, vuint32m1_t, vint16mf2_t, vint16mf2_t, vint16mf2_t, vint16mf2_t, vint16mf2_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vsoxseg5ei32_v)))
void vsoxseg5ei32_v_i16mf4(int16_t *, vuint32mf2_t, vint16mf4_t, vint16mf4_t, vint16mf4_t, vint16mf4_t, vint16mf4_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vsoxseg5ei32_v_m)))
void vsoxseg5ei32_v_i16mf4_m(vbool64_t, int16_t *, vuint32mf2_t, vint16mf4_t, vint16mf4_t, vint16mf4_t, vint16mf4_t, vint16mf4_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vsoxseg5ei32_v)))
void vsoxseg5ei32_v_u16m1(uint16_t *, vuint32m2_t, vuint16m1_t, vuint16m1_t, vuint16m1_t, vuint16m1_t, vuint16m1_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vsoxseg5ei32_v_m)))
void vsoxseg5ei32_v_u16m1_m(vbool16_t, uint16_t *, vuint32m2_t, vuint16m1_t, vuint16m1_t, vuint16m1_t, vuint16m1_t, vuint16m1_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vsoxseg5ei32_v)))
void vsoxseg5ei32_v_u16mf2(uint16_t *, vuint32m1_t, vuint16mf2_t, vuint16mf2_t, vuint16mf2_t, vuint16mf2_t, vuint16mf2_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vsoxseg5ei32_v_m)))
void vsoxseg5ei32_v_u16mf2_m(vbool32_t, uint16_t *, vuint32m1_t, vuint16mf2_t, vuint16mf2_t, vuint16mf2_t, vuint16mf2_t, vuint16mf2_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vsoxseg5ei32_v)))
void vsoxseg5ei32_v_u16mf4(uint16_t *, vuint32mf2_t, vuint16mf4_t, vuint16mf4_t, vuint16mf4_t, vuint16mf4_t, vuint16mf4_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vsoxseg5ei32_v_m)))
void vsoxseg5ei32_v_u16mf4_m(vbool64_t, uint16_t *, vuint32mf2_t, vuint16mf4_t, vuint16mf4_t, vuint16mf4_t, vuint16mf4_t, vuint16mf4_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vsoxseg6ei32_v)))
void vsoxseg6ei32_v_i16m1(int16_t *, vuint32m2_t, vint16m1_t, vint16m1_t, vint16m1_t, vint16m1_t, vint16m1_t, vint16m1_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vsoxseg6ei32_v_m)))
void vsoxseg6ei32_v_i16m1_m(vbool16_t, int16_t *, vuint32m2_t, vint16m1_t, vint16m1_t, vint16m1_t, vint16m1_t, vint16m1_t, vint16m1_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vsoxseg6ei32_v)))
void vsoxseg6ei32_v_i16mf2(int16_t *, vuint32m1_t, vint16mf2_t, vint16mf2_t, vint16mf2_t, vint16mf2_t, vint16mf2_t, vint16mf2_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vsoxseg6ei32_v_m)))
void vsoxseg6ei32_v_i16mf2_m(vbool32_t, int16_t *, vuint32m1_t, vint16mf2_t, vint16mf2_t, vint16mf2_t, vint16mf2_t, vint16mf2_t, vint16mf2_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vsoxseg6ei32_v)))
void vsoxseg6ei32_v_i16mf4(int16_t *, vuint32mf2_t, vint16mf4_t, vint16mf4_t, vint16mf4_t, vint16mf4_t, vint16mf4_t, vint16mf4_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vsoxseg6ei32_v_m)))
void vsoxseg6ei32_v_i16mf4_m(vbool64_t, int16_t *, vuint32mf2_t, vint16mf4_t, vint16mf4_t, vint16mf4_t, vint16mf4_t, vint16mf4_t, vint16mf4_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vsoxseg6ei32_v)))
void vsoxseg6ei32_v_u16m1(uint16_t *, vuint32m2_t, vuint16m1_t, vuint16m1_t, vuint16m1_t, vuint16m1_t, vuint16m1_t, vuint16m1_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vsoxseg6ei32_v_m)))
void vsoxseg6ei32_v_u16m1_m(vbool16_t, uint16_t *, vuint32m2_t, vuint16m1_t, vuint16m1_t, vuint16m1_t, vuint16m1_t, vuint16m1_t, vuint16m1_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vsoxseg6ei32_v)))
void vsoxseg6ei32_v_u16mf2(uint16_t *, vuint32m1_t, vuint16mf2_t, vuint16mf2_t, vuint16mf2_t, vuint16mf2_t, vuint16mf2_t, vuint16mf2_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vsoxseg6ei32_v_m)))
void vsoxseg6ei32_v_u16mf2_m(vbool32_t, uint16_t *, vuint32m1_t, vuint16mf2_t, vuint16mf2_t, vuint16mf2_t, vuint16mf2_t, vuint16mf2_t, vuint16mf2_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vsoxseg6ei32_v)))
void vsoxseg6ei32_v_u16mf4(uint16_t *, vuint32mf2_t, vuint16mf4_t, vuint16mf4_t, vuint16mf4_t, vuint16mf4_t, vuint16mf4_t, vuint16mf4_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vsoxseg6ei32_v_m)))
void vsoxseg6ei32_v_u16mf4_m(vbool64_t, uint16_t *, vuint32mf2_t, vuint16mf4_t, vuint16mf4_t, vuint16mf4_t, vuint16mf4_t, vuint16mf4_t, vuint16mf4_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vsoxseg7ei32_v)))
void vsoxseg7ei32_v_i16m1(int16_t *, vuint32m2_t, vint16m1_t, vint16m1_t, vint16m1_t, vint16m1_t, vint16m1_t, vint16m1_t, vint16m1_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vsoxseg7ei32_v_m)))
void vsoxseg7ei32_v_i16m1_m(vbool16_t, int16_t *, vuint32m2_t, vint16m1_t, vint16m1_t, vint16m1_t, vint16m1_t, vint16m1_t, vint16m1_t, vint16m1_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vsoxseg7ei32_v)))
void vsoxseg7ei32_v_i16mf2(int16_t *, vuint32m1_t, vint16mf2_t, vint16mf2_t, vint16mf2_t, vint16mf2_t, vint16mf2_t, vint16mf2_t, vint16mf2_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vsoxseg7ei32_v_m)))
void vsoxseg7ei32_v_i16mf2_m(vbool32_t, int16_t *, vuint32m1_t, vint16mf2_t, vint16mf2_t, vint16mf2_t, vint16mf2_t, vint16mf2_t, vint16mf2_t, vint16mf2_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vsoxseg7ei32_v)))
void vsoxseg7ei32_v_i16mf4(int16_t *, vuint32mf2_t, vint16mf4_t, vint16mf4_t, vint16mf4_t, vint16mf4_t, vint16mf4_t, vint16mf4_t, vint16mf4_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vsoxseg7ei32_v_m)))
void vsoxseg7ei32_v_i16mf4_m(vbool64_t, int16_t *, vuint32mf2_t, vint16mf4_t, vint16mf4_t, vint16mf4_t, vint16mf4_t, vint16mf4_t, vint16mf4_t, vint16mf4_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vsoxseg7ei32_v)))
void vsoxseg7ei32_v_u16m1(uint16_t *, vuint32m2_t, vuint16m1_t, vuint16m1_t, vuint16m1_t, vuint16m1_t, vuint16m1_t, vuint16m1_t, vuint16m1_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vsoxseg7ei32_v_m)))
void vsoxseg7ei32_v_u16m1_m(vbool16_t, uint16_t *, vuint32m2_t, vuint16m1_t, vuint16m1_t, vuint16m1_t, vuint16m1_t, vuint16m1_t, vuint16m1_t, vuint16m1_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vsoxseg7ei32_v)))
void vsoxseg7ei32_v_u16mf2(uint16_t *, vuint32m1_t, vuint16mf2_t, vuint16mf2_t, vuint16mf2_t, vuint16mf2_t, vuint16mf2_t, vuint16mf2_t, vuint16mf2_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vsoxseg7ei32_v_m)))
void vsoxseg7ei32_v_u16mf2_m(vbool32_t, uint16_t *, vuint32m1_t, vuint16mf2_t, vuint16mf2_t, vuint16mf2_t, vuint16mf2_t, vuint16mf2_t, vuint16mf2_t, vuint16mf2_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vsoxseg7ei32_v)))
void vsoxseg7ei32_v_u16mf4(uint16_t *, vuint32mf2_t, vuint16mf4_t, vuint16mf4_t, vuint16mf4_t, vuint16mf4_t, vuint16mf4_t, vuint16mf4_t, vuint16mf4_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vsoxseg7ei32_v_m)))
void vsoxseg7ei32_v_u16mf4_m(vbool64_t, uint16_t *, vuint32mf2_t, vuint16mf4_t, vuint16mf4_t, vuint16mf4_t, vuint16mf4_t, vuint16mf4_t, vuint16mf4_t, vuint16mf4_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vsoxseg8ei32_v)))
void vsoxseg8ei32_v_i16m1(int16_t *, vuint32m2_t, vint16m1_t, vint16m1_t, vint16m1_t, vint16m1_t, vint16m1_t, vint16m1_t, vint16m1_t, vint16m1_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vsoxseg8ei32_v_m)))
void vsoxseg8ei32_v_i16m1_m(vbool16_t, int16_t *, vuint32m2_t, vint16m1_t, vint16m1_t, vint16m1_t, vint16m1_t, vint16m1_t, vint16m1_t, vint16m1_t, vint16m1_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vsoxseg8ei32_v)))
void vsoxseg8ei32_v_i16mf2(int16_t *, vuint32m1_t, vint16mf2_t, vint16mf2_t, vint16mf2_t, vint16mf2_t, vint16mf2_t, vint16mf2_t, vint16mf2_t, vint16mf2_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vsoxseg8ei32_v_m)))
void vsoxseg8ei32_v_i16mf2_m(vbool32_t, int16_t *, vuint32m1_t, vint16mf2_t, vint16mf2_t, vint16mf2_t, vint16mf2_t, vint16mf2_t, vint16mf2_t, vint16mf2_t, vint16mf2_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vsoxseg8ei32_v)))
void vsoxseg8ei32_v_i16mf4(int16_t *, vuint32mf2_t, vint16mf4_t, vint16mf4_t, vint16mf4_t, vint16mf4_t, vint16mf4_t, vint16mf4_t, vint16mf4_t, vint16mf4_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vsoxseg8ei32_v_m)))
void vsoxseg8ei32_v_i16mf4_m(vbool64_t, int16_t *, vuint32mf2_t, vint16mf4_t, vint16mf4_t, vint16mf4_t, vint16mf4_t, vint16mf4_t, vint16mf4_t, vint16mf4_t, vint16mf4_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vsoxseg8ei32_v)))
void vsoxseg8ei32_v_u16m1(uint16_t *, vuint32m2_t, vuint16m1_t, vuint16m1_t, vuint16m1_t, vuint16m1_t, vuint16m1_t, vuint16m1_t, vuint16m1_t, vuint16m1_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vsoxseg8ei32_v_m)))
void vsoxseg8ei32_v_u16m1_m(vbool16_t, uint16_t *, vuint32m2_t, vuint16m1_t, vuint16m1_t, vuint16m1_t, vuint16m1_t, vuint16m1_t, vuint16m1_t, vuint16m1_t, vuint16m1_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vsoxseg8ei32_v)))
void vsoxseg8ei32_v_u16mf2(uint16_t *, vuint32m1_t, vuint16mf2_t, vuint16mf2_t, vuint16mf2_t, vuint16mf2_t, vuint16mf2_t, vuint16mf2_t, vuint16mf2_t, vuint16mf2_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vsoxseg8ei32_v_m)))
void vsoxseg8ei32_v_u16mf2_m(vbool32_t, uint16_t *, vuint32m1_t, vuint16mf2_t, vuint16mf2_t, vuint16mf2_t, vuint16mf2_t, vuint16mf2_t, vuint16mf2_t, vuint16mf2_t, vuint16mf2_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vsoxseg8ei32_v)))
void vsoxseg8ei32_v_u16mf4(uint16_t *, vuint32mf2_t, vuint16mf4_t, vuint16mf4_t, vuint16mf4_t, vuint16mf4_t, vuint16mf4_t, vuint16mf4_t, vuint16mf4_t, vuint16mf4_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vsoxseg8ei32_v_m)))
void vsoxseg8ei32_v_u16mf4_m(vbool64_t, uint16_t *, vuint32mf2_t, vuint16mf4_t, vuint16mf4_t, vuint16mf4_t, vuint16mf4_t, vuint16mf4_t, vuint16mf4_t, vuint16mf4_t, vuint16mf4_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vloxei8_v)))
vint32m1_t vloxei8_v_i32m1(const int32_t *, vuint8mf4_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vloxei8_v_m)))
vint32m1_t vloxei8_v_i32m1_m(vbool32_t, vint32m1_t, const int32_t *, vuint8mf4_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vloxei8_v)))
vint32m2_t vloxei8_v_i32m2(const int32_t *, vuint8mf2_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vloxei8_v_m)))
vint32m2_t vloxei8_v_i32m2_m(vbool16_t, vint32m2_t, const int32_t *, vuint8mf2_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vloxei8_v)))
vint32m4_t vloxei8_v_i32m4(const int32_t *, vuint8m1_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vloxei8_v_m)))
vint32m4_t vloxei8_v_i32m4_m(vbool8_t, vint32m4_t, const int32_t *, vuint8m1_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vloxei8_v)))
vint32m8_t vloxei8_v_i32m8(const int32_t *, vuint8m2_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vloxei8_v_m)))
vint32m8_t vloxei8_v_i32m8_m(vbool4_t, vint32m8_t, const int32_t *, vuint8m2_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vloxei8_v)))
vint32mf2_t vloxei8_v_i32mf2(const int32_t *, vuint8mf8_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vloxei8_v_m)))
vint32mf2_t vloxei8_v_i32mf2_m(vbool64_t, vint32mf2_t, const int32_t *, vuint8mf8_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vsoxseg2ei8_v)))
void vsoxseg2ei8_v_i32m1(int32_t *, vuint8mf4_t, vint32m1_t, vint32m1_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vsoxseg2ei8_v_m)))
void vsoxseg2ei8_v_i32m1_m(vbool32_t, int32_t *, vuint8mf4_t, vint32m1_t, vint32m1_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vsoxseg2ei8_v)))
void vsoxseg2ei8_v_i32m2(int32_t *, vuint8mf2_t, vint32m2_t, vint32m2_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vsoxseg2ei8_v_m)))
void vsoxseg2ei8_v_i32m2_m(vbool16_t, int32_t *, vuint8mf2_t, vint32m2_t, vint32m2_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vsoxseg2ei8_v)))
void vsoxseg2ei8_v_i32m4(int32_t *, vuint8m1_t, vint32m4_t, vint32m4_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vsoxseg2ei8_v_m)))
void vsoxseg2ei8_v_i32m4_m(vbool8_t, int32_t *, vuint8m1_t, vint32m4_t, vint32m4_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vsoxseg2ei8_v)))
void vsoxseg2ei8_v_i32mf2(int32_t *, vuint8mf8_t, vint32mf2_t, vint32mf2_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vsoxseg2ei8_v_m)))
void vsoxseg2ei8_v_i32mf2_m(vbool64_t, int32_t *, vuint8mf8_t, vint32mf2_t, vint32mf2_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vsoxseg2ei8_v)))
void vsoxseg2ei8_v_u32m1(uint32_t *, vuint8mf4_t, vuint32m1_t, vuint32m1_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vsoxseg2ei8_v_m)))
void vsoxseg2ei8_v_u32m1_m(vbool32_t, uint32_t *, vuint8mf4_t, vuint32m1_t, vuint32m1_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vsoxseg2ei8_v)))
void vsoxseg2ei8_v_u32m2(uint32_t *, vuint8mf2_t, vuint32m2_t, vuint32m2_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vsoxseg2ei8_v_m)))
void vsoxseg2ei8_v_u32m2_m(vbool16_t, uint32_t *, vuint8mf2_t, vuint32m2_t, vuint32m2_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vsoxseg2ei8_v)))
void vsoxseg2ei8_v_u32m4(uint32_t *, vuint8m1_t, vuint32m4_t, vuint32m4_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vsoxseg2ei8_v_m)))
void vsoxseg2ei8_v_u32m4_m(vbool8_t, uint32_t *, vuint8m1_t, vuint32m4_t, vuint32m4_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vsoxseg2ei8_v)))
void vsoxseg2ei8_v_u32mf2(uint32_t *, vuint8mf8_t, vuint32mf2_t, vuint32mf2_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vsoxseg2ei8_v_m)))
void vsoxseg2ei8_v_u32mf2_m(vbool64_t, uint32_t *, vuint8mf8_t, vuint32mf2_t, vuint32mf2_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vsoxseg3ei8_v)))
void vsoxseg3ei8_v_i32m1(int32_t *, vuint8mf4_t, vint32m1_t, vint32m1_t, vint32m1_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vsoxseg3ei8_v_m)))
void vsoxseg3ei8_v_i32m1_m(vbool32_t, int32_t *, vuint8mf4_t, vint32m1_t, vint32m1_t, vint32m1_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vsoxseg3ei8_v)))
void vsoxseg3ei8_v_i32m2(int32_t *, vuint8mf2_t, vint32m2_t, vint32m2_t, vint32m2_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vsoxseg3ei8_v_m)))
void vsoxseg3ei8_v_i32m2_m(vbool16_t, int32_t *, vuint8mf2_t, vint32m2_t, vint32m2_t, vint32m2_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vsoxseg3ei8_v)))
void vsoxseg3ei8_v_i32mf2(int32_t *, vuint8mf8_t, vint32mf2_t, vint32mf2_t, vint32mf2_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vsoxseg3ei8_v_m)))
void vsoxseg3ei8_v_i32mf2_m(vbool64_t, int32_t *, vuint8mf8_t, vint32mf2_t, vint32mf2_t, vint32mf2_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vsoxseg3ei8_v)))
void vsoxseg3ei8_v_u32m1(uint32_t *, vuint8mf4_t, vuint32m1_t, vuint32m1_t, vuint32m1_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vsoxseg3ei8_v_m)))
void vsoxseg3ei8_v_u32m1_m(vbool32_t, uint32_t *, vuint8mf4_t, vuint32m1_t, vuint32m1_t, vuint32m1_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vsoxseg3ei8_v)))
void vsoxseg3ei8_v_u32m2(uint32_t *, vuint8mf2_t, vuint32m2_t, vuint32m2_t, vuint32m2_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vsoxseg3ei8_v_m)))
void vsoxseg3ei8_v_u32m2_m(vbool16_t, uint32_t *, vuint8mf2_t, vuint32m2_t, vuint32m2_t, vuint32m2_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vsoxseg3ei8_v)))
void vsoxseg3ei8_v_u32mf2(uint32_t *, vuint8mf8_t, vuint32mf2_t, vuint32mf2_t, vuint32mf2_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vsoxseg3ei8_v_m)))
void vsoxseg3ei8_v_u32mf2_m(vbool64_t, uint32_t *, vuint8mf8_t, vuint32mf2_t, vuint32mf2_t, vuint32mf2_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vsoxseg4ei8_v)))
void vsoxseg4ei8_v_i32m1(int32_t *, vuint8mf4_t, vint32m1_t, vint32m1_t, vint32m1_t, vint32m1_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vsoxseg4ei8_v_m)))
void vsoxseg4ei8_v_i32m1_m(vbool32_t, int32_t *, vuint8mf4_t, vint32m1_t, vint32m1_t, vint32m1_t, vint32m1_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vsoxseg4ei8_v)))
void vsoxseg4ei8_v_i32m2(int32_t *, vuint8mf2_t, vint32m2_t, vint32m2_t, vint32m2_t, vint32m2_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vsoxseg4ei8_v_m)))
void vsoxseg4ei8_v_i32m2_m(vbool16_t, int32_t *, vuint8mf2_t, vint32m2_t, vint32m2_t, vint32m2_t, vint32m2_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vsoxseg4ei8_v)))
void vsoxseg4ei8_v_i32mf2(int32_t *, vuint8mf8_t, vint32mf2_t, vint32mf2_t, vint32mf2_t, vint32mf2_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vsoxseg4ei8_v_m)))
void vsoxseg4ei8_v_i32mf2_m(vbool64_t, int32_t *, vuint8mf8_t, vint32mf2_t, vint32mf2_t, vint32mf2_t, vint32mf2_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vsoxseg4ei8_v)))
void vsoxseg4ei8_v_u32m1(uint32_t *, vuint8mf4_t, vuint32m1_t, vuint32m1_t, vuint32m1_t, vuint32m1_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vsoxseg4ei8_v_m)))
void vsoxseg4ei8_v_u32m1_m(vbool32_t, uint32_t *, vuint8mf4_t, vuint32m1_t, vuint32m1_t, vuint32m1_t, vuint32m1_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vsoxseg4ei8_v)))
void vsoxseg4ei8_v_u32m2(uint32_t *, vuint8mf2_t, vuint32m2_t, vuint32m2_t, vuint32m2_t, vuint32m2_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vsoxseg4ei8_v_m)))
void vsoxseg4ei8_v_u32m2_m(vbool16_t, uint32_t *, vuint8mf2_t, vuint32m2_t, vuint32m2_t, vuint32m2_t, vuint32m2_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vsoxseg4ei8_v)))
void vsoxseg4ei8_v_u32mf2(uint32_t *, vuint8mf8_t, vuint32mf2_t, vuint32mf2_t, vuint32mf2_t, vuint32mf2_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vsoxseg4ei8_v_m)))
void vsoxseg4ei8_v_u32mf2_m(vbool64_t, uint32_t *, vuint8mf8_t, vuint32mf2_t, vuint32mf2_t, vuint32mf2_t, vuint32mf2_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vsoxseg5ei8_v)))
void vsoxseg5ei8_v_i32m1(int32_t *, vuint8mf4_t, vint32m1_t, vint32m1_t, vint32m1_t, vint32m1_t, vint32m1_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vsoxseg5ei8_v_m)))
void vsoxseg5ei8_v_i32m1_m(vbool32_t, int32_t *, vuint8mf4_t, vint32m1_t, vint32m1_t, vint32m1_t, vint32m1_t, vint32m1_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vsoxseg5ei8_v)))
void vsoxseg5ei8_v_i32mf2(int32_t *, vuint8mf8_t, vint32mf2_t, vint32mf2_t, vint32mf2_t, vint32mf2_t, vint32mf2_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vsoxseg5ei8_v_m)))
void vsoxseg5ei8_v_i32mf2_m(vbool64_t, int32_t *, vuint8mf8_t, vint32mf2_t, vint32mf2_t, vint32mf2_t, vint32mf2_t, vint32mf2_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vsoxseg5ei8_v)))
void vsoxseg5ei8_v_u32m1(uint32_t *, vuint8mf4_t, vuint32m1_t, vuint32m1_t, vuint32m1_t, vuint32m1_t, vuint32m1_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vsoxseg5ei8_v_m)))
void vsoxseg5ei8_v_u32m1_m(vbool32_t, uint32_t *, vuint8mf4_t, vuint32m1_t, vuint32m1_t, vuint32m1_t, vuint32m1_t, vuint32m1_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vsoxseg5ei8_v)))
void vsoxseg5ei8_v_u32mf2(uint32_t *, vuint8mf8_t, vuint32mf2_t, vuint32mf2_t, vuint32mf2_t, vuint32mf2_t, vuint32mf2_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vsoxseg5ei8_v_m)))
void vsoxseg5ei8_v_u32mf2_m(vbool64_t, uint32_t *, vuint8mf8_t, vuint32mf2_t, vuint32mf2_t, vuint32mf2_t, vuint32mf2_t, vuint32mf2_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vsoxseg6ei8_v)))
void vsoxseg6ei8_v_i32m1(int32_t *, vuint8mf4_t, vint32m1_t, vint32m1_t, vint32m1_t, vint32m1_t, vint32m1_t, vint32m1_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vsoxseg6ei8_v_m)))
void vsoxseg6ei8_v_i32m1_m(vbool32_t, int32_t *, vuint8mf4_t, vint32m1_t, vint32m1_t, vint32m1_t, vint32m1_t, vint32m1_t, vint32m1_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vsoxseg6ei8_v)))
void vsoxseg6ei8_v_i32mf2(int32_t *, vuint8mf8_t, vint32mf2_t, vint32mf2_t, vint32mf2_t, vint32mf2_t, vint32mf2_t, vint32mf2_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vsoxseg6ei8_v_m)))
void vsoxseg6ei8_v_i32mf2_m(vbool64_t, int32_t *, vuint8mf8_t, vint32mf2_t, vint32mf2_t, vint32mf2_t, vint32mf2_t, vint32mf2_t, vint32mf2_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vsoxseg6ei8_v)))
void vsoxseg6ei8_v_u32m1(uint32_t *, vuint8mf4_t, vuint32m1_t, vuint32m1_t, vuint32m1_t, vuint32m1_t, vuint32m1_t, vuint32m1_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vsoxseg6ei8_v_m)))
void vsoxseg6ei8_v_u32m1_m(vbool32_t, uint32_t *, vuint8mf4_t, vuint32m1_t, vuint32m1_t, vuint32m1_t, vuint32m1_t, vuint32m1_t, vuint32m1_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vsoxseg6ei8_v)))
void vsoxseg6ei8_v_u32mf2(uint32_t *, vuint8mf8_t, vuint32mf2_t, vuint32mf2_t, vuint32mf2_t, vuint32mf2_t, vuint32mf2_t, vuint32mf2_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vsoxseg6ei8_v_m)))
void vsoxseg6ei8_v_u32mf2_m(vbool64_t, uint32_t *, vuint8mf8_t, vuint32mf2_t, vuint32mf2_t, vuint32mf2_t, vuint32mf2_t, vuint32mf2_t, vuint32mf2_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vloxei8_v)))
vuint32m1_t vloxei8_v_u32m1(const uint32_t *, vuint8mf4_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vloxei8_v_m)))
vuint32m1_t vloxei8_v_u32m1_m(vbool32_t, vuint32m1_t, const uint32_t *, vuint8mf4_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vloxei8_v)))
vuint32m2_t vloxei8_v_u32m2(const uint32_t *, vuint8mf2_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vloxei8_v_m)))
vuint32m2_t vloxei8_v_u32m2_m(vbool16_t, vuint32m2_t, const uint32_t *, vuint8mf2_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vloxei8_v)))
vuint32m4_t vloxei8_v_u32m4(const uint32_t *, vuint8m1_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vloxei8_v_m)))
vuint32m4_t vloxei8_v_u32m4_m(vbool8_t, vuint32m4_t, const uint32_t *, vuint8m1_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vloxei8_v)))
vuint32m8_t vloxei8_v_u32m8(const uint32_t *, vuint8m2_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vloxei8_v_m)))
vuint32m8_t vloxei8_v_u32m8_m(vbool4_t, vuint32m8_t, const uint32_t *, vuint8m2_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vloxei8_v)))
vuint32mf2_t vloxei8_v_u32mf2(const uint32_t *, vuint8mf8_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vloxei8_v_m)))
vuint32mf2_t vloxei8_v_u32mf2_m(vbool64_t, vuint32mf2_t, const uint32_t *, vuint8mf8_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vsoxseg7ei8_v)))
void vsoxseg7ei8_v_i32m1(int32_t *, vuint8mf4_t, vint32m1_t, vint32m1_t, vint32m1_t, vint32m1_t, vint32m1_t, vint32m1_t, vint32m1_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vsoxseg7ei8_v_m)))
void vsoxseg7ei8_v_i32m1_m(vbool32_t, int32_t *, vuint8mf4_t, vint32m1_t, vint32m1_t, vint32m1_t, vint32m1_t, vint32m1_t, vint32m1_t, vint32m1_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vsoxseg7ei8_v)))
void vsoxseg7ei8_v_i32mf2(int32_t *, vuint8mf8_t, vint32mf2_t, vint32mf2_t, vint32mf2_t, vint32mf2_t, vint32mf2_t, vint32mf2_t, vint32mf2_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vsoxseg7ei8_v_m)))
void vsoxseg7ei8_v_i32mf2_m(vbool64_t, int32_t *, vuint8mf8_t, vint32mf2_t, vint32mf2_t, vint32mf2_t, vint32mf2_t, vint32mf2_t, vint32mf2_t, vint32mf2_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vsoxseg7ei8_v)))
void vsoxseg7ei8_v_u32m1(uint32_t *, vuint8mf4_t, vuint32m1_t, vuint32m1_t, vuint32m1_t, vuint32m1_t, vuint32m1_t, vuint32m1_t, vuint32m1_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vsoxseg7ei8_v_m)))
void vsoxseg7ei8_v_u32m1_m(vbool32_t, uint32_t *, vuint8mf4_t, vuint32m1_t, vuint32m1_t, vuint32m1_t, vuint32m1_t, vuint32m1_t, vuint32m1_t, vuint32m1_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vsoxseg7ei8_v)))
void vsoxseg7ei8_v_u32mf2(uint32_t *, vuint8mf8_t, vuint32mf2_t, vuint32mf2_t, vuint32mf2_t, vuint32mf2_t, vuint32mf2_t, vuint32mf2_t, vuint32mf2_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vsoxseg7ei8_v_m)))
void vsoxseg7ei8_v_u32mf2_m(vbool64_t, uint32_t *, vuint8mf8_t, vuint32mf2_t, vuint32mf2_t, vuint32mf2_t, vuint32mf2_t, vuint32mf2_t, vuint32mf2_t, vuint32mf2_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vsoxseg8ei8_v)))
void vsoxseg8ei8_v_i32m1(int32_t *, vuint8mf4_t, vint32m1_t, vint32m1_t, vint32m1_t, vint32m1_t, vint32m1_t, vint32m1_t, vint32m1_t, vint32m1_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vsoxseg8ei8_v_m)))
void vsoxseg8ei8_v_i32m1_m(vbool32_t, int32_t *, vuint8mf4_t, vint32m1_t, vint32m1_t, vint32m1_t, vint32m1_t, vint32m1_t, vint32m1_t, vint32m1_t, vint32m1_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vsoxseg8ei8_v)))
void vsoxseg8ei8_v_i32mf2(int32_t *, vuint8mf8_t, vint32mf2_t, vint32mf2_t, vint32mf2_t, vint32mf2_t, vint32mf2_t, vint32mf2_t, vint32mf2_t, vint32mf2_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vsoxseg8ei8_v_m)))
void vsoxseg8ei8_v_i32mf2_m(vbool64_t, int32_t *, vuint8mf8_t, vint32mf2_t, vint32mf2_t, vint32mf2_t, vint32mf2_t, vint32mf2_t, vint32mf2_t, vint32mf2_t, vint32mf2_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vsoxseg8ei8_v)))
void vsoxseg8ei8_v_u32m1(uint32_t *, vuint8mf4_t, vuint32m1_t, vuint32m1_t, vuint32m1_t, vuint32m1_t, vuint32m1_t, vuint32m1_t, vuint32m1_t, vuint32m1_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vsoxseg8ei8_v_m)))
void vsoxseg8ei8_v_u32m1_m(vbool32_t, uint32_t *, vuint8mf4_t, vuint32m1_t, vuint32m1_t, vuint32m1_t, vuint32m1_t, vuint32m1_t, vuint32m1_t, vuint32m1_t, vuint32m1_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vsoxseg8ei8_v)))
void vsoxseg8ei8_v_u32mf2(uint32_t *, vuint8mf8_t, vuint32mf2_t, vuint32mf2_t, vuint32mf2_t, vuint32mf2_t, vuint32mf2_t, vuint32mf2_t, vuint32mf2_t, vuint32mf2_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vsoxseg8ei8_v_m)))
void vsoxseg8ei8_v_u32mf2_m(vbool64_t, uint32_t *, vuint8mf8_t, vuint32mf2_t, vuint32mf2_t, vuint32mf2_t, vuint32mf2_t, vuint32mf2_t, vuint32mf2_t, vuint32mf2_t, vuint32mf2_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vsoxseg2ei16_v)))
void vsoxseg2ei16_v_i32m1(int32_t *, vuint16mf2_t, vint32m1_t, vint32m1_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vsoxseg2ei16_v_m)))
void vsoxseg2ei16_v_i32m1_m(vbool32_t, int32_t *, vuint16mf2_t, vint32m1_t, vint32m1_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vsoxseg2ei16_v)))
void vsoxseg2ei16_v_i32m2(int32_t *, vuint16m1_t, vint32m2_t, vint32m2_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vsoxseg2ei16_v_m)))
void vsoxseg2ei16_v_i32m2_m(vbool16_t, int32_t *, vuint16m1_t, vint32m2_t, vint32m2_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vsoxseg2ei16_v)))
void vsoxseg2ei16_v_i32m4(int32_t *, vuint16m2_t, vint32m4_t, vint32m4_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vsoxseg2ei16_v_m)))
void vsoxseg2ei16_v_i32m4_m(vbool8_t, int32_t *, vuint16m2_t, vint32m4_t, vint32m4_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vsoxseg2ei16_v)))
void vsoxseg2ei16_v_i32mf2(int32_t *, vuint16mf4_t, vint32mf2_t, vint32mf2_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vsoxseg2ei16_v_m)))
void vsoxseg2ei16_v_i32mf2_m(vbool64_t, int32_t *, vuint16mf4_t, vint32mf2_t, vint32mf2_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vsoxseg2ei16_v)))
void vsoxseg2ei16_v_u32m1(uint32_t *, vuint16mf2_t, vuint32m1_t, vuint32m1_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vsoxseg2ei16_v_m)))
void vsoxseg2ei16_v_u32m1_m(vbool32_t, uint32_t *, vuint16mf2_t, vuint32m1_t, vuint32m1_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vsoxseg2ei16_v)))
void vsoxseg2ei16_v_u32m2(uint32_t *, vuint16m1_t, vuint32m2_t, vuint32m2_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vsoxseg2ei16_v_m)))
void vsoxseg2ei16_v_u32m2_m(vbool16_t, uint32_t *, vuint16m1_t, vuint32m2_t, vuint32m2_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vsoxseg2ei16_v)))
void vsoxseg2ei16_v_u32m4(uint32_t *, vuint16m2_t, vuint32m4_t, vuint32m4_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vsoxseg2ei16_v_m)))
void vsoxseg2ei16_v_u32m4_m(vbool8_t, uint32_t *, vuint16m2_t, vuint32m4_t, vuint32m4_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vsoxseg2ei16_v)))
void vsoxseg2ei16_v_u32mf2(uint32_t *, vuint16mf4_t, vuint32mf2_t, vuint32mf2_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vsoxseg2ei16_v_m)))
void vsoxseg2ei16_v_u32mf2_m(vbool64_t, uint32_t *, vuint16mf4_t, vuint32mf2_t, vuint32mf2_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vsoxseg3ei16_v)))
void vsoxseg3ei16_v_i32m1(int32_t *, vuint16mf2_t, vint32m1_t, vint32m1_t, vint32m1_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vsoxseg3ei16_v_m)))
void vsoxseg3ei16_v_i32m1_m(vbool32_t, int32_t *, vuint16mf2_t, vint32m1_t, vint32m1_t, vint32m1_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vsoxseg3ei16_v)))
void vsoxseg3ei16_v_i32m2(int32_t *, vuint16m1_t, vint32m2_t, vint32m2_t, vint32m2_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vsoxseg3ei16_v_m)))
void vsoxseg3ei16_v_i32m2_m(vbool16_t, int32_t *, vuint16m1_t, vint32m2_t, vint32m2_t, vint32m2_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vsoxseg3ei16_v)))
void vsoxseg3ei16_v_i32mf2(int32_t *, vuint16mf4_t, vint32mf2_t, vint32mf2_t, vint32mf2_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vsoxseg3ei16_v_m)))
void vsoxseg3ei16_v_i32mf2_m(vbool64_t, int32_t *, vuint16mf4_t, vint32mf2_t, vint32mf2_t, vint32mf2_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vsoxseg3ei16_v)))
void vsoxseg3ei16_v_u32m1(uint32_t *, vuint16mf2_t, vuint32m1_t, vuint32m1_t, vuint32m1_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vsoxseg3ei16_v_m)))
void vsoxseg3ei16_v_u32m1_m(vbool32_t, uint32_t *, vuint16mf2_t, vuint32m1_t, vuint32m1_t, vuint32m1_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vsoxseg3ei16_v)))
void vsoxseg3ei16_v_u32m2(uint32_t *, vuint16m1_t, vuint32m2_t, vuint32m2_t, vuint32m2_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vsoxseg3ei16_v_m)))
void vsoxseg3ei16_v_u32m2_m(vbool16_t, uint32_t *, vuint16m1_t, vuint32m2_t, vuint32m2_t, vuint32m2_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vsoxseg3ei16_v)))
void vsoxseg3ei16_v_u32mf2(uint32_t *, vuint16mf4_t, vuint32mf2_t, vuint32mf2_t, vuint32mf2_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vsoxseg3ei16_v_m)))
void vsoxseg3ei16_v_u32mf2_m(vbool64_t, uint32_t *, vuint16mf4_t, vuint32mf2_t, vuint32mf2_t, vuint32mf2_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vsoxseg4ei16_v)))
void vsoxseg4ei16_v_i32m1(int32_t *, vuint16mf2_t, vint32m1_t, vint32m1_t, vint32m1_t, vint32m1_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vsoxseg4ei16_v_m)))
void vsoxseg4ei16_v_i32m1_m(vbool32_t, int32_t *, vuint16mf2_t, vint32m1_t, vint32m1_t, vint32m1_t, vint32m1_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vsoxseg4ei16_v)))
void vsoxseg4ei16_v_i32m2(int32_t *, vuint16m1_t, vint32m2_t, vint32m2_t, vint32m2_t, vint32m2_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vsoxseg4ei16_v_m)))
void vsoxseg4ei16_v_i32m2_m(vbool16_t, int32_t *, vuint16m1_t, vint32m2_t, vint32m2_t, vint32m2_t, vint32m2_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vsoxseg4ei16_v)))
void vsoxseg4ei16_v_i32mf2(int32_t *, vuint16mf4_t, vint32mf2_t, vint32mf2_t, vint32mf2_t, vint32mf2_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vsoxseg4ei16_v_m)))
void vsoxseg4ei16_v_i32mf2_m(vbool64_t, int32_t *, vuint16mf4_t, vint32mf2_t, vint32mf2_t, vint32mf2_t, vint32mf2_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vsoxseg4ei16_v)))
void vsoxseg4ei16_v_u32m1(uint32_t *, vuint16mf2_t, vuint32m1_t, vuint32m1_t, vuint32m1_t, vuint32m1_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vsoxseg4ei16_v_m)))
void vsoxseg4ei16_v_u32m1_m(vbool32_t, uint32_t *, vuint16mf2_t, vuint32m1_t, vuint32m1_t, vuint32m1_t, vuint32m1_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vsoxseg4ei16_v)))
void vsoxseg4ei16_v_u32m2(uint32_t *, vuint16m1_t, vuint32m2_t, vuint32m2_t, vuint32m2_t, vuint32m2_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vsoxseg4ei16_v_m)))
void vsoxseg4ei16_v_u32m2_m(vbool16_t, uint32_t *, vuint16m1_t, vuint32m2_t, vuint32m2_t, vuint32m2_t, vuint32m2_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vsoxseg4ei16_v)))
void vsoxseg4ei16_v_u32mf2(uint32_t *, vuint16mf4_t, vuint32mf2_t, vuint32mf2_t, vuint32mf2_t, vuint32mf2_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vsoxseg4ei16_v_m)))
void vsoxseg4ei16_v_u32mf2_m(vbool64_t, uint32_t *, vuint16mf4_t, vuint32mf2_t, vuint32mf2_t, vuint32mf2_t, vuint32mf2_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vloxei16_v)))
vint32m1_t vloxei16_v_i32m1(const int32_t *, vuint16mf2_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vloxei16_v_m)))
vint32m1_t vloxei16_v_i32m1_m(vbool32_t, vint32m1_t, const int32_t *, vuint16mf2_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vloxei16_v)))
vint32m2_t vloxei16_v_i32m2(const int32_t *, vuint16m1_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vloxei16_v_m)))
vint32m2_t vloxei16_v_i32m2_m(vbool16_t, vint32m2_t, const int32_t *, vuint16m1_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vloxei16_v)))
vint32m4_t vloxei16_v_i32m4(const int32_t *, vuint16m2_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vloxei16_v_m)))
vint32m4_t vloxei16_v_i32m4_m(vbool8_t, vint32m4_t, const int32_t *, vuint16m2_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vloxei16_v)))
vint32m8_t vloxei16_v_i32m8(const int32_t *, vuint16m4_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vloxei16_v_m)))
vint32m8_t vloxei16_v_i32m8_m(vbool4_t, vint32m8_t, const int32_t *, vuint16m4_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vloxei16_v)))
vint32mf2_t vloxei16_v_i32mf2(const int32_t *, vuint16mf4_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vloxei16_v_m)))
vint32mf2_t vloxei16_v_i32mf2_m(vbool64_t, vint32mf2_t, const int32_t *, vuint16mf4_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vsoxseg5ei16_v)))
void vsoxseg5ei16_v_i32m1(int32_t *, vuint16mf2_t, vint32m1_t, vint32m1_t, vint32m1_t, vint32m1_t, vint32m1_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vsoxseg5ei16_v_m)))
void vsoxseg5ei16_v_i32m1_m(vbool32_t, int32_t *, vuint16mf2_t, vint32m1_t, vint32m1_t, vint32m1_t, vint32m1_t, vint32m1_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vsoxseg5ei16_v)))
void vsoxseg5ei16_v_i32mf2(int32_t *, vuint16mf4_t, vint32mf2_t, vint32mf2_t, vint32mf2_t, vint32mf2_t, vint32mf2_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vsoxseg5ei16_v_m)))
void vsoxseg5ei16_v_i32mf2_m(vbool64_t, int32_t *, vuint16mf4_t, vint32mf2_t, vint32mf2_t, vint32mf2_t, vint32mf2_t, vint32mf2_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vsoxseg5ei16_v)))
void vsoxseg5ei16_v_u32m1(uint32_t *, vuint16mf2_t, vuint32m1_t, vuint32m1_t, vuint32m1_t, vuint32m1_t, vuint32m1_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vsoxseg5ei16_v_m)))
void vsoxseg5ei16_v_u32m1_m(vbool32_t, uint32_t *, vuint16mf2_t, vuint32m1_t, vuint32m1_t, vuint32m1_t, vuint32m1_t, vuint32m1_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vsoxseg5ei16_v)))
void vsoxseg5ei16_v_u32mf2(uint32_t *, vuint16mf4_t, vuint32mf2_t, vuint32mf2_t, vuint32mf2_t, vuint32mf2_t, vuint32mf2_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vsoxseg5ei16_v_m)))
void vsoxseg5ei16_v_u32mf2_m(vbool64_t, uint32_t *, vuint16mf4_t, vuint32mf2_t, vuint32mf2_t, vuint32mf2_t, vuint32mf2_t, vuint32mf2_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vsoxseg6ei16_v)))
void vsoxseg6ei16_v_i32m1(int32_t *, vuint16mf2_t, vint32m1_t, vint32m1_t, vint32m1_t, vint32m1_t, vint32m1_t, vint32m1_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vsoxseg6ei16_v_m)))
void vsoxseg6ei16_v_i32m1_m(vbool32_t, int32_t *, vuint16mf2_t, vint32m1_t, vint32m1_t, vint32m1_t, vint32m1_t, vint32m1_t, vint32m1_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vsoxseg6ei16_v)))
void vsoxseg6ei16_v_i32mf2(int32_t *, vuint16mf4_t, vint32mf2_t, vint32mf2_t, vint32mf2_t, vint32mf2_t, vint32mf2_t, vint32mf2_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vsoxseg6ei16_v_m)))
void vsoxseg6ei16_v_i32mf2_m(vbool64_t, int32_t *, vuint16mf4_t, vint32mf2_t, vint32mf2_t, vint32mf2_t, vint32mf2_t, vint32mf2_t, vint32mf2_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vsoxseg6ei16_v)))
void vsoxseg6ei16_v_u32m1(uint32_t *, vuint16mf2_t, vuint32m1_t, vuint32m1_t, vuint32m1_t, vuint32m1_t, vuint32m1_t, vuint32m1_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vsoxseg6ei16_v_m)))
void vsoxseg6ei16_v_u32m1_m(vbool32_t, uint32_t *, vuint16mf2_t, vuint32m1_t, vuint32m1_t, vuint32m1_t, vuint32m1_t, vuint32m1_t, vuint32m1_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vsoxseg6ei16_v)))
void vsoxseg6ei16_v_u32mf2(uint32_t *, vuint16mf4_t, vuint32mf2_t, vuint32mf2_t, vuint32mf2_t, vuint32mf2_t, vuint32mf2_t, vuint32mf2_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vsoxseg6ei16_v_m)))
void vsoxseg6ei16_v_u32mf2_m(vbool64_t, uint32_t *, vuint16mf4_t, vuint32mf2_t, vuint32mf2_t, vuint32mf2_t, vuint32mf2_t, vuint32mf2_t, vuint32mf2_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vsoxseg7ei16_v)))
void vsoxseg7ei16_v_i32m1(int32_t *, vuint16mf2_t, vint32m1_t, vint32m1_t, vint32m1_t, vint32m1_t, vint32m1_t, vint32m1_t, vint32m1_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vsoxseg7ei16_v_m)))
void vsoxseg7ei16_v_i32m1_m(vbool32_t, int32_t *, vuint16mf2_t, vint32m1_t, vint32m1_t, vint32m1_t, vint32m1_t, vint32m1_t, vint32m1_t, vint32m1_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vsoxseg7ei16_v)))
void vsoxseg7ei16_v_i32mf2(int32_t *, vuint16mf4_t, vint32mf2_t, vint32mf2_t, vint32mf2_t, vint32mf2_t, vint32mf2_t, vint32mf2_t, vint32mf2_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vsoxseg7ei16_v_m)))
void vsoxseg7ei16_v_i32mf2_m(vbool64_t, int32_t *, vuint16mf4_t, vint32mf2_t, vint32mf2_t, vint32mf2_t, vint32mf2_t, vint32mf2_t, vint32mf2_t, vint32mf2_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vsoxseg7ei16_v)))
void vsoxseg7ei16_v_u32m1(uint32_t *, vuint16mf2_t, vuint32m1_t, vuint32m1_t, vuint32m1_t, vuint32m1_t, vuint32m1_t, vuint32m1_t, vuint32m1_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vsoxseg7ei16_v_m)))
void vsoxseg7ei16_v_u32m1_m(vbool32_t, uint32_t *, vuint16mf2_t, vuint32m1_t, vuint32m1_t, vuint32m1_t, vuint32m1_t, vuint32m1_t, vuint32m1_t, vuint32m1_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vsoxseg7ei16_v)))
void vsoxseg7ei16_v_u32mf2(uint32_t *, vuint16mf4_t, vuint32mf2_t, vuint32mf2_t, vuint32mf2_t, vuint32mf2_t, vuint32mf2_t, vuint32mf2_t, vuint32mf2_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vsoxseg7ei16_v_m)))
void vsoxseg7ei16_v_u32mf2_m(vbool64_t, uint32_t *, vuint16mf4_t, vuint32mf2_t, vuint32mf2_t, vuint32mf2_t, vuint32mf2_t, vuint32mf2_t, vuint32mf2_t, vuint32mf2_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vsoxseg8ei16_v)))
void vsoxseg8ei16_v_i32m1(int32_t *, vuint16mf2_t, vint32m1_t, vint32m1_t, vint32m1_t, vint32m1_t, vint32m1_t, vint32m1_t, vint32m1_t, vint32m1_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vsoxseg8ei16_v_m)))
void vsoxseg8ei16_v_i32m1_m(vbool32_t, int32_t *, vuint16mf2_t, vint32m1_t, vint32m1_t, vint32m1_t, vint32m1_t, vint32m1_t, vint32m1_t, vint32m1_t, vint32m1_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vsoxseg8ei16_v)))
void vsoxseg8ei16_v_i32mf2(int32_t *, vuint16mf4_t, vint32mf2_t, vint32mf2_t, vint32mf2_t, vint32mf2_t, vint32mf2_t, vint32mf2_t, vint32mf2_t, vint32mf2_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vsoxseg8ei16_v_m)))
void vsoxseg8ei16_v_i32mf2_m(vbool64_t, int32_t *, vuint16mf4_t, vint32mf2_t, vint32mf2_t, vint32mf2_t, vint32mf2_t, vint32mf2_t, vint32mf2_t, vint32mf2_t, vint32mf2_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vsoxseg8ei16_v)))
void vsoxseg8ei16_v_u32m1(uint32_t *, vuint16mf2_t, vuint32m1_t, vuint32m1_t, vuint32m1_t, vuint32m1_t, vuint32m1_t, vuint32m1_t, vuint32m1_t, vuint32m1_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vsoxseg8ei16_v_m)))
void vsoxseg8ei16_v_u32m1_m(vbool32_t, uint32_t *, vuint16mf2_t, vuint32m1_t, vuint32m1_t, vuint32m1_t, vuint32m1_t, vuint32m1_t, vuint32m1_t, vuint32m1_t, vuint32m1_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vsoxseg8ei16_v)))
void vsoxseg8ei16_v_u32mf2(uint32_t *, vuint16mf4_t, vuint32mf2_t, vuint32mf2_t, vuint32mf2_t, vuint32mf2_t, vuint32mf2_t, vuint32mf2_t, vuint32mf2_t, vuint32mf2_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vsoxseg8ei16_v_m)))
void vsoxseg8ei16_v_u32mf2_m(vbool64_t, uint32_t *, vuint16mf4_t, vuint32mf2_t, vuint32mf2_t, vuint32mf2_t, vuint32mf2_t, vuint32mf2_t, vuint32mf2_t, vuint32mf2_t, vuint32mf2_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vsoxseg2ei32_v)))
void vsoxseg2ei32_v_i32m1(int32_t *, vuint32m1_t, vint32m1_t, vint32m1_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vsoxseg2ei32_v_m)))
void vsoxseg2ei32_v_i32m1_m(vbool32_t, int32_t *, vuint32m1_t, vint32m1_t, vint32m1_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vsoxseg2ei32_v)))
void vsoxseg2ei32_v_i32m2(int32_t *, vuint32m2_t, vint32m2_t, vint32m2_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vsoxseg2ei32_v_m)))
void vsoxseg2ei32_v_i32m2_m(vbool16_t, int32_t *, vuint32m2_t, vint32m2_t, vint32m2_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vsoxseg2ei32_v)))
void vsoxseg2ei32_v_i32m4(int32_t *, vuint32m4_t, vint32m4_t, vint32m4_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vsoxseg2ei32_v_m)))
void vsoxseg2ei32_v_i32m4_m(vbool8_t, int32_t *, vuint32m4_t, vint32m4_t, vint32m4_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vsoxseg2ei32_v)))
void vsoxseg2ei32_v_i32mf2(int32_t *, vuint32mf2_t, vint32mf2_t, vint32mf2_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vsoxseg2ei32_v_m)))
void vsoxseg2ei32_v_i32mf2_m(vbool64_t, int32_t *, vuint32mf2_t, vint32mf2_t, vint32mf2_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vsoxseg2ei32_v)))
void vsoxseg2ei32_v_u32m1(uint32_t *, vuint32m1_t, vuint32m1_t, vuint32m1_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vsoxseg2ei32_v_m)))
void vsoxseg2ei32_v_u32m1_m(vbool32_t, uint32_t *, vuint32m1_t, vuint32m1_t, vuint32m1_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vsoxseg2ei32_v)))
void vsoxseg2ei32_v_u32m2(uint32_t *, vuint32m2_t, vuint32m2_t, vuint32m2_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vsoxseg2ei32_v_m)))
void vsoxseg2ei32_v_u32m2_m(vbool16_t, uint32_t *, vuint32m2_t, vuint32m2_t, vuint32m2_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vsoxseg2ei32_v)))
void vsoxseg2ei32_v_u32m4(uint32_t *, vuint32m4_t, vuint32m4_t, vuint32m4_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vsoxseg2ei32_v_m)))
void vsoxseg2ei32_v_u32m4_m(vbool8_t, uint32_t *, vuint32m4_t, vuint32m4_t, vuint32m4_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vsoxseg2ei32_v)))
void vsoxseg2ei32_v_u32mf2(uint32_t *, vuint32mf2_t, vuint32mf2_t, vuint32mf2_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vsoxseg2ei32_v_m)))
void vsoxseg2ei32_v_u32mf2_m(vbool64_t, uint32_t *, vuint32mf2_t, vuint32mf2_t, vuint32mf2_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vloxei16_v)))
vuint32m1_t vloxei16_v_u32m1(const uint32_t *, vuint16mf2_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vloxei16_v_m)))
vuint32m1_t vloxei16_v_u32m1_m(vbool32_t, vuint32m1_t, const uint32_t *, vuint16mf2_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vloxei16_v)))
vuint32m2_t vloxei16_v_u32m2(const uint32_t *, vuint16m1_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vloxei16_v_m)))
vuint32m2_t vloxei16_v_u32m2_m(vbool16_t, vuint32m2_t, const uint32_t *, vuint16m1_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vloxei16_v)))
vuint32m4_t vloxei16_v_u32m4(const uint32_t *, vuint16m2_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vloxei16_v_m)))
vuint32m4_t vloxei16_v_u32m4_m(vbool8_t, vuint32m4_t, const uint32_t *, vuint16m2_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vloxei16_v)))
vuint32m8_t vloxei16_v_u32m8(const uint32_t *, vuint16m4_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vloxei16_v_m)))
vuint32m8_t vloxei16_v_u32m8_m(vbool4_t, vuint32m8_t, const uint32_t *, vuint16m4_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vloxei16_v)))
vuint32mf2_t vloxei16_v_u32mf2(const uint32_t *, vuint16mf4_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vloxei16_v_m)))
vuint32mf2_t vloxei16_v_u32mf2_m(vbool64_t, vuint32mf2_t, const uint32_t *, vuint16mf4_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vsoxseg3ei32_v)))
void vsoxseg3ei32_v_i32m1(int32_t *, vuint32m1_t, vint32m1_t, vint32m1_t, vint32m1_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vsoxseg3ei32_v_m)))
void vsoxseg3ei32_v_i32m1_m(vbool32_t, int32_t *, vuint32m1_t, vint32m1_t, vint32m1_t, vint32m1_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vsoxseg3ei32_v)))
void vsoxseg3ei32_v_i32m2(int32_t *, vuint32m2_t, vint32m2_t, vint32m2_t, vint32m2_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vsoxseg3ei32_v_m)))
void vsoxseg3ei32_v_i32m2_m(vbool16_t, int32_t *, vuint32m2_t, vint32m2_t, vint32m2_t, vint32m2_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vsoxseg3ei32_v)))
void vsoxseg3ei32_v_i32mf2(int32_t *, vuint32mf2_t, vint32mf2_t, vint32mf2_t, vint32mf2_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vsoxseg3ei32_v_m)))
void vsoxseg3ei32_v_i32mf2_m(vbool64_t, int32_t *, vuint32mf2_t, vint32mf2_t, vint32mf2_t, vint32mf2_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vsoxseg3ei32_v)))
void vsoxseg3ei32_v_u32m1(uint32_t *, vuint32m1_t, vuint32m1_t, vuint32m1_t, vuint32m1_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vsoxseg3ei32_v_m)))
void vsoxseg3ei32_v_u32m1_m(vbool32_t, uint32_t *, vuint32m1_t, vuint32m1_t, vuint32m1_t, vuint32m1_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vsoxseg3ei32_v)))
void vsoxseg3ei32_v_u32m2(uint32_t *, vuint32m2_t, vuint32m2_t, vuint32m2_t, vuint32m2_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vsoxseg3ei32_v_m)))
void vsoxseg3ei32_v_u32m2_m(vbool16_t, uint32_t *, vuint32m2_t, vuint32m2_t, vuint32m2_t, vuint32m2_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vsoxseg3ei32_v)))
void vsoxseg3ei32_v_u32mf2(uint32_t *, vuint32mf2_t, vuint32mf2_t, vuint32mf2_t, vuint32mf2_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vsoxseg3ei32_v_m)))
void vsoxseg3ei32_v_u32mf2_m(vbool64_t, uint32_t *, vuint32mf2_t, vuint32mf2_t, vuint32mf2_t, vuint32mf2_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vsoxseg4ei32_v)))
void vsoxseg4ei32_v_i32m1(int32_t *, vuint32m1_t, vint32m1_t, vint32m1_t, vint32m1_t, vint32m1_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vsoxseg4ei32_v_m)))
void vsoxseg4ei32_v_i32m1_m(vbool32_t, int32_t *, vuint32m1_t, vint32m1_t, vint32m1_t, vint32m1_t, vint32m1_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vsoxseg4ei32_v)))
void vsoxseg4ei32_v_i32m2(int32_t *, vuint32m2_t, vint32m2_t, vint32m2_t, vint32m2_t, vint32m2_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vsoxseg4ei32_v_m)))
void vsoxseg4ei32_v_i32m2_m(vbool16_t, int32_t *, vuint32m2_t, vint32m2_t, vint32m2_t, vint32m2_t, vint32m2_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vsoxseg4ei32_v)))
void vsoxseg4ei32_v_i32mf2(int32_t *, vuint32mf2_t, vint32mf2_t, vint32mf2_t, vint32mf2_t, vint32mf2_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vsoxseg4ei32_v_m)))
void vsoxseg4ei32_v_i32mf2_m(vbool64_t, int32_t *, vuint32mf2_t, vint32mf2_t, vint32mf2_t, vint32mf2_t, vint32mf2_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vsoxseg4ei32_v)))
void vsoxseg4ei32_v_u32m1(uint32_t *, vuint32m1_t, vuint32m1_t, vuint32m1_t, vuint32m1_t, vuint32m1_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vsoxseg4ei32_v_m)))
void vsoxseg4ei32_v_u32m1_m(vbool32_t, uint32_t *, vuint32m1_t, vuint32m1_t, vuint32m1_t, vuint32m1_t, vuint32m1_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vsoxseg4ei32_v)))
void vsoxseg4ei32_v_u32m2(uint32_t *, vuint32m2_t, vuint32m2_t, vuint32m2_t, vuint32m2_t, vuint32m2_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vsoxseg4ei32_v_m)))
void vsoxseg4ei32_v_u32m2_m(vbool16_t, uint32_t *, vuint32m2_t, vuint32m2_t, vuint32m2_t, vuint32m2_t, vuint32m2_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vsoxseg4ei32_v)))
void vsoxseg4ei32_v_u32mf2(uint32_t *, vuint32mf2_t, vuint32mf2_t, vuint32mf2_t, vuint32mf2_t, vuint32mf2_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vsoxseg4ei32_v_m)))
void vsoxseg4ei32_v_u32mf2_m(vbool64_t, uint32_t *, vuint32mf2_t, vuint32mf2_t, vuint32mf2_t, vuint32mf2_t, vuint32mf2_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vsoxseg5ei32_v)))
void vsoxseg5ei32_v_i32m1(int32_t *, vuint32m1_t, vint32m1_t, vint32m1_t, vint32m1_t, vint32m1_t, vint32m1_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vsoxseg5ei32_v_m)))
void vsoxseg5ei32_v_i32m1_m(vbool32_t, int32_t *, vuint32m1_t, vint32m1_t, vint32m1_t, vint32m1_t, vint32m1_t, vint32m1_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vsoxseg5ei32_v)))
void vsoxseg5ei32_v_i32mf2(int32_t *, vuint32mf2_t, vint32mf2_t, vint32mf2_t, vint32mf2_t, vint32mf2_t, vint32mf2_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vsoxseg5ei32_v_m)))
void vsoxseg5ei32_v_i32mf2_m(vbool64_t, int32_t *, vuint32mf2_t, vint32mf2_t, vint32mf2_t, vint32mf2_t, vint32mf2_t, vint32mf2_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vsoxseg5ei32_v)))
void vsoxseg5ei32_v_u32m1(uint32_t *, vuint32m1_t, vuint32m1_t, vuint32m1_t, vuint32m1_t, vuint32m1_t, vuint32m1_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vsoxseg5ei32_v_m)))
void vsoxseg5ei32_v_u32m1_m(vbool32_t, uint32_t *, vuint32m1_t, vuint32m1_t, vuint32m1_t, vuint32m1_t, vuint32m1_t, vuint32m1_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vsoxseg5ei32_v)))
void vsoxseg5ei32_v_u32mf2(uint32_t *, vuint32mf2_t, vuint32mf2_t, vuint32mf2_t, vuint32mf2_t, vuint32mf2_t, vuint32mf2_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vsoxseg5ei32_v_m)))
void vsoxseg5ei32_v_u32mf2_m(vbool64_t, uint32_t *, vuint32mf2_t, vuint32mf2_t, vuint32mf2_t, vuint32mf2_t, vuint32mf2_t, vuint32mf2_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vsoxseg6ei32_v)))
void vsoxseg6ei32_v_i32m1(int32_t *, vuint32m1_t, vint32m1_t, vint32m1_t, vint32m1_t, vint32m1_t, vint32m1_t, vint32m1_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vsoxseg6ei32_v_m)))
void vsoxseg6ei32_v_i32m1_m(vbool32_t, int32_t *, vuint32m1_t, vint32m1_t, vint32m1_t, vint32m1_t, vint32m1_t, vint32m1_t, vint32m1_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vsoxseg6ei32_v)))
void vsoxseg6ei32_v_i32mf2(int32_t *, vuint32mf2_t, vint32mf2_t, vint32mf2_t, vint32mf2_t, vint32mf2_t, vint32mf2_t, vint32mf2_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vsoxseg6ei32_v_m)))
void vsoxseg6ei32_v_i32mf2_m(vbool64_t, int32_t *, vuint32mf2_t, vint32mf2_t, vint32mf2_t, vint32mf2_t, vint32mf2_t, vint32mf2_t, vint32mf2_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vsoxseg6ei32_v)))
void vsoxseg6ei32_v_u32m1(uint32_t *, vuint32m1_t, vuint32m1_t, vuint32m1_t, vuint32m1_t, vuint32m1_t, vuint32m1_t, vuint32m1_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vsoxseg6ei32_v_m)))
void vsoxseg6ei32_v_u32m1_m(vbool32_t, uint32_t *, vuint32m1_t, vuint32m1_t, vuint32m1_t, vuint32m1_t, vuint32m1_t, vuint32m1_t, vuint32m1_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vsoxseg6ei32_v)))
void vsoxseg6ei32_v_u32mf2(uint32_t *, vuint32mf2_t, vuint32mf2_t, vuint32mf2_t, vuint32mf2_t, vuint32mf2_t, vuint32mf2_t, vuint32mf2_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vsoxseg6ei32_v_m)))
void vsoxseg6ei32_v_u32mf2_m(vbool64_t, uint32_t *, vuint32mf2_t, vuint32mf2_t, vuint32mf2_t, vuint32mf2_t, vuint32mf2_t, vuint32mf2_t, vuint32mf2_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vsoxseg7ei32_v)))
void vsoxseg7ei32_v_i32m1(int32_t *, vuint32m1_t, vint32m1_t, vint32m1_t, vint32m1_t, vint32m1_t, vint32m1_t, vint32m1_t, vint32m1_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vsoxseg7ei32_v_m)))
void vsoxseg7ei32_v_i32m1_m(vbool32_t, int32_t *, vuint32m1_t, vint32m1_t, vint32m1_t, vint32m1_t, vint32m1_t, vint32m1_t, vint32m1_t, vint32m1_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vsoxseg7ei32_v)))
void vsoxseg7ei32_v_i32mf2(int32_t *, vuint32mf2_t, vint32mf2_t, vint32mf2_t, vint32mf2_t, vint32mf2_t, vint32mf2_t, vint32mf2_t, vint32mf2_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vsoxseg7ei32_v_m)))
void vsoxseg7ei32_v_i32mf2_m(vbool64_t, int32_t *, vuint32mf2_t, vint32mf2_t, vint32mf2_t, vint32mf2_t, vint32mf2_t, vint32mf2_t, vint32mf2_t, vint32mf2_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vsoxseg7ei32_v)))
void vsoxseg7ei32_v_u32m1(uint32_t *, vuint32m1_t, vuint32m1_t, vuint32m1_t, vuint32m1_t, vuint32m1_t, vuint32m1_t, vuint32m1_t, vuint32m1_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vsoxseg7ei32_v_m)))
void vsoxseg7ei32_v_u32m1_m(vbool32_t, uint32_t *, vuint32m1_t, vuint32m1_t, vuint32m1_t, vuint32m1_t, vuint32m1_t, vuint32m1_t, vuint32m1_t, vuint32m1_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vsoxseg7ei32_v)))
void vsoxseg7ei32_v_u32mf2(uint32_t *, vuint32mf2_t, vuint32mf2_t, vuint32mf2_t, vuint32mf2_t, vuint32mf2_t, vuint32mf2_t, vuint32mf2_t, vuint32mf2_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vsoxseg7ei32_v_m)))
void vsoxseg7ei32_v_u32mf2_m(vbool64_t, uint32_t *, vuint32mf2_t, vuint32mf2_t, vuint32mf2_t, vuint32mf2_t, vuint32mf2_t, vuint32mf2_t, vuint32mf2_t, vuint32mf2_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vloxei32_v)))
vint32m1_t vloxei32_v_i32m1(const int32_t *, vuint32m1_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vloxei32_v_m)))
vint32m1_t vloxei32_v_i32m1_m(vbool32_t, vint32m1_t, const int32_t *, vuint32m1_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vloxei32_v)))
vint32m2_t vloxei32_v_i32m2(const int32_t *, vuint32m2_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vloxei32_v_m)))
vint32m2_t vloxei32_v_i32m2_m(vbool16_t, vint32m2_t, const int32_t *, vuint32m2_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vloxei32_v)))
vint32m4_t vloxei32_v_i32m4(const int32_t *, vuint32m4_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vloxei32_v_m)))
vint32m4_t vloxei32_v_i32m4_m(vbool8_t, vint32m4_t, const int32_t *, vuint32m4_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vloxei32_v)))
vint32m8_t vloxei32_v_i32m8(const int32_t *, vuint32m8_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vloxei32_v_m)))
vint32m8_t vloxei32_v_i32m8_m(vbool4_t, vint32m8_t, const int32_t *, vuint32m8_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vloxei32_v)))
vint32mf2_t vloxei32_v_i32mf2(const int32_t *, vuint32mf2_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vloxei32_v_m)))
vint32mf2_t vloxei32_v_i32mf2_m(vbool64_t, vint32mf2_t, const int32_t *, vuint32mf2_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vsoxseg8ei32_v)))
void vsoxseg8ei32_v_i32m1(int32_t *, vuint32m1_t, vint32m1_t, vint32m1_t, vint32m1_t, vint32m1_t, vint32m1_t, vint32m1_t, vint32m1_t, vint32m1_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vsoxseg8ei32_v_m)))
void vsoxseg8ei32_v_i32m1_m(vbool32_t, int32_t *, vuint32m1_t, vint32m1_t, vint32m1_t, vint32m1_t, vint32m1_t, vint32m1_t, vint32m1_t, vint32m1_t, vint32m1_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vsoxseg8ei32_v)))
void vsoxseg8ei32_v_i32mf2(int32_t *, vuint32mf2_t, vint32mf2_t, vint32mf2_t, vint32mf2_t, vint32mf2_t, vint32mf2_t, vint32mf2_t, vint32mf2_t, vint32mf2_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vsoxseg8ei32_v_m)))
void vsoxseg8ei32_v_i32mf2_m(vbool64_t, int32_t *, vuint32mf2_t, vint32mf2_t, vint32mf2_t, vint32mf2_t, vint32mf2_t, vint32mf2_t, vint32mf2_t, vint32mf2_t, vint32mf2_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vsoxseg8ei32_v)))
void vsoxseg8ei32_v_u32m1(uint32_t *, vuint32m1_t, vuint32m1_t, vuint32m1_t, vuint32m1_t, vuint32m1_t, vuint32m1_t, vuint32m1_t, vuint32m1_t, vuint32m1_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vsoxseg8ei32_v_m)))
void vsoxseg8ei32_v_u32m1_m(vbool32_t, uint32_t *, vuint32m1_t, vuint32m1_t, vuint32m1_t, vuint32m1_t, vuint32m1_t, vuint32m1_t, vuint32m1_t, vuint32m1_t, vuint32m1_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vsoxseg8ei32_v)))
void vsoxseg8ei32_v_u32mf2(uint32_t *, vuint32mf2_t, vuint32mf2_t, vuint32mf2_t, vuint32mf2_t, vuint32mf2_t, vuint32mf2_t, vuint32mf2_t, vuint32mf2_t, vuint32mf2_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vsoxseg8ei32_v_m)))
void vsoxseg8ei32_v_u32mf2_m(vbool64_t, uint32_t *, vuint32mf2_t, vuint32mf2_t, vuint32mf2_t, vuint32mf2_t, vuint32mf2_t, vuint32mf2_t, vuint32mf2_t, vuint32mf2_t, vuint32mf2_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vloxei32_v)))
vuint32m1_t vloxei32_v_u32m1(const uint32_t *, vuint32m1_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vloxei32_v_m)))
vuint32m1_t vloxei32_v_u32m1_m(vbool32_t, vuint32m1_t, const uint32_t *, vuint32m1_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vloxei32_v)))
vuint32m2_t vloxei32_v_u32m2(const uint32_t *, vuint32m2_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vloxei32_v_m)))
vuint32m2_t vloxei32_v_u32m2_m(vbool16_t, vuint32m2_t, const uint32_t *, vuint32m2_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vloxei32_v)))
vuint32m4_t vloxei32_v_u32m4(const uint32_t *, vuint32m4_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vloxei32_v_m)))
vuint32m4_t vloxei32_v_u32m4_m(vbool8_t, vuint32m4_t, const uint32_t *, vuint32m4_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vloxei32_v)))
vuint32m8_t vloxei32_v_u32m8(const uint32_t *, vuint32m8_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vloxei32_v_m)))
vuint32m8_t vloxei32_v_u32m8_m(vbool4_t, vuint32m8_t, const uint32_t *, vuint32m8_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vloxei32_v)))
vuint32mf2_t vloxei32_v_u32mf2(const uint32_t *, vuint32mf2_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vloxei32_v_m)))
vuint32mf2_t vloxei32_v_u32mf2_m(vbool64_t, vuint32mf2_t, const uint32_t *, vuint32mf2_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vadd_vx)))
vint8m1_t vadd_vx_i8m1(vint8m1_t, int8_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vadd_vx_m)))
vint8m1_t vadd_vx_i8m1_m(vbool8_t, vint8m1_t, vint8m1_t, int8_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vadd_vx)))
vint8m2_t vadd_vx_i8m2(vint8m2_t, int8_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vadd_vx_m)))
vint8m2_t vadd_vx_i8m2_m(vbool4_t, vint8m2_t, vint8m2_t, int8_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vadd_vx)))
vint8m4_t vadd_vx_i8m4(vint8m4_t, int8_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vadd_vx_m)))
vint8m4_t vadd_vx_i8m4_m(vbool2_t, vint8m4_t, vint8m4_t, int8_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vadd_vx)))
vint8m8_t vadd_vx_i8m8(vint8m8_t, int8_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vadd_vx_m)))
vint8m8_t vadd_vx_i8m8_m(vbool1_t, vint8m8_t, vint8m8_t, int8_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vadd_vx)))
vint8mf2_t vadd_vx_i8mf2(vint8mf2_t, int8_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vadd_vx_m)))
vint8mf2_t vadd_vx_i8mf2_m(vbool16_t, vint8mf2_t, vint8mf2_t, int8_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vadd_vx)))
vint8mf4_t vadd_vx_i8mf4(vint8mf4_t, int8_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vadd_vx_m)))
vint8mf4_t vadd_vx_i8mf4_m(vbool32_t, vint8mf4_t, vint8mf4_t, int8_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vadd_vx)))
vint8mf8_t vadd_vx_i8mf8(vint8mf8_t, int8_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vadd_vx_m)))
vint8mf8_t vadd_vx_i8mf8_m(vbool64_t, vint8mf8_t, vint8mf8_t, int8_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vadd_vx)))
vint16m1_t vadd_vx_i16m1(vint16m1_t, int16_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vadd_vx_m)))
vint16m1_t vadd_vx_i16m1_m(vbool16_t, vint16m1_t, vint16m1_t, int16_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vadd_vx)))
vint16m2_t vadd_vx_i16m2(vint16m2_t, int16_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vadd_vx_m)))
vint16m2_t vadd_vx_i16m2_m(vbool8_t, vint16m2_t, vint16m2_t, int16_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vadd_vx)))
vint16m4_t vadd_vx_i16m4(vint16m4_t, int16_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vadd_vx_m)))
vint16m4_t vadd_vx_i16m4_m(vbool4_t, vint16m4_t, vint16m4_t, int16_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vadd_vx)))
vint16m8_t vadd_vx_i16m8(vint16m8_t, int16_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vadd_vx_m)))
vint16m8_t vadd_vx_i16m8_m(vbool2_t, vint16m8_t, vint16m8_t, int16_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vadd_vx)))
vint16mf2_t vadd_vx_i16mf2(vint16mf2_t, int16_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vadd_vx_m)))
vint16mf2_t vadd_vx_i16mf2_m(vbool32_t, vint16mf2_t, vint16mf2_t, int16_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vadd_vx)))
vint16mf4_t vadd_vx_i16mf4(vint16mf4_t, int16_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vadd_vx_m)))
vint16mf4_t vadd_vx_i16mf4_m(vbool64_t, vint16mf4_t, vint16mf4_t, int16_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vadd_vx)))
vint32m1_t vadd_vx_i32m1(vint32m1_t, int32_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vadd_vx_m)))
vint32m1_t vadd_vx_i32m1_m(vbool32_t, vint32m1_t, vint32m1_t, int32_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vadd_vx)))
vint32m2_t vadd_vx_i32m2(vint32m2_t, int32_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vadd_vx_m)))
vint32m2_t vadd_vx_i32m2_m(vbool16_t, vint32m2_t, vint32m2_t, int32_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vadd_vx)))
vint32m4_t vadd_vx_i32m4(vint32m4_t, int32_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vadd_vx_m)))
vint32m4_t vadd_vx_i32m4_m(vbool8_t, vint32m4_t, vint32m4_t, int32_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vadd_vx)))
vint32m8_t vadd_vx_i32m8(vint32m8_t, int32_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vadd_vx_m)))
vint32m8_t vadd_vx_i32m8_m(vbool4_t, vint32m8_t, vint32m8_t, int32_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vadd_vx)))
vint32mf2_t vadd_vx_i32mf2(vint32mf2_t, int32_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vadd_vx_m)))
vint32mf2_t vadd_vx_i32mf2_m(vbool64_t, vint32mf2_t, vint32mf2_t, int32_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vadd_vv)))
vuint8m1_t vadd_vv_u8m1(vuint8m1_t, vuint8m1_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vadd_vv_m)))
vuint8m1_t vadd_vv_u8m1_m(vbool8_t, vuint8m1_t, vuint8m1_t, vuint8m1_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vadd_vv)))
vuint8m2_t vadd_vv_u8m2(vuint8m2_t, vuint8m2_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vadd_vv_m)))
vuint8m2_t vadd_vv_u8m2_m(vbool4_t, vuint8m2_t, vuint8m2_t, vuint8m2_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vadd_vv)))
vuint8m4_t vadd_vv_u8m4(vuint8m4_t, vuint8m4_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vadd_vv_m)))
vuint8m4_t vadd_vv_u8m4_m(vbool2_t, vuint8m4_t, vuint8m4_t, vuint8m4_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vadd_vv)))
vuint8m8_t vadd_vv_u8m8(vuint8m8_t, vuint8m8_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vadd_vv_m)))
vuint8m8_t vadd_vv_u8m8_m(vbool1_t, vuint8m8_t, vuint8m8_t, vuint8m8_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vadd_vv)))
vuint8mf2_t vadd_vv_u8mf2(vuint8mf2_t, vuint8mf2_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vadd_vv_m)))
vuint8mf2_t vadd_vv_u8mf2_m(vbool16_t, vuint8mf2_t, vuint8mf2_t, vuint8mf2_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vadd_vv)))
vuint8mf4_t vadd_vv_u8mf4(vuint8mf4_t, vuint8mf4_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vadd_vv_m)))
vuint8mf4_t vadd_vv_u8mf4_m(vbool32_t, vuint8mf4_t, vuint8mf4_t, vuint8mf4_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vadd_vv)))
vuint8mf8_t vadd_vv_u8mf8(vuint8mf8_t, vuint8mf8_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vadd_vv_m)))
vuint8mf8_t vadd_vv_u8mf8_m(vbool64_t, vuint8mf8_t, vuint8mf8_t, vuint8mf8_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vadd_vv)))
vuint16m1_t vadd_vv_u16m1(vuint16m1_t, vuint16m1_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vadd_vv_m)))
vuint16m1_t vadd_vv_u16m1_m(vbool16_t, vuint16m1_t, vuint16m1_t, vuint16m1_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vadd_vv)))
vuint16m2_t vadd_vv_u16m2(vuint16m2_t, vuint16m2_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vadd_vv_m)))
vuint16m2_t vadd_vv_u16m2_m(vbool8_t, vuint16m2_t, vuint16m2_t, vuint16m2_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vadd_vv)))
vuint16m4_t vadd_vv_u16m4(vuint16m4_t, vuint16m4_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vadd_vv_m)))
vuint16m4_t vadd_vv_u16m4_m(vbool4_t, vuint16m4_t, vuint16m4_t, vuint16m4_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vadd_vv)))
vuint16m8_t vadd_vv_u16m8(vuint16m8_t, vuint16m8_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vadd_vv_m)))
vuint16m8_t vadd_vv_u16m8_m(vbool2_t, vuint16m8_t, vuint16m8_t, vuint16m8_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vadd_vv)))
vuint16mf2_t vadd_vv_u16mf2(vuint16mf2_t, vuint16mf2_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vadd_vv_m)))
vuint16mf2_t vadd_vv_u16mf2_m(vbool32_t, vuint16mf2_t, vuint16mf2_t, vuint16mf2_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vadd_vv)))
vuint16mf4_t vadd_vv_u16mf4(vuint16mf4_t, vuint16mf4_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vadd_vv_m)))
vuint16mf4_t vadd_vv_u16mf4_m(vbool64_t, vuint16mf4_t, vuint16mf4_t, vuint16mf4_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vadd_vv)))
vuint32m1_t vadd_vv_u32m1(vuint32m1_t, vuint32m1_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vadd_vv_m)))
vuint32m1_t vadd_vv_u32m1_m(vbool32_t, vuint32m1_t, vuint32m1_t, vuint32m1_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vadd_vv)))
vuint32m2_t vadd_vv_u32m2(vuint32m2_t, vuint32m2_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vadd_vv_m)))
vuint32m2_t vadd_vv_u32m2_m(vbool16_t, vuint32m2_t, vuint32m2_t, vuint32m2_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vadd_vv)))
vuint32m4_t vadd_vv_u32m4(vuint32m4_t, vuint32m4_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vadd_vv_m)))
vuint32m4_t vadd_vv_u32m4_m(vbool8_t, vuint32m4_t, vuint32m4_t, vuint32m4_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vadd_vv)))
vuint32m8_t vadd_vv_u32m8(vuint32m8_t, vuint32m8_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vadd_vv_m)))
vuint32m8_t vadd_vv_u32m8_m(vbool4_t, vuint32m8_t, vuint32m8_t, vuint32m8_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vadd_vv)))
vuint32mf2_t vadd_vv_u32mf2(vuint32mf2_t, vuint32mf2_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vadd_vv_m)))
vuint32mf2_t vadd_vv_u32mf2_m(vbool64_t, vuint32mf2_t, vuint32mf2_t, vuint32mf2_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vadd_vx)))
vuint8m1_t vadd_vx_u8m1(vuint8m1_t, uint8_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vadd_vx_m)))
vuint8m1_t vadd_vx_u8m1_m(vbool8_t, vuint8m1_t, vuint8m1_t, uint8_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vadd_vx)))
vuint8m2_t vadd_vx_u8m2(vuint8m2_t, uint8_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vadd_vx_m)))
vuint8m2_t vadd_vx_u8m2_m(vbool4_t, vuint8m2_t, vuint8m2_t, uint8_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vadd_vx)))
vuint8m4_t vadd_vx_u8m4(vuint8m4_t, uint8_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vadd_vx_m)))
vuint8m4_t vadd_vx_u8m4_m(vbool2_t, vuint8m4_t, vuint8m4_t, uint8_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vadd_vx)))
vuint8m8_t vadd_vx_u8m8(vuint8m8_t, uint8_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vadd_vx_m)))
vuint8m8_t vadd_vx_u8m8_m(vbool1_t, vuint8m8_t, vuint8m8_t, uint8_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vadd_vx)))
vuint8mf2_t vadd_vx_u8mf2(vuint8mf2_t, uint8_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vadd_vx_m)))
vuint8mf2_t vadd_vx_u8mf2_m(vbool16_t, vuint8mf2_t, vuint8mf2_t, uint8_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vadd_vx)))
vuint8mf4_t vadd_vx_u8mf4(vuint8mf4_t, uint8_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vadd_vx_m)))
vuint8mf4_t vadd_vx_u8mf4_m(vbool32_t, vuint8mf4_t, vuint8mf4_t, uint8_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vadd_vx)))
vuint8mf8_t vadd_vx_u8mf8(vuint8mf8_t, uint8_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vadd_vx_m)))
vuint8mf8_t vadd_vx_u8mf8_m(vbool64_t, vuint8mf8_t, vuint8mf8_t, uint8_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vadd_vx)))
vuint16m1_t vadd_vx_u16m1(vuint16m1_t, uint16_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vadd_vx_m)))
vuint16m1_t vadd_vx_u16m1_m(vbool16_t, vuint16m1_t, vuint16m1_t, uint16_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vadd_vx)))
vuint16m2_t vadd_vx_u16m2(vuint16m2_t, uint16_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vadd_vx_m)))
vuint16m2_t vadd_vx_u16m2_m(vbool8_t, vuint16m2_t, vuint16m2_t, uint16_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vadd_vx)))
vuint16m4_t vadd_vx_u16m4(vuint16m4_t, uint16_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vadd_vx_m)))
vuint16m4_t vadd_vx_u16m4_m(vbool4_t, vuint16m4_t, vuint16m4_t, uint16_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vadd_vx)))
vuint16m8_t vadd_vx_u16m8(vuint16m8_t, uint16_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vadd_vx_m)))
vuint16m8_t vadd_vx_u16m8_m(vbool2_t, vuint16m8_t, vuint16m8_t, uint16_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vadd_vx)))
vuint16mf2_t vadd_vx_u16mf2(vuint16mf2_t, uint16_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vadd_vx_m)))
vuint16mf2_t vadd_vx_u16mf2_m(vbool32_t, vuint16mf2_t, vuint16mf2_t, uint16_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vadd_vx)))
vuint16mf4_t vadd_vx_u16mf4(vuint16mf4_t, uint16_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vadd_vx_m)))
vuint16mf4_t vadd_vx_u16mf4_m(vbool64_t, vuint16mf4_t, vuint16mf4_t, uint16_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vadd_vx)))
vuint32m1_t vadd_vx_u32m1(vuint32m1_t, uint32_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vadd_vx_m)))
vuint32m1_t vadd_vx_u32m1_m(vbool32_t, vuint32m1_t, vuint32m1_t, uint32_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vadd_vx)))
vuint32m2_t vadd_vx_u32m2(vuint32m2_t, uint32_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vadd_vx_m)))
vuint32m2_t vadd_vx_u32m2_m(vbool16_t, vuint32m2_t, vuint32m2_t, uint32_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vadd_vx)))
vuint32m4_t vadd_vx_u32m4(vuint32m4_t, uint32_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vadd_vx_m)))
vuint32m4_t vadd_vx_u32m4_m(vbool8_t, vuint32m4_t, vuint32m4_t, uint32_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vadd_vx)))
vuint32m8_t vadd_vx_u32m8(vuint32m8_t, uint32_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vadd_vx_m)))
vuint32m8_t vadd_vx_u32m8_m(vbool4_t, vuint32m8_t, vuint32m8_t, uint32_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vadd_vx)))
vuint32mf2_t vadd_vx_u32mf2(vuint32mf2_t, uint32_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vadd_vx_m)))
vuint32mf2_t vadd_vx_u32mf2_m(vbool64_t, vuint32mf2_t, vuint32mf2_t, uint32_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vsub_vv)))
vint8m1_t vsub_vv_i8m1(vint8m1_t, vint8m1_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vsub_vv_m)))
vint8m1_t vsub_vv_i8m1_m(vbool8_t, vint8m1_t, vint8m1_t, vint8m1_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vsub_vv)))
vint8m2_t vsub_vv_i8m2(vint8m2_t, vint8m2_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vsub_vv_m)))
vint8m2_t vsub_vv_i8m2_m(vbool4_t, vint8m2_t, vint8m2_t, vint8m2_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vsub_vv)))
vint8m4_t vsub_vv_i8m4(vint8m4_t, vint8m4_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vsub_vv_m)))
vint8m4_t vsub_vv_i8m4_m(vbool2_t, vint8m4_t, vint8m4_t, vint8m4_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vsub_vv)))
vint8m8_t vsub_vv_i8m8(vint8m8_t, vint8m8_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vsub_vv_m)))
vint8m8_t vsub_vv_i8m8_m(vbool1_t, vint8m8_t, vint8m8_t, vint8m8_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vsub_vv)))
vint8mf2_t vsub_vv_i8mf2(vint8mf2_t, vint8mf2_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vsub_vv_m)))
vint8mf2_t vsub_vv_i8mf2_m(vbool16_t, vint8mf2_t, vint8mf2_t, vint8mf2_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vsub_vv)))
vint8mf4_t vsub_vv_i8mf4(vint8mf4_t, vint8mf4_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vsub_vv_m)))
vint8mf4_t vsub_vv_i8mf4_m(vbool32_t, vint8mf4_t, vint8mf4_t, vint8mf4_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vsub_vv)))
vint8mf8_t vsub_vv_i8mf8(vint8mf8_t, vint8mf8_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vsub_vv_m)))
vint8mf8_t vsub_vv_i8mf8_m(vbool64_t, vint8mf8_t, vint8mf8_t, vint8mf8_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vsub_vv)))
vint16m1_t vsub_vv_i16m1(vint16m1_t, vint16m1_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vsub_vv_m)))
vint16m1_t vsub_vv_i16m1_m(vbool16_t, vint16m1_t, vint16m1_t, vint16m1_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vsub_vv)))
vint16m2_t vsub_vv_i16m2(vint16m2_t, vint16m2_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vsub_vv_m)))
vint16m2_t vsub_vv_i16m2_m(vbool8_t, vint16m2_t, vint16m2_t, vint16m2_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vsub_vv)))
vint16m4_t vsub_vv_i16m4(vint16m4_t, vint16m4_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vsub_vv_m)))
vint16m4_t vsub_vv_i16m4_m(vbool4_t, vint16m4_t, vint16m4_t, vint16m4_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vsub_vv)))
vint16m8_t vsub_vv_i16m8(vint16m8_t, vint16m8_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vsub_vv_m)))
vint16m8_t vsub_vv_i16m8_m(vbool2_t, vint16m8_t, vint16m8_t, vint16m8_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vsub_vv)))
vint16mf2_t vsub_vv_i16mf2(vint16mf2_t, vint16mf2_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vsub_vv_m)))
vint16mf2_t vsub_vv_i16mf2_m(vbool32_t, vint16mf2_t, vint16mf2_t, vint16mf2_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vsub_vv)))
vint16mf4_t vsub_vv_i16mf4(vint16mf4_t, vint16mf4_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vsub_vv_m)))
vint16mf4_t vsub_vv_i16mf4_m(vbool64_t, vint16mf4_t, vint16mf4_t, vint16mf4_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vsub_vv)))
vint32m1_t vsub_vv_i32m1(vint32m1_t, vint32m1_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vsub_vv_m)))
vint32m1_t vsub_vv_i32m1_m(vbool32_t, vint32m1_t, vint32m1_t, vint32m1_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vsub_vv)))
vint32m2_t vsub_vv_i32m2(vint32m2_t, vint32m2_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vsub_vv_m)))
vint32m2_t vsub_vv_i32m2_m(vbool16_t, vint32m2_t, vint32m2_t, vint32m2_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vsub_vv)))
vint32m4_t vsub_vv_i32m4(vint32m4_t, vint32m4_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vsub_vv_m)))
vint32m4_t vsub_vv_i32m4_m(vbool8_t, vint32m4_t, vint32m4_t, vint32m4_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vsub_vv)))
vint32m8_t vsub_vv_i32m8(vint32m8_t, vint32m8_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vsub_vv_m)))
vint32m8_t vsub_vv_i32m8_m(vbool4_t, vint32m8_t, vint32m8_t, vint32m8_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vsub_vv)))
vint32mf2_t vsub_vv_i32mf2(vint32mf2_t, vint32mf2_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vsub_vv_m)))
vint32mf2_t vsub_vv_i32mf2_m(vbool64_t, vint32mf2_t, vint32mf2_t, vint32mf2_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vsub_vx)))
vint8m1_t vsub_vx_i8m1(vint8m1_t, int8_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vsub_vx_m)))
vint8m1_t vsub_vx_i8m1_m(vbool8_t, vint8m1_t, vint8m1_t, int8_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vsub_vx)))
vint8m2_t vsub_vx_i8m2(vint8m2_t, int8_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vsub_vx_m)))
vint8m2_t vsub_vx_i8m2_m(vbool4_t, vint8m2_t, vint8m2_t, int8_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vsub_vx)))
vint8m4_t vsub_vx_i8m4(vint8m4_t, int8_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vsub_vx_m)))
vint8m4_t vsub_vx_i8m4_m(vbool2_t, vint8m4_t, vint8m4_t, int8_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vsub_vx)))
vint8m8_t vsub_vx_i8m8(vint8m8_t, int8_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vsub_vx_m)))
vint8m8_t vsub_vx_i8m8_m(vbool1_t, vint8m8_t, vint8m8_t, int8_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vsub_vx)))
vint8mf2_t vsub_vx_i8mf2(vint8mf2_t, int8_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vsub_vx_m)))
vint8mf2_t vsub_vx_i8mf2_m(vbool16_t, vint8mf2_t, vint8mf2_t, int8_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vsub_vx)))
vint8mf4_t vsub_vx_i8mf4(vint8mf4_t, int8_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vsub_vx_m)))
vint8mf4_t vsub_vx_i8mf4_m(vbool32_t, vint8mf4_t, vint8mf4_t, int8_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vsub_vx)))
vint8mf8_t vsub_vx_i8mf8(vint8mf8_t, int8_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vsub_vx_m)))
vint8mf8_t vsub_vx_i8mf8_m(vbool64_t, vint8mf8_t, vint8mf8_t, int8_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vsub_vx)))
vint16m1_t vsub_vx_i16m1(vint16m1_t, int16_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vsub_vx_m)))
vint16m1_t vsub_vx_i16m1_m(vbool16_t, vint16m1_t, vint16m1_t, int16_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vsub_vx)))
vint16m2_t vsub_vx_i16m2(vint16m2_t, int16_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vsub_vx_m)))
vint16m2_t vsub_vx_i16m2_m(vbool8_t, vint16m2_t, vint16m2_t, int16_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vsub_vx)))
vint16m4_t vsub_vx_i16m4(vint16m4_t, int16_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vsub_vx_m)))
vint16m4_t vsub_vx_i16m4_m(vbool4_t, vint16m4_t, vint16m4_t, int16_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vsub_vx)))
vint16m8_t vsub_vx_i16m8(vint16m8_t, int16_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vsub_vx_m)))
vint16m8_t vsub_vx_i16m8_m(vbool2_t, vint16m8_t, vint16m8_t, int16_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vsub_vx)))
vint16mf2_t vsub_vx_i16mf2(vint16mf2_t, int16_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vsub_vx_m)))
vint16mf2_t vsub_vx_i16mf2_m(vbool32_t, vint16mf2_t, vint16mf2_t, int16_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vsub_vx)))
vint16mf4_t vsub_vx_i16mf4(vint16mf4_t, int16_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vsub_vx_m)))
vint16mf4_t vsub_vx_i16mf4_m(vbool64_t, vint16mf4_t, vint16mf4_t, int16_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vsub_vx)))
vint32m1_t vsub_vx_i32m1(vint32m1_t, int32_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vsub_vx_m)))
vint32m1_t vsub_vx_i32m1_m(vbool32_t, vint32m1_t, vint32m1_t, int32_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vsub_vx)))
vint32m2_t vsub_vx_i32m2(vint32m2_t, int32_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vsub_vx_m)))
vint32m2_t vsub_vx_i32m2_m(vbool16_t, vint32m2_t, vint32m2_t, int32_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vsub_vx)))
vint32m4_t vsub_vx_i32m4(vint32m4_t, int32_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vsub_vx_m)))
vint32m4_t vsub_vx_i32m4_m(vbool8_t, vint32m4_t, vint32m4_t, int32_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vsub_vx)))
vint32m8_t vsub_vx_i32m8(vint32m8_t, int32_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vsub_vx_m)))
vint32m8_t vsub_vx_i32m8_m(vbool4_t, vint32m8_t, vint32m8_t, int32_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vsub_vx)))
vint32mf2_t vsub_vx_i32mf2(vint32mf2_t, int32_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vsub_vx_m)))
vint32mf2_t vsub_vx_i32mf2_m(vbool64_t, vint32mf2_t, vint32mf2_t, int32_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vsub_vv)))
vuint8m1_t vsub_vv_u8m1(vuint8m1_t, vuint8m1_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vsub_vv_m)))
vuint8m1_t vsub_vv_u8m1_m(vbool8_t, vuint8m1_t, vuint8m1_t, vuint8m1_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vsub_vv)))
vuint8m2_t vsub_vv_u8m2(vuint8m2_t, vuint8m2_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vsub_vv_m)))
vuint8m2_t vsub_vv_u8m2_m(vbool4_t, vuint8m2_t, vuint8m2_t, vuint8m2_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vsub_vv)))
vuint8m4_t vsub_vv_u8m4(vuint8m4_t, vuint8m4_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vsub_vv_m)))
vuint8m4_t vsub_vv_u8m4_m(vbool2_t, vuint8m4_t, vuint8m4_t, vuint8m4_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vsub_vv)))
vuint8m8_t vsub_vv_u8m8(vuint8m8_t, vuint8m8_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vsub_vv_m)))
vuint8m8_t vsub_vv_u8m8_m(vbool1_t, vuint8m8_t, vuint8m8_t, vuint8m8_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vsub_vv)))
vuint8mf2_t vsub_vv_u8mf2(vuint8mf2_t, vuint8mf2_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vsub_vv_m)))
vuint8mf2_t vsub_vv_u8mf2_m(vbool16_t, vuint8mf2_t, vuint8mf2_t, vuint8mf2_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vsub_vv)))
vuint8mf4_t vsub_vv_u8mf4(vuint8mf4_t, vuint8mf4_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vsub_vv_m)))
vuint8mf4_t vsub_vv_u8mf4_m(vbool32_t, vuint8mf4_t, vuint8mf4_t, vuint8mf4_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vsub_vv)))
vuint8mf8_t vsub_vv_u8mf8(vuint8mf8_t, vuint8mf8_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vsub_vv_m)))
vuint8mf8_t vsub_vv_u8mf8_m(vbool64_t, vuint8mf8_t, vuint8mf8_t, vuint8mf8_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vsub_vv)))
vuint16m1_t vsub_vv_u16m1(vuint16m1_t, vuint16m1_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vsub_vv_m)))
vuint16m1_t vsub_vv_u16m1_m(vbool16_t, vuint16m1_t, vuint16m1_t, vuint16m1_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vsub_vv)))
vuint16m2_t vsub_vv_u16m2(vuint16m2_t, vuint16m2_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vsub_vv_m)))
vuint16m2_t vsub_vv_u16m2_m(vbool8_t, vuint16m2_t, vuint16m2_t, vuint16m2_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vsub_vv)))
vuint16m4_t vsub_vv_u16m4(vuint16m4_t, vuint16m4_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vsub_vv_m)))
vuint16m4_t vsub_vv_u16m4_m(vbool4_t, vuint16m4_t, vuint16m4_t, vuint16m4_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vsub_vv)))
vuint16m8_t vsub_vv_u16m8(vuint16m8_t, vuint16m8_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vsub_vv_m)))
vuint16m8_t vsub_vv_u16m8_m(vbool2_t, vuint16m8_t, vuint16m8_t, vuint16m8_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vsub_vv)))
vuint16mf2_t vsub_vv_u16mf2(vuint16mf2_t, vuint16mf2_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vsub_vv_m)))
vuint16mf2_t vsub_vv_u16mf2_m(vbool32_t, vuint16mf2_t, vuint16mf2_t, vuint16mf2_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vsub_vv)))
vuint16mf4_t vsub_vv_u16mf4(vuint16mf4_t, vuint16mf4_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vsub_vv_m)))
vuint16mf4_t vsub_vv_u16mf4_m(vbool64_t, vuint16mf4_t, vuint16mf4_t, vuint16mf4_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vsub_vv)))
vuint32m1_t vsub_vv_u32m1(vuint32m1_t, vuint32m1_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vsub_vv_m)))
vuint32m1_t vsub_vv_u32m1_m(vbool32_t, vuint32m1_t, vuint32m1_t, vuint32m1_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vsub_vv)))
vuint32m2_t vsub_vv_u32m2(vuint32m2_t, vuint32m2_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vsub_vv_m)))
vuint32m2_t vsub_vv_u32m2_m(vbool16_t, vuint32m2_t, vuint32m2_t, vuint32m2_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vsub_vv)))
vuint32m4_t vsub_vv_u32m4(vuint32m4_t, vuint32m4_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vsub_vv_m)))
vuint32m4_t vsub_vv_u32m4_m(vbool8_t, vuint32m4_t, vuint32m4_t, vuint32m4_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vsub_vv)))
vuint32m8_t vsub_vv_u32m8(vuint32m8_t, vuint32m8_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vsub_vv_m)))
vuint32m8_t vsub_vv_u32m8_m(vbool4_t, vuint32m8_t, vuint32m8_t, vuint32m8_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vsub_vv)))
vuint32mf2_t vsub_vv_u32mf2(vuint32mf2_t, vuint32mf2_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vsub_vv_m)))
vuint32mf2_t vsub_vv_u32mf2_m(vbool64_t, vuint32mf2_t, vuint32mf2_t, vuint32mf2_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vsub_vx)))
vuint8m1_t vsub_vx_u8m1(vuint8m1_t, uint8_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vsub_vx_m)))
vuint8m1_t vsub_vx_u8m1_m(vbool8_t, vuint8m1_t, vuint8m1_t, uint8_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vsub_vx)))
vuint8m2_t vsub_vx_u8m2(vuint8m2_t, uint8_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vsub_vx_m)))
vuint8m2_t vsub_vx_u8m2_m(vbool4_t, vuint8m2_t, vuint8m2_t, uint8_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vsub_vx)))
vuint8m4_t vsub_vx_u8m4(vuint8m4_t, uint8_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vsub_vx_m)))
vuint8m4_t vsub_vx_u8m4_m(vbool2_t, vuint8m4_t, vuint8m4_t, uint8_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vsub_vx)))
vuint8m8_t vsub_vx_u8m8(vuint8m8_t, uint8_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vsub_vx_m)))
vuint8m8_t vsub_vx_u8m8_m(vbool1_t, vuint8m8_t, vuint8m8_t, uint8_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vsub_vx)))
vuint8mf2_t vsub_vx_u8mf2(vuint8mf2_t, uint8_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vsub_vx_m)))
vuint8mf2_t vsub_vx_u8mf2_m(vbool16_t, vuint8mf2_t, vuint8mf2_t, uint8_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vsub_vx)))
vuint8mf4_t vsub_vx_u8mf4(vuint8mf4_t, uint8_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vsub_vx_m)))
vuint8mf4_t vsub_vx_u8mf4_m(vbool32_t, vuint8mf4_t, vuint8mf4_t, uint8_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vsub_vx)))
vuint8mf8_t vsub_vx_u8mf8(vuint8mf8_t, uint8_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vsub_vx_m)))
vuint8mf8_t vsub_vx_u8mf8_m(vbool64_t, vuint8mf8_t, vuint8mf8_t, uint8_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vsub_vx)))
vuint16m1_t vsub_vx_u16m1(vuint16m1_t, uint16_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vsub_vx_m)))
vuint16m1_t vsub_vx_u16m1_m(vbool16_t, vuint16m1_t, vuint16m1_t, uint16_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vsub_vx)))
vuint16m2_t vsub_vx_u16m2(vuint16m2_t, uint16_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vsub_vx_m)))
vuint16m2_t vsub_vx_u16m2_m(vbool8_t, vuint16m2_t, vuint16m2_t, uint16_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vsub_vx)))
vuint16m4_t vsub_vx_u16m4(vuint16m4_t, uint16_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vsub_vx_m)))
vuint16m4_t vsub_vx_u16m4_m(vbool4_t, vuint16m4_t, vuint16m4_t, uint16_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vsub_vx)))
vuint16m8_t vsub_vx_u16m8(vuint16m8_t, uint16_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vsub_vx_m)))
vuint16m8_t vsub_vx_u16m8_m(vbool2_t, vuint16m8_t, vuint16m8_t, uint16_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vsub_vx)))
vuint16mf2_t vsub_vx_u16mf2(vuint16mf2_t, uint16_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vsub_vx_m)))
vuint16mf2_t vsub_vx_u16mf2_m(vbool32_t, vuint16mf2_t, vuint16mf2_t, uint16_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vsub_vx)))
vuint16mf4_t vsub_vx_u16mf4(vuint16mf4_t, uint16_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vsub_vx_m)))
vuint16mf4_t vsub_vx_u16mf4_m(vbool64_t, vuint16mf4_t, vuint16mf4_t, uint16_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vsub_vx)))
vuint32m1_t vsub_vx_u32m1(vuint32m1_t, uint32_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vsub_vx_m)))
vuint32m1_t vsub_vx_u32m1_m(vbool32_t, vuint32m1_t, vuint32m1_t, uint32_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vsub_vx)))
vuint32m2_t vsub_vx_u32m2(vuint32m2_t, uint32_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vsub_vx_m)))
vuint32m2_t vsub_vx_u32m2_m(vbool16_t, vuint32m2_t, vuint32m2_t, uint32_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vsub_vx)))
vuint32m4_t vsub_vx_u32m4(vuint32m4_t, uint32_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vsub_vx_m)))
vuint32m4_t vsub_vx_u32m4_m(vbool8_t, vuint32m4_t, vuint32m4_t, uint32_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vsub_vx)))
vuint32m8_t vsub_vx_u32m8(vuint32m8_t, uint32_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vsub_vx_m)))
vuint32m8_t vsub_vx_u32m8_m(vbool4_t, vuint32m8_t, vuint32m8_t, uint32_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vsub_vx)))
vuint32mf2_t vsub_vx_u32mf2(vuint32mf2_t, uint32_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vsub_vx_m)))
vuint32mf2_t vsub_vx_u32mf2_m(vbool64_t, vuint32mf2_t, vuint32mf2_t, uint32_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vrsub_vx)))
vint8m1_t vrsub_vx_i8m1(vint8m1_t, int8_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vrsub_vx_m)))
vint8m1_t vrsub_vx_i8m1_m(vbool8_t, vint8m1_t, vint8m1_t, int8_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vrsub_vx)))
vint8m2_t vrsub_vx_i8m2(vint8m2_t, int8_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vrsub_vx_m)))
vint8m2_t vrsub_vx_i8m2_m(vbool4_t, vint8m2_t, vint8m2_t, int8_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vrsub_vx)))
vint8m4_t vrsub_vx_i8m4(vint8m4_t, int8_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vrsub_vx_m)))
vint8m4_t vrsub_vx_i8m4_m(vbool2_t, vint8m4_t, vint8m4_t, int8_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vrsub_vx)))
vint8m8_t vrsub_vx_i8m8(vint8m8_t, int8_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vrsub_vx_m)))
vint8m8_t vrsub_vx_i8m8_m(vbool1_t, vint8m8_t, vint8m8_t, int8_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vrsub_vx)))
vint8mf2_t vrsub_vx_i8mf2(vint8mf2_t, int8_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vrsub_vx_m)))
vint8mf2_t vrsub_vx_i8mf2_m(vbool16_t, vint8mf2_t, vint8mf2_t, int8_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vrsub_vx)))
vint8mf4_t vrsub_vx_i8mf4(vint8mf4_t, int8_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vrsub_vx_m)))
vint8mf4_t vrsub_vx_i8mf4_m(vbool32_t, vint8mf4_t, vint8mf4_t, int8_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vrsub_vx)))
vint8mf8_t vrsub_vx_i8mf8(vint8mf8_t, int8_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vrsub_vx_m)))
vint8mf8_t vrsub_vx_i8mf8_m(vbool64_t, vint8mf8_t, vint8mf8_t, int8_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vrsub_vx)))
vint16m1_t vrsub_vx_i16m1(vint16m1_t, int16_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vrsub_vx_m)))
vint16m1_t vrsub_vx_i16m1_m(vbool16_t, vint16m1_t, vint16m1_t, int16_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vrsub_vx)))
vint16m2_t vrsub_vx_i16m2(vint16m2_t, int16_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vrsub_vx_m)))
vint16m2_t vrsub_vx_i16m2_m(vbool8_t, vint16m2_t, vint16m2_t, int16_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vrsub_vx)))
vint16m4_t vrsub_vx_i16m4(vint16m4_t, int16_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vrsub_vx_m)))
vint16m4_t vrsub_vx_i16m4_m(vbool4_t, vint16m4_t, vint16m4_t, int16_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vrsub_vx)))
vint16m8_t vrsub_vx_i16m8(vint16m8_t, int16_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vrsub_vx_m)))
vint16m8_t vrsub_vx_i16m8_m(vbool2_t, vint16m8_t, vint16m8_t, int16_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vrsub_vx)))
vint16mf2_t vrsub_vx_i16mf2(vint16mf2_t, int16_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vrsub_vx_m)))
vint16mf2_t vrsub_vx_i16mf2_m(vbool32_t, vint16mf2_t, vint16mf2_t, int16_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vrsub_vx)))
vint16mf4_t vrsub_vx_i16mf4(vint16mf4_t, int16_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vrsub_vx_m)))
vint16mf4_t vrsub_vx_i16mf4_m(vbool64_t, vint16mf4_t, vint16mf4_t, int16_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vrsub_vx)))
vint32m1_t vrsub_vx_i32m1(vint32m1_t, int32_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vrsub_vx_m)))
vint32m1_t vrsub_vx_i32m1_m(vbool32_t, vint32m1_t, vint32m1_t, int32_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vrsub_vx)))
vint32m2_t vrsub_vx_i32m2(vint32m2_t, int32_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vrsub_vx_m)))
vint32m2_t vrsub_vx_i32m2_m(vbool16_t, vint32m2_t, vint32m2_t, int32_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vrsub_vx)))
vint32m4_t vrsub_vx_i32m4(vint32m4_t, int32_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vrsub_vx_m)))
vint32m4_t vrsub_vx_i32m4_m(vbool8_t, vint32m4_t, vint32m4_t, int32_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vrsub_vx)))
vint32m8_t vrsub_vx_i32m8(vint32m8_t, int32_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vrsub_vx_m)))
vint32m8_t vrsub_vx_i32m8_m(vbool4_t, vint32m8_t, vint32m8_t, int32_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vrsub_vx)))
vint32mf2_t vrsub_vx_i32mf2(vint32mf2_t, int32_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vrsub_vx_m)))
vint32mf2_t vrsub_vx_i32mf2_m(vbool64_t, vint32mf2_t, vint32mf2_t, int32_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vrsub_vx)))
vuint8m1_t vrsub_vx_u8m1(vuint8m1_t, uint8_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vrsub_vx_m)))
vuint8m1_t vrsub_vx_u8m1_m(vbool8_t, vuint8m1_t, vuint8m1_t, uint8_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vrsub_vx)))
vuint8m2_t vrsub_vx_u8m2(vuint8m2_t, uint8_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vrsub_vx_m)))
vuint8m2_t vrsub_vx_u8m2_m(vbool4_t, vuint8m2_t, vuint8m2_t, uint8_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vrsub_vx)))
vuint8m4_t vrsub_vx_u8m4(vuint8m4_t, uint8_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vrsub_vx_m)))
vuint8m4_t vrsub_vx_u8m4_m(vbool2_t, vuint8m4_t, vuint8m4_t, uint8_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vrsub_vx)))
vuint8m8_t vrsub_vx_u8m8(vuint8m8_t, uint8_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vrsub_vx_m)))
vuint8m8_t vrsub_vx_u8m8_m(vbool1_t, vuint8m8_t, vuint8m8_t, uint8_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vrsub_vx)))
vuint8mf2_t vrsub_vx_u8mf2(vuint8mf2_t, uint8_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vrsub_vx_m)))
vuint8mf2_t vrsub_vx_u8mf2_m(vbool16_t, vuint8mf2_t, vuint8mf2_t, uint8_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vrsub_vx)))
vuint8mf4_t vrsub_vx_u8mf4(vuint8mf4_t, uint8_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vrsub_vx_m)))
vuint8mf4_t vrsub_vx_u8mf4_m(vbool32_t, vuint8mf4_t, vuint8mf4_t, uint8_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vrsub_vx)))
vuint8mf8_t vrsub_vx_u8mf8(vuint8mf8_t, uint8_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vrsub_vx_m)))
vuint8mf8_t vrsub_vx_u8mf8_m(vbool64_t, vuint8mf8_t, vuint8mf8_t, uint8_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vrsub_vx)))
vuint16m1_t vrsub_vx_u16m1(vuint16m1_t, uint16_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vrsub_vx_m)))
vuint16m1_t vrsub_vx_u16m1_m(vbool16_t, vuint16m1_t, vuint16m1_t, uint16_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vrsub_vx)))
vuint16m2_t vrsub_vx_u16m2(vuint16m2_t, uint16_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vrsub_vx_m)))
vuint16m2_t vrsub_vx_u16m2_m(vbool8_t, vuint16m2_t, vuint16m2_t, uint16_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vrsub_vx)))
vuint16m4_t vrsub_vx_u16m4(vuint16m4_t, uint16_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vrsub_vx_m)))
vuint16m4_t vrsub_vx_u16m4_m(vbool4_t, vuint16m4_t, vuint16m4_t, uint16_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vrsub_vx)))
vuint16m8_t vrsub_vx_u16m8(vuint16m8_t, uint16_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vrsub_vx_m)))
vuint16m8_t vrsub_vx_u16m8_m(vbool2_t, vuint16m8_t, vuint16m8_t, uint16_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vrsub_vx)))
vuint16mf2_t vrsub_vx_u16mf2(vuint16mf2_t, uint16_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vrsub_vx_m)))
vuint16mf2_t vrsub_vx_u16mf2_m(vbool32_t, vuint16mf2_t, vuint16mf2_t, uint16_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vrsub_vx)))
vuint16mf4_t vrsub_vx_u16mf4(vuint16mf4_t, uint16_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vrsub_vx_m)))
vuint16mf4_t vrsub_vx_u16mf4_m(vbool64_t, vuint16mf4_t, vuint16mf4_t, uint16_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vrsub_vx)))
vuint32m1_t vrsub_vx_u32m1(vuint32m1_t, uint32_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vrsub_vx_m)))
vuint32m1_t vrsub_vx_u32m1_m(vbool32_t, vuint32m1_t, vuint32m1_t, uint32_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vrsub_vx)))
vuint32m2_t vrsub_vx_u32m2(vuint32m2_t, uint32_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vrsub_vx_m)))
vuint32m2_t vrsub_vx_u32m2_m(vbool16_t, vuint32m2_t, vuint32m2_t, uint32_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vrsub_vx)))
vuint32m4_t vrsub_vx_u32m4(vuint32m4_t, uint32_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vrsub_vx_m)))
vuint32m4_t vrsub_vx_u32m4_m(vbool8_t, vuint32m4_t, vuint32m4_t, uint32_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vrsub_vx)))
vuint32m8_t vrsub_vx_u32m8(vuint32m8_t, uint32_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vrsub_vx_m)))
vuint32m8_t vrsub_vx_u32m8_m(vbool4_t, vuint32m8_t, vuint32m8_t, uint32_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vrsub_vx)))
vuint32mf2_t vrsub_vx_u32mf2(vuint32mf2_t, uint32_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vrsub_vx_m)))
vuint32mf2_t vrsub_vx_u32mf2_m(vbool64_t, vuint32mf2_t, vuint32mf2_t, uint32_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vwaddu_vx)))
vuint16mf4_t vwaddu_vx_u16mf4(vuint8mf8_t, uint8_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vwaddu_vx_m)))
vuint16mf4_t vwaddu_vx_u16mf4_m(vbool64_t, vuint16mf4_t, vuint8mf8_t, uint8_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vwaddu_vx)))
vuint16mf2_t vwaddu_vx_u16mf2(vuint8mf4_t, uint8_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vwaddu_vx_m)))
vuint16mf2_t vwaddu_vx_u16mf2_m(vbool32_t, vuint16mf2_t, vuint8mf4_t, uint8_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vwaddu_vx)))
vuint16m1_t vwaddu_vx_u16m1(vuint8mf2_t, uint8_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vwaddu_vx_m)))
vuint16m1_t vwaddu_vx_u16m1_m(vbool16_t, vuint16m1_t, vuint8mf2_t, uint8_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vwaddu_vx)))
vuint16m2_t vwaddu_vx_u16m2(vuint8m1_t, uint8_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vwaddu_vx_m)))
vuint16m2_t vwaddu_vx_u16m2_m(vbool8_t, vuint16m2_t, vuint8m1_t, uint8_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vwaddu_vx)))
vuint16m4_t vwaddu_vx_u16m4(vuint8m2_t, uint8_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vwaddu_vx_m)))
vuint16m4_t vwaddu_vx_u16m4_m(vbool4_t, vuint16m4_t, vuint8m2_t, uint8_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vwaddu_vx)))
vuint16m8_t vwaddu_vx_u16m8(vuint8m4_t, uint8_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vwaddu_vx_m)))
vuint16m8_t vwaddu_vx_u16m8_m(vbool2_t, vuint16m8_t, vuint8m4_t, uint8_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vwaddu_vx)))
vuint32mf2_t vwaddu_vx_u32mf2(vuint16mf4_t, uint16_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vwaddu_vx_m)))
vuint32mf2_t vwaddu_vx_u32mf2_m(vbool64_t, vuint32mf2_t, vuint16mf4_t, uint16_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vwaddu_vx)))
vuint32m1_t vwaddu_vx_u32m1(vuint16mf2_t, uint16_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vwaddu_vx_m)))
vuint32m1_t vwaddu_vx_u32m1_m(vbool32_t, vuint32m1_t, vuint16mf2_t, uint16_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vwaddu_vx)))
vuint32m2_t vwaddu_vx_u32m2(vuint16m1_t, uint16_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vwaddu_vx_m)))
vuint32m2_t vwaddu_vx_u32m2_m(vbool16_t, vuint32m2_t, vuint16m1_t, uint16_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vwaddu_vx)))
vuint32m4_t vwaddu_vx_u32m4(vuint16m2_t, uint16_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vwaddu_vx_m)))
vuint32m4_t vwaddu_vx_u32m4_m(vbool8_t, vuint32m4_t, vuint16m2_t, uint16_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vwaddu_vx)))
vuint32m8_t vwaddu_vx_u32m8(vuint16m4_t, uint16_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vwaddu_vx_m)))
vuint32m8_t vwaddu_vx_u32m8_m(vbool4_t, vuint32m8_t, vuint16m4_t, uint16_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vwsubu_vv)))
vuint16mf4_t vwsubu_vv_u16mf4(vuint8mf8_t, vuint8mf8_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vwsubu_vv_m)))
vuint16mf4_t vwsubu_vv_u16mf4_m(vbool64_t, vuint16mf4_t, vuint8mf8_t, vuint8mf8_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vwsubu_vv)))
vuint16mf2_t vwsubu_vv_u16mf2(vuint8mf4_t, vuint8mf4_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vwsubu_vv_m)))
vuint16mf2_t vwsubu_vv_u16mf2_m(vbool32_t, vuint16mf2_t, vuint8mf4_t, vuint8mf4_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vwsubu_vv)))
vuint16m1_t vwsubu_vv_u16m1(vuint8mf2_t, vuint8mf2_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vwsubu_vv_m)))
vuint16m1_t vwsubu_vv_u16m1_m(vbool16_t, vuint16m1_t, vuint8mf2_t, vuint8mf2_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vwsubu_vv)))
vuint16m2_t vwsubu_vv_u16m2(vuint8m1_t, vuint8m1_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vwsubu_vv_m)))
vuint16m2_t vwsubu_vv_u16m2_m(vbool8_t, vuint16m2_t, vuint8m1_t, vuint8m1_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vwsubu_vv)))
vuint16m4_t vwsubu_vv_u16m4(vuint8m2_t, vuint8m2_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vwsubu_vv_m)))
vuint16m4_t vwsubu_vv_u16m4_m(vbool4_t, vuint16m4_t, vuint8m2_t, vuint8m2_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vwsubu_vv)))
vuint16m8_t vwsubu_vv_u16m8(vuint8m4_t, vuint8m4_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vwsubu_vv_m)))
vuint16m8_t vwsubu_vv_u16m8_m(vbool2_t, vuint16m8_t, vuint8m4_t, vuint8m4_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vwsubu_vv)))
vuint32mf2_t vwsubu_vv_u32mf2(vuint16mf4_t, vuint16mf4_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vwsubu_vv_m)))
vuint32mf2_t vwsubu_vv_u32mf2_m(vbool64_t, vuint32mf2_t, vuint16mf4_t, vuint16mf4_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vwsubu_vv)))
vuint32m1_t vwsubu_vv_u32m1(vuint16mf2_t, vuint16mf2_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vwsubu_vv_m)))
vuint32m1_t vwsubu_vv_u32m1_m(vbool32_t, vuint32m1_t, vuint16mf2_t, vuint16mf2_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vwsubu_vv)))
vuint32m2_t vwsubu_vv_u32m2(vuint16m1_t, vuint16m1_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vwsubu_vv_m)))
vuint32m2_t vwsubu_vv_u32m2_m(vbool16_t, vuint32m2_t, vuint16m1_t, vuint16m1_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vwsubu_vv)))
vuint32m4_t vwsubu_vv_u32m4(vuint16m2_t, vuint16m2_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vwsubu_vv_m)))
vuint32m4_t vwsubu_vv_u32m4_m(vbool8_t, vuint32m4_t, vuint16m2_t, vuint16m2_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vwsubu_vv)))
vuint32m8_t vwsubu_vv_u32m8(vuint16m4_t, vuint16m4_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vwsubu_vv_m)))
vuint32m8_t vwsubu_vv_u32m8_m(vbool4_t, vuint32m8_t, vuint16m4_t, vuint16m4_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vwsubu_vx)))
vuint16mf4_t vwsubu_vx_u16mf4(vuint8mf8_t, uint8_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vwsubu_vx_m)))
vuint16mf4_t vwsubu_vx_u16mf4_m(vbool64_t, vuint16mf4_t, vuint8mf8_t, uint8_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vwsubu_vx)))
vuint16mf2_t vwsubu_vx_u16mf2(vuint8mf4_t, uint8_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vwsubu_vx_m)))
vuint16mf2_t vwsubu_vx_u16mf2_m(vbool32_t, vuint16mf2_t, vuint8mf4_t, uint8_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vwsubu_vx)))
vuint16m1_t vwsubu_vx_u16m1(vuint8mf2_t, uint8_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vwsubu_vx_m)))
vuint16m1_t vwsubu_vx_u16m1_m(vbool16_t, vuint16m1_t, vuint8mf2_t, uint8_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vwsubu_vx)))
vuint16m2_t vwsubu_vx_u16m2(vuint8m1_t, uint8_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vwsubu_vx_m)))
vuint16m2_t vwsubu_vx_u16m2_m(vbool8_t, vuint16m2_t, vuint8m1_t, uint8_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vwsubu_vx)))
vuint16m4_t vwsubu_vx_u16m4(vuint8m2_t, uint8_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vwsubu_vx_m)))
vuint16m4_t vwsubu_vx_u16m4_m(vbool4_t, vuint16m4_t, vuint8m2_t, uint8_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vwsubu_vx)))
vuint16m8_t vwsubu_vx_u16m8(vuint8m4_t, uint8_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vwsubu_vx_m)))
vuint16m8_t vwsubu_vx_u16m8_m(vbool2_t, vuint16m8_t, vuint8m4_t, uint8_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vwsubu_vx)))
vuint32mf2_t vwsubu_vx_u32mf2(vuint16mf4_t, uint16_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vwsubu_vx_m)))
vuint32mf2_t vwsubu_vx_u32mf2_m(vbool64_t, vuint32mf2_t, vuint16mf4_t, uint16_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vwsubu_vx)))
vuint32m1_t vwsubu_vx_u32m1(vuint16mf2_t, uint16_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vwsubu_vx_m)))
vuint32m1_t vwsubu_vx_u32m1_m(vbool32_t, vuint32m1_t, vuint16mf2_t, uint16_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vwsubu_vx)))
vuint32m2_t vwsubu_vx_u32m2(vuint16m1_t, uint16_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vwsubu_vx_m)))
vuint32m2_t vwsubu_vx_u32m2_m(vbool16_t, vuint32m2_t, vuint16m1_t, uint16_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vwsubu_vx)))
vuint32m4_t vwsubu_vx_u32m4(vuint16m2_t, uint16_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vwsubu_vx_m)))
vuint32m4_t vwsubu_vx_u32m4_m(vbool8_t, vuint32m4_t, vuint16m2_t, uint16_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vwsubu_vx)))
vuint32m8_t vwsubu_vx_u32m8(vuint16m4_t, uint16_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vwsubu_vx_m)))
vuint32m8_t vwsubu_vx_u32m8_m(vbool4_t, vuint32m8_t, vuint16m4_t, uint16_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vwadd_vv)))
vint16mf4_t vwadd_vv_i16mf4(vint8mf8_t, vint8mf8_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vwadd_vv_m)))
vint16mf4_t vwadd_vv_i16mf4_m(vbool64_t, vint16mf4_t, vint8mf8_t, vint8mf8_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vwadd_vv)))
vint16mf2_t vwadd_vv_i16mf2(vint8mf4_t, vint8mf4_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vwadd_vv_m)))
vint16mf2_t vwadd_vv_i16mf2_m(vbool32_t, vint16mf2_t, vint8mf4_t, vint8mf4_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vwadd_vv)))
vint16m1_t vwadd_vv_i16m1(vint8mf2_t, vint8mf2_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vwadd_vv_m)))
vint16m1_t vwadd_vv_i16m1_m(vbool16_t, vint16m1_t, vint8mf2_t, vint8mf2_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vwadd_vv)))
vint16m2_t vwadd_vv_i16m2(vint8m1_t, vint8m1_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vwadd_vv_m)))
vint16m2_t vwadd_vv_i16m2_m(vbool8_t, vint16m2_t, vint8m1_t, vint8m1_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vwadd_vv)))
vint16m4_t vwadd_vv_i16m4(vint8m2_t, vint8m2_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vwadd_vv_m)))
vint16m4_t vwadd_vv_i16m4_m(vbool4_t, vint16m4_t, vint8m2_t, vint8m2_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vwadd_vv)))
vint16m8_t vwadd_vv_i16m8(vint8m4_t, vint8m4_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vwadd_vv_m)))
vint16m8_t vwadd_vv_i16m8_m(vbool2_t, vint16m8_t, vint8m4_t, vint8m4_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vwadd_vv)))
vint32mf2_t vwadd_vv_i32mf2(vint16mf4_t, vint16mf4_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vwadd_vv_m)))
vint32mf2_t vwadd_vv_i32mf2_m(vbool64_t, vint32mf2_t, vint16mf4_t, vint16mf4_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vwadd_vv)))
vint32m1_t vwadd_vv_i32m1(vint16mf2_t, vint16mf2_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vwadd_vv_m)))
vint32m1_t vwadd_vv_i32m1_m(vbool32_t, vint32m1_t, vint16mf2_t, vint16mf2_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vwadd_vv)))
vint32m2_t vwadd_vv_i32m2(vint16m1_t, vint16m1_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vwadd_vv_m)))
vint32m2_t vwadd_vv_i32m2_m(vbool16_t, vint32m2_t, vint16m1_t, vint16m1_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vwadd_vv)))
vint32m4_t vwadd_vv_i32m4(vint16m2_t, vint16m2_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vwadd_vv_m)))
vint32m4_t vwadd_vv_i32m4_m(vbool8_t, vint32m4_t, vint16m2_t, vint16m2_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vwadd_vv)))
vint32m8_t vwadd_vv_i32m8(vint16m4_t, vint16m4_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vwadd_vv_m)))
vint32m8_t vwadd_vv_i32m8_m(vbool4_t, vint32m8_t, vint16m4_t, vint16m4_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vwadd_vx)))
vint16mf4_t vwadd_vx_i16mf4(vint8mf8_t, int8_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vwadd_vx_m)))
vint16mf4_t vwadd_vx_i16mf4_m(vbool64_t, vint16mf4_t, vint8mf8_t, int8_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vwadd_vx)))
vint16mf2_t vwadd_vx_i16mf2(vint8mf4_t, int8_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vwadd_vx_m)))
vint16mf2_t vwadd_vx_i16mf2_m(vbool32_t, vint16mf2_t, vint8mf4_t, int8_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vwadd_vx)))
vint16m1_t vwadd_vx_i16m1(vint8mf2_t, int8_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vwadd_vx_m)))
vint16m1_t vwadd_vx_i16m1_m(vbool16_t, vint16m1_t, vint8mf2_t, int8_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vwadd_vx)))
vint16m2_t vwadd_vx_i16m2(vint8m1_t, int8_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vwadd_vx_m)))
vint16m2_t vwadd_vx_i16m2_m(vbool8_t, vint16m2_t, vint8m1_t, int8_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vwadd_vx)))
vint16m4_t vwadd_vx_i16m4(vint8m2_t, int8_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vwadd_vx_m)))
vint16m4_t vwadd_vx_i16m4_m(vbool4_t, vint16m4_t, vint8m2_t, int8_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vwadd_vx)))
vint16m8_t vwadd_vx_i16m8(vint8m4_t, int8_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vwadd_vx_m)))
vint16m8_t vwadd_vx_i16m8_m(vbool2_t, vint16m8_t, vint8m4_t, int8_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vwadd_vx)))
vint32mf2_t vwadd_vx_i32mf2(vint16mf4_t, int16_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vwadd_vx_m)))
vint32mf2_t vwadd_vx_i32mf2_m(vbool64_t, vint32mf2_t, vint16mf4_t, int16_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vwadd_vx)))
vint32m1_t vwadd_vx_i32m1(vint16mf2_t, int16_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vwadd_vx_m)))
vint32m1_t vwadd_vx_i32m1_m(vbool32_t, vint32m1_t, vint16mf2_t, int16_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vwadd_vx)))
vint32m2_t vwadd_vx_i32m2(vint16m1_t, int16_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vwadd_vx_m)))
vint32m2_t vwadd_vx_i32m2_m(vbool16_t, vint32m2_t, vint16m1_t, int16_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vwadd_vx)))
vint32m4_t vwadd_vx_i32m4(vint16m2_t, int16_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vwadd_vx_m)))
vint32m4_t vwadd_vx_i32m4_m(vbool8_t, vint32m4_t, vint16m2_t, int16_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vwadd_vx)))
vint32m8_t vwadd_vx_i32m8(vint16m4_t, int16_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vwadd_vx_m)))
vint32m8_t vwadd_vx_i32m8_m(vbool4_t, vint32m8_t, vint16m4_t, int16_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vwsub_vv)))
vint16mf4_t vwsub_vv_i16mf4(vint8mf8_t, vint8mf8_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vwsub_vv_m)))
vint16mf4_t vwsub_vv_i16mf4_m(vbool64_t, vint16mf4_t, vint8mf8_t, vint8mf8_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vwsub_vv)))
vint16mf2_t vwsub_vv_i16mf2(vint8mf4_t, vint8mf4_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vwsub_vv_m)))
vint16mf2_t vwsub_vv_i16mf2_m(vbool32_t, vint16mf2_t, vint8mf4_t, vint8mf4_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vwsub_vv)))
vint16m1_t vwsub_vv_i16m1(vint8mf2_t, vint8mf2_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vwsub_vv_m)))
vint16m1_t vwsub_vv_i16m1_m(vbool16_t, vint16m1_t, vint8mf2_t, vint8mf2_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vwsub_vv)))
vint16m2_t vwsub_vv_i16m2(vint8m1_t, vint8m1_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vwsub_vv_m)))
vint16m2_t vwsub_vv_i16m2_m(vbool8_t, vint16m2_t, vint8m1_t, vint8m1_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vwsub_vv)))
vint16m4_t vwsub_vv_i16m4(vint8m2_t, vint8m2_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vwsub_vv_m)))
vint16m4_t vwsub_vv_i16m4_m(vbool4_t, vint16m4_t, vint8m2_t, vint8m2_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vwsub_vv)))
vint16m8_t vwsub_vv_i16m8(vint8m4_t, vint8m4_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vwsub_vv_m)))
vint16m8_t vwsub_vv_i16m8_m(vbool2_t, vint16m8_t, vint8m4_t, vint8m4_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vwsub_vv)))
vint32mf2_t vwsub_vv_i32mf2(vint16mf4_t, vint16mf4_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vwsub_vv_m)))
vint32mf2_t vwsub_vv_i32mf2_m(vbool64_t, vint32mf2_t, vint16mf4_t, vint16mf4_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vwsub_vv)))
vint32m1_t vwsub_vv_i32m1(vint16mf2_t, vint16mf2_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vwsub_vv_m)))
vint32m1_t vwsub_vv_i32m1_m(vbool32_t, vint32m1_t, vint16mf2_t, vint16mf2_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vwsub_vv)))
vint32m2_t vwsub_vv_i32m2(vint16m1_t, vint16m1_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vwsub_vv_m)))
vint32m2_t vwsub_vv_i32m2_m(vbool16_t, vint32m2_t, vint16m1_t, vint16m1_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vwsub_vv)))
vint32m4_t vwsub_vv_i32m4(vint16m2_t, vint16m2_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vwsub_vv_m)))
vint32m4_t vwsub_vv_i32m4_m(vbool8_t, vint32m4_t, vint16m2_t, vint16m2_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vwsub_vv)))
vint32m8_t vwsub_vv_i32m8(vint16m4_t, vint16m4_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vwsub_vv_m)))
vint32m8_t vwsub_vv_i32m8_m(vbool4_t, vint32m8_t, vint16m4_t, vint16m4_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vwsub_vx)))
vint16mf4_t vwsub_vx_i16mf4(vint8mf8_t, int8_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vwsub_vx_m)))
vint16mf4_t vwsub_vx_i16mf4_m(vbool64_t, vint16mf4_t, vint8mf8_t, int8_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vwsub_vx)))
vint16mf2_t vwsub_vx_i16mf2(vint8mf4_t, int8_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vwsub_vx_m)))
vint16mf2_t vwsub_vx_i16mf2_m(vbool32_t, vint16mf2_t, vint8mf4_t, int8_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vwsub_vx)))
vint16m1_t vwsub_vx_i16m1(vint8mf2_t, int8_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vwsub_vx_m)))
vint16m1_t vwsub_vx_i16m1_m(vbool16_t, vint16m1_t, vint8mf2_t, int8_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vwsub_vx)))
vint16m2_t vwsub_vx_i16m2(vint8m1_t, int8_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vwsub_vx_m)))
vint16m2_t vwsub_vx_i16m2_m(vbool8_t, vint16m2_t, vint8m1_t, int8_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vwsub_vx)))
vint16m4_t vwsub_vx_i16m4(vint8m2_t, int8_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vwsub_vx_m)))
vint16m4_t vwsub_vx_i16m4_m(vbool4_t, vint16m4_t, vint8m2_t, int8_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vwsub_vx)))
vint16m8_t vwsub_vx_i16m8(vint8m4_t, int8_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vwsub_vx_m)))
vint16m8_t vwsub_vx_i16m8_m(vbool2_t, vint16m8_t, vint8m4_t, int8_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vwsub_vx)))
vint32mf2_t vwsub_vx_i32mf2(vint16mf4_t, int16_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vwsub_vx_m)))
vint32mf2_t vwsub_vx_i32mf2_m(vbool64_t, vint32mf2_t, vint16mf4_t, int16_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vwsub_vx)))
vint32m1_t vwsub_vx_i32m1(vint16mf2_t, int16_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vwsub_vx_m)))
vint32m1_t vwsub_vx_i32m1_m(vbool32_t, vint32m1_t, vint16mf2_t, int16_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vwsub_vx)))
vint32m2_t vwsub_vx_i32m2(vint16m1_t, int16_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vwsub_vx_m)))
vint32m2_t vwsub_vx_i32m2_m(vbool16_t, vint32m2_t, vint16m1_t, int16_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vwsub_vx)))
vint32m4_t vwsub_vx_i32m4(vint16m2_t, int16_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vwsub_vx_m)))
vint32m4_t vwsub_vx_i32m4_m(vbool8_t, vint32m4_t, vint16m2_t, int16_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vwsub_vx)))
vint32m8_t vwsub_vx_i32m8(vint16m4_t, int16_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vwsub_vx_m)))
vint32m8_t vwsub_vx_i32m8_m(vbool4_t, vint32m8_t, vint16m4_t, int16_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vwaddu_wx)))
vuint16mf4_t vwaddu_wx_u16mf4(vuint16mf4_t, uint8_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vwaddu_wx_m)))
vuint16mf4_t vwaddu_wx_u16mf4_m(vbool64_t, vuint16mf4_t, vuint16mf4_t, uint8_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vwaddu_wx)))
vuint16mf2_t vwaddu_wx_u16mf2(vuint16mf2_t, uint8_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vwaddu_wx_m)))
vuint16mf2_t vwaddu_wx_u16mf2_m(vbool32_t, vuint16mf2_t, vuint16mf2_t, uint8_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vwaddu_wx)))
vuint16m1_t vwaddu_wx_u16m1(vuint16m1_t, uint8_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vwaddu_wx_m)))
vuint16m1_t vwaddu_wx_u16m1_m(vbool16_t, vuint16m1_t, vuint16m1_t, uint8_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vwaddu_wx)))
vuint16m2_t vwaddu_wx_u16m2(vuint16m2_t, uint8_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vwaddu_wx_m)))
vuint16m2_t vwaddu_wx_u16m2_m(vbool8_t, vuint16m2_t, vuint16m2_t, uint8_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vwaddu_wx)))
vuint16m4_t vwaddu_wx_u16m4(vuint16m4_t, uint8_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vwaddu_wx_m)))
vuint16m4_t vwaddu_wx_u16m4_m(vbool4_t, vuint16m4_t, vuint16m4_t, uint8_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vwaddu_wx)))
vuint16m8_t vwaddu_wx_u16m8(vuint16m8_t, uint8_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vwaddu_wx_m)))
vuint16m8_t vwaddu_wx_u16m8_m(vbool2_t, vuint16m8_t, vuint16m8_t, uint8_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vwaddu_wx)))
vuint32mf2_t vwaddu_wx_u32mf2(vuint32mf2_t, uint16_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vwaddu_wx_m)))
vuint32mf2_t vwaddu_wx_u32mf2_m(vbool64_t, vuint32mf2_t, vuint32mf2_t, uint16_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vwaddu_wx)))
vuint32m1_t vwaddu_wx_u32m1(vuint32m1_t, uint16_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vwaddu_wx_m)))
vuint32m1_t vwaddu_wx_u32m1_m(vbool32_t, vuint32m1_t, vuint32m1_t, uint16_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vwaddu_wx)))
vuint32m2_t vwaddu_wx_u32m2(vuint32m2_t, uint16_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vwaddu_wx_m)))
vuint32m2_t vwaddu_wx_u32m2_m(vbool16_t, vuint32m2_t, vuint32m2_t, uint16_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vwaddu_wx)))
vuint32m4_t vwaddu_wx_u32m4(vuint32m4_t, uint16_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vwaddu_wx_m)))
vuint32m4_t vwaddu_wx_u32m4_m(vbool8_t, vuint32m4_t, vuint32m4_t, uint16_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vwaddu_wx)))
vuint32m8_t vwaddu_wx_u32m8(vuint32m8_t, uint16_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vwaddu_wx_m)))
vuint32m8_t vwaddu_wx_u32m8_m(vbool4_t, vuint32m8_t, vuint32m8_t, uint16_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vwsubu_wv)))
vuint16mf4_t vwsubu_wv_u16mf4(vuint16mf4_t, vuint8mf8_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vwsubu_wv_m)))
vuint16mf4_t vwsubu_wv_u16mf4_m(vbool64_t, vuint16mf4_t, vuint16mf4_t, vuint8mf8_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vwsubu_wv)))
vuint16mf2_t vwsubu_wv_u16mf2(vuint16mf2_t, vuint8mf4_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vwsubu_wv_m)))
vuint16mf2_t vwsubu_wv_u16mf2_m(vbool32_t, vuint16mf2_t, vuint16mf2_t, vuint8mf4_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vwsubu_wv)))
vuint16m1_t vwsubu_wv_u16m1(vuint16m1_t, vuint8mf2_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vwsubu_wv_m)))
vuint16m1_t vwsubu_wv_u16m1_m(vbool16_t, vuint16m1_t, vuint16m1_t, vuint8mf2_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vwsubu_wv)))
vuint16m2_t vwsubu_wv_u16m2(vuint16m2_t, vuint8m1_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vwsubu_wv_m)))
vuint16m2_t vwsubu_wv_u16m2_m(vbool8_t, vuint16m2_t, vuint16m2_t, vuint8m1_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vwsubu_wv)))
vuint16m4_t vwsubu_wv_u16m4(vuint16m4_t, vuint8m2_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vwsubu_wv_m)))
vuint16m4_t vwsubu_wv_u16m4_m(vbool4_t, vuint16m4_t, vuint16m4_t, vuint8m2_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vwsubu_wv)))
vuint16m8_t vwsubu_wv_u16m8(vuint16m8_t, vuint8m4_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vwsubu_wv_m)))
vuint16m8_t vwsubu_wv_u16m8_m(vbool2_t, vuint16m8_t, vuint16m8_t, vuint8m4_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vwsubu_wv)))
vuint32mf2_t vwsubu_wv_u32mf2(vuint32mf2_t, vuint16mf4_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vwsubu_wv_m)))
vuint32mf2_t vwsubu_wv_u32mf2_m(vbool64_t, vuint32mf2_t, vuint32mf2_t, vuint16mf4_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vwsubu_wv)))
vuint32m1_t vwsubu_wv_u32m1(vuint32m1_t, vuint16mf2_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vwsubu_wv_m)))
vuint32m1_t vwsubu_wv_u32m1_m(vbool32_t, vuint32m1_t, vuint32m1_t, vuint16mf2_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vwsubu_wv)))
vuint32m2_t vwsubu_wv_u32m2(vuint32m2_t, vuint16m1_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vwsubu_wv_m)))
vuint32m2_t vwsubu_wv_u32m2_m(vbool16_t, vuint32m2_t, vuint32m2_t, vuint16m1_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vwsubu_wv)))
vuint32m4_t vwsubu_wv_u32m4(vuint32m4_t, vuint16m2_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vwsubu_wv_m)))
vuint32m4_t vwsubu_wv_u32m4_m(vbool8_t, vuint32m4_t, vuint32m4_t, vuint16m2_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vwsubu_wv)))
vuint32m8_t vwsubu_wv_u32m8(vuint32m8_t, vuint16m4_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vwsubu_wv_m)))
vuint32m8_t vwsubu_wv_u32m8_m(vbool4_t, vuint32m8_t, vuint32m8_t, vuint16m4_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vwsubu_wx)))
vuint16mf4_t vwsubu_wx_u16mf4(vuint16mf4_t, uint8_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vwsubu_wx_m)))
vuint16mf4_t vwsubu_wx_u16mf4_m(vbool64_t, vuint16mf4_t, vuint16mf4_t, uint8_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vwsubu_wx)))
vuint16mf2_t vwsubu_wx_u16mf2(vuint16mf2_t, uint8_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vwsubu_wx_m)))
vuint16mf2_t vwsubu_wx_u16mf2_m(vbool32_t, vuint16mf2_t, vuint16mf2_t, uint8_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vwsubu_wx)))
vuint16m1_t vwsubu_wx_u16m1(vuint16m1_t, uint8_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vwsubu_wx_m)))
vuint16m1_t vwsubu_wx_u16m1_m(vbool16_t, vuint16m1_t, vuint16m1_t, uint8_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vwsubu_wx)))
vuint16m2_t vwsubu_wx_u16m2(vuint16m2_t, uint8_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vwsubu_wx_m)))
vuint16m2_t vwsubu_wx_u16m2_m(vbool8_t, vuint16m2_t, vuint16m2_t, uint8_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vwsubu_wx)))
vuint16m4_t vwsubu_wx_u16m4(vuint16m4_t, uint8_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vwsubu_wx_m)))
vuint16m4_t vwsubu_wx_u16m4_m(vbool4_t, vuint16m4_t, vuint16m4_t, uint8_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vwsubu_wx)))
vuint16m8_t vwsubu_wx_u16m8(vuint16m8_t, uint8_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vwsubu_wx_m)))
vuint16m8_t vwsubu_wx_u16m8_m(vbool2_t, vuint16m8_t, vuint16m8_t, uint8_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vwsubu_wx)))
vuint32mf2_t vwsubu_wx_u32mf2(vuint32mf2_t, uint16_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vwsubu_wx_m)))
vuint32mf2_t vwsubu_wx_u32mf2_m(vbool64_t, vuint32mf2_t, vuint32mf2_t, uint16_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vwsubu_wx)))
vuint32m1_t vwsubu_wx_u32m1(vuint32m1_t, uint16_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vwsubu_wx_m)))
vuint32m1_t vwsubu_wx_u32m1_m(vbool32_t, vuint32m1_t, vuint32m1_t, uint16_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vwsubu_wx)))
vuint32m2_t vwsubu_wx_u32m2(vuint32m2_t, uint16_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vwsubu_wx_m)))
vuint32m2_t vwsubu_wx_u32m2_m(vbool16_t, vuint32m2_t, vuint32m2_t, uint16_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vwsubu_wx)))
vuint32m4_t vwsubu_wx_u32m4(vuint32m4_t, uint16_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vwsubu_wx_m)))
vuint32m4_t vwsubu_wx_u32m4_m(vbool8_t, vuint32m4_t, vuint32m4_t, uint16_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vwsubu_wx)))
vuint32m8_t vwsubu_wx_u32m8(vuint32m8_t, uint16_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vwsubu_wx_m)))
vuint32m8_t vwsubu_wx_u32m8_m(vbool4_t, vuint32m8_t, vuint32m8_t, uint16_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vwadd_wv)))
vint16mf4_t vwadd_wv_i16mf4(vint16mf4_t, vint8mf8_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vwadd_wv_m)))
vint16mf4_t vwadd_wv_i16mf4_m(vbool64_t, vint16mf4_t, vint16mf4_t, vint8mf8_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vwadd_wv)))
vint16mf2_t vwadd_wv_i16mf2(vint16mf2_t, vint8mf4_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vwadd_wv_m)))
vint16mf2_t vwadd_wv_i16mf2_m(vbool32_t, vint16mf2_t, vint16mf2_t, vint8mf4_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vwadd_wv)))
vint16m1_t vwadd_wv_i16m1(vint16m1_t, vint8mf2_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vwadd_wv_m)))
vint16m1_t vwadd_wv_i16m1_m(vbool16_t, vint16m1_t, vint16m1_t, vint8mf2_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vwadd_wv)))
vint16m2_t vwadd_wv_i16m2(vint16m2_t, vint8m1_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vwadd_wv_m)))
vint16m2_t vwadd_wv_i16m2_m(vbool8_t, vint16m2_t, vint16m2_t, vint8m1_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vwadd_wv)))
vint16m4_t vwadd_wv_i16m4(vint16m4_t, vint8m2_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vwadd_wv_m)))
vint16m4_t vwadd_wv_i16m4_m(vbool4_t, vint16m4_t, vint16m4_t, vint8m2_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vwadd_wv)))
vint16m8_t vwadd_wv_i16m8(vint16m8_t, vint8m4_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vwadd_wv_m)))
vint16m8_t vwadd_wv_i16m8_m(vbool2_t, vint16m8_t, vint16m8_t, vint8m4_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vwadd_wv)))
vint32mf2_t vwadd_wv_i32mf2(vint32mf2_t, vint16mf4_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vwadd_wv_m)))
vint32mf2_t vwadd_wv_i32mf2_m(vbool64_t, vint32mf2_t, vint32mf2_t, vint16mf4_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vwadd_wv)))
vint32m1_t vwadd_wv_i32m1(vint32m1_t, vint16mf2_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vwadd_wv_m)))
vint32m1_t vwadd_wv_i32m1_m(vbool32_t, vint32m1_t, vint32m1_t, vint16mf2_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vwadd_wv)))
vint32m2_t vwadd_wv_i32m2(vint32m2_t, vint16m1_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vwadd_wv_m)))
vint32m2_t vwadd_wv_i32m2_m(vbool16_t, vint32m2_t, vint32m2_t, vint16m1_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vwadd_wv)))
vint32m4_t vwadd_wv_i32m4(vint32m4_t, vint16m2_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vwadd_wv_m)))
vint32m4_t vwadd_wv_i32m4_m(vbool8_t, vint32m4_t, vint32m4_t, vint16m2_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vwadd_wv)))
vint32m8_t vwadd_wv_i32m8(vint32m8_t, vint16m4_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vwadd_wv_m)))
vint32m8_t vwadd_wv_i32m8_m(vbool4_t, vint32m8_t, vint32m8_t, vint16m4_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vwadd_wx)))
vint16mf4_t vwadd_wx_i16mf4(vint16mf4_t, int8_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vwadd_wx_m)))
vint16mf4_t vwadd_wx_i16mf4_m(vbool64_t, vint16mf4_t, vint16mf4_t, int8_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vwadd_wx)))
vint16mf2_t vwadd_wx_i16mf2(vint16mf2_t, int8_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vwadd_wx_m)))
vint16mf2_t vwadd_wx_i16mf2_m(vbool32_t, vint16mf2_t, vint16mf2_t, int8_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vwadd_wx)))
vint16m1_t vwadd_wx_i16m1(vint16m1_t, int8_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vwadd_wx_m)))
vint16m1_t vwadd_wx_i16m1_m(vbool16_t, vint16m1_t, vint16m1_t, int8_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vwadd_wx)))
vint16m2_t vwadd_wx_i16m2(vint16m2_t, int8_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vwadd_wx_m)))
vint16m2_t vwadd_wx_i16m2_m(vbool8_t, vint16m2_t, vint16m2_t, int8_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vwadd_wx)))
vint16m4_t vwadd_wx_i16m4(vint16m4_t, int8_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vwadd_wx_m)))
vint16m4_t vwadd_wx_i16m4_m(vbool4_t, vint16m4_t, vint16m4_t, int8_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vwadd_wx)))
vint16m8_t vwadd_wx_i16m8(vint16m8_t, int8_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vwadd_wx_m)))
vint16m8_t vwadd_wx_i16m8_m(vbool2_t, vint16m8_t, vint16m8_t, int8_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vwadd_wx)))
vint32mf2_t vwadd_wx_i32mf2(vint32mf2_t, int16_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vwadd_wx_m)))
vint32mf2_t vwadd_wx_i32mf2_m(vbool64_t, vint32mf2_t, vint32mf2_t, int16_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vwadd_wx)))
vint32m1_t vwadd_wx_i32m1(vint32m1_t, int16_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vwadd_wx_m)))
vint32m1_t vwadd_wx_i32m1_m(vbool32_t, vint32m1_t, vint32m1_t, int16_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vwadd_wx)))
vint32m2_t vwadd_wx_i32m2(vint32m2_t, int16_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vwadd_wx_m)))
vint32m2_t vwadd_wx_i32m2_m(vbool16_t, vint32m2_t, vint32m2_t, int16_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vwadd_wx)))
vint32m4_t vwadd_wx_i32m4(vint32m4_t, int16_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vwadd_wx_m)))
vint32m4_t vwadd_wx_i32m4_m(vbool8_t, vint32m4_t, vint32m4_t, int16_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vwadd_wx)))
vint32m8_t vwadd_wx_i32m8(vint32m8_t, int16_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vwadd_wx_m)))
vint32m8_t vwadd_wx_i32m8_m(vbool4_t, vint32m8_t, vint32m8_t, int16_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vwsub_wv)))
vint16mf4_t vwsub_wv_i16mf4(vint16mf4_t, vint8mf8_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vwsub_wv_m)))
vint16mf4_t vwsub_wv_i16mf4_m(vbool64_t, vint16mf4_t, vint16mf4_t, vint8mf8_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vwsub_wv)))
vint16mf2_t vwsub_wv_i16mf2(vint16mf2_t, vint8mf4_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vwsub_wv_m)))
vint16mf2_t vwsub_wv_i16mf2_m(vbool32_t, vint16mf2_t, vint16mf2_t, vint8mf4_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vwsub_wv)))
vint16m1_t vwsub_wv_i16m1(vint16m1_t, vint8mf2_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vwsub_wv_m)))
vint16m1_t vwsub_wv_i16m1_m(vbool16_t, vint16m1_t, vint16m1_t, vint8mf2_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vwsub_wv)))
vint16m2_t vwsub_wv_i16m2(vint16m2_t, vint8m1_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vwsub_wv_m)))
vint16m2_t vwsub_wv_i16m2_m(vbool8_t, vint16m2_t, vint16m2_t, vint8m1_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vwsub_wv)))
vint16m4_t vwsub_wv_i16m4(vint16m4_t, vint8m2_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vwsub_wv_m)))
vint16m4_t vwsub_wv_i16m4_m(vbool4_t, vint16m4_t, vint16m4_t, vint8m2_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vwsub_wv)))
vint16m8_t vwsub_wv_i16m8(vint16m8_t, vint8m4_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vwsub_wv_m)))
vint16m8_t vwsub_wv_i16m8_m(vbool2_t, vint16m8_t, vint16m8_t, vint8m4_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vwsub_wv)))
vint32mf2_t vwsub_wv_i32mf2(vint32mf2_t, vint16mf4_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vwsub_wv_m)))
vint32mf2_t vwsub_wv_i32mf2_m(vbool64_t, vint32mf2_t, vint32mf2_t, vint16mf4_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vwsub_wv)))
vint32m1_t vwsub_wv_i32m1(vint32m1_t, vint16mf2_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vwsub_wv_m)))
vint32m1_t vwsub_wv_i32m1_m(vbool32_t, vint32m1_t, vint32m1_t, vint16mf2_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vwsub_wv)))
vint32m2_t vwsub_wv_i32m2(vint32m2_t, vint16m1_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vwsub_wv_m)))
vint32m2_t vwsub_wv_i32m2_m(vbool16_t, vint32m2_t, vint32m2_t, vint16m1_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vwsub_wv)))
vint32m4_t vwsub_wv_i32m4(vint32m4_t, vint16m2_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vwsub_wv_m)))
vint32m4_t vwsub_wv_i32m4_m(vbool8_t, vint32m4_t, vint32m4_t, vint16m2_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vwsub_wv)))
vint32m8_t vwsub_wv_i32m8(vint32m8_t, vint16m4_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vwsub_wv_m)))
vint32m8_t vwsub_wv_i32m8_m(vbool4_t, vint32m8_t, vint32m8_t, vint16m4_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vwsub_wx)))
vint16mf4_t vwsub_wx_i16mf4(vint16mf4_t, int8_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vwsub_wx_m)))
vint16mf4_t vwsub_wx_i16mf4_m(vbool64_t, vint16mf4_t, vint16mf4_t, int8_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vwsub_wx)))
vint16mf2_t vwsub_wx_i16mf2(vint16mf2_t, int8_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vwsub_wx_m)))
vint16mf2_t vwsub_wx_i16mf2_m(vbool32_t, vint16mf2_t, vint16mf2_t, int8_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vwsub_wx)))
vint16m1_t vwsub_wx_i16m1(vint16m1_t, int8_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vwsub_wx_m)))
vint16m1_t vwsub_wx_i16m1_m(vbool16_t, vint16m1_t, vint16m1_t, int8_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vwsub_wx)))
vint16m2_t vwsub_wx_i16m2(vint16m2_t, int8_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vwsub_wx_m)))
vint16m2_t vwsub_wx_i16m2_m(vbool8_t, vint16m2_t, vint16m2_t, int8_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vwsub_wx)))
vint16m4_t vwsub_wx_i16m4(vint16m4_t, int8_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vwsub_wx_m)))
vint16m4_t vwsub_wx_i16m4_m(vbool4_t, vint16m4_t, vint16m4_t, int8_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vwsub_wx)))
vint16m8_t vwsub_wx_i16m8(vint16m8_t, int8_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vwsub_wx_m)))
vint16m8_t vwsub_wx_i16m8_m(vbool2_t, vint16m8_t, vint16m8_t, int8_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vwsub_wx)))
vint32mf2_t vwsub_wx_i32mf2(vint32mf2_t, int16_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vwsub_wx_m)))
vint32mf2_t vwsub_wx_i32mf2_m(vbool64_t, vint32mf2_t, vint32mf2_t, int16_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vwsub_wx)))
vint32m1_t vwsub_wx_i32m1(vint32m1_t, int16_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vwsub_wx_m)))
vint32m1_t vwsub_wx_i32m1_m(vbool32_t, vint32m1_t, vint32m1_t, int16_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vwsub_wx)))
vint32m2_t vwsub_wx_i32m2(vint32m2_t, int16_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vwsub_wx_m)))
vint32m2_t vwsub_wx_i32m2_m(vbool16_t, vint32m2_t, vint32m2_t, int16_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vwsub_wx)))
vint32m4_t vwsub_wx_i32m4(vint32m4_t, int16_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vwsub_wx_m)))
vint32m4_t vwsub_wx_i32m4_m(vbool8_t, vint32m4_t, vint32m4_t, int16_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vwsub_wx)))
vint32m8_t vwsub_wx_i32m8(vint32m8_t, int16_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vwsub_wx_m)))
vint32m8_t vwsub_wx_i32m8_m(vbool4_t, vint32m8_t, vint32m8_t, int16_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vwcvt_x_x_v)))
vint16m2_t vwcvt_x_x_v_i16m2(vint8m1_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vwcvt_x_x_v_m)))
vint16m2_t vwcvt_x_x_v_i16m2_m(vbool8_t, vint16m2_t, vint8m1_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vwcvt_x_x_v)))
vint16m4_t vwcvt_x_x_v_i16m4(vint8m2_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vwcvt_x_x_v_m)))
vint16m4_t vwcvt_x_x_v_i16m4_m(vbool4_t, vint16m4_t, vint8m2_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vwcvt_x_x_v)))
vint16m8_t vwcvt_x_x_v_i16m8(vint8m4_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vwcvt_x_x_v_m)))
vint16m8_t vwcvt_x_x_v_i16m8_m(vbool2_t, vint16m8_t, vint8m4_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vwcvt_x_x_v)))
vint16m1_t vwcvt_x_x_v_i16m1(vint8mf2_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vwcvt_x_x_v_m)))
vint16m1_t vwcvt_x_x_v_i16m1_m(vbool16_t, vint16m1_t, vint8mf2_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vwcvt_x_x_v)))
vint16mf2_t vwcvt_x_x_v_i16mf2(vint8mf4_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vwcvt_x_x_v_m)))
vint16mf2_t vwcvt_x_x_v_i16mf2_m(vbool32_t, vint16mf2_t, vint8mf4_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vwcvt_x_x_v)))
vint16mf4_t vwcvt_x_x_v_i16mf4(vint8mf8_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vwcvt_x_x_v_m)))
vint16mf4_t vwcvt_x_x_v_i16mf4_m(vbool64_t, vint16mf4_t, vint8mf8_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vwcvt_x_x_v)))
vint32m2_t vwcvt_x_x_v_i32m2(vint16m1_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vwcvt_x_x_v_m)))
vint32m2_t vwcvt_x_x_v_i32m2_m(vbool16_t, vint32m2_t, vint16m1_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vwcvt_x_x_v)))
vint32m4_t vwcvt_x_x_v_i32m4(vint16m2_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vwcvt_x_x_v_m)))
vint32m4_t vwcvt_x_x_v_i32m4_m(vbool8_t, vint32m4_t, vint16m2_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vwcvt_x_x_v)))
vint32m8_t vwcvt_x_x_v_i32m8(vint16m4_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vwcvt_x_x_v_m)))
vint32m8_t vwcvt_x_x_v_i32m8_m(vbool4_t, vint32m8_t, vint16m4_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vwcvt_x_x_v)))
vint32m1_t vwcvt_x_x_v_i32m1(vint16mf2_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vwcvt_x_x_v_m)))
vint32m1_t vwcvt_x_x_v_i32m1_m(vbool32_t, vint32m1_t, vint16mf2_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vwcvt_x_x_v)))
vint32mf2_t vwcvt_x_x_v_i32mf2(vint16mf4_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vwcvt_x_x_v_m)))
vint32mf2_t vwcvt_x_x_v_i32mf2_m(vbool64_t, vint32mf2_t, vint16mf4_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vadc_vvm)))
vint8m1_t vadc_vvm_i8m1(vint8m1_t, vint8m1_t, vbool8_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vadc_vvm)))
vint8m2_t vadc_vvm_i8m2(vint8m2_t, vint8m2_t, vbool4_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vadc_vvm)))
vint8m4_t vadc_vvm_i8m4(vint8m4_t, vint8m4_t, vbool2_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vadc_vvm)))
vint8m8_t vadc_vvm_i8m8(vint8m8_t, vint8m8_t, vbool1_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vadc_vvm)))
vint8mf2_t vadc_vvm_i8mf2(vint8mf2_t, vint8mf2_t, vbool16_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vadc_vvm)))
vint8mf4_t vadc_vvm_i8mf4(vint8mf4_t, vint8mf4_t, vbool32_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vadc_vvm)))
vint8mf8_t vadc_vvm_i8mf8(vint8mf8_t, vint8mf8_t, vbool64_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vadc_vvm)))
vint16m1_t vadc_vvm_i16m1(vint16m1_t, vint16m1_t, vbool16_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vadc_vvm)))
vint16m2_t vadc_vvm_i16m2(vint16m2_t, vint16m2_t, vbool8_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vadc_vvm)))
vint16m4_t vadc_vvm_i16m4(vint16m4_t, vint16m4_t, vbool4_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vadc_vvm)))
vint16m8_t vadc_vvm_i16m8(vint16m8_t, vint16m8_t, vbool2_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vadc_vvm)))
vint16mf2_t vadc_vvm_i16mf2(vint16mf2_t, vint16mf2_t, vbool32_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vadc_vvm)))
vint16mf4_t vadc_vvm_i16mf4(vint16mf4_t, vint16mf4_t, vbool64_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vadc_vvm)))
vint32m1_t vadc_vvm_i32m1(vint32m1_t, vint32m1_t, vbool32_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vadc_vvm)))
vint32m2_t vadc_vvm_i32m2(vint32m2_t, vint32m2_t, vbool16_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vadc_vvm)))
vint32m4_t vadc_vvm_i32m4(vint32m4_t, vint32m4_t, vbool8_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vadc_vvm)))
vint32m8_t vadc_vvm_i32m8(vint32m8_t, vint32m8_t, vbool4_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vadc_vvm)))
vint32mf2_t vadc_vvm_i32mf2(vint32mf2_t, vint32mf2_t, vbool64_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vadc_vxm)))
vint8m1_t vadc_vxm_i8m1(vint8m1_t, int8_t, vbool8_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vadc_vxm)))
vint8m2_t vadc_vxm_i8m2(vint8m2_t, int8_t, vbool4_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vadc_vxm)))
vint8m4_t vadc_vxm_i8m4(vint8m4_t, int8_t, vbool2_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vadc_vxm)))
vint8m8_t vadc_vxm_i8m8(vint8m8_t, int8_t, vbool1_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vadc_vxm)))
vint8mf2_t vadc_vxm_i8mf2(vint8mf2_t, int8_t, vbool16_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vadc_vxm)))
vint8mf4_t vadc_vxm_i8mf4(vint8mf4_t, int8_t, vbool32_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vadc_vxm)))
vint8mf8_t vadc_vxm_i8mf8(vint8mf8_t, int8_t, vbool64_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vadc_vxm)))
vint16m1_t vadc_vxm_i16m1(vint16m1_t, int16_t, vbool16_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vadc_vxm)))
vint16m2_t vadc_vxm_i16m2(vint16m2_t, int16_t, vbool8_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vadc_vxm)))
vint16m4_t vadc_vxm_i16m4(vint16m4_t, int16_t, vbool4_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vadc_vxm)))
vint16m8_t vadc_vxm_i16m8(vint16m8_t, int16_t, vbool2_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vadc_vxm)))
vint16mf2_t vadc_vxm_i16mf2(vint16mf2_t, int16_t, vbool32_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vadc_vxm)))
vint16mf4_t vadc_vxm_i16mf4(vint16mf4_t, int16_t, vbool64_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vadc_vxm)))
vint32m1_t vadc_vxm_i32m1(vint32m1_t, int32_t, vbool32_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vadc_vxm)))
vint32m2_t vadc_vxm_i32m2(vint32m2_t, int32_t, vbool16_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vadc_vxm)))
vint32m4_t vadc_vxm_i32m4(vint32m4_t, int32_t, vbool8_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vadc_vxm)))
vint32m8_t vadc_vxm_i32m8(vint32m8_t, int32_t, vbool4_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vadc_vxm)))
vint32mf2_t vadc_vxm_i32mf2(vint32mf2_t, int32_t, vbool64_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vadc_vvm)))
vuint8m1_t vadc_vvm_u8m1(vuint8m1_t, vuint8m1_t, vbool8_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vadc_vvm)))
vuint8m2_t vadc_vvm_u8m2(vuint8m2_t, vuint8m2_t, vbool4_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vadc_vvm)))
vuint8m4_t vadc_vvm_u8m4(vuint8m4_t, vuint8m4_t, vbool2_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vadc_vvm)))
vuint8m8_t vadc_vvm_u8m8(vuint8m8_t, vuint8m8_t, vbool1_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vadc_vvm)))
vuint8mf2_t vadc_vvm_u8mf2(vuint8mf2_t, vuint8mf2_t, vbool16_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vadc_vvm)))
vuint8mf4_t vadc_vvm_u8mf4(vuint8mf4_t, vuint8mf4_t, vbool32_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vadc_vvm)))
vuint8mf8_t vadc_vvm_u8mf8(vuint8mf8_t, vuint8mf8_t, vbool64_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vadc_vvm)))
vuint16m1_t vadc_vvm_u16m1(vuint16m1_t, vuint16m1_t, vbool16_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vadc_vvm)))
vuint16m2_t vadc_vvm_u16m2(vuint16m2_t, vuint16m2_t, vbool8_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vadc_vvm)))
vuint16m4_t vadc_vvm_u16m4(vuint16m4_t, vuint16m4_t, vbool4_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vadc_vvm)))
vuint16m8_t vadc_vvm_u16m8(vuint16m8_t, vuint16m8_t, vbool2_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vadc_vvm)))
vuint16mf2_t vadc_vvm_u16mf2(vuint16mf2_t, vuint16mf2_t, vbool32_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vadc_vvm)))
vuint16mf4_t vadc_vvm_u16mf4(vuint16mf4_t, vuint16mf4_t, vbool64_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vadc_vvm)))
vuint32m1_t vadc_vvm_u32m1(vuint32m1_t, vuint32m1_t, vbool32_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vadc_vvm)))
vuint32m2_t vadc_vvm_u32m2(vuint32m2_t, vuint32m2_t, vbool16_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vadc_vvm)))
vuint32m4_t vadc_vvm_u32m4(vuint32m4_t, vuint32m4_t, vbool8_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vadc_vvm)))
vuint32m8_t vadc_vvm_u32m8(vuint32m8_t, vuint32m8_t, vbool4_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vadc_vvm)))
vuint32mf2_t vadc_vvm_u32mf2(vuint32mf2_t, vuint32mf2_t, vbool64_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vadc_vxm)))
vuint8m1_t vadc_vxm_u8m1(vuint8m1_t, uint8_t, vbool8_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vadc_vxm)))
vuint8m2_t vadc_vxm_u8m2(vuint8m2_t, uint8_t, vbool4_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vadc_vxm)))
vuint8m4_t vadc_vxm_u8m4(vuint8m4_t, uint8_t, vbool2_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vadc_vxm)))
vuint8m8_t vadc_vxm_u8m8(vuint8m8_t, uint8_t, vbool1_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vadc_vxm)))
vuint8mf2_t vadc_vxm_u8mf2(vuint8mf2_t, uint8_t, vbool16_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vadc_vxm)))
vuint8mf4_t vadc_vxm_u8mf4(vuint8mf4_t, uint8_t, vbool32_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vadc_vxm)))
vuint8mf8_t vadc_vxm_u8mf8(vuint8mf8_t, uint8_t, vbool64_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vadc_vxm)))
vuint16m1_t vadc_vxm_u16m1(vuint16m1_t, uint16_t, vbool16_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vadc_vxm)))
vuint16m2_t vadc_vxm_u16m2(vuint16m2_t, uint16_t, vbool8_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vadc_vxm)))
vuint16m4_t vadc_vxm_u16m4(vuint16m4_t, uint16_t, vbool4_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vadc_vxm)))
vuint16m8_t vadc_vxm_u16m8(vuint16m8_t, uint16_t, vbool2_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vadc_vxm)))
vuint16mf2_t vadc_vxm_u16mf2(vuint16mf2_t, uint16_t, vbool32_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vadc_vxm)))
vuint16mf4_t vadc_vxm_u16mf4(vuint16mf4_t, uint16_t, vbool64_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vadc_vxm)))
vuint32m1_t vadc_vxm_u32m1(vuint32m1_t, uint32_t, vbool32_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vadc_vxm)))
vuint32m2_t vadc_vxm_u32m2(vuint32m2_t, uint32_t, vbool16_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vadc_vxm)))
vuint32m4_t vadc_vxm_u32m4(vuint32m4_t, uint32_t, vbool8_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vadc_vxm)))
vuint32m8_t vadc_vxm_u32m8(vuint32m8_t, uint32_t, vbool4_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vadc_vxm)))
vuint32mf2_t vadc_vxm_u32mf2(vuint32mf2_t, uint32_t, vbool64_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vmadc_vvm)))
vbool8_t vmadc_vvm_i8m1_b8(vint8m1_t, vint8m1_t, vbool8_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vmadc_vvm)))
vbool4_t vmadc_vvm_i8m2_b4(vint8m2_t, vint8m2_t, vbool4_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vmadc_vvm)))
vbool2_t vmadc_vvm_i8m4_b2(vint8m4_t, vint8m4_t, vbool2_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vmadc_vvm)))
vbool1_t vmadc_vvm_i8m8_b1(vint8m8_t, vint8m8_t, vbool1_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vmadc_vvm)))
vbool16_t vmadc_vvm_i8mf2_b16(vint8mf2_t, vint8mf2_t, vbool16_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vmadc_vvm)))
vbool32_t vmadc_vvm_i8mf4_b32(vint8mf4_t, vint8mf4_t, vbool32_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vmadc_vvm)))
vbool64_t vmadc_vvm_i8mf8_b64(vint8mf8_t, vint8mf8_t, vbool64_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vmadc_vvm)))
vbool16_t vmadc_vvm_i16m1_b16(vint16m1_t, vint16m1_t, vbool16_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vmadc_vvm)))
vbool8_t vmadc_vvm_i16m2_b8(vint16m2_t, vint16m2_t, vbool8_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vmadc_vvm)))
vbool4_t vmadc_vvm_i16m4_b4(vint16m4_t, vint16m4_t, vbool4_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vmadc_vvm)))
vbool2_t vmadc_vvm_i16m8_b2(vint16m8_t, vint16m8_t, vbool2_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vmadc_vvm)))
vbool32_t vmadc_vvm_i16mf2_b32(vint16mf2_t, vint16mf2_t, vbool32_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vmadc_vvm)))
vbool64_t vmadc_vvm_i16mf4_b64(vint16mf4_t, vint16mf4_t, vbool64_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vmadc_vvm)))
vbool32_t vmadc_vvm_i32m1_b32(vint32m1_t, vint32m1_t, vbool32_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vmadc_vvm)))
vbool16_t vmadc_vvm_i32m2_b16(vint32m2_t, vint32m2_t, vbool16_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vmadc_vvm)))
vbool8_t vmadc_vvm_i32m4_b8(vint32m4_t, vint32m4_t, vbool8_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vmadc_vvm)))
vbool4_t vmadc_vvm_i32m8_b4(vint32m8_t, vint32m8_t, vbool4_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vmadc_vvm)))
vbool64_t vmadc_vvm_i32mf2_b64(vint32mf2_t, vint32mf2_t, vbool64_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vmadc_vxm)))
vbool8_t vmadc_vxm_i8m1_b8(vint8m1_t, int8_t, vbool8_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vmadc_vxm)))
vbool4_t vmadc_vxm_i8m2_b4(vint8m2_t, int8_t, vbool4_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vmadc_vxm)))
vbool2_t vmadc_vxm_i8m4_b2(vint8m4_t, int8_t, vbool2_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vmadc_vxm)))
vbool1_t vmadc_vxm_i8m8_b1(vint8m8_t, int8_t, vbool1_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vmadc_vxm)))
vbool16_t vmadc_vxm_i8mf2_b16(vint8mf2_t, int8_t, vbool16_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vmadc_vxm)))
vbool32_t vmadc_vxm_i8mf4_b32(vint8mf4_t, int8_t, vbool32_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vmadc_vxm)))
vbool64_t vmadc_vxm_i8mf8_b64(vint8mf8_t, int8_t, vbool64_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vmadc_vxm)))
vbool16_t vmadc_vxm_i16m1_b16(vint16m1_t, int16_t, vbool16_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vmadc_vxm)))
vbool8_t vmadc_vxm_i16m2_b8(vint16m2_t, int16_t, vbool8_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vmadc_vxm)))
vbool4_t vmadc_vxm_i16m4_b4(vint16m4_t, int16_t, vbool4_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vmadc_vxm)))
vbool2_t vmadc_vxm_i16m8_b2(vint16m8_t, int16_t, vbool2_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vmadc_vxm)))
vbool32_t vmadc_vxm_i16mf2_b32(vint16mf2_t, int16_t, vbool32_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vmadc_vxm)))
vbool64_t vmadc_vxm_i16mf4_b64(vint16mf4_t, int16_t, vbool64_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vmadc_vxm)))
vbool32_t vmadc_vxm_i32m1_b32(vint32m1_t, int32_t, vbool32_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vmadc_vxm)))
vbool16_t vmadc_vxm_i32m2_b16(vint32m2_t, int32_t, vbool16_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vmadc_vxm)))
vbool8_t vmadc_vxm_i32m4_b8(vint32m4_t, int32_t, vbool8_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vmadc_vxm)))
vbool4_t vmadc_vxm_i32m8_b4(vint32m8_t, int32_t, vbool4_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vmadc_vxm)))
vbool64_t vmadc_vxm_i32mf2_b64(vint32mf2_t, int32_t, vbool64_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vmadc_vvm)))
vbool8_t vmadc_vvm_u8m1_b8(vuint8m1_t, vuint8m1_t, vbool8_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vmadc_vvm)))
vbool4_t vmadc_vvm_u8m2_b4(vuint8m2_t, vuint8m2_t, vbool4_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vmadc_vvm)))
vbool2_t vmadc_vvm_u8m4_b2(vuint8m4_t, vuint8m4_t, vbool2_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vmadc_vvm)))
vbool1_t vmadc_vvm_u8m8_b1(vuint8m8_t, vuint8m8_t, vbool1_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vmadc_vvm)))
vbool16_t vmadc_vvm_u8mf2_b16(vuint8mf2_t, vuint8mf2_t, vbool16_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vmadc_vvm)))
vbool32_t vmadc_vvm_u8mf4_b32(vuint8mf4_t, vuint8mf4_t, vbool32_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vmadc_vvm)))
vbool64_t vmadc_vvm_u8mf8_b64(vuint8mf8_t, vuint8mf8_t, vbool64_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vmadc_vvm)))
vbool16_t vmadc_vvm_u16m1_b16(vuint16m1_t, vuint16m1_t, vbool16_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vmadc_vvm)))
vbool8_t vmadc_vvm_u16m2_b8(vuint16m2_t, vuint16m2_t, vbool8_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vmadc_vvm)))
vbool4_t vmadc_vvm_u16m4_b4(vuint16m4_t, vuint16m4_t, vbool4_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vmadc_vvm)))
vbool2_t vmadc_vvm_u16m8_b2(vuint16m8_t, vuint16m8_t, vbool2_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vmadc_vvm)))
vbool32_t vmadc_vvm_u16mf2_b32(vuint16mf2_t, vuint16mf2_t, vbool32_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vmadc_vvm)))
vbool64_t vmadc_vvm_u16mf4_b64(vuint16mf4_t, vuint16mf4_t, vbool64_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vmadc_vvm)))
vbool32_t vmadc_vvm_u32m1_b32(vuint32m1_t, vuint32m1_t, vbool32_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vmadc_vvm)))
vbool16_t vmadc_vvm_u32m2_b16(vuint32m2_t, vuint32m2_t, vbool16_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vmadc_vvm)))
vbool8_t vmadc_vvm_u32m4_b8(vuint32m4_t, vuint32m4_t, vbool8_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vmadc_vvm)))
vbool4_t vmadc_vvm_u32m8_b4(vuint32m8_t, vuint32m8_t, vbool4_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vmadc_vvm)))
vbool64_t vmadc_vvm_u32mf2_b64(vuint32mf2_t, vuint32mf2_t, vbool64_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vmadc_vxm)))
vbool8_t vmadc_vxm_u8m1_b8(vuint8m1_t, uint8_t, vbool8_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vmadc_vxm)))
vbool4_t vmadc_vxm_u8m2_b4(vuint8m2_t, uint8_t, vbool4_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vmadc_vxm)))
vbool2_t vmadc_vxm_u8m4_b2(vuint8m4_t, uint8_t, vbool2_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vmadc_vxm)))
vbool1_t vmadc_vxm_u8m8_b1(vuint8m8_t, uint8_t, vbool1_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vmadc_vxm)))
vbool16_t vmadc_vxm_u8mf2_b16(vuint8mf2_t, uint8_t, vbool16_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vmadc_vxm)))
vbool32_t vmadc_vxm_u8mf4_b32(vuint8mf4_t, uint8_t, vbool32_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vmadc_vxm)))
vbool64_t vmadc_vxm_u8mf8_b64(vuint8mf8_t, uint8_t, vbool64_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vmadc_vxm)))
vbool16_t vmadc_vxm_u16m1_b16(vuint16m1_t, uint16_t, vbool16_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vmadc_vxm)))
vbool8_t vmadc_vxm_u16m2_b8(vuint16m2_t, uint16_t, vbool8_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vmadc_vxm)))
vbool4_t vmadc_vxm_u16m4_b4(vuint16m4_t, uint16_t, vbool4_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vmadc_vxm)))
vbool2_t vmadc_vxm_u16m8_b2(vuint16m8_t, uint16_t, vbool2_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vmadc_vxm)))
vbool32_t vmadc_vxm_u16mf2_b32(vuint16mf2_t, uint16_t, vbool32_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vmadc_vxm)))
vbool64_t vmadc_vxm_u16mf4_b64(vuint16mf4_t, uint16_t, vbool64_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vmadc_vxm)))
vbool32_t vmadc_vxm_u32m1_b32(vuint32m1_t, uint32_t, vbool32_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vmadc_vxm)))
vbool16_t vmadc_vxm_u32m2_b16(vuint32m2_t, uint32_t, vbool16_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vmadc_vxm)))
vbool8_t vmadc_vxm_u32m4_b8(vuint32m4_t, uint32_t, vbool8_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vmadc_vxm)))
vbool4_t vmadc_vxm_u32m8_b4(vuint32m8_t, uint32_t, vbool4_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vmadc_vxm)))
vbool64_t vmadc_vxm_u32mf2_b64(vuint32mf2_t, uint32_t, vbool64_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vmadc_vv)))
vbool8_t vmadc_vv_i8m1_b8(vint8m1_t, vint8m1_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vmadc_vv)))
vbool4_t vmadc_vv_i8m2_b4(vint8m2_t, vint8m2_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vmadc_vv)))
vbool2_t vmadc_vv_i8m4_b2(vint8m4_t, vint8m4_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vmadc_vv)))
vbool1_t vmadc_vv_i8m8_b1(vint8m8_t, vint8m8_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vmadc_vv)))
vbool16_t vmadc_vv_i8mf2_b16(vint8mf2_t, vint8mf2_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vmadc_vv)))
vbool32_t vmadc_vv_i8mf4_b32(vint8mf4_t, vint8mf4_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vmadc_vv)))
vbool64_t vmadc_vv_i8mf8_b64(vint8mf8_t, vint8mf8_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vmadc_vv)))
vbool16_t vmadc_vv_i16m1_b16(vint16m1_t, vint16m1_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vmadc_vv)))
vbool8_t vmadc_vv_i16m2_b8(vint16m2_t, vint16m2_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vmadc_vv)))
vbool4_t vmadc_vv_i16m4_b4(vint16m4_t, vint16m4_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vmadc_vv)))
vbool2_t vmadc_vv_i16m8_b2(vint16m8_t, vint16m8_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vmadc_vv)))
vbool32_t vmadc_vv_i16mf2_b32(vint16mf2_t, vint16mf2_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vmadc_vv)))
vbool64_t vmadc_vv_i16mf4_b64(vint16mf4_t, vint16mf4_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vmadc_vv)))
vbool32_t vmadc_vv_i32m1_b32(vint32m1_t, vint32m1_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vmadc_vv)))
vbool16_t vmadc_vv_i32m2_b16(vint32m2_t, vint32m2_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vmadc_vv)))
vbool8_t vmadc_vv_i32m4_b8(vint32m4_t, vint32m4_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vmadc_vv)))
vbool4_t vmadc_vv_i32m8_b4(vint32m8_t, vint32m8_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vmadc_vv)))
vbool64_t vmadc_vv_i32mf2_b64(vint32mf2_t, vint32mf2_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vmadc_vx)))
vbool8_t vmadc_vx_i8m1_b8(vint8m1_t, int8_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vmadc_vx)))
vbool4_t vmadc_vx_i8m2_b4(vint8m2_t, int8_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vmadc_vx)))
vbool2_t vmadc_vx_i8m4_b2(vint8m4_t, int8_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vmadc_vx)))
vbool1_t vmadc_vx_i8m8_b1(vint8m8_t, int8_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vmadc_vx)))
vbool16_t vmadc_vx_i8mf2_b16(vint8mf2_t, int8_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vmadc_vx)))
vbool32_t vmadc_vx_i8mf4_b32(vint8mf4_t, int8_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vmadc_vx)))
vbool64_t vmadc_vx_i8mf8_b64(vint8mf8_t, int8_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vmadc_vx)))
vbool16_t vmadc_vx_i16m1_b16(vint16m1_t, int16_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vmadc_vx)))
vbool8_t vmadc_vx_i16m2_b8(vint16m2_t, int16_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vmadc_vx)))
vbool4_t vmadc_vx_i16m4_b4(vint16m4_t, int16_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vmadc_vx)))
vbool2_t vmadc_vx_i16m8_b2(vint16m8_t, int16_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vmadc_vx)))
vbool32_t vmadc_vx_i16mf2_b32(vint16mf2_t, int16_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vmadc_vx)))
vbool64_t vmadc_vx_i16mf4_b64(vint16mf4_t, int16_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vmadc_vx)))
vbool32_t vmadc_vx_i32m1_b32(vint32m1_t, int32_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vmadc_vx)))
vbool16_t vmadc_vx_i32m2_b16(vint32m2_t, int32_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vmadc_vx)))
vbool8_t vmadc_vx_i32m4_b8(vint32m4_t, int32_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vmadc_vx)))
vbool4_t vmadc_vx_i32m8_b4(vint32m8_t, int32_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vmadc_vx)))
vbool64_t vmadc_vx_i32mf2_b64(vint32mf2_t, int32_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vmadc_vv)))
vbool8_t vmadc_vv_u8m1_b8(vuint8m1_t, vuint8m1_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vmadc_vv)))
vbool4_t vmadc_vv_u8m2_b4(vuint8m2_t, vuint8m2_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vmadc_vv)))
vbool2_t vmadc_vv_u8m4_b2(vuint8m4_t, vuint8m4_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vmadc_vv)))
vbool1_t vmadc_vv_u8m8_b1(vuint8m8_t, vuint8m8_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vmadc_vv)))
vbool16_t vmadc_vv_u8mf2_b16(vuint8mf2_t, vuint8mf2_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vmadc_vv)))
vbool32_t vmadc_vv_u8mf4_b32(vuint8mf4_t, vuint8mf4_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vmadc_vv)))
vbool64_t vmadc_vv_u8mf8_b64(vuint8mf8_t, vuint8mf8_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vmadc_vv)))
vbool16_t vmadc_vv_u16m1_b16(vuint16m1_t, vuint16m1_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vmadc_vv)))
vbool8_t vmadc_vv_u16m2_b8(vuint16m2_t, vuint16m2_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vmadc_vv)))
vbool4_t vmadc_vv_u16m4_b4(vuint16m4_t, vuint16m4_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vmadc_vv)))
vbool2_t vmadc_vv_u16m8_b2(vuint16m8_t, vuint16m8_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vmadc_vv)))
vbool32_t vmadc_vv_u16mf2_b32(vuint16mf2_t, vuint16mf2_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vmadc_vv)))
vbool64_t vmadc_vv_u16mf4_b64(vuint16mf4_t, vuint16mf4_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vmadc_vv)))
vbool32_t vmadc_vv_u32m1_b32(vuint32m1_t, vuint32m1_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vmadc_vv)))
vbool16_t vmadc_vv_u32m2_b16(vuint32m2_t, vuint32m2_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vmadc_vv)))
vbool8_t vmadc_vv_u32m4_b8(vuint32m4_t, vuint32m4_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vmadc_vv)))
vbool4_t vmadc_vv_u32m8_b4(vuint32m8_t, vuint32m8_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vmadc_vv)))
vbool64_t vmadc_vv_u32mf2_b64(vuint32mf2_t, vuint32mf2_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vmadc_vx)))
vbool8_t vmadc_vx_u8m1_b8(vuint8m1_t, uint8_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vmadc_vx)))
vbool4_t vmadc_vx_u8m2_b4(vuint8m2_t, uint8_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vmadc_vx)))
vbool2_t vmadc_vx_u8m4_b2(vuint8m4_t, uint8_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vmadc_vx)))
vbool1_t vmadc_vx_u8m8_b1(vuint8m8_t, uint8_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vmadc_vx)))
vbool16_t vmadc_vx_u8mf2_b16(vuint8mf2_t, uint8_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vmadc_vx)))
vbool32_t vmadc_vx_u8mf4_b32(vuint8mf4_t, uint8_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vmadc_vx)))
vbool64_t vmadc_vx_u8mf8_b64(vuint8mf8_t, uint8_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vmadc_vx)))
vbool16_t vmadc_vx_u16m1_b16(vuint16m1_t, uint16_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vmadc_vx)))
vbool8_t vmadc_vx_u16m2_b8(vuint16m2_t, uint16_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vmadc_vx)))
vbool4_t vmadc_vx_u16m4_b4(vuint16m4_t, uint16_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vmadc_vx)))
vbool2_t vmadc_vx_u16m8_b2(vuint16m8_t, uint16_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vmadc_vx)))
vbool32_t vmadc_vx_u16mf2_b32(vuint16mf2_t, uint16_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vmadc_vx)))
vbool64_t vmadc_vx_u16mf4_b64(vuint16mf4_t, uint16_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vmadc_vx)))
vbool32_t vmadc_vx_u32m1_b32(vuint32m1_t, uint32_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vmadc_vx)))
vbool16_t vmadc_vx_u32m2_b16(vuint32m2_t, uint32_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vmadc_vx)))
vbool8_t vmadc_vx_u32m4_b8(vuint32m4_t, uint32_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vmadc_vx)))
vbool4_t vmadc_vx_u32m8_b4(vuint32m8_t, uint32_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vmadc_vx)))
vbool64_t vmadc_vx_u32mf2_b64(vuint32mf2_t, uint32_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vsbc_vvm)))
vint8m1_t vsbc_vvm_i8m1(vint8m1_t, vint8m1_t, vbool8_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vsbc_vvm)))
vint8m2_t vsbc_vvm_i8m2(vint8m2_t, vint8m2_t, vbool4_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vsbc_vvm)))
vint8m4_t vsbc_vvm_i8m4(vint8m4_t, vint8m4_t, vbool2_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vsbc_vvm)))
vint8m8_t vsbc_vvm_i8m8(vint8m8_t, vint8m8_t, vbool1_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vsbc_vvm)))
vint8mf2_t vsbc_vvm_i8mf2(vint8mf2_t, vint8mf2_t, vbool16_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vsbc_vvm)))
vint8mf4_t vsbc_vvm_i8mf4(vint8mf4_t, vint8mf4_t, vbool32_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vsbc_vvm)))
vint8mf8_t vsbc_vvm_i8mf8(vint8mf8_t, vint8mf8_t, vbool64_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vsbc_vvm)))
vint16m1_t vsbc_vvm_i16m1(vint16m1_t, vint16m1_t, vbool16_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vsbc_vvm)))
vint16m2_t vsbc_vvm_i16m2(vint16m2_t, vint16m2_t, vbool8_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vsbc_vvm)))
vint16m4_t vsbc_vvm_i16m4(vint16m4_t, vint16m4_t, vbool4_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vsbc_vvm)))
vint16m8_t vsbc_vvm_i16m8(vint16m8_t, vint16m8_t, vbool2_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vsbc_vvm)))
vint16mf2_t vsbc_vvm_i16mf2(vint16mf2_t, vint16mf2_t, vbool32_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vsbc_vvm)))
vint16mf4_t vsbc_vvm_i16mf4(vint16mf4_t, vint16mf4_t, vbool64_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vsbc_vvm)))
vint32m1_t vsbc_vvm_i32m1(vint32m1_t, vint32m1_t, vbool32_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vsbc_vvm)))
vint32m2_t vsbc_vvm_i32m2(vint32m2_t, vint32m2_t, vbool16_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vsbc_vvm)))
vint32m4_t vsbc_vvm_i32m4(vint32m4_t, vint32m4_t, vbool8_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vsbc_vvm)))
vint32m8_t vsbc_vvm_i32m8(vint32m8_t, vint32m8_t, vbool4_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vsbc_vvm)))
vint32mf2_t vsbc_vvm_i32mf2(vint32mf2_t, vint32mf2_t, vbool64_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vsbc_vxm)))
vint8m1_t vsbc_vxm_i8m1(vint8m1_t, int8_t, vbool8_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vsbc_vxm)))
vint8m2_t vsbc_vxm_i8m2(vint8m2_t, int8_t, vbool4_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vsbc_vxm)))
vint8m4_t vsbc_vxm_i8m4(vint8m4_t, int8_t, vbool2_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vsbc_vxm)))
vint8m8_t vsbc_vxm_i8m8(vint8m8_t, int8_t, vbool1_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vsbc_vxm)))
vint8mf2_t vsbc_vxm_i8mf2(vint8mf2_t, int8_t, vbool16_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vsbc_vxm)))
vint8mf4_t vsbc_vxm_i8mf4(vint8mf4_t, int8_t, vbool32_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vsbc_vxm)))
vint8mf8_t vsbc_vxm_i8mf8(vint8mf8_t, int8_t, vbool64_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vsbc_vxm)))
vint16m1_t vsbc_vxm_i16m1(vint16m1_t, int16_t, vbool16_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vsbc_vxm)))
vint16m2_t vsbc_vxm_i16m2(vint16m2_t, int16_t, vbool8_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vsbc_vxm)))
vint16m4_t vsbc_vxm_i16m4(vint16m4_t, int16_t, vbool4_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vsbc_vxm)))
vint16m8_t vsbc_vxm_i16m8(vint16m8_t, int16_t, vbool2_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vsbc_vxm)))
vint16mf2_t vsbc_vxm_i16mf2(vint16mf2_t, int16_t, vbool32_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vsbc_vxm)))
vint16mf4_t vsbc_vxm_i16mf4(vint16mf4_t, int16_t, vbool64_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vsbc_vxm)))
vint32m1_t vsbc_vxm_i32m1(vint32m1_t, int32_t, vbool32_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vsbc_vxm)))
vint32m2_t vsbc_vxm_i32m2(vint32m2_t, int32_t, vbool16_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vsbc_vxm)))
vint32m4_t vsbc_vxm_i32m4(vint32m4_t, int32_t, vbool8_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vsbc_vxm)))
vint32m8_t vsbc_vxm_i32m8(vint32m8_t, int32_t, vbool4_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vsbc_vxm)))
vint32mf2_t vsbc_vxm_i32mf2(vint32mf2_t, int32_t, vbool64_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vsbc_vvm)))
vuint8m1_t vsbc_vvm_u8m1(vuint8m1_t, vuint8m1_t, vbool8_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vsbc_vvm)))
vuint8m2_t vsbc_vvm_u8m2(vuint8m2_t, vuint8m2_t, vbool4_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vsbc_vvm)))
vuint8m4_t vsbc_vvm_u8m4(vuint8m4_t, vuint8m4_t, vbool2_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vsbc_vvm)))
vuint8m8_t vsbc_vvm_u8m8(vuint8m8_t, vuint8m8_t, vbool1_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vsbc_vvm)))
vuint8mf2_t vsbc_vvm_u8mf2(vuint8mf2_t, vuint8mf2_t, vbool16_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vsbc_vvm)))
vuint8mf4_t vsbc_vvm_u8mf4(vuint8mf4_t, vuint8mf4_t, vbool32_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vsbc_vvm)))
vuint8mf8_t vsbc_vvm_u8mf8(vuint8mf8_t, vuint8mf8_t, vbool64_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vsbc_vvm)))
vuint16m1_t vsbc_vvm_u16m1(vuint16m1_t, vuint16m1_t, vbool16_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vsbc_vvm)))
vuint16m2_t vsbc_vvm_u16m2(vuint16m2_t, vuint16m2_t, vbool8_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vsbc_vvm)))
vuint16m4_t vsbc_vvm_u16m4(vuint16m4_t, vuint16m4_t, vbool4_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vsbc_vvm)))
vuint16m8_t vsbc_vvm_u16m8(vuint16m8_t, vuint16m8_t, vbool2_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vsbc_vvm)))
vuint16mf2_t vsbc_vvm_u16mf2(vuint16mf2_t, vuint16mf2_t, vbool32_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vsbc_vvm)))
vuint16mf4_t vsbc_vvm_u16mf4(vuint16mf4_t, vuint16mf4_t, vbool64_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vsbc_vvm)))
vuint32m1_t vsbc_vvm_u32m1(vuint32m1_t, vuint32m1_t, vbool32_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vsbc_vvm)))
vuint32m2_t vsbc_vvm_u32m2(vuint32m2_t, vuint32m2_t, vbool16_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vsbc_vvm)))
vuint32m4_t vsbc_vvm_u32m4(vuint32m4_t, vuint32m4_t, vbool8_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vsbc_vvm)))
vuint32m8_t vsbc_vvm_u32m8(vuint32m8_t, vuint32m8_t, vbool4_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vsbc_vvm)))
vuint32mf2_t vsbc_vvm_u32mf2(vuint32mf2_t, vuint32mf2_t, vbool64_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vsbc_vxm)))
vuint8m1_t vsbc_vxm_u8m1(vuint8m1_t, uint8_t, vbool8_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vsbc_vxm)))
vuint8m2_t vsbc_vxm_u8m2(vuint8m2_t, uint8_t, vbool4_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vsbc_vxm)))
vuint8m4_t vsbc_vxm_u8m4(vuint8m4_t, uint8_t, vbool2_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vsbc_vxm)))
vuint8m8_t vsbc_vxm_u8m8(vuint8m8_t, uint8_t, vbool1_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vsbc_vxm)))
vuint8mf2_t vsbc_vxm_u8mf2(vuint8mf2_t, uint8_t, vbool16_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vsbc_vxm)))
vuint8mf4_t vsbc_vxm_u8mf4(vuint8mf4_t, uint8_t, vbool32_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vsbc_vxm)))
vuint8mf8_t vsbc_vxm_u8mf8(vuint8mf8_t, uint8_t, vbool64_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vsbc_vxm)))
vuint16m1_t vsbc_vxm_u16m1(vuint16m1_t, uint16_t, vbool16_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vsbc_vxm)))
vuint16m2_t vsbc_vxm_u16m2(vuint16m2_t, uint16_t, vbool8_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vsbc_vxm)))
vuint16m4_t vsbc_vxm_u16m4(vuint16m4_t, uint16_t, vbool4_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vsbc_vxm)))
vuint16m8_t vsbc_vxm_u16m8(vuint16m8_t, uint16_t, vbool2_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vsbc_vxm)))
vuint16mf2_t vsbc_vxm_u16mf2(vuint16mf2_t, uint16_t, vbool32_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vsbc_vxm)))
vuint16mf4_t vsbc_vxm_u16mf4(vuint16mf4_t, uint16_t, vbool64_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vsbc_vxm)))
vuint32m1_t vsbc_vxm_u32m1(vuint32m1_t, uint32_t, vbool32_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vsbc_vxm)))
vuint32m2_t vsbc_vxm_u32m2(vuint32m2_t, uint32_t, vbool16_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vsbc_vxm)))
vuint32m4_t vsbc_vxm_u32m4(vuint32m4_t, uint32_t, vbool8_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vsbc_vxm)))
vuint32m8_t vsbc_vxm_u32m8(vuint32m8_t, uint32_t, vbool4_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vsbc_vxm)))
vuint32mf2_t vsbc_vxm_u32mf2(vuint32mf2_t, uint32_t, vbool64_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vmsbc_vvm)))
vbool8_t vmsbc_vvm_i8m1_b8(vint8m1_t, vint8m1_t, vbool8_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vmsbc_vvm)))
vbool4_t vmsbc_vvm_i8m2_b4(vint8m2_t, vint8m2_t, vbool4_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vmsbc_vvm)))
vbool2_t vmsbc_vvm_i8m4_b2(vint8m4_t, vint8m4_t, vbool2_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vmsbc_vvm)))
vbool1_t vmsbc_vvm_i8m8_b1(vint8m8_t, vint8m8_t, vbool1_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vmsbc_vvm)))
vbool16_t vmsbc_vvm_i8mf2_b16(vint8mf2_t, vint8mf2_t, vbool16_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vmsbc_vvm)))
vbool32_t vmsbc_vvm_i8mf4_b32(vint8mf4_t, vint8mf4_t, vbool32_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vmsbc_vvm)))
vbool64_t vmsbc_vvm_i8mf8_b64(vint8mf8_t, vint8mf8_t, vbool64_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vmsbc_vvm)))
vbool16_t vmsbc_vvm_i16m1_b16(vint16m1_t, vint16m1_t, vbool16_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vmsbc_vvm)))
vbool8_t vmsbc_vvm_i16m2_b8(vint16m2_t, vint16m2_t, vbool8_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vmsbc_vvm)))
vbool4_t vmsbc_vvm_i16m4_b4(vint16m4_t, vint16m4_t, vbool4_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vmsbc_vvm)))
vbool2_t vmsbc_vvm_i16m8_b2(vint16m8_t, vint16m8_t, vbool2_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vmsbc_vvm)))
vbool32_t vmsbc_vvm_i16mf2_b32(vint16mf2_t, vint16mf2_t, vbool32_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vmsbc_vvm)))
vbool64_t vmsbc_vvm_i16mf4_b64(vint16mf4_t, vint16mf4_t, vbool64_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vmsbc_vvm)))
vbool32_t vmsbc_vvm_i32m1_b32(vint32m1_t, vint32m1_t, vbool32_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vmsbc_vvm)))
vbool16_t vmsbc_vvm_i32m2_b16(vint32m2_t, vint32m2_t, vbool16_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vmsbc_vvm)))
vbool8_t vmsbc_vvm_i32m4_b8(vint32m4_t, vint32m4_t, vbool8_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vmsbc_vvm)))
vbool4_t vmsbc_vvm_i32m8_b4(vint32m8_t, vint32m8_t, vbool4_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vmsbc_vvm)))
vbool64_t vmsbc_vvm_i32mf2_b64(vint32mf2_t, vint32mf2_t, vbool64_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vmsbc_vxm)))
vbool8_t vmsbc_vxm_i8m1_b8(vint8m1_t, int8_t, vbool8_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vmsbc_vxm)))
vbool4_t vmsbc_vxm_i8m2_b4(vint8m2_t, int8_t, vbool4_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vmsbc_vxm)))
vbool2_t vmsbc_vxm_i8m4_b2(vint8m4_t, int8_t, vbool2_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vmsbc_vxm)))
vbool1_t vmsbc_vxm_i8m8_b1(vint8m8_t, int8_t, vbool1_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vmsbc_vxm)))
vbool16_t vmsbc_vxm_i8mf2_b16(vint8mf2_t, int8_t, vbool16_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vmsbc_vxm)))
vbool32_t vmsbc_vxm_i8mf4_b32(vint8mf4_t, int8_t, vbool32_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vmsbc_vxm)))
vbool64_t vmsbc_vxm_i8mf8_b64(vint8mf8_t, int8_t, vbool64_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vmsbc_vxm)))
vbool16_t vmsbc_vxm_i16m1_b16(vint16m1_t, int16_t, vbool16_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vmsbc_vxm)))
vbool8_t vmsbc_vxm_i16m2_b8(vint16m2_t, int16_t, vbool8_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vmsbc_vxm)))
vbool4_t vmsbc_vxm_i16m4_b4(vint16m4_t, int16_t, vbool4_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vmsbc_vxm)))
vbool2_t vmsbc_vxm_i16m8_b2(vint16m8_t, int16_t, vbool2_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vmsbc_vxm)))
vbool32_t vmsbc_vxm_i16mf2_b32(vint16mf2_t, int16_t, vbool32_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vmsbc_vxm)))
vbool64_t vmsbc_vxm_i16mf4_b64(vint16mf4_t, int16_t, vbool64_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vmsbc_vxm)))
vbool32_t vmsbc_vxm_i32m1_b32(vint32m1_t, int32_t, vbool32_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vmsbc_vxm)))
vbool16_t vmsbc_vxm_i32m2_b16(vint32m2_t, int32_t, vbool16_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vmsbc_vxm)))
vbool8_t vmsbc_vxm_i32m4_b8(vint32m4_t, int32_t, vbool8_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vmsbc_vxm)))
vbool4_t vmsbc_vxm_i32m8_b4(vint32m8_t, int32_t, vbool4_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vmsbc_vxm)))
vbool64_t vmsbc_vxm_i32mf2_b64(vint32mf2_t, int32_t, vbool64_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vmsbc_vvm)))
vbool8_t vmsbc_vvm_u8m1_b8(vuint8m1_t, vuint8m1_t, vbool8_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vmsbc_vvm)))
vbool4_t vmsbc_vvm_u8m2_b4(vuint8m2_t, vuint8m2_t, vbool4_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vmsbc_vvm)))
vbool2_t vmsbc_vvm_u8m4_b2(vuint8m4_t, vuint8m4_t, vbool2_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vmsbc_vvm)))
vbool1_t vmsbc_vvm_u8m8_b1(vuint8m8_t, vuint8m8_t, vbool1_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vmsbc_vvm)))
vbool16_t vmsbc_vvm_u8mf2_b16(vuint8mf2_t, vuint8mf2_t, vbool16_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vmsbc_vvm)))
vbool32_t vmsbc_vvm_u8mf4_b32(vuint8mf4_t, vuint8mf4_t, vbool32_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vmsbc_vvm)))
vbool64_t vmsbc_vvm_u8mf8_b64(vuint8mf8_t, vuint8mf8_t, vbool64_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vmsbc_vvm)))
vbool16_t vmsbc_vvm_u16m1_b16(vuint16m1_t, vuint16m1_t, vbool16_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vmsbc_vvm)))
vbool8_t vmsbc_vvm_u16m2_b8(vuint16m2_t, vuint16m2_t, vbool8_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vmsbc_vvm)))
vbool4_t vmsbc_vvm_u16m4_b4(vuint16m4_t, vuint16m4_t, vbool4_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vmsbc_vvm)))
vbool2_t vmsbc_vvm_u16m8_b2(vuint16m8_t, vuint16m8_t, vbool2_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vmsbc_vvm)))
vbool32_t vmsbc_vvm_u16mf2_b32(vuint16mf2_t, vuint16mf2_t, vbool32_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vmsbc_vvm)))
vbool64_t vmsbc_vvm_u16mf4_b64(vuint16mf4_t, vuint16mf4_t, vbool64_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vmsbc_vvm)))
vbool32_t vmsbc_vvm_u32m1_b32(vuint32m1_t, vuint32m1_t, vbool32_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vmsbc_vvm)))
vbool16_t vmsbc_vvm_u32m2_b16(vuint32m2_t, vuint32m2_t, vbool16_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vmsbc_vvm)))
vbool8_t vmsbc_vvm_u32m4_b8(vuint32m4_t, vuint32m4_t, vbool8_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vmsbc_vvm)))
vbool4_t vmsbc_vvm_u32m8_b4(vuint32m8_t, vuint32m8_t, vbool4_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vmsbc_vvm)))
vbool64_t vmsbc_vvm_u32mf2_b64(vuint32mf2_t, vuint32mf2_t, vbool64_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vmsbc_vxm)))
vbool8_t vmsbc_vxm_u8m1_b8(vuint8m1_t, uint8_t, vbool8_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vmsbc_vxm)))
vbool4_t vmsbc_vxm_u8m2_b4(vuint8m2_t, uint8_t, vbool4_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vmsbc_vxm)))
vbool2_t vmsbc_vxm_u8m4_b2(vuint8m4_t, uint8_t, vbool2_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vmsbc_vxm)))
vbool1_t vmsbc_vxm_u8m8_b1(vuint8m8_t, uint8_t, vbool1_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vmsbc_vxm)))
vbool16_t vmsbc_vxm_u8mf2_b16(vuint8mf2_t, uint8_t, vbool16_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vmsbc_vxm)))
vbool32_t vmsbc_vxm_u8mf4_b32(vuint8mf4_t, uint8_t, vbool32_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vmsbc_vxm)))
vbool64_t vmsbc_vxm_u8mf8_b64(vuint8mf8_t, uint8_t, vbool64_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vmsbc_vxm)))
vbool16_t vmsbc_vxm_u16m1_b16(vuint16m1_t, uint16_t, vbool16_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vmsbc_vxm)))
vbool8_t vmsbc_vxm_u16m2_b8(vuint16m2_t, uint16_t, vbool8_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vmsbc_vxm)))
vbool4_t vmsbc_vxm_u16m4_b4(vuint16m4_t, uint16_t, vbool4_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vmsbc_vxm)))
vbool2_t vmsbc_vxm_u16m8_b2(vuint16m8_t, uint16_t, vbool2_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vmsbc_vxm)))
vbool32_t vmsbc_vxm_u16mf2_b32(vuint16mf2_t, uint16_t, vbool32_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vmsbc_vxm)))
vbool64_t vmsbc_vxm_u16mf4_b64(vuint16mf4_t, uint16_t, vbool64_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vmsbc_vxm)))
vbool32_t vmsbc_vxm_u32m1_b32(vuint32m1_t, uint32_t, vbool32_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vmsbc_vxm)))
vbool16_t vmsbc_vxm_u32m2_b16(vuint32m2_t, uint32_t, vbool16_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vmsbc_vxm)))
vbool8_t vmsbc_vxm_u32m4_b8(vuint32m4_t, uint32_t, vbool8_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vmsbc_vxm)))
vbool4_t vmsbc_vxm_u32m8_b4(vuint32m8_t, uint32_t, vbool4_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vmsbc_vxm)))
vbool64_t vmsbc_vxm_u32mf2_b64(vuint32mf2_t, uint32_t, vbool64_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vmsbc_vv)))
vbool8_t vmsbc_vv_i8m1_b8(vint8m1_t, vint8m1_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vmsbc_vv)))
vbool4_t vmsbc_vv_i8m2_b4(vint8m2_t, vint8m2_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vmsbc_vv)))
vbool2_t vmsbc_vv_i8m4_b2(vint8m4_t, vint8m4_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vmsbc_vv)))
vbool1_t vmsbc_vv_i8m8_b1(vint8m8_t, vint8m8_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vmsbc_vv)))
vbool16_t vmsbc_vv_i8mf2_b16(vint8mf2_t, vint8mf2_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vmsbc_vv)))
vbool32_t vmsbc_vv_i8mf4_b32(vint8mf4_t, vint8mf4_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vmsbc_vv)))
vbool64_t vmsbc_vv_i8mf8_b64(vint8mf8_t, vint8mf8_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vmsbc_vv)))
vbool16_t vmsbc_vv_i16m1_b16(vint16m1_t, vint16m1_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vmsbc_vv)))
vbool8_t vmsbc_vv_i16m2_b8(vint16m2_t, vint16m2_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vmsbc_vv)))
vbool4_t vmsbc_vv_i16m4_b4(vint16m4_t, vint16m4_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vmsbc_vv)))
vbool2_t vmsbc_vv_i16m8_b2(vint16m8_t, vint16m8_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vmsbc_vv)))
vbool32_t vmsbc_vv_i16mf2_b32(vint16mf2_t, vint16mf2_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vmsbc_vv)))
vbool64_t vmsbc_vv_i16mf4_b64(vint16mf4_t, vint16mf4_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vmsbc_vv)))
vbool32_t vmsbc_vv_i32m1_b32(vint32m1_t, vint32m1_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vmsbc_vv)))
vbool16_t vmsbc_vv_i32m2_b16(vint32m2_t, vint32m2_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vmsbc_vv)))
vbool8_t vmsbc_vv_i32m4_b8(vint32m4_t, vint32m4_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vmsbc_vv)))
vbool4_t vmsbc_vv_i32m8_b4(vint32m8_t, vint32m8_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vmsbc_vv)))
vbool64_t vmsbc_vv_i32mf2_b64(vint32mf2_t, vint32mf2_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vmsbc_vx)))
vbool8_t vmsbc_vx_i8m1_b8(vint8m1_t, int8_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vmsbc_vx)))
vbool4_t vmsbc_vx_i8m2_b4(vint8m2_t, int8_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vmsbc_vx)))
vbool2_t vmsbc_vx_i8m4_b2(vint8m4_t, int8_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vmsbc_vx)))
vbool1_t vmsbc_vx_i8m8_b1(vint8m8_t, int8_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vmsbc_vx)))
vbool16_t vmsbc_vx_i8mf2_b16(vint8mf2_t, int8_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vmsbc_vx)))
vbool32_t vmsbc_vx_i8mf4_b32(vint8mf4_t, int8_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vmsbc_vx)))
vbool64_t vmsbc_vx_i8mf8_b64(vint8mf8_t, int8_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vmsbc_vx)))
vbool16_t vmsbc_vx_i16m1_b16(vint16m1_t, int16_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vmsbc_vx)))
vbool8_t vmsbc_vx_i16m2_b8(vint16m2_t, int16_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vmsbc_vx)))
vbool4_t vmsbc_vx_i16m4_b4(vint16m4_t, int16_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vmsbc_vx)))
vbool2_t vmsbc_vx_i16m8_b2(vint16m8_t, int16_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vmsbc_vx)))
vbool32_t vmsbc_vx_i16mf2_b32(vint16mf2_t, int16_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vmsbc_vx)))
vbool64_t vmsbc_vx_i16mf4_b64(vint16mf4_t, int16_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vmsbc_vx)))
vbool32_t vmsbc_vx_i32m1_b32(vint32m1_t, int32_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vmsbc_vx)))
vbool16_t vmsbc_vx_i32m2_b16(vint32m2_t, int32_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vmsbc_vx)))
vbool8_t vmsbc_vx_i32m4_b8(vint32m4_t, int32_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vmsbc_vx)))
vbool4_t vmsbc_vx_i32m8_b4(vint32m8_t, int32_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vmsbc_vx)))
vbool64_t vmsbc_vx_i32mf2_b64(vint32mf2_t, int32_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vmsbc_vv)))
vbool8_t vmsbc_vv_u8m1_b8(vuint8m1_t, vuint8m1_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vmsbc_vv)))
vbool4_t vmsbc_vv_u8m2_b4(vuint8m2_t, vuint8m2_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vmsbc_vv)))
vbool2_t vmsbc_vv_u8m4_b2(vuint8m4_t, vuint8m4_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vmsbc_vv)))
vbool1_t vmsbc_vv_u8m8_b1(vuint8m8_t, vuint8m8_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vmsbc_vv)))
vbool16_t vmsbc_vv_u8mf2_b16(vuint8mf2_t, vuint8mf2_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vmsbc_vv)))
vbool32_t vmsbc_vv_u8mf4_b32(vuint8mf4_t, vuint8mf4_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vmsbc_vv)))
vbool64_t vmsbc_vv_u8mf8_b64(vuint8mf8_t, vuint8mf8_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vmsbc_vv)))
vbool16_t vmsbc_vv_u16m1_b16(vuint16m1_t, vuint16m1_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vmsbc_vv)))
vbool8_t vmsbc_vv_u16m2_b8(vuint16m2_t, vuint16m2_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vmsbc_vv)))
vbool4_t vmsbc_vv_u16m4_b4(vuint16m4_t, vuint16m4_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vmsbc_vv)))
vbool2_t vmsbc_vv_u16m8_b2(vuint16m8_t, vuint16m8_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vmsbc_vv)))
vbool32_t vmsbc_vv_u16mf2_b32(vuint16mf2_t, vuint16mf2_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vmsbc_vv)))
vbool64_t vmsbc_vv_u16mf4_b64(vuint16mf4_t, vuint16mf4_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vmsbc_vv)))
vbool32_t vmsbc_vv_u32m1_b32(vuint32m1_t, vuint32m1_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vmsbc_vv)))
vbool16_t vmsbc_vv_u32m2_b16(vuint32m2_t, vuint32m2_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vmsbc_vv)))
vbool8_t vmsbc_vv_u32m4_b8(vuint32m4_t, vuint32m4_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vmsbc_vv)))
vbool4_t vmsbc_vv_u32m8_b4(vuint32m8_t, vuint32m8_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vmsbc_vv)))
vbool64_t vmsbc_vv_u32mf2_b64(vuint32mf2_t, vuint32mf2_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vmsbc_vx)))
vbool8_t vmsbc_vx_u8m1_b8(vuint8m1_t, uint8_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vmsbc_vx)))
vbool4_t vmsbc_vx_u8m2_b4(vuint8m2_t, uint8_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vmsbc_vx)))
vbool2_t vmsbc_vx_u8m4_b2(vuint8m4_t, uint8_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vmsbc_vx)))
vbool1_t vmsbc_vx_u8m8_b1(vuint8m8_t, uint8_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vmsbc_vx)))
vbool16_t vmsbc_vx_u8mf2_b16(vuint8mf2_t, uint8_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vmsbc_vx)))
vbool32_t vmsbc_vx_u8mf4_b32(vuint8mf4_t, uint8_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vmsbc_vx)))
vbool64_t vmsbc_vx_u8mf8_b64(vuint8mf8_t, uint8_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vmsbc_vx)))
vbool16_t vmsbc_vx_u16m1_b16(vuint16m1_t, uint16_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vmsbc_vx)))
vbool8_t vmsbc_vx_u16m2_b8(vuint16m2_t, uint16_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vmsbc_vx)))
vbool4_t vmsbc_vx_u16m4_b4(vuint16m4_t, uint16_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vmsbc_vx)))
vbool2_t vmsbc_vx_u16m8_b2(vuint16m8_t, uint16_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vmsbc_vx)))
vbool32_t vmsbc_vx_u16mf2_b32(vuint16mf2_t, uint16_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vmsbc_vx)))
vbool64_t vmsbc_vx_u16mf4_b64(vuint16mf4_t, uint16_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vmsbc_vx)))
vbool32_t vmsbc_vx_u32m1_b32(vuint32m1_t, uint32_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vmsbc_vx)))
vbool16_t vmsbc_vx_u32m2_b16(vuint32m2_t, uint32_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vmsbc_vx)))
vbool8_t vmsbc_vx_u32m4_b8(vuint32m4_t, uint32_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vmsbc_vx)))
vbool4_t vmsbc_vx_u32m8_b4(vuint32m8_t, uint32_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vmsbc_vx)))
vbool64_t vmsbc_vx_u32mf2_b64(vuint32mf2_t, uint32_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vand_vv)))
vint8m1_t vand_vv_i8m1(vint8m1_t, vint8m1_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vand_vv_m)))
vint8m1_t vand_vv_i8m1_m(vbool8_t, vint8m1_t, vint8m1_t, vint8m1_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vand_vv)))
vint8m2_t vand_vv_i8m2(vint8m2_t, vint8m2_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vand_vv_m)))
vint8m2_t vand_vv_i8m2_m(vbool4_t, vint8m2_t, vint8m2_t, vint8m2_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vand_vv)))
vint8m4_t vand_vv_i8m4(vint8m4_t, vint8m4_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vand_vv_m)))
vint8m4_t vand_vv_i8m4_m(vbool2_t, vint8m4_t, vint8m4_t, vint8m4_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vand_vv)))
vint8m8_t vand_vv_i8m8(vint8m8_t, vint8m8_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vand_vv_m)))
vint8m8_t vand_vv_i8m8_m(vbool1_t, vint8m8_t, vint8m8_t, vint8m8_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vand_vv)))
vint8mf2_t vand_vv_i8mf2(vint8mf2_t, vint8mf2_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vand_vv_m)))
vint8mf2_t vand_vv_i8mf2_m(vbool16_t, vint8mf2_t, vint8mf2_t, vint8mf2_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vand_vv)))
vint8mf4_t vand_vv_i8mf4(vint8mf4_t, vint8mf4_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vand_vv_m)))
vint8mf4_t vand_vv_i8mf4_m(vbool32_t, vint8mf4_t, vint8mf4_t, vint8mf4_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vand_vv)))
vint8mf8_t vand_vv_i8mf8(vint8mf8_t, vint8mf8_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vand_vv_m)))
vint8mf8_t vand_vv_i8mf8_m(vbool64_t, vint8mf8_t, vint8mf8_t, vint8mf8_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vand_vv)))
vint16m1_t vand_vv_i16m1(vint16m1_t, vint16m1_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vand_vv_m)))
vint16m1_t vand_vv_i16m1_m(vbool16_t, vint16m1_t, vint16m1_t, vint16m1_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vand_vv)))
vint16m2_t vand_vv_i16m2(vint16m2_t, vint16m2_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vand_vv_m)))
vint16m2_t vand_vv_i16m2_m(vbool8_t, vint16m2_t, vint16m2_t, vint16m2_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vand_vv)))
vint16m4_t vand_vv_i16m4(vint16m4_t, vint16m4_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vand_vv_m)))
vint16m4_t vand_vv_i16m4_m(vbool4_t, vint16m4_t, vint16m4_t, vint16m4_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vand_vv)))
vint16m8_t vand_vv_i16m8(vint16m8_t, vint16m8_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vand_vv_m)))
vint16m8_t vand_vv_i16m8_m(vbool2_t, vint16m8_t, vint16m8_t, vint16m8_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vand_vv)))
vint16mf2_t vand_vv_i16mf2(vint16mf2_t, vint16mf2_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vand_vv_m)))
vint16mf2_t vand_vv_i16mf2_m(vbool32_t, vint16mf2_t, vint16mf2_t, vint16mf2_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vand_vv)))
vint16mf4_t vand_vv_i16mf4(vint16mf4_t, vint16mf4_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vand_vv_m)))
vint16mf4_t vand_vv_i16mf4_m(vbool64_t, vint16mf4_t, vint16mf4_t, vint16mf4_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vand_vv)))
vint32m1_t vand_vv_i32m1(vint32m1_t, vint32m1_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vand_vv_m)))
vint32m1_t vand_vv_i32m1_m(vbool32_t, vint32m1_t, vint32m1_t, vint32m1_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vand_vv)))
vint32m2_t vand_vv_i32m2(vint32m2_t, vint32m2_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vand_vv_m)))
vint32m2_t vand_vv_i32m2_m(vbool16_t, vint32m2_t, vint32m2_t, vint32m2_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vand_vv)))
vint32m4_t vand_vv_i32m4(vint32m4_t, vint32m4_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vand_vv_m)))
vint32m4_t vand_vv_i32m4_m(vbool8_t, vint32m4_t, vint32m4_t, vint32m4_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vand_vv)))
vint32m8_t vand_vv_i32m8(vint32m8_t, vint32m8_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vand_vv_m)))
vint32m8_t vand_vv_i32m8_m(vbool4_t, vint32m8_t, vint32m8_t, vint32m8_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vand_vv)))
vint32mf2_t vand_vv_i32mf2(vint32mf2_t, vint32mf2_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vand_vv_m)))
vint32mf2_t vand_vv_i32mf2_m(vbool64_t, vint32mf2_t, vint32mf2_t, vint32mf2_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vand_vx)))
vint8m1_t vand_vx_i8m1(vint8m1_t, int8_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vand_vx_m)))
vint8m1_t vand_vx_i8m1_m(vbool8_t, vint8m1_t, vint8m1_t, int8_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vand_vx)))
vint8m2_t vand_vx_i8m2(vint8m2_t, int8_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vand_vx_m)))
vint8m2_t vand_vx_i8m2_m(vbool4_t, vint8m2_t, vint8m2_t, int8_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vand_vx)))
vint8m4_t vand_vx_i8m4(vint8m4_t, int8_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vand_vx_m)))
vint8m4_t vand_vx_i8m4_m(vbool2_t, vint8m4_t, vint8m4_t, int8_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vand_vx)))
vint8m8_t vand_vx_i8m8(vint8m8_t, int8_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vand_vx_m)))
vint8m8_t vand_vx_i8m8_m(vbool1_t, vint8m8_t, vint8m8_t, int8_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vand_vx)))
vint8mf2_t vand_vx_i8mf2(vint8mf2_t, int8_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vand_vx_m)))
vint8mf2_t vand_vx_i8mf2_m(vbool16_t, vint8mf2_t, vint8mf2_t, int8_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vand_vx)))
vint8mf4_t vand_vx_i8mf4(vint8mf4_t, int8_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vand_vx_m)))
vint8mf4_t vand_vx_i8mf4_m(vbool32_t, vint8mf4_t, vint8mf4_t, int8_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vand_vx)))
vint8mf8_t vand_vx_i8mf8(vint8mf8_t, int8_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vand_vx_m)))
vint8mf8_t vand_vx_i8mf8_m(vbool64_t, vint8mf8_t, vint8mf8_t, int8_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vand_vx)))
vint16m1_t vand_vx_i16m1(vint16m1_t, int16_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vand_vx_m)))
vint16m1_t vand_vx_i16m1_m(vbool16_t, vint16m1_t, vint16m1_t, int16_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vand_vx)))
vint16m2_t vand_vx_i16m2(vint16m2_t, int16_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vand_vx_m)))
vint16m2_t vand_vx_i16m2_m(vbool8_t, vint16m2_t, vint16m2_t, int16_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vand_vx)))
vint16m4_t vand_vx_i16m4(vint16m4_t, int16_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vand_vx_m)))
vint16m4_t vand_vx_i16m4_m(vbool4_t, vint16m4_t, vint16m4_t, int16_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vand_vx)))
vint16m8_t vand_vx_i16m8(vint16m8_t, int16_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vand_vx_m)))
vint16m8_t vand_vx_i16m8_m(vbool2_t, vint16m8_t, vint16m8_t, int16_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vand_vx)))
vint16mf2_t vand_vx_i16mf2(vint16mf2_t, int16_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vand_vx_m)))
vint16mf2_t vand_vx_i16mf2_m(vbool32_t, vint16mf2_t, vint16mf2_t, int16_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vand_vx)))
vint16mf4_t vand_vx_i16mf4(vint16mf4_t, int16_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vand_vx_m)))
vint16mf4_t vand_vx_i16mf4_m(vbool64_t, vint16mf4_t, vint16mf4_t, int16_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vand_vx)))
vint32m1_t vand_vx_i32m1(vint32m1_t, int32_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vand_vx_m)))
vint32m1_t vand_vx_i32m1_m(vbool32_t, vint32m1_t, vint32m1_t, int32_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vand_vx)))
vint32m2_t vand_vx_i32m2(vint32m2_t, int32_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vand_vx_m)))
vint32m2_t vand_vx_i32m2_m(vbool16_t, vint32m2_t, vint32m2_t, int32_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vand_vx)))
vint32m4_t vand_vx_i32m4(vint32m4_t, int32_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vand_vx_m)))
vint32m4_t vand_vx_i32m4_m(vbool8_t, vint32m4_t, vint32m4_t, int32_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vand_vx)))
vint32m8_t vand_vx_i32m8(vint32m8_t, int32_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vand_vx_m)))
vint32m8_t vand_vx_i32m8_m(vbool4_t, vint32m8_t, vint32m8_t, int32_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vand_vx)))
vint32mf2_t vand_vx_i32mf2(vint32mf2_t, int32_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vand_vx_m)))
vint32mf2_t vand_vx_i32mf2_m(vbool64_t, vint32mf2_t, vint32mf2_t, int32_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vand_vv)))
vuint8m1_t vand_vv_u8m1(vuint8m1_t, vuint8m1_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vand_vv_m)))
vuint8m1_t vand_vv_u8m1_m(vbool8_t, vuint8m1_t, vuint8m1_t, vuint8m1_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vand_vv)))
vuint8m2_t vand_vv_u8m2(vuint8m2_t, vuint8m2_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vand_vv_m)))
vuint8m2_t vand_vv_u8m2_m(vbool4_t, vuint8m2_t, vuint8m2_t, vuint8m2_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vand_vv)))
vuint8m4_t vand_vv_u8m4(vuint8m4_t, vuint8m4_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vand_vv_m)))
vuint8m4_t vand_vv_u8m4_m(vbool2_t, vuint8m4_t, vuint8m4_t, vuint8m4_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vand_vv)))
vuint8m8_t vand_vv_u8m8(vuint8m8_t, vuint8m8_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vand_vv_m)))
vuint8m8_t vand_vv_u8m8_m(vbool1_t, vuint8m8_t, vuint8m8_t, vuint8m8_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vand_vv)))
vuint8mf2_t vand_vv_u8mf2(vuint8mf2_t, vuint8mf2_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vand_vv_m)))
vuint8mf2_t vand_vv_u8mf2_m(vbool16_t, vuint8mf2_t, vuint8mf2_t, vuint8mf2_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vand_vv)))
vuint8mf4_t vand_vv_u8mf4(vuint8mf4_t, vuint8mf4_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vand_vv_m)))
vuint8mf4_t vand_vv_u8mf4_m(vbool32_t, vuint8mf4_t, vuint8mf4_t, vuint8mf4_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vand_vv)))
vuint8mf8_t vand_vv_u8mf8(vuint8mf8_t, vuint8mf8_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vand_vv_m)))
vuint8mf8_t vand_vv_u8mf8_m(vbool64_t, vuint8mf8_t, vuint8mf8_t, vuint8mf8_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vand_vv)))
vuint16m1_t vand_vv_u16m1(vuint16m1_t, vuint16m1_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vand_vv_m)))
vuint16m1_t vand_vv_u16m1_m(vbool16_t, vuint16m1_t, vuint16m1_t, vuint16m1_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vand_vv)))
vuint16m2_t vand_vv_u16m2(vuint16m2_t, vuint16m2_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vand_vv_m)))
vuint16m2_t vand_vv_u16m2_m(vbool8_t, vuint16m2_t, vuint16m2_t, vuint16m2_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vand_vv)))
vuint16m4_t vand_vv_u16m4(vuint16m4_t, vuint16m4_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vand_vv_m)))
vuint16m4_t vand_vv_u16m4_m(vbool4_t, vuint16m4_t, vuint16m4_t, vuint16m4_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vand_vv)))
vuint16m8_t vand_vv_u16m8(vuint16m8_t, vuint16m8_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vand_vv_m)))
vuint16m8_t vand_vv_u16m8_m(vbool2_t, vuint16m8_t, vuint16m8_t, vuint16m8_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vand_vv)))
vuint16mf2_t vand_vv_u16mf2(vuint16mf2_t, vuint16mf2_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vand_vv_m)))
vuint16mf2_t vand_vv_u16mf2_m(vbool32_t, vuint16mf2_t, vuint16mf2_t, vuint16mf2_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vand_vv)))
vuint16mf4_t vand_vv_u16mf4(vuint16mf4_t, vuint16mf4_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vand_vv_m)))
vuint16mf4_t vand_vv_u16mf4_m(vbool64_t, vuint16mf4_t, vuint16mf4_t, vuint16mf4_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vand_vv)))
vuint32m1_t vand_vv_u32m1(vuint32m1_t, vuint32m1_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vand_vv_m)))
vuint32m1_t vand_vv_u32m1_m(vbool32_t, vuint32m1_t, vuint32m1_t, vuint32m1_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vand_vv)))
vuint32m2_t vand_vv_u32m2(vuint32m2_t, vuint32m2_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vand_vv_m)))
vuint32m2_t vand_vv_u32m2_m(vbool16_t, vuint32m2_t, vuint32m2_t, vuint32m2_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vand_vv)))
vuint32m4_t vand_vv_u32m4(vuint32m4_t, vuint32m4_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vand_vv_m)))
vuint32m4_t vand_vv_u32m4_m(vbool8_t, vuint32m4_t, vuint32m4_t, vuint32m4_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vand_vv)))
vuint32m8_t vand_vv_u32m8(vuint32m8_t, vuint32m8_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vand_vv_m)))
vuint32m8_t vand_vv_u32m8_m(vbool4_t, vuint32m8_t, vuint32m8_t, vuint32m8_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vand_vv)))
vuint32mf2_t vand_vv_u32mf2(vuint32mf2_t, vuint32mf2_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vand_vv_m)))
vuint32mf2_t vand_vv_u32mf2_m(vbool64_t, vuint32mf2_t, vuint32mf2_t, vuint32mf2_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vand_vx)))
vuint8m1_t vand_vx_u8m1(vuint8m1_t, uint8_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vand_vx_m)))
vuint8m1_t vand_vx_u8m1_m(vbool8_t, vuint8m1_t, vuint8m1_t, uint8_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vand_vx)))
vuint8m2_t vand_vx_u8m2(vuint8m2_t, uint8_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vand_vx_m)))
vuint8m2_t vand_vx_u8m2_m(vbool4_t, vuint8m2_t, vuint8m2_t, uint8_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vand_vx)))
vuint8m4_t vand_vx_u8m4(vuint8m4_t, uint8_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vand_vx_m)))
vuint8m4_t vand_vx_u8m4_m(vbool2_t, vuint8m4_t, vuint8m4_t, uint8_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vand_vx)))
vuint8m8_t vand_vx_u8m8(vuint8m8_t, uint8_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vand_vx_m)))
vuint8m8_t vand_vx_u8m8_m(vbool1_t, vuint8m8_t, vuint8m8_t, uint8_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vand_vx)))
vuint8mf2_t vand_vx_u8mf2(vuint8mf2_t, uint8_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vand_vx_m)))
vuint8mf2_t vand_vx_u8mf2_m(vbool16_t, vuint8mf2_t, vuint8mf2_t, uint8_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vand_vx)))
vuint8mf4_t vand_vx_u8mf4(vuint8mf4_t, uint8_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vand_vx_m)))
vuint8mf4_t vand_vx_u8mf4_m(vbool32_t, vuint8mf4_t, vuint8mf4_t, uint8_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vand_vx)))
vuint8mf8_t vand_vx_u8mf8(vuint8mf8_t, uint8_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vand_vx_m)))
vuint8mf8_t vand_vx_u8mf8_m(vbool64_t, vuint8mf8_t, vuint8mf8_t, uint8_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vand_vx)))
vuint16m1_t vand_vx_u16m1(vuint16m1_t, uint16_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vand_vx_m)))
vuint16m1_t vand_vx_u16m1_m(vbool16_t, vuint16m1_t, vuint16m1_t, uint16_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vand_vx)))
vuint16m2_t vand_vx_u16m2(vuint16m2_t, uint16_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vand_vx_m)))
vuint16m2_t vand_vx_u16m2_m(vbool8_t, vuint16m2_t, vuint16m2_t, uint16_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vand_vx)))
vuint16m4_t vand_vx_u16m4(vuint16m4_t, uint16_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vand_vx_m)))
vuint16m4_t vand_vx_u16m4_m(vbool4_t, vuint16m4_t, vuint16m4_t, uint16_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vand_vx)))
vuint16m8_t vand_vx_u16m8(vuint16m8_t, uint16_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vand_vx_m)))
vuint16m8_t vand_vx_u16m8_m(vbool2_t, vuint16m8_t, vuint16m8_t, uint16_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vand_vx)))
vuint16mf2_t vand_vx_u16mf2(vuint16mf2_t, uint16_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vand_vx_m)))
vuint16mf2_t vand_vx_u16mf2_m(vbool32_t, vuint16mf2_t, vuint16mf2_t, uint16_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vand_vx)))
vuint16mf4_t vand_vx_u16mf4(vuint16mf4_t, uint16_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vand_vx_m)))
vuint16mf4_t vand_vx_u16mf4_m(vbool64_t, vuint16mf4_t, vuint16mf4_t, uint16_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vand_vx)))
vuint32m1_t vand_vx_u32m1(vuint32m1_t, uint32_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vand_vx_m)))
vuint32m1_t vand_vx_u32m1_m(vbool32_t, vuint32m1_t, vuint32m1_t, uint32_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vand_vx)))
vuint32m2_t vand_vx_u32m2(vuint32m2_t, uint32_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vand_vx_m)))
vuint32m2_t vand_vx_u32m2_m(vbool16_t, vuint32m2_t, vuint32m2_t, uint32_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vand_vx)))
vuint32m4_t vand_vx_u32m4(vuint32m4_t, uint32_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vand_vx_m)))
vuint32m4_t vand_vx_u32m4_m(vbool8_t, vuint32m4_t, vuint32m4_t, uint32_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vand_vx)))
vuint32m8_t vand_vx_u32m8(vuint32m8_t, uint32_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vand_vx_m)))
vuint32m8_t vand_vx_u32m8_m(vbool4_t, vuint32m8_t, vuint32m8_t, uint32_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vand_vx)))
vuint32mf2_t vand_vx_u32mf2(vuint32mf2_t, uint32_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vand_vx_m)))
vuint32mf2_t vand_vx_u32mf2_m(vbool64_t, vuint32mf2_t, vuint32mf2_t, uint32_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vxor_vv)))
vint8m1_t vxor_vv_i8m1(vint8m1_t, vint8m1_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vxor_vv_m)))
vint8m1_t vxor_vv_i8m1_m(vbool8_t, vint8m1_t, vint8m1_t, vint8m1_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vxor_vv)))
vint8m2_t vxor_vv_i8m2(vint8m2_t, vint8m2_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vxor_vv_m)))
vint8m2_t vxor_vv_i8m2_m(vbool4_t, vint8m2_t, vint8m2_t, vint8m2_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vxor_vv)))
vint8m4_t vxor_vv_i8m4(vint8m4_t, vint8m4_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vxor_vv_m)))
vint8m4_t vxor_vv_i8m4_m(vbool2_t, vint8m4_t, vint8m4_t, vint8m4_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vxor_vv)))
vint8m8_t vxor_vv_i8m8(vint8m8_t, vint8m8_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vxor_vv_m)))
vint8m8_t vxor_vv_i8m8_m(vbool1_t, vint8m8_t, vint8m8_t, vint8m8_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vxor_vv)))
vint8mf2_t vxor_vv_i8mf2(vint8mf2_t, vint8mf2_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vxor_vv_m)))
vint8mf2_t vxor_vv_i8mf2_m(vbool16_t, vint8mf2_t, vint8mf2_t, vint8mf2_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vxor_vv)))
vint8mf4_t vxor_vv_i8mf4(vint8mf4_t, vint8mf4_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vxor_vv_m)))
vint8mf4_t vxor_vv_i8mf4_m(vbool32_t, vint8mf4_t, vint8mf4_t, vint8mf4_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vxor_vv)))
vint8mf8_t vxor_vv_i8mf8(vint8mf8_t, vint8mf8_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vxor_vv_m)))
vint8mf8_t vxor_vv_i8mf8_m(vbool64_t, vint8mf8_t, vint8mf8_t, vint8mf8_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vxor_vv)))
vint16m1_t vxor_vv_i16m1(vint16m1_t, vint16m1_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vxor_vv_m)))
vint16m1_t vxor_vv_i16m1_m(vbool16_t, vint16m1_t, vint16m1_t, vint16m1_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vxor_vv)))
vint16m2_t vxor_vv_i16m2(vint16m2_t, vint16m2_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vxor_vv_m)))
vint16m2_t vxor_vv_i16m2_m(vbool8_t, vint16m2_t, vint16m2_t, vint16m2_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vxor_vv)))
vint16m4_t vxor_vv_i16m4(vint16m4_t, vint16m4_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vxor_vv_m)))
vint16m4_t vxor_vv_i16m4_m(vbool4_t, vint16m4_t, vint16m4_t, vint16m4_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vxor_vv)))
vint16m8_t vxor_vv_i16m8(vint16m8_t, vint16m8_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vxor_vv_m)))
vint16m8_t vxor_vv_i16m8_m(vbool2_t, vint16m8_t, vint16m8_t, vint16m8_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vxor_vv)))
vint16mf2_t vxor_vv_i16mf2(vint16mf2_t, vint16mf2_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vxor_vv_m)))
vint16mf2_t vxor_vv_i16mf2_m(vbool32_t, vint16mf2_t, vint16mf2_t, vint16mf2_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vxor_vv)))
vint16mf4_t vxor_vv_i16mf4(vint16mf4_t, vint16mf4_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vxor_vv_m)))
vint16mf4_t vxor_vv_i16mf4_m(vbool64_t, vint16mf4_t, vint16mf4_t, vint16mf4_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vxor_vv)))
vint32m1_t vxor_vv_i32m1(vint32m1_t, vint32m1_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vxor_vv_m)))
vint32m1_t vxor_vv_i32m1_m(vbool32_t, vint32m1_t, vint32m1_t, vint32m1_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vxor_vv)))
vint32m2_t vxor_vv_i32m2(vint32m2_t, vint32m2_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vxor_vv_m)))
vint32m2_t vxor_vv_i32m2_m(vbool16_t, vint32m2_t, vint32m2_t, vint32m2_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vxor_vv)))
vint32m4_t vxor_vv_i32m4(vint32m4_t, vint32m4_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vxor_vv_m)))
vint32m4_t vxor_vv_i32m4_m(vbool8_t, vint32m4_t, vint32m4_t, vint32m4_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vxor_vv)))
vint32m8_t vxor_vv_i32m8(vint32m8_t, vint32m8_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vxor_vv_m)))
vint32m8_t vxor_vv_i32m8_m(vbool4_t, vint32m8_t, vint32m8_t, vint32m8_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vxor_vv)))
vint32mf2_t vxor_vv_i32mf2(vint32mf2_t, vint32mf2_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vxor_vv_m)))
vint32mf2_t vxor_vv_i32mf2_m(vbool64_t, vint32mf2_t, vint32mf2_t, vint32mf2_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vxor_vx)))
vint8m1_t vxor_vx_i8m1(vint8m1_t, int8_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vxor_vx_m)))
vint8m1_t vxor_vx_i8m1_m(vbool8_t, vint8m1_t, vint8m1_t, int8_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vxor_vx)))
vint8m2_t vxor_vx_i8m2(vint8m2_t, int8_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vxor_vx_m)))
vint8m2_t vxor_vx_i8m2_m(vbool4_t, vint8m2_t, vint8m2_t, int8_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vxor_vx)))
vint8m4_t vxor_vx_i8m4(vint8m4_t, int8_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vxor_vx_m)))
vint8m4_t vxor_vx_i8m4_m(vbool2_t, vint8m4_t, vint8m4_t, int8_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vxor_vx)))
vint8m8_t vxor_vx_i8m8(vint8m8_t, int8_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vxor_vx_m)))
vint8m8_t vxor_vx_i8m8_m(vbool1_t, vint8m8_t, vint8m8_t, int8_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vxor_vx)))
vint8mf2_t vxor_vx_i8mf2(vint8mf2_t, int8_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vxor_vx_m)))
vint8mf2_t vxor_vx_i8mf2_m(vbool16_t, vint8mf2_t, vint8mf2_t, int8_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vxor_vx)))
vint8mf4_t vxor_vx_i8mf4(vint8mf4_t, int8_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vxor_vx_m)))
vint8mf4_t vxor_vx_i8mf4_m(vbool32_t, vint8mf4_t, vint8mf4_t, int8_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vxor_vx)))
vint8mf8_t vxor_vx_i8mf8(vint8mf8_t, int8_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vxor_vx_m)))
vint8mf8_t vxor_vx_i8mf8_m(vbool64_t, vint8mf8_t, vint8mf8_t, int8_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vxor_vx)))
vint16m1_t vxor_vx_i16m1(vint16m1_t, int16_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vxor_vx_m)))
vint16m1_t vxor_vx_i16m1_m(vbool16_t, vint16m1_t, vint16m1_t, int16_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vxor_vx)))
vint16m2_t vxor_vx_i16m2(vint16m2_t, int16_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vxor_vx_m)))
vint16m2_t vxor_vx_i16m2_m(vbool8_t, vint16m2_t, vint16m2_t, int16_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vxor_vx)))
vint16m4_t vxor_vx_i16m4(vint16m4_t, int16_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vxor_vx_m)))
vint16m4_t vxor_vx_i16m4_m(vbool4_t, vint16m4_t, vint16m4_t, int16_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vxor_vx)))
vint16m8_t vxor_vx_i16m8(vint16m8_t, int16_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vxor_vx_m)))
vint16m8_t vxor_vx_i16m8_m(vbool2_t, vint16m8_t, vint16m8_t, int16_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vxor_vx)))
vint16mf2_t vxor_vx_i16mf2(vint16mf2_t, int16_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vxor_vx_m)))
vint16mf2_t vxor_vx_i16mf2_m(vbool32_t, vint16mf2_t, vint16mf2_t, int16_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vxor_vx)))
vint16mf4_t vxor_vx_i16mf4(vint16mf4_t, int16_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vxor_vx_m)))
vint16mf4_t vxor_vx_i16mf4_m(vbool64_t, vint16mf4_t, vint16mf4_t, int16_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vxor_vx)))
vint32m1_t vxor_vx_i32m1(vint32m1_t, int32_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vxor_vx_m)))
vint32m1_t vxor_vx_i32m1_m(vbool32_t, vint32m1_t, vint32m1_t, int32_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vxor_vx)))
vint32m2_t vxor_vx_i32m2(vint32m2_t, int32_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vxor_vx_m)))
vint32m2_t vxor_vx_i32m2_m(vbool16_t, vint32m2_t, vint32m2_t, int32_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vxor_vx)))
vint32m4_t vxor_vx_i32m4(vint32m4_t, int32_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vxor_vx_m)))
vint32m4_t vxor_vx_i32m4_m(vbool8_t, vint32m4_t, vint32m4_t, int32_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vxor_vx)))
vint32m8_t vxor_vx_i32m8(vint32m8_t, int32_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vxor_vx_m)))
vint32m8_t vxor_vx_i32m8_m(vbool4_t, vint32m8_t, vint32m8_t, int32_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vxor_vx)))
vint32mf2_t vxor_vx_i32mf2(vint32mf2_t, int32_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vxor_vx_m)))
vint32mf2_t vxor_vx_i32mf2_m(vbool64_t, vint32mf2_t, vint32mf2_t, int32_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vxor_vv)))
vuint8m1_t vxor_vv_u8m1(vuint8m1_t, vuint8m1_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vxor_vv_m)))
vuint8m1_t vxor_vv_u8m1_m(vbool8_t, vuint8m1_t, vuint8m1_t, vuint8m1_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vxor_vv)))
vuint8m2_t vxor_vv_u8m2(vuint8m2_t, vuint8m2_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vxor_vv_m)))
vuint8m2_t vxor_vv_u8m2_m(vbool4_t, vuint8m2_t, vuint8m2_t, vuint8m2_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vxor_vv)))
vuint8m4_t vxor_vv_u8m4(vuint8m4_t, vuint8m4_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vxor_vv_m)))
vuint8m4_t vxor_vv_u8m4_m(vbool2_t, vuint8m4_t, vuint8m4_t, vuint8m4_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vxor_vv)))
vuint8m8_t vxor_vv_u8m8(vuint8m8_t, vuint8m8_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vxor_vv_m)))
vuint8m8_t vxor_vv_u8m8_m(vbool1_t, vuint8m8_t, vuint8m8_t, vuint8m8_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vxor_vv)))
vuint8mf2_t vxor_vv_u8mf2(vuint8mf2_t, vuint8mf2_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vxor_vv_m)))
vuint8mf2_t vxor_vv_u8mf2_m(vbool16_t, vuint8mf2_t, vuint8mf2_t, vuint8mf2_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vxor_vv)))
vuint8mf4_t vxor_vv_u8mf4(vuint8mf4_t, vuint8mf4_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vxor_vv_m)))
vuint8mf4_t vxor_vv_u8mf4_m(vbool32_t, vuint8mf4_t, vuint8mf4_t, vuint8mf4_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vxor_vv)))
vuint8mf8_t vxor_vv_u8mf8(vuint8mf8_t, vuint8mf8_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vxor_vv_m)))
vuint8mf8_t vxor_vv_u8mf8_m(vbool64_t, vuint8mf8_t, vuint8mf8_t, vuint8mf8_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vxor_vv)))
vuint16m1_t vxor_vv_u16m1(vuint16m1_t, vuint16m1_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vxor_vv_m)))
vuint16m1_t vxor_vv_u16m1_m(vbool16_t, vuint16m1_t, vuint16m1_t, vuint16m1_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vxor_vv)))
vuint16m2_t vxor_vv_u16m2(vuint16m2_t, vuint16m2_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vxor_vv_m)))
vuint16m2_t vxor_vv_u16m2_m(vbool8_t, vuint16m2_t, vuint16m2_t, vuint16m2_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vxor_vv)))
vuint16m4_t vxor_vv_u16m4(vuint16m4_t, vuint16m4_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vxor_vv_m)))
vuint16m4_t vxor_vv_u16m4_m(vbool4_t, vuint16m4_t, vuint16m4_t, vuint16m4_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vxor_vv)))
vuint16m8_t vxor_vv_u16m8(vuint16m8_t, vuint16m8_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vxor_vv_m)))
vuint16m8_t vxor_vv_u16m8_m(vbool2_t, vuint16m8_t, vuint16m8_t, vuint16m8_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vxor_vv)))
vuint16mf2_t vxor_vv_u16mf2(vuint16mf2_t, vuint16mf2_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vxor_vv_m)))
vuint16mf2_t vxor_vv_u16mf2_m(vbool32_t, vuint16mf2_t, vuint16mf2_t, vuint16mf2_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vxor_vv)))
vuint16mf4_t vxor_vv_u16mf4(vuint16mf4_t, vuint16mf4_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vxor_vv_m)))
vuint16mf4_t vxor_vv_u16mf4_m(vbool64_t, vuint16mf4_t, vuint16mf4_t, vuint16mf4_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vxor_vv)))
vuint32m1_t vxor_vv_u32m1(vuint32m1_t, vuint32m1_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vxor_vv_m)))
vuint32m1_t vxor_vv_u32m1_m(vbool32_t, vuint32m1_t, vuint32m1_t, vuint32m1_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vxor_vv)))
vuint32m2_t vxor_vv_u32m2(vuint32m2_t, vuint32m2_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vxor_vv_m)))
vuint32m2_t vxor_vv_u32m2_m(vbool16_t, vuint32m2_t, vuint32m2_t, vuint32m2_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vxor_vv)))
vuint32m4_t vxor_vv_u32m4(vuint32m4_t, vuint32m4_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vxor_vv_m)))
vuint32m4_t vxor_vv_u32m4_m(vbool8_t, vuint32m4_t, vuint32m4_t, vuint32m4_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vxor_vv)))
vuint32m8_t vxor_vv_u32m8(vuint32m8_t, vuint32m8_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vxor_vv_m)))
vuint32m8_t vxor_vv_u32m8_m(vbool4_t, vuint32m8_t, vuint32m8_t, vuint32m8_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vxor_vv)))
vuint32mf2_t vxor_vv_u32mf2(vuint32mf2_t, vuint32mf2_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vxor_vv_m)))
vuint32mf2_t vxor_vv_u32mf2_m(vbool64_t, vuint32mf2_t, vuint32mf2_t, vuint32mf2_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vxor_vx)))
vuint8m1_t vxor_vx_u8m1(vuint8m1_t, uint8_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vxor_vx_m)))
vuint8m1_t vxor_vx_u8m1_m(vbool8_t, vuint8m1_t, vuint8m1_t, uint8_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vxor_vx)))
vuint8m2_t vxor_vx_u8m2(vuint8m2_t, uint8_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vxor_vx_m)))
vuint8m2_t vxor_vx_u8m2_m(vbool4_t, vuint8m2_t, vuint8m2_t, uint8_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vxor_vx)))
vuint8m4_t vxor_vx_u8m4(vuint8m4_t, uint8_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vxor_vx_m)))
vuint8m4_t vxor_vx_u8m4_m(vbool2_t, vuint8m4_t, vuint8m4_t, uint8_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vxor_vx)))
vuint8m8_t vxor_vx_u8m8(vuint8m8_t, uint8_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vxor_vx_m)))
vuint8m8_t vxor_vx_u8m8_m(vbool1_t, vuint8m8_t, vuint8m8_t, uint8_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vxor_vx)))
vuint8mf2_t vxor_vx_u8mf2(vuint8mf2_t, uint8_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vxor_vx_m)))
vuint8mf2_t vxor_vx_u8mf2_m(vbool16_t, vuint8mf2_t, vuint8mf2_t, uint8_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vxor_vx)))
vuint8mf4_t vxor_vx_u8mf4(vuint8mf4_t, uint8_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vxor_vx_m)))
vuint8mf4_t vxor_vx_u8mf4_m(vbool32_t, vuint8mf4_t, vuint8mf4_t, uint8_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vxor_vx)))
vuint8mf8_t vxor_vx_u8mf8(vuint8mf8_t, uint8_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vxor_vx_m)))
vuint8mf8_t vxor_vx_u8mf8_m(vbool64_t, vuint8mf8_t, vuint8mf8_t, uint8_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vxor_vx)))
vuint16m1_t vxor_vx_u16m1(vuint16m1_t, uint16_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vxor_vx_m)))
vuint16m1_t vxor_vx_u16m1_m(vbool16_t, vuint16m1_t, vuint16m1_t, uint16_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vxor_vx)))
vuint16m2_t vxor_vx_u16m2(vuint16m2_t, uint16_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vxor_vx_m)))
vuint16m2_t vxor_vx_u16m2_m(vbool8_t, vuint16m2_t, vuint16m2_t, uint16_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vxor_vx)))
vuint16m4_t vxor_vx_u16m4(vuint16m4_t, uint16_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vxor_vx_m)))
vuint16m4_t vxor_vx_u16m4_m(vbool4_t, vuint16m4_t, vuint16m4_t, uint16_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vxor_vx)))
vuint16m8_t vxor_vx_u16m8(vuint16m8_t, uint16_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vxor_vx_m)))
vuint16m8_t vxor_vx_u16m8_m(vbool2_t, vuint16m8_t, vuint16m8_t, uint16_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vxor_vx)))
vuint16mf2_t vxor_vx_u16mf2(vuint16mf2_t, uint16_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vxor_vx_m)))
vuint16mf2_t vxor_vx_u16mf2_m(vbool32_t, vuint16mf2_t, vuint16mf2_t, uint16_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vxor_vx)))
vuint16mf4_t vxor_vx_u16mf4(vuint16mf4_t, uint16_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vxor_vx_m)))
vuint16mf4_t vxor_vx_u16mf4_m(vbool64_t, vuint16mf4_t, vuint16mf4_t, uint16_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vxor_vx)))
vuint32m1_t vxor_vx_u32m1(vuint32m1_t, uint32_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vxor_vx_m)))
vuint32m1_t vxor_vx_u32m1_m(vbool32_t, vuint32m1_t, vuint32m1_t, uint32_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vxor_vx)))
vuint32m2_t vxor_vx_u32m2(vuint32m2_t, uint32_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vxor_vx_m)))
vuint32m2_t vxor_vx_u32m2_m(vbool16_t, vuint32m2_t, vuint32m2_t, uint32_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vxor_vx)))
vuint32m4_t vxor_vx_u32m4(vuint32m4_t, uint32_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vxor_vx_m)))
vuint32m4_t vxor_vx_u32m4_m(vbool8_t, vuint32m4_t, vuint32m4_t, uint32_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vxor_vx)))
vuint32m8_t vxor_vx_u32m8(vuint32m8_t, uint32_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vxor_vx_m)))
vuint32m8_t vxor_vx_u32m8_m(vbool4_t, vuint32m8_t, vuint32m8_t, uint32_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vxor_vx)))
vuint32mf2_t vxor_vx_u32mf2(vuint32mf2_t, uint32_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vxor_vx_m)))
vuint32mf2_t vxor_vx_u32mf2_m(vbool64_t, vuint32mf2_t, vuint32mf2_t, uint32_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vor_vv)))
vint8m1_t vor_vv_i8m1(vint8m1_t, vint8m1_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vor_vv_m)))
vint8m1_t vor_vv_i8m1_m(vbool8_t, vint8m1_t, vint8m1_t, vint8m1_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vor_vv)))
vint8m2_t vor_vv_i8m2(vint8m2_t, vint8m2_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vor_vv_m)))
vint8m2_t vor_vv_i8m2_m(vbool4_t, vint8m2_t, vint8m2_t, vint8m2_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vor_vv)))
vint8m4_t vor_vv_i8m4(vint8m4_t, vint8m4_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vor_vv_m)))
vint8m4_t vor_vv_i8m4_m(vbool2_t, vint8m4_t, vint8m4_t, vint8m4_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vor_vv)))
vint8m8_t vor_vv_i8m8(vint8m8_t, vint8m8_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vor_vv_m)))
vint8m8_t vor_vv_i8m8_m(vbool1_t, vint8m8_t, vint8m8_t, vint8m8_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vor_vv)))
vint8mf2_t vor_vv_i8mf2(vint8mf2_t, vint8mf2_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vor_vv_m)))
vint8mf2_t vor_vv_i8mf2_m(vbool16_t, vint8mf2_t, vint8mf2_t, vint8mf2_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vor_vv)))
vint8mf4_t vor_vv_i8mf4(vint8mf4_t, vint8mf4_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vor_vv_m)))
vint8mf4_t vor_vv_i8mf4_m(vbool32_t, vint8mf4_t, vint8mf4_t, vint8mf4_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vor_vv)))
vint8mf8_t vor_vv_i8mf8(vint8mf8_t, vint8mf8_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vor_vv_m)))
vint8mf8_t vor_vv_i8mf8_m(vbool64_t, vint8mf8_t, vint8mf8_t, vint8mf8_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vor_vv)))
vint16m1_t vor_vv_i16m1(vint16m1_t, vint16m1_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vor_vv_m)))
vint16m1_t vor_vv_i16m1_m(vbool16_t, vint16m1_t, vint16m1_t, vint16m1_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vor_vv)))
vint16m2_t vor_vv_i16m2(vint16m2_t, vint16m2_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vor_vv_m)))
vint16m2_t vor_vv_i16m2_m(vbool8_t, vint16m2_t, vint16m2_t, vint16m2_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vor_vv)))
vint16m4_t vor_vv_i16m4(vint16m4_t, vint16m4_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vor_vv_m)))
vint16m4_t vor_vv_i16m4_m(vbool4_t, vint16m4_t, vint16m4_t, vint16m4_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vor_vv)))
vint16m8_t vor_vv_i16m8(vint16m8_t, vint16m8_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vor_vv_m)))
vint16m8_t vor_vv_i16m8_m(vbool2_t, vint16m8_t, vint16m8_t, vint16m8_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vor_vv)))
vint16mf2_t vor_vv_i16mf2(vint16mf2_t, vint16mf2_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vor_vv_m)))
vint16mf2_t vor_vv_i16mf2_m(vbool32_t, vint16mf2_t, vint16mf2_t, vint16mf2_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vor_vv)))
vint16mf4_t vor_vv_i16mf4(vint16mf4_t, vint16mf4_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vor_vv_m)))
vint16mf4_t vor_vv_i16mf4_m(vbool64_t, vint16mf4_t, vint16mf4_t, vint16mf4_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vor_vv)))
vint32m1_t vor_vv_i32m1(vint32m1_t, vint32m1_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vor_vv_m)))
vint32m1_t vor_vv_i32m1_m(vbool32_t, vint32m1_t, vint32m1_t, vint32m1_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vor_vv)))
vint32m2_t vor_vv_i32m2(vint32m2_t, vint32m2_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vor_vv_m)))
vint32m2_t vor_vv_i32m2_m(vbool16_t, vint32m2_t, vint32m2_t, vint32m2_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vor_vv)))
vint32m4_t vor_vv_i32m4(vint32m4_t, vint32m4_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vor_vv_m)))
vint32m4_t vor_vv_i32m4_m(vbool8_t, vint32m4_t, vint32m4_t, vint32m4_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vor_vv)))
vint32m8_t vor_vv_i32m8(vint32m8_t, vint32m8_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vor_vv_m)))
vint32m8_t vor_vv_i32m8_m(vbool4_t, vint32m8_t, vint32m8_t, vint32m8_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vor_vv)))
vint32mf2_t vor_vv_i32mf2(vint32mf2_t, vint32mf2_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vor_vv_m)))
vint32mf2_t vor_vv_i32mf2_m(vbool64_t, vint32mf2_t, vint32mf2_t, vint32mf2_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vor_vx)))
vint8m1_t vor_vx_i8m1(vint8m1_t, int8_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vor_vx_m)))
vint8m1_t vor_vx_i8m1_m(vbool8_t, vint8m1_t, vint8m1_t, int8_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vor_vx)))
vint8m2_t vor_vx_i8m2(vint8m2_t, int8_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vor_vx_m)))
vint8m2_t vor_vx_i8m2_m(vbool4_t, vint8m2_t, vint8m2_t, int8_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vor_vx)))
vint8m4_t vor_vx_i8m4(vint8m4_t, int8_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vor_vx_m)))
vint8m4_t vor_vx_i8m4_m(vbool2_t, vint8m4_t, vint8m4_t, int8_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vor_vx)))
vint8m8_t vor_vx_i8m8(vint8m8_t, int8_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vor_vx_m)))
vint8m8_t vor_vx_i8m8_m(vbool1_t, vint8m8_t, vint8m8_t, int8_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vor_vx)))
vint8mf2_t vor_vx_i8mf2(vint8mf2_t, int8_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vor_vx_m)))
vint8mf2_t vor_vx_i8mf2_m(vbool16_t, vint8mf2_t, vint8mf2_t, int8_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vor_vx)))
vint8mf4_t vor_vx_i8mf4(vint8mf4_t, int8_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vor_vx_m)))
vint8mf4_t vor_vx_i8mf4_m(vbool32_t, vint8mf4_t, vint8mf4_t, int8_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vor_vx)))
vint8mf8_t vor_vx_i8mf8(vint8mf8_t, int8_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vor_vx_m)))
vint8mf8_t vor_vx_i8mf8_m(vbool64_t, vint8mf8_t, vint8mf8_t, int8_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vor_vx)))
vint16m1_t vor_vx_i16m1(vint16m1_t, int16_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vor_vx_m)))
vint16m1_t vor_vx_i16m1_m(vbool16_t, vint16m1_t, vint16m1_t, int16_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vor_vx)))
vint16m2_t vor_vx_i16m2(vint16m2_t, int16_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vor_vx_m)))
vint16m2_t vor_vx_i16m2_m(vbool8_t, vint16m2_t, vint16m2_t, int16_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vor_vx)))
vint16m4_t vor_vx_i16m4(vint16m4_t, int16_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vor_vx_m)))
vint16m4_t vor_vx_i16m4_m(vbool4_t, vint16m4_t, vint16m4_t, int16_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vor_vx)))
vint16m8_t vor_vx_i16m8(vint16m8_t, int16_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vor_vx_m)))
vint16m8_t vor_vx_i16m8_m(vbool2_t, vint16m8_t, vint16m8_t, int16_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vor_vx)))
vint16mf2_t vor_vx_i16mf2(vint16mf2_t, int16_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vor_vx_m)))
vint16mf2_t vor_vx_i16mf2_m(vbool32_t, vint16mf2_t, vint16mf2_t, int16_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vor_vx)))
vint16mf4_t vor_vx_i16mf4(vint16mf4_t, int16_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vor_vx_m)))
vint16mf4_t vor_vx_i16mf4_m(vbool64_t, vint16mf4_t, vint16mf4_t, int16_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vor_vx)))
vint32m1_t vor_vx_i32m1(vint32m1_t, int32_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vor_vx_m)))
vint32m1_t vor_vx_i32m1_m(vbool32_t, vint32m1_t, vint32m1_t, int32_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vor_vx)))
vint32m2_t vor_vx_i32m2(vint32m2_t, int32_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vor_vx_m)))
vint32m2_t vor_vx_i32m2_m(vbool16_t, vint32m2_t, vint32m2_t, int32_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vor_vx)))
vint32m4_t vor_vx_i32m4(vint32m4_t, int32_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vor_vx_m)))
vint32m4_t vor_vx_i32m4_m(vbool8_t, vint32m4_t, vint32m4_t, int32_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vor_vx)))
vint32m8_t vor_vx_i32m8(vint32m8_t, int32_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vor_vx_m)))
vint32m8_t vor_vx_i32m8_m(vbool4_t, vint32m8_t, vint32m8_t, int32_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vor_vx)))
vint32mf2_t vor_vx_i32mf2(vint32mf2_t, int32_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vor_vx_m)))
vint32mf2_t vor_vx_i32mf2_m(vbool64_t, vint32mf2_t, vint32mf2_t, int32_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vor_vv)))
vuint8m1_t vor_vv_u8m1(vuint8m1_t, vuint8m1_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vor_vv_m)))
vuint8m1_t vor_vv_u8m1_m(vbool8_t, vuint8m1_t, vuint8m1_t, vuint8m1_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vor_vv)))
vuint8m2_t vor_vv_u8m2(vuint8m2_t, vuint8m2_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vor_vv_m)))
vuint8m2_t vor_vv_u8m2_m(vbool4_t, vuint8m2_t, vuint8m2_t, vuint8m2_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vor_vv)))
vuint8m4_t vor_vv_u8m4(vuint8m4_t, vuint8m4_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vor_vv_m)))
vuint8m4_t vor_vv_u8m4_m(vbool2_t, vuint8m4_t, vuint8m4_t, vuint8m4_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vor_vv)))
vuint8m8_t vor_vv_u8m8(vuint8m8_t, vuint8m8_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vor_vv_m)))
vuint8m8_t vor_vv_u8m8_m(vbool1_t, vuint8m8_t, vuint8m8_t, vuint8m8_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vor_vv)))
vuint8mf2_t vor_vv_u8mf2(vuint8mf2_t, vuint8mf2_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vor_vv_m)))
vuint8mf2_t vor_vv_u8mf2_m(vbool16_t, vuint8mf2_t, vuint8mf2_t, vuint8mf2_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vor_vv)))
vuint8mf4_t vor_vv_u8mf4(vuint8mf4_t, vuint8mf4_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vor_vv_m)))
vuint8mf4_t vor_vv_u8mf4_m(vbool32_t, vuint8mf4_t, vuint8mf4_t, vuint8mf4_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vor_vv)))
vuint8mf8_t vor_vv_u8mf8(vuint8mf8_t, vuint8mf8_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vor_vv_m)))
vuint8mf8_t vor_vv_u8mf8_m(vbool64_t, vuint8mf8_t, vuint8mf8_t, vuint8mf8_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vor_vv)))
vuint16m1_t vor_vv_u16m1(vuint16m1_t, vuint16m1_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vor_vv_m)))
vuint16m1_t vor_vv_u16m1_m(vbool16_t, vuint16m1_t, vuint16m1_t, vuint16m1_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vor_vv)))
vuint16m2_t vor_vv_u16m2(vuint16m2_t, vuint16m2_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vor_vv_m)))
vuint16m2_t vor_vv_u16m2_m(vbool8_t, vuint16m2_t, vuint16m2_t, vuint16m2_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vor_vv)))
vuint16m4_t vor_vv_u16m4(vuint16m4_t, vuint16m4_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vor_vv_m)))
vuint16m4_t vor_vv_u16m4_m(vbool4_t, vuint16m4_t, vuint16m4_t, vuint16m4_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vor_vv)))
vuint16m8_t vor_vv_u16m8(vuint16m8_t, vuint16m8_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vor_vv_m)))
vuint16m8_t vor_vv_u16m8_m(vbool2_t, vuint16m8_t, vuint16m8_t, vuint16m8_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vor_vv)))
vuint16mf2_t vor_vv_u16mf2(vuint16mf2_t, vuint16mf2_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vor_vv_m)))
vuint16mf2_t vor_vv_u16mf2_m(vbool32_t, vuint16mf2_t, vuint16mf2_t, vuint16mf2_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vor_vv)))
vuint16mf4_t vor_vv_u16mf4(vuint16mf4_t, vuint16mf4_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vor_vv_m)))
vuint16mf4_t vor_vv_u16mf4_m(vbool64_t, vuint16mf4_t, vuint16mf4_t, vuint16mf4_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vor_vv)))
vuint32m1_t vor_vv_u32m1(vuint32m1_t, vuint32m1_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vor_vv_m)))
vuint32m1_t vor_vv_u32m1_m(vbool32_t, vuint32m1_t, vuint32m1_t, vuint32m1_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vor_vv)))
vuint32m2_t vor_vv_u32m2(vuint32m2_t, vuint32m2_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vor_vv_m)))
vuint32m2_t vor_vv_u32m2_m(vbool16_t, vuint32m2_t, vuint32m2_t, vuint32m2_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vor_vv)))
vuint32m4_t vor_vv_u32m4(vuint32m4_t, vuint32m4_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vor_vv_m)))
vuint32m4_t vor_vv_u32m4_m(vbool8_t, vuint32m4_t, vuint32m4_t, vuint32m4_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vor_vv)))
vuint32m8_t vor_vv_u32m8(vuint32m8_t, vuint32m8_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vor_vv_m)))
vuint32m8_t vor_vv_u32m8_m(vbool4_t, vuint32m8_t, vuint32m8_t, vuint32m8_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vor_vv)))
vuint32mf2_t vor_vv_u32mf2(vuint32mf2_t, vuint32mf2_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vor_vv_m)))
vuint32mf2_t vor_vv_u32mf2_m(vbool64_t, vuint32mf2_t, vuint32mf2_t, vuint32mf2_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vor_vx)))
vuint8m1_t vor_vx_u8m1(vuint8m1_t, uint8_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vor_vx_m)))
vuint8m1_t vor_vx_u8m1_m(vbool8_t, vuint8m1_t, vuint8m1_t, uint8_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vor_vx)))
vuint8m2_t vor_vx_u8m2(vuint8m2_t, uint8_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vor_vx_m)))
vuint8m2_t vor_vx_u8m2_m(vbool4_t, vuint8m2_t, vuint8m2_t, uint8_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vor_vx)))
vuint8m4_t vor_vx_u8m4(vuint8m4_t, uint8_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vor_vx_m)))
vuint8m4_t vor_vx_u8m4_m(vbool2_t, vuint8m4_t, vuint8m4_t, uint8_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vor_vx)))
vuint8m8_t vor_vx_u8m8(vuint8m8_t, uint8_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vor_vx_m)))
vuint8m8_t vor_vx_u8m8_m(vbool1_t, vuint8m8_t, vuint8m8_t, uint8_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vor_vx)))
vuint8mf2_t vor_vx_u8mf2(vuint8mf2_t, uint8_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vor_vx_m)))
vuint8mf2_t vor_vx_u8mf2_m(vbool16_t, vuint8mf2_t, vuint8mf2_t, uint8_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vor_vx)))
vuint8mf4_t vor_vx_u8mf4(vuint8mf4_t, uint8_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vor_vx_m)))
vuint8mf4_t vor_vx_u8mf4_m(vbool32_t, vuint8mf4_t, vuint8mf4_t, uint8_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vor_vx)))
vuint8mf8_t vor_vx_u8mf8(vuint8mf8_t, uint8_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vor_vx_m)))
vuint8mf8_t vor_vx_u8mf8_m(vbool64_t, vuint8mf8_t, vuint8mf8_t, uint8_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vor_vx)))
vuint16m1_t vor_vx_u16m1(vuint16m1_t, uint16_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vor_vx_m)))
vuint16m1_t vor_vx_u16m1_m(vbool16_t, vuint16m1_t, vuint16m1_t, uint16_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vor_vx)))
vuint16m2_t vor_vx_u16m2(vuint16m2_t, uint16_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vor_vx_m)))
vuint16m2_t vor_vx_u16m2_m(vbool8_t, vuint16m2_t, vuint16m2_t, uint16_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vor_vx)))
vuint16m4_t vor_vx_u16m4(vuint16m4_t, uint16_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vor_vx_m)))
vuint16m4_t vor_vx_u16m4_m(vbool4_t, vuint16m4_t, vuint16m4_t, uint16_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vor_vx)))
vuint16m8_t vor_vx_u16m8(vuint16m8_t, uint16_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vor_vx_m)))
vuint16m8_t vor_vx_u16m8_m(vbool2_t, vuint16m8_t, vuint16m8_t, uint16_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vor_vx)))
vuint16mf2_t vor_vx_u16mf2(vuint16mf2_t, uint16_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vor_vx_m)))
vuint16mf2_t vor_vx_u16mf2_m(vbool32_t, vuint16mf2_t, vuint16mf2_t, uint16_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vor_vx)))
vuint16mf4_t vor_vx_u16mf4(vuint16mf4_t, uint16_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vor_vx_m)))
vuint16mf4_t vor_vx_u16mf4_m(vbool64_t, vuint16mf4_t, vuint16mf4_t, uint16_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vor_vx)))
vuint32m1_t vor_vx_u32m1(vuint32m1_t, uint32_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vor_vx_m)))
vuint32m1_t vor_vx_u32m1_m(vbool32_t, vuint32m1_t, vuint32m1_t, uint32_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vor_vx)))
vuint32m2_t vor_vx_u32m2(vuint32m2_t, uint32_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vor_vx_m)))
vuint32m2_t vor_vx_u32m2_m(vbool16_t, vuint32m2_t, vuint32m2_t, uint32_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vor_vx)))
vuint32m4_t vor_vx_u32m4(vuint32m4_t, uint32_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vor_vx_m)))
vuint32m4_t vor_vx_u32m4_m(vbool8_t, vuint32m4_t, vuint32m4_t, uint32_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vor_vx)))
vuint32m8_t vor_vx_u32m8(vuint32m8_t, uint32_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vor_vx_m)))
vuint32m8_t vor_vx_u32m8_m(vbool4_t, vuint32m8_t, vuint32m8_t, uint32_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vor_vx)))
vuint32mf2_t vor_vx_u32mf2(vuint32mf2_t, uint32_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vor_vx_m)))
vuint32mf2_t vor_vx_u32mf2_m(vbool64_t, vuint32mf2_t, vuint32mf2_t, uint32_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vsll_vv)))
vint8m1_t vsll_vv_i8m1(vint8m1_t, vuint8m1_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vsll_vv_m)))
vint8m1_t vsll_vv_i8m1_m(vbool8_t, vint8m1_t, vint8m1_t, vuint8m1_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vsll_vv)))
vint8m2_t vsll_vv_i8m2(vint8m2_t, vuint8m2_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vsll_vv_m)))
vint8m2_t vsll_vv_i8m2_m(vbool4_t, vint8m2_t, vint8m2_t, vuint8m2_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vsll_vv)))
vint8m4_t vsll_vv_i8m4(vint8m4_t, vuint8m4_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vsll_vv_m)))
vint8m4_t vsll_vv_i8m4_m(vbool2_t, vint8m4_t, vint8m4_t, vuint8m4_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vsll_vv)))
vint8m8_t vsll_vv_i8m8(vint8m8_t, vuint8m8_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vsll_vv_m)))
vint8m8_t vsll_vv_i8m8_m(vbool1_t, vint8m8_t, vint8m8_t, vuint8m8_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vsll_vv)))
vint8mf2_t vsll_vv_i8mf2(vint8mf2_t, vuint8mf2_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vsll_vv_m)))
vint8mf2_t vsll_vv_i8mf2_m(vbool16_t, vint8mf2_t, vint8mf2_t, vuint8mf2_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vsll_vv)))
vint8mf4_t vsll_vv_i8mf4(vint8mf4_t, vuint8mf4_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vsll_vv_m)))
vint8mf4_t vsll_vv_i8mf4_m(vbool32_t, vint8mf4_t, vint8mf4_t, vuint8mf4_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vsll_vv)))
vint8mf8_t vsll_vv_i8mf8(vint8mf8_t, vuint8mf8_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vsll_vv_m)))
vint8mf8_t vsll_vv_i8mf8_m(vbool64_t, vint8mf8_t, vint8mf8_t, vuint8mf8_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vsll_vv)))
vint16m1_t vsll_vv_i16m1(vint16m1_t, vuint16m1_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vsll_vv_m)))
vint16m1_t vsll_vv_i16m1_m(vbool16_t, vint16m1_t, vint16m1_t, vuint16m1_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vsll_vv)))
vint16m2_t vsll_vv_i16m2(vint16m2_t, vuint16m2_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vsll_vv_m)))
vint16m2_t vsll_vv_i16m2_m(vbool8_t, vint16m2_t, vint16m2_t, vuint16m2_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vsll_vv)))
vint16m4_t vsll_vv_i16m4(vint16m4_t, vuint16m4_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vsll_vv_m)))
vint16m4_t vsll_vv_i16m4_m(vbool4_t, vint16m4_t, vint16m4_t, vuint16m4_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vsll_vv)))
vint16m8_t vsll_vv_i16m8(vint16m8_t, vuint16m8_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vsll_vv_m)))
vint16m8_t vsll_vv_i16m8_m(vbool2_t, vint16m8_t, vint16m8_t, vuint16m8_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vsll_vv)))
vint16mf2_t vsll_vv_i16mf2(vint16mf2_t, vuint16mf2_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vsll_vv_m)))
vint16mf2_t vsll_vv_i16mf2_m(vbool32_t, vint16mf2_t, vint16mf2_t, vuint16mf2_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vsll_vv)))
vint16mf4_t vsll_vv_i16mf4(vint16mf4_t, vuint16mf4_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vsll_vv_m)))
vint16mf4_t vsll_vv_i16mf4_m(vbool64_t, vint16mf4_t, vint16mf4_t, vuint16mf4_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vsll_vv)))
vint32m1_t vsll_vv_i32m1(vint32m1_t, vuint32m1_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vsll_vv_m)))
vint32m1_t vsll_vv_i32m1_m(vbool32_t, vint32m1_t, vint32m1_t, vuint32m1_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vsll_vv)))
vint32m2_t vsll_vv_i32m2(vint32m2_t, vuint32m2_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vsll_vv_m)))
vint32m2_t vsll_vv_i32m2_m(vbool16_t, vint32m2_t, vint32m2_t, vuint32m2_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vsll_vv)))
vint32m4_t vsll_vv_i32m4(vint32m4_t, vuint32m4_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vsll_vv_m)))
vint32m4_t vsll_vv_i32m4_m(vbool8_t, vint32m4_t, vint32m4_t, vuint32m4_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vsll_vv)))
vint32m8_t vsll_vv_i32m8(vint32m8_t, vuint32m8_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vsll_vv_m)))
vint32m8_t vsll_vv_i32m8_m(vbool4_t, vint32m8_t, vint32m8_t, vuint32m8_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vsll_vv)))
vint32mf2_t vsll_vv_i32mf2(vint32mf2_t, vuint32mf2_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vsll_vv_m)))
vint32mf2_t vsll_vv_i32mf2_m(vbool64_t, vint32mf2_t, vint32mf2_t, vuint32mf2_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vsll_vx)))
vint8m1_t vsll_vx_i8m1(vint8m1_t, size_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vsll_vx_m)))
vint8m1_t vsll_vx_i8m1_m(vbool8_t, vint8m1_t, vint8m1_t, size_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vsll_vx)))
vint8m2_t vsll_vx_i8m2(vint8m2_t, size_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vsll_vx_m)))
vint8m2_t vsll_vx_i8m2_m(vbool4_t, vint8m2_t, vint8m2_t, size_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vsll_vx)))
vint8m4_t vsll_vx_i8m4(vint8m4_t, size_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vsll_vx_m)))
vint8m4_t vsll_vx_i8m4_m(vbool2_t, vint8m4_t, vint8m4_t, size_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vsll_vx)))
vint8m8_t vsll_vx_i8m8(vint8m8_t, size_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vsll_vx_m)))
vint8m8_t vsll_vx_i8m8_m(vbool1_t, vint8m8_t, vint8m8_t, size_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vsll_vx)))
vint8mf2_t vsll_vx_i8mf2(vint8mf2_t, size_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vsll_vx_m)))
vint8mf2_t vsll_vx_i8mf2_m(vbool16_t, vint8mf2_t, vint8mf2_t, size_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vsll_vx)))
vint8mf4_t vsll_vx_i8mf4(vint8mf4_t, size_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vsll_vx_m)))
vint8mf4_t vsll_vx_i8mf4_m(vbool32_t, vint8mf4_t, vint8mf4_t, size_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vsll_vx)))
vint8mf8_t vsll_vx_i8mf8(vint8mf8_t, size_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vsll_vx_m)))
vint8mf8_t vsll_vx_i8mf8_m(vbool64_t, vint8mf8_t, vint8mf8_t, size_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vsll_vx)))
vint16m1_t vsll_vx_i16m1(vint16m1_t, size_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vsll_vx_m)))
vint16m1_t vsll_vx_i16m1_m(vbool16_t, vint16m1_t, vint16m1_t, size_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vsll_vx)))
vint16m2_t vsll_vx_i16m2(vint16m2_t, size_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vsll_vx_m)))
vint16m2_t vsll_vx_i16m2_m(vbool8_t, vint16m2_t, vint16m2_t, size_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vsll_vx)))
vint16m4_t vsll_vx_i16m4(vint16m4_t, size_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vsll_vx_m)))
vint16m4_t vsll_vx_i16m4_m(vbool4_t, vint16m4_t, vint16m4_t, size_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vsll_vx)))
vint16m8_t vsll_vx_i16m8(vint16m8_t, size_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vsll_vx_m)))
vint16m8_t vsll_vx_i16m8_m(vbool2_t, vint16m8_t, vint16m8_t, size_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vsll_vx)))
vint16mf2_t vsll_vx_i16mf2(vint16mf2_t, size_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vsll_vx_m)))
vint16mf2_t vsll_vx_i16mf2_m(vbool32_t, vint16mf2_t, vint16mf2_t, size_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vsll_vx)))
vint16mf4_t vsll_vx_i16mf4(vint16mf4_t, size_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vsll_vx_m)))
vint16mf4_t vsll_vx_i16mf4_m(vbool64_t, vint16mf4_t, vint16mf4_t, size_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vsll_vx)))
vint32m1_t vsll_vx_i32m1(vint32m1_t, size_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vsll_vx_m)))
vint32m1_t vsll_vx_i32m1_m(vbool32_t, vint32m1_t, vint32m1_t, size_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vsll_vx)))
vint32m2_t vsll_vx_i32m2(vint32m2_t, size_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vsll_vx_m)))
vint32m2_t vsll_vx_i32m2_m(vbool16_t, vint32m2_t, vint32m2_t, size_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vsll_vx)))
vint32m4_t vsll_vx_i32m4(vint32m4_t, size_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vsll_vx_m)))
vint32m4_t vsll_vx_i32m4_m(vbool8_t, vint32m4_t, vint32m4_t, size_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vsll_vx)))
vint32m8_t vsll_vx_i32m8(vint32m8_t, size_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vsll_vx_m)))
vint32m8_t vsll_vx_i32m8_m(vbool4_t, vint32m8_t, vint32m8_t, size_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vsll_vx)))
vint32mf2_t vsll_vx_i32mf2(vint32mf2_t, size_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vsll_vx_m)))
vint32mf2_t vsll_vx_i32mf2_m(vbool64_t, vint32mf2_t, vint32mf2_t, size_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vsll_vv)))
vuint8m1_t vsll_vv_u8m1(vuint8m1_t, vuint8m1_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vsll_vv_m)))
vuint8m1_t vsll_vv_u8m1_m(vbool8_t, vuint8m1_t, vuint8m1_t, vuint8m1_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vsll_vv)))
vuint8m2_t vsll_vv_u8m2(vuint8m2_t, vuint8m2_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vsll_vv_m)))
vuint8m2_t vsll_vv_u8m2_m(vbool4_t, vuint8m2_t, vuint8m2_t, vuint8m2_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vsll_vv)))
vuint8m4_t vsll_vv_u8m4(vuint8m4_t, vuint8m4_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vsll_vv_m)))
vuint8m4_t vsll_vv_u8m4_m(vbool2_t, vuint8m4_t, vuint8m4_t, vuint8m4_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vsll_vv)))
vuint8m8_t vsll_vv_u8m8(vuint8m8_t, vuint8m8_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vsll_vv_m)))
vuint8m8_t vsll_vv_u8m8_m(vbool1_t, vuint8m8_t, vuint8m8_t, vuint8m8_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vsll_vv)))
vuint8mf2_t vsll_vv_u8mf2(vuint8mf2_t, vuint8mf2_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vsll_vv_m)))
vuint8mf2_t vsll_vv_u8mf2_m(vbool16_t, vuint8mf2_t, vuint8mf2_t, vuint8mf2_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vsll_vv)))
vuint8mf4_t vsll_vv_u8mf4(vuint8mf4_t, vuint8mf4_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vsll_vv_m)))
vuint8mf4_t vsll_vv_u8mf4_m(vbool32_t, vuint8mf4_t, vuint8mf4_t, vuint8mf4_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vsll_vv)))
vuint8mf8_t vsll_vv_u8mf8(vuint8mf8_t, vuint8mf8_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vsll_vv_m)))
vuint8mf8_t vsll_vv_u8mf8_m(vbool64_t, vuint8mf8_t, vuint8mf8_t, vuint8mf8_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vsll_vv)))
vuint16m1_t vsll_vv_u16m1(vuint16m1_t, vuint16m1_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vsll_vv_m)))
vuint16m1_t vsll_vv_u16m1_m(vbool16_t, vuint16m1_t, vuint16m1_t, vuint16m1_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vsll_vv)))
vuint16m2_t vsll_vv_u16m2(vuint16m2_t, vuint16m2_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vsll_vv_m)))
vuint16m2_t vsll_vv_u16m2_m(vbool8_t, vuint16m2_t, vuint16m2_t, vuint16m2_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vsll_vv)))
vuint16m4_t vsll_vv_u16m4(vuint16m4_t, vuint16m4_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vsll_vv_m)))
vuint16m4_t vsll_vv_u16m4_m(vbool4_t, vuint16m4_t, vuint16m4_t, vuint16m4_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vsll_vv)))
vuint16m8_t vsll_vv_u16m8(vuint16m8_t, vuint16m8_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vsll_vv_m)))
vuint16m8_t vsll_vv_u16m8_m(vbool2_t, vuint16m8_t, vuint16m8_t, vuint16m8_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vsll_vv)))
vuint16mf2_t vsll_vv_u16mf2(vuint16mf2_t, vuint16mf2_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vsll_vv_m)))
vuint16mf2_t vsll_vv_u16mf2_m(vbool32_t, vuint16mf2_t, vuint16mf2_t, vuint16mf2_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vsll_vv)))
vuint16mf4_t vsll_vv_u16mf4(vuint16mf4_t, vuint16mf4_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vsll_vv_m)))
vuint16mf4_t vsll_vv_u16mf4_m(vbool64_t, vuint16mf4_t, vuint16mf4_t, vuint16mf4_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vsll_vv)))
vuint32m1_t vsll_vv_u32m1(vuint32m1_t, vuint32m1_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vsll_vv_m)))
vuint32m1_t vsll_vv_u32m1_m(vbool32_t, vuint32m1_t, vuint32m1_t, vuint32m1_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vsll_vv)))
vuint32m2_t vsll_vv_u32m2(vuint32m2_t, vuint32m2_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vsll_vv_m)))
vuint32m2_t vsll_vv_u32m2_m(vbool16_t, vuint32m2_t, vuint32m2_t, vuint32m2_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vsll_vv)))
vuint32m4_t vsll_vv_u32m4(vuint32m4_t, vuint32m4_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vsll_vv_m)))
vuint32m4_t vsll_vv_u32m4_m(vbool8_t, vuint32m4_t, vuint32m4_t, vuint32m4_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vsll_vv)))
vuint32m8_t vsll_vv_u32m8(vuint32m8_t, vuint32m8_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vsll_vv_m)))
vuint32m8_t vsll_vv_u32m8_m(vbool4_t, vuint32m8_t, vuint32m8_t, vuint32m8_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vsll_vv)))
vuint32mf2_t vsll_vv_u32mf2(vuint32mf2_t, vuint32mf2_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vsll_vv_m)))
vuint32mf2_t vsll_vv_u32mf2_m(vbool64_t, vuint32mf2_t, vuint32mf2_t, vuint32mf2_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vsll_vx)))
vuint8m1_t vsll_vx_u8m1(vuint8m1_t, size_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vsll_vx_m)))
vuint8m1_t vsll_vx_u8m1_m(vbool8_t, vuint8m1_t, vuint8m1_t, size_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vsll_vx)))
vuint8m2_t vsll_vx_u8m2(vuint8m2_t, size_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vsll_vx_m)))
vuint8m2_t vsll_vx_u8m2_m(vbool4_t, vuint8m2_t, vuint8m2_t, size_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vsll_vx)))
vuint8m4_t vsll_vx_u8m4(vuint8m4_t, size_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vsll_vx_m)))
vuint8m4_t vsll_vx_u8m4_m(vbool2_t, vuint8m4_t, vuint8m4_t, size_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vsll_vx)))
vuint8m8_t vsll_vx_u8m8(vuint8m8_t, size_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vsll_vx_m)))
vuint8m8_t vsll_vx_u8m8_m(vbool1_t, vuint8m8_t, vuint8m8_t, size_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vsll_vx)))
vuint8mf2_t vsll_vx_u8mf2(vuint8mf2_t, size_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vsll_vx_m)))
vuint8mf2_t vsll_vx_u8mf2_m(vbool16_t, vuint8mf2_t, vuint8mf2_t, size_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vsll_vx)))
vuint8mf4_t vsll_vx_u8mf4(vuint8mf4_t, size_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vsll_vx_m)))
vuint8mf4_t vsll_vx_u8mf4_m(vbool32_t, vuint8mf4_t, vuint8mf4_t, size_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vsll_vx)))
vuint8mf8_t vsll_vx_u8mf8(vuint8mf8_t, size_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vsll_vx_m)))
vuint8mf8_t vsll_vx_u8mf8_m(vbool64_t, vuint8mf8_t, vuint8mf8_t, size_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vsll_vx)))
vuint16m1_t vsll_vx_u16m1(vuint16m1_t, size_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vsll_vx_m)))
vuint16m1_t vsll_vx_u16m1_m(vbool16_t, vuint16m1_t, vuint16m1_t, size_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vsll_vx)))
vuint16m2_t vsll_vx_u16m2(vuint16m2_t, size_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vsll_vx_m)))
vuint16m2_t vsll_vx_u16m2_m(vbool8_t, vuint16m2_t, vuint16m2_t, size_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vsll_vx)))
vuint16m4_t vsll_vx_u16m4(vuint16m4_t, size_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vsll_vx_m)))
vuint16m4_t vsll_vx_u16m4_m(vbool4_t, vuint16m4_t, vuint16m4_t, size_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vsll_vx)))
vuint16m8_t vsll_vx_u16m8(vuint16m8_t, size_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vsll_vx_m)))
vuint16m8_t vsll_vx_u16m8_m(vbool2_t, vuint16m8_t, vuint16m8_t, size_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vsll_vx)))
vuint16mf2_t vsll_vx_u16mf2(vuint16mf2_t, size_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vsll_vx_m)))
vuint16mf2_t vsll_vx_u16mf2_m(vbool32_t, vuint16mf2_t, vuint16mf2_t, size_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vsll_vx)))
vuint16mf4_t vsll_vx_u16mf4(vuint16mf4_t, size_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vsll_vx_m)))
vuint16mf4_t vsll_vx_u16mf4_m(vbool64_t, vuint16mf4_t, vuint16mf4_t, size_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vsll_vx)))
vuint32m1_t vsll_vx_u32m1(vuint32m1_t, size_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vsll_vx_m)))
vuint32m1_t vsll_vx_u32m1_m(vbool32_t, vuint32m1_t, vuint32m1_t, size_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vsll_vx)))
vuint32m2_t vsll_vx_u32m2(vuint32m2_t, size_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vsll_vx_m)))
vuint32m2_t vsll_vx_u32m2_m(vbool16_t, vuint32m2_t, vuint32m2_t, size_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vsll_vx)))
vuint32m4_t vsll_vx_u32m4(vuint32m4_t, size_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vsll_vx_m)))
vuint32m4_t vsll_vx_u32m4_m(vbool8_t, vuint32m4_t, vuint32m4_t, size_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vsll_vx)))
vuint32m8_t vsll_vx_u32m8(vuint32m8_t, size_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vsll_vx_m)))
vuint32m8_t vsll_vx_u32m8_m(vbool4_t, vuint32m8_t, vuint32m8_t, size_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vsll_vx)))
vuint32mf2_t vsll_vx_u32mf2(vuint32mf2_t, size_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vsll_vx_m)))
vuint32mf2_t vsll_vx_u32mf2_m(vbool64_t, vuint32mf2_t, vuint32mf2_t, size_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vsrl_vv)))
vuint8m1_t vsrl_vv_u8m1(vuint8m1_t, vuint8m1_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vsrl_vv_m)))
vuint8m1_t vsrl_vv_u8m1_m(vbool8_t, vuint8m1_t, vuint8m1_t, vuint8m1_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vsrl_vv)))
vuint8m2_t vsrl_vv_u8m2(vuint8m2_t, vuint8m2_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vsrl_vv_m)))
vuint8m2_t vsrl_vv_u8m2_m(vbool4_t, vuint8m2_t, vuint8m2_t, vuint8m2_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vsrl_vv)))
vuint8m4_t vsrl_vv_u8m4(vuint8m4_t, vuint8m4_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vsrl_vv_m)))
vuint8m4_t vsrl_vv_u8m4_m(vbool2_t, vuint8m4_t, vuint8m4_t, vuint8m4_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vsrl_vv)))
vuint8m8_t vsrl_vv_u8m8(vuint8m8_t, vuint8m8_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vsrl_vv_m)))
vuint8m8_t vsrl_vv_u8m8_m(vbool1_t, vuint8m8_t, vuint8m8_t, vuint8m8_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vsrl_vv)))
vuint8mf2_t vsrl_vv_u8mf2(vuint8mf2_t, vuint8mf2_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vsrl_vv_m)))
vuint8mf2_t vsrl_vv_u8mf2_m(vbool16_t, vuint8mf2_t, vuint8mf2_t, vuint8mf2_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vsrl_vv)))
vuint8mf4_t vsrl_vv_u8mf4(vuint8mf4_t, vuint8mf4_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vsrl_vv_m)))
vuint8mf4_t vsrl_vv_u8mf4_m(vbool32_t, vuint8mf4_t, vuint8mf4_t, vuint8mf4_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vsrl_vv)))
vuint8mf8_t vsrl_vv_u8mf8(vuint8mf8_t, vuint8mf8_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vsrl_vv_m)))
vuint8mf8_t vsrl_vv_u8mf8_m(vbool64_t, vuint8mf8_t, vuint8mf8_t, vuint8mf8_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vsrl_vv)))
vuint16m1_t vsrl_vv_u16m1(vuint16m1_t, vuint16m1_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vsrl_vv_m)))
vuint16m1_t vsrl_vv_u16m1_m(vbool16_t, vuint16m1_t, vuint16m1_t, vuint16m1_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vsrl_vv)))
vuint16m2_t vsrl_vv_u16m2(vuint16m2_t, vuint16m2_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vsrl_vv_m)))
vuint16m2_t vsrl_vv_u16m2_m(vbool8_t, vuint16m2_t, vuint16m2_t, vuint16m2_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vsrl_vv)))
vuint16m4_t vsrl_vv_u16m4(vuint16m4_t, vuint16m4_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vsrl_vv_m)))
vuint16m4_t vsrl_vv_u16m4_m(vbool4_t, vuint16m4_t, vuint16m4_t, vuint16m4_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vsrl_vv)))
vuint16m8_t vsrl_vv_u16m8(vuint16m8_t, vuint16m8_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vsrl_vv_m)))
vuint16m8_t vsrl_vv_u16m8_m(vbool2_t, vuint16m8_t, vuint16m8_t, vuint16m8_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vsrl_vv)))
vuint16mf2_t vsrl_vv_u16mf2(vuint16mf2_t, vuint16mf2_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vsrl_vv_m)))
vuint16mf2_t vsrl_vv_u16mf2_m(vbool32_t, vuint16mf2_t, vuint16mf2_t, vuint16mf2_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vsrl_vv)))
vuint16mf4_t vsrl_vv_u16mf4(vuint16mf4_t, vuint16mf4_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vsrl_vv_m)))
vuint16mf4_t vsrl_vv_u16mf4_m(vbool64_t, vuint16mf4_t, vuint16mf4_t, vuint16mf4_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vsrl_vv)))
vuint32m1_t vsrl_vv_u32m1(vuint32m1_t, vuint32m1_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vsrl_vv_m)))
vuint32m1_t vsrl_vv_u32m1_m(vbool32_t, vuint32m1_t, vuint32m1_t, vuint32m1_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vsrl_vv)))
vuint32m2_t vsrl_vv_u32m2(vuint32m2_t, vuint32m2_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vsrl_vv_m)))
vuint32m2_t vsrl_vv_u32m2_m(vbool16_t, vuint32m2_t, vuint32m2_t, vuint32m2_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vsrl_vv)))
vuint32m4_t vsrl_vv_u32m4(vuint32m4_t, vuint32m4_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vsrl_vv_m)))
vuint32m4_t vsrl_vv_u32m4_m(vbool8_t, vuint32m4_t, vuint32m4_t, vuint32m4_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vsrl_vv)))
vuint32m8_t vsrl_vv_u32m8(vuint32m8_t, vuint32m8_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vsrl_vv_m)))
vuint32m8_t vsrl_vv_u32m8_m(vbool4_t, vuint32m8_t, vuint32m8_t, vuint32m8_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vsrl_vv)))
vuint32mf2_t vsrl_vv_u32mf2(vuint32mf2_t, vuint32mf2_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vsrl_vv_m)))
vuint32mf2_t vsrl_vv_u32mf2_m(vbool64_t, vuint32mf2_t, vuint32mf2_t, vuint32mf2_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vsrl_vx)))
vuint8m1_t vsrl_vx_u8m1(vuint8m1_t, size_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vsrl_vx_m)))
vuint8m1_t vsrl_vx_u8m1_m(vbool8_t, vuint8m1_t, vuint8m1_t, size_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vsrl_vx)))
vuint8m2_t vsrl_vx_u8m2(vuint8m2_t, size_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vsrl_vx_m)))
vuint8m2_t vsrl_vx_u8m2_m(vbool4_t, vuint8m2_t, vuint8m2_t, size_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vsrl_vx)))
vuint8m4_t vsrl_vx_u8m4(vuint8m4_t, size_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vsrl_vx_m)))
vuint8m4_t vsrl_vx_u8m4_m(vbool2_t, vuint8m4_t, vuint8m4_t, size_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vsrl_vx)))
vuint8m8_t vsrl_vx_u8m8(vuint8m8_t, size_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vsrl_vx_m)))
vuint8m8_t vsrl_vx_u8m8_m(vbool1_t, vuint8m8_t, vuint8m8_t, size_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vsrl_vx)))
vuint8mf2_t vsrl_vx_u8mf2(vuint8mf2_t, size_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vsrl_vx_m)))
vuint8mf2_t vsrl_vx_u8mf2_m(vbool16_t, vuint8mf2_t, vuint8mf2_t, size_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vsrl_vx)))
vuint8mf4_t vsrl_vx_u8mf4(vuint8mf4_t, size_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vsrl_vx_m)))
vuint8mf4_t vsrl_vx_u8mf4_m(vbool32_t, vuint8mf4_t, vuint8mf4_t, size_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vsrl_vx)))
vuint8mf8_t vsrl_vx_u8mf8(vuint8mf8_t, size_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vsrl_vx_m)))
vuint8mf8_t vsrl_vx_u8mf8_m(vbool64_t, vuint8mf8_t, vuint8mf8_t, size_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vsrl_vx)))
vuint16m1_t vsrl_vx_u16m1(vuint16m1_t, size_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vsrl_vx_m)))
vuint16m1_t vsrl_vx_u16m1_m(vbool16_t, vuint16m1_t, vuint16m1_t, size_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vsrl_vx)))
vuint16m2_t vsrl_vx_u16m2(vuint16m2_t, size_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vsrl_vx_m)))
vuint16m2_t vsrl_vx_u16m2_m(vbool8_t, vuint16m2_t, vuint16m2_t, size_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vsrl_vx)))
vuint16m4_t vsrl_vx_u16m4(vuint16m4_t, size_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vsrl_vx_m)))
vuint16m4_t vsrl_vx_u16m4_m(vbool4_t, vuint16m4_t, vuint16m4_t, size_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vsrl_vx)))
vuint16m8_t vsrl_vx_u16m8(vuint16m8_t, size_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vsrl_vx_m)))
vuint16m8_t vsrl_vx_u16m8_m(vbool2_t, vuint16m8_t, vuint16m8_t, size_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vsrl_vx)))
vuint16mf2_t vsrl_vx_u16mf2(vuint16mf2_t, size_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vsrl_vx_m)))
vuint16mf2_t vsrl_vx_u16mf2_m(vbool32_t, vuint16mf2_t, vuint16mf2_t, size_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vsrl_vx)))
vuint16mf4_t vsrl_vx_u16mf4(vuint16mf4_t, size_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vsrl_vx_m)))
vuint16mf4_t vsrl_vx_u16mf4_m(vbool64_t, vuint16mf4_t, vuint16mf4_t, size_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vsrl_vx)))
vuint32m1_t vsrl_vx_u32m1(vuint32m1_t, size_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vsrl_vx_m)))
vuint32m1_t vsrl_vx_u32m1_m(vbool32_t, vuint32m1_t, vuint32m1_t, size_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vsrl_vx)))
vuint32m2_t vsrl_vx_u32m2(vuint32m2_t, size_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vsrl_vx_m)))
vuint32m2_t vsrl_vx_u32m2_m(vbool16_t, vuint32m2_t, vuint32m2_t, size_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vsrl_vx)))
vuint32m4_t vsrl_vx_u32m4(vuint32m4_t, size_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vsrl_vx_m)))
vuint32m4_t vsrl_vx_u32m4_m(vbool8_t, vuint32m4_t, vuint32m4_t, size_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vsrl_vx)))
vuint32m8_t vsrl_vx_u32m8(vuint32m8_t, size_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vsrl_vx_m)))
vuint32m8_t vsrl_vx_u32m8_m(vbool4_t, vuint32m8_t, vuint32m8_t, size_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vsrl_vx)))
vuint32mf2_t vsrl_vx_u32mf2(vuint32mf2_t, size_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vsrl_vx_m)))
vuint32mf2_t vsrl_vx_u32mf2_m(vbool64_t, vuint32mf2_t, vuint32mf2_t, size_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vsra_vv)))
vint8m1_t vsra_vv_i8m1(vint8m1_t, vuint8m1_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vsra_vv_m)))
vint8m1_t vsra_vv_i8m1_m(vbool8_t, vint8m1_t, vint8m1_t, vuint8m1_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vsra_vv)))
vint8m2_t vsra_vv_i8m2(vint8m2_t, vuint8m2_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vsra_vv_m)))
vint8m2_t vsra_vv_i8m2_m(vbool4_t, vint8m2_t, vint8m2_t, vuint8m2_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vsra_vv)))
vint8m4_t vsra_vv_i8m4(vint8m4_t, vuint8m4_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vsra_vv_m)))
vint8m4_t vsra_vv_i8m4_m(vbool2_t, vint8m4_t, vint8m4_t, vuint8m4_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vsra_vv)))
vint8m8_t vsra_vv_i8m8(vint8m8_t, vuint8m8_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vsra_vv_m)))
vint8m8_t vsra_vv_i8m8_m(vbool1_t, vint8m8_t, vint8m8_t, vuint8m8_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vsra_vv)))
vint8mf2_t vsra_vv_i8mf2(vint8mf2_t, vuint8mf2_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vsra_vv_m)))
vint8mf2_t vsra_vv_i8mf2_m(vbool16_t, vint8mf2_t, vint8mf2_t, vuint8mf2_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vsra_vv)))
vint8mf4_t vsra_vv_i8mf4(vint8mf4_t, vuint8mf4_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vsra_vv_m)))
vint8mf4_t vsra_vv_i8mf4_m(vbool32_t, vint8mf4_t, vint8mf4_t, vuint8mf4_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vsra_vv)))
vint8mf8_t vsra_vv_i8mf8(vint8mf8_t, vuint8mf8_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vsra_vv_m)))
vint8mf8_t vsra_vv_i8mf8_m(vbool64_t, vint8mf8_t, vint8mf8_t, vuint8mf8_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vsra_vv)))
vint16m1_t vsra_vv_i16m1(vint16m1_t, vuint16m1_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vsra_vv_m)))
vint16m1_t vsra_vv_i16m1_m(vbool16_t, vint16m1_t, vint16m1_t, vuint16m1_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vsra_vv)))
vint16m2_t vsra_vv_i16m2(vint16m2_t, vuint16m2_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vsra_vv_m)))
vint16m2_t vsra_vv_i16m2_m(vbool8_t, vint16m2_t, vint16m2_t, vuint16m2_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vsra_vv)))
vint16m4_t vsra_vv_i16m4(vint16m4_t, vuint16m4_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vsra_vv_m)))
vint16m4_t vsra_vv_i16m4_m(vbool4_t, vint16m4_t, vint16m4_t, vuint16m4_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vsra_vv)))
vint16m8_t vsra_vv_i16m8(vint16m8_t, vuint16m8_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vsra_vv_m)))
vint16m8_t vsra_vv_i16m8_m(vbool2_t, vint16m8_t, vint16m8_t, vuint16m8_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vsra_vv)))
vint16mf2_t vsra_vv_i16mf2(vint16mf2_t, vuint16mf2_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vsra_vv_m)))
vint16mf2_t vsra_vv_i16mf2_m(vbool32_t, vint16mf2_t, vint16mf2_t, vuint16mf2_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vsra_vv)))
vint16mf4_t vsra_vv_i16mf4(vint16mf4_t, vuint16mf4_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vsra_vv_m)))
vint16mf4_t vsra_vv_i16mf4_m(vbool64_t, vint16mf4_t, vint16mf4_t, vuint16mf4_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vsra_vv)))
vint32m1_t vsra_vv_i32m1(vint32m1_t, vuint32m1_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vsra_vv_m)))
vint32m1_t vsra_vv_i32m1_m(vbool32_t, vint32m1_t, vint32m1_t, vuint32m1_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vsra_vv)))
vint32m2_t vsra_vv_i32m2(vint32m2_t, vuint32m2_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vsra_vv_m)))
vint32m2_t vsra_vv_i32m2_m(vbool16_t, vint32m2_t, vint32m2_t, vuint32m2_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vsra_vv)))
vint32m4_t vsra_vv_i32m4(vint32m4_t, vuint32m4_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vsra_vv_m)))
vint32m4_t vsra_vv_i32m4_m(vbool8_t, vint32m4_t, vint32m4_t, vuint32m4_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vsra_vv)))
vint32m8_t vsra_vv_i32m8(vint32m8_t, vuint32m8_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vsra_vv_m)))
vint32m8_t vsra_vv_i32m8_m(vbool4_t, vint32m8_t, vint32m8_t, vuint32m8_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vsra_vv)))
vint32mf2_t vsra_vv_i32mf2(vint32mf2_t, vuint32mf2_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vsra_vv_m)))
vint32mf2_t vsra_vv_i32mf2_m(vbool64_t, vint32mf2_t, vint32mf2_t, vuint32mf2_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vsra_vx)))
vint8m1_t vsra_vx_i8m1(vint8m1_t, size_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vsra_vx_m)))
vint8m1_t vsra_vx_i8m1_m(vbool8_t, vint8m1_t, vint8m1_t, size_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vsra_vx)))
vint8m2_t vsra_vx_i8m2(vint8m2_t, size_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vsra_vx_m)))
vint8m2_t vsra_vx_i8m2_m(vbool4_t, vint8m2_t, vint8m2_t, size_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vsra_vx)))
vint8m4_t vsra_vx_i8m4(vint8m4_t, size_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vsra_vx_m)))
vint8m4_t vsra_vx_i8m4_m(vbool2_t, vint8m4_t, vint8m4_t, size_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vsra_vx)))
vint8m8_t vsra_vx_i8m8(vint8m8_t, size_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vsra_vx_m)))
vint8m8_t vsra_vx_i8m8_m(vbool1_t, vint8m8_t, vint8m8_t, size_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vsra_vx)))
vint8mf2_t vsra_vx_i8mf2(vint8mf2_t, size_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vsra_vx_m)))
vint8mf2_t vsra_vx_i8mf2_m(vbool16_t, vint8mf2_t, vint8mf2_t, size_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vsra_vx)))
vint8mf4_t vsra_vx_i8mf4(vint8mf4_t, size_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vsra_vx_m)))
vint8mf4_t vsra_vx_i8mf4_m(vbool32_t, vint8mf4_t, vint8mf4_t, size_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vsra_vx)))
vint8mf8_t vsra_vx_i8mf8(vint8mf8_t, size_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vsra_vx_m)))
vint8mf8_t vsra_vx_i8mf8_m(vbool64_t, vint8mf8_t, vint8mf8_t, size_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vsra_vx)))
vint16m1_t vsra_vx_i16m1(vint16m1_t, size_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vsra_vx_m)))
vint16m1_t vsra_vx_i16m1_m(vbool16_t, vint16m1_t, vint16m1_t, size_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vsra_vx)))
vint16m2_t vsra_vx_i16m2(vint16m2_t, size_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vsra_vx_m)))
vint16m2_t vsra_vx_i16m2_m(vbool8_t, vint16m2_t, vint16m2_t, size_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vsra_vx)))
vint16m4_t vsra_vx_i16m4(vint16m4_t, size_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vsra_vx_m)))
vint16m4_t vsra_vx_i16m4_m(vbool4_t, vint16m4_t, vint16m4_t, size_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vsra_vx)))
vint16m8_t vsra_vx_i16m8(vint16m8_t, size_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vsra_vx_m)))
vint16m8_t vsra_vx_i16m8_m(vbool2_t, vint16m8_t, vint16m8_t, size_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vsra_vx)))
vint16mf2_t vsra_vx_i16mf2(vint16mf2_t, size_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vsra_vx_m)))
vint16mf2_t vsra_vx_i16mf2_m(vbool32_t, vint16mf2_t, vint16mf2_t, size_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vsra_vx)))
vint16mf4_t vsra_vx_i16mf4(vint16mf4_t, size_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vsra_vx_m)))
vint16mf4_t vsra_vx_i16mf4_m(vbool64_t, vint16mf4_t, vint16mf4_t, size_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vsra_vx)))
vint32m1_t vsra_vx_i32m1(vint32m1_t, size_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vsra_vx_m)))
vint32m1_t vsra_vx_i32m1_m(vbool32_t, vint32m1_t, vint32m1_t, size_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vsra_vx)))
vint32m2_t vsra_vx_i32m2(vint32m2_t, size_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vsra_vx_m)))
vint32m2_t vsra_vx_i32m2_m(vbool16_t, vint32m2_t, vint32m2_t, size_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vsra_vx)))
vint32m4_t vsra_vx_i32m4(vint32m4_t, size_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vsra_vx_m)))
vint32m4_t vsra_vx_i32m4_m(vbool8_t, vint32m4_t, vint32m4_t, size_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vsra_vx)))
vint32m8_t vsra_vx_i32m8(vint32m8_t, size_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vsra_vx_m)))
vint32m8_t vsra_vx_i32m8_m(vbool4_t, vint32m8_t, vint32m8_t, size_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vsra_vx)))
vint32mf2_t vsra_vx_i32mf2(vint32mf2_t, size_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vsra_vx_m)))
vint32mf2_t vsra_vx_i32mf2_m(vbool64_t, vint32mf2_t, vint32mf2_t, size_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vnsrl_wv)))
vuint8m1_t vnsrl_wv_u8m1(vuint16m2_t, vuint8m1_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vnsrl_wv_m)))
vuint8m1_t vnsrl_wv_u8m1_m(vbool8_t, vuint8m1_t, vuint16m2_t, vuint8m1_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vnsrl_wv)))
vuint8m2_t vnsrl_wv_u8m2(vuint16m4_t, vuint8m2_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vnsrl_wv_m)))
vuint8m2_t vnsrl_wv_u8m2_m(vbool4_t, vuint8m2_t, vuint16m4_t, vuint8m2_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vnsrl_wv)))
vuint8m4_t vnsrl_wv_u8m4(vuint16m8_t, vuint8m4_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vnsrl_wv_m)))
vuint8m4_t vnsrl_wv_u8m4_m(vbool2_t, vuint8m4_t, vuint16m8_t, vuint8m4_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vnsrl_wv)))
vuint8mf2_t vnsrl_wv_u8mf2(vuint16m1_t, vuint8mf2_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vnsrl_wv_m)))
vuint8mf2_t vnsrl_wv_u8mf2_m(vbool16_t, vuint8mf2_t, vuint16m1_t, vuint8mf2_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vnsrl_wv)))
vuint8mf4_t vnsrl_wv_u8mf4(vuint16mf2_t, vuint8mf4_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vnsrl_wv_m)))
vuint8mf4_t vnsrl_wv_u8mf4_m(vbool32_t, vuint8mf4_t, vuint16mf2_t, vuint8mf4_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vnsrl_wv)))
vuint8mf8_t vnsrl_wv_u8mf8(vuint16mf4_t, vuint8mf8_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vnsrl_wv_m)))
vuint8mf8_t vnsrl_wv_u8mf8_m(vbool64_t, vuint8mf8_t, vuint16mf4_t, vuint8mf8_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vnsrl_wv)))
vuint16m1_t vnsrl_wv_u16m1(vuint32m2_t, vuint16m1_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vnsrl_wv_m)))
vuint16m1_t vnsrl_wv_u16m1_m(vbool16_t, vuint16m1_t, vuint32m2_t, vuint16m1_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vnsrl_wv)))
vuint16m2_t vnsrl_wv_u16m2(vuint32m4_t, vuint16m2_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vnsrl_wv_m)))
vuint16m2_t vnsrl_wv_u16m2_m(vbool8_t, vuint16m2_t, vuint32m4_t, vuint16m2_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vnsrl_wv)))
vuint16m4_t vnsrl_wv_u16m4(vuint32m8_t, vuint16m4_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vnsrl_wv_m)))
vuint16m4_t vnsrl_wv_u16m4_m(vbool4_t, vuint16m4_t, vuint32m8_t, vuint16m4_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vnsrl_wv)))
vuint16mf2_t vnsrl_wv_u16mf2(vuint32m1_t, vuint16mf2_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vnsrl_wv_m)))
vuint16mf2_t vnsrl_wv_u16mf2_m(vbool32_t, vuint16mf2_t, vuint32m1_t, vuint16mf2_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vnsrl_wv)))
vuint16mf4_t vnsrl_wv_u16mf4(vuint32mf2_t, vuint16mf4_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vnsrl_wv_m)))
vuint16mf4_t vnsrl_wv_u16mf4_m(vbool64_t, vuint16mf4_t, vuint32mf2_t, vuint16mf4_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vnsrl_wx)))
vuint8m1_t vnsrl_wx_u8m1(vuint16m2_t, size_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vnsrl_wx_m)))
vuint8m1_t vnsrl_wx_u8m1_m(vbool8_t, vuint8m1_t, vuint16m2_t, size_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vnsrl_wx)))
vuint8m2_t vnsrl_wx_u8m2(vuint16m4_t, size_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vnsrl_wx_m)))
vuint8m2_t vnsrl_wx_u8m2_m(vbool4_t, vuint8m2_t, vuint16m4_t, size_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vnsrl_wx)))
vuint8m4_t vnsrl_wx_u8m4(vuint16m8_t, size_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vnsrl_wx_m)))
vuint8m4_t vnsrl_wx_u8m4_m(vbool2_t, vuint8m4_t, vuint16m8_t, size_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vnsrl_wx)))
vuint8mf2_t vnsrl_wx_u8mf2(vuint16m1_t, size_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vnsrl_wx_m)))
vuint8mf2_t vnsrl_wx_u8mf2_m(vbool16_t, vuint8mf2_t, vuint16m1_t, size_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vnsrl_wx)))
vuint8mf4_t vnsrl_wx_u8mf4(vuint16mf2_t, size_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vnsrl_wx_m)))
vuint8mf4_t vnsrl_wx_u8mf4_m(vbool32_t, vuint8mf4_t, vuint16mf2_t, size_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vnsrl_wx)))
vuint8mf8_t vnsrl_wx_u8mf8(vuint16mf4_t, size_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vnsrl_wx_m)))
vuint8mf8_t vnsrl_wx_u8mf8_m(vbool64_t, vuint8mf8_t, vuint16mf4_t, size_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vnsrl_wx)))
vuint16m1_t vnsrl_wx_u16m1(vuint32m2_t, size_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vnsrl_wx_m)))
vuint16m1_t vnsrl_wx_u16m1_m(vbool16_t, vuint16m1_t, vuint32m2_t, size_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vnsrl_wx)))
vuint16m2_t vnsrl_wx_u16m2(vuint32m4_t, size_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vnsrl_wx_m)))
vuint16m2_t vnsrl_wx_u16m2_m(vbool8_t, vuint16m2_t, vuint32m4_t, size_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vnsrl_wx)))
vuint16m4_t vnsrl_wx_u16m4(vuint32m8_t, size_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vnsrl_wx_m)))
vuint16m4_t vnsrl_wx_u16m4_m(vbool4_t, vuint16m4_t, vuint32m8_t, size_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vnsrl_wx)))
vuint16mf2_t vnsrl_wx_u16mf2(vuint32m1_t, size_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vnsrl_wx_m)))
vuint16mf2_t vnsrl_wx_u16mf2_m(vbool32_t, vuint16mf2_t, vuint32m1_t, size_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vnsrl_wx)))
vuint16mf4_t vnsrl_wx_u16mf4(vuint32mf2_t, size_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vnsrl_wx_m)))
vuint16mf4_t vnsrl_wx_u16mf4_m(vbool64_t, vuint16mf4_t, vuint32mf2_t, size_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vnsra_wv)))
vint8m1_t vnsra_wv_i8m1(vint16m2_t, vuint8m1_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vnsra_wv_m)))
vint8m1_t vnsra_wv_i8m1_m(vbool8_t, vint8m1_t, vint16m2_t, vuint8m1_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vnsra_wv)))
vint8m2_t vnsra_wv_i8m2(vint16m4_t, vuint8m2_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vnsra_wv_m)))
vint8m2_t vnsra_wv_i8m2_m(vbool4_t, vint8m2_t, vint16m4_t, vuint8m2_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vnsra_wv)))
vint8m4_t vnsra_wv_i8m4(vint16m8_t, vuint8m4_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vnsra_wv_m)))
vint8m4_t vnsra_wv_i8m4_m(vbool2_t, vint8m4_t, vint16m8_t, vuint8m4_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vnsra_wv)))
vint8mf2_t vnsra_wv_i8mf2(vint16m1_t, vuint8mf2_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vnsra_wv_m)))
vint8mf2_t vnsra_wv_i8mf2_m(vbool16_t, vint8mf2_t, vint16m1_t, vuint8mf2_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vnsra_wv)))
vint8mf4_t vnsra_wv_i8mf4(vint16mf2_t, vuint8mf4_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vnsra_wv_m)))
vint8mf4_t vnsra_wv_i8mf4_m(vbool32_t, vint8mf4_t, vint16mf2_t, vuint8mf4_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vnsra_wv)))
vint8mf8_t vnsra_wv_i8mf8(vint16mf4_t, vuint8mf8_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vnsra_wv_m)))
vint8mf8_t vnsra_wv_i8mf8_m(vbool64_t, vint8mf8_t, vint16mf4_t, vuint8mf8_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vnsra_wv)))
vint16m1_t vnsra_wv_i16m1(vint32m2_t, vuint16m1_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vnsra_wv_m)))
vint16m1_t vnsra_wv_i16m1_m(vbool16_t, vint16m1_t, vint32m2_t, vuint16m1_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vnsra_wv)))
vint16m2_t vnsra_wv_i16m2(vint32m4_t, vuint16m2_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vnsra_wv_m)))
vint16m2_t vnsra_wv_i16m2_m(vbool8_t, vint16m2_t, vint32m4_t, vuint16m2_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vnsra_wv)))
vint16m4_t vnsra_wv_i16m4(vint32m8_t, vuint16m4_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vnsra_wv_m)))
vint16m4_t vnsra_wv_i16m4_m(vbool4_t, vint16m4_t, vint32m8_t, vuint16m4_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vnsra_wv)))
vint16mf2_t vnsra_wv_i16mf2(vint32m1_t, vuint16mf2_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vnsra_wv_m)))
vint16mf2_t vnsra_wv_i16mf2_m(vbool32_t, vint16mf2_t, vint32m1_t, vuint16mf2_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vnsra_wv)))
vint16mf4_t vnsra_wv_i16mf4(vint32mf2_t, vuint16mf4_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vnsra_wv_m)))
vint16mf4_t vnsra_wv_i16mf4_m(vbool64_t, vint16mf4_t, vint32mf2_t, vuint16mf4_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vnsra_wx)))
vint8m1_t vnsra_wx_i8m1(vint16m2_t, size_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vnsra_wx_m)))
vint8m1_t vnsra_wx_i8m1_m(vbool8_t, vint8m1_t, vint16m2_t, size_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vnsra_wx)))
vint8m2_t vnsra_wx_i8m2(vint16m4_t, size_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vnsra_wx_m)))
vint8m2_t vnsra_wx_i8m2_m(vbool4_t, vint8m2_t, vint16m4_t, size_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vnsra_wx)))
vint8m4_t vnsra_wx_i8m4(vint16m8_t, size_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vnsra_wx_m)))
vint8m4_t vnsra_wx_i8m4_m(vbool2_t, vint8m4_t, vint16m8_t, size_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vnsra_wx)))
vint8mf2_t vnsra_wx_i8mf2(vint16m1_t, size_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vnsra_wx_m)))
vint8mf2_t vnsra_wx_i8mf2_m(vbool16_t, vint8mf2_t, vint16m1_t, size_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vnsra_wx)))
vint8mf4_t vnsra_wx_i8mf4(vint16mf2_t, size_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vnsra_wx_m)))
vint8mf4_t vnsra_wx_i8mf4_m(vbool32_t, vint8mf4_t, vint16mf2_t, size_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vnsra_wx)))
vint8mf8_t vnsra_wx_i8mf8(vint16mf4_t, size_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vnsra_wx_m)))
vint8mf8_t vnsra_wx_i8mf8_m(vbool64_t, vint8mf8_t, vint16mf4_t, size_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vnsra_wx)))
vint16m1_t vnsra_wx_i16m1(vint32m2_t, size_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vnsra_wx_m)))
vint16m1_t vnsra_wx_i16m1_m(vbool16_t, vint16m1_t, vint32m2_t, size_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vnsra_wx)))
vint16m2_t vnsra_wx_i16m2(vint32m4_t, size_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vnsra_wx_m)))
vint16m2_t vnsra_wx_i16m2_m(vbool8_t, vint16m2_t, vint32m4_t, size_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vnsra_wx)))
vint16m4_t vnsra_wx_i16m4(vint32m8_t, size_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vnsra_wx_m)))
vint16m4_t vnsra_wx_i16m4_m(vbool4_t, vint16m4_t, vint32m8_t, size_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vnsra_wx)))
vint16mf2_t vnsra_wx_i16mf2(vint32m1_t, size_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vnsra_wx_m)))
vint16mf2_t vnsra_wx_i16mf2_m(vbool32_t, vint16mf2_t, vint32m1_t, size_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vnsra_wx)))
vint16mf4_t vnsra_wx_i16mf4(vint32mf2_t, size_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vnsra_wx_m)))
vint16mf4_t vnsra_wx_i16mf4_m(vbool64_t, vint16mf4_t, vint32mf2_t, size_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vncvt_x_x_w)))
vuint8m1_t vncvt_x_x_w_u8m1(vuint16m2_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vncvt_x_x_w_m)))
vuint8m1_t vncvt_x_x_w_u8m1_m(vbool8_t, vuint8m1_t, vuint16m2_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vncvt_x_x_w)))
vuint8m2_t vncvt_x_x_w_u8m2(vuint16m4_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vncvt_x_x_w_m)))
vuint8m2_t vncvt_x_x_w_u8m2_m(vbool4_t, vuint8m2_t, vuint16m4_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vncvt_x_x_w)))
vuint8m4_t vncvt_x_x_w_u8m4(vuint16m8_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vncvt_x_x_w_m)))
vuint8m4_t vncvt_x_x_w_u8m4_m(vbool2_t, vuint8m4_t, vuint16m8_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vncvt_x_x_w)))
vuint8mf2_t vncvt_x_x_w_u8mf2(vuint16m1_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vncvt_x_x_w_m)))
vuint8mf2_t vncvt_x_x_w_u8mf2_m(vbool16_t, vuint8mf2_t, vuint16m1_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vncvt_x_x_w)))
vuint8mf4_t vncvt_x_x_w_u8mf4(vuint16mf2_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vncvt_x_x_w_m)))
vuint8mf4_t vncvt_x_x_w_u8mf4_m(vbool32_t, vuint8mf4_t, vuint16mf2_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vncvt_x_x_w)))
vuint8mf8_t vncvt_x_x_w_u8mf8(vuint16mf4_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vncvt_x_x_w_m)))
vuint8mf8_t vncvt_x_x_w_u8mf8_m(vbool64_t, vuint8mf8_t, vuint16mf4_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vncvt_x_x_w)))
vuint16m1_t vncvt_x_x_w_u16m1(vuint32m2_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vncvt_x_x_w_m)))
vuint16m1_t vncvt_x_x_w_u16m1_m(vbool16_t, vuint16m1_t, vuint32m2_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vncvt_x_x_w)))
vuint16m2_t vncvt_x_x_w_u16m2(vuint32m4_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vncvt_x_x_w_m)))
vuint16m2_t vncvt_x_x_w_u16m2_m(vbool8_t, vuint16m2_t, vuint32m4_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vncvt_x_x_w)))
vuint16m4_t vncvt_x_x_w_u16m4(vuint32m8_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vncvt_x_x_w_m)))
vuint16m4_t vncvt_x_x_w_u16m4_m(vbool4_t, vuint16m4_t, vuint32m8_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vncvt_x_x_w)))
vuint16mf2_t vncvt_x_x_w_u16mf2(vuint32m1_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vncvt_x_x_w_m)))
vuint16mf2_t vncvt_x_x_w_u16mf2_m(vbool32_t, vuint16mf2_t, vuint32m1_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vncvt_x_x_w)))
vuint16mf4_t vncvt_x_x_w_u16mf4(vuint32mf2_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vncvt_x_x_w_m)))
vuint16mf4_t vncvt_x_x_w_u16mf4_m(vbool64_t, vuint16mf4_t, vuint32mf2_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vmseq_vv)))
vbool8_t vmseq_vv_i8m1_b8(vint8m1_t, vint8m1_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vmseq_vv_m)))
vbool8_t vmseq_vv_i8m1_b8_m(vbool8_t, vbool8_t, vint8m1_t, vint8m1_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vmseq_vv)))
vbool4_t vmseq_vv_i8m2_b4(vint8m2_t, vint8m2_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vmseq_vv_m)))
vbool4_t vmseq_vv_i8m2_b4_m(vbool4_t, vbool4_t, vint8m2_t, vint8m2_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vmseq_vv)))
vbool2_t vmseq_vv_i8m4_b2(vint8m4_t, vint8m4_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vmseq_vv_m)))
vbool2_t vmseq_vv_i8m4_b2_m(vbool2_t, vbool2_t, vint8m4_t, vint8m4_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vmseq_vv)))
vbool1_t vmseq_vv_i8m8_b1(vint8m8_t, vint8m8_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vmseq_vv_m)))
vbool1_t vmseq_vv_i8m8_b1_m(vbool1_t, vbool1_t, vint8m8_t, vint8m8_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vmseq_vv)))
vbool16_t vmseq_vv_i8mf2_b16(vint8mf2_t, vint8mf2_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vmseq_vv_m)))
vbool16_t vmseq_vv_i8mf2_b16_m(vbool16_t, vbool16_t, vint8mf2_t, vint8mf2_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vmseq_vv)))
vbool32_t vmseq_vv_i8mf4_b32(vint8mf4_t, vint8mf4_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vmseq_vv_m)))
vbool32_t vmseq_vv_i8mf4_b32_m(vbool32_t, vbool32_t, vint8mf4_t, vint8mf4_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vmseq_vv)))
vbool64_t vmseq_vv_i8mf8_b64(vint8mf8_t, vint8mf8_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vmseq_vv_m)))
vbool64_t vmseq_vv_i8mf8_b64_m(vbool64_t, vbool64_t, vint8mf8_t, vint8mf8_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vmseq_vv)))
vbool16_t vmseq_vv_i16m1_b16(vint16m1_t, vint16m1_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vmseq_vv_m)))
vbool16_t vmseq_vv_i16m1_b16_m(vbool16_t, vbool16_t, vint16m1_t, vint16m1_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vmseq_vv)))
vbool8_t vmseq_vv_i16m2_b8(vint16m2_t, vint16m2_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vmseq_vv_m)))
vbool8_t vmseq_vv_i16m2_b8_m(vbool8_t, vbool8_t, vint16m2_t, vint16m2_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vmseq_vv)))
vbool4_t vmseq_vv_i16m4_b4(vint16m4_t, vint16m4_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vmseq_vv_m)))
vbool4_t vmseq_vv_i16m4_b4_m(vbool4_t, vbool4_t, vint16m4_t, vint16m4_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vmseq_vv)))
vbool2_t vmseq_vv_i16m8_b2(vint16m8_t, vint16m8_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vmseq_vv_m)))
vbool2_t vmseq_vv_i16m8_b2_m(vbool2_t, vbool2_t, vint16m8_t, vint16m8_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vmseq_vv)))
vbool32_t vmseq_vv_i16mf2_b32(vint16mf2_t, vint16mf2_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vmseq_vv_m)))
vbool32_t vmseq_vv_i16mf2_b32_m(vbool32_t, vbool32_t, vint16mf2_t, vint16mf2_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vmseq_vv)))
vbool64_t vmseq_vv_i16mf4_b64(vint16mf4_t, vint16mf4_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vmseq_vv_m)))
vbool64_t vmseq_vv_i16mf4_b64_m(vbool64_t, vbool64_t, vint16mf4_t, vint16mf4_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vmseq_vv)))
vbool32_t vmseq_vv_i32m1_b32(vint32m1_t, vint32m1_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vmseq_vv_m)))
vbool32_t vmseq_vv_i32m1_b32_m(vbool32_t, vbool32_t, vint32m1_t, vint32m1_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vmseq_vv)))
vbool16_t vmseq_vv_i32m2_b16(vint32m2_t, vint32m2_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vmseq_vv_m)))
vbool16_t vmseq_vv_i32m2_b16_m(vbool16_t, vbool16_t, vint32m2_t, vint32m2_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vmseq_vv)))
vbool8_t vmseq_vv_i32m4_b8(vint32m4_t, vint32m4_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vmseq_vv_m)))
vbool8_t vmseq_vv_i32m4_b8_m(vbool8_t, vbool8_t, vint32m4_t, vint32m4_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vmseq_vv)))
vbool4_t vmseq_vv_i32m8_b4(vint32m8_t, vint32m8_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vmseq_vv_m)))
vbool4_t vmseq_vv_i32m8_b4_m(vbool4_t, vbool4_t, vint32m8_t, vint32m8_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vmseq_vv)))
vbool64_t vmseq_vv_i32mf2_b64(vint32mf2_t, vint32mf2_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vmseq_vv_m)))
vbool64_t vmseq_vv_i32mf2_b64_m(vbool64_t, vbool64_t, vint32mf2_t, vint32mf2_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vmseq_vx)))
vbool8_t vmseq_vx_i8m1_b8(vint8m1_t, int8_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vmseq_vx_m)))
vbool8_t vmseq_vx_i8m1_b8_m(vbool8_t, vbool8_t, vint8m1_t, int8_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vmseq_vx)))
vbool4_t vmseq_vx_i8m2_b4(vint8m2_t, int8_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vmseq_vx_m)))
vbool4_t vmseq_vx_i8m2_b4_m(vbool4_t, vbool4_t, vint8m2_t, int8_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vmseq_vx)))
vbool2_t vmseq_vx_i8m4_b2(vint8m4_t, int8_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vmseq_vx_m)))
vbool2_t vmseq_vx_i8m4_b2_m(vbool2_t, vbool2_t, vint8m4_t, int8_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vmseq_vx)))
vbool1_t vmseq_vx_i8m8_b1(vint8m8_t, int8_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vmseq_vx_m)))
vbool1_t vmseq_vx_i8m8_b1_m(vbool1_t, vbool1_t, vint8m8_t, int8_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vmseq_vx)))
vbool16_t vmseq_vx_i8mf2_b16(vint8mf2_t, int8_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vmseq_vx_m)))
vbool16_t vmseq_vx_i8mf2_b16_m(vbool16_t, vbool16_t, vint8mf2_t, int8_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vmseq_vx)))
vbool32_t vmseq_vx_i8mf4_b32(vint8mf4_t, int8_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vmseq_vx_m)))
vbool32_t vmseq_vx_i8mf4_b32_m(vbool32_t, vbool32_t, vint8mf4_t, int8_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vmseq_vx)))
vbool64_t vmseq_vx_i8mf8_b64(vint8mf8_t, int8_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vmseq_vx_m)))
vbool64_t vmseq_vx_i8mf8_b64_m(vbool64_t, vbool64_t, vint8mf8_t, int8_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vmseq_vx)))
vbool16_t vmseq_vx_i16m1_b16(vint16m1_t, int16_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vmseq_vx_m)))
vbool16_t vmseq_vx_i16m1_b16_m(vbool16_t, vbool16_t, vint16m1_t, int16_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vmseq_vx)))
vbool8_t vmseq_vx_i16m2_b8(vint16m2_t, int16_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vmseq_vx_m)))
vbool8_t vmseq_vx_i16m2_b8_m(vbool8_t, vbool8_t, vint16m2_t, int16_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vmseq_vx)))
vbool4_t vmseq_vx_i16m4_b4(vint16m4_t, int16_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vmseq_vx_m)))
vbool4_t vmseq_vx_i16m4_b4_m(vbool4_t, vbool4_t, vint16m4_t, int16_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vmseq_vx)))
vbool2_t vmseq_vx_i16m8_b2(vint16m8_t, int16_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vmseq_vx_m)))
vbool2_t vmseq_vx_i16m8_b2_m(vbool2_t, vbool2_t, vint16m8_t, int16_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vmseq_vx)))
vbool32_t vmseq_vx_i16mf2_b32(vint16mf2_t, int16_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vmseq_vx_m)))
vbool32_t vmseq_vx_i16mf2_b32_m(vbool32_t, vbool32_t, vint16mf2_t, int16_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vmseq_vx)))
vbool64_t vmseq_vx_i16mf4_b64(vint16mf4_t, int16_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vmseq_vx_m)))
vbool64_t vmseq_vx_i16mf4_b64_m(vbool64_t, vbool64_t, vint16mf4_t, int16_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vmseq_vx)))
vbool32_t vmseq_vx_i32m1_b32(vint32m1_t, int32_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vmseq_vx_m)))
vbool32_t vmseq_vx_i32m1_b32_m(vbool32_t, vbool32_t, vint32m1_t, int32_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vmseq_vx)))
vbool16_t vmseq_vx_i32m2_b16(vint32m2_t, int32_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vmseq_vx_m)))
vbool16_t vmseq_vx_i32m2_b16_m(vbool16_t, vbool16_t, vint32m2_t, int32_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vmseq_vx)))
vbool8_t vmseq_vx_i32m4_b8(vint32m4_t, int32_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vmseq_vx_m)))
vbool8_t vmseq_vx_i32m4_b8_m(vbool8_t, vbool8_t, vint32m4_t, int32_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vmseq_vx)))
vbool4_t vmseq_vx_i32m8_b4(vint32m8_t, int32_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vmseq_vx_m)))
vbool4_t vmseq_vx_i32m8_b4_m(vbool4_t, vbool4_t, vint32m8_t, int32_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vmseq_vx)))
vbool64_t vmseq_vx_i32mf2_b64(vint32mf2_t, int32_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vmseq_vx_m)))
vbool64_t vmseq_vx_i32mf2_b64_m(vbool64_t, vbool64_t, vint32mf2_t, int32_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vmseq_vv)))
vbool8_t vmseq_vv_u8m1_b8(vuint8m1_t, vuint8m1_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vmseq_vv_m)))
vbool8_t vmseq_vv_u8m1_b8_m(vbool8_t, vbool8_t, vuint8m1_t, vuint8m1_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vmseq_vv)))
vbool4_t vmseq_vv_u8m2_b4(vuint8m2_t, vuint8m2_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vmseq_vv_m)))
vbool4_t vmseq_vv_u8m2_b4_m(vbool4_t, vbool4_t, vuint8m2_t, vuint8m2_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vmseq_vv)))
vbool2_t vmseq_vv_u8m4_b2(vuint8m4_t, vuint8m4_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vmseq_vv_m)))
vbool2_t vmseq_vv_u8m4_b2_m(vbool2_t, vbool2_t, vuint8m4_t, vuint8m4_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vmseq_vv)))
vbool1_t vmseq_vv_u8m8_b1(vuint8m8_t, vuint8m8_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vmseq_vv_m)))
vbool1_t vmseq_vv_u8m8_b1_m(vbool1_t, vbool1_t, vuint8m8_t, vuint8m8_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vmseq_vv)))
vbool16_t vmseq_vv_u8mf2_b16(vuint8mf2_t, vuint8mf2_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vmseq_vv_m)))
vbool16_t vmseq_vv_u8mf2_b16_m(vbool16_t, vbool16_t, vuint8mf2_t, vuint8mf2_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vmseq_vv)))
vbool32_t vmseq_vv_u8mf4_b32(vuint8mf4_t, vuint8mf4_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vmseq_vv_m)))
vbool32_t vmseq_vv_u8mf4_b32_m(vbool32_t, vbool32_t, vuint8mf4_t, vuint8mf4_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vmseq_vv)))
vbool64_t vmseq_vv_u8mf8_b64(vuint8mf8_t, vuint8mf8_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vmseq_vv_m)))
vbool64_t vmseq_vv_u8mf8_b64_m(vbool64_t, vbool64_t, vuint8mf8_t, vuint8mf8_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vmseq_vv)))
vbool16_t vmseq_vv_u16m1_b16(vuint16m1_t, vuint16m1_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vmseq_vv_m)))
vbool16_t vmseq_vv_u16m1_b16_m(vbool16_t, vbool16_t, vuint16m1_t, vuint16m1_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vmseq_vv)))
vbool8_t vmseq_vv_u16m2_b8(vuint16m2_t, vuint16m2_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vmseq_vv_m)))
vbool8_t vmseq_vv_u16m2_b8_m(vbool8_t, vbool8_t, vuint16m2_t, vuint16m2_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vmseq_vv)))
vbool4_t vmseq_vv_u16m4_b4(vuint16m4_t, vuint16m4_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vmseq_vv_m)))
vbool4_t vmseq_vv_u16m4_b4_m(vbool4_t, vbool4_t, vuint16m4_t, vuint16m4_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vmseq_vv)))
vbool2_t vmseq_vv_u16m8_b2(vuint16m8_t, vuint16m8_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vmseq_vv_m)))
vbool2_t vmseq_vv_u16m8_b2_m(vbool2_t, vbool2_t, vuint16m8_t, vuint16m8_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vmseq_vv)))
vbool32_t vmseq_vv_u16mf2_b32(vuint16mf2_t, vuint16mf2_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vmseq_vv_m)))
vbool32_t vmseq_vv_u16mf2_b32_m(vbool32_t, vbool32_t, vuint16mf2_t, vuint16mf2_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vmseq_vv)))
vbool64_t vmseq_vv_u16mf4_b64(vuint16mf4_t, vuint16mf4_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vmseq_vv_m)))
vbool64_t vmseq_vv_u16mf4_b64_m(vbool64_t, vbool64_t, vuint16mf4_t, vuint16mf4_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vmseq_vv)))
vbool32_t vmseq_vv_u32m1_b32(vuint32m1_t, vuint32m1_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vmseq_vv_m)))
vbool32_t vmseq_vv_u32m1_b32_m(vbool32_t, vbool32_t, vuint32m1_t, vuint32m1_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vmseq_vv)))
vbool16_t vmseq_vv_u32m2_b16(vuint32m2_t, vuint32m2_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vmseq_vv_m)))
vbool16_t vmseq_vv_u32m2_b16_m(vbool16_t, vbool16_t, vuint32m2_t, vuint32m2_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vmseq_vv)))
vbool8_t vmseq_vv_u32m4_b8(vuint32m4_t, vuint32m4_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vmseq_vv_m)))
vbool8_t vmseq_vv_u32m4_b8_m(vbool8_t, vbool8_t, vuint32m4_t, vuint32m4_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vmseq_vv)))
vbool4_t vmseq_vv_u32m8_b4(vuint32m8_t, vuint32m8_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vmseq_vv_m)))
vbool4_t vmseq_vv_u32m8_b4_m(vbool4_t, vbool4_t, vuint32m8_t, vuint32m8_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vmseq_vv)))
vbool64_t vmseq_vv_u32mf2_b64(vuint32mf2_t, vuint32mf2_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vmseq_vv_m)))
vbool64_t vmseq_vv_u32mf2_b64_m(vbool64_t, vbool64_t, vuint32mf2_t, vuint32mf2_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vmseq_vx)))
vbool8_t vmseq_vx_u8m1_b8(vuint8m1_t, uint8_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vmseq_vx_m)))
vbool8_t vmseq_vx_u8m1_b8_m(vbool8_t, vbool8_t, vuint8m1_t, uint8_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vmseq_vx)))
vbool4_t vmseq_vx_u8m2_b4(vuint8m2_t, uint8_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vmseq_vx_m)))
vbool4_t vmseq_vx_u8m2_b4_m(vbool4_t, vbool4_t, vuint8m2_t, uint8_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vmseq_vx)))
vbool2_t vmseq_vx_u8m4_b2(vuint8m4_t, uint8_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vmseq_vx_m)))
vbool2_t vmseq_vx_u8m4_b2_m(vbool2_t, vbool2_t, vuint8m4_t, uint8_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vmseq_vx)))
vbool1_t vmseq_vx_u8m8_b1(vuint8m8_t, uint8_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vmseq_vx_m)))
vbool1_t vmseq_vx_u8m8_b1_m(vbool1_t, vbool1_t, vuint8m8_t, uint8_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vmseq_vx)))
vbool16_t vmseq_vx_u8mf2_b16(vuint8mf2_t, uint8_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vmseq_vx_m)))
vbool16_t vmseq_vx_u8mf2_b16_m(vbool16_t, vbool16_t, vuint8mf2_t, uint8_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vmseq_vx)))
vbool32_t vmseq_vx_u8mf4_b32(vuint8mf4_t, uint8_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vmseq_vx_m)))
vbool32_t vmseq_vx_u8mf4_b32_m(vbool32_t, vbool32_t, vuint8mf4_t, uint8_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vmseq_vx)))
vbool64_t vmseq_vx_u8mf8_b64(vuint8mf8_t, uint8_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vmseq_vx_m)))
vbool64_t vmseq_vx_u8mf8_b64_m(vbool64_t, vbool64_t, vuint8mf8_t, uint8_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vmseq_vx)))
vbool16_t vmseq_vx_u16m1_b16(vuint16m1_t, uint16_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vmseq_vx_m)))
vbool16_t vmseq_vx_u16m1_b16_m(vbool16_t, vbool16_t, vuint16m1_t, uint16_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vmseq_vx)))
vbool8_t vmseq_vx_u16m2_b8(vuint16m2_t, uint16_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vmseq_vx_m)))
vbool8_t vmseq_vx_u16m2_b8_m(vbool8_t, vbool8_t, vuint16m2_t, uint16_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vmseq_vx)))
vbool4_t vmseq_vx_u16m4_b4(vuint16m4_t, uint16_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vmseq_vx_m)))
vbool4_t vmseq_vx_u16m4_b4_m(vbool4_t, vbool4_t, vuint16m4_t, uint16_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vmseq_vx)))
vbool2_t vmseq_vx_u16m8_b2(vuint16m8_t, uint16_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vmseq_vx_m)))
vbool2_t vmseq_vx_u16m8_b2_m(vbool2_t, vbool2_t, vuint16m8_t, uint16_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vmseq_vx)))
vbool32_t vmseq_vx_u16mf2_b32(vuint16mf2_t, uint16_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vmseq_vx_m)))
vbool32_t vmseq_vx_u16mf2_b32_m(vbool32_t, vbool32_t, vuint16mf2_t, uint16_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vmseq_vx)))
vbool64_t vmseq_vx_u16mf4_b64(vuint16mf4_t, uint16_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vmseq_vx_m)))
vbool64_t vmseq_vx_u16mf4_b64_m(vbool64_t, vbool64_t, vuint16mf4_t, uint16_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vmseq_vx)))
vbool32_t vmseq_vx_u32m1_b32(vuint32m1_t, uint32_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vmseq_vx_m)))
vbool32_t vmseq_vx_u32m1_b32_m(vbool32_t, vbool32_t, vuint32m1_t, uint32_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vmseq_vx)))
vbool16_t vmseq_vx_u32m2_b16(vuint32m2_t, uint32_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vmseq_vx_m)))
vbool16_t vmseq_vx_u32m2_b16_m(vbool16_t, vbool16_t, vuint32m2_t, uint32_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vmseq_vx)))
vbool8_t vmseq_vx_u32m4_b8(vuint32m4_t, uint32_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vmseq_vx_m)))
vbool8_t vmseq_vx_u32m4_b8_m(vbool8_t, vbool8_t, vuint32m4_t, uint32_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vmseq_vx)))
vbool4_t vmseq_vx_u32m8_b4(vuint32m8_t, uint32_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vmseq_vx_m)))
vbool4_t vmseq_vx_u32m8_b4_m(vbool4_t, vbool4_t, vuint32m8_t, uint32_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vmseq_vx)))
vbool64_t vmseq_vx_u32mf2_b64(vuint32mf2_t, uint32_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vmseq_vx_m)))
vbool64_t vmseq_vx_u32mf2_b64_m(vbool64_t, vbool64_t, vuint32mf2_t, uint32_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vmsne_vv)))
vbool8_t vmsne_vv_i8m1_b8(vint8m1_t, vint8m1_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vmsne_vv_m)))
vbool8_t vmsne_vv_i8m1_b8_m(vbool8_t, vbool8_t, vint8m1_t, vint8m1_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vmsne_vv)))
vbool4_t vmsne_vv_i8m2_b4(vint8m2_t, vint8m2_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vmsne_vv_m)))
vbool4_t vmsne_vv_i8m2_b4_m(vbool4_t, vbool4_t, vint8m2_t, vint8m2_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vmsne_vv)))
vbool2_t vmsne_vv_i8m4_b2(vint8m4_t, vint8m4_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vmsne_vv_m)))
vbool2_t vmsne_vv_i8m4_b2_m(vbool2_t, vbool2_t, vint8m4_t, vint8m4_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vmsne_vv)))
vbool1_t vmsne_vv_i8m8_b1(vint8m8_t, vint8m8_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vmsne_vv_m)))
vbool1_t vmsne_vv_i8m8_b1_m(vbool1_t, vbool1_t, vint8m8_t, vint8m8_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vmsne_vv)))
vbool16_t vmsne_vv_i8mf2_b16(vint8mf2_t, vint8mf2_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vmsne_vv_m)))
vbool16_t vmsne_vv_i8mf2_b16_m(vbool16_t, vbool16_t, vint8mf2_t, vint8mf2_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vmsne_vv)))
vbool32_t vmsne_vv_i8mf4_b32(vint8mf4_t, vint8mf4_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vmsne_vv_m)))
vbool32_t vmsne_vv_i8mf4_b32_m(vbool32_t, vbool32_t, vint8mf4_t, vint8mf4_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vmsne_vv)))
vbool64_t vmsne_vv_i8mf8_b64(vint8mf8_t, vint8mf8_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vmsne_vv_m)))
vbool64_t vmsne_vv_i8mf8_b64_m(vbool64_t, vbool64_t, vint8mf8_t, vint8mf8_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vmsne_vv)))
vbool16_t vmsne_vv_i16m1_b16(vint16m1_t, vint16m1_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vmsne_vv_m)))
vbool16_t vmsne_vv_i16m1_b16_m(vbool16_t, vbool16_t, vint16m1_t, vint16m1_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vmsne_vv)))
vbool8_t vmsne_vv_i16m2_b8(vint16m2_t, vint16m2_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vmsne_vv_m)))
vbool8_t vmsne_vv_i16m2_b8_m(vbool8_t, vbool8_t, vint16m2_t, vint16m2_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vmsne_vv)))
vbool4_t vmsne_vv_i16m4_b4(vint16m4_t, vint16m4_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vmsne_vv_m)))
vbool4_t vmsne_vv_i16m4_b4_m(vbool4_t, vbool4_t, vint16m4_t, vint16m4_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vmsne_vv)))
vbool2_t vmsne_vv_i16m8_b2(vint16m8_t, vint16m8_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vmsne_vv_m)))
vbool2_t vmsne_vv_i16m8_b2_m(vbool2_t, vbool2_t, vint16m8_t, vint16m8_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vmsne_vv)))
vbool32_t vmsne_vv_i16mf2_b32(vint16mf2_t, vint16mf2_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vmsne_vv_m)))
vbool32_t vmsne_vv_i16mf2_b32_m(vbool32_t, vbool32_t, vint16mf2_t, vint16mf2_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vmsne_vv)))
vbool64_t vmsne_vv_i16mf4_b64(vint16mf4_t, vint16mf4_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vmsne_vv_m)))
vbool64_t vmsne_vv_i16mf4_b64_m(vbool64_t, vbool64_t, vint16mf4_t, vint16mf4_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vmsne_vv)))
vbool32_t vmsne_vv_i32m1_b32(vint32m1_t, vint32m1_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vmsne_vv_m)))
vbool32_t vmsne_vv_i32m1_b32_m(vbool32_t, vbool32_t, vint32m1_t, vint32m1_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vmsne_vv)))
vbool16_t vmsne_vv_i32m2_b16(vint32m2_t, vint32m2_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vmsne_vv_m)))
vbool16_t vmsne_vv_i32m2_b16_m(vbool16_t, vbool16_t, vint32m2_t, vint32m2_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vmsne_vv)))
vbool8_t vmsne_vv_i32m4_b8(vint32m4_t, vint32m4_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vmsne_vv_m)))
vbool8_t vmsne_vv_i32m4_b8_m(vbool8_t, vbool8_t, vint32m4_t, vint32m4_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vmsne_vv)))
vbool4_t vmsne_vv_i32m8_b4(vint32m8_t, vint32m8_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vmsne_vv_m)))
vbool4_t vmsne_vv_i32m8_b4_m(vbool4_t, vbool4_t, vint32m8_t, vint32m8_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vmsne_vv)))
vbool64_t vmsne_vv_i32mf2_b64(vint32mf2_t, vint32mf2_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vmsne_vv_m)))
vbool64_t vmsne_vv_i32mf2_b64_m(vbool64_t, vbool64_t, vint32mf2_t, vint32mf2_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vmsne_vx)))
vbool8_t vmsne_vx_i8m1_b8(vint8m1_t, int8_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vmsne_vx_m)))
vbool8_t vmsne_vx_i8m1_b8_m(vbool8_t, vbool8_t, vint8m1_t, int8_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vmsne_vx)))
vbool4_t vmsne_vx_i8m2_b4(vint8m2_t, int8_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vmsne_vx_m)))
vbool4_t vmsne_vx_i8m2_b4_m(vbool4_t, vbool4_t, vint8m2_t, int8_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vmsne_vx)))
vbool2_t vmsne_vx_i8m4_b2(vint8m4_t, int8_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vmsne_vx_m)))
vbool2_t vmsne_vx_i8m4_b2_m(vbool2_t, vbool2_t, vint8m4_t, int8_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vmsne_vx)))
vbool1_t vmsne_vx_i8m8_b1(vint8m8_t, int8_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vmsne_vx_m)))
vbool1_t vmsne_vx_i8m8_b1_m(vbool1_t, vbool1_t, vint8m8_t, int8_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vmsne_vx)))
vbool16_t vmsne_vx_i8mf2_b16(vint8mf2_t, int8_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vmsne_vx_m)))
vbool16_t vmsne_vx_i8mf2_b16_m(vbool16_t, vbool16_t, vint8mf2_t, int8_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vmsne_vx)))
vbool32_t vmsne_vx_i8mf4_b32(vint8mf4_t, int8_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vmsne_vx_m)))
vbool32_t vmsne_vx_i8mf4_b32_m(vbool32_t, vbool32_t, vint8mf4_t, int8_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vmsne_vx)))
vbool64_t vmsne_vx_i8mf8_b64(vint8mf8_t, int8_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vmsne_vx_m)))
vbool64_t vmsne_vx_i8mf8_b64_m(vbool64_t, vbool64_t, vint8mf8_t, int8_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vmsne_vx)))
vbool16_t vmsne_vx_i16m1_b16(vint16m1_t, int16_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vmsne_vx_m)))
vbool16_t vmsne_vx_i16m1_b16_m(vbool16_t, vbool16_t, vint16m1_t, int16_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vmsne_vx)))
vbool8_t vmsne_vx_i16m2_b8(vint16m2_t, int16_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vmsne_vx_m)))
vbool8_t vmsne_vx_i16m2_b8_m(vbool8_t, vbool8_t, vint16m2_t, int16_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vmsne_vx)))
vbool4_t vmsne_vx_i16m4_b4(vint16m4_t, int16_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vmsne_vx_m)))
vbool4_t vmsne_vx_i16m4_b4_m(vbool4_t, vbool4_t, vint16m4_t, int16_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vmsne_vx)))
vbool2_t vmsne_vx_i16m8_b2(vint16m8_t, int16_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vmsne_vx_m)))
vbool2_t vmsne_vx_i16m8_b2_m(vbool2_t, vbool2_t, vint16m8_t, int16_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vmsne_vx)))
vbool32_t vmsne_vx_i16mf2_b32(vint16mf2_t, int16_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vmsne_vx_m)))
vbool32_t vmsne_vx_i16mf2_b32_m(vbool32_t, vbool32_t, vint16mf2_t, int16_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vmsne_vx)))
vbool64_t vmsne_vx_i16mf4_b64(vint16mf4_t, int16_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vmsne_vx_m)))
vbool64_t vmsne_vx_i16mf4_b64_m(vbool64_t, vbool64_t, vint16mf4_t, int16_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vmsne_vx)))
vbool32_t vmsne_vx_i32m1_b32(vint32m1_t, int32_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vmsne_vx_m)))
vbool32_t vmsne_vx_i32m1_b32_m(vbool32_t, vbool32_t, vint32m1_t, int32_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vmsne_vx)))
vbool16_t vmsne_vx_i32m2_b16(vint32m2_t, int32_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vmsne_vx_m)))
vbool16_t vmsne_vx_i32m2_b16_m(vbool16_t, vbool16_t, vint32m2_t, int32_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vmsne_vx)))
vbool8_t vmsne_vx_i32m4_b8(vint32m4_t, int32_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vmsne_vx_m)))
vbool8_t vmsne_vx_i32m4_b8_m(vbool8_t, vbool8_t, vint32m4_t, int32_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vmsne_vx)))
vbool4_t vmsne_vx_i32m8_b4(vint32m8_t, int32_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vmsne_vx_m)))
vbool4_t vmsne_vx_i32m8_b4_m(vbool4_t, vbool4_t, vint32m8_t, int32_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vmsne_vx)))
vbool64_t vmsne_vx_i32mf2_b64(vint32mf2_t, int32_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vmsne_vx_m)))
vbool64_t vmsne_vx_i32mf2_b64_m(vbool64_t, vbool64_t, vint32mf2_t, int32_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vmsne_vv)))
vbool8_t vmsne_vv_u8m1_b8(vuint8m1_t, vuint8m1_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vmsne_vv_m)))
vbool8_t vmsne_vv_u8m1_b8_m(vbool8_t, vbool8_t, vuint8m1_t, vuint8m1_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vmsne_vv)))
vbool4_t vmsne_vv_u8m2_b4(vuint8m2_t, vuint8m2_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vmsne_vv_m)))
vbool4_t vmsne_vv_u8m2_b4_m(vbool4_t, vbool4_t, vuint8m2_t, vuint8m2_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vmsne_vv)))
vbool2_t vmsne_vv_u8m4_b2(vuint8m4_t, vuint8m4_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vmsne_vv_m)))
vbool2_t vmsne_vv_u8m4_b2_m(vbool2_t, vbool2_t, vuint8m4_t, vuint8m4_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vmsne_vv)))
vbool1_t vmsne_vv_u8m8_b1(vuint8m8_t, vuint8m8_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vmsne_vv_m)))
vbool1_t vmsne_vv_u8m8_b1_m(vbool1_t, vbool1_t, vuint8m8_t, vuint8m8_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vmsne_vv)))
vbool16_t vmsne_vv_u8mf2_b16(vuint8mf2_t, vuint8mf2_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vmsne_vv_m)))
vbool16_t vmsne_vv_u8mf2_b16_m(vbool16_t, vbool16_t, vuint8mf2_t, vuint8mf2_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vmsne_vv)))
vbool32_t vmsne_vv_u8mf4_b32(vuint8mf4_t, vuint8mf4_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vmsne_vv_m)))
vbool32_t vmsne_vv_u8mf4_b32_m(vbool32_t, vbool32_t, vuint8mf4_t, vuint8mf4_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vmsne_vv)))
vbool64_t vmsne_vv_u8mf8_b64(vuint8mf8_t, vuint8mf8_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vmsne_vv_m)))
vbool64_t vmsne_vv_u8mf8_b64_m(vbool64_t, vbool64_t, vuint8mf8_t, vuint8mf8_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vmsne_vv)))
vbool16_t vmsne_vv_u16m1_b16(vuint16m1_t, vuint16m1_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vmsne_vv_m)))
vbool16_t vmsne_vv_u16m1_b16_m(vbool16_t, vbool16_t, vuint16m1_t, vuint16m1_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vmsne_vv)))
vbool8_t vmsne_vv_u16m2_b8(vuint16m2_t, vuint16m2_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vmsne_vv_m)))
vbool8_t vmsne_vv_u16m2_b8_m(vbool8_t, vbool8_t, vuint16m2_t, vuint16m2_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vmsne_vv)))
vbool4_t vmsne_vv_u16m4_b4(vuint16m4_t, vuint16m4_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vmsne_vv_m)))
vbool4_t vmsne_vv_u16m4_b4_m(vbool4_t, vbool4_t, vuint16m4_t, vuint16m4_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vmsne_vv)))
vbool2_t vmsne_vv_u16m8_b2(vuint16m8_t, vuint16m8_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vmsne_vv_m)))
vbool2_t vmsne_vv_u16m8_b2_m(vbool2_t, vbool2_t, vuint16m8_t, vuint16m8_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vmsne_vv)))
vbool32_t vmsne_vv_u16mf2_b32(vuint16mf2_t, vuint16mf2_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vmsne_vv_m)))
vbool32_t vmsne_vv_u16mf2_b32_m(vbool32_t, vbool32_t, vuint16mf2_t, vuint16mf2_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vmsne_vv)))
vbool64_t vmsne_vv_u16mf4_b64(vuint16mf4_t, vuint16mf4_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vmsne_vv_m)))
vbool64_t vmsne_vv_u16mf4_b64_m(vbool64_t, vbool64_t, vuint16mf4_t, vuint16mf4_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vmsne_vv)))
vbool32_t vmsne_vv_u32m1_b32(vuint32m1_t, vuint32m1_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vmsne_vv_m)))
vbool32_t vmsne_vv_u32m1_b32_m(vbool32_t, vbool32_t, vuint32m1_t, vuint32m1_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vmsne_vv)))
vbool16_t vmsne_vv_u32m2_b16(vuint32m2_t, vuint32m2_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vmsne_vv_m)))
vbool16_t vmsne_vv_u32m2_b16_m(vbool16_t, vbool16_t, vuint32m2_t, vuint32m2_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vmsne_vv)))
vbool8_t vmsne_vv_u32m4_b8(vuint32m4_t, vuint32m4_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vmsne_vv_m)))
vbool8_t vmsne_vv_u32m4_b8_m(vbool8_t, vbool8_t, vuint32m4_t, vuint32m4_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vmsne_vv)))
vbool4_t vmsne_vv_u32m8_b4(vuint32m8_t, vuint32m8_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vmsne_vv_m)))
vbool4_t vmsne_vv_u32m8_b4_m(vbool4_t, vbool4_t, vuint32m8_t, vuint32m8_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vmsne_vv)))
vbool64_t vmsne_vv_u32mf2_b64(vuint32mf2_t, vuint32mf2_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vmsne_vv_m)))
vbool64_t vmsne_vv_u32mf2_b64_m(vbool64_t, vbool64_t, vuint32mf2_t, vuint32mf2_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vmsne_vx)))
vbool8_t vmsne_vx_u8m1_b8(vuint8m1_t, uint8_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vmsne_vx_m)))
vbool8_t vmsne_vx_u8m1_b8_m(vbool8_t, vbool8_t, vuint8m1_t, uint8_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vmsne_vx)))
vbool4_t vmsne_vx_u8m2_b4(vuint8m2_t, uint8_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vmsne_vx_m)))
vbool4_t vmsne_vx_u8m2_b4_m(vbool4_t, vbool4_t, vuint8m2_t, uint8_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vmsne_vx)))
vbool2_t vmsne_vx_u8m4_b2(vuint8m4_t, uint8_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vmsne_vx_m)))
vbool2_t vmsne_vx_u8m4_b2_m(vbool2_t, vbool2_t, vuint8m4_t, uint8_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vmsne_vx)))
vbool1_t vmsne_vx_u8m8_b1(vuint8m8_t, uint8_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vmsne_vx_m)))
vbool1_t vmsne_vx_u8m8_b1_m(vbool1_t, vbool1_t, vuint8m8_t, uint8_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vmsne_vx)))
vbool16_t vmsne_vx_u8mf2_b16(vuint8mf2_t, uint8_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vmsne_vx_m)))
vbool16_t vmsne_vx_u8mf2_b16_m(vbool16_t, vbool16_t, vuint8mf2_t, uint8_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vmsne_vx)))
vbool32_t vmsne_vx_u8mf4_b32(vuint8mf4_t, uint8_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vmsne_vx_m)))
vbool32_t vmsne_vx_u8mf4_b32_m(vbool32_t, vbool32_t, vuint8mf4_t, uint8_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vmsne_vx)))
vbool64_t vmsne_vx_u8mf8_b64(vuint8mf8_t, uint8_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vmsne_vx_m)))
vbool64_t vmsne_vx_u8mf8_b64_m(vbool64_t, vbool64_t, vuint8mf8_t, uint8_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vmsne_vx)))
vbool16_t vmsne_vx_u16m1_b16(vuint16m1_t, uint16_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vmsne_vx_m)))
vbool16_t vmsne_vx_u16m1_b16_m(vbool16_t, vbool16_t, vuint16m1_t, uint16_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vmsne_vx)))
vbool8_t vmsne_vx_u16m2_b8(vuint16m2_t, uint16_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vmsne_vx_m)))
vbool8_t vmsne_vx_u16m2_b8_m(vbool8_t, vbool8_t, vuint16m2_t, uint16_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vmsne_vx)))
vbool4_t vmsne_vx_u16m4_b4(vuint16m4_t, uint16_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vmsne_vx_m)))
vbool4_t vmsne_vx_u16m4_b4_m(vbool4_t, vbool4_t, vuint16m4_t, uint16_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vmsne_vx)))
vbool2_t vmsne_vx_u16m8_b2(vuint16m8_t, uint16_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vmsne_vx_m)))
vbool2_t vmsne_vx_u16m8_b2_m(vbool2_t, vbool2_t, vuint16m8_t, uint16_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vmsne_vx)))
vbool32_t vmsne_vx_u16mf2_b32(vuint16mf2_t, uint16_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vmsne_vx_m)))
vbool32_t vmsne_vx_u16mf2_b32_m(vbool32_t, vbool32_t, vuint16mf2_t, uint16_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vmsne_vx)))
vbool64_t vmsne_vx_u16mf4_b64(vuint16mf4_t, uint16_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vmsne_vx_m)))
vbool64_t vmsne_vx_u16mf4_b64_m(vbool64_t, vbool64_t, vuint16mf4_t, uint16_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vmsne_vx)))
vbool32_t vmsne_vx_u32m1_b32(vuint32m1_t, uint32_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vmsne_vx_m)))
vbool32_t vmsne_vx_u32m1_b32_m(vbool32_t, vbool32_t, vuint32m1_t, uint32_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vmsne_vx)))
vbool16_t vmsne_vx_u32m2_b16(vuint32m2_t, uint32_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vmsne_vx_m)))
vbool16_t vmsne_vx_u32m2_b16_m(vbool16_t, vbool16_t, vuint32m2_t, uint32_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vmsne_vx)))
vbool8_t vmsne_vx_u32m4_b8(vuint32m4_t, uint32_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vmsne_vx_m)))
vbool8_t vmsne_vx_u32m4_b8_m(vbool8_t, vbool8_t, vuint32m4_t, uint32_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vmsne_vx)))
vbool4_t vmsne_vx_u32m8_b4(vuint32m8_t, uint32_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vmsne_vx_m)))
vbool4_t vmsne_vx_u32m8_b4_m(vbool4_t, vbool4_t, vuint32m8_t, uint32_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vmsne_vx)))
vbool64_t vmsne_vx_u32mf2_b64(vuint32mf2_t, uint32_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vmsne_vx_m)))
vbool64_t vmsne_vx_u32mf2_b64_m(vbool64_t, vbool64_t, vuint32mf2_t, uint32_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vmsltu_vv)))
vbool8_t vmsltu_vv_u8m1_b8(vuint8m1_t, vuint8m1_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vmsltu_vv_m)))
vbool8_t vmsltu_vv_u8m1_b8_m(vbool8_t, vbool8_t, vuint8m1_t, vuint8m1_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vmsltu_vv)))
vbool4_t vmsltu_vv_u8m2_b4(vuint8m2_t, vuint8m2_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vmsltu_vv_m)))
vbool4_t vmsltu_vv_u8m2_b4_m(vbool4_t, vbool4_t, vuint8m2_t, vuint8m2_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vmsltu_vv)))
vbool2_t vmsltu_vv_u8m4_b2(vuint8m4_t, vuint8m4_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vmsltu_vv_m)))
vbool2_t vmsltu_vv_u8m4_b2_m(vbool2_t, vbool2_t, vuint8m4_t, vuint8m4_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vmsltu_vv)))
vbool1_t vmsltu_vv_u8m8_b1(vuint8m8_t, vuint8m8_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vmsltu_vv_m)))
vbool1_t vmsltu_vv_u8m8_b1_m(vbool1_t, vbool1_t, vuint8m8_t, vuint8m8_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vmsltu_vv)))
vbool16_t vmsltu_vv_u8mf2_b16(vuint8mf2_t, vuint8mf2_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vmsltu_vv_m)))
vbool16_t vmsltu_vv_u8mf2_b16_m(vbool16_t, vbool16_t, vuint8mf2_t, vuint8mf2_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vmsltu_vv)))
vbool32_t vmsltu_vv_u8mf4_b32(vuint8mf4_t, vuint8mf4_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vmsltu_vv_m)))
vbool32_t vmsltu_vv_u8mf4_b32_m(vbool32_t, vbool32_t, vuint8mf4_t, vuint8mf4_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vmsltu_vv)))
vbool64_t vmsltu_vv_u8mf8_b64(vuint8mf8_t, vuint8mf8_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vmsltu_vv_m)))
vbool64_t vmsltu_vv_u8mf8_b64_m(vbool64_t, vbool64_t, vuint8mf8_t, vuint8mf8_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vmsltu_vv)))
vbool16_t vmsltu_vv_u16m1_b16(vuint16m1_t, vuint16m1_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vmsltu_vv_m)))
vbool16_t vmsltu_vv_u16m1_b16_m(vbool16_t, vbool16_t, vuint16m1_t, vuint16m1_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vmsltu_vv)))
vbool8_t vmsltu_vv_u16m2_b8(vuint16m2_t, vuint16m2_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vmsltu_vv_m)))
vbool8_t vmsltu_vv_u16m2_b8_m(vbool8_t, vbool8_t, vuint16m2_t, vuint16m2_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vmsltu_vv)))
vbool4_t vmsltu_vv_u16m4_b4(vuint16m4_t, vuint16m4_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vmsltu_vv_m)))
vbool4_t vmsltu_vv_u16m4_b4_m(vbool4_t, vbool4_t, vuint16m4_t, vuint16m4_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vmsltu_vv)))
vbool2_t vmsltu_vv_u16m8_b2(vuint16m8_t, vuint16m8_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vmsltu_vv_m)))
vbool2_t vmsltu_vv_u16m8_b2_m(vbool2_t, vbool2_t, vuint16m8_t, vuint16m8_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vmsltu_vv)))
vbool32_t vmsltu_vv_u16mf2_b32(vuint16mf2_t, vuint16mf2_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vmsltu_vv_m)))
vbool32_t vmsltu_vv_u16mf2_b32_m(vbool32_t, vbool32_t, vuint16mf2_t, vuint16mf2_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vmsltu_vv)))
vbool64_t vmsltu_vv_u16mf4_b64(vuint16mf4_t, vuint16mf4_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vmsltu_vv_m)))
vbool64_t vmsltu_vv_u16mf4_b64_m(vbool64_t, vbool64_t, vuint16mf4_t, vuint16mf4_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vmsltu_vv)))
vbool32_t vmsltu_vv_u32m1_b32(vuint32m1_t, vuint32m1_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vmsltu_vv_m)))
vbool32_t vmsltu_vv_u32m1_b32_m(vbool32_t, vbool32_t, vuint32m1_t, vuint32m1_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vmsltu_vv)))
vbool16_t vmsltu_vv_u32m2_b16(vuint32m2_t, vuint32m2_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vmsltu_vv_m)))
vbool16_t vmsltu_vv_u32m2_b16_m(vbool16_t, vbool16_t, vuint32m2_t, vuint32m2_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vmsltu_vv)))
vbool8_t vmsltu_vv_u32m4_b8(vuint32m4_t, vuint32m4_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vmsltu_vv_m)))
vbool8_t vmsltu_vv_u32m4_b8_m(vbool8_t, vbool8_t, vuint32m4_t, vuint32m4_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vmsltu_vv)))
vbool4_t vmsltu_vv_u32m8_b4(vuint32m8_t, vuint32m8_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vmsltu_vv_m)))
vbool4_t vmsltu_vv_u32m8_b4_m(vbool4_t, vbool4_t, vuint32m8_t, vuint32m8_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vmsltu_vv)))
vbool64_t vmsltu_vv_u32mf2_b64(vuint32mf2_t, vuint32mf2_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vmsltu_vv_m)))
vbool64_t vmsltu_vv_u32mf2_b64_m(vbool64_t, vbool64_t, vuint32mf2_t, vuint32mf2_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vmsltu_vx)))
vbool8_t vmsltu_vx_u8m1_b8(vuint8m1_t, uint8_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vmsltu_vx_m)))
vbool8_t vmsltu_vx_u8m1_b8_m(vbool8_t, vbool8_t, vuint8m1_t, uint8_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vmsltu_vx)))
vbool4_t vmsltu_vx_u8m2_b4(vuint8m2_t, uint8_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vmsltu_vx_m)))
vbool4_t vmsltu_vx_u8m2_b4_m(vbool4_t, vbool4_t, vuint8m2_t, uint8_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vmsltu_vx)))
vbool2_t vmsltu_vx_u8m4_b2(vuint8m4_t, uint8_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vmsltu_vx_m)))
vbool2_t vmsltu_vx_u8m4_b2_m(vbool2_t, vbool2_t, vuint8m4_t, uint8_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vmsltu_vx)))
vbool1_t vmsltu_vx_u8m8_b1(vuint8m8_t, uint8_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vmsltu_vx_m)))
vbool1_t vmsltu_vx_u8m8_b1_m(vbool1_t, vbool1_t, vuint8m8_t, uint8_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vmsltu_vx)))
vbool16_t vmsltu_vx_u8mf2_b16(vuint8mf2_t, uint8_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vmsltu_vx_m)))
vbool16_t vmsltu_vx_u8mf2_b16_m(vbool16_t, vbool16_t, vuint8mf2_t, uint8_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vmsltu_vx)))
vbool32_t vmsltu_vx_u8mf4_b32(vuint8mf4_t, uint8_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vmsltu_vx_m)))
vbool32_t vmsltu_vx_u8mf4_b32_m(vbool32_t, vbool32_t, vuint8mf4_t, uint8_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vmsltu_vx)))
vbool64_t vmsltu_vx_u8mf8_b64(vuint8mf8_t, uint8_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vmsltu_vx_m)))
vbool64_t vmsltu_vx_u8mf8_b64_m(vbool64_t, vbool64_t, vuint8mf8_t, uint8_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vmsltu_vx)))
vbool16_t vmsltu_vx_u16m1_b16(vuint16m1_t, uint16_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vmsltu_vx_m)))
vbool16_t vmsltu_vx_u16m1_b16_m(vbool16_t, vbool16_t, vuint16m1_t, uint16_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vmsltu_vx)))
vbool8_t vmsltu_vx_u16m2_b8(vuint16m2_t, uint16_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vmsltu_vx_m)))
vbool8_t vmsltu_vx_u16m2_b8_m(vbool8_t, vbool8_t, vuint16m2_t, uint16_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vmsltu_vx)))
vbool4_t vmsltu_vx_u16m4_b4(vuint16m4_t, uint16_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vmsltu_vx_m)))
vbool4_t vmsltu_vx_u16m4_b4_m(vbool4_t, vbool4_t, vuint16m4_t, uint16_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vmsltu_vx)))
vbool2_t vmsltu_vx_u16m8_b2(vuint16m8_t, uint16_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vmsltu_vx_m)))
vbool2_t vmsltu_vx_u16m8_b2_m(vbool2_t, vbool2_t, vuint16m8_t, uint16_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vmsltu_vx)))
vbool32_t vmsltu_vx_u16mf2_b32(vuint16mf2_t, uint16_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vmsltu_vx_m)))
vbool32_t vmsltu_vx_u16mf2_b32_m(vbool32_t, vbool32_t, vuint16mf2_t, uint16_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vmsltu_vx)))
vbool64_t vmsltu_vx_u16mf4_b64(vuint16mf4_t, uint16_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vmsltu_vx_m)))
vbool64_t vmsltu_vx_u16mf4_b64_m(vbool64_t, vbool64_t, vuint16mf4_t, uint16_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vmsltu_vx)))
vbool32_t vmsltu_vx_u32m1_b32(vuint32m1_t, uint32_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vmsltu_vx_m)))
vbool32_t vmsltu_vx_u32m1_b32_m(vbool32_t, vbool32_t, vuint32m1_t, uint32_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vmsltu_vx)))
vbool16_t vmsltu_vx_u32m2_b16(vuint32m2_t, uint32_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vmsltu_vx_m)))
vbool16_t vmsltu_vx_u32m2_b16_m(vbool16_t, vbool16_t, vuint32m2_t, uint32_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vmsltu_vx)))
vbool8_t vmsltu_vx_u32m4_b8(vuint32m4_t, uint32_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vmsltu_vx_m)))
vbool8_t vmsltu_vx_u32m4_b8_m(vbool8_t, vbool8_t, vuint32m4_t, uint32_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vmsltu_vx)))
vbool4_t vmsltu_vx_u32m8_b4(vuint32m8_t, uint32_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vmsltu_vx_m)))
vbool4_t vmsltu_vx_u32m8_b4_m(vbool4_t, vbool4_t, vuint32m8_t, uint32_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vmsltu_vx)))
vbool64_t vmsltu_vx_u32mf2_b64(vuint32mf2_t, uint32_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vmsltu_vx_m)))
vbool64_t vmsltu_vx_u32mf2_b64_m(vbool64_t, vbool64_t, vuint32mf2_t, uint32_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vmslt_vv)))
vbool8_t vmslt_vv_i8m1_b8(vint8m1_t, vint8m1_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vmslt_vv_m)))
vbool8_t vmslt_vv_i8m1_b8_m(vbool8_t, vbool8_t, vint8m1_t, vint8m1_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vmslt_vv)))
vbool4_t vmslt_vv_i8m2_b4(vint8m2_t, vint8m2_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vmslt_vv_m)))
vbool4_t vmslt_vv_i8m2_b4_m(vbool4_t, vbool4_t, vint8m2_t, vint8m2_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vmslt_vv)))
vbool2_t vmslt_vv_i8m4_b2(vint8m4_t, vint8m4_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vmslt_vv_m)))
vbool2_t vmslt_vv_i8m4_b2_m(vbool2_t, vbool2_t, vint8m4_t, vint8m4_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vmslt_vv)))
vbool1_t vmslt_vv_i8m8_b1(vint8m8_t, vint8m8_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vmslt_vv_m)))
vbool1_t vmslt_vv_i8m8_b1_m(vbool1_t, vbool1_t, vint8m8_t, vint8m8_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vmslt_vv)))
vbool16_t vmslt_vv_i8mf2_b16(vint8mf2_t, vint8mf2_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vmslt_vv_m)))
vbool16_t vmslt_vv_i8mf2_b16_m(vbool16_t, vbool16_t, vint8mf2_t, vint8mf2_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vmslt_vv)))
vbool32_t vmslt_vv_i8mf4_b32(vint8mf4_t, vint8mf4_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vmslt_vv_m)))
vbool32_t vmslt_vv_i8mf4_b32_m(vbool32_t, vbool32_t, vint8mf4_t, vint8mf4_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vmslt_vv)))
vbool64_t vmslt_vv_i8mf8_b64(vint8mf8_t, vint8mf8_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vmslt_vv_m)))
vbool64_t vmslt_vv_i8mf8_b64_m(vbool64_t, vbool64_t, vint8mf8_t, vint8mf8_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vmslt_vv)))
vbool16_t vmslt_vv_i16m1_b16(vint16m1_t, vint16m1_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vmslt_vv_m)))
vbool16_t vmslt_vv_i16m1_b16_m(vbool16_t, vbool16_t, vint16m1_t, vint16m1_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vmslt_vv)))
vbool8_t vmslt_vv_i16m2_b8(vint16m2_t, vint16m2_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vmslt_vv_m)))
vbool8_t vmslt_vv_i16m2_b8_m(vbool8_t, vbool8_t, vint16m2_t, vint16m2_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vmslt_vv)))
vbool4_t vmslt_vv_i16m4_b4(vint16m4_t, vint16m4_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vmslt_vv_m)))
vbool4_t vmslt_vv_i16m4_b4_m(vbool4_t, vbool4_t, vint16m4_t, vint16m4_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vmslt_vv)))
vbool2_t vmslt_vv_i16m8_b2(vint16m8_t, vint16m8_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vmslt_vv_m)))
vbool2_t vmslt_vv_i16m8_b2_m(vbool2_t, vbool2_t, vint16m8_t, vint16m8_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vmslt_vv)))
vbool32_t vmslt_vv_i16mf2_b32(vint16mf2_t, vint16mf2_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vmslt_vv_m)))
vbool32_t vmslt_vv_i16mf2_b32_m(vbool32_t, vbool32_t, vint16mf2_t, vint16mf2_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vmslt_vv)))
vbool64_t vmslt_vv_i16mf4_b64(vint16mf4_t, vint16mf4_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vmslt_vv_m)))
vbool64_t vmslt_vv_i16mf4_b64_m(vbool64_t, vbool64_t, vint16mf4_t, vint16mf4_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vmslt_vv)))
vbool32_t vmslt_vv_i32m1_b32(vint32m1_t, vint32m1_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vmslt_vv_m)))
vbool32_t vmslt_vv_i32m1_b32_m(vbool32_t, vbool32_t, vint32m1_t, vint32m1_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vmslt_vv)))
vbool16_t vmslt_vv_i32m2_b16(vint32m2_t, vint32m2_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vmslt_vv_m)))
vbool16_t vmslt_vv_i32m2_b16_m(vbool16_t, vbool16_t, vint32m2_t, vint32m2_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vmslt_vv)))
vbool8_t vmslt_vv_i32m4_b8(vint32m4_t, vint32m4_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vmslt_vv_m)))
vbool8_t vmslt_vv_i32m4_b8_m(vbool8_t, vbool8_t, vint32m4_t, vint32m4_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vmslt_vv)))
vbool4_t vmslt_vv_i32m8_b4(vint32m8_t, vint32m8_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vmslt_vv_m)))
vbool4_t vmslt_vv_i32m8_b4_m(vbool4_t, vbool4_t, vint32m8_t, vint32m8_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vmslt_vv)))
vbool64_t vmslt_vv_i32mf2_b64(vint32mf2_t, vint32mf2_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vmslt_vv_m)))
vbool64_t vmslt_vv_i32mf2_b64_m(vbool64_t, vbool64_t, vint32mf2_t, vint32mf2_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vmslt_vx)))
vbool8_t vmslt_vx_i8m1_b8(vint8m1_t, int8_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vmslt_vx_m)))
vbool8_t vmslt_vx_i8m1_b8_m(vbool8_t, vbool8_t, vint8m1_t, int8_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vmslt_vx)))
vbool4_t vmslt_vx_i8m2_b4(vint8m2_t, int8_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vmslt_vx_m)))
vbool4_t vmslt_vx_i8m2_b4_m(vbool4_t, vbool4_t, vint8m2_t, int8_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vmslt_vx)))
vbool2_t vmslt_vx_i8m4_b2(vint8m4_t, int8_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vmslt_vx_m)))
vbool2_t vmslt_vx_i8m4_b2_m(vbool2_t, vbool2_t, vint8m4_t, int8_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vmslt_vx)))
vbool1_t vmslt_vx_i8m8_b1(vint8m8_t, int8_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vmslt_vx_m)))
vbool1_t vmslt_vx_i8m8_b1_m(vbool1_t, vbool1_t, vint8m8_t, int8_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vmslt_vx)))
vbool16_t vmslt_vx_i8mf2_b16(vint8mf2_t, int8_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vmslt_vx_m)))
vbool16_t vmslt_vx_i8mf2_b16_m(vbool16_t, vbool16_t, vint8mf2_t, int8_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vmslt_vx)))
vbool32_t vmslt_vx_i8mf4_b32(vint8mf4_t, int8_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vmslt_vx_m)))
vbool32_t vmslt_vx_i8mf4_b32_m(vbool32_t, vbool32_t, vint8mf4_t, int8_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vmslt_vx)))
vbool64_t vmslt_vx_i8mf8_b64(vint8mf8_t, int8_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vmslt_vx_m)))
vbool64_t vmslt_vx_i8mf8_b64_m(vbool64_t, vbool64_t, vint8mf8_t, int8_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vmslt_vx)))
vbool16_t vmslt_vx_i16m1_b16(vint16m1_t, int16_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vmslt_vx_m)))
vbool16_t vmslt_vx_i16m1_b16_m(vbool16_t, vbool16_t, vint16m1_t, int16_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vmslt_vx)))
vbool8_t vmslt_vx_i16m2_b8(vint16m2_t, int16_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vmslt_vx_m)))
vbool8_t vmslt_vx_i16m2_b8_m(vbool8_t, vbool8_t, vint16m2_t, int16_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vmslt_vx)))
vbool4_t vmslt_vx_i16m4_b4(vint16m4_t, int16_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vmslt_vx_m)))
vbool4_t vmslt_vx_i16m4_b4_m(vbool4_t, vbool4_t, vint16m4_t, int16_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vmslt_vx)))
vbool2_t vmslt_vx_i16m8_b2(vint16m8_t, int16_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vmslt_vx_m)))
vbool2_t vmslt_vx_i16m8_b2_m(vbool2_t, vbool2_t, vint16m8_t, int16_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vmslt_vx)))
vbool32_t vmslt_vx_i16mf2_b32(vint16mf2_t, int16_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vmslt_vx_m)))
vbool32_t vmslt_vx_i16mf2_b32_m(vbool32_t, vbool32_t, vint16mf2_t, int16_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vmslt_vx)))
vbool64_t vmslt_vx_i16mf4_b64(vint16mf4_t, int16_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vmslt_vx_m)))
vbool64_t vmslt_vx_i16mf4_b64_m(vbool64_t, vbool64_t, vint16mf4_t, int16_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vmslt_vx)))
vbool32_t vmslt_vx_i32m1_b32(vint32m1_t, int32_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vmslt_vx_m)))
vbool32_t vmslt_vx_i32m1_b32_m(vbool32_t, vbool32_t, vint32m1_t, int32_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vmslt_vx)))
vbool16_t vmslt_vx_i32m2_b16(vint32m2_t, int32_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vmslt_vx_m)))
vbool16_t vmslt_vx_i32m2_b16_m(vbool16_t, vbool16_t, vint32m2_t, int32_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vmslt_vx)))
vbool8_t vmslt_vx_i32m4_b8(vint32m4_t, int32_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vmslt_vx_m)))
vbool8_t vmslt_vx_i32m4_b8_m(vbool8_t, vbool8_t, vint32m4_t, int32_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vmslt_vx)))
vbool4_t vmslt_vx_i32m8_b4(vint32m8_t, int32_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vmslt_vx_m)))
vbool4_t vmslt_vx_i32m8_b4_m(vbool4_t, vbool4_t, vint32m8_t, int32_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vmslt_vx)))
vbool64_t vmslt_vx_i32mf2_b64(vint32mf2_t, int32_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vmslt_vx_m)))
vbool64_t vmslt_vx_i32mf2_b64_m(vbool64_t, vbool64_t, vint32mf2_t, int32_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vmsleu_vv)))
vbool8_t vmsleu_vv_u8m1_b8(vuint8m1_t, vuint8m1_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vmsleu_vv_m)))
vbool8_t vmsleu_vv_u8m1_b8_m(vbool8_t, vbool8_t, vuint8m1_t, vuint8m1_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vmsleu_vv)))
vbool4_t vmsleu_vv_u8m2_b4(vuint8m2_t, vuint8m2_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vmsleu_vv_m)))
vbool4_t vmsleu_vv_u8m2_b4_m(vbool4_t, vbool4_t, vuint8m2_t, vuint8m2_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vmsleu_vv)))
vbool2_t vmsleu_vv_u8m4_b2(vuint8m4_t, vuint8m4_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vmsleu_vv_m)))
vbool2_t vmsleu_vv_u8m4_b2_m(vbool2_t, vbool2_t, vuint8m4_t, vuint8m4_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vmsleu_vv)))
vbool1_t vmsleu_vv_u8m8_b1(vuint8m8_t, vuint8m8_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vmsleu_vv_m)))
vbool1_t vmsleu_vv_u8m8_b1_m(vbool1_t, vbool1_t, vuint8m8_t, vuint8m8_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vmsleu_vv)))
vbool16_t vmsleu_vv_u8mf2_b16(vuint8mf2_t, vuint8mf2_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vmsleu_vv_m)))
vbool16_t vmsleu_vv_u8mf2_b16_m(vbool16_t, vbool16_t, vuint8mf2_t, vuint8mf2_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vmsleu_vv)))
vbool32_t vmsleu_vv_u8mf4_b32(vuint8mf4_t, vuint8mf4_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vmsleu_vv_m)))
vbool32_t vmsleu_vv_u8mf4_b32_m(vbool32_t, vbool32_t, vuint8mf4_t, vuint8mf4_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vmsleu_vv)))
vbool64_t vmsleu_vv_u8mf8_b64(vuint8mf8_t, vuint8mf8_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vmsleu_vv_m)))
vbool64_t vmsleu_vv_u8mf8_b64_m(vbool64_t, vbool64_t, vuint8mf8_t, vuint8mf8_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vmsleu_vv)))
vbool16_t vmsleu_vv_u16m1_b16(vuint16m1_t, vuint16m1_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vmsleu_vv_m)))
vbool16_t vmsleu_vv_u16m1_b16_m(vbool16_t, vbool16_t, vuint16m1_t, vuint16m1_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vmsleu_vv)))
vbool8_t vmsleu_vv_u16m2_b8(vuint16m2_t, vuint16m2_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vmsleu_vv_m)))
vbool8_t vmsleu_vv_u16m2_b8_m(vbool8_t, vbool8_t, vuint16m2_t, vuint16m2_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vmsleu_vv)))
vbool4_t vmsleu_vv_u16m4_b4(vuint16m4_t, vuint16m4_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vmsleu_vv_m)))
vbool4_t vmsleu_vv_u16m4_b4_m(vbool4_t, vbool4_t, vuint16m4_t, vuint16m4_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vmsleu_vv)))
vbool2_t vmsleu_vv_u16m8_b2(vuint16m8_t, vuint16m8_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vmsleu_vv_m)))
vbool2_t vmsleu_vv_u16m8_b2_m(vbool2_t, vbool2_t, vuint16m8_t, vuint16m8_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vmsleu_vv)))
vbool32_t vmsleu_vv_u16mf2_b32(vuint16mf2_t, vuint16mf2_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vmsleu_vv_m)))
vbool32_t vmsleu_vv_u16mf2_b32_m(vbool32_t, vbool32_t, vuint16mf2_t, vuint16mf2_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vmsleu_vv)))
vbool64_t vmsleu_vv_u16mf4_b64(vuint16mf4_t, vuint16mf4_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vmsleu_vv_m)))
vbool64_t vmsleu_vv_u16mf4_b64_m(vbool64_t, vbool64_t, vuint16mf4_t, vuint16mf4_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vmsleu_vv)))
vbool32_t vmsleu_vv_u32m1_b32(vuint32m1_t, vuint32m1_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vmsleu_vv_m)))
vbool32_t vmsleu_vv_u32m1_b32_m(vbool32_t, vbool32_t, vuint32m1_t, vuint32m1_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vmsleu_vv)))
vbool16_t vmsleu_vv_u32m2_b16(vuint32m2_t, vuint32m2_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vmsleu_vv_m)))
vbool16_t vmsleu_vv_u32m2_b16_m(vbool16_t, vbool16_t, vuint32m2_t, vuint32m2_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vmsleu_vv)))
vbool8_t vmsleu_vv_u32m4_b8(vuint32m4_t, vuint32m4_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vmsleu_vv_m)))
vbool8_t vmsleu_vv_u32m4_b8_m(vbool8_t, vbool8_t, vuint32m4_t, vuint32m4_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vmsleu_vv)))
vbool4_t vmsleu_vv_u32m8_b4(vuint32m8_t, vuint32m8_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vmsleu_vv_m)))
vbool4_t vmsleu_vv_u32m8_b4_m(vbool4_t, vbool4_t, vuint32m8_t, vuint32m8_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vmsleu_vv)))
vbool64_t vmsleu_vv_u32mf2_b64(vuint32mf2_t, vuint32mf2_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vmsleu_vv_m)))
vbool64_t vmsleu_vv_u32mf2_b64_m(vbool64_t, vbool64_t, vuint32mf2_t, vuint32mf2_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vmsleu_vx)))
vbool8_t vmsleu_vx_u8m1_b8(vuint8m1_t, uint8_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vmsleu_vx_m)))
vbool8_t vmsleu_vx_u8m1_b8_m(vbool8_t, vbool8_t, vuint8m1_t, uint8_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vmsleu_vx)))
vbool4_t vmsleu_vx_u8m2_b4(vuint8m2_t, uint8_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vmsleu_vx_m)))
vbool4_t vmsleu_vx_u8m2_b4_m(vbool4_t, vbool4_t, vuint8m2_t, uint8_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vmsleu_vx)))
vbool2_t vmsleu_vx_u8m4_b2(vuint8m4_t, uint8_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vmsleu_vx_m)))
vbool2_t vmsleu_vx_u8m4_b2_m(vbool2_t, vbool2_t, vuint8m4_t, uint8_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vmsleu_vx)))
vbool1_t vmsleu_vx_u8m8_b1(vuint8m8_t, uint8_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vmsleu_vx_m)))
vbool1_t vmsleu_vx_u8m8_b1_m(vbool1_t, vbool1_t, vuint8m8_t, uint8_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vmsleu_vx)))
vbool16_t vmsleu_vx_u8mf2_b16(vuint8mf2_t, uint8_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vmsleu_vx_m)))
vbool16_t vmsleu_vx_u8mf2_b16_m(vbool16_t, vbool16_t, vuint8mf2_t, uint8_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vmsleu_vx)))
vbool32_t vmsleu_vx_u8mf4_b32(vuint8mf4_t, uint8_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vmsleu_vx_m)))
vbool32_t vmsleu_vx_u8mf4_b32_m(vbool32_t, vbool32_t, vuint8mf4_t, uint8_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vmsleu_vx)))
vbool64_t vmsleu_vx_u8mf8_b64(vuint8mf8_t, uint8_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vmsleu_vx_m)))
vbool64_t vmsleu_vx_u8mf8_b64_m(vbool64_t, vbool64_t, vuint8mf8_t, uint8_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vmsleu_vx)))
vbool16_t vmsleu_vx_u16m1_b16(vuint16m1_t, uint16_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vmsleu_vx_m)))
vbool16_t vmsleu_vx_u16m1_b16_m(vbool16_t, vbool16_t, vuint16m1_t, uint16_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vmsleu_vx)))
vbool8_t vmsleu_vx_u16m2_b8(vuint16m2_t, uint16_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vmsleu_vx_m)))
vbool8_t vmsleu_vx_u16m2_b8_m(vbool8_t, vbool8_t, vuint16m2_t, uint16_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vmsleu_vx)))
vbool4_t vmsleu_vx_u16m4_b4(vuint16m4_t, uint16_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vmsleu_vx_m)))
vbool4_t vmsleu_vx_u16m4_b4_m(vbool4_t, vbool4_t, vuint16m4_t, uint16_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vmsleu_vx)))
vbool2_t vmsleu_vx_u16m8_b2(vuint16m8_t, uint16_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vmsleu_vx_m)))
vbool2_t vmsleu_vx_u16m8_b2_m(vbool2_t, vbool2_t, vuint16m8_t, uint16_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vmsleu_vx)))
vbool32_t vmsleu_vx_u16mf2_b32(vuint16mf2_t, uint16_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vmsleu_vx_m)))
vbool32_t vmsleu_vx_u16mf2_b32_m(vbool32_t, vbool32_t, vuint16mf2_t, uint16_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vmsleu_vx)))
vbool64_t vmsleu_vx_u16mf4_b64(vuint16mf4_t, uint16_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vmsleu_vx_m)))
vbool64_t vmsleu_vx_u16mf4_b64_m(vbool64_t, vbool64_t, vuint16mf4_t, uint16_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vmsleu_vx)))
vbool32_t vmsleu_vx_u32m1_b32(vuint32m1_t, uint32_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vmsleu_vx_m)))
vbool32_t vmsleu_vx_u32m1_b32_m(vbool32_t, vbool32_t, vuint32m1_t, uint32_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vmsleu_vx)))
vbool16_t vmsleu_vx_u32m2_b16(vuint32m2_t, uint32_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vmsleu_vx_m)))
vbool16_t vmsleu_vx_u32m2_b16_m(vbool16_t, vbool16_t, vuint32m2_t, uint32_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vmsleu_vx)))
vbool8_t vmsleu_vx_u32m4_b8(vuint32m4_t, uint32_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vmsleu_vx_m)))
vbool8_t vmsleu_vx_u32m4_b8_m(vbool8_t, vbool8_t, vuint32m4_t, uint32_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vmsleu_vx)))
vbool4_t vmsleu_vx_u32m8_b4(vuint32m8_t, uint32_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vmsleu_vx_m)))
vbool4_t vmsleu_vx_u32m8_b4_m(vbool4_t, vbool4_t, vuint32m8_t, uint32_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vmsleu_vx)))
vbool64_t vmsleu_vx_u32mf2_b64(vuint32mf2_t, uint32_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vmsleu_vx_m)))
vbool64_t vmsleu_vx_u32mf2_b64_m(vbool64_t, vbool64_t, vuint32mf2_t, uint32_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vmsle_vv)))
vbool8_t vmsle_vv_i8m1_b8(vint8m1_t, vint8m1_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vmsle_vv_m)))
vbool8_t vmsle_vv_i8m1_b8_m(vbool8_t, vbool8_t, vint8m1_t, vint8m1_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vmsle_vv)))
vbool4_t vmsle_vv_i8m2_b4(vint8m2_t, vint8m2_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vmsle_vv_m)))
vbool4_t vmsle_vv_i8m2_b4_m(vbool4_t, vbool4_t, vint8m2_t, vint8m2_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vmsle_vv)))
vbool2_t vmsle_vv_i8m4_b2(vint8m4_t, vint8m4_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vmsle_vv_m)))
vbool2_t vmsle_vv_i8m4_b2_m(vbool2_t, vbool2_t, vint8m4_t, vint8m4_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vmsle_vv)))
vbool1_t vmsle_vv_i8m8_b1(vint8m8_t, vint8m8_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vmsle_vv_m)))
vbool1_t vmsle_vv_i8m8_b1_m(vbool1_t, vbool1_t, vint8m8_t, vint8m8_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vmsle_vv)))
vbool16_t vmsle_vv_i8mf2_b16(vint8mf2_t, vint8mf2_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vmsle_vv_m)))
vbool16_t vmsle_vv_i8mf2_b16_m(vbool16_t, vbool16_t, vint8mf2_t, vint8mf2_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vmsle_vv)))
vbool32_t vmsle_vv_i8mf4_b32(vint8mf4_t, vint8mf4_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vmsle_vv_m)))
vbool32_t vmsle_vv_i8mf4_b32_m(vbool32_t, vbool32_t, vint8mf4_t, vint8mf4_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vmsle_vv)))
vbool64_t vmsle_vv_i8mf8_b64(vint8mf8_t, vint8mf8_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vmsle_vv_m)))
vbool64_t vmsle_vv_i8mf8_b64_m(vbool64_t, vbool64_t, vint8mf8_t, vint8mf8_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vmsle_vv)))
vbool16_t vmsle_vv_i16m1_b16(vint16m1_t, vint16m1_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vmsle_vv_m)))
vbool16_t vmsle_vv_i16m1_b16_m(vbool16_t, vbool16_t, vint16m1_t, vint16m1_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vmsle_vv)))
vbool8_t vmsle_vv_i16m2_b8(vint16m2_t, vint16m2_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vmsle_vv_m)))
vbool8_t vmsle_vv_i16m2_b8_m(vbool8_t, vbool8_t, vint16m2_t, vint16m2_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vmsle_vv)))
vbool4_t vmsle_vv_i16m4_b4(vint16m4_t, vint16m4_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vmsle_vv_m)))
vbool4_t vmsle_vv_i16m4_b4_m(vbool4_t, vbool4_t, vint16m4_t, vint16m4_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vmsle_vv)))
vbool2_t vmsle_vv_i16m8_b2(vint16m8_t, vint16m8_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vmsle_vv_m)))
vbool2_t vmsle_vv_i16m8_b2_m(vbool2_t, vbool2_t, vint16m8_t, vint16m8_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vmsle_vv)))
vbool32_t vmsle_vv_i16mf2_b32(vint16mf2_t, vint16mf2_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vmsle_vv_m)))
vbool32_t vmsle_vv_i16mf2_b32_m(vbool32_t, vbool32_t, vint16mf2_t, vint16mf2_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vmsle_vv)))
vbool64_t vmsle_vv_i16mf4_b64(vint16mf4_t, vint16mf4_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vmsle_vv_m)))
vbool64_t vmsle_vv_i16mf4_b64_m(vbool64_t, vbool64_t, vint16mf4_t, vint16mf4_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vmsle_vv)))
vbool32_t vmsle_vv_i32m1_b32(vint32m1_t, vint32m1_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vmsle_vv_m)))
vbool32_t vmsle_vv_i32m1_b32_m(vbool32_t, vbool32_t, vint32m1_t, vint32m1_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vmsle_vv)))
vbool16_t vmsle_vv_i32m2_b16(vint32m2_t, vint32m2_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vmsle_vv_m)))
vbool16_t vmsle_vv_i32m2_b16_m(vbool16_t, vbool16_t, vint32m2_t, vint32m2_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vmsle_vv)))
vbool8_t vmsle_vv_i32m4_b8(vint32m4_t, vint32m4_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vmsle_vv_m)))
vbool8_t vmsle_vv_i32m4_b8_m(vbool8_t, vbool8_t, vint32m4_t, vint32m4_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vmsle_vv)))
vbool4_t vmsle_vv_i32m8_b4(vint32m8_t, vint32m8_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vmsle_vv_m)))
vbool4_t vmsle_vv_i32m8_b4_m(vbool4_t, vbool4_t, vint32m8_t, vint32m8_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vmsle_vv)))
vbool64_t vmsle_vv_i32mf2_b64(vint32mf2_t, vint32mf2_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vmsle_vv_m)))
vbool64_t vmsle_vv_i32mf2_b64_m(vbool64_t, vbool64_t, vint32mf2_t, vint32mf2_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vmsle_vx)))
vbool8_t vmsle_vx_i8m1_b8(vint8m1_t, int8_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vmsle_vx_m)))
vbool8_t vmsle_vx_i8m1_b8_m(vbool8_t, vbool8_t, vint8m1_t, int8_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vmsle_vx)))
vbool4_t vmsle_vx_i8m2_b4(vint8m2_t, int8_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vmsle_vx_m)))
vbool4_t vmsle_vx_i8m2_b4_m(vbool4_t, vbool4_t, vint8m2_t, int8_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vmsle_vx)))
vbool2_t vmsle_vx_i8m4_b2(vint8m4_t, int8_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vmsle_vx_m)))
vbool2_t vmsle_vx_i8m4_b2_m(vbool2_t, vbool2_t, vint8m4_t, int8_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vmsle_vx)))
vbool1_t vmsle_vx_i8m8_b1(vint8m8_t, int8_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vmsle_vx_m)))
vbool1_t vmsle_vx_i8m8_b1_m(vbool1_t, vbool1_t, vint8m8_t, int8_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vmsle_vx)))
vbool16_t vmsle_vx_i8mf2_b16(vint8mf2_t, int8_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vmsle_vx_m)))
vbool16_t vmsle_vx_i8mf2_b16_m(vbool16_t, vbool16_t, vint8mf2_t, int8_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vmsle_vx)))
vbool32_t vmsle_vx_i8mf4_b32(vint8mf4_t, int8_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vmsle_vx_m)))
vbool32_t vmsle_vx_i8mf4_b32_m(vbool32_t, vbool32_t, vint8mf4_t, int8_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vmsle_vx)))
vbool64_t vmsle_vx_i8mf8_b64(vint8mf8_t, int8_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vmsle_vx_m)))
vbool64_t vmsle_vx_i8mf8_b64_m(vbool64_t, vbool64_t, vint8mf8_t, int8_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vmsle_vx)))
vbool16_t vmsle_vx_i16m1_b16(vint16m1_t, int16_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vmsle_vx_m)))
vbool16_t vmsle_vx_i16m1_b16_m(vbool16_t, vbool16_t, vint16m1_t, int16_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vmsle_vx)))
vbool8_t vmsle_vx_i16m2_b8(vint16m2_t, int16_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vmsle_vx_m)))
vbool8_t vmsle_vx_i16m2_b8_m(vbool8_t, vbool8_t, vint16m2_t, int16_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vmsle_vx)))
vbool4_t vmsle_vx_i16m4_b4(vint16m4_t, int16_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vmsle_vx_m)))
vbool4_t vmsle_vx_i16m4_b4_m(vbool4_t, vbool4_t, vint16m4_t, int16_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vmsle_vx)))
vbool2_t vmsle_vx_i16m8_b2(vint16m8_t, int16_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vmsle_vx_m)))
vbool2_t vmsle_vx_i16m8_b2_m(vbool2_t, vbool2_t, vint16m8_t, int16_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vmsle_vx)))
vbool32_t vmsle_vx_i16mf2_b32(vint16mf2_t, int16_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vmsle_vx_m)))
vbool32_t vmsle_vx_i16mf2_b32_m(vbool32_t, vbool32_t, vint16mf2_t, int16_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vmsle_vx)))
vbool64_t vmsle_vx_i16mf4_b64(vint16mf4_t, int16_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vmsle_vx_m)))
vbool64_t vmsle_vx_i16mf4_b64_m(vbool64_t, vbool64_t, vint16mf4_t, int16_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vmsle_vx)))
vbool32_t vmsle_vx_i32m1_b32(vint32m1_t, int32_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vmsle_vx_m)))
vbool32_t vmsle_vx_i32m1_b32_m(vbool32_t, vbool32_t, vint32m1_t, int32_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vmsle_vx)))
vbool16_t vmsle_vx_i32m2_b16(vint32m2_t, int32_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vmsle_vx_m)))
vbool16_t vmsle_vx_i32m2_b16_m(vbool16_t, vbool16_t, vint32m2_t, int32_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vmsle_vx)))
vbool8_t vmsle_vx_i32m4_b8(vint32m4_t, int32_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vmsle_vx_m)))
vbool8_t vmsle_vx_i32m4_b8_m(vbool8_t, vbool8_t, vint32m4_t, int32_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vmsle_vx)))
vbool4_t vmsle_vx_i32m8_b4(vint32m8_t, int32_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vmsle_vx_m)))
vbool4_t vmsle_vx_i32m8_b4_m(vbool4_t, vbool4_t, vint32m8_t, int32_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vmsle_vx)))
vbool64_t vmsle_vx_i32mf2_b64(vint32mf2_t, int32_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vmsle_vx_m)))
vbool64_t vmsle_vx_i32mf2_b64_m(vbool64_t, vbool64_t, vint32mf2_t, int32_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vmsgtu_vv)))
vbool8_t vmsgtu_vv_u8m1_b8(vuint8m1_t, vuint8m1_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vmsgtu_vv_m)))
vbool8_t vmsgtu_vv_u8m1_b8_m(vbool8_t, vbool8_t, vuint8m1_t, vuint8m1_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vmsgtu_vv)))
vbool4_t vmsgtu_vv_u8m2_b4(vuint8m2_t, vuint8m2_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vmsgtu_vv_m)))
vbool4_t vmsgtu_vv_u8m2_b4_m(vbool4_t, vbool4_t, vuint8m2_t, vuint8m2_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vmsgtu_vv)))
vbool2_t vmsgtu_vv_u8m4_b2(vuint8m4_t, vuint8m4_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vmsgtu_vv_m)))
vbool2_t vmsgtu_vv_u8m4_b2_m(vbool2_t, vbool2_t, vuint8m4_t, vuint8m4_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vmsgtu_vv)))
vbool1_t vmsgtu_vv_u8m8_b1(vuint8m8_t, vuint8m8_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vmsgtu_vv_m)))
vbool1_t vmsgtu_vv_u8m8_b1_m(vbool1_t, vbool1_t, vuint8m8_t, vuint8m8_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vmsgtu_vv)))
vbool16_t vmsgtu_vv_u8mf2_b16(vuint8mf2_t, vuint8mf2_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vmsgtu_vv_m)))
vbool16_t vmsgtu_vv_u8mf2_b16_m(vbool16_t, vbool16_t, vuint8mf2_t, vuint8mf2_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vmsgtu_vv)))
vbool32_t vmsgtu_vv_u8mf4_b32(vuint8mf4_t, vuint8mf4_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vmsgtu_vv_m)))
vbool32_t vmsgtu_vv_u8mf4_b32_m(vbool32_t, vbool32_t, vuint8mf4_t, vuint8mf4_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vmsgtu_vv)))
vbool64_t vmsgtu_vv_u8mf8_b64(vuint8mf8_t, vuint8mf8_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vmsgtu_vv_m)))
vbool64_t vmsgtu_vv_u8mf8_b64_m(vbool64_t, vbool64_t, vuint8mf8_t, vuint8mf8_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vmsgtu_vv)))
vbool16_t vmsgtu_vv_u16m1_b16(vuint16m1_t, vuint16m1_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vmsgtu_vv_m)))
vbool16_t vmsgtu_vv_u16m1_b16_m(vbool16_t, vbool16_t, vuint16m1_t, vuint16m1_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vmsgtu_vv)))
vbool8_t vmsgtu_vv_u16m2_b8(vuint16m2_t, vuint16m2_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vmsgtu_vv_m)))
vbool8_t vmsgtu_vv_u16m2_b8_m(vbool8_t, vbool8_t, vuint16m2_t, vuint16m2_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vmsgtu_vv)))
vbool4_t vmsgtu_vv_u16m4_b4(vuint16m4_t, vuint16m4_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vmsgtu_vv_m)))
vbool4_t vmsgtu_vv_u16m4_b4_m(vbool4_t, vbool4_t, vuint16m4_t, vuint16m4_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vmsgtu_vv)))
vbool2_t vmsgtu_vv_u16m8_b2(vuint16m8_t, vuint16m8_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vmsgtu_vv_m)))
vbool2_t vmsgtu_vv_u16m8_b2_m(vbool2_t, vbool2_t, vuint16m8_t, vuint16m8_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vmsgtu_vv)))
vbool32_t vmsgtu_vv_u16mf2_b32(vuint16mf2_t, vuint16mf2_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vmsgtu_vv_m)))
vbool32_t vmsgtu_vv_u16mf2_b32_m(vbool32_t, vbool32_t, vuint16mf2_t, vuint16mf2_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vmsgtu_vv)))
vbool64_t vmsgtu_vv_u16mf4_b64(vuint16mf4_t, vuint16mf4_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vmsgtu_vv_m)))
vbool64_t vmsgtu_vv_u16mf4_b64_m(vbool64_t, vbool64_t, vuint16mf4_t, vuint16mf4_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vmsgtu_vv)))
vbool32_t vmsgtu_vv_u32m1_b32(vuint32m1_t, vuint32m1_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vmsgtu_vv_m)))
vbool32_t vmsgtu_vv_u32m1_b32_m(vbool32_t, vbool32_t, vuint32m1_t, vuint32m1_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vmsgtu_vv)))
vbool16_t vmsgtu_vv_u32m2_b16(vuint32m2_t, vuint32m2_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vmsgtu_vv_m)))
vbool16_t vmsgtu_vv_u32m2_b16_m(vbool16_t, vbool16_t, vuint32m2_t, vuint32m2_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vmsgtu_vv)))
vbool8_t vmsgtu_vv_u32m4_b8(vuint32m4_t, vuint32m4_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vmsgtu_vv_m)))
vbool8_t vmsgtu_vv_u32m4_b8_m(vbool8_t, vbool8_t, vuint32m4_t, vuint32m4_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vmsgtu_vv)))
vbool4_t vmsgtu_vv_u32m8_b4(vuint32m8_t, vuint32m8_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vmsgtu_vv_m)))
vbool4_t vmsgtu_vv_u32m8_b4_m(vbool4_t, vbool4_t, vuint32m8_t, vuint32m8_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vmsgtu_vv)))
vbool64_t vmsgtu_vv_u32mf2_b64(vuint32mf2_t, vuint32mf2_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vmsgtu_vv_m)))
vbool64_t vmsgtu_vv_u32mf2_b64_m(vbool64_t, vbool64_t, vuint32mf2_t, vuint32mf2_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vmsgtu_vx)))
vbool8_t vmsgtu_vx_u8m1_b8(vuint8m1_t, uint8_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vmsgtu_vx_m)))
vbool8_t vmsgtu_vx_u8m1_b8_m(vbool8_t, vbool8_t, vuint8m1_t, uint8_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vmsgtu_vx)))
vbool4_t vmsgtu_vx_u8m2_b4(vuint8m2_t, uint8_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vmsgtu_vx_m)))
vbool4_t vmsgtu_vx_u8m2_b4_m(vbool4_t, vbool4_t, vuint8m2_t, uint8_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vmsgtu_vx)))
vbool2_t vmsgtu_vx_u8m4_b2(vuint8m4_t, uint8_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vmsgtu_vx_m)))
vbool2_t vmsgtu_vx_u8m4_b2_m(vbool2_t, vbool2_t, vuint8m4_t, uint8_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vmsgtu_vx)))
vbool1_t vmsgtu_vx_u8m8_b1(vuint8m8_t, uint8_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vmsgtu_vx_m)))
vbool1_t vmsgtu_vx_u8m8_b1_m(vbool1_t, vbool1_t, vuint8m8_t, uint8_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vmsgtu_vx)))
vbool16_t vmsgtu_vx_u8mf2_b16(vuint8mf2_t, uint8_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vmsgtu_vx_m)))
vbool16_t vmsgtu_vx_u8mf2_b16_m(vbool16_t, vbool16_t, vuint8mf2_t, uint8_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vmsgtu_vx)))
vbool32_t vmsgtu_vx_u8mf4_b32(vuint8mf4_t, uint8_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vmsgtu_vx_m)))
vbool32_t vmsgtu_vx_u8mf4_b32_m(vbool32_t, vbool32_t, vuint8mf4_t, uint8_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vmsgtu_vx)))
vbool64_t vmsgtu_vx_u8mf8_b64(vuint8mf8_t, uint8_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vmsgtu_vx_m)))
vbool64_t vmsgtu_vx_u8mf8_b64_m(vbool64_t, vbool64_t, vuint8mf8_t, uint8_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vmsgtu_vx)))
vbool16_t vmsgtu_vx_u16m1_b16(vuint16m1_t, uint16_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vmsgtu_vx_m)))
vbool16_t vmsgtu_vx_u16m1_b16_m(vbool16_t, vbool16_t, vuint16m1_t, uint16_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vmsgtu_vx)))
vbool8_t vmsgtu_vx_u16m2_b8(vuint16m2_t, uint16_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vmsgtu_vx_m)))
vbool8_t vmsgtu_vx_u16m2_b8_m(vbool8_t, vbool8_t, vuint16m2_t, uint16_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vmsgtu_vx)))
vbool4_t vmsgtu_vx_u16m4_b4(vuint16m4_t, uint16_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vmsgtu_vx_m)))
vbool4_t vmsgtu_vx_u16m4_b4_m(vbool4_t, vbool4_t, vuint16m4_t, uint16_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vmsgtu_vx)))
vbool2_t vmsgtu_vx_u16m8_b2(vuint16m8_t, uint16_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vmsgtu_vx_m)))
vbool2_t vmsgtu_vx_u16m8_b2_m(vbool2_t, vbool2_t, vuint16m8_t, uint16_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vmsgtu_vx)))
vbool32_t vmsgtu_vx_u16mf2_b32(vuint16mf2_t, uint16_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vmsgtu_vx_m)))
vbool32_t vmsgtu_vx_u16mf2_b32_m(vbool32_t, vbool32_t, vuint16mf2_t, uint16_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vmsgtu_vx)))
vbool64_t vmsgtu_vx_u16mf4_b64(vuint16mf4_t, uint16_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vmsgtu_vx_m)))
vbool64_t vmsgtu_vx_u16mf4_b64_m(vbool64_t, vbool64_t, vuint16mf4_t, uint16_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vmsgtu_vx)))
vbool32_t vmsgtu_vx_u32m1_b32(vuint32m1_t, uint32_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vmsgtu_vx_m)))
vbool32_t vmsgtu_vx_u32m1_b32_m(vbool32_t, vbool32_t, vuint32m1_t, uint32_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vmsgtu_vx)))
vbool16_t vmsgtu_vx_u32m2_b16(vuint32m2_t, uint32_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vmsgtu_vx_m)))
vbool16_t vmsgtu_vx_u32m2_b16_m(vbool16_t, vbool16_t, vuint32m2_t, uint32_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vmsgtu_vx)))
vbool8_t vmsgtu_vx_u32m4_b8(vuint32m4_t, uint32_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vmsgtu_vx_m)))
vbool8_t vmsgtu_vx_u32m4_b8_m(vbool8_t, vbool8_t, vuint32m4_t, uint32_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vmsgtu_vx)))
vbool4_t vmsgtu_vx_u32m8_b4(vuint32m8_t, uint32_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vmsgtu_vx_m)))
vbool4_t vmsgtu_vx_u32m8_b4_m(vbool4_t, vbool4_t, vuint32m8_t, uint32_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vmsgtu_vx)))
vbool64_t vmsgtu_vx_u32mf2_b64(vuint32mf2_t, uint32_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vmsgtu_vx_m)))
vbool64_t vmsgtu_vx_u32mf2_b64_m(vbool64_t, vbool64_t, vuint32mf2_t, uint32_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vmsgt_vv)))
vbool8_t vmsgt_vv_i8m1_b8(vint8m1_t, vint8m1_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vmsgt_vv_m)))
vbool8_t vmsgt_vv_i8m1_b8_m(vbool8_t, vbool8_t, vint8m1_t, vint8m1_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vmsgt_vv)))
vbool4_t vmsgt_vv_i8m2_b4(vint8m2_t, vint8m2_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vmsgt_vv_m)))
vbool4_t vmsgt_vv_i8m2_b4_m(vbool4_t, vbool4_t, vint8m2_t, vint8m2_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vmsgt_vv)))
vbool2_t vmsgt_vv_i8m4_b2(vint8m4_t, vint8m4_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vmsgt_vv_m)))
vbool2_t vmsgt_vv_i8m4_b2_m(vbool2_t, vbool2_t, vint8m4_t, vint8m4_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vmsgt_vv)))
vbool1_t vmsgt_vv_i8m8_b1(vint8m8_t, vint8m8_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vmsgt_vv_m)))
vbool1_t vmsgt_vv_i8m8_b1_m(vbool1_t, vbool1_t, vint8m8_t, vint8m8_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vmsgt_vv)))
vbool16_t vmsgt_vv_i8mf2_b16(vint8mf2_t, vint8mf2_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vmsgt_vv_m)))
vbool16_t vmsgt_vv_i8mf2_b16_m(vbool16_t, vbool16_t, vint8mf2_t, vint8mf2_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vmsgt_vv)))
vbool32_t vmsgt_vv_i8mf4_b32(vint8mf4_t, vint8mf4_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vmsgt_vv_m)))
vbool32_t vmsgt_vv_i8mf4_b32_m(vbool32_t, vbool32_t, vint8mf4_t, vint8mf4_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vmsgt_vv)))
vbool64_t vmsgt_vv_i8mf8_b64(vint8mf8_t, vint8mf8_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vmsgt_vv_m)))
vbool64_t vmsgt_vv_i8mf8_b64_m(vbool64_t, vbool64_t, vint8mf8_t, vint8mf8_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vmsgt_vv)))
vbool16_t vmsgt_vv_i16m1_b16(vint16m1_t, vint16m1_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vmsgt_vv_m)))
vbool16_t vmsgt_vv_i16m1_b16_m(vbool16_t, vbool16_t, vint16m1_t, vint16m1_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vmsgt_vv)))
vbool8_t vmsgt_vv_i16m2_b8(vint16m2_t, vint16m2_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vmsgt_vv_m)))
vbool8_t vmsgt_vv_i16m2_b8_m(vbool8_t, vbool8_t, vint16m2_t, vint16m2_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vmsgt_vv)))
vbool4_t vmsgt_vv_i16m4_b4(vint16m4_t, vint16m4_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vmsgt_vv_m)))
vbool4_t vmsgt_vv_i16m4_b4_m(vbool4_t, vbool4_t, vint16m4_t, vint16m4_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vmsgt_vv)))
vbool2_t vmsgt_vv_i16m8_b2(vint16m8_t, vint16m8_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vmsgt_vv_m)))
vbool2_t vmsgt_vv_i16m8_b2_m(vbool2_t, vbool2_t, vint16m8_t, vint16m8_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vmsgt_vv)))
vbool32_t vmsgt_vv_i16mf2_b32(vint16mf2_t, vint16mf2_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vmsgt_vv_m)))
vbool32_t vmsgt_vv_i16mf2_b32_m(vbool32_t, vbool32_t, vint16mf2_t, vint16mf2_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vmsgt_vv)))
vbool64_t vmsgt_vv_i16mf4_b64(vint16mf4_t, vint16mf4_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vmsgt_vv_m)))
vbool64_t vmsgt_vv_i16mf4_b64_m(vbool64_t, vbool64_t, vint16mf4_t, vint16mf4_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vmsgt_vv)))
vbool32_t vmsgt_vv_i32m1_b32(vint32m1_t, vint32m1_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vmsgt_vv_m)))
vbool32_t vmsgt_vv_i32m1_b32_m(vbool32_t, vbool32_t, vint32m1_t, vint32m1_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vmsgt_vv)))
vbool16_t vmsgt_vv_i32m2_b16(vint32m2_t, vint32m2_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vmsgt_vv_m)))
vbool16_t vmsgt_vv_i32m2_b16_m(vbool16_t, vbool16_t, vint32m2_t, vint32m2_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vmsgt_vv)))
vbool8_t vmsgt_vv_i32m4_b8(vint32m4_t, vint32m4_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vmsgt_vv_m)))
vbool8_t vmsgt_vv_i32m4_b8_m(vbool8_t, vbool8_t, vint32m4_t, vint32m4_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vmsgt_vv)))
vbool4_t vmsgt_vv_i32m8_b4(vint32m8_t, vint32m8_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vmsgt_vv_m)))
vbool4_t vmsgt_vv_i32m8_b4_m(vbool4_t, vbool4_t, vint32m8_t, vint32m8_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vmsgt_vv)))
vbool64_t vmsgt_vv_i32mf2_b64(vint32mf2_t, vint32mf2_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vmsgt_vv_m)))
vbool64_t vmsgt_vv_i32mf2_b64_m(vbool64_t, vbool64_t, vint32mf2_t, vint32mf2_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vmsgt_vx)))
vbool8_t vmsgt_vx_i8m1_b8(vint8m1_t, int8_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vmsgt_vx_m)))
vbool8_t vmsgt_vx_i8m1_b8_m(vbool8_t, vbool8_t, vint8m1_t, int8_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vmsgt_vx)))
vbool4_t vmsgt_vx_i8m2_b4(vint8m2_t, int8_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vmsgt_vx_m)))
vbool4_t vmsgt_vx_i8m2_b4_m(vbool4_t, vbool4_t, vint8m2_t, int8_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vmsgt_vx)))
vbool2_t vmsgt_vx_i8m4_b2(vint8m4_t, int8_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vmsgt_vx_m)))
vbool2_t vmsgt_vx_i8m4_b2_m(vbool2_t, vbool2_t, vint8m4_t, int8_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vmsgt_vx)))
vbool1_t vmsgt_vx_i8m8_b1(vint8m8_t, int8_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vmsgt_vx_m)))
vbool1_t vmsgt_vx_i8m8_b1_m(vbool1_t, vbool1_t, vint8m8_t, int8_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vmsgt_vx)))
vbool16_t vmsgt_vx_i8mf2_b16(vint8mf2_t, int8_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vmsgt_vx_m)))
vbool16_t vmsgt_vx_i8mf2_b16_m(vbool16_t, vbool16_t, vint8mf2_t, int8_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vmsgt_vx)))
vbool32_t vmsgt_vx_i8mf4_b32(vint8mf4_t, int8_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vmsgt_vx_m)))
vbool32_t vmsgt_vx_i8mf4_b32_m(vbool32_t, vbool32_t, vint8mf4_t, int8_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vmsgt_vx)))
vbool64_t vmsgt_vx_i8mf8_b64(vint8mf8_t, int8_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vmsgt_vx_m)))
vbool64_t vmsgt_vx_i8mf8_b64_m(vbool64_t, vbool64_t, vint8mf8_t, int8_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vmsgt_vx)))
vbool16_t vmsgt_vx_i16m1_b16(vint16m1_t, int16_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vmsgt_vx_m)))
vbool16_t vmsgt_vx_i16m1_b16_m(vbool16_t, vbool16_t, vint16m1_t, int16_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vmsgt_vx)))
vbool8_t vmsgt_vx_i16m2_b8(vint16m2_t, int16_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vmsgt_vx_m)))
vbool8_t vmsgt_vx_i16m2_b8_m(vbool8_t, vbool8_t, vint16m2_t, int16_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vmsgt_vx)))
vbool4_t vmsgt_vx_i16m4_b4(vint16m4_t, int16_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vmsgt_vx_m)))
vbool4_t vmsgt_vx_i16m4_b4_m(vbool4_t, vbool4_t, vint16m4_t, int16_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vmsgt_vx)))
vbool2_t vmsgt_vx_i16m8_b2(vint16m8_t, int16_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vmsgt_vx_m)))
vbool2_t vmsgt_vx_i16m8_b2_m(vbool2_t, vbool2_t, vint16m8_t, int16_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vmsgt_vx)))
vbool32_t vmsgt_vx_i16mf2_b32(vint16mf2_t, int16_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vmsgt_vx_m)))
vbool32_t vmsgt_vx_i16mf2_b32_m(vbool32_t, vbool32_t, vint16mf2_t, int16_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vmsgt_vx)))
vbool64_t vmsgt_vx_i16mf4_b64(vint16mf4_t, int16_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vmsgt_vx_m)))
vbool64_t vmsgt_vx_i16mf4_b64_m(vbool64_t, vbool64_t, vint16mf4_t, int16_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vmsgt_vx)))
vbool32_t vmsgt_vx_i32m1_b32(vint32m1_t, int32_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vmsgt_vx_m)))
vbool32_t vmsgt_vx_i32m1_b32_m(vbool32_t, vbool32_t, vint32m1_t, int32_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vmsgt_vx)))
vbool16_t vmsgt_vx_i32m2_b16(vint32m2_t, int32_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vmsgt_vx_m)))
vbool16_t vmsgt_vx_i32m2_b16_m(vbool16_t, vbool16_t, vint32m2_t, int32_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vmsgt_vx)))
vbool8_t vmsgt_vx_i32m4_b8(vint32m4_t, int32_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vmsgt_vx_m)))
vbool8_t vmsgt_vx_i32m4_b8_m(vbool8_t, vbool8_t, vint32m4_t, int32_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vmsgt_vx)))
vbool4_t vmsgt_vx_i32m8_b4(vint32m8_t, int32_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vmsgt_vx_m)))
vbool4_t vmsgt_vx_i32m8_b4_m(vbool4_t, vbool4_t, vint32m8_t, int32_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vmsgt_vx)))
vbool64_t vmsgt_vx_i32mf2_b64(vint32mf2_t, int32_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vmsgt_vx_m)))
vbool64_t vmsgt_vx_i32mf2_b64_m(vbool64_t, vbool64_t, vint32mf2_t, int32_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vmsgeu_vv)))
vbool8_t vmsgeu_vv_u8m1_b8(vuint8m1_t, vuint8m1_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vmsgeu_vv_m)))
vbool8_t vmsgeu_vv_u8m1_b8_m(vbool8_t, vbool8_t, vuint8m1_t, vuint8m1_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vmsgeu_vv)))
vbool4_t vmsgeu_vv_u8m2_b4(vuint8m2_t, vuint8m2_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vmsgeu_vv_m)))
vbool4_t vmsgeu_vv_u8m2_b4_m(vbool4_t, vbool4_t, vuint8m2_t, vuint8m2_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vmsgeu_vv)))
vbool2_t vmsgeu_vv_u8m4_b2(vuint8m4_t, vuint8m4_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vmsgeu_vv_m)))
vbool2_t vmsgeu_vv_u8m4_b2_m(vbool2_t, vbool2_t, vuint8m4_t, vuint8m4_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vmsgeu_vv)))
vbool1_t vmsgeu_vv_u8m8_b1(vuint8m8_t, vuint8m8_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vmsgeu_vv_m)))
vbool1_t vmsgeu_vv_u8m8_b1_m(vbool1_t, vbool1_t, vuint8m8_t, vuint8m8_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vmsgeu_vv)))
vbool16_t vmsgeu_vv_u8mf2_b16(vuint8mf2_t, vuint8mf2_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vmsgeu_vv_m)))
vbool16_t vmsgeu_vv_u8mf2_b16_m(vbool16_t, vbool16_t, vuint8mf2_t, vuint8mf2_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vmsgeu_vv)))
vbool32_t vmsgeu_vv_u8mf4_b32(vuint8mf4_t, vuint8mf4_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vmsgeu_vv_m)))
vbool32_t vmsgeu_vv_u8mf4_b32_m(vbool32_t, vbool32_t, vuint8mf4_t, vuint8mf4_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vmsgeu_vv)))
vbool64_t vmsgeu_vv_u8mf8_b64(vuint8mf8_t, vuint8mf8_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vmsgeu_vv_m)))
vbool64_t vmsgeu_vv_u8mf8_b64_m(vbool64_t, vbool64_t, vuint8mf8_t, vuint8mf8_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vmsgeu_vv)))
vbool16_t vmsgeu_vv_u16m1_b16(vuint16m1_t, vuint16m1_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vmsgeu_vv_m)))
vbool16_t vmsgeu_vv_u16m1_b16_m(vbool16_t, vbool16_t, vuint16m1_t, vuint16m1_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vmsgeu_vv)))
vbool8_t vmsgeu_vv_u16m2_b8(vuint16m2_t, vuint16m2_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vmsgeu_vv_m)))
vbool8_t vmsgeu_vv_u16m2_b8_m(vbool8_t, vbool8_t, vuint16m2_t, vuint16m2_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vmsgeu_vv)))
vbool4_t vmsgeu_vv_u16m4_b4(vuint16m4_t, vuint16m4_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vmsgeu_vv_m)))
vbool4_t vmsgeu_vv_u16m4_b4_m(vbool4_t, vbool4_t, vuint16m4_t, vuint16m4_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vmsgeu_vv)))
vbool2_t vmsgeu_vv_u16m8_b2(vuint16m8_t, vuint16m8_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vmsgeu_vv_m)))
vbool2_t vmsgeu_vv_u16m8_b2_m(vbool2_t, vbool2_t, vuint16m8_t, vuint16m8_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vmsgeu_vv)))
vbool32_t vmsgeu_vv_u16mf2_b32(vuint16mf2_t, vuint16mf2_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vmsgeu_vv_m)))
vbool32_t vmsgeu_vv_u16mf2_b32_m(vbool32_t, vbool32_t, vuint16mf2_t, vuint16mf2_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vmsgeu_vv)))
vbool64_t vmsgeu_vv_u16mf4_b64(vuint16mf4_t, vuint16mf4_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vmsgeu_vv_m)))
vbool64_t vmsgeu_vv_u16mf4_b64_m(vbool64_t, vbool64_t, vuint16mf4_t, vuint16mf4_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vmsgeu_vv)))
vbool32_t vmsgeu_vv_u32m1_b32(vuint32m1_t, vuint32m1_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vmsgeu_vv_m)))
vbool32_t vmsgeu_vv_u32m1_b32_m(vbool32_t, vbool32_t, vuint32m1_t, vuint32m1_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vmsgeu_vv)))
vbool16_t vmsgeu_vv_u32m2_b16(vuint32m2_t, vuint32m2_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vmsgeu_vv_m)))
vbool16_t vmsgeu_vv_u32m2_b16_m(vbool16_t, vbool16_t, vuint32m2_t, vuint32m2_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vmsgeu_vv)))
vbool8_t vmsgeu_vv_u32m4_b8(vuint32m4_t, vuint32m4_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vmsgeu_vv_m)))
vbool8_t vmsgeu_vv_u32m4_b8_m(vbool8_t, vbool8_t, vuint32m4_t, vuint32m4_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vmsgeu_vv)))
vbool4_t vmsgeu_vv_u32m8_b4(vuint32m8_t, vuint32m8_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vmsgeu_vv_m)))
vbool4_t vmsgeu_vv_u32m8_b4_m(vbool4_t, vbool4_t, vuint32m8_t, vuint32m8_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vmsgeu_vv)))
vbool64_t vmsgeu_vv_u32mf2_b64(vuint32mf2_t, vuint32mf2_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vmsgeu_vv_m)))
vbool64_t vmsgeu_vv_u32mf2_b64_m(vbool64_t, vbool64_t, vuint32mf2_t, vuint32mf2_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vwaddu_wv)))
vuint16mf4_t vwaddu_wv_u16mf4(vuint16mf4_t, vuint8mf8_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vwaddu_wv_m)))
vuint16mf4_t vwaddu_wv_u16mf4_m(vbool64_t, vuint16mf4_t, vuint16mf4_t, vuint8mf8_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vwaddu_wv)))
vuint16mf2_t vwaddu_wv_u16mf2(vuint16mf2_t, vuint8mf4_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vwaddu_wv_m)))
vuint16mf2_t vwaddu_wv_u16mf2_m(vbool32_t, vuint16mf2_t, vuint16mf2_t, vuint8mf4_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vwaddu_wv)))
vuint16m1_t vwaddu_wv_u16m1(vuint16m1_t, vuint8mf2_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vwaddu_wv_m)))
vuint16m1_t vwaddu_wv_u16m1_m(vbool16_t, vuint16m1_t, vuint16m1_t, vuint8mf2_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vwaddu_wv)))
vuint16m2_t vwaddu_wv_u16m2(vuint16m2_t, vuint8m1_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vwaddu_wv_m)))
vuint16m2_t vwaddu_wv_u16m2_m(vbool8_t, vuint16m2_t, vuint16m2_t, vuint8m1_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vwaddu_wv)))
vuint16m4_t vwaddu_wv_u16m4(vuint16m4_t, vuint8m2_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vwaddu_wv_m)))
vuint16m4_t vwaddu_wv_u16m4_m(vbool4_t, vuint16m4_t, vuint16m4_t, vuint8m2_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vwaddu_wv)))
vuint16m8_t vwaddu_wv_u16m8(vuint16m8_t, vuint8m4_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vwaddu_wv_m)))
vuint16m8_t vwaddu_wv_u16m8_m(vbool2_t, vuint16m8_t, vuint16m8_t, vuint8m4_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vwaddu_wv)))
vuint32mf2_t vwaddu_wv_u32mf2(vuint32mf2_t, vuint16mf4_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vwaddu_wv_m)))
vuint32mf2_t vwaddu_wv_u32mf2_m(vbool64_t, vuint32mf2_t, vuint32mf2_t, vuint16mf4_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vwaddu_wv)))
vuint32m1_t vwaddu_wv_u32m1(vuint32m1_t, vuint16mf2_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vwaddu_wv_m)))
vuint32m1_t vwaddu_wv_u32m1_m(vbool32_t, vuint32m1_t, vuint32m1_t, vuint16mf2_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vwaddu_wv)))
vuint32m2_t vwaddu_wv_u32m2(vuint32m2_t, vuint16m1_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vwaddu_wv_m)))
vuint32m2_t vwaddu_wv_u32m2_m(vbool16_t, vuint32m2_t, vuint32m2_t, vuint16m1_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vwaddu_wv)))
vuint32m4_t vwaddu_wv_u32m4(vuint32m4_t, vuint16m2_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vwaddu_wv_m)))
vuint32m4_t vwaddu_wv_u32m4_m(vbool8_t, vuint32m4_t, vuint32m4_t, vuint16m2_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vwaddu_wv)))
vuint32m8_t vwaddu_wv_u32m8(vuint32m8_t, vuint16m4_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vwaddu_wv_m)))
vuint32m8_t vwaddu_wv_u32m8_m(vbool4_t, vuint32m8_t, vuint32m8_t, vuint16m4_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vse8_v)))
void vse8_v_i8m1(int8_t *, vint8m1_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vse8_v_m)))
void vse8_v_i8m1_m(vbool8_t, int8_t *, vint8m1_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vse8_v)))
void vse8_v_i8m2(int8_t *, vint8m2_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vse8_v_m)))
void vse8_v_i8m2_m(vbool4_t, int8_t *, vint8m2_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vse8_v)))
void vse8_v_i8m4(int8_t *, vint8m4_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vse8_v_m)))
void vse8_v_i8m4_m(vbool2_t, int8_t *, vint8m4_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vse8_v)))
void vse8_v_i8m8(int8_t *, vint8m8_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vse8_v_m)))
void vse8_v_i8m8_m(vbool1_t, int8_t *, vint8m8_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vse8_v)))
void vse8_v_i8mf2(int8_t *, vint8mf2_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vse8_v_m)))
void vse8_v_i8mf2_m(vbool16_t, int8_t *, vint8mf2_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vse8_v)))
void vse8_v_i8mf4(int8_t *, vint8mf4_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vse8_v_m)))
void vse8_v_i8mf4_m(vbool32_t, int8_t *, vint8mf4_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vse8_v)))
void vse8_v_i8mf8(int8_t *, vint8mf8_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vse8_v_m)))
void vse8_v_i8mf8_m(vbool64_t, int8_t *, vint8mf8_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vsuxei16_v)))
void vsuxei16_v_i8m1(int8_t *, vuint16m2_t, vint8m1_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vsuxei16_v_m)))
void vsuxei16_v_i8m1_m(vbool8_t, int8_t *, vuint16m2_t, vint8m1_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vsuxei16_v)))
void vsuxei16_v_i8m2(int8_t *, vuint16m4_t, vint8m2_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vsuxei16_v_m)))
void vsuxei16_v_i8m2_m(vbool4_t, int8_t *, vuint16m4_t, vint8m2_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vsuxei16_v)))
void vsuxei16_v_i8m4(int8_t *, vuint16m8_t, vint8m4_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vsuxei16_v_m)))
void vsuxei16_v_i8m4_m(vbool2_t, int8_t *, vuint16m8_t, vint8m4_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vsuxei16_v)))
void vsuxei16_v_i8mf2(int8_t *, vuint16m1_t, vint8mf2_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vsuxei16_v_m)))
void vsuxei16_v_i8mf2_m(vbool16_t, int8_t *, vuint16m1_t, vint8mf2_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vsuxei16_v)))
void vsuxei16_v_i8mf4(int8_t *, vuint16mf2_t, vint8mf4_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vsuxei16_v_m)))
void vsuxei16_v_i8mf4_m(vbool32_t, int8_t *, vuint16mf2_t, vint8mf4_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vsuxei16_v)))
void vsuxei16_v_i8mf8(int8_t *, vuint16mf4_t, vint8mf8_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vsuxei16_v_m)))
void vsuxei16_v_i8mf8_m(vbool64_t, int8_t *, vuint16mf4_t, vint8mf8_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vmsgeu_vx)))
vbool8_t vmsgeu_vx_u8m1_b8(vuint8m1_t, uint8_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vmsgeu_vx_m)))
vbool8_t vmsgeu_vx_u8m1_b8_m(vbool8_t, vbool8_t, vuint8m1_t, uint8_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vmsgeu_vx)))
vbool4_t vmsgeu_vx_u8m2_b4(vuint8m2_t, uint8_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vmsgeu_vx_m)))
vbool4_t vmsgeu_vx_u8m2_b4_m(vbool4_t, vbool4_t, vuint8m2_t, uint8_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vmsgeu_vx)))
vbool2_t vmsgeu_vx_u8m4_b2(vuint8m4_t, uint8_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vmsgeu_vx_m)))
vbool2_t vmsgeu_vx_u8m4_b2_m(vbool2_t, vbool2_t, vuint8m4_t, uint8_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vmsgeu_vx)))
vbool1_t vmsgeu_vx_u8m8_b1(vuint8m8_t, uint8_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vmsgeu_vx_m)))
vbool1_t vmsgeu_vx_u8m8_b1_m(vbool1_t, vbool1_t, vuint8m8_t, uint8_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vmsgeu_vx)))
vbool16_t vmsgeu_vx_u8mf2_b16(vuint8mf2_t, uint8_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vmsgeu_vx_m)))
vbool16_t vmsgeu_vx_u8mf2_b16_m(vbool16_t, vbool16_t, vuint8mf2_t, uint8_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vmsgeu_vx)))
vbool32_t vmsgeu_vx_u8mf4_b32(vuint8mf4_t, uint8_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vmsgeu_vx_m)))
vbool32_t vmsgeu_vx_u8mf4_b32_m(vbool32_t, vbool32_t, vuint8mf4_t, uint8_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vmsgeu_vx)))
vbool64_t vmsgeu_vx_u8mf8_b64(vuint8mf8_t, uint8_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vmsgeu_vx_m)))
vbool64_t vmsgeu_vx_u8mf8_b64_m(vbool64_t, vbool64_t, vuint8mf8_t, uint8_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vmsgeu_vx)))
vbool16_t vmsgeu_vx_u16m1_b16(vuint16m1_t, uint16_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vmsgeu_vx_m)))
vbool16_t vmsgeu_vx_u16m1_b16_m(vbool16_t, vbool16_t, vuint16m1_t, uint16_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vmsgeu_vx)))
vbool8_t vmsgeu_vx_u16m2_b8(vuint16m2_t, uint16_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vmsgeu_vx_m)))
vbool8_t vmsgeu_vx_u16m2_b8_m(vbool8_t, vbool8_t, vuint16m2_t, uint16_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vmsgeu_vx)))
vbool4_t vmsgeu_vx_u16m4_b4(vuint16m4_t, uint16_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vmsgeu_vx_m)))
vbool4_t vmsgeu_vx_u16m4_b4_m(vbool4_t, vbool4_t, vuint16m4_t, uint16_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vmsgeu_vx)))
vbool2_t vmsgeu_vx_u16m8_b2(vuint16m8_t, uint16_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vmsgeu_vx_m)))
vbool2_t vmsgeu_vx_u16m8_b2_m(vbool2_t, vbool2_t, vuint16m8_t, uint16_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vmsgeu_vx)))
vbool32_t vmsgeu_vx_u16mf2_b32(vuint16mf2_t, uint16_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vmsgeu_vx_m)))
vbool32_t vmsgeu_vx_u16mf2_b32_m(vbool32_t, vbool32_t, vuint16mf2_t, uint16_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vmsgeu_vx)))
vbool64_t vmsgeu_vx_u16mf4_b64(vuint16mf4_t, uint16_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vmsgeu_vx_m)))
vbool64_t vmsgeu_vx_u16mf4_b64_m(vbool64_t, vbool64_t, vuint16mf4_t, uint16_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vmsgeu_vx)))
vbool32_t vmsgeu_vx_u32m1_b32(vuint32m1_t, uint32_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vmsgeu_vx_m)))
vbool32_t vmsgeu_vx_u32m1_b32_m(vbool32_t, vbool32_t, vuint32m1_t, uint32_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vmsgeu_vx)))
vbool16_t vmsgeu_vx_u32m2_b16(vuint32m2_t, uint32_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vmsgeu_vx_m)))
vbool16_t vmsgeu_vx_u32m2_b16_m(vbool16_t, vbool16_t, vuint32m2_t, uint32_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vmsgeu_vx)))
vbool8_t vmsgeu_vx_u32m4_b8(vuint32m4_t, uint32_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vmsgeu_vx_m)))
vbool8_t vmsgeu_vx_u32m4_b8_m(vbool8_t, vbool8_t, vuint32m4_t, uint32_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vmsgeu_vx)))
vbool4_t vmsgeu_vx_u32m8_b4(vuint32m8_t, uint32_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vmsgeu_vx_m)))
vbool4_t vmsgeu_vx_u32m8_b4_m(vbool4_t, vbool4_t, vuint32m8_t, uint32_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vmsgeu_vx)))
vbool64_t vmsgeu_vx_u32mf2_b64(vuint32mf2_t, uint32_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vmsgeu_vx_m)))
vbool64_t vmsgeu_vx_u32mf2_b64_m(vbool64_t, vbool64_t, vuint32mf2_t, uint32_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vmsge_vv)))
vbool8_t vmsge_vv_i8m1_b8(vint8m1_t, vint8m1_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vmsge_vv_m)))
vbool8_t vmsge_vv_i8m1_b8_m(vbool8_t, vbool8_t, vint8m1_t, vint8m1_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vmsge_vv)))
vbool4_t vmsge_vv_i8m2_b4(vint8m2_t, vint8m2_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vmsge_vv_m)))
vbool4_t vmsge_vv_i8m2_b4_m(vbool4_t, vbool4_t, vint8m2_t, vint8m2_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vmsge_vv)))
vbool2_t vmsge_vv_i8m4_b2(vint8m4_t, vint8m4_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vmsge_vv_m)))
vbool2_t vmsge_vv_i8m4_b2_m(vbool2_t, vbool2_t, vint8m4_t, vint8m4_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vmsge_vv)))
vbool1_t vmsge_vv_i8m8_b1(vint8m8_t, vint8m8_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vmsge_vv_m)))
vbool1_t vmsge_vv_i8m8_b1_m(vbool1_t, vbool1_t, vint8m8_t, vint8m8_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vmsge_vv)))
vbool16_t vmsge_vv_i8mf2_b16(vint8mf2_t, vint8mf2_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vmsge_vv_m)))
vbool16_t vmsge_vv_i8mf2_b16_m(vbool16_t, vbool16_t, vint8mf2_t, vint8mf2_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vmsge_vv)))
vbool32_t vmsge_vv_i8mf4_b32(vint8mf4_t, vint8mf4_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vmsge_vv_m)))
vbool32_t vmsge_vv_i8mf4_b32_m(vbool32_t, vbool32_t, vint8mf4_t, vint8mf4_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vmsge_vv)))
vbool64_t vmsge_vv_i8mf8_b64(vint8mf8_t, vint8mf8_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vmsge_vv_m)))
vbool64_t vmsge_vv_i8mf8_b64_m(vbool64_t, vbool64_t, vint8mf8_t, vint8mf8_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vmsge_vv)))
vbool16_t vmsge_vv_i16m1_b16(vint16m1_t, vint16m1_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vmsge_vv_m)))
vbool16_t vmsge_vv_i16m1_b16_m(vbool16_t, vbool16_t, vint16m1_t, vint16m1_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vmsge_vv)))
vbool8_t vmsge_vv_i16m2_b8(vint16m2_t, vint16m2_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vmsge_vv_m)))
vbool8_t vmsge_vv_i16m2_b8_m(vbool8_t, vbool8_t, vint16m2_t, vint16m2_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vmsge_vv)))
vbool4_t vmsge_vv_i16m4_b4(vint16m4_t, vint16m4_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vmsge_vv_m)))
vbool4_t vmsge_vv_i16m4_b4_m(vbool4_t, vbool4_t, vint16m4_t, vint16m4_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vmsge_vv)))
vbool2_t vmsge_vv_i16m8_b2(vint16m8_t, vint16m8_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vmsge_vv_m)))
vbool2_t vmsge_vv_i16m8_b2_m(vbool2_t, vbool2_t, vint16m8_t, vint16m8_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vmsge_vv)))
vbool32_t vmsge_vv_i16mf2_b32(vint16mf2_t, vint16mf2_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vmsge_vv_m)))
vbool32_t vmsge_vv_i16mf2_b32_m(vbool32_t, vbool32_t, vint16mf2_t, vint16mf2_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vmsge_vv)))
vbool64_t vmsge_vv_i16mf4_b64(vint16mf4_t, vint16mf4_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vmsge_vv_m)))
vbool64_t vmsge_vv_i16mf4_b64_m(vbool64_t, vbool64_t, vint16mf4_t, vint16mf4_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vmsge_vv)))
vbool32_t vmsge_vv_i32m1_b32(vint32m1_t, vint32m1_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vmsge_vv_m)))
vbool32_t vmsge_vv_i32m1_b32_m(vbool32_t, vbool32_t, vint32m1_t, vint32m1_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vmsge_vv)))
vbool16_t vmsge_vv_i32m2_b16(vint32m2_t, vint32m2_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vmsge_vv_m)))
vbool16_t vmsge_vv_i32m2_b16_m(vbool16_t, vbool16_t, vint32m2_t, vint32m2_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vmsge_vv)))
vbool8_t vmsge_vv_i32m4_b8(vint32m4_t, vint32m4_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vmsge_vv_m)))
vbool8_t vmsge_vv_i32m4_b8_m(vbool8_t, vbool8_t, vint32m4_t, vint32m4_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vmsge_vv)))
vbool4_t vmsge_vv_i32m8_b4(vint32m8_t, vint32m8_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vmsge_vv_m)))
vbool4_t vmsge_vv_i32m8_b4_m(vbool4_t, vbool4_t, vint32m8_t, vint32m8_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vmsge_vv)))
vbool64_t vmsge_vv_i32mf2_b64(vint32mf2_t, vint32mf2_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vmsge_vv_m)))
vbool64_t vmsge_vv_i32mf2_b64_m(vbool64_t, vbool64_t, vint32mf2_t, vint32mf2_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vmsge_vx)))
vbool8_t vmsge_vx_i8m1_b8(vint8m1_t, int8_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vmsge_vx_m)))
vbool8_t vmsge_vx_i8m1_b8_m(vbool8_t, vbool8_t, vint8m1_t, int8_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vmsge_vx)))
vbool4_t vmsge_vx_i8m2_b4(vint8m2_t, int8_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vmsge_vx_m)))
vbool4_t vmsge_vx_i8m2_b4_m(vbool4_t, vbool4_t, vint8m2_t, int8_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vmsge_vx)))
vbool2_t vmsge_vx_i8m4_b2(vint8m4_t, int8_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vmsge_vx_m)))
vbool2_t vmsge_vx_i8m4_b2_m(vbool2_t, vbool2_t, vint8m4_t, int8_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vmsge_vx)))
vbool1_t vmsge_vx_i8m8_b1(vint8m8_t, int8_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vmsge_vx_m)))
vbool1_t vmsge_vx_i8m8_b1_m(vbool1_t, vbool1_t, vint8m8_t, int8_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vmsge_vx)))
vbool16_t vmsge_vx_i8mf2_b16(vint8mf2_t, int8_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vmsge_vx_m)))
vbool16_t vmsge_vx_i8mf2_b16_m(vbool16_t, vbool16_t, vint8mf2_t, int8_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vmsge_vx)))
vbool32_t vmsge_vx_i8mf4_b32(vint8mf4_t, int8_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vmsge_vx_m)))
vbool32_t vmsge_vx_i8mf4_b32_m(vbool32_t, vbool32_t, vint8mf4_t, int8_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vmsge_vx)))
vbool64_t vmsge_vx_i8mf8_b64(vint8mf8_t, int8_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vmsge_vx_m)))
vbool64_t vmsge_vx_i8mf8_b64_m(vbool64_t, vbool64_t, vint8mf8_t, int8_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vmsge_vx)))
vbool16_t vmsge_vx_i16m1_b16(vint16m1_t, int16_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vmsge_vx_m)))
vbool16_t vmsge_vx_i16m1_b16_m(vbool16_t, vbool16_t, vint16m1_t, int16_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vmsge_vx)))
vbool8_t vmsge_vx_i16m2_b8(vint16m2_t, int16_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vmsge_vx_m)))
vbool8_t vmsge_vx_i16m2_b8_m(vbool8_t, vbool8_t, vint16m2_t, int16_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vmsge_vx)))
vbool4_t vmsge_vx_i16m4_b4(vint16m4_t, int16_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vmsge_vx_m)))
vbool4_t vmsge_vx_i16m4_b4_m(vbool4_t, vbool4_t, vint16m4_t, int16_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vmsge_vx)))
vbool2_t vmsge_vx_i16m8_b2(vint16m8_t, int16_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vmsge_vx_m)))
vbool2_t vmsge_vx_i16m8_b2_m(vbool2_t, vbool2_t, vint16m8_t, int16_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vmsge_vx)))
vbool32_t vmsge_vx_i16mf2_b32(vint16mf2_t, int16_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vmsge_vx_m)))
vbool32_t vmsge_vx_i16mf2_b32_m(vbool32_t, vbool32_t, vint16mf2_t, int16_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vmsge_vx)))
vbool64_t vmsge_vx_i16mf4_b64(vint16mf4_t, int16_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vmsge_vx_m)))
vbool64_t vmsge_vx_i16mf4_b64_m(vbool64_t, vbool64_t, vint16mf4_t, int16_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vmsge_vx)))
vbool32_t vmsge_vx_i32m1_b32(vint32m1_t, int32_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vmsge_vx_m)))
vbool32_t vmsge_vx_i32m1_b32_m(vbool32_t, vbool32_t, vint32m1_t, int32_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vmsge_vx)))
vbool16_t vmsge_vx_i32m2_b16(vint32m2_t, int32_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vmsge_vx_m)))
vbool16_t vmsge_vx_i32m2_b16_m(vbool16_t, vbool16_t, vint32m2_t, int32_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vmsge_vx)))
vbool8_t vmsge_vx_i32m4_b8(vint32m4_t, int32_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vmsge_vx_m)))
vbool8_t vmsge_vx_i32m4_b8_m(vbool8_t, vbool8_t, vint32m4_t, int32_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vmsge_vx)))
vbool4_t vmsge_vx_i32m8_b4(vint32m8_t, int32_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vmsge_vx_m)))
vbool4_t vmsge_vx_i32m8_b4_m(vbool4_t, vbool4_t, vint32m8_t, int32_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vmsge_vx)))
vbool64_t vmsge_vx_i32mf2_b64(vint32mf2_t, int32_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vmsge_vx_m)))
vbool64_t vmsge_vx_i32mf2_b64_m(vbool64_t, vbool64_t, vint32mf2_t, int32_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vminu_vv)))
vuint8m1_t vminu_vv_u8m1(vuint8m1_t, vuint8m1_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vminu_vv_m)))
vuint8m1_t vminu_vv_u8m1_m(vbool8_t, vuint8m1_t, vuint8m1_t, vuint8m1_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vminu_vv)))
vuint8m2_t vminu_vv_u8m2(vuint8m2_t, vuint8m2_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vminu_vv_m)))
vuint8m2_t vminu_vv_u8m2_m(vbool4_t, vuint8m2_t, vuint8m2_t, vuint8m2_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vminu_vv)))
vuint8m4_t vminu_vv_u8m4(vuint8m4_t, vuint8m4_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vminu_vv_m)))
vuint8m4_t vminu_vv_u8m4_m(vbool2_t, vuint8m4_t, vuint8m4_t, vuint8m4_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vminu_vv)))
vuint8m8_t vminu_vv_u8m8(vuint8m8_t, vuint8m8_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vminu_vv_m)))
vuint8m8_t vminu_vv_u8m8_m(vbool1_t, vuint8m8_t, vuint8m8_t, vuint8m8_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vminu_vv)))
vuint8mf2_t vminu_vv_u8mf2(vuint8mf2_t, vuint8mf2_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vminu_vv_m)))
vuint8mf2_t vminu_vv_u8mf2_m(vbool16_t, vuint8mf2_t, vuint8mf2_t, vuint8mf2_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vminu_vv)))
vuint8mf4_t vminu_vv_u8mf4(vuint8mf4_t, vuint8mf4_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vminu_vv_m)))
vuint8mf4_t vminu_vv_u8mf4_m(vbool32_t, vuint8mf4_t, vuint8mf4_t, vuint8mf4_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vminu_vv)))
vuint8mf8_t vminu_vv_u8mf8(vuint8mf8_t, vuint8mf8_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vminu_vv_m)))
vuint8mf8_t vminu_vv_u8mf8_m(vbool64_t, vuint8mf8_t, vuint8mf8_t, vuint8mf8_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vminu_vv)))
vuint16m1_t vminu_vv_u16m1(vuint16m1_t, vuint16m1_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vminu_vv_m)))
vuint16m1_t vminu_vv_u16m1_m(vbool16_t, vuint16m1_t, vuint16m1_t, vuint16m1_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vminu_vv)))
vuint16m2_t vminu_vv_u16m2(vuint16m2_t, vuint16m2_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vminu_vv_m)))
vuint16m2_t vminu_vv_u16m2_m(vbool8_t, vuint16m2_t, vuint16m2_t, vuint16m2_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vminu_vv)))
vuint16m4_t vminu_vv_u16m4(vuint16m4_t, vuint16m4_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vminu_vv_m)))
vuint16m4_t vminu_vv_u16m4_m(vbool4_t, vuint16m4_t, vuint16m4_t, vuint16m4_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vminu_vv)))
vuint16m8_t vminu_vv_u16m8(vuint16m8_t, vuint16m8_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vminu_vv_m)))
vuint16m8_t vminu_vv_u16m8_m(vbool2_t, vuint16m8_t, vuint16m8_t, vuint16m8_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vminu_vv)))
vuint16mf2_t vminu_vv_u16mf2(vuint16mf2_t, vuint16mf2_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vminu_vv_m)))
vuint16mf2_t vminu_vv_u16mf2_m(vbool32_t, vuint16mf2_t, vuint16mf2_t, vuint16mf2_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vminu_vv)))
vuint16mf4_t vminu_vv_u16mf4(vuint16mf4_t, vuint16mf4_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vminu_vv_m)))
vuint16mf4_t vminu_vv_u16mf4_m(vbool64_t, vuint16mf4_t, vuint16mf4_t, vuint16mf4_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vminu_vv)))
vuint32m1_t vminu_vv_u32m1(vuint32m1_t, vuint32m1_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vminu_vv_m)))
vuint32m1_t vminu_vv_u32m1_m(vbool32_t, vuint32m1_t, vuint32m1_t, vuint32m1_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vminu_vv)))
vuint32m2_t vminu_vv_u32m2(vuint32m2_t, vuint32m2_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vminu_vv_m)))
vuint32m2_t vminu_vv_u32m2_m(vbool16_t, vuint32m2_t, vuint32m2_t, vuint32m2_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vminu_vv)))
vuint32m4_t vminu_vv_u32m4(vuint32m4_t, vuint32m4_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vminu_vv_m)))
vuint32m4_t vminu_vv_u32m4_m(vbool8_t, vuint32m4_t, vuint32m4_t, vuint32m4_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vminu_vv)))
vuint32m8_t vminu_vv_u32m8(vuint32m8_t, vuint32m8_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vminu_vv_m)))
vuint32m8_t vminu_vv_u32m8_m(vbool4_t, vuint32m8_t, vuint32m8_t, vuint32m8_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vminu_vv)))
vuint32mf2_t vminu_vv_u32mf2(vuint32mf2_t, vuint32mf2_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vminu_vv_m)))
vuint32mf2_t vminu_vv_u32mf2_m(vbool64_t, vuint32mf2_t, vuint32mf2_t, vuint32mf2_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vminu_vx)))
vuint8m1_t vminu_vx_u8m1(vuint8m1_t, uint8_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vminu_vx_m)))
vuint8m1_t vminu_vx_u8m1_m(vbool8_t, vuint8m1_t, vuint8m1_t, uint8_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vminu_vx)))
vuint8m2_t vminu_vx_u8m2(vuint8m2_t, uint8_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vminu_vx_m)))
vuint8m2_t vminu_vx_u8m2_m(vbool4_t, vuint8m2_t, vuint8m2_t, uint8_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vminu_vx)))
vuint8m4_t vminu_vx_u8m4(vuint8m4_t, uint8_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vminu_vx_m)))
vuint8m4_t vminu_vx_u8m4_m(vbool2_t, vuint8m4_t, vuint8m4_t, uint8_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vminu_vx)))
vuint8m8_t vminu_vx_u8m8(vuint8m8_t, uint8_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vminu_vx_m)))
vuint8m8_t vminu_vx_u8m8_m(vbool1_t, vuint8m8_t, vuint8m8_t, uint8_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vminu_vx)))
vuint8mf2_t vminu_vx_u8mf2(vuint8mf2_t, uint8_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vminu_vx_m)))
vuint8mf2_t vminu_vx_u8mf2_m(vbool16_t, vuint8mf2_t, vuint8mf2_t, uint8_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vminu_vx)))
vuint8mf4_t vminu_vx_u8mf4(vuint8mf4_t, uint8_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vminu_vx_m)))
vuint8mf4_t vminu_vx_u8mf4_m(vbool32_t, vuint8mf4_t, vuint8mf4_t, uint8_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vminu_vx)))
vuint8mf8_t vminu_vx_u8mf8(vuint8mf8_t, uint8_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vminu_vx_m)))
vuint8mf8_t vminu_vx_u8mf8_m(vbool64_t, vuint8mf8_t, vuint8mf8_t, uint8_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vminu_vx)))
vuint16m1_t vminu_vx_u16m1(vuint16m1_t, uint16_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vminu_vx_m)))
vuint16m1_t vminu_vx_u16m1_m(vbool16_t, vuint16m1_t, vuint16m1_t, uint16_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vminu_vx)))
vuint16m2_t vminu_vx_u16m2(vuint16m2_t, uint16_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vminu_vx_m)))
vuint16m2_t vminu_vx_u16m2_m(vbool8_t, vuint16m2_t, vuint16m2_t, uint16_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vminu_vx)))
vuint16m4_t vminu_vx_u16m4(vuint16m4_t, uint16_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vminu_vx_m)))
vuint16m4_t vminu_vx_u16m4_m(vbool4_t, vuint16m4_t, vuint16m4_t, uint16_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vminu_vx)))
vuint16m8_t vminu_vx_u16m8(vuint16m8_t, uint16_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vminu_vx_m)))
vuint16m8_t vminu_vx_u16m8_m(vbool2_t, vuint16m8_t, vuint16m8_t, uint16_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vminu_vx)))
vuint16mf2_t vminu_vx_u16mf2(vuint16mf2_t, uint16_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vminu_vx_m)))
vuint16mf2_t vminu_vx_u16mf2_m(vbool32_t, vuint16mf2_t, vuint16mf2_t, uint16_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vminu_vx)))
vuint16mf4_t vminu_vx_u16mf4(vuint16mf4_t, uint16_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vminu_vx_m)))
vuint16mf4_t vminu_vx_u16mf4_m(vbool64_t, vuint16mf4_t, vuint16mf4_t, uint16_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vminu_vx)))
vuint32m1_t vminu_vx_u32m1(vuint32m1_t, uint32_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vminu_vx_m)))
vuint32m1_t vminu_vx_u32m1_m(vbool32_t, vuint32m1_t, vuint32m1_t, uint32_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vminu_vx)))
vuint32m2_t vminu_vx_u32m2(vuint32m2_t, uint32_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vminu_vx_m)))
vuint32m2_t vminu_vx_u32m2_m(vbool16_t, vuint32m2_t, vuint32m2_t, uint32_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vminu_vx)))
vuint32m4_t vminu_vx_u32m4(vuint32m4_t, uint32_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vminu_vx_m)))
vuint32m4_t vminu_vx_u32m4_m(vbool8_t, vuint32m4_t, vuint32m4_t, uint32_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vminu_vx)))
vuint32m8_t vminu_vx_u32m8(vuint32m8_t, uint32_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vminu_vx_m)))
vuint32m8_t vminu_vx_u32m8_m(vbool4_t, vuint32m8_t, vuint32m8_t, uint32_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vminu_vx)))
vuint32mf2_t vminu_vx_u32mf2(vuint32mf2_t, uint32_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vminu_vx_m)))
vuint32mf2_t vminu_vx_u32mf2_m(vbool64_t, vuint32mf2_t, vuint32mf2_t, uint32_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vmin_vv)))
vint8m1_t vmin_vv_i8m1(vint8m1_t, vint8m1_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vmin_vv_m)))
vint8m1_t vmin_vv_i8m1_m(vbool8_t, vint8m1_t, vint8m1_t, vint8m1_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vmin_vv)))
vint8m2_t vmin_vv_i8m2(vint8m2_t, vint8m2_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vmin_vv_m)))
vint8m2_t vmin_vv_i8m2_m(vbool4_t, vint8m2_t, vint8m2_t, vint8m2_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vmin_vv)))
vint8m4_t vmin_vv_i8m4(vint8m4_t, vint8m4_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vmin_vv_m)))
vint8m4_t vmin_vv_i8m4_m(vbool2_t, vint8m4_t, vint8m4_t, vint8m4_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vmin_vv)))
vint8m8_t vmin_vv_i8m8(vint8m8_t, vint8m8_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vmin_vv_m)))
vint8m8_t vmin_vv_i8m8_m(vbool1_t, vint8m8_t, vint8m8_t, vint8m8_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vmin_vv)))
vint8mf2_t vmin_vv_i8mf2(vint8mf2_t, vint8mf2_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vmin_vv_m)))
vint8mf2_t vmin_vv_i8mf2_m(vbool16_t, vint8mf2_t, vint8mf2_t, vint8mf2_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vmin_vv)))
vint8mf4_t vmin_vv_i8mf4(vint8mf4_t, vint8mf4_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vmin_vv_m)))
vint8mf4_t vmin_vv_i8mf4_m(vbool32_t, vint8mf4_t, vint8mf4_t, vint8mf4_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vmin_vv)))
vint8mf8_t vmin_vv_i8mf8(vint8mf8_t, vint8mf8_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vmin_vv_m)))
vint8mf8_t vmin_vv_i8mf8_m(vbool64_t, vint8mf8_t, vint8mf8_t, vint8mf8_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vmin_vv)))
vint16m1_t vmin_vv_i16m1(vint16m1_t, vint16m1_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vmin_vv_m)))
vint16m1_t vmin_vv_i16m1_m(vbool16_t, vint16m1_t, vint16m1_t, vint16m1_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vmin_vv)))
vint16m2_t vmin_vv_i16m2(vint16m2_t, vint16m2_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vmin_vv_m)))
vint16m2_t vmin_vv_i16m2_m(vbool8_t, vint16m2_t, vint16m2_t, vint16m2_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vmin_vv)))
vint16m4_t vmin_vv_i16m4(vint16m4_t, vint16m4_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vmin_vv_m)))
vint16m4_t vmin_vv_i16m4_m(vbool4_t, vint16m4_t, vint16m4_t, vint16m4_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vmin_vv)))
vint16m8_t vmin_vv_i16m8(vint16m8_t, vint16m8_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vmin_vv_m)))
vint16m8_t vmin_vv_i16m8_m(vbool2_t, vint16m8_t, vint16m8_t, vint16m8_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vmin_vv)))
vint16mf2_t vmin_vv_i16mf2(vint16mf2_t, vint16mf2_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vmin_vv_m)))
vint16mf2_t vmin_vv_i16mf2_m(vbool32_t, vint16mf2_t, vint16mf2_t, vint16mf2_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vmin_vv)))
vint16mf4_t vmin_vv_i16mf4(vint16mf4_t, vint16mf4_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vmin_vv_m)))
vint16mf4_t vmin_vv_i16mf4_m(vbool64_t, vint16mf4_t, vint16mf4_t, vint16mf4_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vmin_vv)))
vint32m1_t vmin_vv_i32m1(vint32m1_t, vint32m1_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vmin_vv_m)))
vint32m1_t vmin_vv_i32m1_m(vbool32_t, vint32m1_t, vint32m1_t, vint32m1_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vmin_vv)))
vint32m2_t vmin_vv_i32m2(vint32m2_t, vint32m2_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vmin_vv_m)))
vint32m2_t vmin_vv_i32m2_m(vbool16_t, vint32m2_t, vint32m2_t, vint32m2_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vmin_vv)))
vint32m4_t vmin_vv_i32m4(vint32m4_t, vint32m4_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vmin_vv_m)))
vint32m4_t vmin_vv_i32m4_m(vbool8_t, vint32m4_t, vint32m4_t, vint32m4_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vmin_vv)))
vint32m8_t vmin_vv_i32m8(vint32m8_t, vint32m8_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vmin_vv_m)))
vint32m8_t vmin_vv_i32m8_m(vbool4_t, vint32m8_t, vint32m8_t, vint32m8_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vmin_vv)))
vint32mf2_t vmin_vv_i32mf2(vint32mf2_t, vint32mf2_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vmin_vv_m)))
vint32mf2_t vmin_vv_i32mf2_m(vbool64_t, vint32mf2_t, vint32mf2_t, vint32mf2_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vmin_vx)))
vint8m1_t vmin_vx_i8m1(vint8m1_t, int8_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vmin_vx_m)))
vint8m1_t vmin_vx_i8m1_m(vbool8_t, vint8m1_t, vint8m1_t, int8_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vmin_vx)))
vint8m2_t vmin_vx_i8m2(vint8m2_t, int8_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vmin_vx_m)))
vint8m2_t vmin_vx_i8m2_m(vbool4_t, vint8m2_t, vint8m2_t, int8_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vmin_vx)))
vint8m4_t vmin_vx_i8m4(vint8m4_t, int8_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vmin_vx_m)))
vint8m4_t vmin_vx_i8m4_m(vbool2_t, vint8m4_t, vint8m4_t, int8_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vmin_vx)))
vint8m8_t vmin_vx_i8m8(vint8m8_t, int8_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vmin_vx_m)))
vint8m8_t vmin_vx_i8m8_m(vbool1_t, vint8m8_t, vint8m8_t, int8_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vmin_vx)))
vint8mf2_t vmin_vx_i8mf2(vint8mf2_t, int8_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vmin_vx_m)))
vint8mf2_t vmin_vx_i8mf2_m(vbool16_t, vint8mf2_t, vint8mf2_t, int8_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vmin_vx)))
vint8mf4_t vmin_vx_i8mf4(vint8mf4_t, int8_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vmin_vx_m)))
vint8mf4_t vmin_vx_i8mf4_m(vbool32_t, vint8mf4_t, vint8mf4_t, int8_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vmin_vx)))
vint8mf8_t vmin_vx_i8mf8(vint8mf8_t, int8_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vmin_vx_m)))
vint8mf8_t vmin_vx_i8mf8_m(vbool64_t, vint8mf8_t, vint8mf8_t, int8_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vmin_vx)))
vint16m1_t vmin_vx_i16m1(vint16m1_t, int16_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vmin_vx_m)))
vint16m1_t vmin_vx_i16m1_m(vbool16_t, vint16m1_t, vint16m1_t, int16_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vmin_vx)))
vint16m2_t vmin_vx_i16m2(vint16m2_t, int16_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vmin_vx_m)))
vint16m2_t vmin_vx_i16m2_m(vbool8_t, vint16m2_t, vint16m2_t, int16_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vmin_vx)))
vint16m4_t vmin_vx_i16m4(vint16m4_t, int16_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vmin_vx_m)))
vint16m4_t vmin_vx_i16m4_m(vbool4_t, vint16m4_t, vint16m4_t, int16_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vmin_vx)))
vint16m8_t vmin_vx_i16m8(vint16m8_t, int16_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vmin_vx_m)))
vint16m8_t vmin_vx_i16m8_m(vbool2_t, vint16m8_t, vint16m8_t, int16_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vmin_vx)))
vint16mf2_t vmin_vx_i16mf2(vint16mf2_t, int16_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vmin_vx_m)))
vint16mf2_t vmin_vx_i16mf2_m(vbool32_t, vint16mf2_t, vint16mf2_t, int16_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vmin_vx)))
vint16mf4_t vmin_vx_i16mf4(vint16mf4_t, int16_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vmin_vx_m)))
vint16mf4_t vmin_vx_i16mf4_m(vbool64_t, vint16mf4_t, vint16mf4_t, int16_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vmin_vx)))
vint32m1_t vmin_vx_i32m1(vint32m1_t, int32_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vmin_vx_m)))
vint32m1_t vmin_vx_i32m1_m(vbool32_t, vint32m1_t, vint32m1_t, int32_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vmin_vx)))
vint32m2_t vmin_vx_i32m2(vint32m2_t, int32_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vmin_vx_m)))
vint32m2_t vmin_vx_i32m2_m(vbool16_t, vint32m2_t, vint32m2_t, int32_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vmin_vx)))
vint32m4_t vmin_vx_i32m4(vint32m4_t, int32_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vmin_vx_m)))
vint32m4_t vmin_vx_i32m4_m(vbool8_t, vint32m4_t, vint32m4_t, int32_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vmin_vx)))
vint32m8_t vmin_vx_i32m8(vint32m8_t, int32_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vmin_vx_m)))
vint32m8_t vmin_vx_i32m8_m(vbool4_t, vint32m8_t, vint32m8_t, int32_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vmin_vx)))
vint32mf2_t vmin_vx_i32mf2(vint32mf2_t, int32_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vmin_vx_m)))
vint32mf2_t vmin_vx_i32mf2_m(vbool64_t, vint32mf2_t, vint32mf2_t, int32_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vmaxu_vv)))
vuint8m1_t vmaxu_vv_u8m1(vuint8m1_t, vuint8m1_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vmaxu_vv_m)))
vuint8m1_t vmaxu_vv_u8m1_m(vbool8_t, vuint8m1_t, vuint8m1_t, vuint8m1_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vmaxu_vv)))
vuint8m2_t vmaxu_vv_u8m2(vuint8m2_t, vuint8m2_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vmaxu_vv_m)))
vuint8m2_t vmaxu_vv_u8m2_m(vbool4_t, vuint8m2_t, vuint8m2_t, vuint8m2_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vmaxu_vv)))
vuint8m4_t vmaxu_vv_u8m4(vuint8m4_t, vuint8m4_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vmaxu_vv_m)))
vuint8m4_t vmaxu_vv_u8m4_m(vbool2_t, vuint8m4_t, vuint8m4_t, vuint8m4_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vmaxu_vv)))
vuint8m8_t vmaxu_vv_u8m8(vuint8m8_t, vuint8m8_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vmaxu_vv_m)))
vuint8m8_t vmaxu_vv_u8m8_m(vbool1_t, vuint8m8_t, vuint8m8_t, vuint8m8_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vmaxu_vv)))
vuint8mf2_t vmaxu_vv_u8mf2(vuint8mf2_t, vuint8mf2_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vmaxu_vv_m)))
vuint8mf2_t vmaxu_vv_u8mf2_m(vbool16_t, vuint8mf2_t, vuint8mf2_t, vuint8mf2_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vmaxu_vv)))
vuint8mf4_t vmaxu_vv_u8mf4(vuint8mf4_t, vuint8mf4_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vmaxu_vv_m)))
vuint8mf4_t vmaxu_vv_u8mf4_m(vbool32_t, vuint8mf4_t, vuint8mf4_t, vuint8mf4_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vmaxu_vv)))
vuint8mf8_t vmaxu_vv_u8mf8(vuint8mf8_t, vuint8mf8_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vmaxu_vv_m)))
vuint8mf8_t vmaxu_vv_u8mf8_m(vbool64_t, vuint8mf8_t, vuint8mf8_t, vuint8mf8_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vmaxu_vv)))
vuint16m1_t vmaxu_vv_u16m1(vuint16m1_t, vuint16m1_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vmaxu_vv_m)))
vuint16m1_t vmaxu_vv_u16m1_m(vbool16_t, vuint16m1_t, vuint16m1_t, vuint16m1_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vmaxu_vv)))
vuint16m2_t vmaxu_vv_u16m2(vuint16m2_t, vuint16m2_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vmaxu_vv_m)))
vuint16m2_t vmaxu_vv_u16m2_m(vbool8_t, vuint16m2_t, vuint16m2_t, vuint16m2_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vmaxu_vv)))
vuint16m4_t vmaxu_vv_u16m4(vuint16m4_t, vuint16m4_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vmaxu_vv_m)))
vuint16m4_t vmaxu_vv_u16m4_m(vbool4_t, vuint16m4_t, vuint16m4_t, vuint16m4_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vmaxu_vv)))
vuint16m8_t vmaxu_vv_u16m8(vuint16m8_t, vuint16m8_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vmaxu_vv_m)))
vuint16m8_t vmaxu_vv_u16m8_m(vbool2_t, vuint16m8_t, vuint16m8_t, vuint16m8_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vmaxu_vv)))
vuint16mf2_t vmaxu_vv_u16mf2(vuint16mf2_t, vuint16mf2_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vmaxu_vv_m)))
vuint16mf2_t vmaxu_vv_u16mf2_m(vbool32_t, vuint16mf2_t, vuint16mf2_t, vuint16mf2_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vmaxu_vv)))
vuint16mf4_t vmaxu_vv_u16mf4(vuint16mf4_t, vuint16mf4_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vmaxu_vv_m)))
vuint16mf4_t vmaxu_vv_u16mf4_m(vbool64_t, vuint16mf4_t, vuint16mf4_t, vuint16mf4_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vmaxu_vv)))
vuint32m1_t vmaxu_vv_u32m1(vuint32m1_t, vuint32m1_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vmaxu_vv_m)))
vuint32m1_t vmaxu_vv_u32m1_m(vbool32_t, vuint32m1_t, vuint32m1_t, vuint32m1_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vmaxu_vv)))
vuint32m2_t vmaxu_vv_u32m2(vuint32m2_t, vuint32m2_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vmaxu_vv_m)))
vuint32m2_t vmaxu_vv_u32m2_m(vbool16_t, vuint32m2_t, vuint32m2_t, vuint32m2_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vmaxu_vv)))
vuint32m4_t vmaxu_vv_u32m4(vuint32m4_t, vuint32m4_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vmaxu_vv_m)))
vuint32m4_t vmaxu_vv_u32m4_m(vbool8_t, vuint32m4_t, vuint32m4_t, vuint32m4_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vmaxu_vv)))
vuint32m8_t vmaxu_vv_u32m8(vuint32m8_t, vuint32m8_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vmaxu_vv_m)))
vuint32m8_t vmaxu_vv_u32m8_m(vbool4_t, vuint32m8_t, vuint32m8_t, vuint32m8_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vmaxu_vv)))
vuint32mf2_t vmaxu_vv_u32mf2(vuint32mf2_t, vuint32mf2_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vmaxu_vv_m)))
vuint32mf2_t vmaxu_vv_u32mf2_m(vbool64_t, vuint32mf2_t, vuint32mf2_t, vuint32mf2_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vmaxu_vx)))
vuint8m1_t vmaxu_vx_u8m1(vuint8m1_t, uint8_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vmaxu_vx_m)))
vuint8m1_t vmaxu_vx_u8m1_m(vbool8_t, vuint8m1_t, vuint8m1_t, uint8_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vmaxu_vx)))
vuint8m2_t vmaxu_vx_u8m2(vuint8m2_t, uint8_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vmaxu_vx_m)))
vuint8m2_t vmaxu_vx_u8m2_m(vbool4_t, vuint8m2_t, vuint8m2_t, uint8_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vmaxu_vx)))
vuint8m4_t vmaxu_vx_u8m4(vuint8m4_t, uint8_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vmaxu_vx_m)))
vuint8m4_t vmaxu_vx_u8m4_m(vbool2_t, vuint8m4_t, vuint8m4_t, uint8_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vmaxu_vx)))
vuint8m8_t vmaxu_vx_u8m8(vuint8m8_t, uint8_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vmaxu_vx_m)))
vuint8m8_t vmaxu_vx_u8m8_m(vbool1_t, vuint8m8_t, vuint8m8_t, uint8_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vmaxu_vx)))
vuint8mf2_t vmaxu_vx_u8mf2(vuint8mf2_t, uint8_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vmaxu_vx_m)))
vuint8mf2_t vmaxu_vx_u8mf2_m(vbool16_t, vuint8mf2_t, vuint8mf2_t, uint8_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vmaxu_vx)))
vuint8mf4_t vmaxu_vx_u8mf4(vuint8mf4_t, uint8_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vmaxu_vx_m)))
vuint8mf4_t vmaxu_vx_u8mf4_m(vbool32_t, vuint8mf4_t, vuint8mf4_t, uint8_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vmaxu_vx)))
vuint8mf8_t vmaxu_vx_u8mf8(vuint8mf8_t, uint8_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vmaxu_vx_m)))
vuint8mf8_t vmaxu_vx_u8mf8_m(vbool64_t, vuint8mf8_t, vuint8mf8_t, uint8_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vmaxu_vx)))
vuint16m1_t vmaxu_vx_u16m1(vuint16m1_t, uint16_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vmaxu_vx_m)))
vuint16m1_t vmaxu_vx_u16m1_m(vbool16_t, vuint16m1_t, vuint16m1_t, uint16_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vmaxu_vx)))
vuint16m2_t vmaxu_vx_u16m2(vuint16m2_t, uint16_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vmaxu_vx_m)))
vuint16m2_t vmaxu_vx_u16m2_m(vbool8_t, vuint16m2_t, vuint16m2_t, uint16_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vmaxu_vx)))
vuint16m4_t vmaxu_vx_u16m4(vuint16m4_t, uint16_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vmaxu_vx_m)))
vuint16m4_t vmaxu_vx_u16m4_m(vbool4_t, vuint16m4_t, vuint16m4_t, uint16_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vmaxu_vx)))
vuint16m8_t vmaxu_vx_u16m8(vuint16m8_t, uint16_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vmaxu_vx_m)))
vuint16m8_t vmaxu_vx_u16m8_m(vbool2_t, vuint16m8_t, vuint16m8_t, uint16_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vmaxu_vx)))
vuint16mf2_t vmaxu_vx_u16mf2(vuint16mf2_t, uint16_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vmaxu_vx_m)))
vuint16mf2_t vmaxu_vx_u16mf2_m(vbool32_t, vuint16mf2_t, vuint16mf2_t, uint16_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vmaxu_vx)))
vuint16mf4_t vmaxu_vx_u16mf4(vuint16mf4_t, uint16_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vmaxu_vx_m)))
vuint16mf4_t vmaxu_vx_u16mf4_m(vbool64_t, vuint16mf4_t, vuint16mf4_t, uint16_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vmaxu_vx)))
vuint32m1_t vmaxu_vx_u32m1(vuint32m1_t, uint32_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vmaxu_vx_m)))
vuint32m1_t vmaxu_vx_u32m1_m(vbool32_t, vuint32m1_t, vuint32m1_t, uint32_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vmaxu_vx)))
vuint32m2_t vmaxu_vx_u32m2(vuint32m2_t, uint32_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vmaxu_vx_m)))
vuint32m2_t vmaxu_vx_u32m2_m(vbool16_t, vuint32m2_t, vuint32m2_t, uint32_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vmaxu_vx)))
vuint32m4_t vmaxu_vx_u32m4(vuint32m4_t, uint32_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vmaxu_vx_m)))
vuint32m4_t vmaxu_vx_u32m4_m(vbool8_t, vuint32m4_t, vuint32m4_t, uint32_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vmaxu_vx)))
vuint32m8_t vmaxu_vx_u32m8(vuint32m8_t, uint32_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vmaxu_vx_m)))
vuint32m8_t vmaxu_vx_u32m8_m(vbool4_t, vuint32m8_t, vuint32m8_t, uint32_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vmaxu_vx)))
vuint32mf2_t vmaxu_vx_u32mf2(vuint32mf2_t, uint32_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vmaxu_vx_m)))
vuint32mf2_t vmaxu_vx_u32mf2_m(vbool64_t, vuint32mf2_t, vuint32mf2_t, uint32_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vmax_vv)))
vint8m1_t vmax_vv_i8m1(vint8m1_t, vint8m1_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vmax_vv_m)))
vint8m1_t vmax_vv_i8m1_m(vbool8_t, vint8m1_t, vint8m1_t, vint8m1_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vmax_vv)))
vint8m2_t vmax_vv_i8m2(vint8m2_t, vint8m2_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vmax_vv_m)))
vint8m2_t vmax_vv_i8m2_m(vbool4_t, vint8m2_t, vint8m2_t, vint8m2_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vmax_vv)))
vint8m4_t vmax_vv_i8m4(vint8m4_t, vint8m4_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vmax_vv_m)))
vint8m4_t vmax_vv_i8m4_m(vbool2_t, vint8m4_t, vint8m4_t, vint8m4_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vmax_vv)))
vint8m8_t vmax_vv_i8m8(vint8m8_t, vint8m8_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vmax_vv_m)))
vint8m8_t vmax_vv_i8m8_m(vbool1_t, vint8m8_t, vint8m8_t, vint8m8_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vmax_vv)))
vint8mf2_t vmax_vv_i8mf2(vint8mf2_t, vint8mf2_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vmax_vv_m)))
vint8mf2_t vmax_vv_i8mf2_m(vbool16_t, vint8mf2_t, vint8mf2_t, vint8mf2_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vmax_vv)))
vint8mf4_t vmax_vv_i8mf4(vint8mf4_t, vint8mf4_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vmax_vv_m)))
vint8mf4_t vmax_vv_i8mf4_m(vbool32_t, vint8mf4_t, vint8mf4_t, vint8mf4_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vmax_vv)))
vint8mf8_t vmax_vv_i8mf8(vint8mf8_t, vint8mf8_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vmax_vv_m)))
vint8mf8_t vmax_vv_i8mf8_m(vbool64_t, vint8mf8_t, vint8mf8_t, vint8mf8_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vmax_vv)))
vint16m1_t vmax_vv_i16m1(vint16m1_t, vint16m1_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vmax_vv_m)))
vint16m1_t vmax_vv_i16m1_m(vbool16_t, vint16m1_t, vint16m1_t, vint16m1_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vmax_vv)))
vint16m2_t vmax_vv_i16m2(vint16m2_t, vint16m2_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vmax_vv_m)))
vint16m2_t vmax_vv_i16m2_m(vbool8_t, vint16m2_t, vint16m2_t, vint16m2_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vmax_vv)))
vint16m4_t vmax_vv_i16m4(vint16m4_t, vint16m4_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vmax_vv_m)))
vint16m4_t vmax_vv_i16m4_m(vbool4_t, vint16m4_t, vint16m4_t, vint16m4_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vmax_vv)))
vint16m8_t vmax_vv_i16m8(vint16m8_t, vint16m8_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vmax_vv_m)))
vint16m8_t vmax_vv_i16m8_m(vbool2_t, vint16m8_t, vint16m8_t, vint16m8_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vmax_vv)))
vint16mf2_t vmax_vv_i16mf2(vint16mf2_t, vint16mf2_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vmax_vv_m)))
vint16mf2_t vmax_vv_i16mf2_m(vbool32_t, vint16mf2_t, vint16mf2_t, vint16mf2_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vmax_vv)))
vint16mf4_t vmax_vv_i16mf4(vint16mf4_t, vint16mf4_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vmax_vv_m)))
vint16mf4_t vmax_vv_i16mf4_m(vbool64_t, vint16mf4_t, vint16mf4_t, vint16mf4_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vmax_vv)))
vint32m1_t vmax_vv_i32m1(vint32m1_t, vint32m1_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vmax_vv_m)))
vint32m1_t vmax_vv_i32m1_m(vbool32_t, vint32m1_t, vint32m1_t, vint32m1_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vmax_vv)))
vint32m2_t vmax_vv_i32m2(vint32m2_t, vint32m2_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vmax_vv_m)))
vint32m2_t vmax_vv_i32m2_m(vbool16_t, vint32m2_t, vint32m2_t, vint32m2_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vmax_vv)))
vint32m4_t vmax_vv_i32m4(vint32m4_t, vint32m4_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vmax_vv_m)))
vint32m4_t vmax_vv_i32m4_m(vbool8_t, vint32m4_t, vint32m4_t, vint32m4_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vmax_vv)))
vint32m8_t vmax_vv_i32m8(vint32m8_t, vint32m8_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vmax_vv_m)))
vint32m8_t vmax_vv_i32m8_m(vbool4_t, vint32m8_t, vint32m8_t, vint32m8_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vmax_vv)))
vint32mf2_t vmax_vv_i32mf2(vint32mf2_t, vint32mf2_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vmax_vv_m)))
vint32mf2_t vmax_vv_i32mf2_m(vbool64_t, vint32mf2_t, vint32mf2_t, vint32mf2_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vsuxei16_v)))
void vsuxei16_v_u8m1(uint8_t *, vuint16m2_t, vuint8m1_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vsuxei16_v_m)))
void vsuxei16_v_u8m1_m(vbool8_t, uint8_t *, vuint16m2_t, vuint8m1_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vsuxei16_v)))
void vsuxei16_v_u8m2(uint8_t *, vuint16m4_t, vuint8m2_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vsuxei16_v_m)))
void vsuxei16_v_u8m2_m(vbool4_t, uint8_t *, vuint16m4_t, vuint8m2_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vsuxei16_v)))
void vsuxei16_v_u8m4(uint8_t *, vuint16m8_t, vuint8m4_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vsuxei16_v_m)))
void vsuxei16_v_u8m4_m(vbool2_t, uint8_t *, vuint16m8_t, vuint8m4_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vsuxei16_v)))
void vsuxei16_v_u8mf2(uint8_t *, vuint16m1_t, vuint8mf2_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vsuxei16_v_m)))
void vsuxei16_v_u8mf2_m(vbool16_t, uint8_t *, vuint16m1_t, vuint8mf2_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vsuxei16_v)))
void vsuxei16_v_u8mf4(uint8_t *, vuint16mf2_t, vuint8mf4_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vsuxei16_v_m)))
void vsuxei16_v_u8mf4_m(vbool32_t, uint8_t *, vuint16mf2_t, vuint8mf4_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vsuxei16_v)))
void vsuxei16_v_u8mf8(uint8_t *, vuint16mf4_t, vuint8mf8_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vsuxei16_v_m)))
void vsuxei16_v_u8mf8_m(vbool64_t, uint8_t *, vuint16mf4_t, vuint8mf8_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vmax_vx)))
vint8m1_t vmax_vx_i8m1(vint8m1_t, int8_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vmax_vx_m)))
vint8m1_t vmax_vx_i8m1_m(vbool8_t, vint8m1_t, vint8m1_t, int8_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vmax_vx)))
vint8m2_t vmax_vx_i8m2(vint8m2_t, int8_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vmax_vx_m)))
vint8m2_t vmax_vx_i8m2_m(vbool4_t, vint8m2_t, vint8m2_t, int8_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vmax_vx)))
vint8m4_t vmax_vx_i8m4(vint8m4_t, int8_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vmax_vx_m)))
vint8m4_t vmax_vx_i8m4_m(vbool2_t, vint8m4_t, vint8m4_t, int8_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vmax_vx)))
vint8m8_t vmax_vx_i8m8(vint8m8_t, int8_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vmax_vx_m)))
vint8m8_t vmax_vx_i8m8_m(vbool1_t, vint8m8_t, vint8m8_t, int8_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vmax_vx)))
vint8mf2_t vmax_vx_i8mf2(vint8mf2_t, int8_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vmax_vx_m)))
vint8mf2_t vmax_vx_i8mf2_m(vbool16_t, vint8mf2_t, vint8mf2_t, int8_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vmax_vx)))
vint8mf4_t vmax_vx_i8mf4(vint8mf4_t, int8_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vmax_vx_m)))
vint8mf4_t vmax_vx_i8mf4_m(vbool32_t, vint8mf4_t, vint8mf4_t, int8_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vmax_vx)))
vint8mf8_t vmax_vx_i8mf8(vint8mf8_t, int8_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vmax_vx_m)))
vint8mf8_t vmax_vx_i8mf8_m(vbool64_t, vint8mf8_t, vint8mf8_t, int8_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vmax_vx)))
vint16m1_t vmax_vx_i16m1(vint16m1_t, int16_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vmax_vx_m)))
vint16m1_t vmax_vx_i16m1_m(vbool16_t, vint16m1_t, vint16m1_t, int16_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vmax_vx)))
vint16m2_t vmax_vx_i16m2(vint16m2_t, int16_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vmax_vx_m)))
vint16m2_t vmax_vx_i16m2_m(vbool8_t, vint16m2_t, vint16m2_t, int16_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vmax_vx)))
vint16m4_t vmax_vx_i16m4(vint16m4_t, int16_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vmax_vx_m)))
vint16m4_t vmax_vx_i16m4_m(vbool4_t, vint16m4_t, vint16m4_t, int16_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vmax_vx)))
vint16m8_t vmax_vx_i16m8(vint16m8_t, int16_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vmax_vx_m)))
vint16m8_t vmax_vx_i16m8_m(vbool2_t, vint16m8_t, vint16m8_t, int16_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vmax_vx)))
vint16mf2_t vmax_vx_i16mf2(vint16mf2_t, int16_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vmax_vx_m)))
vint16mf2_t vmax_vx_i16mf2_m(vbool32_t, vint16mf2_t, vint16mf2_t, int16_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vmax_vx)))
vint16mf4_t vmax_vx_i16mf4(vint16mf4_t, int16_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vmax_vx_m)))
vint16mf4_t vmax_vx_i16mf4_m(vbool64_t, vint16mf4_t, vint16mf4_t, int16_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vmax_vx)))
vint32m1_t vmax_vx_i32m1(vint32m1_t, int32_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vmax_vx_m)))
vint32m1_t vmax_vx_i32m1_m(vbool32_t, vint32m1_t, vint32m1_t, int32_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vmax_vx)))
vint32m2_t vmax_vx_i32m2(vint32m2_t, int32_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vmax_vx_m)))
vint32m2_t vmax_vx_i32m2_m(vbool16_t, vint32m2_t, vint32m2_t, int32_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vmax_vx)))
vint32m4_t vmax_vx_i32m4(vint32m4_t, int32_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vmax_vx_m)))
vint32m4_t vmax_vx_i32m4_m(vbool8_t, vint32m4_t, vint32m4_t, int32_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vmax_vx)))
vint32m8_t vmax_vx_i32m8(vint32m8_t, int32_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vmax_vx_m)))
vint32m8_t vmax_vx_i32m8_m(vbool4_t, vint32m8_t, vint32m8_t, int32_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vmax_vx)))
vint32mf2_t vmax_vx_i32mf2(vint32mf2_t, int32_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vmax_vx_m)))
vint32mf2_t vmax_vx_i32mf2_m(vbool64_t, vint32mf2_t, vint32mf2_t, int32_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vmul_vv)))
vint8m1_t vmul_vv_i8m1(vint8m1_t, vint8m1_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vmul_vv_m)))
vint8m1_t vmul_vv_i8m1_m(vbool8_t, vint8m1_t, vint8m1_t, vint8m1_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vmul_vv)))
vint8m2_t vmul_vv_i8m2(vint8m2_t, vint8m2_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vmul_vv_m)))
vint8m2_t vmul_vv_i8m2_m(vbool4_t, vint8m2_t, vint8m2_t, vint8m2_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vmul_vv)))
vint8m4_t vmul_vv_i8m4(vint8m4_t, vint8m4_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vmul_vv_m)))
vint8m4_t vmul_vv_i8m4_m(vbool2_t, vint8m4_t, vint8m4_t, vint8m4_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vmul_vv)))
vint8m8_t vmul_vv_i8m8(vint8m8_t, vint8m8_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vmul_vv_m)))
vint8m8_t vmul_vv_i8m8_m(vbool1_t, vint8m8_t, vint8m8_t, vint8m8_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vmul_vv)))
vint8mf2_t vmul_vv_i8mf2(vint8mf2_t, vint8mf2_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vmul_vv_m)))
vint8mf2_t vmul_vv_i8mf2_m(vbool16_t, vint8mf2_t, vint8mf2_t, vint8mf2_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vmul_vv)))
vint8mf4_t vmul_vv_i8mf4(vint8mf4_t, vint8mf4_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vmul_vv_m)))
vint8mf4_t vmul_vv_i8mf4_m(vbool32_t, vint8mf4_t, vint8mf4_t, vint8mf4_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vmul_vv)))
vint8mf8_t vmul_vv_i8mf8(vint8mf8_t, vint8mf8_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vmul_vv_m)))
vint8mf8_t vmul_vv_i8mf8_m(vbool64_t, vint8mf8_t, vint8mf8_t, vint8mf8_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vmul_vv)))
vint16m1_t vmul_vv_i16m1(vint16m1_t, vint16m1_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vmul_vv_m)))
vint16m1_t vmul_vv_i16m1_m(vbool16_t, vint16m1_t, vint16m1_t, vint16m1_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vmul_vv)))
vint16m2_t vmul_vv_i16m2(vint16m2_t, vint16m2_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vmul_vv_m)))
vint16m2_t vmul_vv_i16m2_m(vbool8_t, vint16m2_t, vint16m2_t, vint16m2_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vmul_vv)))
vint16m4_t vmul_vv_i16m4(vint16m4_t, vint16m4_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vmul_vv_m)))
vint16m4_t vmul_vv_i16m4_m(vbool4_t, vint16m4_t, vint16m4_t, vint16m4_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vmul_vv)))
vint16m8_t vmul_vv_i16m8(vint16m8_t, vint16m8_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vmul_vv_m)))
vint16m8_t vmul_vv_i16m8_m(vbool2_t, vint16m8_t, vint16m8_t, vint16m8_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vmul_vv)))
vint16mf2_t vmul_vv_i16mf2(vint16mf2_t, vint16mf2_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vmul_vv_m)))
vint16mf2_t vmul_vv_i16mf2_m(vbool32_t, vint16mf2_t, vint16mf2_t, vint16mf2_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vmul_vv)))
vint16mf4_t vmul_vv_i16mf4(vint16mf4_t, vint16mf4_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vmul_vv_m)))
vint16mf4_t vmul_vv_i16mf4_m(vbool64_t, vint16mf4_t, vint16mf4_t, vint16mf4_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vmul_vv)))
vint32m1_t vmul_vv_i32m1(vint32m1_t, vint32m1_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vmul_vv_m)))
vint32m1_t vmul_vv_i32m1_m(vbool32_t, vint32m1_t, vint32m1_t, vint32m1_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vmul_vv)))
vint32m2_t vmul_vv_i32m2(vint32m2_t, vint32m2_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vmul_vv_m)))
vint32m2_t vmul_vv_i32m2_m(vbool16_t, vint32m2_t, vint32m2_t, vint32m2_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vmul_vv)))
vint32m4_t vmul_vv_i32m4(vint32m4_t, vint32m4_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vmul_vv_m)))
vint32m4_t vmul_vv_i32m4_m(vbool8_t, vint32m4_t, vint32m4_t, vint32m4_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vmul_vv)))
vint32m8_t vmul_vv_i32m8(vint32m8_t, vint32m8_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vmul_vv_m)))
vint32m8_t vmul_vv_i32m8_m(vbool4_t, vint32m8_t, vint32m8_t, vint32m8_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vmul_vv)))
vint32mf2_t vmul_vv_i32mf2(vint32mf2_t, vint32mf2_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vmul_vv_m)))
vint32mf2_t vmul_vv_i32mf2_m(vbool64_t, vint32mf2_t, vint32mf2_t, vint32mf2_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vmul_vx)))
vint8m1_t vmul_vx_i8m1(vint8m1_t, int8_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vmul_vx_m)))
vint8m1_t vmul_vx_i8m1_m(vbool8_t, vint8m1_t, vint8m1_t, int8_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vmul_vx)))
vint8m2_t vmul_vx_i8m2(vint8m2_t, int8_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vmul_vx_m)))
vint8m2_t vmul_vx_i8m2_m(vbool4_t, vint8m2_t, vint8m2_t, int8_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vmul_vx)))
vint8m4_t vmul_vx_i8m4(vint8m4_t, int8_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vmul_vx_m)))
vint8m4_t vmul_vx_i8m4_m(vbool2_t, vint8m4_t, vint8m4_t, int8_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vmul_vx)))
vint8m8_t vmul_vx_i8m8(vint8m8_t, int8_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vmul_vx_m)))
vint8m8_t vmul_vx_i8m8_m(vbool1_t, vint8m8_t, vint8m8_t, int8_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vmul_vx)))
vint8mf2_t vmul_vx_i8mf2(vint8mf2_t, int8_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vmul_vx_m)))
vint8mf2_t vmul_vx_i8mf2_m(vbool16_t, vint8mf2_t, vint8mf2_t, int8_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vmul_vx)))
vint8mf4_t vmul_vx_i8mf4(vint8mf4_t, int8_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vmul_vx_m)))
vint8mf4_t vmul_vx_i8mf4_m(vbool32_t, vint8mf4_t, vint8mf4_t, int8_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vmul_vx)))
vint8mf8_t vmul_vx_i8mf8(vint8mf8_t, int8_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vmul_vx_m)))
vint8mf8_t vmul_vx_i8mf8_m(vbool64_t, vint8mf8_t, vint8mf8_t, int8_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vmul_vx)))
vint16m1_t vmul_vx_i16m1(vint16m1_t, int16_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vmul_vx_m)))
vint16m1_t vmul_vx_i16m1_m(vbool16_t, vint16m1_t, vint16m1_t, int16_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vmul_vx)))
vint16m2_t vmul_vx_i16m2(vint16m2_t, int16_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vmul_vx_m)))
vint16m2_t vmul_vx_i16m2_m(vbool8_t, vint16m2_t, vint16m2_t, int16_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vmul_vx)))
vint16m4_t vmul_vx_i16m4(vint16m4_t, int16_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vmul_vx_m)))
vint16m4_t vmul_vx_i16m4_m(vbool4_t, vint16m4_t, vint16m4_t, int16_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vmul_vx)))
vint16m8_t vmul_vx_i16m8(vint16m8_t, int16_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vmul_vx_m)))
vint16m8_t vmul_vx_i16m8_m(vbool2_t, vint16m8_t, vint16m8_t, int16_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vmul_vx)))
vint16mf2_t vmul_vx_i16mf2(vint16mf2_t, int16_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vmul_vx_m)))
vint16mf2_t vmul_vx_i16mf2_m(vbool32_t, vint16mf2_t, vint16mf2_t, int16_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vmul_vx)))
vint16mf4_t vmul_vx_i16mf4(vint16mf4_t, int16_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vmul_vx_m)))
vint16mf4_t vmul_vx_i16mf4_m(vbool64_t, vint16mf4_t, vint16mf4_t, int16_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vmul_vx)))
vint32m1_t vmul_vx_i32m1(vint32m1_t, int32_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vmul_vx_m)))
vint32m1_t vmul_vx_i32m1_m(vbool32_t, vint32m1_t, vint32m1_t, int32_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vmul_vx)))
vint32m2_t vmul_vx_i32m2(vint32m2_t, int32_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vmul_vx_m)))
vint32m2_t vmul_vx_i32m2_m(vbool16_t, vint32m2_t, vint32m2_t, int32_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vmul_vx)))
vint32m4_t vmul_vx_i32m4(vint32m4_t, int32_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vmul_vx_m)))
vint32m4_t vmul_vx_i32m4_m(vbool8_t, vint32m4_t, vint32m4_t, int32_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vmul_vx)))
vint32m8_t vmul_vx_i32m8(vint32m8_t, int32_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vmul_vx_m)))
vint32m8_t vmul_vx_i32m8_m(vbool4_t, vint32m8_t, vint32m8_t, int32_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vmul_vx)))
vint32mf2_t vmul_vx_i32mf2(vint32mf2_t, int32_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vmul_vx_m)))
vint32mf2_t vmul_vx_i32mf2_m(vbool64_t, vint32mf2_t, vint32mf2_t, int32_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vmul_vv)))
vuint8m1_t vmul_vv_u8m1(vuint8m1_t, vuint8m1_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vmul_vv_m)))
vuint8m1_t vmul_vv_u8m1_m(vbool8_t, vuint8m1_t, vuint8m1_t, vuint8m1_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vmul_vv)))
vuint8m2_t vmul_vv_u8m2(vuint8m2_t, vuint8m2_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vmul_vv_m)))
vuint8m2_t vmul_vv_u8m2_m(vbool4_t, vuint8m2_t, vuint8m2_t, vuint8m2_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vmul_vv)))
vuint8m4_t vmul_vv_u8m4(vuint8m4_t, vuint8m4_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vmul_vv_m)))
vuint8m4_t vmul_vv_u8m4_m(vbool2_t, vuint8m4_t, vuint8m4_t, vuint8m4_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vmul_vv)))
vuint8m8_t vmul_vv_u8m8(vuint8m8_t, vuint8m8_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vmul_vv_m)))
vuint8m8_t vmul_vv_u8m8_m(vbool1_t, vuint8m8_t, vuint8m8_t, vuint8m8_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vmul_vv)))
vuint8mf2_t vmul_vv_u8mf2(vuint8mf2_t, vuint8mf2_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vmul_vv_m)))
vuint8mf2_t vmul_vv_u8mf2_m(vbool16_t, vuint8mf2_t, vuint8mf2_t, vuint8mf2_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vmul_vv)))
vuint8mf4_t vmul_vv_u8mf4(vuint8mf4_t, vuint8mf4_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vmul_vv_m)))
vuint8mf4_t vmul_vv_u8mf4_m(vbool32_t, vuint8mf4_t, vuint8mf4_t, vuint8mf4_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vmul_vv)))
vuint8mf8_t vmul_vv_u8mf8(vuint8mf8_t, vuint8mf8_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vmul_vv_m)))
vuint8mf8_t vmul_vv_u8mf8_m(vbool64_t, vuint8mf8_t, vuint8mf8_t, vuint8mf8_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vmul_vv)))
vuint16m1_t vmul_vv_u16m1(vuint16m1_t, vuint16m1_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vmul_vv_m)))
vuint16m1_t vmul_vv_u16m1_m(vbool16_t, vuint16m1_t, vuint16m1_t, vuint16m1_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vmul_vv)))
vuint16m2_t vmul_vv_u16m2(vuint16m2_t, vuint16m2_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vmul_vv_m)))
vuint16m2_t vmul_vv_u16m2_m(vbool8_t, vuint16m2_t, vuint16m2_t, vuint16m2_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vmul_vv)))
vuint16m4_t vmul_vv_u16m4(vuint16m4_t, vuint16m4_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vmul_vv_m)))
vuint16m4_t vmul_vv_u16m4_m(vbool4_t, vuint16m4_t, vuint16m4_t, vuint16m4_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vmul_vv)))
vuint16m8_t vmul_vv_u16m8(vuint16m8_t, vuint16m8_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vmul_vv_m)))
vuint16m8_t vmul_vv_u16m8_m(vbool2_t, vuint16m8_t, vuint16m8_t, vuint16m8_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vmul_vv)))
vuint16mf2_t vmul_vv_u16mf2(vuint16mf2_t, vuint16mf2_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vmul_vv_m)))
vuint16mf2_t vmul_vv_u16mf2_m(vbool32_t, vuint16mf2_t, vuint16mf2_t, vuint16mf2_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vmul_vv)))
vuint16mf4_t vmul_vv_u16mf4(vuint16mf4_t, vuint16mf4_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vmul_vv_m)))
vuint16mf4_t vmul_vv_u16mf4_m(vbool64_t, vuint16mf4_t, vuint16mf4_t, vuint16mf4_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vmul_vv)))
vuint32m1_t vmul_vv_u32m1(vuint32m1_t, vuint32m1_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vmul_vv_m)))
vuint32m1_t vmul_vv_u32m1_m(vbool32_t, vuint32m1_t, vuint32m1_t, vuint32m1_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vmul_vv)))
vuint32m2_t vmul_vv_u32m2(vuint32m2_t, vuint32m2_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vmul_vv_m)))
vuint32m2_t vmul_vv_u32m2_m(vbool16_t, vuint32m2_t, vuint32m2_t, vuint32m2_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vmul_vv)))
vuint32m4_t vmul_vv_u32m4(vuint32m4_t, vuint32m4_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vmul_vv_m)))
vuint32m4_t vmul_vv_u32m4_m(vbool8_t, vuint32m4_t, vuint32m4_t, vuint32m4_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vmul_vv)))
vuint32m8_t vmul_vv_u32m8(vuint32m8_t, vuint32m8_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vmul_vv_m)))
vuint32m8_t vmul_vv_u32m8_m(vbool4_t, vuint32m8_t, vuint32m8_t, vuint32m8_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vmul_vv)))
vuint32mf2_t vmul_vv_u32mf2(vuint32mf2_t, vuint32mf2_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vmul_vv_m)))
vuint32mf2_t vmul_vv_u32mf2_m(vbool64_t, vuint32mf2_t, vuint32mf2_t, vuint32mf2_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vmul_vx)))
vuint8m1_t vmul_vx_u8m1(vuint8m1_t, uint8_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vmul_vx_m)))
vuint8m1_t vmul_vx_u8m1_m(vbool8_t, vuint8m1_t, vuint8m1_t, uint8_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vmul_vx)))
vuint8m2_t vmul_vx_u8m2(vuint8m2_t, uint8_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vmul_vx_m)))
vuint8m2_t vmul_vx_u8m2_m(vbool4_t, vuint8m2_t, vuint8m2_t, uint8_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vmul_vx)))
vuint8m4_t vmul_vx_u8m4(vuint8m4_t, uint8_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vmul_vx_m)))
vuint8m4_t vmul_vx_u8m4_m(vbool2_t, vuint8m4_t, vuint8m4_t, uint8_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vmul_vx)))
vuint8m8_t vmul_vx_u8m8(vuint8m8_t, uint8_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vmul_vx_m)))
vuint8m8_t vmul_vx_u8m8_m(vbool1_t, vuint8m8_t, vuint8m8_t, uint8_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vmul_vx)))
vuint8mf2_t vmul_vx_u8mf2(vuint8mf2_t, uint8_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vmul_vx_m)))
vuint8mf2_t vmul_vx_u8mf2_m(vbool16_t, vuint8mf2_t, vuint8mf2_t, uint8_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vmul_vx)))
vuint8mf4_t vmul_vx_u8mf4(vuint8mf4_t, uint8_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vmul_vx_m)))
vuint8mf4_t vmul_vx_u8mf4_m(vbool32_t, vuint8mf4_t, vuint8mf4_t, uint8_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vmul_vx)))
vuint8mf8_t vmul_vx_u8mf8(vuint8mf8_t, uint8_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vmul_vx_m)))
vuint8mf8_t vmul_vx_u8mf8_m(vbool64_t, vuint8mf8_t, vuint8mf8_t, uint8_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vmul_vx)))
vuint16m1_t vmul_vx_u16m1(vuint16m1_t, uint16_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vmul_vx_m)))
vuint16m1_t vmul_vx_u16m1_m(vbool16_t, vuint16m1_t, vuint16m1_t, uint16_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vmul_vx)))
vuint16m2_t vmul_vx_u16m2(vuint16m2_t, uint16_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vmul_vx_m)))
vuint16m2_t vmul_vx_u16m2_m(vbool8_t, vuint16m2_t, vuint16m2_t, uint16_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vmul_vx)))
vuint16m4_t vmul_vx_u16m4(vuint16m4_t, uint16_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vmul_vx_m)))
vuint16m4_t vmul_vx_u16m4_m(vbool4_t, vuint16m4_t, vuint16m4_t, uint16_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vmul_vx)))
vuint16m8_t vmul_vx_u16m8(vuint16m8_t, uint16_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vmul_vx_m)))
vuint16m8_t vmul_vx_u16m8_m(vbool2_t, vuint16m8_t, vuint16m8_t, uint16_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vmul_vx)))
vuint16mf2_t vmul_vx_u16mf2(vuint16mf2_t, uint16_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vmul_vx_m)))
vuint16mf2_t vmul_vx_u16mf2_m(vbool32_t, vuint16mf2_t, vuint16mf2_t, uint16_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vmul_vx)))
vuint16mf4_t vmul_vx_u16mf4(vuint16mf4_t, uint16_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vmul_vx_m)))
vuint16mf4_t vmul_vx_u16mf4_m(vbool64_t, vuint16mf4_t, vuint16mf4_t, uint16_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vmul_vx)))
vuint32m1_t vmul_vx_u32m1(vuint32m1_t, uint32_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vmul_vx_m)))
vuint32m1_t vmul_vx_u32m1_m(vbool32_t, vuint32m1_t, vuint32m1_t, uint32_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vmul_vx)))
vuint32m2_t vmul_vx_u32m2(vuint32m2_t, uint32_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vmul_vx_m)))
vuint32m2_t vmul_vx_u32m2_m(vbool16_t, vuint32m2_t, vuint32m2_t, uint32_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vmul_vx)))
vuint32m4_t vmul_vx_u32m4(vuint32m4_t, uint32_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vmul_vx_m)))
vuint32m4_t vmul_vx_u32m4_m(vbool8_t, vuint32m4_t, vuint32m4_t, uint32_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vmul_vx)))
vuint32m8_t vmul_vx_u32m8(vuint32m8_t, uint32_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vmul_vx_m)))
vuint32m8_t vmul_vx_u32m8_m(vbool4_t, vuint32m8_t, vuint32m8_t, uint32_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vmul_vx)))
vuint32mf2_t vmul_vx_u32mf2(vuint32mf2_t, uint32_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vmul_vx_m)))
vuint32mf2_t vmul_vx_u32mf2_m(vbool64_t, vuint32mf2_t, vuint32mf2_t, uint32_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vmulh_vv)))
vint8m1_t vmulh_vv_i8m1(vint8m1_t, vint8m1_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vmulh_vv_m)))
vint8m1_t vmulh_vv_i8m1_m(vbool8_t, vint8m1_t, vint8m1_t, vint8m1_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vmulh_vv)))
vint8m2_t vmulh_vv_i8m2(vint8m2_t, vint8m2_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vmulh_vv_m)))
vint8m2_t vmulh_vv_i8m2_m(vbool4_t, vint8m2_t, vint8m2_t, vint8m2_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vmulh_vv)))
vint8m4_t vmulh_vv_i8m4(vint8m4_t, vint8m4_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vmulh_vv_m)))
vint8m4_t vmulh_vv_i8m4_m(vbool2_t, vint8m4_t, vint8m4_t, vint8m4_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vmulh_vv)))
vint8m8_t vmulh_vv_i8m8(vint8m8_t, vint8m8_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vmulh_vv_m)))
vint8m8_t vmulh_vv_i8m8_m(vbool1_t, vint8m8_t, vint8m8_t, vint8m8_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vmulh_vv)))
vint8mf2_t vmulh_vv_i8mf2(vint8mf2_t, vint8mf2_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vmulh_vv_m)))
vint8mf2_t vmulh_vv_i8mf2_m(vbool16_t, vint8mf2_t, vint8mf2_t, vint8mf2_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vmulh_vv)))
vint8mf4_t vmulh_vv_i8mf4(vint8mf4_t, vint8mf4_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vmulh_vv_m)))
vint8mf4_t vmulh_vv_i8mf4_m(vbool32_t, vint8mf4_t, vint8mf4_t, vint8mf4_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vmulh_vv)))
vint8mf8_t vmulh_vv_i8mf8(vint8mf8_t, vint8mf8_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vmulh_vv_m)))
vint8mf8_t vmulh_vv_i8mf8_m(vbool64_t, vint8mf8_t, vint8mf8_t, vint8mf8_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vmulh_vv)))
vint16m1_t vmulh_vv_i16m1(vint16m1_t, vint16m1_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vmulh_vv_m)))
vint16m1_t vmulh_vv_i16m1_m(vbool16_t, vint16m1_t, vint16m1_t, vint16m1_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vmulh_vv)))
vint16m2_t vmulh_vv_i16m2(vint16m2_t, vint16m2_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vmulh_vv_m)))
vint16m2_t vmulh_vv_i16m2_m(vbool8_t, vint16m2_t, vint16m2_t, vint16m2_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vmulh_vv)))
vint16m4_t vmulh_vv_i16m4(vint16m4_t, vint16m4_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vmulh_vv_m)))
vint16m4_t vmulh_vv_i16m4_m(vbool4_t, vint16m4_t, vint16m4_t, vint16m4_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vmulh_vv)))
vint16m8_t vmulh_vv_i16m8(vint16m8_t, vint16m8_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vmulh_vv_m)))
vint16m8_t vmulh_vv_i16m8_m(vbool2_t, vint16m8_t, vint16m8_t, vint16m8_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vmulh_vv)))
vint16mf2_t vmulh_vv_i16mf2(vint16mf2_t, vint16mf2_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vmulh_vv_m)))
vint16mf2_t vmulh_vv_i16mf2_m(vbool32_t, vint16mf2_t, vint16mf2_t, vint16mf2_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vmulh_vv)))
vint16mf4_t vmulh_vv_i16mf4(vint16mf4_t, vint16mf4_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vmulh_vv_m)))
vint16mf4_t vmulh_vv_i16mf4_m(vbool64_t, vint16mf4_t, vint16mf4_t, vint16mf4_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vmulh_vv)))
vint32m1_t vmulh_vv_i32m1(vint32m1_t, vint32m1_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vmulh_vv_m)))
vint32m1_t vmulh_vv_i32m1_m(vbool32_t, vint32m1_t, vint32m1_t, vint32m1_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vmulh_vv)))
vint32m2_t vmulh_vv_i32m2(vint32m2_t, vint32m2_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vmulh_vv_m)))
vint32m2_t vmulh_vv_i32m2_m(vbool16_t, vint32m2_t, vint32m2_t, vint32m2_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vmulh_vv)))
vint32m4_t vmulh_vv_i32m4(vint32m4_t, vint32m4_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vmulh_vv_m)))
vint32m4_t vmulh_vv_i32m4_m(vbool8_t, vint32m4_t, vint32m4_t, vint32m4_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vmulh_vv)))
vint32m8_t vmulh_vv_i32m8(vint32m8_t, vint32m8_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vmulh_vv_m)))
vint32m8_t vmulh_vv_i32m8_m(vbool4_t, vint32m8_t, vint32m8_t, vint32m8_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vmulh_vv)))
vint32mf2_t vmulh_vv_i32mf2(vint32mf2_t, vint32mf2_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vmulh_vv_m)))
vint32mf2_t vmulh_vv_i32mf2_m(vbool64_t, vint32mf2_t, vint32mf2_t, vint32mf2_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vmulh_vx)))
vint8m1_t vmulh_vx_i8m1(vint8m1_t, int8_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vmulh_vx_m)))
vint8m1_t vmulh_vx_i8m1_m(vbool8_t, vint8m1_t, vint8m1_t, int8_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vmulh_vx)))
vint8m2_t vmulh_vx_i8m2(vint8m2_t, int8_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vmulh_vx_m)))
vint8m2_t vmulh_vx_i8m2_m(vbool4_t, vint8m2_t, vint8m2_t, int8_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vmulh_vx)))
vint8m4_t vmulh_vx_i8m4(vint8m4_t, int8_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vmulh_vx_m)))
vint8m4_t vmulh_vx_i8m4_m(vbool2_t, vint8m4_t, vint8m4_t, int8_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vmulh_vx)))
vint8m8_t vmulh_vx_i8m8(vint8m8_t, int8_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vmulh_vx_m)))
vint8m8_t vmulh_vx_i8m8_m(vbool1_t, vint8m8_t, vint8m8_t, int8_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vmulh_vx)))
vint8mf2_t vmulh_vx_i8mf2(vint8mf2_t, int8_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vmulh_vx_m)))
vint8mf2_t vmulh_vx_i8mf2_m(vbool16_t, vint8mf2_t, vint8mf2_t, int8_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vmulh_vx)))
vint8mf4_t vmulh_vx_i8mf4(vint8mf4_t, int8_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vmulh_vx_m)))
vint8mf4_t vmulh_vx_i8mf4_m(vbool32_t, vint8mf4_t, vint8mf4_t, int8_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vmulh_vx)))
vint8mf8_t vmulh_vx_i8mf8(vint8mf8_t, int8_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vmulh_vx_m)))
vint8mf8_t vmulh_vx_i8mf8_m(vbool64_t, vint8mf8_t, vint8mf8_t, int8_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vmulh_vx)))
vint16m1_t vmulh_vx_i16m1(vint16m1_t, int16_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vmulh_vx_m)))
vint16m1_t vmulh_vx_i16m1_m(vbool16_t, vint16m1_t, vint16m1_t, int16_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vmulh_vx)))
vint16m2_t vmulh_vx_i16m2(vint16m2_t, int16_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vmulh_vx_m)))
vint16m2_t vmulh_vx_i16m2_m(vbool8_t, vint16m2_t, vint16m2_t, int16_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vmulh_vx)))
vint16m4_t vmulh_vx_i16m4(vint16m4_t, int16_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vmulh_vx_m)))
vint16m4_t vmulh_vx_i16m4_m(vbool4_t, vint16m4_t, vint16m4_t, int16_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vmulh_vx)))
vint16m8_t vmulh_vx_i16m8(vint16m8_t, int16_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vmulh_vx_m)))
vint16m8_t vmulh_vx_i16m8_m(vbool2_t, vint16m8_t, vint16m8_t, int16_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vmulh_vx)))
vint16mf2_t vmulh_vx_i16mf2(vint16mf2_t, int16_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vmulh_vx_m)))
vint16mf2_t vmulh_vx_i16mf2_m(vbool32_t, vint16mf2_t, vint16mf2_t, int16_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vmulh_vx)))
vint16mf4_t vmulh_vx_i16mf4(vint16mf4_t, int16_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vmulh_vx_m)))
vint16mf4_t vmulh_vx_i16mf4_m(vbool64_t, vint16mf4_t, vint16mf4_t, int16_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vmulh_vx)))
vint32m1_t vmulh_vx_i32m1(vint32m1_t, int32_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vmulh_vx_m)))
vint32m1_t vmulh_vx_i32m1_m(vbool32_t, vint32m1_t, vint32m1_t, int32_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vmulh_vx)))
vint32m2_t vmulh_vx_i32m2(vint32m2_t, int32_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vmulh_vx_m)))
vint32m2_t vmulh_vx_i32m2_m(vbool16_t, vint32m2_t, vint32m2_t, int32_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vmulh_vx)))
vint32m4_t vmulh_vx_i32m4(vint32m4_t, int32_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vmulh_vx_m)))
vint32m4_t vmulh_vx_i32m4_m(vbool8_t, vint32m4_t, vint32m4_t, int32_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vmulh_vx)))
vint32m8_t vmulh_vx_i32m8(vint32m8_t, int32_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vmulh_vx_m)))
vint32m8_t vmulh_vx_i32m8_m(vbool4_t, vint32m8_t, vint32m8_t, int32_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vmulh_vx)))
vint32mf2_t vmulh_vx_i32mf2(vint32mf2_t, int32_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vmulh_vx_m)))
vint32mf2_t vmulh_vx_i32mf2_m(vbool64_t, vint32mf2_t, vint32mf2_t, int32_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vmulhu_vv)))
vuint8m1_t vmulhu_vv_u8m1(vuint8m1_t, vuint8m1_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vmulhu_vv_m)))
vuint8m1_t vmulhu_vv_u8m1_m(vbool8_t, vuint8m1_t, vuint8m1_t, vuint8m1_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vmulhu_vv)))
vuint8m2_t vmulhu_vv_u8m2(vuint8m2_t, vuint8m2_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vmulhu_vv_m)))
vuint8m2_t vmulhu_vv_u8m2_m(vbool4_t, vuint8m2_t, vuint8m2_t, vuint8m2_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vmulhu_vv)))
vuint8m4_t vmulhu_vv_u8m4(vuint8m4_t, vuint8m4_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vmulhu_vv_m)))
vuint8m4_t vmulhu_vv_u8m4_m(vbool2_t, vuint8m4_t, vuint8m4_t, vuint8m4_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vmulhu_vv)))
vuint8m8_t vmulhu_vv_u8m8(vuint8m8_t, vuint8m8_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vmulhu_vv_m)))
vuint8m8_t vmulhu_vv_u8m8_m(vbool1_t, vuint8m8_t, vuint8m8_t, vuint8m8_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vmulhu_vv)))
vuint8mf2_t vmulhu_vv_u8mf2(vuint8mf2_t, vuint8mf2_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vmulhu_vv_m)))
vuint8mf2_t vmulhu_vv_u8mf2_m(vbool16_t, vuint8mf2_t, vuint8mf2_t, vuint8mf2_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vmulhu_vv)))
vuint8mf4_t vmulhu_vv_u8mf4(vuint8mf4_t, vuint8mf4_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vmulhu_vv_m)))
vuint8mf4_t vmulhu_vv_u8mf4_m(vbool32_t, vuint8mf4_t, vuint8mf4_t, vuint8mf4_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vmulhu_vv)))
vuint8mf8_t vmulhu_vv_u8mf8(vuint8mf8_t, vuint8mf8_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vmulhu_vv_m)))
vuint8mf8_t vmulhu_vv_u8mf8_m(vbool64_t, vuint8mf8_t, vuint8mf8_t, vuint8mf8_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vmulhu_vv)))
vuint16m1_t vmulhu_vv_u16m1(vuint16m1_t, vuint16m1_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vmulhu_vv_m)))
vuint16m1_t vmulhu_vv_u16m1_m(vbool16_t, vuint16m1_t, vuint16m1_t, vuint16m1_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vmulhu_vv)))
vuint16m2_t vmulhu_vv_u16m2(vuint16m2_t, vuint16m2_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vmulhu_vv_m)))
vuint16m2_t vmulhu_vv_u16m2_m(vbool8_t, vuint16m2_t, vuint16m2_t, vuint16m2_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vmulhu_vv)))
vuint16m4_t vmulhu_vv_u16m4(vuint16m4_t, vuint16m4_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vmulhu_vv_m)))
vuint16m4_t vmulhu_vv_u16m4_m(vbool4_t, vuint16m4_t, vuint16m4_t, vuint16m4_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vmulhu_vv)))
vuint16m8_t vmulhu_vv_u16m8(vuint16m8_t, vuint16m8_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vmulhu_vv_m)))
vuint16m8_t vmulhu_vv_u16m8_m(vbool2_t, vuint16m8_t, vuint16m8_t, vuint16m8_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vmulhu_vv)))
vuint16mf2_t vmulhu_vv_u16mf2(vuint16mf2_t, vuint16mf2_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vmulhu_vv_m)))
vuint16mf2_t vmulhu_vv_u16mf2_m(vbool32_t, vuint16mf2_t, vuint16mf2_t, vuint16mf2_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vmulhu_vv)))
vuint16mf4_t vmulhu_vv_u16mf4(vuint16mf4_t, vuint16mf4_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vmulhu_vv_m)))
vuint16mf4_t vmulhu_vv_u16mf4_m(vbool64_t, vuint16mf4_t, vuint16mf4_t, vuint16mf4_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vmulhu_vv)))
vuint32m1_t vmulhu_vv_u32m1(vuint32m1_t, vuint32m1_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vmulhu_vv_m)))
vuint32m1_t vmulhu_vv_u32m1_m(vbool32_t, vuint32m1_t, vuint32m1_t, vuint32m1_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vmulhu_vv)))
vuint32m2_t vmulhu_vv_u32m2(vuint32m2_t, vuint32m2_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vmulhu_vv_m)))
vuint32m2_t vmulhu_vv_u32m2_m(vbool16_t, vuint32m2_t, vuint32m2_t, vuint32m2_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vmulhu_vv)))
vuint32m4_t vmulhu_vv_u32m4(vuint32m4_t, vuint32m4_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vmulhu_vv_m)))
vuint32m4_t vmulhu_vv_u32m4_m(vbool8_t, vuint32m4_t, vuint32m4_t, vuint32m4_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vmulhu_vv)))
vuint32m8_t vmulhu_vv_u32m8(vuint32m8_t, vuint32m8_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vmulhu_vv_m)))
vuint32m8_t vmulhu_vv_u32m8_m(vbool4_t, vuint32m8_t, vuint32m8_t, vuint32m8_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vmulhu_vv)))
vuint32mf2_t vmulhu_vv_u32mf2(vuint32mf2_t, vuint32mf2_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vmulhu_vv_m)))
vuint32mf2_t vmulhu_vv_u32mf2_m(vbool64_t, vuint32mf2_t, vuint32mf2_t, vuint32mf2_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vmulhu_vx)))
vuint8m1_t vmulhu_vx_u8m1(vuint8m1_t, uint8_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vmulhu_vx_m)))
vuint8m1_t vmulhu_vx_u8m1_m(vbool8_t, vuint8m1_t, vuint8m1_t, uint8_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vmulhu_vx)))
vuint8m2_t vmulhu_vx_u8m2(vuint8m2_t, uint8_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vmulhu_vx_m)))
vuint8m2_t vmulhu_vx_u8m2_m(vbool4_t, vuint8m2_t, vuint8m2_t, uint8_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vmulhu_vx)))
vuint8m4_t vmulhu_vx_u8m4(vuint8m4_t, uint8_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vmulhu_vx_m)))
vuint8m4_t vmulhu_vx_u8m4_m(vbool2_t, vuint8m4_t, vuint8m4_t, uint8_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vmulhu_vx)))
vuint8m8_t vmulhu_vx_u8m8(vuint8m8_t, uint8_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vmulhu_vx_m)))
vuint8m8_t vmulhu_vx_u8m8_m(vbool1_t, vuint8m8_t, vuint8m8_t, uint8_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vmulhu_vx)))
vuint8mf2_t vmulhu_vx_u8mf2(vuint8mf2_t, uint8_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vmulhu_vx_m)))
vuint8mf2_t vmulhu_vx_u8mf2_m(vbool16_t, vuint8mf2_t, vuint8mf2_t, uint8_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vmulhu_vx)))
vuint8mf4_t vmulhu_vx_u8mf4(vuint8mf4_t, uint8_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vmulhu_vx_m)))
vuint8mf4_t vmulhu_vx_u8mf4_m(vbool32_t, vuint8mf4_t, vuint8mf4_t, uint8_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vmulhu_vx)))
vuint8mf8_t vmulhu_vx_u8mf8(vuint8mf8_t, uint8_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vmulhu_vx_m)))
vuint8mf8_t vmulhu_vx_u8mf8_m(vbool64_t, vuint8mf8_t, vuint8mf8_t, uint8_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vmulhu_vx)))
vuint16m1_t vmulhu_vx_u16m1(vuint16m1_t, uint16_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vmulhu_vx_m)))
vuint16m1_t vmulhu_vx_u16m1_m(vbool16_t, vuint16m1_t, vuint16m1_t, uint16_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vmulhu_vx)))
vuint16m2_t vmulhu_vx_u16m2(vuint16m2_t, uint16_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vmulhu_vx_m)))
vuint16m2_t vmulhu_vx_u16m2_m(vbool8_t, vuint16m2_t, vuint16m2_t, uint16_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vmulhu_vx)))
vuint16m4_t vmulhu_vx_u16m4(vuint16m4_t, uint16_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vmulhu_vx_m)))
vuint16m4_t vmulhu_vx_u16m4_m(vbool4_t, vuint16m4_t, vuint16m4_t, uint16_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vmulhu_vx)))
vuint16m8_t vmulhu_vx_u16m8(vuint16m8_t, uint16_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vmulhu_vx_m)))
vuint16m8_t vmulhu_vx_u16m8_m(vbool2_t, vuint16m8_t, vuint16m8_t, uint16_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vmulhu_vx)))
vuint16mf2_t vmulhu_vx_u16mf2(vuint16mf2_t, uint16_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vmulhu_vx_m)))
vuint16mf2_t vmulhu_vx_u16mf2_m(vbool32_t, vuint16mf2_t, vuint16mf2_t, uint16_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vmulhu_vx)))
vuint16mf4_t vmulhu_vx_u16mf4(vuint16mf4_t, uint16_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vmulhu_vx_m)))
vuint16mf4_t vmulhu_vx_u16mf4_m(vbool64_t, vuint16mf4_t, vuint16mf4_t, uint16_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vmulhu_vx)))
vuint32m1_t vmulhu_vx_u32m1(vuint32m1_t, uint32_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vmulhu_vx_m)))
vuint32m1_t vmulhu_vx_u32m1_m(vbool32_t, vuint32m1_t, vuint32m1_t, uint32_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vmulhu_vx)))
vuint32m2_t vmulhu_vx_u32m2(vuint32m2_t, uint32_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vmulhu_vx_m)))
vuint32m2_t vmulhu_vx_u32m2_m(vbool16_t, vuint32m2_t, vuint32m2_t, uint32_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vmulhu_vx)))
vuint32m4_t vmulhu_vx_u32m4(vuint32m4_t, uint32_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vmulhu_vx_m)))
vuint32m4_t vmulhu_vx_u32m4_m(vbool8_t, vuint32m4_t, vuint32m4_t, uint32_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vmulhu_vx)))
vuint32m8_t vmulhu_vx_u32m8(vuint32m8_t, uint32_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vmulhu_vx_m)))
vuint32m8_t vmulhu_vx_u32m8_m(vbool4_t, vuint32m8_t, vuint32m8_t, uint32_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vmulhu_vx)))
vuint32mf2_t vmulhu_vx_u32mf2(vuint32mf2_t, uint32_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vmulhu_vx_m)))
vuint32mf2_t vmulhu_vx_u32mf2_m(vbool64_t, vuint32mf2_t, vuint32mf2_t, uint32_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vmulhsu_vv)))
vint8m1_t vmulhsu_vv_i8m1(vint8m1_t, vuint8m1_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vmulhsu_vv_m)))
vint8m1_t vmulhsu_vv_i8m1_m(vbool8_t, vint8m1_t, vint8m1_t, vuint8m1_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vmulhsu_vv)))
vint8m2_t vmulhsu_vv_i8m2(vint8m2_t, vuint8m2_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vmulhsu_vv_m)))
vint8m2_t vmulhsu_vv_i8m2_m(vbool4_t, vint8m2_t, vint8m2_t, vuint8m2_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vmulhsu_vv)))
vint8m4_t vmulhsu_vv_i8m4(vint8m4_t, vuint8m4_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vmulhsu_vv_m)))
vint8m4_t vmulhsu_vv_i8m4_m(vbool2_t, vint8m4_t, vint8m4_t, vuint8m4_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vmulhsu_vv)))
vint8m8_t vmulhsu_vv_i8m8(vint8m8_t, vuint8m8_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vmulhsu_vv_m)))
vint8m8_t vmulhsu_vv_i8m8_m(vbool1_t, vint8m8_t, vint8m8_t, vuint8m8_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vmulhsu_vv)))
vint8mf2_t vmulhsu_vv_i8mf2(vint8mf2_t, vuint8mf2_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vmulhsu_vv_m)))
vint8mf2_t vmulhsu_vv_i8mf2_m(vbool16_t, vint8mf2_t, vint8mf2_t, vuint8mf2_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vmulhsu_vv)))
vint8mf4_t vmulhsu_vv_i8mf4(vint8mf4_t, vuint8mf4_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vmulhsu_vv_m)))
vint8mf4_t vmulhsu_vv_i8mf4_m(vbool32_t, vint8mf4_t, vint8mf4_t, vuint8mf4_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vmulhsu_vv)))
vint8mf8_t vmulhsu_vv_i8mf8(vint8mf8_t, vuint8mf8_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vmulhsu_vv_m)))
vint8mf8_t vmulhsu_vv_i8mf8_m(vbool64_t, vint8mf8_t, vint8mf8_t, vuint8mf8_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vmulhsu_vv)))
vint16m1_t vmulhsu_vv_i16m1(vint16m1_t, vuint16m1_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vmulhsu_vv_m)))
vint16m1_t vmulhsu_vv_i16m1_m(vbool16_t, vint16m1_t, vint16m1_t, vuint16m1_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vmulhsu_vv)))
vint16m2_t vmulhsu_vv_i16m2(vint16m2_t, vuint16m2_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vmulhsu_vv_m)))
vint16m2_t vmulhsu_vv_i16m2_m(vbool8_t, vint16m2_t, vint16m2_t, vuint16m2_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vmulhsu_vv)))
vint16m4_t vmulhsu_vv_i16m4(vint16m4_t, vuint16m4_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vmulhsu_vv_m)))
vint16m4_t vmulhsu_vv_i16m4_m(vbool4_t, vint16m4_t, vint16m4_t, vuint16m4_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vmulhsu_vv)))
vint16m8_t vmulhsu_vv_i16m8(vint16m8_t, vuint16m8_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vmulhsu_vv_m)))
vint16m8_t vmulhsu_vv_i16m8_m(vbool2_t, vint16m8_t, vint16m8_t, vuint16m8_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vmulhsu_vv)))
vint16mf2_t vmulhsu_vv_i16mf2(vint16mf2_t, vuint16mf2_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vmulhsu_vv_m)))
vint16mf2_t vmulhsu_vv_i16mf2_m(vbool32_t, vint16mf2_t, vint16mf2_t, vuint16mf2_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vmulhsu_vv)))
vint16mf4_t vmulhsu_vv_i16mf4(vint16mf4_t, vuint16mf4_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vmulhsu_vv_m)))
vint16mf4_t vmulhsu_vv_i16mf4_m(vbool64_t, vint16mf4_t, vint16mf4_t, vuint16mf4_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vmulhsu_vv)))
vint32m1_t vmulhsu_vv_i32m1(vint32m1_t, vuint32m1_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vmulhsu_vv_m)))
vint32m1_t vmulhsu_vv_i32m1_m(vbool32_t, vint32m1_t, vint32m1_t, vuint32m1_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vmulhsu_vv)))
vint32m2_t vmulhsu_vv_i32m2(vint32m2_t, vuint32m2_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vmulhsu_vv_m)))
vint32m2_t vmulhsu_vv_i32m2_m(vbool16_t, vint32m2_t, vint32m2_t, vuint32m2_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vmulhsu_vv)))
vint32m4_t vmulhsu_vv_i32m4(vint32m4_t, vuint32m4_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vmulhsu_vv_m)))
vint32m4_t vmulhsu_vv_i32m4_m(vbool8_t, vint32m4_t, vint32m4_t, vuint32m4_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vmulhsu_vv)))
vint32m8_t vmulhsu_vv_i32m8(vint32m8_t, vuint32m8_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vmulhsu_vv_m)))
vint32m8_t vmulhsu_vv_i32m8_m(vbool4_t, vint32m8_t, vint32m8_t, vuint32m8_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vmulhsu_vv)))
vint32mf2_t vmulhsu_vv_i32mf2(vint32mf2_t, vuint32mf2_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vmulhsu_vv_m)))
vint32mf2_t vmulhsu_vv_i32mf2_m(vbool64_t, vint32mf2_t, vint32mf2_t, vuint32mf2_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vsuxei32_v)))
void vsuxei32_v_i8m1(int8_t *, vuint32m4_t, vint8m1_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vsuxei32_v_m)))
void vsuxei32_v_i8m1_m(vbool8_t, int8_t *, vuint32m4_t, vint8m1_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vsuxei32_v)))
void vsuxei32_v_i8m2(int8_t *, vuint32m8_t, vint8m2_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vsuxei32_v_m)))
void vsuxei32_v_i8m2_m(vbool4_t, int8_t *, vuint32m8_t, vint8m2_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vsuxei32_v)))
void vsuxei32_v_i8mf2(int8_t *, vuint32m2_t, vint8mf2_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vsuxei32_v_m)))
void vsuxei32_v_i8mf2_m(vbool16_t, int8_t *, vuint32m2_t, vint8mf2_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vsuxei32_v)))
void vsuxei32_v_i8mf4(int8_t *, vuint32m1_t, vint8mf4_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vsuxei32_v_m)))
void vsuxei32_v_i8mf4_m(vbool32_t, int8_t *, vuint32m1_t, vint8mf4_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vsuxei32_v)))
void vsuxei32_v_i8mf8(int8_t *, vuint32mf2_t, vint8mf8_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vsuxei32_v_m)))
void vsuxei32_v_i8mf8_m(vbool64_t, int8_t *, vuint32mf2_t, vint8mf8_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vmulhsu_vx)))
vint8m1_t vmulhsu_vx_i8m1(vint8m1_t, uint8_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vmulhsu_vx_m)))
vint8m1_t vmulhsu_vx_i8m1_m(vbool8_t, vint8m1_t, vint8m1_t, uint8_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vmulhsu_vx)))
vint8m2_t vmulhsu_vx_i8m2(vint8m2_t, uint8_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vmulhsu_vx_m)))
vint8m2_t vmulhsu_vx_i8m2_m(vbool4_t, vint8m2_t, vint8m2_t, uint8_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vmulhsu_vx)))
vint8m4_t vmulhsu_vx_i8m4(vint8m4_t, uint8_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vmulhsu_vx_m)))
vint8m4_t vmulhsu_vx_i8m4_m(vbool2_t, vint8m4_t, vint8m4_t, uint8_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vmulhsu_vx)))
vint8m8_t vmulhsu_vx_i8m8(vint8m8_t, uint8_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vmulhsu_vx_m)))
vint8m8_t vmulhsu_vx_i8m8_m(vbool1_t, vint8m8_t, vint8m8_t, uint8_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vmulhsu_vx)))
vint8mf2_t vmulhsu_vx_i8mf2(vint8mf2_t, uint8_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vmulhsu_vx_m)))
vint8mf2_t vmulhsu_vx_i8mf2_m(vbool16_t, vint8mf2_t, vint8mf2_t, uint8_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vmulhsu_vx)))
vint8mf4_t vmulhsu_vx_i8mf4(vint8mf4_t, uint8_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vmulhsu_vx_m)))
vint8mf4_t vmulhsu_vx_i8mf4_m(vbool32_t, vint8mf4_t, vint8mf4_t, uint8_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vmulhsu_vx)))
vint8mf8_t vmulhsu_vx_i8mf8(vint8mf8_t, uint8_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vmulhsu_vx_m)))
vint8mf8_t vmulhsu_vx_i8mf8_m(vbool64_t, vint8mf8_t, vint8mf8_t, uint8_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vmulhsu_vx)))
vint16m1_t vmulhsu_vx_i16m1(vint16m1_t, uint16_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vmulhsu_vx_m)))
vint16m1_t vmulhsu_vx_i16m1_m(vbool16_t, vint16m1_t, vint16m1_t, uint16_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vmulhsu_vx)))
vint16m2_t vmulhsu_vx_i16m2(vint16m2_t, uint16_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vmulhsu_vx_m)))
vint16m2_t vmulhsu_vx_i16m2_m(vbool8_t, vint16m2_t, vint16m2_t, uint16_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vmulhsu_vx)))
vint16m4_t vmulhsu_vx_i16m4(vint16m4_t, uint16_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vmulhsu_vx_m)))
vint16m4_t vmulhsu_vx_i16m4_m(vbool4_t, vint16m4_t, vint16m4_t, uint16_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vmulhsu_vx)))
vint16m8_t vmulhsu_vx_i16m8(vint16m8_t, uint16_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vmulhsu_vx_m)))
vint16m8_t vmulhsu_vx_i16m8_m(vbool2_t, vint16m8_t, vint16m8_t, uint16_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vmulhsu_vx)))
vint16mf2_t vmulhsu_vx_i16mf2(vint16mf2_t, uint16_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vmulhsu_vx_m)))
vint16mf2_t vmulhsu_vx_i16mf2_m(vbool32_t, vint16mf2_t, vint16mf2_t, uint16_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vmulhsu_vx)))
vint16mf4_t vmulhsu_vx_i16mf4(vint16mf4_t, uint16_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vmulhsu_vx_m)))
vint16mf4_t vmulhsu_vx_i16mf4_m(vbool64_t, vint16mf4_t, vint16mf4_t, uint16_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vmulhsu_vx)))
vint32m1_t vmulhsu_vx_i32m1(vint32m1_t, uint32_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vmulhsu_vx_m)))
vint32m1_t vmulhsu_vx_i32m1_m(vbool32_t, vint32m1_t, vint32m1_t, uint32_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vmulhsu_vx)))
vint32m2_t vmulhsu_vx_i32m2(vint32m2_t, uint32_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vmulhsu_vx_m)))
vint32m2_t vmulhsu_vx_i32m2_m(vbool16_t, vint32m2_t, vint32m2_t, uint32_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vmulhsu_vx)))
vint32m4_t vmulhsu_vx_i32m4(vint32m4_t, uint32_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vmulhsu_vx_m)))
vint32m4_t vmulhsu_vx_i32m4_m(vbool8_t, vint32m4_t, vint32m4_t, uint32_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vmulhsu_vx)))
vint32m8_t vmulhsu_vx_i32m8(vint32m8_t, uint32_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vmulhsu_vx_m)))
vint32m8_t vmulhsu_vx_i32m8_m(vbool4_t, vint32m8_t, vint32m8_t, uint32_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vmulhsu_vx)))
vint32mf2_t vmulhsu_vx_i32mf2(vint32mf2_t, uint32_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vmulhsu_vx_m)))
vint32mf2_t vmulhsu_vx_i32mf2_m(vbool64_t, vint32mf2_t, vint32mf2_t, uint32_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vdivu_vv)))
vuint8m1_t vdivu_vv_u8m1(vuint8m1_t, vuint8m1_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vdivu_vv_m)))
vuint8m1_t vdivu_vv_u8m1_m(vbool8_t, vuint8m1_t, vuint8m1_t, vuint8m1_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vdivu_vv)))
vuint8m2_t vdivu_vv_u8m2(vuint8m2_t, vuint8m2_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vdivu_vv_m)))
vuint8m2_t vdivu_vv_u8m2_m(vbool4_t, vuint8m2_t, vuint8m2_t, vuint8m2_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vdivu_vv)))
vuint8m4_t vdivu_vv_u8m4(vuint8m4_t, vuint8m4_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vdivu_vv_m)))
vuint8m4_t vdivu_vv_u8m4_m(vbool2_t, vuint8m4_t, vuint8m4_t, vuint8m4_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vdivu_vv)))
vuint8m8_t vdivu_vv_u8m8(vuint8m8_t, vuint8m8_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vdivu_vv_m)))
vuint8m8_t vdivu_vv_u8m8_m(vbool1_t, vuint8m8_t, vuint8m8_t, vuint8m8_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vdivu_vv)))
vuint8mf2_t vdivu_vv_u8mf2(vuint8mf2_t, vuint8mf2_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vdivu_vv_m)))
vuint8mf2_t vdivu_vv_u8mf2_m(vbool16_t, vuint8mf2_t, vuint8mf2_t, vuint8mf2_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vdivu_vv)))
vuint8mf4_t vdivu_vv_u8mf4(vuint8mf4_t, vuint8mf4_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vdivu_vv_m)))
vuint8mf4_t vdivu_vv_u8mf4_m(vbool32_t, vuint8mf4_t, vuint8mf4_t, vuint8mf4_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vdivu_vv)))
vuint8mf8_t vdivu_vv_u8mf8(vuint8mf8_t, vuint8mf8_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vdivu_vv_m)))
vuint8mf8_t vdivu_vv_u8mf8_m(vbool64_t, vuint8mf8_t, vuint8mf8_t, vuint8mf8_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vdivu_vv)))
vuint16m1_t vdivu_vv_u16m1(vuint16m1_t, vuint16m1_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vdivu_vv_m)))
vuint16m1_t vdivu_vv_u16m1_m(vbool16_t, vuint16m1_t, vuint16m1_t, vuint16m1_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vdivu_vv)))
vuint16m2_t vdivu_vv_u16m2(vuint16m2_t, vuint16m2_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vdivu_vv_m)))
vuint16m2_t vdivu_vv_u16m2_m(vbool8_t, vuint16m2_t, vuint16m2_t, vuint16m2_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vdivu_vv)))
vuint16m4_t vdivu_vv_u16m4(vuint16m4_t, vuint16m4_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vdivu_vv_m)))
vuint16m4_t vdivu_vv_u16m4_m(vbool4_t, vuint16m4_t, vuint16m4_t, vuint16m4_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vdivu_vv)))
vuint16m8_t vdivu_vv_u16m8(vuint16m8_t, vuint16m8_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vdivu_vv_m)))
vuint16m8_t vdivu_vv_u16m8_m(vbool2_t, vuint16m8_t, vuint16m8_t, vuint16m8_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vdivu_vv)))
vuint16mf2_t vdivu_vv_u16mf2(vuint16mf2_t, vuint16mf2_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vdivu_vv_m)))
vuint16mf2_t vdivu_vv_u16mf2_m(vbool32_t, vuint16mf2_t, vuint16mf2_t, vuint16mf2_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vdivu_vv)))
vuint16mf4_t vdivu_vv_u16mf4(vuint16mf4_t, vuint16mf4_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vdivu_vv_m)))
vuint16mf4_t vdivu_vv_u16mf4_m(vbool64_t, vuint16mf4_t, vuint16mf4_t, vuint16mf4_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vdivu_vv)))
vuint32m1_t vdivu_vv_u32m1(vuint32m1_t, vuint32m1_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vdivu_vv_m)))
vuint32m1_t vdivu_vv_u32m1_m(vbool32_t, vuint32m1_t, vuint32m1_t, vuint32m1_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vdivu_vv)))
vuint32m2_t vdivu_vv_u32m2(vuint32m2_t, vuint32m2_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vdivu_vv_m)))
vuint32m2_t vdivu_vv_u32m2_m(vbool16_t, vuint32m2_t, vuint32m2_t, vuint32m2_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vdivu_vv)))
vuint32m4_t vdivu_vv_u32m4(vuint32m4_t, vuint32m4_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vdivu_vv_m)))
vuint32m4_t vdivu_vv_u32m4_m(vbool8_t, vuint32m4_t, vuint32m4_t, vuint32m4_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vdivu_vv)))
vuint32m8_t vdivu_vv_u32m8(vuint32m8_t, vuint32m8_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vdivu_vv_m)))
vuint32m8_t vdivu_vv_u32m8_m(vbool4_t, vuint32m8_t, vuint32m8_t, vuint32m8_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vdivu_vv)))
vuint32mf2_t vdivu_vv_u32mf2(vuint32mf2_t, vuint32mf2_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vdivu_vv_m)))
vuint32mf2_t vdivu_vv_u32mf2_m(vbool64_t, vuint32mf2_t, vuint32mf2_t, vuint32mf2_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vdivu_vx)))
vuint8m1_t vdivu_vx_u8m1(vuint8m1_t, uint8_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vdivu_vx_m)))
vuint8m1_t vdivu_vx_u8m1_m(vbool8_t, vuint8m1_t, vuint8m1_t, uint8_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vdivu_vx)))
vuint8m2_t vdivu_vx_u8m2(vuint8m2_t, uint8_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vdivu_vx_m)))
vuint8m2_t vdivu_vx_u8m2_m(vbool4_t, vuint8m2_t, vuint8m2_t, uint8_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vdivu_vx)))
vuint8m4_t vdivu_vx_u8m4(vuint8m4_t, uint8_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vdivu_vx_m)))
vuint8m4_t vdivu_vx_u8m4_m(vbool2_t, vuint8m4_t, vuint8m4_t, uint8_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vdivu_vx)))
vuint8m8_t vdivu_vx_u8m8(vuint8m8_t, uint8_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vdivu_vx_m)))
vuint8m8_t vdivu_vx_u8m8_m(vbool1_t, vuint8m8_t, vuint8m8_t, uint8_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vdivu_vx)))
vuint8mf2_t vdivu_vx_u8mf2(vuint8mf2_t, uint8_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vdivu_vx_m)))
vuint8mf2_t vdivu_vx_u8mf2_m(vbool16_t, vuint8mf2_t, vuint8mf2_t, uint8_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vdivu_vx)))
vuint8mf4_t vdivu_vx_u8mf4(vuint8mf4_t, uint8_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vdivu_vx_m)))
vuint8mf4_t vdivu_vx_u8mf4_m(vbool32_t, vuint8mf4_t, vuint8mf4_t, uint8_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vdivu_vx)))
vuint8mf8_t vdivu_vx_u8mf8(vuint8mf8_t, uint8_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vdivu_vx_m)))
vuint8mf8_t vdivu_vx_u8mf8_m(vbool64_t, vuint8mf8_t, vuint8mf8_t, uint8_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vdivu_vx)))
vuint16m1_t vdivu_vx_u16m1(vuint16m1_t, uint16_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vdivu_vx_m)))
vuint16m1_t vdivu_vx_u16m1_m(vbool16_t, vuint16m1_t, vuint16m1_t, uint16_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vdivu_vx)))
vuint16m2_t vdivu_vx_u16m2(vuint16m2_t, uint16_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vdivu_vx_m)))
vuint16m2_t vdivu_vx_u16m2_m(vbool8_t, vuint16m2_t, vuint16m2_t, uint16_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vdivu_vx)))
vuint16m4_t vdivu_vx_u16m4(vuint16m4_t, uint16_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vdivu_vx_m)))
vuint16m4_t vdivu_vx_u16m4_m(vbool4_t, vuint16m4_t, vuint16m4_t, uint16_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vdivu_vx)))
vuint16m8_t vdivu_vx_u16m8(vuint16m8_t, uint16_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vdivu_vx_m)))
vuint16m8_t vdivu_vx_u16m8_m(vbool2_t, vuint16m8_t, vuint16m8_t, uint16_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vdivu_vx)))
vuint16mf2_t vdivu_vx_u16mf2(vuint16mf2_t, uint16_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vdivu_vx_m)))
vuint16mf2_t vdivu_vx_u16mf2_m(vbool32_t, vuint16mf2_t, vuint16mf2_t, uint16_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vdivu_vx)))
vuint16mf4_t vdivu_vx_u16mf4(vuint16mf4_t, uint16_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vdivu_vx_m)))
vuint16mf4_t vdivu_vx_u16mf4_m(vbool64_t, vuint16mf4_t, vuint16mf4_t, uint16_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vdivu_vx)))
vuint32m1_t vdivu_vx_u32m1(vuint32m1_t, uint32_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vdivu_vx_m)))
vuint32m1_t vdivu_vx_u32m1_m(vbool32_t, vuint32m1_t, vuint32m1_t, uint32_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vdivu_vx)))
vuint32m2_t vdivu_vx_u32m2(vuint32m2_t, uint32_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vdivu_vx_m)))
vuint32m2_t vdivu_vx_u32m2_m(vbool16_t, vuint32m2_t, vuint32m2_t, uint32_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vdivu_vx)))
vuint32m4_t vdivu_vx_u32m4(vuint32m4_t, uint32_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vdivu_vx_m)))
vuint32m4_t vdivu_vx_u32m4_m(vbool8_t, vuint32m4_t, vuint32m4_t, uint32_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vdivu_vx)))
vuint32m8_t vdivu_vx_u32m8(vuint32m8_t, uint32_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vdivu_vx_m)))
vuint32m8_t vdivu_vx_u32m8_m(vbool4_t, vuint32m8_t, vuint32m8_t, uint32_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vdivu_vx)))
vuint32mf2_t vdivu_vx_u32mf2(vuint32mf2_t, uint32_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vdivu_vx_m)))
vuint32mf2_t vdivu_vx_u32mf2_m(vbool64_t, vuint32mf2_t, vuint32mf2_t, uint32_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vdiv_vv)))
vint8m1_t vdiv_vv_i8m1(vint8m1_t, vint8m1_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vdiv_vv_m)))
vint8m1_t vdiv_vv_i8m1_m(vbool8_t, vint8m1_t, vint8m1_t, vint8m1_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vdiv_vv)))
vint8m2_t vdiv_vv_i8m2(vint8m2_t, vint8m2_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vdiv_vv_m)))
vint8m2_t vdiv_vv_i8m2_m(vbool4_t, vint8m2_t, vint8m2_t, vint8m2_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vdiv_vv)))
vint8m4_t vdiv_vv_i8m4(vint8m4_t, vint8m4_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vdiv_vv_m)))
vint8m4_t vdiv_vv_i8m4_m(vbool2_t, vint8m4_t, vint8m4_t, vint8m4_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vdiv_vv)))
vint8m8_t vdiv_vv_i8m8(vint8m8_t, vint8m8_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vdiv_vv_m)))
vint8m8_t vdiv_vv_i8m8_m(vbool1_t, vint8m8_t, vint8m8_t, vint8m8_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vdiv_vv)))
vint8mf2_t vdiv_vv_i8mf2(vint8mf2_t, vint8mf2_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vdiv_vv_m)))
vint8mf2_t vdiv_vv_i8mf2_m(vbool16_t, vint8mf2_t, vint8mf2_t, vint8mf2_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vdiv_vv)))
vint8mf4_t vdiv_vv_i8mf4(vint8mf4_t, vint8mf4_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vdiv_vv_m)))
vint8mf4_t vdiv_vv_i8mf4_m(vbool32_t, vint8mf4_t, vint8mf4_t, vint8mf4_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vdiv_vv)))
vint8mf8_t vdiv_vv_i8mf8(vint8mf8_t, vint8mf8_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vdiv_vv_m)))
vint8mf8_t vdiv_vv_i8mf8_m(vbool64_t, vint8mf8_t, vint8mf8_t, vint8mf8_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vdiv_vv)))
vint16m1_t vdiv_vv_i16m1(vint16m1_t, vint16m1_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vdiv_vv_m)))
vint16m1_t vdiv_vv_i16m1_m(vbool16_t, vint16m1_t, vint16m1_t, vint16m1_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vdiv_vv)))
vint16m2_t vdiv_vv_i16m2(vint16m2_t, vint16m2_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vdiv_vv_m)))
vint16m2_t vdiv_vv_i16m2_m(vbool8_t, vint16m2_t, vint16m2_t, vint16m2_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vdiv_vv)))
vint16m4_t vdiv_vv_i16m4(vint16m4_t, vint16m4_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vdiv_vv_m)))
vint16m4_t vdiv_vv_i16m4_m(vbool4_t, vint16m4_t, vint16m4_t, vint16m4_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vdiv_vv)))
vint16m8_t vdiv_vv_i16m8(vint16m8_t, vint16m8_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vdiv_vv_m)))
vint16m8_t vdiv_vv_i16m8_m(vbool2_t, vint16m8_t, vint16m8_t, vint16m8_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vdiv_vv)))
vint16mf2_t vdiv_vv_i16mf2(vint16mf2_t, vint16mf2_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vdiv_vv_m)))
vint16mf2_t vdiv_vv_i16mf2_m(vbool32_t, vint16mf2_t, vint16mf2_t, vint16mf2_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vdiv_vv)))
vint16mf4_t vdiv_vv_i16mf4(vint16mf4_t, vint16mf4_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vdiv_vv_m)))
vint16mf4_t vdiv_vv_i16mf4_m(vbool64_t, vint16mf4_t, vint16mf4_t, vint16mf4_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vdiv_vv)))
vint32m1_t vdiv_vv_i32m1(vint32m1_t, vint32m1_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vdiv_vv_m)))
vint32m1_t vdiv_vv_i32m1_m(vbool32_t, vint32m1_t, vint32m1_t, vint32m1_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vdiv_vv)))
vint32m2_t vdiv_vv_i32m2(vint32m2_t, vint32m2_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vdiv_vv_m)))
vint32m2_t vdiv_vv_i32m2_m(vbool16_t, vint32m2_t, vint32m2_t, vint32m2_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vdiv_vv)))
vint32m4_t vdiv_vv_i32m4(vint32m4_t, vint32m4_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vdiv_vv_m)))
vint32m4_t vdiv_vv_i32m4_m(vbool8_t, vint32m4_t, vint32m4_t, vint32m4_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vdiv_vv)))
vint32m8_t vdiv_vv_i32m8(vint32m8_t, vint32m8_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vdiv_vv_m)))
vint32m8_t vdiv_vv_i32m8_m(vbool4_t, vint32m8_t, vint32m8_t, vint32m8_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vdiv_vv)))
vint32mf2_t vdiv_vv_i32mf2(vint32mf2_t, vint32mf2_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vdiv_vv_m)))
vint32mf2_t vdiv_vv_i32mf2_m(vbool64_t, vint32mf2_t, vint32mf2_t, vint32mf2_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vdiv_vx)))
vint8m1_t vdiv_vx_i8m1(vint8m1_t, int8_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vdiv_vx_m)))
vint8m1_t vdiv_vx_i8m1_m(vbool8_t, vint8m1_t, vint8m1_t, int8_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vdiv_vx)))
vint8m2_t vdiv_vx_i8m2(vint8m2_t, int8_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vdiv_vx_m)))
vint8m2_t vdiv_vx_i8m2_m(vbool4_t, vint8m2_t, vint8m2_t, int8_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vdiv_vx)))
vint8m4_t vdiv_vx_i8m4(vint8m4_t, int8_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vdiv_vx_m)))
vint8m4_t vdiv_vx_i8m4_m(vbool2_t, vint8m4_t, vint8m4_t, int8_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vdiv_vx)))
vint8m8_t vdiv_vx_i8m8(vint8m8_t, int8_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vdiv_vx_m)))
vint8m8_t vdiv_vx_i8m8_m(vbool1_t, vint8m8_t, vint8m8_t, int8_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vdiv_vx)))
vint8mf2_t vdiv_vx_i8mf2(vint8mf2_t, int8_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vdiv_vx_m)))
vint8mf2_t vdiv_vx_i8mf2_m(vbool16_t, vint8mf2_t, vint8mf2_t, int8_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vdiv_vx)))
vint8mf4_t vdiv_vx_i8mf4(vint8mf4_t, int8_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vdiv_vx_m)))
vint8mf4_t vdiv_vx_i8mf4_m(vbool32_t, vint8mf4_t, vint8mf4_t, int8_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vdiv_vx)))
vint8mf8_t vdiv_vx_i8mf8(vint8mf8_t, int8_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vdiv_vx_m)))
vint8mf8_t vdiv_vx_i8mf8_m(vbool64_t, vint8mf8_t, vint8mf8_t, int8_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vdiv_vx)))
vint16m1_t vdiv_vx_i16m1(vint16m1_t, int16_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vdiv_vx_m)))
vint16m1_t vdiv_vx_i16m1_m(vbool16_t, vint16m1_t, vint16m1_t, int16_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vdiv_vx)))
vint16m2_t vdiv_vx_i16m2(vint16m2_t, int16_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vdiv_vx_m)))
vint16m2_t vdiv_vx_i16m2_m(vbool8_t, vint16m2_t, vint16m2_t, int16_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vdiv_vx)))
vint16m4_t vdiv_vx_i16m4(vint16m4_t, int16_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vdiv_vx_m)))
vint16m4_t vdiv_vx_i16m4_m(vbool4_t, vint16m4_t, vint16m4_t, int16_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vdiv_vx)))
vint16m8_t vdiv_vx_i16m8(vint16m8_t, int16_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vdiv_vx_m)))
vint16m8_t vdiv_vx_i16m8_m(vbool2_t, vint16m8_t, vint16m8_t, int16_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vdiv_vx)))
vint16mf2_t vdiv_vx_i16mf2(vint16mf2_t, int16_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vdiv_vx_m)))
vint16mf2_t vdiv_vx_i16mf2_m(vbool32_t, vint16mf2_t, vint16mf2_t, int16_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vdiv_vx)))
vint16mf4_t vdiv_vx_i16mf4(vint16mf4_t, int16_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vdiv_vx_m)))
vint16mf4_t vdiv_vx_i16mf4_m(vbool64_t, vint16mf4_t, vint16mf4_t, int16_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vdiv_vx)))
vint32m1_t vdiv_vx_i32m1(vint32m1_t, int32_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vdiv_vx_m)))
vint32m1_t vdiv_vx_i32m1_m(vbool32_t, vint32m1_t, vint32m1_t, int32_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vdiv_vx)))
vint32m2_t vdiv_vx_i32m2(vint32m2_t, int32_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vdiv_vx_m)))
vint32m2_t vdiv_vx_i32m2_m(vbool16_t, vint32m2_t, vint32m2_t, int32_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vdiv_vx)))
vint32m4_t vdiv_vx_i32m4(vint32m4_t, int32_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vdiv_vx_m)))
vint32m4_t vdiv_vx_i32m4_m(vbool8_t, vint32m4_t, vint32m4_t, int32_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vdiv_vx)))
vint32m8_t vdiv_vx_i32m8(vint32m8_t, int32_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vdiv_vx_m)))
vint32m8_t vdiv_vx_i32m8_m(vbool4_t, vint32m8_t, vint32m8_t, int32_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vdiv_vx)))
vint32mf2_t vdiv_vx_i32mf2(vint32mf2_t, int32_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vdiv_vx_m)))
vint32mf2_t vdiv_vx_i32mf2_m(vbool64_t, vint32mf2_t, vint32mf2_t, int32_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vremu_vv)))
vuint8m1_t vremu_vv_u8m1(vuint8m1_t, vuint8m1_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vremu_vv_m)))
vuint8m1_t vremu_vv_u8m1_m(vbool8_t, vuint8m1_t, vuint8m1_t, vuint8m1_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vremu_vv)))
vuint8m2_t vremu_vv_u8m2(vuint8m2_t, vuint8m2_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vremu_vv_m)))
vuint8m2_t vremu_vv_u8m2_m(vbool4_t, vuint8m2_t, vuint8m2_t, vuint8m2_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vremu_vv)))
vuint8m4_t vremu_vv_u8m4(vuint8m4_t, vuint8m4_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vremu_vv_m)))
vuint8m4_t vremu_vv_u8m4_m(vbool2_t, vuint8m4_t, vuint8m4_t, vuint8m4_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vremu_vv)))
vuint8m8_t vremu_vv_u8m8(vuint8m8_t, vuint8m8_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vremu_vv_m)))
vuint8m8_t vremu_vv_u8m8_m(vbool1_t, vuint8m8_t, vuint8m8_t, vuint8m8_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vremu_vv)))
vuint8mf2_t vremu_vv_u8mf2(vuint8mf2_t, vuint8mf2_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vremu_vv_m)))
vuint8mf2_t vremu_vv_u8mf2_m(vbool16_t, vuint8mf2_t, vuint8mf2_t, vuint8mf2_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vremu_vv)))
vuint8mf4_t vremu_vv_u8mf4(vuint8mf4_t, vuint8mf4_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vremu_vv_m)))
vuint8mf4_t vremu_vv_u8mf4_m(vbool32_t, vuint8mf4_t, vuint8mf4_t, vuint8mf4_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vremu_vv)))
vuint8mf8_t vremu_vv_u8mf8(vuint8mf8_t, vuint8mf8_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vremu_vv_m)))
vuint8mf8_t vremu_vv_u8mf8_m(vbool64_t, vuint8mf8_t, vuint8mf8_t, vuint8mf8_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vremu_vv)))
vuint16m1_t vremu_vv_u16m1(vuint16m1_t, vuint16m1_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vremu_vv_m)))
vuint16m1_t vremu_vv_u16m1_m(vbool16_t, vuint16m1_t, vuint16m1_t, vuint16m1_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vremu_vv)))
vuint16m2_t vremu_vv_u16m2(vuint16m2_t, vuint16m2_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vremu_vv_m)))
vuint16m2_t vremu_vv_u16m2_m(vbool8_t, vuint16m2_t, vuint16m2_t, vuint16m2_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vremu_vv)))
vuint16m4_t vremu_vv_u16m4(vuint16m4_t, vuint16m4_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vremu_vv_m)))
vuint16m4_t vremu_vv_u16m4_m(vbool4_t, vuint16m4_t, vuint16m4_t, vuint16m4_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vremu_vv)))
vuint16m8_t vremu_vv_u16m8(vuint16m8_t, vuint16m8_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vremu_vv_m)))
vuint16m8_t vremu_vv_u16m8_m(vbool2_t, vuint16m8_t, vuint16m8_t, vuint16m8_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vremu_vv)))
vuint16mf2_t vremu_vv_u16mf2(vuint16mf2_t, vuint16mf2_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vremu_vv_m)))
vuint16mf2_t vremu_vv_u16mf2_m(vbool32_t, vuint16mf2_t, vuint16mf2_t, vuint16mf2_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vremu_vv)))
vuint16mf4_t vremu_vv_u16mf4(vuint16mf4_t, vuint16mf4_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vremu_vv_m)))
vuint16mf4_t vremu_vv_u16mf4_m(vbool64_t, vuint16mf4_t, vuint16mf4_t, vuint16mf4_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vremu_vv)))
vuint32m1_t vremu_vv_u32m1(vuint32m1_t, vuint32m1_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vremu_vv_m)))
vuint32m1_t vremu_vv_u32m1_m(vbool32_t, vuint32m1_t, vuint32m1_t, vuint32m1_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vremu_vv)))
vuint32m2_t vremu_vv_u32m2(vuint32m2_t, vuint32m2_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vremu_vv_m)))
vuint32m2_t vremu_vv_u32m2_m(vbool16_t, vuint32m2_t, vuint32m2_t, vuint32m2_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vremu_vv)))
vuint32m4_t vremu_vv_u32m4(vuint32m4_t, vuint32m4_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vremu_vv_m)))
vuint32m4_t vremu_vv_u32m4_m(vbool8_t, vuint32m4_t, vuint32m4_t, vuint32m4_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vremu_vv)))
vuint32m8_t vremu_vv_u32m8(vuint32m8_t, vuint32m8_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vremu_vv_m)))
vuint32m8_t vremu_vv_u32m8_m(vbool4_t, vuint32m8_t, vuint32m8_t, vuint32m8_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vremu_vv)))
vuint32mf2_t vremu_vv_u32mf2(vuint32mf2_t, vuint32mf2_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vremu_vv_m)))
vuint32mf2_t vremu_vv_u32mf2_m(vbool64_t, vuint32mf2_t, vuint32mf2_t, vuint32mf2_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vremu_vx)))
vuint8m1_t vremu_vx_u8m1(vuint8m1_t, uint8_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vremu_vx_m)))
vuint8m1_t vremu_vx_u8m1_m(vbool8_t, vuint8m1_t, vuint8m1_t, uint8_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vremu_vx)))
vuint8m2_t vremu_vx_u8m2(vuint8m2_t, uint8_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vremu_vx_m)))
vuint8m2_t vremu_vx_u8m2_m(vbool4_t, vuint8m2_t, vuint8m2_t, uint8_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vremu_vx)))
vuint8m4_t vremu_vx_u8m4(vuint8m4_t, uint8_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vremu_vx_m)))
vuint8m4_t vremu_vx_u8m4_m(vbool2_t, vuint8m4_t, vuint8m4_t, uint8_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vremu_vx)))
vuint8m8_t vremu_vx_u8m8(vuint8m8_t, uint8_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vremu_vx_m)))
vuint8m8_t vremu_vx_u8m8_m(vbool1_t, vuint8m8_t, vuint8m8_t, uint8_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vremu_vx)))
vuint8mf2_t vremu_vx_u8mf2(vuint8mf2_t, uint8_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vremu_vx_m)))
vuint8mf2_t vremu_vx_u8mf2_m(vbool16_t, vuint8mf2_t, vuint8mf2_t, uint8_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vremu_vx)))
vuint8mf4_t vremu_vx_u8mf4(vuint8mf4_t, uint8_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vremu_vx_m)))
vuint8mf4_t vremu_vx_u8mf4_m(vbool32_t, vuint8mf4_t, vuint8mf4_t, uint8_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vremu_vx)))
vuint8mf8_t vremu_vx_u8mf8(vuint8mf8_t, uint8_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vremu_vx_m)))
vuint8mf8_t vremu_vx_u8mf8_m(vbool64_t, vuint8mf8_t, vuint8mf8_t, uint8_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vremu_vx)))
vuint16m1_t vremu_vx_u16m1(vuint16m1_t, uint16_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vremu_vx_m)))
vuint16m1_t vremu_vx_u16m1_m(vbool16_t, vuint16m1_t, vuint16m1_t, uint16_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vremu_vx)))
vuint16m2_t vremu_vx_u16m2(vuint16m2_t, uint16_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vremu_vx_m)))
vuint16m2_t vremu_vx_u16m2_m(vbool8_t, vuint16m2_t, vuint16m2_t, uint16_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vremu_vx)))
vuint16m4_t vremu_vx_u16m4(vuint16m4_t, uint16_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vremu_vx_m)))
vuint16m4_t vremu_vx_u16m4_m(vbool4_t, vuint16m4_t, vuint16m4_t, uint16_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vremu_vx)))
vuint16m8_t vremu_vx_u16m8(vuint16m8_t, uint16_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vremu_vx_m)))
vuint16m8_t vremu_vx_u16m8_m(vbool2_t, vuint16m8_t, vuint16m8_t, uint16_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vremu_vx)))
vuint16mf2_t vremu_vx_u16mf2(vuint16mf2_t, uint16_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vremu_vx_m)))
vuint16mf2_t vremu_vx_u16mf2_m(vbool32_t, vuint16mf2_t, vuint16mf2_t, uint16_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vremu_vx)))
vuint16mf4_t vremu_vx_u16mf4(vuint16mf4_t, uint16_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vremu_vx_m)))
vuint16mf4_t vremu_vx_u16mf4_m(vbool64_t, vuint16mf4_t, vuint16mf4_t, uint16_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vremu_vx)))
vuint32m1_t vremu_vx_u32m1(vuint32m1_t, uint32_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vremu_vx_m)))
vuint32m1_t vremu_vx_u32m1_m(vbool32_t, vuint32m1_t, vuint32m1_t, uint32_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vremu_vx)))
vuint32m2_t vremu_vx_u32m2(vuint32m2_t, uint32_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vremu_vx_m)))
vuint32m2_t vremu_vx_u32m2_m(vbool16_t, vuint32m2_t, vuint32m2_t, uint32_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vremu_vx)))
vuint32m4_t vremu_vx_u32m4(vuint32m4_t, uint32_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vremu_vx_m)))
vuint32m4_t vremu_vx_u32m4_m(vbool8_t, vuint32m4_t, vuint32m4_t, uint32_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vremu_vx)))
vuint32m8_t vremu_vx_u32m8(vuint32m8_t, uint32_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vremu_vx_m)))
vuint32m8_t vremu_vx_u32m8_m(vbool4_t, vuint32m8_t, vuint32m8_t, uint32_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vremu_vx)))
vuint32mf2_t vremu_vx_u32mf2(vuint32mf2_t, uint32_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vremu_vx_m)))
vuint32mf2_t vremu_vx_u32mf2_m(vbool64_t, vuint32mf2_t, vuint32mf2_t, uint32_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vrem_vv)))
vint8m1_t vrem_vv_i8m1(vint8m1_t, vint8m1_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vrem_vv_m)))
vint8m1_t vrem_vv_i8m1_m(vbool8_t, vint8m1_t, vint8m1_t, vint8m1_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vrem_vv)))
vint8m2_t vrem_vv_i8m2(vint8m2_t, vint8m2_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vrem_vv_m)))
vint8m2_t vrem_vv_i8m2_m(vbool4_t, vint8m2_t, vint8m2_t, vint8m2_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vrem_vv)))
vint8m4_t vrem_vv_i8m4(vint8m4_t, vint8m4_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vrem_vv_m)))
vint8m4_t vrem_vv_i8m4_m(vbool2_t, vint8m4_t, vint8m4_t, vint8m4_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vrem_vv)))
vint8m8_t vrem_vv_i8m8(vint8m8_t, vint8m8_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vrem_vv_m)))
vint8m8_t vrem_vv_i8m8_m(vbool1_t, vint8m8_t, vint8m8_t, vint8m8_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vrem_vv)))
vint8mf2_t vrem_vv_i8mf2(vint8mf2_t, vint8mf2_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vrem_vv_m)))
vint8mf2_t vrem_vv_i8mf2_m(vbool16_t, vint8mf2_t, vint8mf2_t, vint8mf2_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vrem_vv)))
vint8mf4_t vrem_vv_i8mf4(vint8mf4_t, vint8mf4_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vrem_vv_m)))
vint8mf4_t vrem_vv_i8mf4_m(vbool32_t, vint8mf4_t, vint8mf4_t, vint8mf4_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vrem_vv)))
vint8mf8_t vrem_vv_i8mf8(vint8mf8_t, vint8mf8_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vrem_vv_m)))
vint8mf8_t vrem_vv_i8mf8_m(vbool64_t, vint8mf8_t, vint8mf8_t, vint8mf8_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vrem_vv)))
vint16m1_t vrem_vv_i16m1(vint16m1_t, vint16m1_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vrem_vv_m)))
vint16m1_t vrem_vv_i16m1_m(vbool16_t, vint16m1_t, vint16m1_t, vint16m1_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vrem_vv)))
vint16m2_t vrem_vv_i16m2(vint16m2_t, vint16m2_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vrem_vv_m)))
vint16m2_t vrem_vv_i16m2_m(vbool8_t, vint16m2_t, vint16m2_t, vint16m2_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vrem_vv)))
vint16m4_t vrem_vv_i16m4(vint16m4_t, vint16m4_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vrem_vv_m)))
vint16m4_t vrem_vv_i16m4_m(vbool4_t, vint16m4_t, vint16m4_t, vint16m4_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vrem_vv)))
vint16m8_t vrem_vv_i16m8(vint16m8_t, vint16m8_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vrem_vv_m)))
vint16m8_t vrem_vv_i16m8_m(vbool2_t, vint16m8_t, vint16m8_t, vint16m8_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vrem_vv)))
vint16mf2_t vrem_vv_i16mf2(vint16mf2_t, vint16mf2_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vrem_vv_m)))
vint16mf2_t vrem_vv_i16mf2_m(vbool32_t, vint16mf2_t, vint16mf2_t, vint16mf2_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vrem_vv)))
vint16mf4_t vrem_vv_i16mf4(vint16mf4_t, vint16mf4_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vrem_vv_m)))
vint16mf4_t vrem_vv_i16mf4_m(vbool64_t, vint16mf4_t, vint16mf4_t, vint16mf4_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vrem_vv)))
vint32m1_t vrem_vv_i32m1(vint32m1_t, vint32m1_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vrem_vv_m)))
vint32m1_t vrem_vv_i32m1_m(vbool32_t, vint32m1_t, vint32m1_t, vint32m1_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vrem_vv)))
vint32m2_t vrem_vv_i32m2(vint32m2_t, vint32m2_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vrem_vv_m)))
vint32m2_t vrem_vv_i32m2_m(vbool16_t, vint32m2_t, vint32m2_t, vint32m2_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vrem_vv)))
vint32m4_t vrem_vv_i32m4(vint32m4_t, vint32m4_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vrem_vv_m)))
vint32m4_t vrem_vv_i32m4_m(vbool8_t, vint32m4_t, vint32m4_t, vint32m4_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vrem_vv)))
vint32m8_t vrem_vv_i32m8(vint32m8_t, vint32m8_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vrem_vv_m)))
vint32m8_t vrem_vv_i32m8_m(vbool4_t, vint32m8_t, vint32m8_t, vint32m8_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vrem_vv)))
vint32mf2_t vrem_vv_i32mf2(vint32mf2_t, vint32mf2_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vrem_vv_m)))
vint32mf2_t vrem_vv_i32mf2_m(vbool64_t, vint32mf2_t, vint32mf2_t, vint32mf2_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vrem_vx)))
vint8m1_t vrem_vx_i8m1(vint8m1_t, int8_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vrem_vx_m)))
vint8m1_t vrem_vx_i8m1_m(vbool8_t, vint8m1_t, vint8m1_t, int8_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vrem_vx)))
vint8m2_t vrem_vx_i8m2(vint8m2_t, int8_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vrem_vx_m)))
vint8m2_t vrem_vx_i8m2_m(vbool4_t, vint8m2_t, vint8m2_t, int8_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vrem_vx)))
vint8m4_t vrem_vx_i8m4(vint8m4_t, int8_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vrem_vx_m)))
vint8m4_t vrem_vx_i8m4_m(vbool2_t, vint8m4_t, vint8m4_t, int8_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vrem_vx)))
vint8m8_t vrem_vx_i8m8(vint8m8_t, int8_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vrem_vx_m)))
vint8m8_t vrem_vx_i8m8_m(vbool1_t, vint8m8_t, vint8m8_t, int8_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vrem_vx)))
vint8mf2_t vrem_vx_i8mf2(vint8mf2_t, int8_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vrem_vx_m)))
vint8mf2_t vrem_vx_i8mf2_m(vbool16_t, vint8mf2_t, vint8mf2_t, int8_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vrem_vx)))
vint8mf4_t vrem_vx_i8mf4(vint8mf4_t, int8_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vrem_vx_m)))
vint8mf4_t vrem_vx_i8mf4_m(vbool32_t, vint8mf4_t, vint8mf4_t, int8_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vrem_vx)))
vint8mf8_t vrem_vx_i8mf8(vint8mf8_t, int8_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vrem_vx_m)))
vint8mf8_t vrem_vx_i8mf8_m(vbool64_t, vint8mf8_t, vint8mf8_t, int8_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vrem_vx)))
vint16m1_t vrem_vx_i16m1(vint16m1_t, int16_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vrem_vx_m)))
vint16m1_t vrem_vx_i16m1_m(vbool16_t, vint16m1_t, vint16m1_t, int16_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vrem_vx)))
vint16m2_t vrem_vx_i16m2(vint16m2_t, int16_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vrem_vx_m)))
vint16m2_t vrem_vx_i16m2_m(vbool8_t, vint16m2_t, vint16m2_t, int16_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vrem_vx)))
vint16m4_t vrem_vx_i16m4(vint16m4_t, int16_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vrem_vx_m)))
vint16m4_t vrem_vx_i16m4_m(vbool4_t, vint16m4_t, vint16m4_t, int16_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vrem_vx)))
vint16m8_t vrem_vx_i16m8(vint16m8_t, int16_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vrem_vx_m)))
vint16m8_t vrem_vx_i16m8_m(vbool2_t, vint16m8_t, vint16m8_t, int16_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vrem_vx)))
vint16mf2_t vrem_vx_i16mf2(vint16mf2_t, int16_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vrem_vx_m)))
vint16mf2_t vrem_vx_i16mf2_m(vbool32_t, vint16mf2_t, vint16mf2_t, int16_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vrem_vx)))
vint16mf4_t vrem_vx_i16mf4(vint16mf4_t, int16_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vrem_vx_m)))
vint16mf4_t vrem_vx_i16mf4_m(vbool64_t, vint16mf4_t, vint16mf4_t, int16_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vrem_vx)))
vint32m1_t vrem_vx_i32m1(vint32m1_t, int32_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vrem_vx_m)))
vint32m1_t vrem_vx_i32m1_m(vbool32_t, vint32m1_t, vint32m1_t, int32_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vrem_vx)))
vint32m2_t vrem_vx_i32m2(vint32m2_t, int32_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vrem_vx_m)))
vint32m2_t vrem_vx_i32m2_m(vbool16_t, vint32m2_t, vint32m2_t, int32_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vrem_vx)))
vint32m4_t vrem_vx_i32m4(vint32m4_t, int32_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vrem_vx_m)))
vint32m4_t vrem_vx_i32m4_m(vbool8_t, vint32m4_t, vint32m4_t, int32_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vrem_vx)))
vint32m8_t vrem_vx_i32m8(vint32m8_t, int32_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vrem_vx_m)))
vint32m8_t vrem_vx_i32m8_m(vbool4_t, vint32m8_t, vint32m8_t, int32_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vrem_vx)))
vint32mf2_t vrem_vx_i32mf2(vint32mf2_t, int32_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vrem_vx_m)))
vint32mf2_t vrem_vx_i32mf2_m(vbool64_t, vint32mf2_t, vint32mf2_t, int32_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vwmul_vv)))
vint16mf4_t vwmul_vv_i16mf4(vint8mf8_t, vint8mf8_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vwmul_vv_m)))
vint16mf4_t vwmul_vv_i16mf4_m(vbool64_t, vint16mf4_t, vint8mf8_t, vint8mf8_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vwmul_vv)))
vint16mf2_t vwmul_vv_i16mf2(vint8mf4_t, vint8mf4_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vwmul_vv_m)))
vint16mf2_t vwmul_vv_i16mf2_m(vbool32_t, vint16mf2_t, vint8mf4_t, vint8mf4_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vwmul_vv)))
vint16m1_t vwmul_vv_i16m1(vint8mf2_t, vint8mf2_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vwmul_vv_m)))
vint16m1_t vwmul_vv_i16m1_m(vbool16_t, vint16m1_t, vint8mf2_t, vint8mf2_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vwmul_vv)))
vint16m2_t vwmul_vv_i16m2(vint8m1_t, vint8m1_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vwmul_vv_m)))
vint16m2_t vwmul_vv_i16m2_m(vbool8_t, vint16m2_t, vint8m1_t, vint8m1_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vwmul_vv)))
vint16m4_t vwmul_vv_i16m4(vint8m2_t, vint8m2_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vwmul_vv_m)))
vint16m4_t vwmul_vv_i16m4_m(vbool4_t, vint16m4_t, vint8m2_t, vint8m2_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vwmul_vv)))
vint16m8_t vwmul_vv_i16m8(vint8m4_t, vint8m4_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vwmul_vv_m)))
vint16m8_t vwmul_vv_i16m8_m(vbool2_t, vint16m8_t, vint8m4_t, vint8m4_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vwmul_vv)))
vint32mf2_t vwmul_vv_i32mf2(vint16mf4_t, vint16mf4_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vwmul_vv_m)))
vint32mf2_t vwmul_vv_i32mf2_m(vbool64_t, vint32mf2_t, vint16mf4_t, vint16mf4_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vwmul_vv)))
vint32m1_t vwmul_vv_i32m1(vint16mf2_t, vint16mf2_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vwmul_vv_m)))
vint32m1_t vwmul_vv_i32m1_m(vbool32_t, vint32m1_t, vint16mf2_t, vint16mf2_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vwmul_vv)))
vint32m2_t vwmul_vv_i32m2(vint16m1_t, vint16m1_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vwmul_vv_m)))
vint32m2_t vwmul_vv_i32m2_m(vbool16_t, vint32m2_t, vint16m1_t, vint16m1_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vwmul_vv)))
vint32m4_t vwmul_vv_i32m4(vint16m2_t, vint16m2_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vwmul_vv_m)))
vint32m4_t vwmul_vv_i32m4_m(vbool8_t, vint32m4_t, vint16m2_t, vint16m2_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vwmul_vv)))
vint32m8_t vwmul_vv_i32m8(vint16m4_t, vint16m4_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vwmul_vv_m)))
vint32m8_t vwmul_vv_i32m8_m(vbool4_t, vint32m8_t, vint16m4_t, vint16m4_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vsuxei32_v)))
void vsuxei32_v_u8m1(uint8_t *, vuint32m4_t, vuint8m1_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vsuxei32_v_m)))
void vsuxei32_v_u8m1_m(vbool8_t, uint8_t *, vuint32m4_t, vuint8m1_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vsuxei32_v)))
void vsuxei32_v_u8m2(uint8_t *, vuint32m8_t, vuint8m2_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vsuxei32_v_m)))
void vsuxei32_v_u8m2_m(vbool4_t, uint8_t *, vuint32m8_t, vuint8m2_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vsuxei32_v)))
void vsuxei32_v_u8mf2(uint8_t *, vuint32m2_t, vuint8mf2_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vsuxei32_v_m)))
void vsuxei32_v_u8mf2_m(vbool16_t, uint8_t *, vuint32m2_t, vuint8mf2_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vsuxei32_v)))
void vsuxei32_v_u8mf4(uint8_t *, vuint32m1_t, vuint8mf4_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vsuxei32_v_m)))
void vsuxei32_v_u8mf4_m(vbool32_t, uint8_t *, vuint32m1_t, vuint8mf4_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vsuxei32_v)))
void vsuxei32_v_u8mf8(uint8_t *, vuint32mf2_t, vuint8mf8_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vsuxei32_v_m)))
void vsuxei32_v_u8mf8_m(vbool64_t, uint8_t *, vuint32mf2_t, vuint8mf8_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vwmul_vx)))
vint16mf4_t vwmul_vx_i16mf4(vint8mf8_t, int8_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vwmul_vx_m)))
vint16mf4_t vwmul_vx_i16mf4_m(vbool64_t, vint16mf4_t, vint8mf8_t, int8_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vwmul_vx)))
vint16mf2_t vwmul_vx_i16mf2(vint8mf4_t, int8_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vwmul_vx_m)))
vint16mf2_t vwmul_vx_i16mf2_m(vbool32_t, vint16mf2_t, vint8mf4_t, int8_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vwmul_vx)))
vint16m1_t vwmul_vx_i16m1(vint8mf2_t, int8_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vwmul_vx_m)))
vint16m1_t vwmul_vx_i16m1_m(vbool16_t, vint16m1_t, vint8mf2_t, int8_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vwmul_vx)))
vint16m2_t vwmul_vx_i16m2(vint8m1_t, int8_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vwmul_vx_m)))
vint16m2_t vwmul_vx_i16m2_m(vbool8_t, vint16m2_t, vint8m1_t, int8_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vwmul_vx)))
vint16m4_t vwmul_vx_i16m4(vint8m2_t, int8_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vwmul_vx_m)))
vint16m4_t vwmul_vx_i16m4_m(vbool4_t, vint16m4_t, vint8m2_t, int8_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vwmul_vx)))
vint16m8_t vwmul_vx_i16m8(vint8m4_t, int8_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vwmul_vx_m)))
vint16m8_t vwmul_vx_i16m8_m(vbool2_t, vint16m8_t, vint8m4_t, int8_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vwmul_vx)))
vint32mf2_t vwmul_vx_i32mf2(vint16mf4_t, int16_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vwmul_vx_m)))
vint32mf2_t vwmul_vx_i32mf2_m(vbool64_t, vint32mf2_t, vint16mf4_t, int16_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vwmul_vx)))
vint32m1_t vwmul_vx_i32m1(vint16mf2_t, int16_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vwmul_vx_m)))
vint32m1_t vwmul_vx_i32m1_m(vbool32_t, vint32m1_t, vint16mf2_t, int16_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vwmul_vx)))
vint32m2_t vwmul_vx_i32m2(vint16m1_t, int16_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vwmul_vx_m)))
vint32m2_t vwmul_vx_i32m2_m(vbool16_t, vint32m2_t, vint16m1_t, int16_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vwmul_vx)))
vint32m4_t vwmul_vx_i32m4(vint16m2_t, int16_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vwmul_vx_m)))
vint32m4_t vwmul_vx_i32m4_m(vbool8_t, vint32m4_t, vint16m2_t, int16_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vwmul_vx)))
vint32m8_t vwmul_vx_i32m8(vint16m4_t, int16_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vwmul_vx_m)))
vint32m8_t vwmul_vx_i32m8_m(vbool4_t, vint32m8_t, vint16m4_t, int16_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vwmulu_vv)))
vuint16mf4_t vwmulu_vv_u16mf4(vuint8mf8_t, vuint8mf8_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vwmulu_vv_m)))
vuint16mf4_t vwmulu_vv_u16mf4_m(vbool64_t, vuint16mf4_t, vuint8mf8_t, vuint8mf8_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vwmulu_vv)))
vuint16mf2_t vwmulu_vv_u16mf2(vuint8mf4_t, vuint8mf4_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vwmulu_vv_m)))
vuint16mf2_t vwmulu_vv_u16mf2_m(vbool32_t, vuint16mf2_t, vuint8mf4_t, vuint8mf4_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vwmulu_vv)))
vuint16m1_t vwmulu_vv_u16m1(vuint8mf2_t, vuint8mf2_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vwmulu_vv_m)))
vuint16m1_t vwmulu_vv_u16m1_m(vbool16_t, vuint16m1_t, vuint8mf2_t, vuint8mf2_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vwmulu_vv)))
vuint16m2_t vwmulu_vv_u16m2(vuint8m1_t, vuint8m1_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vwmulu_vv_m)))
vuint16m2_t vwmulu_vv_u16m2_m(vbool8_t, vuint16m2_t, vuint8m1_t, vuint8m1_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vwmulu_vv)))
vuint16m4_t vwmulu_vv_u16m4(vuint8m2_t, vuint8m2_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vwmulu_vv_m)))
vuint16m4_t vwmulu_vv_u16m4_m(vbool4_t, vuint16m4_t, vuint8m2_t, vuint8m2_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vwmulu_vv)))
vuint16m8_t vwmulu_vv_u16m8(vuint8m4_t, vuint8m4_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vwmulu_vv_m)))
vuint16m8_t vwmulu_vv_u16m8_m(vbool2_t, vuint16m8_t, vuint8m4_t, vuint8m4_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vwmulu_vv)))
vuint32mf2_t vwmulu_vv_u32mf2(vuint16mf4_t, vuint16mf4_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vwmulu_vv_m)))
vuint32mf2_t vwmulu_vv_u32mf2_m(vbool64_t, vuint32mf2_t, vuint16mf4_t, vuint16mf4_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vwmulu_vv)))
vuint32m1_t vwmulu_vv_u32m1(vuint16mf2_t, vuint16mf2_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vwmulu_vv_m)))
vuint32m1_t vwmulu_vv_u32m1_m(vbool32_t, vuint32m1_t, vuint16mf2_t, vuint16mf2_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vwmulu_vv)))
vuint32m2_t vwmulu_vv_u32m2(vuint16m1_t, vuint16m1_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vwmulu_vv_m)))
vuint32m2_t vwmulu_vv_u32m2_m(vbool16_t, vuint32m2_t, vuint16m1_t, vuint16m1_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vwmulu_vv)))
vuint32m4_t vwmulu_vv_u32m4(vuint16m2_t, vuint16m2_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vwmulu_vv_m)))
vuint32m4_t vwmulu_vv_u32m4_m(vbool8_t, vuint32m4_t, vuint16m2_t, vuint16m2_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vwmulu_vv)))
vuint32m8_t vwmulu_vv_u32m8(vuint16m4_t, vuint16m4_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vwmulu_vv_m)))
vuint32m8_t vwmulu_vv_u32m8_m(vbool4_t, vuint32m8_t, vuint16m4_t, vuint16m4_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vwmulu_vx)))
vuint16mf4_t vwmulu_vx_u16mf4(vuint8mf8_t, uint8_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vwmulu_vx_m)))
vuint16mf4_t vwmulu_vx_u16mf4_m(vbool64_t, vuint16mf4_t, vuint8mf8_t, uint8_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vwmulu_vx)))
vuint16mf2_t vwmulu_vx_u16mf2(vuint8mf4_t, uint8_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vwmulu_vx_m)))
vuint16mf2_t vwmulu_vx_u16mf2_m(vbool32_t, vuint16mf2_t, vuint8mf4_t, uint8_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vwmulu_vx)))
vuint16m1_t vwmulu_vx_u16m1(vuint8mf2_t, uint8_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vwmulu_vx_m)))
vuint16m1_t vwmulu_vx_u16m1_m(vbool16_t, vuint16m1_t, vuint8mf2_t, uint8_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vwmulu_vx)))
vuint16m2_t vwmulu_vx_u16m2(vuint8m1_t, uint8_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vwmulu_vx_m)))
vuint16m2_t vwmulu_vx_u16m2_m(vbool8_t, vuint16m2_t, vuint8m1_t, uint8_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vwmulu_vx)))
vuint16m4_t vwmulu_vx_u16m4(vuint8m2_t, uint8_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vwmulu_vx_m)))
vuint16m4_t vwmulu_vx_u16m4_m(vbool4_t, vuint16m4_t, vuint8m2_t, uint8_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vwmulu_vx)))
vuint16m8_t vwmulu_vx_u16m8(vuint8m4_t, uint8_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vwmulu_vx_m)))
vuint16m8_t vwmulu_vx_u16m8_m(vbool2_t, vuint16m8_t, vuint8m4_t, uint8_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vwmulu_vx)))
vuint32mf2_t vwmulu_vx_u32mf2(vuint16mf4_t, uint16_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vwmulu_vx_m)))
vuint32mf2_t vwmulu_vx_u32mf2_m(vbool64_t, vuint32mf2_t, vuint16mf4_t, uint16_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vwmulu_vx)))
vuint32m1_t vwmulu_vx_u32m1(vuint16mf2_t, uint16_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vwmulu_vx_m)))
vuint32m1_t vwmulu_vx_u32m1_m(vbool32_t, vuint32m1_t, vuint16mf2_t, uint16_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vwmulu_vx)))
vuint32m2_t vwmulu_vx_u32m2(vuint16m1_t, uint16_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vwmulu_vx_m)))
vuint32m2_t vwmulu_vx_u32m2_m(vbool16_t, vuint32m2_t, vuint16m1_t, uint16_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vwmulu_vx)))
vuint32m4_t vwmulu_vx_u32m4(vuint16m2_t, uint16_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vwmulu_vx_m)))
vuint32m4_t vwmulu_vx_u32m4_m(vbool8_t, vuint32m4_t, vuint16m2_t, uint16_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vwmulu_vx)))
vuint32m8_t vwmulu_vx_u32m8(vuint16m4_t, uint16_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vwmulu_vx_m)))
vuint32m8_t vwmulu_vx_u32m8_m(vbool4_t, vuint32m8_t, vuint16m4_t, uint16_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vwmulsu_vv)))
vint16mf4_t vwmulsu_vv_i16mf4(vint8mf8_t, vuint8mf8_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vwmulsu_vv_m)))
vint16mf4_t vwmulsu_vv_i16mf4_m(vbool64_t, vint16mf4_t, vint8mf8_t, vuint8mf8_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vwmulsu_vv)))
vint16mf2_t vwmulsu_vv_i16mf2(vint8mf4_t, vuint8mf4_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vwmulsu_vv_m)))
vint16mf2_t vwmulsu_vv_i16mf2_m(vbool32_t, vint16mf2_t, vint8mf4_t, vuint8mf4_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vwmulsu_vv)))
vint16m1_t vwmulsu_vv_i16m1(vint8mf2_t, vuint8mf2_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vwmulsu_vv_m)))
vint16m1_t vwmulsu_vv_i16m1_m(vbool16_t, vint16m1_t, vint8mf2_t, vuint8mf2_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vwmulsu_vv)))
vint16m2_t vwmulsu_vv_i16m2(vint8m1_t, vuint8m1_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vwmulsu_vv_m)))
vint16m2_t vwmulsu_vv_i16m2_m(vbool8_t, vint16m2_t, vint8m1_t, vuint8m1_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vwmulsu_vv)))
vint16m4_t vwmulsu_vv_i16m4(vint8m2_t, vuint8m2_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vwmulsu_vv_m)))
vint16m4_t vwmulsu_vv_i16m4_m(vbool4_t, vint16m4_t, vint8m2_t, vuint8m2_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vwmulsu_vv)))
vint16m8_t vwmulsu_vv_i16m8(vint8m4_t, vuint8m4_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vwmulsu_vv_m)))
vint16m8_t vwmulsu_vv_i16m8_m(vbool2_t, vint16m8_t, vint8m4_t, vuint8m4_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vwmulsu_vv)))
vint32mf2_t vwmulsu_vv_i32mf2(vint16mf4_t, vuint16mf4_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vwmulsu_vv_m)))
vint32mf2_t vwmulsu_vv_i32mf2_m(vbool64_t, vint32mf2_t, vint16mf4_t, vuint16mf4_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vwmulsu_vv)))
vint32m1_t vwmulsu_vv_i32m1(vint16mf2_t, vuint16mf2_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vwmulsu_vv_m)))
vint32m1_t vwmulsu_vv_i32m1_m(vbool32_t, vint32m1_t, vint16mf2_t, vuint16mf2_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vwmulsu_vv)))
vint32m2_t vwmulsu_vv_i32m2(vint16m1_t, vuint16m1_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vwmulsu_vv_m)))
vint32m2_t vwmulsu_vv_i32m2_m(vbool16_t, vint32m2_t, vint16m1_t, vuint16m1_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vwmulsu_vv)))
vint32m4_t vwmulsu_vv_i32m4(vint16m2_t, vuint16m2_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vwmulsu_vv_m)))
vint32m4_t vwmulsu_vv_i32m4_m(vbool8_t, vint32m4_t, vint16m2_t, vuint16m2_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vwmulsu_vv)))
vint32m8_t vwmulsu_vv_i32m8(vint16m4_t, vuint16m4_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vwmulsu_vv_m)))
vint32m8_t vwmulsu_vv_i32m8_m(vbool4_t, vint32m8_t, vint16m4_t, vuint16m4_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vwmulsu_vx)))
vint16mf4_t vwmulsu_vx_i16mf4(vint8mf8_t, uint8_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vwmulsu_vx_m)))
vint16mf4_t vwmulsu_vx_i16mf4_m(vbool64_t, vint16mf4_t, vint8mf8_t, uint8_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vwmulsu_vx)))
vint16mf2_t vwmulsu_vx_i16mf2(vint8mf4_t, uint8_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vwmulsu_vx_m)))
vint16mf2_t vwmulsu_vx_i16mf2_m(vbool32_t, vint16mf2_t, vint8mf4_t, uint8_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vwmulsu_vx)))
vint16m1_t vwmulsu_vx_i16m1(vint8mf2_t, uint8_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vwmulsu_vx_m)))
vint16m1_t vwmulsu_vx_i16m1_m(vbool16_t, vint16m1_t, vint8mf2_t, uint8_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vwmulsu_vx)))
vint16m2_t vwmulsu_vx_i16m2(vint8m1_t, uint8_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vwmulsu_vx_m)))
vint16m2_t vwmulsu_vx_i16m2_m(vbool8_t, vint16m2_t, vint8m1_t, uint8_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vwmulsu_vx)))
vint16m4_t vwmulsu_vx_i16m4(vint8m2_t, uint8_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vwmulsu_vx_m)))
vint16m4_t vwmulsu_vx_i16m4_m(vbool4_t, vint16m4_t, vint8m2_t, uint8_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vwmulsu_vx)))
vint16m8_t vwmulsu_vx_i16m8(vint8m4_t, uint8_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vwmulsu_vx_m)))
vint16m8_t vwmulsu_vx_i16m8_m(vbool2_t, vint16m8_t, vint8m4_t, uint8_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vwmulsu_vx)))
vint32mf2_t vwmulsu_vx_i32mf2(vint16mf4_t, uint16_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vwmulsu_vx_m)))
vint32mf2_t vwmulsu_vx_i32mf2_m(vbool64_t, vint32mf2_t, vint16mf4_t, uint16_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vwmulsu_vx)))
vint32m1_t vwmulsu_vx_i32m1(vint16mf2_t, uint16_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vwmulsu_vx_m)))
vint32m1_t vwmulsu_vx_i32m1_m(vbool32_t, vint32m1_t, vint16mf2_t, uint16_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vwmulsu_vx)))
vint32m2_t vwmulsu_vx_i32m2(vint16m1_t, uint16_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vwmulsu_vx_m)))
vint32m2_t vwmulsu_vx_i32m2_m(vbool16_t, vint32m2_t, vint16m1_t, uint16_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vwmulsu_vx)))
vint32m4_t vwmulsu_vx_i32m4(vint16m2_t, uint16_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vwmulsu_vx_m)))
vint32m4_t vwmulsu_vx_i32m4_m(vbool8_t, vint32m4_t, vint16m2_t, uint16_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vwmulsu_vx)))
vint32m8_t vwmulsu_vx_i32m8(vint16m4_t, uint16_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vwmulsu_vx_m)))
vint32m8_t vwmulsu_vx_i32m8_m(vbool4_t, vint32m8_t, vint16m4_t, uint16_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vmacc_vv)))
vint8m1_t vmacc_vv_i8m1(vint8m1_t, vint8m1_t, vint8m1_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vmacc_vv_m)))
vint8m1_t vmacc_vv_i8m1_m(vbool8_t, vint8m1_t, vint8m1_t, vint8m1_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vmacc_vv)))
vint8m2_t vmacc_vv_i8m2(vint8m2_t, vint8m2_t, vint8m2_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vmacc_vv_m)))
vint8m2_t vmacc_vv_i8m2_m(vbool4_t, vint8m2_t, vint8m2_t, vint8m2_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vmacc_vv)))
vint8m4_t vmacc_vv_i8m4(vint8m4_t, vint8m4_t, vint8m4_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vmacc_vv_m)))
vint8m4_t vmacc_vv_i8m4_m(vbool2_t, vint8m4_t, vint8m4_t, vint8m4_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vmacc_vv)))
vint8m8_t vmacc_vv_i8m8(vint8m8_t, vint8m8_t, vint8m8_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vmacc_vv_m)))
vint8m8_t vmacc_vv_i8m8_m(vbool1_t, vint8m8_t, vint8m8_t, vint8m8_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vmacc_vv)))
vint8mf2_t vmacc_vv_i8mf2(vint8mf2_t, vint8mf2_t, vint8mf2_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vmacc_vv_m)))
vint8mf2_t vmacc_vv_i8mf2_m(vbool16_t, vint8mf2_t, vint8mf2_t, vint8mf2_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vmacc_vv)))
vint8mf4_t vmacc_vv_i8mf4(vint8mf4_t, vint8mf4_t, vint8mf4_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vmacc_vv_m)))
vint8mf4_t vmacc_vv_i8mf4_m(vbool32_t, vint8mf4_t, vint8mf4_t, vint8mf4_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vmacc_vv)))
vint8mf8_t vmacc_vv_i8mf8(vint8mf8_t, vint8mf8_t, vint8mf8_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vmacc_vv_m)))
vint8mf8_t vmacc_vv_i8mf8_m(vbool64_t, vint8mf8_t, vint8mf8_t, vint8mf8_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vmacc_vv)))
vint16m1_t vmacc_vv_i16m1(vint16m1_t, vint16m1_t, vint16m1_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vmacc_vv_m)))
vint16m1_t vmacc_vv_i16m1_m(vbool16_t, vint16m1_t, vint16m1_t, vint16m1_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vmacc_vv)))
vint16m2_t vmacc_vv_i16m2(vint16m2_t, vint16m2_t, vint16m2_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vmacc_vv_m)))
vint16m2_t vmacc_vv_i16m2_m(vbool8_t, vint16m2_t, vint16m2_t, vint16m2_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vmacc_vv)))
vint16m4_t vmacc_vv_i16m4(vint16m4_t, vint16m4_t, vint16m4_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vmacc_vv_m)))
vint16m4_t vmacc_vv_i16m4_m(vbool4_t, vint16m4_t, vint16m4_t, vint16m4_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vmacc_vv)))
vint16m8_t vmacc_vv_i16m8(vint16m8_t, vint16m8_t, vint16m8_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vmacc_vv_m)))
vint16m8_t vmacc_vv_i16m8_m(vbool2_t, vint16m8_t, vint16m8_t, vint16m8_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vmacc_vv)))
vint16mf2_t vmacc_vv_i16mf2(vint16mf2_t, vint16mf2_t, vint16mf2_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vmacc_vv_m)))
vint16mf2_t vmacc_vv_i16mf2_m(vbool32_t, vint16mf2_t, vint16mf2_t, vint16mf2_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vmacc_vv)))
vint16mf4_t vmacc_vv_i16mf4(vint16mf4_t, vint16mf4_t, vint16mf4_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vmacc_vv_m)))
vint16mf4_t vmacc_vv_i16mf4_m(vbool64_t, vint16mf4_t, vint16mf4_t, vint16mf4_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vmacc_vv)))
vint32m1_t vmacc_vv_i32m1(vint32m1_t, vint32m1_t, vint32m1_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vmacc_vv_m)))
vint32m1_t vmacc_vv_i32m1_m(vbool32_t, vint32m1_t, vint32m1_t, vint32m1_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vmacc_vv)))
vint32m2_t vmacc_vv_i32m2(vint32m2_t, vint32m2_t, vint32m2_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vmacc_vv_m)))
vint32m2_t vmacc_vv_i32m2_m(vbool16_t, vint32m2_t, vint32m2_t, vint32m2_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vmacc_vv)))
vint32m4_t vmacc_vv_i32m4(vint32m4_t, vint32m4_t, vint32m4_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vmacc_vv_m)))
vint32m4_t vmacc_vv_i32m4_m(vbool8_t, vint32m4_t, vint32m4_t, vint32m4_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vmacc_vv)))
vint32m8_t vmacc_vv_i32m8(vint32m8_t, vint32m8_t, vint32m8_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vmacc_vv_m)))
vint32m8_t vmacc_vv_i32m8_m(vbool4_t, vint32m8_t, vint32m8_t, vint32m8_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vmacc_vv)))
vint32mf2_t vmacc_vv_i32mf2(vint32mf2_t, vint32mf2_t, vint32mf2_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vmacc_vv_m)))
vint32mf2_t vmacc_vv_i32mf2_m(vbool64_t, vint32mf2_t, vint32mf2_t, vint32mf2_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vmacc_vx)))
vint8m1_t vmacc_vx_i8m1(vint8m1_t, int8_t, vint8m1_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vmacc_vx_m)))
vint8m1_t vmacc_vx_i8m1_m(vbool8_t, vint8m1_t, int8_t, vint8m1_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vmacc_vx)))
vint8m2_t vmacc_vx_i8m2(vint8m2_t, int8_t, vint8m2_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vmacc_vx_m)))
vint8m2_t vmacc_vx_i8m2_m(vbool4_t, vint8m2_t, int8_t, vint8m2_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vmacc_vx)))
vint8m4_t vmacc_vx_i8m4(vint8m4_t, int8_t, vint8m4_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vmacc_vx_m)))
vint8m4_t vmacc_vx_i8m4_m(vbool2_t, vint8m4_t, int8_t, vint8m4_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vmacc_vx)))
vint8m8_t vmacc_vx_i8m8(vint8m8_t, int8_t, vint8m8_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vmacc_vx_m)))
vint8m8_t vmacc_vx_i8m8_m(vbool1_t, vint8m8_t, int8_t, vint8m8_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vmacc_vx)))
vint8mf2_t vmacc_vx_i8mf2(vint8mf2_t, int8_t, vint8mf2_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vmacc_vx_m)))
vint8mf2_t vmacc_vx_i8mf2_m(vbool16_t, vint8mf2_t, int8_t, vint8mf2_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vmacc_vx)))
vint8mf4_t vmacc_vx_i8mf4(vint8mf4_t, int8_t, vint8mf4_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vmacc_vx_m)))
vint8mf4_t vmacc_vx_i8mf4_m(vbool32_t, vint8mf4_t, int8_t, vint8mf4_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vmacc_vx)))
vint8mf8_t vmacc_vx_i8mf8(vint8mf8_t, int8_t, vint8mf8_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vmacc_vx_m)))
vint8mf8_t vmacc_vx_i8mf8_m(vbool64_t, vint8mf8_t, int8_t, vint8mf8_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vmacc_vx)))
vint16m1_t vmacc_vx_i16m1(vint16m1_t, int16_t, vint16m1_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vmacc_vx_m)))
vint16m1_t vmacc_vx_i16m1_m(vbool16_t, vint16m1_t, int16_t, vint16m1_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vmacc_vx)))
vint16m2_t vmacc_vx_i16m2(vint16m2_t, int16_t, vint16m2_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vmacc_vx_m)))
vint16m2_t vmacc_vx_i16m2_m(vbool8_t, vint16m2_t, int16_t, vint16m2_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vmacc_vx)))
vint16m4_t vmacc_vx_i16m4(vint16m4_t, int16_t, vint16m4_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vmacc_vx_m)))
vint16m4_t vmacc_vx_i16m4_m(vbool4_t, vint16m4_t, int16_t, vint16m4_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vmacc_vx)))
vint16m8_t vmacc_vx_i16m8(vint16m8_t, int16_t, vint16m8_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vmacc_vx_m)))
vint16m8_t vmacc_vx_i16m8_m(vbool2_t, vint16m8_t, int16_t, vint16m8_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vmacc_vx)))
vint16mf2_t vmacc_vx_i16mf2(vint16mf2_t, int16_t, vint16mf2_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vmacc_vx_m)))
vint16mf2_t vmacc_vx_i16mf2_m(vbool32_t, vint16mf2_t, int16_t, vint16mf2_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vmacc_vx)))
vint16mf4_t vmacc_vx_i16mf4(vint16mf4_t, int16_t, vint16mf4_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vmacc_vx_m)))
vint16mf4_t vmacc_vx_i16mf4_m(vbool64_t, vint16mf4_t, int16_t, vint16mf4_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vmacc_vx)))
vint32m1_t vmacc_vx_i32m1(vint32m1_t, int32_t, vint32m1_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vmacc_vx_m)))
vint32m1_t vmacc_vx_i32m1_m(vbool32_t, vint32m1_t, int32_t, vint32m1_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vmacc_vx)))
vint32m2_t vmacc_vx_i32m2(vint32m2_t, int32_t, vint32m2_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vmacc_vx_m)))
vint32m2_t vmacc_vx_i32m2_m(vbool16_t, vint32m2_t, int32_t, vint32m2_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vmacc_vx)))
vint32m4_t vmacc_vx_i32m4(vint32m4_t, int32_t, vint32m4_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vmacc_vx_m)))
vint32m4_t vmacc_vx_i32m4_m(vbool8_t, vint32m4_t, int32_t, vint32m4_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vmacc_vx)))
vint32m8_t vmacc_vx_i32m8(vint32m8_t, int32_t, vint32m8_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vmacc_vx_m)))
vint32m8_t vmacc_vx_i32m8_m(vbool4_t, vint32m8_t, int32_t, vint32m8_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vmacc_vx)))
vint32mf2_t vmacc_vx_i32mf2(vint32mf2_t, int32_t, vint32mf2_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vmacc_vx_m)))
vint32mf2_t vmacc_vx_i32mf2_m(vbool64_t, vint32mf2_t, int32_t, vint32mf2_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vmacc_vv)))
vuint8m1_t vmacc_vv_u8m1(vuint8m1_t, vuint8m1_t, vuint8m1_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vmacc_vv_m)))
vuint8m1_t vmacc_vv_u8m1_m(vbool8_t, vuint8m1_t, vuint8m1_t, vuint8m1_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vmacc_vv)))
vuint8m2_t vmacc_vv_u8m2(vuint8m2_t, vuint8m2_t, vuint8m2_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vmacc_vv_m)))
vuint8m2_t vmacc_vv_u8m2_m(vbool4_t, vuint8m2_t, vuint8m2_t, vuint8m2_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vmacc_vv)))
vuint8m4_t vmacc_vv_u8m4(vuint8m4_t, vuint8m4_t, vuint8m4_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vmacc_vv_m)))
vuint8m4_t vmacc_vv_u8m4_m(vbool2_t, vuint8m4_t, vuint8m4_t, vuint8m4_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vmacc_vv)))
vuint8m8_t vmacc_vv_u8m8(vuint8m8_t, vuint8m8_t, vuint8m8_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vmacc_vv_m)))
vuint8m8_t vmacc_vv_u8m8_m(vbool1_t, vuint8m8_t, vuint8m8_t, vuint8m8_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vmacc_vv)))
vuint8mf2_t vmacc_vv_u8mf2(vuint8mf2_t, vuint8mf2_t, vuint8mf2_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vmacc_vv_m)))
vuint8mf2_t vmacc_vv_u8mf2_m(vbool16_t, vuint8mf2_t, vuint8mf2_t, vuint8mf2_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vmacc_vv)))
vuint8mf4_t vmacc_vv_u8mf4(vuint8mf4_t, vuint8mf4_t, vuint8mf4_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vmacc_vv_m)))
vuint8mf4_t vmacc_vv_u8mf4_m(vbool32_t, vuint8mf4_t, vuint8mf4_t, vuint8mf4_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vmacc_vv)))
vuint8mf8_t vmacc_vv_u8mf8(vuint8mf8_t, vuint8mf8_t, vuint8mf8_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vmacc_vv_m)))
vuint8mf8_t vmacc_vv_u8mf8_m(vbool64_t, vuint8mf8_t, vuint8mf8_t, vuint8mf8_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vmacc_vv)))
vuint16m1_t vmacc_vv_u16m1(vuint16m1_t, vuint16m1_t, vuint16m1_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vmacc_vv_m)))
vuint16m1_t vmacc_vv_u16m1_m(vbool16_t, vuint16m1_t, vuint16m1_t, vuint16m1_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vmacc_vv)))
vuint16m2_t vmacc_vv_u16m2(vuint16m2_t, vuint16m2_t, vuint16m2_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vmacc_vv_m)))
vuint16m2_t vmacc_vv_u16m2_m(vbool8_t, vuint16m2_t, vuint16m2_t, vuint16m2_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vmacc_vv)))
vuint16m4_t vmacc_vv_u16m4(vuint16m4_t, vuint16m4_t, vuint16m4_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vmacc_vv_m)))
vuint16m4_t vmacc_vv_u16m4_m(vbool4_t, vuint16m4_t, vuint16m4_t, vuint16m4_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vmacc_vv)))
vuint16m8_t vmacc_vv_u16m8(vuint16m8_t, vuint16m8_t, vuint16m8_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vmacc_vv_m)))
vuint16m8_t vmacc_vv_u16m8_m(vbool2_t, vuint16m8_t, vuint16m8_t, vuint16m8_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vmacc_vv)))
vuint16mf2_t vmacc_vv_u16mf2(vuint16mf2_t, vuint16mf2_t, vuint16mf2_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vmacc_vv_m)))
vuint16mf2_t vmacc_vv_u16mf2_m(vbool32_t, vuint16mf2_t, vuint16mf2_t, vuint16mf2_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vmacc_vv)))
vuint16mf4_t vmacc_vv_u16mf4(vuint16mf4_t, vuint16mf4_t, vuint16mf4_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vmacc_vv_m)))
vuint16mf4_t vmacc_vv_u16mf4_m(vbool64_t, vuint16mf4_t, vuint16mf4_t, vuint16mf4_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vmacc_vv)))
vuint32m1_t vmacc_vv_u32m1(vuint32m1_t, vuint32m1_t, vuint32m1_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vmacc_vv_m)))
vuint32m1_t vmacc_vv_u32m1_m(vbool32_t, vuint32m1_t, vuint32m1_t, vuint32m1_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vmacc_vv)))
vuint32m2_t vmacc_vv_u32m2(vuint32m2_t, vuint32m2_t, vuint32m2_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vmacc_vv_m)))
vuint32m2_t vmacc_vv_u32m2_m(vbool16_t, vuint32m2_t, vuint32m2_t, vuint32m2_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vmacc_vv)))
vuint32m4_t vmacc_vv_u32m4(vuint32m4_t, vuint32m4_t, vuint32m4_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vmacc_vv_m)))
vuint32m4_t vmacc_vv_u32m4_m(vbool8_t, vuint32m4_t, vuint32m4_t, vuint32m4_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vmacc_vv)))
vuint32m8_t vmacc_vv_u32m8(vuint32m8_t, vuint32m8_t, vuint32m8_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vmacc_vv_m)))
vuint32m8_t vmacc_vv_u32m8_m(vbool4_t, vuint32m8_t, vuint32m8_t, vuint32m8_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vmacc_vv)))
vuint32mf2_t vmacc_vv_u32mf2(vuint32mf2_t, vuint32mf2_t, vuint32mf2_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vmacc_vv_m)))
vuint32mf2_t vmacc_vv_u32mf2_m(vbool64_t, vuint32mf2_t, vuint32mf2_t, vuint32mf2_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vmacc_vx)))
vuint8m1_t vmacc_vx_u8m1(vuint8m1_t, uint8_t, vuint8m1_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vmacc_vx_m)))
vuint8m1_t vmacc_vx_u8m1_m(vbool8_t, vuint8m1_t, uint8_t, vuint8m1_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vmacc_vx)))
vuint8m2_t vmacc_vx_u8m2(vuint8m2_t, uint8_t, vuint8m2_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vmacc_vx_m)))
vuint8m2_t vmacc_vx_u8m2_m(vbool4_t, vuint8m2_t, uint8_t, vuint8m2_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vmacc_vx)))
vuint8m4_t vmacc_vx_u8m4(vuint8m4_t, uint8_t, vuint8m4_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vmacc_vx_m)))
vuint8m4_t vmacc_vx_u8m4_m(vbool2_t, vuint8m4_t, uint8_t, vuint8m4_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vmacc_vx)))
vuint8m8_t vmacc_vx_u8m8(vuint8m8_t, uint8_t, vuint8m8_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vmacc_vx_m)))
vuint8m8_t vmacc_vx_u8m8_m(vbool1_t, vuint8m8_t, uint8_t, vuint8m8_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vmacc_vx)))
vuint8mf2_t vmacc_vx_u8mf2(vuint8mf2_t, uint8_t, vuint8mf2_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vmacc_vx_m)))
vuint8mf2_t vmacc_vx_u8mf2_m(vbool16_t, vuint8mf2_t, uint8_t, vuint8mf2_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vmacc_vx)))
vuint8mf4_t vmacc_vx_u8mf4(vuint8mf4_t, uint8_t, vuint8mf4_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vmacc_vx_m)))
vuint8mf4_t vmacc_vx_u8mf4_m(vbool32_t, vuint8mf4_t, uint8_t, vuint8mf4_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vmacc_vx)))
vuint8mf8_t vmacc_vx_u8mf8(vuint8mf8_t, uint8_t, vuint8mf8_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vmacc_vx_m)))
vuint8mf8_t vmacc_vx_u8mf8_m(vbool64_t, vuint8mf8_t, uint8_t, vuint8mf8_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vmacc_vx)))
vuint16m1_t vmacc_vx_u16m1(vuint16m1_t, uint16_t, vuint16m1_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vmacc_vx_m)))
vuint16m1_t vmacc_vx_u16m1_m(vbool16_t, vuint16m1_t, uint16_t, vuint16m1_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vmacc_vx)))
vuint16m2_t vmacc_vx_u16m2(vuint16m2_t, uint16_t, vuint16m2_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vmacc_vx_m)))
vuint16m2_t vmacc_vx_u16m2_m(vbool8_t, vuint16m2_t, uint16_t, vuint16m2_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vmacc_vx)))
vuint16m4_t vmacc_vx_u16m4(vuint16m4_t, uint16_t, vuint16m4_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vmacc_vx_m)))
vuint16m4_t vmacc_vx_u16m4_m(vbool4_t, vuint16m4_t, uint16_t, vuint16m4_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vmacc_vx)))
vuint16m8_t vmacc_vx_u16m8(vuint16m8_t, uint16_t, vuint16m8_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vmacc_vx_m)))
vuint16m8_t vmacc_vx_u16m8_m(vbool2_t, vuint16m8_t, uint16_t, vuint16m8_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vmacc_vx)))
vuint16mf2_t vmacc_vx_u16mf2(vuint16mf2_t, uint16_t, vuint16mf2_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vmacc_vx_m)))
vuint16mf2_t vmacc_vx_u16mf2_m(vbool32_t, vuint16mf2_t, uint16_t, vuint16mf2_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vmacc_vx)))
vuint16mf4_t vmacc_vx_u16mf4(vuint16mf4_t, uint16_t, vuint16mf4_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vmacc_vx_m)))
vuint16mf4_t vmacc_vx_u16mf4_m(vbool64_t, vuint16mf4_t, uint16_t, vuint16mf4_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vmacc_vx)))
vuint32m1_t vmacc_vx_u32m1(vuint32m1_t, uint32_t, vuint32m1_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vmacc_vx_m)))
vuint32m1_t vmacc_vx_u32m1_m(vbool32_t, vuint32m1_t, uint32_t, vuint32m1_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vmacc_vx)))
vuint32m2_t vmacc_vx_u32m2(vuint32m2_t, uint32_t, vuint32m2_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vmacc_vx_m)))
vuint32m2_t vmacc_vx_u32m2_m(vbool16_t, vuint32m2_t, uint32_t, vuint32m2_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vmacc_vx)))
vuint32m4_t vmacc_vx_u32m4(vuint32m4_t, uint32_t, vuint32m4_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vmacc_vx_m)))
vuint32m4_t vmacc_vx_u32m4_m(vbool8_t, vuint32m4_t, uint32_t, vuint32m4_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vmacc_vx)))
vuint32m8_t vmacc_vx_u32m8(vuint32m8_t, uint32_t, vuint32m8_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vmacc_vx_m)))
vuint32m8_t vmacc_vx_u32m8_m(vbool4_t, vuint32m8_t, uint32_t, vuint32m8_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vmacc_vx)))
vuint32mf2_t vmacc_vx_u32mf2(vuint32mf2_t, uint32_t, vuint32mf2_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vmacc_vx_m)))
vuint32mf2_t vmacc_vx_u32mf2_m(vbool64_t, vuint32mf2_t, uint32_t, vuint32mf2_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vnmsac_vv)))
vint8m1_t vnmsac_vv_i8m1(vint8m1_t, vint8m1_t, vint8m1_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vnmsac_vv_m)))
vint8m1_t vnmsac_vv_i8m1_m(vbool8_t, vint8m1_t, vint8m1_t, vint8m1_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vnmsac_vv)))
vint8m2_t vnmsac_vv_i8m2(vint8m2_t, vint8m2_t, vint8m2_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vnmsac_vv_m)))
vint8m2_t vnmsac_vv_i8m2_m(vbool4_t, vint8m2_t, vint8m2_t, vint8m2_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vnmsac_vv)))
vint8m4_t vnmsac_vv_i8m4(vint8m4_t, vint8m4_t, vint8m4_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vnmsac_vv_m)))
vint8m4_t vnmsac_vv_i8m4_m(vbool2_t, vint8m4_t, vint8m4_t, vint8m4_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vnmsac_vv)))
vint8m8_t vnmsac_vv_i8m8(vint8m8_t, vint8m8_t, vint8m8_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vnmsac_vv_m)))
vint8m8_t vnmsac_vv_i8m8_m(vbool1_t, vint8m8_t, vint8m8_t, vint8m8_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vnmsac_vv)))
vint8mf2_t vnmsac_vv_i8mf2(vint8mf2_t, vint8mf2_t, vint8mf2_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vnmsac_vv_m)))
vint8mf2_t vnmsac_vv_i8mf2_m(vbool16_t, vint8mf2_t, vint8mf2_t, vint8mf2_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vnmsac_vv)))
vint8mf4_t vnmsac_vv_i8mf4(vint8mf4_t, vint8mf4_t, vint8mf4_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vnmsac_vv_m)))
vint8mf4_t vnmsac_vv_i8mf4_m(vbool32_t, vint8mf4_t, vint8mf4_t, vint8mf4_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vnmsac_vv)))
vint8mf8_t vnmsac_vv_i8mf8(vint8mf8_t, vint8mf8_t, vint8mf8_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vnmsac_vv_m)))
vint8mf8_t vnmsac_vv_i8mf8_m(vbool64_t, vint8mf8_t, vint8mf8_t, vint8mf8_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vnmsac_vv)))
vint16m1_t vnmsac_vv_i16m1(vint16m1_t, vint16m1_t, vint16m1_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vnmsac_vv_m)))
vint16m1_t vnmsac_vv_i16m1_m(vbool16_t, vint16m1_t, vint16m1_t, vint16m1_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vnmsac_vv)))
vint16m2_t vnmsac_vv_i16m2(vint16m2_t, vint16m2_t, vint16m2_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vnmsac_vv_m)))
vint16m2_t vnmsac_vv_i16m2_m(vbool8_t, vint16m2_t, vint16m2_t, vint16m2_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vnmsac_vv)))
vint16m4_t vnmsac_vv_i16m4(vint16m4_t, vint16m4_t, vint16m4_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vnmsac_vv_m)))
vint16m4_t vnmsac_vv_i16m4_m(vbool4_t, vint16m4_t, vint16m4_t, vint16m4_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vnmsac_vv)))
vint16m8_t vnmsac_vv_i16m8(vint16m8_t, vint16m8_t, vint16m8_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vnmsac_vv_m)))
vint16m8_t vnmsac_vv_i16m8_m(vbool2_t, vint16m8_t, vint16m8_t, vint16m8_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vnmsac_vv)))
vint16mf2_t vnmsac_vv_i16mf2(vint16mf2_t, vint16mf2_t, vint16mf2_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vnmsac_vv_m)))
vint16mf2_t vnmsac_vv_i16mf2_m(vbool32_t, vint16mf2_t, vint16mf2_t, vint16mf2_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vnmsac_vv)))
vint16mf4_t vnmsac_vv_i16mf4(vint16mf4_t, vint16mf4_t, vint16mf4_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vnmsac_vv_m)))
vint16mf4_t vnmsac_vv_i16mf4_m(vbool64_t, vint16mf4_t, vint16mf4_t, vint16mf4_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vnmsac_vv)))
vint32m1_t vnmsac_vv_i32m1(vint32m1_t, vint32m1_t, vint32m1_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vnmsac_vv_m)))
vint32m1_t vnmsac_vv_i32m1_m(vbool32_t, vint32m1_t, vint32m1_t, vint32m1_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vnmsac_vv)))
vint32m2_t vnmsac_vv_i32m2(vint32m2_t, vint32m2_t, vint32m2_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vnmsac_vv_m)))
vint32m2_t vnmsac_vv_i32m2_m(vbool16_t, vint32m2_t, vint32m2_t, vint32m2_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vnmsac_vv)))
vint32m4_t vnmsac_vv_i32m4(vint32m4_t, vint32m4_t, vint32m4_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vnmsac_vv_m)))
vint32m4_t vnmsac_vv_i32m4_m(vbool8_t, vint32m4_t, vint32m4_t, vint32m4_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vnmsac_vv)))
vint32m8_t vnmsac_vv_i32m8(vint32m8_t, vint32m8_t, vint32m8_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vnmsac_vv_m)))
vint32m8_t vnmsac_vv_i32m8_m(vbool4_t, vint32m8_t, vint32m8_t, vint32m8_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vnmsac_vv)))
vint32mf2_t vnmsac_vv_i32mf2(vint32mf2_t, vint32mf2_t, vint32mf2_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vnmsac_vv_m)))
vint32mf2_t vnmsac_vv_i32mf2_m(vbool64_t, vint32mf2_t, vint32mf2_t, vint32mf2_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vsuxei8_v)))
void vsuxei8_v_i16m1(int16_t *, vuint8mf2_t, vint16m1_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vsuxei8_v_m)))
void vsuxei8_v_i16m1_m(vbool16_t, int16_t *, vuint8mf2_t, vint16m1_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vsuxei8_v)))
void vsuxei8_v_i16m2(int16_t *, vuint8m1_t, vint16m2_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vsuxei8_v_m)))
void vsuxei8_v_i16m2_m(vbool8_t, int16_t *, vuint8m1_t, vint16m2_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vsuxei8_v)))
void vsuxei8_v_i16m4(int16_t *, vuint8m2_t, vint16m4_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vsuxei8_v_m)))
void vsuxei8_v_i16m4_m(vbool4_t, int16_t *, vuint8m2_t, vint16m4_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vsuxei8_v)))
void vsuxei8_v_i16m8(int16_t *, vuint8m4_t, vint16m8_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vsuxei8_v_m)))
void vsuxei8_v_i16m8_m(vbool2_t, int16_t *, vuint8m4_t, vint16m8_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vsuxei8_v)))
void vsuxei8_v_i16mf2(int16_t *, vuint8mf4_t, vint16mf2_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vsuxei8_v_m)))
void vsuxei8_v_i16mf2_m(vbool32_t, int16_t *, vuint8mf4_t, vint16mf2_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vsuxei8_v)))
void vsuxei8_v_i16mf4(int16_t *, vuint8mf8_t, vint16mf4_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vsuxei8_v_m)))
void vsuxei8_v_i16mf4_m(vbool64_t, int16_t *, vuint8mf8_t, vint16mf4_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vnmsac_vx)))
vint8m1_t vnmsac_vx_i8m1(vint8m1_t, int8_t, vint8m1_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vnmsac_vx_m)))
vint8m1_t vnmsac_vx_i8m1_m(vbool8_t, vint8m1_t, int8_t, vint8m1_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vnmsac_vx)))
vint8m2_t vnmsac_vx_i8m2(vint8m2_t, int8_t, vint8m2_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vnmsac_vx_m)))
vint8m2_t vnmsac_vx_i8m2_m(vbool4_t, vint8m2_t, int8_t, vint8m2_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vnmsac_vx)))
vint8m4_t vnmsac_vx_i8m4(vint8m4_t, int8_t, vint8m4_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vnmsac_vx_m)))
vint8m4_t vnmsac_vx_i8m4_m(vbool2_t, vint8m4_t, int8_t, vint8m4_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vnmsac_vx)))
vint8m8_t vnmsac_vx_i8m8(vint8m8_t, int8_t, vint8m8_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vnmsac_vx_m)))
vint8m8_t vnmsac_vx_i8m8_m(vbool1_t, vint8m8_t, int8_t, vint8m8_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vnmsac_vx)))
vint8mf2_t vnmsac_vx_i8mf2(vint8mf2_t, int8_t, vint8mf2_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vnmsac_vx_m)))
vint8mf2_t vnmsac_vx_i8mf2_m(vbool16_t, vint8mf2_t, int8_t, vint8mf2_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vnmsac_vx)))
vint8mf4_t vnmsac_vx_i8mf4(vint8mf4_t, int8_t, vint8mf4_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vnmsac_vx_m)))
vint8mf4_t vnmsac_vx_i8mf4_m(vbool32_t, vint8mf4_t, int8_t, vint8mf4_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vnmsac_vx)))
vint8mf8_t vnmsac_vx_i8mf8(vint8mf8_t, int8_t, vint8mf8_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vnmsac_vx_m)))
vint8mf8_t vnmsac_vx_i8mf8_m(vbool64_t, vint8mf8_t, int8_t, vint8mf8_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vnmsac_vx)))
vint16m1_t vnmsac_vx_i16m1(vint16m1_t, int16_t, vint16m1_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vnmsac_vx_m)))
vint16m1_t vnmsac_vx_i16m1_m(vbool16_t, vint16m1_t, int16_t, vint16m1_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vnmsac_vx)))
vint16m2_t vnmsac_vx_i16m2(vint16m2_t, int16_t, vint16m2_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vnmsac_vx_m)))
vint16m2_t vnmsac_vx_i16m2_m(vbool8_t, vint16m2_t, int16_t, vint16m2_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vnmsac_vx)))
vint16m4_t vnmsac_vx_i16m4(vint16m4_t, int16_t, vint16m4_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vnmsac_vx_m)))
vint16m4_t vnmsac_vx_i16m4_m(vbool4_t, vint16m4_t, int16_t, vint16m4_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vnmsac_vx)))
vint16m8_t vnmsac_vx_i16m8(vint16m8_t, int16_t, vint16m8_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vnmsac_vx_m)))
vint16m8_t vnmsac_vx_i16m8_m(vbool2_t, vint16m8_t, int16_t, vint16m8_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vnmsac_vx)))
vint16mf2_t vnmsac_vx_i16mf2(vint16mf2_t, int16_t, vint16mf2_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vnmsac_vx_m)))
vint16mf2_t vnmsac_vx_i16mf2_m(vbool32_t, vint16mf2_t, int16_t, vint16mf2_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vnmsac_vx)))
vint16mf4_t vnmsac_vx_i16mf4(vint16mf4_t, int16_t, vint16mf4_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vnmsac_vx_m)))
vint16mf4_t vnmsac_vx_i16mf4_m(vbool64_t, vint16mf4_t, int16_t, vint16mf4_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vnmsac_vx)))
vint32m1_t vnmsac_vx_i32m1(vint32m1_t, int32_t, vint32m1_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vnmsac_vx_m)))
vint32m1_t vnmsac_vx_i32m1_m(vbool32_t, vint32m1_t, int32_t, vint32m1_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vnmsac_vx)))
vint32m2_t vnmsac_vx_i32m2(vint32m2_t, int32_t, vint32m2_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vnmsac_vx_m)))
vint32m2_t vnmsac_vx_i32m2_m(vbool16_t, vint32m2_t, int32_t, vint32m2_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vnmsac_vx)))
vint32m4_t vnmsac_vx_i32m4(vint32m4_t, int32_t, vint32m4_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vnmsac_vx_m)))
vint32m4_t vnmsac_vx_i32m4_m(vbool8_t, vint32m4_t, int32_t, vint32m4_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vnmsac_vx)))
vint32m8_t vnmsac_vx_i32m8(vint32m8_t, int32_t, vint32m8_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vnmsac_vx_m)))
vint32m8_t vnmsac_vx_i32m8_m(vbool4_t, vint32m8_t, int32_t, vint32m8_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vnmsac_vx)))
vint32mf2_t vnmsac_vx_i32mf2(vint32mf2_t, int32_t, vint32mf2_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vnmsac_vx_m)))
vint32mf2_t vnmsac_vx_i32mf2_m(vbool64_t, vint32mf2_t, int32_t, vint32mf2_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vnmsac_vv)))
vuint8m1_t vnmsac_vv_u8m1(vuint8m1_t, vuint8m1_t, vuint8m1_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vnmsac_vv_m)))
vuint8m1_t vnmsac_vv_u8m1_m(vbool8_t, vuint8m1_t, vuint8m1_t, vuint8m1_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vnmsac_vv)))
vuint8m2_t vnmsac_vv_u8m2(vuint8m2_t, vuint8m2_t, vuint8m2_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vnmsac_vv_m)))
vuint8m2_t vnmsac_vv_u8m2_m(vbool4_t, vuint8m2_t, vuint8m2_t, vuint8m2_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vnmsac_vv)))
vuint8m4_t vnmsac_vv_u8m4(vuint8m4_t, vuint8m4_t, vuint8m4_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vnmsac_vv_m)))
vuint8m4_t vnmsac_vv_u8m4_m(vbool2_t, vuint8m4_t, vuint8m4_t, vuint8m4_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vnmsac_vv)))
vuint8m8_t vnmsac_vv_u8m8(vuint8m8_t, vuint8m8_t, vuint8m8_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vnmsac_vv_m)))
vuint8m8_t vnmsac_vv_u8m8_m(vbool1_t, vuint8m8_t, vuint8m8_t, vuint8m8_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vnmsac_vv)))
vuint8mf2_t vnmsac_vv_u8mf2(vuint8mf2_t, vuint8mf2_t, vuint8mf2_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vnmsac_vv_m)))
vuint8mf2_t vnmsac_vv_u8mf2_m(vbool16_t, vuint8mf2_t, vuint8mf2_t, vuint8mf2_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vnmsac_vv)))
vuint8mf4_t vnmsac_vv_u8mf4(vuint8mf4_t, vuint8mf4_t, vuint8mf4_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vnmsac_vv_m)))
vuint8mf4_t vnmsac_vv_u8mf4_m(vbool32_t, vuint8mf4_t, vuint8mf4_t, vuint8mf4_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vnmsac_vv)))
vuint8mf8_t vnmsac_vv_u8mf8(vuint8mf8_t, vuint8mf8_t, vuint8mf8_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vnmsac_vv_m)))
vuint8mf8_t vnmsac_vv_u8mf8_m(vbool64_t, vuint8mf8_t, vuint8mf8_t, vuint8mf8_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vnmsac_vv)))
vuint16m1_t vnmsac_vv_u16m1(vuint16m1_t, vuint16m1_t, vuint16m1_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vnmsac_vv_m)))
vuint16m1_t vnmsac_vv_u16m1_m(vbool16_t, vuint16m1_t, vuint16m1_t, vuint16m1_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vnmsac_vv)))
vuint16m2_t vnmsac_vv_u16m2(vuint16m2_t, vuint16m2_t, vuint16m2_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vnmsac_vv_m)))
vuint16m2_t vnmsac_vv_u16m2_m(vbool8_t, vuint16m2_t, vuint16m2_t, vuint16m2_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vnmsac_vv)))
vuint16m4_t vnmsac_vv_u16m4(vuint16m4_t, vuint16m4_t, vuint16m4_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vnmsac_vv_m)))
vuint16m4_t vnmsac_vv_u16m4_m(vbool4_t, vuint16m4_t, vuint16m4_t, vuint16m4_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vnmsac_vv)))
vuint16m8_t vnmsac_vv_u16m8(vuint16m8_t, vuint16m8_t, vuint16m8_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vnmsac_vv_m)))
vuint16m8_t vnmsac_vv_u16m8_m(vbool2_t, vuint16m8_t, vuint16m8_t, vuint16m8_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vnmsac_vv)))
vuint16mf2_t vnmsac_vv_u16mf2(vuint16mf2_t, vuint16mf2_t, vuint16mf2_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vnmsac_vv_m)))
vuint16mf2_t vnmsac_vv_u16mf2_m(vbool32_t, vuint16mf2_t, vuint16mf2_t, vuint16mf2_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vnmsac_vv)))
vuint16mf4_t vnmsac_vv_u16mf4(vuint16mf4_t, vuint16mf4_t, vuint16mf4_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vnmsac_vv_m)))
vuint16mf4_t vnmsac_vv_u16mf4_m(vbool64_t, vuint16mf4_t, vuint16mf4_t, vuint16mf4_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vnmsac_vv)))
vuint32m1_t vnmsac_vv_u32m1(vuint32m1_t, vuint32m1_t, vuint32m1_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vnmsac_vv_m)))
vuint32m1_t vnmsac_vv_u32m1_m(vbool32_t, vuint32m1_t, vuint32m1_t, vuint32m1_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vnmsac_vv)))
vuint32m2_t vnmsac_vv_u32m2(vuint32m2_t, vuint32m2_t, vuint32m2_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vnmsac_vv_m)))
vuint32m2_t vnmsac_vv_u32m2_m(vbool16_t, vuint32m2_t, vuint32m2_t, vuint32m2_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vnmsac_vv)))
vuint32m4_t vnmsac_vv_u32m4(vuint32m4_t, vuint32m4_t, vuint32m4_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vnmsac_vv_m)))
vuint32m4_t vnmsac_vv_u32m4_m(vbool8_t, vuint32m4_t, vuint32m4_t, vuint32m4_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vnmsac_vv)))
vuint32m8_t vnmsac_vv_u32m8(vuint32m8_t, vuint32m8_t, vuint32m8_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vnmsac_vv_m)))
vuint32m8_t vnmsac_vv_u32m8_m(vbool4_t, vuint32m8_t, vuint32m8_t, vuint32m8_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vnmsac_vv)))
vuint32mf2_t vnmsac_vv_u32mf2(vuint32mf2_t, vuint32mf2_t, vuint32mf2_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vnmsac_vv_m)))
vuint32mf2_t vnmsac_vv_u32mf2_m(vbool64_t, vuint32mf2_t, vuint32mf2_t, vuint32mf2_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vnmsac_vx)))
vuint8m1_t vnmsac_vx_u8m1(vuint8m1_t, uint8_t, vuint8m1_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vnmsac_vx_m)))
vuint8m1_t vnmsac_vx_u8m1_m(vbool8_t, vuint8m1_t, uint8_t, vuint8m1_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vnmsac_vx)))
vuint8m2_t vnmsac_vx_u8m2(vuint8m2_t, uint8_t, vuint8m2_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vnmsac_vx_m)))
vuint8m2_t vnmsac_vx_u8m2_m(vbool4_t, vuint8m2_t, uint8_t, vuint8m2_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vnmsac_vx)))
vuint8m4_t vnmsac_vx_u8m4(vuint8m4_t, uint8_t, vuint8m4_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vnmsac_vx_m)))
vuint8m4_t vnmsac_vx_u8m4_m(vbool2_t, vuint8m4_t, uint8_t, vuint8m4_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vnmsac_vx)))
vuint8m8_t vnmsac_vx_u8m8(vuint8m8_t, uint8_t, vuint8m8_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vnmsac_vx_m)))
vuint8m8_t vnmsac_vx_u8m8_m(vbool1_t, vuint8m8_t, uint8_t, vuint8m8_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vnmsac_vx)))
vuint8mf2_t vnmsac_vx_u8mf2(vuint8mf2_t, uint8_t, vuint8mf2_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vnmsac_vx_m)))
vuint8mf2_t vnmsac_vx_u8mf2_m(vbool16_t, vuint8mf2_t, uint8_t, vuint8mf2_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vnmsac_vx)))
vuint8mf4_t vnmsac_vx_u8mf4(vuint8mf4_t, uint8_t, vuint8mf4_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vnmsac_vx_m)))
vuint8mf4_t vnmsac_vx_u8mf4_m(vbool32_t, vuint8mf4_t, uint8_t, vuint8mf4_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vnmsac_vx)))
vuint8mf8_t vnmsac_vx_u8mf8(vuint8mf8_t, uint8_t, vuint8mf8_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vnmsac_vx_m)))
vuint8mf8_t vnmsac_vx_u8mf8_m(vbool64_t, vuint8mf8_t, uint8_t, vuint8mf8_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vnmsac_vx)))
vuint16m1_t vnmsac_vx_u16m1(vuint16m1_t, uint16_t, vuint16m1_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vnmsac_vx_m)))
vuint16m1_t vnmsac_vx_u16m1_m(vbool16_t, vuint16m1_t, uint16_t, vuint16m1_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vnmsac_vx)))
vuint16m2_t vnmsac_vx_u16m2(vuint16m2_t, uint16_t, vuint16m2_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vnmsac_vx_m)))
vuint16m2_t vnmsac_vx_u16m2_m(vbool8_t, vuint16m2_t, uint16_t, vuint16m2_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vnmsac_vx)))
vuint16m4_t vnmsac_vx_u16m4(vuint16m4_t, uint16_t, vuint16m4_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vnmsac_vx_m)))
vuint16m4_t vnmsac_vx_u16m4_m(vbool4_t, vuint16m4_t, uint16_t, vuint16m4_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vnmsac_vx)))
vuint16m8_t vnmsac_vx_u16m8(vuint16m8_t, uint16_t, vuint16m8_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vnmsac_vx_m)))
vuint16m8_t vnmsac_vx_u16m8_m(vbool2_t, vuint16m8_t, uint16_t, vuint16m8_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vnmsac_vx)))
vuint16mf2_t vnmsac_vx_u16mf2(vuint16mf2_t, uint16_t, vuint16mf2_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vnmsac_vx_m)))
vuint16mf2_t vnmsac_vx_u16mf2_m(vbool32_t, vuint16mf2_t, uint16_t, vuint16mf2_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vnmsac_vx)))
vuint16mf4_t vnmsac_vx_u16mf4(vuint16mf4_t, uint16_t, vuint16mf4_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vnmsac_vx_m)))
vuint16mf4_t vnmsac_vx_u16mf4_m(vbool64_t, vuint16mf4_t, uint16_t, vuint16mf4_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vnmsac_vx)))
vuint32m1_t vnmsac_vx_u32m1(vuint32m1_t, uint32_t, vuint32m1_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vnmsac_vx_m)))
vuint32m1_t vnmsac_vx_u32m1_m(vbool32_t, vuint32m1_t, uint32_t, vuint32m1_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vnmsac_vx)))
vuint32m2_t vnmsac_vx_u32m2(vuint32m2_t, uint32_t, vuint32m2_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vnmsac_vx_m)))
vuint32m2_t vnmsac_vx_u32m2_m(vbool16_t, vuint32m2_t, uint32_t, vuint32m2_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vnmsac_vx)))
vuint32m4_t vnmsac_vx_u32m4(vuint32m4_t, uint32_t, vuint32m4_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vnmsac_vx_m)))
vuint32m4_t vnmsac_vx_u32m4_m(vbool8_t, vuint32m4_t, uint32_t, vuint32m4_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vnmsac_vx)))
vuint32m8_t vnmsac_vx_u32m8(vuint32m8_t, uint32_t, vuint32m8_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vnmsac_vx_m)))
vuint32m8_t vnmsac_vx_u32m8_m(vbool4_t, vuint32m8_t, uint32_t, vuint32m8_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vnmsac_vx)))
vuint32mf2_t vnmsac_vx_u32mf2(vuint32mf2_t, uint32_t, vuint32mf2_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vnmsac_vx_m)))
vuint32mf2_t vnmsac_vx_u32mf2_m(vbool64_t, vuint32mf2_t, uint32_t, vuint32mf2_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vmadd_vv)))
vint8m1_t vmadd_vv_i8m1(vint8m1_t, vint8m1_t, vint8m1_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vmadd_vv_m)))
vint8m1_t vmadd_vv_i8m1_m(vbool8_t, vint8m1_t, vint8m1_t, vint8m1_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vmadd_vv)))
vint8m2_t vmadd_vv_i8m2(vint8m2_t, vint8m2_t, vint8m2_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vmadd_vv_m)))
vint8m2_t vmadd_vv_i8m2_m(vbool4_t, vint8m2_t, vint8m2_t, vint8m2_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vmadd_vv)))
vint8m4_t vmadd_vv_i8m4(vint8m4_t, vint8m4_t, vint8m4_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vmadd_vv_m)))
vint8m4_t vmadd_vv_i8m4_m(vbool2_t, vint8m4_t, vint8m4_t, vint8m4_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vmadd_vv)))
vint8m8_t vmadd_vv_i8m8(vint8m8_t, vint8m8_t, vint8m8_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vmadd_vv_m)))
vint8m8_t vmadd_vv_i8m8_m(vbool1_t, vint8m8_t, vint8m8_t, vint8m8_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vmadd_vv)))
vint8mf2_t vmadd_vv_i8mf2(vint8mf2_t, vint8mf2_t, vint8mf2_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vmadd_vv_m)))
vint8mf2_t vmadd_vv_i8mf2_m(vbool16_t, vint8mf2_t, vint8mf2_t, vint8mf2_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vmadd_vv)))
vint8mf4_t vmadd_vv_i8mf4(vint8mf4_t, vint8mf4_t, vint8mf4_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vmadd_vv_m)))
vint8mf4_t vmadd_vv_i8mf4_m(vbool32_t, vint8mf4_t, vint8mf4_t, vint8mf4_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vmadd_vv)))
vint8mf8_t vmadd_vv_i8mf8(vint8mf8_t, vint8mf8_t, vint8mf8_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vmadd_vv_m)))
vint8mf8_t vmadd_vv_i8mf8_m(vbool64_t, vint8mf8_t, vint8mf8_t, vint8mf8_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vmadd_vv)))
vint16m1_t vmadd_vv_i16m1(vint16m1_t, vint16m1_t, vint16m1_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vmadd_vv_m)))
vint16m1_t vmadd_vv_i16m1_m(vbool16_t, vint16m1_t, vint16m1_t, vint16m1_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vmadd_vv)))
vint16m2_t vmadd_vv_i16m2(vint16m2_t, vint16m2_t, vint16m2_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vmadd_vv_m)))
vint16m2_t vmadd_vv_i16m2_m(vbool8_t, vint16m2_t, vint16m2_t, vint16m2_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vmadd_vv)))
vint16m4_t vmadd_vv_i16m4(vint16m4_t, vint16m4_t, vint16m4_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vmadd_vv_m)))
vint16m4_t vmadd_vv_i16m4_m(vbool4_t, vint16m4_t, vint16m4_t, vint16m4_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vmadd_vv)))
vint16m8_t vmadd_vv_i16m8(vint16m8_t, vint16m8_t, vint16m8_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vmadd_vv_m)))
vint16m8_t vmadd_vv_i16m8_m(vbool2_t, vint16m8_t, vint16m8_t, vint16m8_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vmadd_vv)))
vint16mf2_t vmadd_vv_i16mf2(vint16mf2_t, vint16mf2_t, vint16mf2_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vmadd_vv_m)))
vint16mf2_t vmadd_vv_i16mf2_m(vbool32_t, vint16mf2_t, vint16mf2_t, vint16mf2_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vmadd_vv)))
vint16mf4_t vmadd_vv_i16mf4(vint16mf4_t, vint16mf4_t, vint16mf4_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vmadd_vv_m)))
vint16mf4_t vmadd_vv_i16mf4_m(vbool64_t, vint16mf4_t, vint16mf4_t, vint16mf4_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vmadd_vv)))
vint32m1_t vmadd_vv_i32m1(vint32m1_t, vint32m1_t, vint32m1_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vmadd_vv_m)))
vint32m1_t vmadd_vv_i32m1_m(vbool32_t, vint32m1_t, vint32m1_t, vint32m1_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vmadd_vv)))
vint32m2_t vmadd_vv_i32m2(vint32m2_t, vint32m2_t, vint32m2_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vmadd_vv_m)))
vint32m2_t vmadd_vv_i32m2_m(vbool16_t, vint32m2_t, vint32m2_t, vint32m2_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vmadd_vv)))
vint32m4_t vmadd_vv_i32m4(vint32m4_t, vint32m4_t, vint32m4_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vmadd_vv_m)))
vint32m4_t vmadd_vv_i32m4_m(vbool8_t, vint32m4_t, vint32m4_t, vint32m4_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vmadd_vv)))
vint32m8_t vmadd_vv_i32m8(vint32m8_t, vint32m8_t, vint32m8_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vmadd_vv_m)))
vint32m8_t vmadd_vv_i32m8_m(vbool4_t, vint32m8_t, vint32m8_t, vint32m8_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vmadd_vv)))
vint32mf2_t vmadd_vv_i32mf2(vint32mf2_t, vint32mf2_t, vint32mf2_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vmadd_vv_m)))
vint32mf2_t vmadd_vv_i32mf2_m(vbool64_t, vint32mf2_t, vint32mf2_t, vint32mf2_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vmadd_vx)))
vint8m1_t vmadd_vx_i8m1(vint8m1_t, int8_t, vint8m1_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vmadd_vx_m)))
vint8m1_t vmadd_vx_i8m1_m(vbool8_t, vint8m1_t, int8_t, vint8m1_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vmadd_vx)))
vint8m2_t vmadd_vx_i8m2(vint8m2_t, int8_t, vint8m2_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vmadd_vx_m)))
vint8m2_t vmadd_vx_i8m2_m(vbool4_t, vint8m2_t, int8_t, vint8m2_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vmadd_vx)))
vint8m4_t vmadd_vx_i8m4(vint8m4_t, int8_t, vint8m4_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vmadd_vx_m)))
vint8m4_t vmadd_vx_i8m4_m(vbool2_t, vint8m4_t, int8_t, vint8m4_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vmadd_vx)))
vint8m8_t vmadd_vx_i8m8(vint8m8_t, int8_t, vint8m8_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vmadd_vx_m)))
vint8m8_t vmadd_vx_i8m8_m(vbool1_t, vint8m8_t, int8_t, vint8m8_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vmadd_vx)))
vint8mf2_t vmadd_vx_i8mf2(vint8mf2_t, int8_t, vint8mf2_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vmadd_vx_m)))
vint8mf2_t vmadd_vx_i8mf2_m(vbool16_t, vint8mf2_t, int8_t, vint8mf2_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vmadd_vx)))
vint8mf4_t vmadd_vx_i8mf4(vint8mf4_t, int8_t, vint8mf4_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vmadd_vx_m)))
vint8mf4_t vmadd_vx_i8mf4_m(vbool32_t, vint8mf4_t, int8_t, vint8mf4_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vmadd_vx)))
vint8mf8_t vmadd_vx_i8mf8(vint8mf8_t, int8_t, vint8mf8_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vmadd_vx_m)))
vint8mf8_t vmadd_vx_i8mf8_m(vbool64_t, vint8mf8_t, int8_t, vint8mf8_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vmadd_vx)))
vint16m1_t vmadd_vx_i16m1(vint16m1_t, int16_t, vint16m1_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vmadd_vx_m)))
vint16m1_t vmadd_vx_i16m1_m(vbool16_t, vint16m1_t, int16_t, vint16m1_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vmadd_vx)))
vint16m2_t vmadd_vx_i16m2(vint16m2_t, int16_t, vint16m2_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vmadd_vx_m)))
vint16m2_t vmadd_vx_i16m2_m(vbool8_t, vint16m2_t, int16_t, vint16m2_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vmadd_vx)))
vint16m4_t vmadd_vx_i16m4(vint16m4_t, int16_t, vint16m4_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vmadd_vx_m)))
vint16m4_t vmadd_vx_i16m4_m(vbool4_t, vint16m4_t, int16_t, vint16m4_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vmadd_vx)))
vint16m8_t vmadd_vx_i16m8(vint16m8_t, int16_t, vint16m8_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vmadd_vx_m)))
vint16m8_t vmadd_vx_i16m8_m(vbool2_t, vint16m8_t, int16_t, vint16m8_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vmadd_vx)))
vint16mf2_t vmadd_vx_i16mf2(vint16mf2_t, int16_t, vint16mf2_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vmadd_vx_m)))
vint16mf2_t vmadd_vx_i16mf2_m(vbool32_t, vint16mf2_t, int16_t, vint16mf2_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vmadd_vx)))
vint16mf4_t vmadd_vx_i16mf4(vint16mf4_t, int16_t, vint16mf4_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vmadd_vx_m)))
vint16mf4_t vmadd_vx_i16mf4_m(vbool64_t, vint16mf4_t, int16_t, vint16mf4_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vmadd_vx)))
vint32m1_t vmadd_vx_i32m1(vint32m1_t, int32_t, vint32m1_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vmadd_vx_m)))
vint32m1_t vmadd_vx_i32m1_m(vbool32_t, vint32m1_t, int32_t, vint32m1_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vmadd_vx)))
vint32m2_t vmadd_vx_i32m2(vint32m2_t, int32_t, vint32m2_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vmadd_vx_m)))
vint32m2_t vmadd_vx_i32m2_m(vbool16_t, vint32m2_t, int32_t, vint32m2_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vmadd_vx)))
vint32m4_t vmadd_vx_i32m4(vint32m4_t, int32_t, vint32m4_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vmadd_vx_m)))
vint32m4_t vmadd_vx_i32m4_m(vbool8_t, vint32m4_t, int32_t, vint32m4_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vmadd_vx)))
vint32m8_t vmadd_vx_i32m8(vint32m8_t, int32_t, vint32m8_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vmadd_vx_m)))
vint32m8_t vmadd_vx_i32m8_m(vbool4_t, vint32m8_t, int32_t, vint32m8_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vmadd_vx)))
vint32mf2_t vmadd_vx_i32mf2(vint32mf2_t, int32_t, vint32mf2_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vmadd_vx_m)))
vint32mf2_t vmadd_vx_i32mf2_m(vbool64_t, vint32mf2_t, int32_t, vint32mf2_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vmadd_vv)))
vuint8m1_t vmadd_vv_u8m1(vuint8m1_t, vuint8m1_t, vuint8m1_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vmadd_vv_m)))
vuint8m1_t vmadd_vv_u8m1_m(vbool8_t, vuint8m1_t, vuint8m1_t, vuint8m1_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vmadd_vv)))
vuint8m2_t vmadd_vv_u8m2(vuint8m2_t, vuint8m2_t, vuint8m2_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vmadd_vv_m)))
vuint8m2_t vmadd_vv_u8m2_m(vbool4_t, vuint8m2_t, vuint8m2_t, vuint8m2_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vmadd_vv)))
vuint8m4_t vmadd_vv_u8m4(vuint8m4_t, vuint8m4_t, vuint8m4_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vmadd_vv_m)))
vuint8m4_t vmadd_vv_u8m4_m(vbool2_t, vuint8m4_t, vuint8m4_t, vuint8m4_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vmadd_vv)))
vuint8m8_t vmadd_vv_u8m8(vuint8m8_t, vuint8m8_t, vuint8m8_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vmadd_vv_m)))
vuint8m8_t vmadd_vv_u8m8_m(vbool1_t, vuint8m8_t, vuint8m8_t, vuint8m8_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vmadd_vv)))
vuint8mf2_t vmadd_vv_u8mf2(vuint8mf2_t, vuint8mf2_t, vuint8mf2_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vmadd_vv_m)))
vuint8mf2_t vmadd_vv_u8mf2_m(vbool16_t, vuint8mf2_t, vuint8mf2_t, vuint8mf2_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vmadd_vv)))
vuint8mf4_t vmadd_vv_u8mf4(vuint8mf4_t, vuint8mf4_t, vuint8mf4_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vmadd_vv_m)))
vuint8mf4_t vmadd_vv_u8mf4_m(vbool32_t, vuint8mf4_t, vuint8mf4_t, vuint8mf4_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vmadd_vv)))
vuint8mf8_t vmadd_vv_u8mf8(vuint8mf8_t, vuint8mf8_t, vuint8mf8_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vmadd_vv_m)))
vuint8mf8_t vmadd_vv_u8mf8_m(vbool64_t, vuint8mf8_t, vuint8mf8_t, vuint8mf8_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vmadd_vv)))
vuint16m1_t vmadd_vv_u16m1(vuint16m1_t, vuint16m1_t, vuint16m1_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vmadd_vv_m)))
vuint16m1_t vmadd_vv_u16m1_m(vbool16_t, vuint16m1_t, vuint16m1_t, vuint16m1_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vmadd_vv)))
vuint16m2_t vmadd_vv_u16m2(vuint16m2_t, vuint16m2_t, vuint16m2_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vmadd_vv_m)))
vuint16m2_t vmadd_vv_u16m2_m(vbool8_t, vuint16m2_t, vuint16m2_t, vuint16m2_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vmadd_vv)))
vuint16m4_t vmadd_vv_u16m4(vuint16m4_t, vuint16m4_t, vuint16m4_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vmadd_vv_m)))
vuint16m4_t vmadd_vv_u16m4_m(vbool4_t, vuint16m4_t, vuint16m4_t, vuint16m4_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vmadd_vv)))
vuint16m8_t vmadd_vv_u16m8(vuint16m8_t, vuint16m8_t, vuint16m8_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vmadd_vv_m)))
vuint16m8_t vmadd_vv_u16m8_m(vbool2_t, vuint16m8_t, vuint16m8_t, vuint16m8_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vmadd_vv)))
vuint16mf2_t vmadd_vv_u16mf2(vuint16mf2_t, vuint16mf2_t, vuint16mf2_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vmadd_vv_m)))
vuint16mf2_t vmadd_vv_u16mf2_m(vbool32_t, vuint16mf2_t, vuint16mf2_t, vuint16mf2_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vmadd_vv)))
vuint16mf4_t vmadd_vv_u16mf4(vuint16mf4_t, vuint16mf4_t, vuint16mf4_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vmadd_vv_m)))
vuint16mf4_t vmadd_vv_u16mf4_m(vbool64_t, vuint16mf4_t, vuint16mf4_t, vuint16mf4_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vmadd_vv)))
vuint32m1_t vmadd_vv_u32m1(vuint32m1_t, vuint32m1_t, vuint32m1_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vmadd_vv_m)))
vuint32m1_t vmadd_vv_u32m1_m(vbool32_t, vuint32m1_t, vuint32m1_t, vuint32m1_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vmadd_vv)))
vuint32m2_t vmadd_vv_u32m2(vuint32m2_t, vuint32m2_t, vuint32m2_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vmadd_vv_m)))
vuint32m2_t vmadd_vv_u32m2_m(vbool16_t, vuint32m2_t, vuint32m2_t, vuint32m2_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vmadd_vv)))
vuint32m4_t vmadd_vv_u32m4(vuint32m4_t, vuint32m4_t, vuint32m4_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vmadd_vv_m)))
vuint32m4_t vmadd_vv_u32m4_m(vbool8_t, vuint32m4_t, vuint32m4_t, vuint32m4_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vmadd_vv)))
vuint32m8_t vmadd_vv_u32m8(vuint32m8_t, vuint32m8_t, vuint32m8_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vmadd_vv_m)))
vuint32m8_t vmadd_vv_u32m8_m(vbool4_t, vuint32m8_t, vuint32m8_t, vuint32m8_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vmadd_vv)))
vuint32mf2_t vmadd_vv_u32mf2(vuint32mf2_t, vuint32mf2_t, vuint32mf2_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vmadd_vv_m)))
vuint32mf2_t vmadd_vv_u32mf2_m(vbool64_t, vuint32mf2_t, vuint32mf2_t, vuint32mf2_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vmadd_vx)))
vuint8m1_t vmadd_vx_u8m1(vuint8m1_t, uint8_t, vuint8m1_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vmadd_vx_m)))
vuint8m1_t vmadd_vx_u8m1_m(vbool8_t, vuint8m1_t, uint8_t, vuint8m1_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vmadd_vx)))
vuint8m2_t vmadd_vx_u8m2(vuint8m2_t, uint8_t, vuint8m2_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vmadd_vx_m)))
vuint8m2_t vmadd_vx_u8m2_m(vbool4_t, vuint8m2_t, uint8_t, vuint8m2_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vmadd_vx)))
vuint8m4_t vmadd_vx_u8m4(vuint8m4_t, uint8_t, vuint8m4_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vmadd_vx_m)))
vuint8m4_t vmadd_vx_u8m4_m(vbool2_t, vuint8m4_t, uint8_t, vuint8m4_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vmadd_vx)))
vuint8m8_t vmadd_vx_u8m8(vuint8m8_t, uint8_t, vuint8m8_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vmadd_vx_m)))
vuint8m8_t vmadd_vx_u8m8_m(vbool1_t, vuint8m8_t, uint8_t, vuint8m8_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vmadd_vx)))
vuint8mf2_t vmadd_vx_u8mf2(vuint8mf2_t, uint8_t, vuint8mf2_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vmadd_vx_m)))
vuint8mf2_t vmadd_vx_u8mf2_m(vbool16_t, vuint8mf2_t, uint8_t, vuint8mf2_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vmadd_vx)))
vuint8mf4_t vmadd_vx_u8mf4(vuint8mf4_t, uint8_t, vuint8mf4_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vmadd_vx_m)))
vuint8mf4_t vmadd_vx_u8mf4_m(vbool32_t, vuint8mf4_t, uint8_t, vuint8mf4_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vmadd_vx)))
vuint8mf8_t vmadd_vx_u8mf8(vuint8mf8_t, uint8_t, vuint8mf8_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vmadd_vx_m)))
vuint8mf8_t vmadd_vx_u8mf8_m(vbool64_t, vuint8mf8_t, uint8_t, vuint8mf8_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vmadd_vx)))
vuint16m1_t vmadd_vx_u16m1(vuint16m1_t, uint16_t, vuint16m1_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vmadd_vx_m)))
vuint16m1_t vmadd_vx_u16m1_m(vbool16_t, vuint16m1_t, uint16_t, vuint16m1_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vmadd_vx)))
vuint16m2_t vmadd_vx_u16m2(vuint16m2_t, uint16_t, vuint16m2_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vmadd_vx_m)))
vuint16m2_t vmadd_vx_u16m2_m(vbool8_t, vuint16m2_t, uint16_t, vuint16m2_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vmadd_vx)))
vuint16m4_t vmadd_vx_u16m4(vuint16m4_t, uint16_t, vuint16m4_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vmadd_vx_m)))
vuint16m4_t vmadd_vx_u16m4_m(vbool4_t, vuint16m4_t, uint16_t, vuint16m4_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vmadd_vx)))
vuint16m8_t vmadd_vx_u16m8(vuint16m8_t, uint16_t, vuint16m8_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vmadd_vx_m)))
vuint16m8_t vmadd_vx_u16m8_m(vbool2_t, vuint16m8_t, uint16_t, vuint16m8_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vmadd_vx)))
vuint16mf2_t vmadd_vx_u16mf2(vuint16mf2_t, uint16_t, vuint16mf2_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vmadd_vx_m)))
vuint16mf2_t vmadd_vx_u16mf2_m(vbool32_t, vuint16mf2_t, uint16_t, vuint16mf2_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vmadd_vx)))
vuint16mf4_t vmadd_vx_u16mf4(vuint16mf4_t, uint16_t, vuint16mf4_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vmadd_vx_m)))
vuint16mf4_t vmadd_vx_u16mf4_m(vbool64_t, vuint16mf4_t, uint16_t, vuint16mf4_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vmadd_vx)))
vuint32m1_t vmadd_vx_u32m1(vuint32m1_t, uint32_t, vuint32m1_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vmadd_vx_m)))
vuint32m1_t vmadd_vx_u32m1_m(vbool32_t, vuint32m1_t, uint32_t, vuint32m1_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vmadd_vx)))
vuint32m2_t vmadd_vx_u32m2(vuint32m2_t, uint32_t, vuint32m2_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vmadd_vx_m)))
vuint32m2_t vmadd_vx_u32m2_m(vbool16_t, vuint32m2_t, uint32_t, vuint32m2_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vmadd_vx)))
vuint32m4_t vmadd_vx_u32m4(vuint32m4_t, uint32_t, vuint32m4_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vmadd_vx_m)))
vuint32m4_t vmadd_vx_u32m4_m(vbool8_t, vuint32m4_t, uint32_t, vuint32m4_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vmadd_vx)))
vuint32m8_t vmadd_vx_u32m8(vuint32m8_t, uint32_t, vuint32m8_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vmadd_vx_m)))
vuint32m8_t vmadd_vx_u32m8_m(vbool4_t, vuint32m8_t, uint32_t, vuint32m8_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vmadd_vx)))
vuint32mf2_t vmadd_vx_u32mf2(vuint32mf2_t, uint32_t, vuint32mf2_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vmadd_vx_m)))
vuint32mf2_t vmadd_vx_u32mf2_m(vbool64_t, vuint32mf2_t, uint32_t, vuint32mf2_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vnmsub_vv)))
vint8m1_t vnmsub_vv_i8m1(vint8m1_t, vint8m1_t, vint8m1_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vnmsub_vv_m)))
vint8m1_t vnmsub_vv_i8m1_m(vbool8_t, vint8m1_t, vint8m1_t, vint8m1_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vnmsub_vv)))
vint8m2_t vnmsub_vv_i8m2(vint8m2_t, vint8m2_t, vint8m2_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vnmsub_vv_m)))
vint8m2_t vnmsub_vv_i8m2_m(vbool4_t, vint8m2_t, vint8m2_t, vint8m2_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vnmsub_vv)))
vint8m4_t vnmsub_vv_i8m4(vint8m4_t, vint8m4_t, vint8m4_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vnmsub_vv_m)))
vint8m4_t vnmsub_vv_i8m4_m(vbool2_t, vint8m4_t, vint8m4_t, vint8m4_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vnmsub_vv)))
vint8m8_t vnmsub_vv_i8m8(vint8m8_t, vint8m8_t, vint8m8_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vnmsub_vv_m)))
vint8m8_t vnmsub_vv_i8m8_m(vbool1_t, vint8m8_t, vint8m8_t, vint8m8_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vnmsub_vv)))
vint8mf2_t vnmsub_vv_i8mf2(vint8mf2_t, vint8mf2_t, vint8mf2_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vnmsub_vv_m)))
vint8mf2_t vnmsub_vv_i8mf2_m(vbool16_t, vint8mf2_t, vint8mf2_t, vint8mf2_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vnmsub_vv)))
vint8mf4_t vnmsub_vv_i8mf4(vint8mf4_t, vint8mf4_t, vint8mf4_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vnmsub_vv_m)))
vint8mf4_t vnmsub_vv_i8mf4_m(vbool32_t, vint8mf4_t, vint8mf4_t, vint8mf4_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vnmsub_vv)))
vint8mf8_t vnmsub_vv_i8mf8(vint8mf8_t, vint8mf8_t, vint8mf8_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vnmsub_vv_m)))
vint8mf8_t vnmsub_vv_i8mf8_m(vbool64_t, vint8mf8_t, vint8mf8_t, vint8mf8_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vnmsub_vv)))
vint16m1_t vnmsub_vv_i16m1(vint16m1_t, vint16m1_t, vint16m1_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vnmsub_vv_m)))
vint16m1_t vnmsub_vv_i16m1_m(vbool16_t, vint16m1_t, vint16m1_t, vint16m1_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vnmsub_vv)))
vint16m2_t vnmsub_vv_i16m2(vint16m2_t, vint16m2_t, vint16m2_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vnmsub_vv_m)))
vint16m2_t vnmsub_vv_i16m2_m(vbool8_t, vint16m2_t, vint16m2_t, vint16m2_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vnmsub_vv)))
vint16m4_t vnmsub_vv_i16m4(vint16m4_t, vint16m4_t, vint16m4_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vnmsub_vv_m)))
vint16m4_t vnmsub_vv_i16m4_m(vbool4_t, vint16m4_t, vint16m4_t, vint16m4_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vnmsub_vv)))
vint16m8_t vnmsub_vv_i16m8(vint16m8_t, vint16m8_t, vint16m8_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vnmsub_vv_m)))
vint16m8_t vnmsub_vv_i16m8_m(vbool2_t, vint16m8_t, vint16m8_t, vint16m8_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vnmsub_vv)))
vint16mf2_t vnmsub_vv_i16mf2(vint16mf2_t, vint16mf2_t, vint16mf2_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vnmsub_vv_m)))
vint16mf2_t vnmsub_vv_i16mf2_m(vbool32_t, vint16mf2_t, vint16mf2_t, vint16mf2_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vnmsub_vv)))
vint16mf4_t vnmsub_vv_i16mf4(vint16mf4_t, vint16mf4_t, vint16mf4_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vnmsub_vv_m)))
vint16mf4_t vnmsub_vv_i16mf4_m(vbool64_t, vint16mf4_t, vint16mf4_t, vint16mf4_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vnmsub_vv)))
vint32m1_t vnmsub_vv_i32m1(vint32m1_t, vint32m1_t, vint32m1_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vnmsub_vv_m)))
vint32m1_t vnmsub_vv_i32m1_m(vbool32_t, vint32m1_t, vint32m1_t, vint32m1_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vnmsub_vv)))
vint32m2_t vnmsub_vv_i32m2(vint32m2_t, vint32m2_t, vint32m2_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vnmsub_vv_m)))
vint32m2_t vnmsub_vv_i32m2_m(vbool16_t, vint32m2_t, vint32m2_t, vint32m2_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vnmsub_vv)))
vint32m4_t vnmsub_vv_i32m4(vint32m4_t, vint32m4_t, vint32m4_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vnmsub_vv_m)))
vint32m4_t vnmsub_vv_i32m4_m(vbool8_t, vint32m4_t, vint32m4_t, vint32m4_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vnmsub_vv)))
vint32m8_t vnmsub_vv_i32m8(vint32m8_t, vint32m8_t, vint32m8_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vnmsub_vv_m)))
vint32m8_t vnmsub_vv_i32m8_m(vbool4_t, vint32m8_t, vint32m8_t, vint32m8_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vnmsub_vv)))
vint32mf2_t vnmsub_vv_i32mf2(vint32mf2_t, vint32mf2_t, vint32mf2_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vnmsub_vv_m)))
vint32mf2_t vnmsub_vv_i32mf2_m(vbool64_t, vint32mf2_t, vint32mf2_t, vint32mf2_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vnmsub_vx)))
vint8m1_t vnmsub_vx_i8m1(vint8m1_t, int8_t, vint8m1_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vnmsub_vx_m)))
vint8m1_t vnmsub_vx_i8m1_m(vbool8_t, vint8m1_t, int8_t, vint8m1_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vnmsub_vx)))
vint8m2_t vnmsub_vx_i8m2(vint8m2_t, int8_t, vint8m2_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vnmsub_vx_m)))
vint8m2_t vnmsub_vx_i8m2_m(vbool4_t, vint8m2_t, int8_t, vint8m2_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vnmsub_vx)))
vint8m4_t vnmsub_vx_i8m4(vint8m4_t, int8_t, vint8m4_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vnmsub_vx_m)))
vint8m4_t vnmsub_vx_i8m4_m(vbool2_t, vint8m4_t, int8_t, vint8m4_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vnmsub_vx)))
vint8m8_t vnmsub_vx_i8m8(vint8m8_t, int8_t, vint8m8_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vnmsub_vx_m)))
vint8m8_t vnmsub_vx_i8m8_m(vbool1_t, vint8m8_t, int8_t, vint8m8_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vnmsub_vx)))
vint8mf2_t vnmsub_vx_i8mf2(vint8mf2_t, int8_t, vint8mf2_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vnmsub_vx_m)))
vint8mf2_t vnmsub_vx_i8mf2_m(vbool16_t, vint8mf2_t, int8_t, vint8mf2_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vnmsub_vx)))
vint8mf4_t vnmsub_vx_i8mf4(vint8mf4_t, int8_t, vint8mf4_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vnmsub_vx_m)))
vint8mf4_t vnmsub_vx_i8mf4_m(vbool32_t, vint8mf4_t, int8_t, vint8mf4_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vnmsub_vx)))
vint8mf8_t vnmsub_vx_i8mf8(vint8mf8_t, int8_t, vint8mf8_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vnmsub_vx_m)))
vint8mf8_t vnmsub_vx_i8mf8_m(vbool64_t, vint8mf8_t, int8_t, vint8mf8_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vnmsub_vx)))
vint16m1_t vnmsub_vx_i16m1(vint16m1_t, int16_t, vint16m1_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vnmsub_vx_m)))
vint16m1_t vnmsub_vx_i16m1_m(vbool16_t, vint16m1_t, int16_t, vint16m1_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vnmsub_vx)))
vint16m2_t vnmsub_vx_i16m2(vint16m2_t, int16_t, vint16m2_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vnmsub_vx_m)))
vint16m2_t vnmsub_vx_i16m2_m(vbool8_t, vint16m2_t, int16_t, vint16m2_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vnmsub_vx)))
vint16m4_t vnmsub_vx_i16m4(vint16m4_t, int16_t, vint16m4_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vnmsub_vx_m)))
vint16m4_t vnmsub_vx_i16m4_m(vbool4_t, vint16m4_t, int16_t, vint16m4_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vnmsub_vx)))
vint16m8_t vnmsub_vx_i16m8(vint16m8_t, int16_t, vint16m8_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vnmsub_vx_m)))
vint16m8_t vnmsub_vx_i16m8_m(vbool2_t, vint16m8_t, int16_t, vint16m8_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vnmsub_vx)))
vint16mf2_t vnmsub_vx_i16mf2(vint16mf2_t, int16_t, vint16mf2_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vnmsub_vx_m)))
vint16mf2_t vnmsub_vx_i16mf2_m(vbool32_t, vint16mf2_t, int16_t, vint16mf2_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vnmsub_vx)))
vint16mf4_t vnmsub_vx_i16mf4(vint16mf4_t, int16_t, vint16mf4_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vnmsub_vx_m)))
vint16mf4_t vnmsub_vx_i16mf4_m(vbool64_t, vint16mf4_t, int16_t, vint16mf4_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vnmsub_vx)))
vint32m1_t vnmsub_vx_i32m1(vint32m1_t, int32_t, vint32m1_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vnmsub_vx_m)))
vint32m1_t vnmsub_vx_i32m1_m(vbool32_t, vint32m1_t, int32_t, vint32m1_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vnmsub_vx)))
vint32m2_t vnmsub_vx_i32m2(vint32m2_t, int32_t, vint32m2_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vnmsub_vx_m)))
vint32m2_t vnmsub_vx_i32m2_m(vbool16_t, vint32m2_t, int32_t, vint32m2_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vnmsub_vx)))
vint32m4_t vnmsub_vx_i32m4(vint32m4_t, int32_t, vint32m4_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vnmsub_vx_m)))
vint32m4_t vnmsub_vx_i32m4_m(vbool8_t, vint32m4_t, int32_t, vint32m4_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vnmsub_vx)))
vint32m8_t vnmsub_vx_i32m8(vint32m8_t, int32_t, vint32m8_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vnmsub_vx_m)))
vint32m8_t vnmsub_vx_i32m8_m(vbool4_t, vint32m8_t, int32_t, vint32m8_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vnmsub_vx)))
vint32mf2_t vnmsub_vx_i32mf2(vint32mf2_t, int32_t, vint32mf2_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vnmsub_vx_m)))
vint32mf2_t vnmsub_vx_i32mf2_m(vbool64_t, vint32mf2_t, int32_t, vint32mf2_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vnmsub_vv)))
vuint8m1_t vnmsub_vv_u8m1(vuint8m1_t, vuint8m1_t, vuint8m1_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vnmsub_vv_m)))
vuint8m1_t vnmsub_vv_u8m1_m(vbool8_t, vuint8m1_t, vuint8m1_t, vuint8m1_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vnmsub_vv)))
vuint8m2_t vnmsub_vv_u8m2(vuint8m2_t, vuint8m2_t, vuint8m2_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vnmsub_vv_m)))
vuint8m2_t vnmsub_vv_u8m2_m(vbool4_t, vuint8m2_t, vuint8m2_t, vuint8m2_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vnmsub_vv)))
vuint8m4_t vnmsub_vv_u8m4(vuint8m4_t, vuint8m4_t, vuint8m4_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vnmsub_vv_m)))
vuint8m4_t vnmsub_vv_u8m4_m(vbool2_t, vuint8m4_t, vuint8m4_t, vuint8m4_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vnmsub_vv)))
vuint8m8_t vnmsub_vv_u8m8(vuint8m8_t, vuint8m8_t, vuint8m8_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vnmsub_vv_m)))
vuint8m8_t vnmsub_vv_u8m8_m(vbool1_t, vuint8m8_t, vuint8m8_t, vuint8m8_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vnmsub_vv)))
vuint8mf2_t vnmsub_vv_u8mf2(vuint8mf2_t, vuint8mf2_t, vuint8mf2_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vnmsub_vv_m)))
vuint8mf2_t vnmsub_vv_u8mf2_m(vbool16_t, vuint8mf2_t, vuint8mf2_t, vuint8mf2_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vnmsub_vv)))
vuint8mf4_t vnmsub_vv_u8mf4(vuint8mf4_t, vuint8mf4_t, vuint8mf4_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vnmsub_vv_m)))
vuint8mf4_t vnmsub_vv_u8mf4_m(vbool32_t, vuint8mf4_t, vuint8mf4_t, vuint8mf4_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vnmsub_vv)))
vuint8mf8_t vnmsub_vv_u8mf8(vuint8mf8_t, vuint8mf8_t, vuint8mf8_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vnmsub_vv_m)))
vuint8mf8_t vnmsub_vv_u8mf8_m(vbool64_t, vuint8mf8_t, vuint8mf8_t, vuint8mf8_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vnmsub_vv)))
vuint16m1_t vnmsub_vv_u16m1(vuint16m1_t, vuint16m1_t, vuint16m1_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vnmsub_vv_m)))
vuint16m1_t vnmsub_vv_u16m1_m(vbool16_t, vuint16m1_t, vuint16m1_t, vuint16m1_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vnmsub_vv)))
vuint16m2_t vnmsub_vv_u16m2(vuint16m2_t, vuint16m2_t, vuint16m2_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vnmsub_vv_m)))
vuint16m2_t vnmsub_vv_u16m2_m(vbool8_t, vuint16m2_t, vuint16m2_t, vuint16m2_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vnmsub_vv)))
vuint16m4_t vnmsub_vv_u16m4(vuint16m4_t, vuint16m4_t, vuint16m4_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vnmsub_vv_m)))
vuint16m4_t vnmsub_vv_u16m4_m(vbool4_t, vuint16m4_t, vuint16m4_t, vuint16m4_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vnmsub_vv)))
vuint16m8_t vnmsub_vv_u16m8(vuint16m8_t, vuint16m8_t, vuint16m8_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vnmsub_vv_m)))
vuint16m8_t vnmsub_vv_u16m8_m(vbool2_t, vuint16m8_t, vuint16m8_t, vuint16m8_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vnmsub_vv)))
vuint16mf2_t vnmsub_vv_u16mf2(vuint16mf2_t, vuint16mf2_t, vuint16mf2_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vnmsub_vv_m)))
vuint16mf2_t vnmsub_vv_u16mf2_m(vbool32_t, vuint16mf2_t, vuint16mf2_t, vuint16mf2_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vnmsub_vv)))
vuint16mf4_t vnmsub_vv_u16mf4(vuint16mf4_t, vuint16mf4_t, vuint16mf4_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vnmsub_vv_m)))
vuint16mf4_t vnmsub_vv_u16mf4_m(vbool64_t, vuint16mf4_t, vuint16mf4_t, vuint16mf4_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vnmsub_vv)))
vuint32m1_t vnmsub_vv_u32m1(vuint32m1_t, vuint32m1_t, vuint32m1_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vnmsub_vv_m)))
vuint32m1_t vnmsub_vv_u32m1_m(vbool32_t, vuint32m1_t, vuint32m1_t, vuint32m1_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vnmsub_vv)))
vuint32m2_t vnmsub_vv_u32m2(vuint32m2_t, vuint32m2_t, vuint32m2_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vnmsub_vv_m)))
vuint32m2_t vnmsub_vv_u32m2_m(vbool16_t, vuint32m2_t, vuint32m2_t, vuint32m2_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vnmsub_vv)))
vuint32m4_t vnmsub_vv_u32m4(vuint32m4_t, vuint32m4_t, vuint32m4_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vnmsub_vv_m)))
vuint32m4_t vnmsub_vv_u32m4_m(vbool8_t, vuint32m4_t, vuint32m4_t, vuint32m4_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vnmsub_vv)))
vuint32m8_t vnmsub_vv_u32m8(vuint32m8_t, vuint32m8_t, vuint32m8_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vnmsub_vv_m)))
vuint32m8_t vnmsub_vv_u32m8_m(vbool4_t, vuint32m8_t, vuint32m8_t, vuint32m8_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vnmsub_vv)))
vuint32mf2_t vnmsub_vv_u32mf2(vuint32mf2_t, vuint32mf2_t, vuint32mf2_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vnmsub_vv_m)))
vuint32mf2_t vnmsub_vv_u32mf2_m(vbool64_t, vuint32mf2_t, vuint32mf2_t, vuint32mf2_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vsuxei8_v)))
void vsuxei8_v_u16m1(uint16_t *, vuint8mf2_t, vuint16m1_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vsuxei8_v_m)))
void vsuxei8_v_u16m1_m(vbool16_t, uint16_t *, vuint8mf2_t, vuint16m1_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vsuxei8_v)))
void vsuxei8_v_u16m2(uint16_t *, vuint8m1_t, vuint16m2_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vsuxei8_v_m)))
void vsuxei8_v_u16m2_m(vbool8_t, uint16_t *, vuint8m1_t, vuint16m2_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vsuxei8_v)))
void vsuxei8_v_u16m4(uint16_t *, vuint8m2_t, vuint16m4_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vsuxei8_v_m)))
void vsuxei8_v_u16m4_m(vbool4_t, uint16_t *, vuint8m2_t, vuint16m4_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vsuxei8_v)))
void vsuxei8_v_u16m8(uint16_t *, vuint8m4_t, vuint16m8_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vsuxei8_v_m)))
void vsuxei8_v_u16m8_m(vbool2_t, uint16_t *, vuint8m4_t, vuint16m8_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vsuxei8_v)))
void vsuxei8_v_u16mf2(uint16_t *, vuint8mf4_t, vuint16mf2_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vsuxei8_v_m)))
void vsuxei8_v_u16mf2_m(vbool32_t, uint16_t *, vuint8mf4_t, vuint16mf2_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vsuxei8_v)))
void vsuxei8_v_u16mf4(uint16_t *, vuint8mf8_t, vuint16mf4_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vsuxei8_v_m)))
void vsuxei8_v_u16mf4_m(vbool64_t, uint16_t *, vuint8mf8_t, vuint16mf4_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vnmsub_vx)))
vuint8m1_t vnmsub_vx_u8m1(vuint8m1_t, uint8_t, vuint8m1_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vnmsub_vx_m)))
vuint8m1_t vnmsub_vx_u8m1_m(vbool8_t, vuint8m1_t, uint8_t, vuint8m1_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vnmsub_vx)))
vuint8m2_t vnmsub_vx_u8m2(vuint8m2_t, uint8_t, vuint8m2_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vnmsub_vx_m)))
vuint8m2_t vnmsub_vx_u8m2_m(vbool4_t, vuint8m2_t, uint8_t, vuint8m2_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vnmsub_vx)))
vuint8m4_t vnmsub_vx_u8m4(vuint8m4_t, uint8_t, vuint8m4_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vnmsub_vx_m)))
vuint8m4_t vnmsub_vx_u8m4_m(vbool2_t, vuint8m4_t, uint8_t, vuint8m4_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vnmsub_vx)))
vuint8m8_t vnmsub_vx_u8m8(vuint8m8_t, uint8_t, vuint8m8_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vnmsub_vx_m)))
vuint8m8_t vnmsub_vx_u8m8_m(vbool1_t, vuint8m8_t, uint8_t, vuint8m8_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vnmsub_vx)))
vuint8mf2_t vnmsub_vx_u8mf2(vuint8mf2_t, uint8_t, vuint8mf2_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vnmsub_vx_m)))
vuint8mf2_t vnmsub_vx_u8mf2_m(vbool16_t, vuint8mf2_t, uint8_t, vuint8mf2_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vnmsub_vx)))
vuint8mf4_t vnmsub_vx_u8mf4(vuint8mf4_t, uint8_t, vuint8mf4_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vnmsub_vx_m)))
vuint8mf4_t vnmsub_vx_u8mf4_m(vbool32_t, vuint8mf4_t, uint8_t, vuint8mf4_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vnmsub_vx)))
vuint8mf8_t vnmsub_vx_u8mf8(vuint8mf8_t, uint8_t, vuint8mf8_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vnmsub_vx_m)))
vuint8mf8_t vnmsub_vx_u8mf8_m(vbool64_t, vuint8mf8_t, uint8_t, vuint8mf8_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vnmsub_vx)))
vuint16m1_t vnmsub_vx_u16m1(vuint16m1_t, uint16_t, vuint16m1_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vnmsub_vx_m)))
vuint16m1_t vnmsub_vx_u16m1_m(vbool16_t, vuint16m1_t, uint16_t, vuint16m1_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vnmsub_vx)))
vuint16m2_t vnmsub_vx_u16m2(vuint16m2_t, uint16_t, vuint16m2_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vnmsub_vx_m)))
vuint16m2_t vnmsub_vx_u16m2_m(vbool8_t, vuint16m2_t, uint16_t, vuint16m2_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vnmsub_vx)))
vuint16m4_t vnmsub_vx_u16m4(vuint16m4_t, uint16_t, vuint16m4_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vnmsub_vx_m)))
vuint16m4_t vnmsub_vx_u16m4_m(vbool4_t, vuint16m4_t, uint16_t, vuint16m4_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vnmsub_vx)))
vuint16m8_t vnmsub_vx_u16m8(vuint16m8_t, uint16_t, vuint16m8_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vnmsub_vx_m)))
vuint16m8_t vnmsub_vx_u16m8_m(vbool2_t, vuint16m8_t, uint16_t, vuint16m8_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vnmsub_vx)))
vuint16mf2_t vnmsub_vx_u16mf2(vuint16mf2_t, uint16_t, vuint16mf2_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vnmsub_vx_m)))
vuint16mf2_t vnmsub_vx_u16mf2_m(vbool32_t, vuint16mf2_t, uint16_t, vuint16mf2_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vnmsub_vx)))
vuint16mf4_t vnmsub_vx_u16mf4(vuint16mf4_t, uint16_t, vuint16mf4_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vnmsub_vx_m)))
vuint16mf4_t vnmsub_vx_u16mf4_m(vbool64_t, vuint16mf4_t, uint16_t, vuint16mf4_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vnmsub_vx)))
vuint32m1_t vnmsub_vx_u32m1(vuint32m1_t, uint32_t, vuint32m1_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vnmsub_vx_m)))
vuint32m1_t vnmsub_vx_u32m1_m(vbool32_t, vuint32m1_t, uint32_t, vuint32m1_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vnmsub_vx)))
vuint32m2_t vnmsub_vx_u32m2(vuint32m2_t, uint32_t, vuint32m2_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vnmsub_vx_m)))
vuint32m2_t vnmsub_vx_u32m2_m(vbool16_t, vuint32m2_t, uint32_t, vuint32m2_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vnmsub_vx)))
vuint32m4_t vnmsub_vx_u32m4(vuint32m4_t, uint32_t, vuint32m4_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vnmsub_vx_m)))
vuint32m4_t vnmsub_vx_u32m4_m(vbool8_t, vuint32m4_t, uint32_t, vuint32m4_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vnmsub_vx)))
vuint32m8_t vnmsub_vx_u32m8(vuint32m8_t, uint32_t, vuint32m8_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vnmsub_vx_m)))
vuint32m8_t vnmsub_vx_u32m8_m(vbool4_t, vuint32m8_t, uint32_t, vuint32m8_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vnmsub_vx)))
vuint32mf2_t vnmsub_vx_u32mf2(vuint32mf2_t, uint32_t, vuint32mf2_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vnmsub_vx_m)))
vuint32mf2_t vnmsub_vx_u32mf2_m(vbool64_t, vuint32mf2_t, uint32_t, vuint32mf2_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vwmaccu_vv)))
vuint16mf4_t vwmaccu_vv_u16mf4(vuint16mf4_t, vuint8mf8_t, vuint8mf8_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vwmaccu_vv_m)))
vuint16mf4_t vwmaccu_vv_u16mf4_m(vbool64_t, vuint16mf4_t, vuint8mf8_t, vuint8mf8_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vwmaccu_vv)))
vuint16mf2_t vwmaccu_vv_u16mf2(vuint16mf2_t, vuint8mf4_t, vuint8mf4_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vwmaccu_vv_m)))
vuint16mf2_t vwmaccu_vv_u16mf2_m(vbool32_t, vuint16mf2_t, vuint8mf4_t, vuint8mf4_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vwmaccu_vv)))
vuint16m1_t vwmaccu_vv_u16m1(vuint16m1_t, vuint8mf2_t, vuint8mf2_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vwmaccu_vv_m)))
vuint16m1_t vwmaccu_vv_u16m1_m(vbool16_t, vuint16m1_t, vuint8mf2_t, vuint8mf2_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vwmaccu_vv)))
vuint16m2_t vwmaccu_vv_u16m2(vuint16m2_t, vuint8m1_t, vuint8m1_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vwmaccu_vv_m)))
vuint16m2_t vwmaccu_vv_u16m2_m(vbool8_t, vuint16m2_t, vuint8m1_t, vuint8m1_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vwmaccu_vv)))
vuint16m4_t vwmaccu_vv_u16m4(vuint16m4_t, vuint8m2_t, vuint8m2_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vwmaccu_vv_m)))
vuint16m4_t vwmaccu_vv_u16m4_m(vbool4_t, vuint16m4_t, vuint8m2_t, vuint8m2_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vwmaccu_vv)))
vuint16m8_t vwmaccu_vv_u16m8(vuint16m8_t, vuint8m4_t, vuint8m4_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vwmaccu_vv_m)))
vuint16m8_t vwmaccu_vv_u16m8_m(vbool2_t, vuint16m8_t, vuint8m4_t, vuint8m4_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vwmaccu_vv)))
vuint32mf2_t vwmaccu_vv_u32mf2(vuint32mf2_t, vuint16mf4_t, vuint16mf4_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vwmaccu_vv_m)))
vuint32mf2_t vwmaccu_vv_u32mf2_m(vbool64_t, vuint32mf2_t, vuint16mf4_t, vuint16mf4_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vwmaccu_vv)))
vuint32m1_t vwmaccu_vv_u32m1(vuint32m1_t, vuint16mf2_t, vuint16mf2_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vwmaccu_vv_m)))
vuint32m1_t vwmaccu_vv_u32m1_m(vbool32_t, vuint32m1_t, vuint16mf2_t, vuint16mf2_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vwmaccu_vv)))
vuint32m2_t vwmaccu_vv_u32m2(vuint32m2_t, vuint16m1_t, vuint16m1_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vwmaccu_vv_m)))
vuint32m2_t vwmaccu_vv_u32m2_m(vbool16_t, vuint32m2_t, vuint16m1_t, vuint16m1_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vwmaccu_vv)))
vuint32m4_t vwmaccu_vv_u32m4(vuint32m4_t, vuint16m2_t, vuint16m2_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vwmaccu_vv_m)))
vuint32m4_t vwmaccu_vv_u32m4_m(vbool8_t, vuint32m4_t, vuint16m2_t, vuint16m2_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vwmaccu_vv)))
vuint32m8_t vwmaccu_vv_u32m8(vuint32m8_t, vuint16m4_t, vuint16m4_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vwmaccu_vv_m)))
vuint32m8_t vwmaccu_vv_u32m8_m(vbool4_t, vuint32m8_t, vuint16m4_t, vuint16m4_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vwmaccu_vx)))
vuint16mf4_t vwmaccu_vx_u16mf4(vuint16mf4_t, uint8_t, vuint8mf8_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vwmaccu_vx_m)))
vuint16mf4_t vwmaccu_vx_u16mf4_m(vbool64_t, vuint16mf4_t, uint8_t, vuint8mf8_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vwmaccu_vx)))
vuint16mf2_t vwmaccu_vx_u16mf2(vuint16mf2_t, uint8_t, vuint8mf4_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vwmaccu_vx_m)))
vuint16mf2_t vwmaccu_vx_u16mf2_m(vbool32_t, vuint16mf2_t, uint8_t, vuint8mf4_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vwmaccu_vx)))
vuint16m1_t vwmaccu_vx_u16m1(vuint16m1_t, uint8_t, vuint8mf2_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vwmaccu_vx_m)))
vuint16m1_t vwmaccu_vx_u16m1_m(vbool16_t, vuint16m1_t, uint8_t, vuint8mf2_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vwmaccu_vx)))
vuint16m2_t vwmaccu_vx_u16m2(vuint16m2_t, uint8_t, vuint8m1_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vwmaccu_vx_m)))
vuint16m2_t vwmaccu_vx_u16m2_m(vbool8_t, vuint16m2_t, uint8_t, vuint8m1_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vwmaccu_vx)))
vuint16m4_t vwmaccu_vx_u16m4(vuint16m4_t, uint8_t, vuint8m2_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vwmaccu_vx_m)))
vuint16m4_t vwmaccu_vx_u16m4_m(vbool4_t, vuint16m4_t, uint8_t, vuint8m2_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vwmaccu_vx)))
vuint16m8_t vwmaccu_vx_u16m8(vuint16m8_t, uint8_t, vuint8m4_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vwmaccu_vx_m)))
vuint16m8_t vwmaccu_vx_u16m8_m(vbool2_t, vuint16m8_t, uint8_t, vuint8m4_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vwmaccu_vx)))
vuint32mf2_t vwmaccu_vx_u32mf2(vuint32mf2_t, uint16_t, vuint16mf4_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vwmaccu_vx_m)))
vuint32mf2_t vwmaccu_vx_u32mf2_m(vbool64_t, vuint32mf2_t, uint16_t, vuint16mf4_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vwmaccu_vx)))
vuint32m1_t vwmaccu_vx_u32m1(vuint32m1_t, uint16_t, vuint16mf2_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vwmaccu_vx_m)))
vuint32m1_t vwmaccu_vx_u32m1_m(vbool32_t, vuint32m1_t, uint16_t, vuint16mf2_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vwmaccu_vx)))
vuint32m2_t vwmaccu_vx_u32m2(vuint32m2_t, uint16_t, vuint16m1_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vwmaccu_vx_m)))
vuint32m2_t vwmaccu_vx_u32m2_m(vbool16_t, vuint32m2_t, uint16_t, vuint16m1_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vwmaccu_vx)))
vuint32m4_t vwmaccu_vx_u32m4(vuint32m4_t, uint16_t, vuint16m2_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vwmaccu_vx_m)))
vuint32m4_t vwmaccu_vx_u32m4_m(vbool8_t, vuint32m4_t, uint16_t, vuint16m2_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vwmaccu_vx)))
vuint32m8_t vwmaccu_vx_u32m8(vuint32m8_t, uint16_t, vuint16m4_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vwmaccu_vx_m)))
vuint32m8_t vwmaccu_vx_u32m8_m(vbool4_t, vuint32m8_t, uint16_t, vuint16m4_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vwmacc_vv)))
vint16mf4_t vwmacc_vv_i16mf4(vint16mf4_t, vint8mf8_t, vint8mf8_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vwmacc_vv_m)))
vint16mf4_t vwmacc_vv_i16mf4_m(vbool64_t, vint16mf4_t, vint8mf8_t, vint8mf8_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vwmacc_vv)))
vint16mf2_t vwmacc_vv_i16mf2(vint16mf2_t, vint8mf4_t, vint8mf4_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vwmacc_vv_m)))
vint16mf2_t vwmacc_vv_i16mf2_m(vbool32_t, vint16mf2_t, vint8mf4_t, vint8mf4_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vwmacc_vv)))
vint16m1_t vwmacc_vv_i16m1(vint16m1_t, vint8mf2_t, vint8mf2_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vwmacc_vv_m)))
vint16m1_t vwmacc_vv_i16m1_m(vbool16_t, vint16m1_t, vint8mf2_t, vint8mf2_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vwmacc_vv)))
vint16m2_t vwmacc_vv_i16m2(vint16m2_t, vint8m1_t, vint8m1_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vwmacc_vv_m)))
vint16m2_t vwmacc_vv_i16m2_m(vbool8_t, vint16m2_t, vint8m1_t, vint8m1_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vwmacc_vv)))
vint16m4_t vwmacc_vv_i16m4(vint16m4_t, vint8m2_t, vint8m2_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vwmacc_vv_m)))
vint16m4_t vwmacc_vv_i16m4_m(vbool4_t, vint16m4_t, vint8m2_t, vint8m2_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vwmacc_vv)))
vint16m8_t vwmacc_vv_i16m8(vint16m8_t, vint8m4_t, vint8m4_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vwmacc_vv_m)))
vint16m8_t vwmacc_vv_i16m8_m(vbool2_t, vint16m8_t, vint8m4_t, vint8m4_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vwmacc_vv)))
vint32mf2_t vwmacc_vv_i32mf2(vint32mf2_t, vint16mf4_t, vint16mf4_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vwmacc_vv_m)))
vint32mf2_t vwmacc_vv_i32mf2_m(vbool64_t, vint32mf2_t, vint16mf4_t, vint16mf4_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vwmacc_vv)))
vint32m1_t vwmacc_vv_i32m1(vint32m1_t, vint16mf2_t, vint16mf2_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vwmacc_vv_m)))
vint32m1_t vwmacc_vv_i32m1_m(vbool32_t, vint32m1_t, vint16mf2_t, vint16mf2_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vwmacc_vv)))
vint32m2_t vwmacc_vv_i32m2(vint32m2_t, vint16m1_t, vint16m1_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vwmacc_vv_m)))
vint32m2_t vwmacc_vv_i32m2_m(vbool16_t, vint32m2_t, vint16m1_t, vint16m1_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vwmacc_vv)))
vint32m4_t vwmacc_vv_i32m4(vint32m4_t, vint16m2_t, vint16m2_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vwmacc_vv_m)))
vint32m4_t vwmacc_vv_i32m4_m(vbool8_t, vint32m4_t, vint16m2_t, vint16m2_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vwmacc_vv)))
vint32m8_t vwmacc_vv_i32m8(vint32m8_t, vint16m4_t, vint16m4_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vwmacc_vv_m)))
vint32m8_t vwmacc_vv_i32m8_m(vbool4_t, vint32m8_t, vint16m4_t, vint16m4_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vwmacc_vx)))
vint16mf4_t vwmacc_vx_i16mf4(vint16mf4_t, int8_t, vint8mf8_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vwmacc_vx_m)))
vint16mf4_t vwmacc_vx_i16mf4_m(vbool64_t, vint16mf4_t, int8_t, vint8mf8_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vwmacc_vx)))
vint16mf2_t vwmacc_vx_i16mf2(vint16mf2_t, int8_t, vint8mf4_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vwmacc_vx_m)))
vint16mf2_t vwmacc_vx_i16mf2_m(vbool32_t, vint16mf2_t, int8_t, vint8mf4_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vwmacc_vx)))
vint16m1_t vwmacc_vx_i16m1(vint16m1_t, int8_t, vint8mf2_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vwmacc_vx_m)))
vint16m1_t vwmacc_vx_i16m1_m(vbool16_t, vint16m1_t, int8_t, vint8mf2_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vwmacc_vx)))
vint16m2_t vwmacc_vx_i16m2(vint16m2_t, int8_t, vint8m1_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vwmacc_vx_m)))
vint16m2_t vwmacc_vx_i16m2_m(vbool8_t, vint16m2_t, int8_t, vint8m1_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vwmacc_vx)))
vint16m4_t vwmacc_vx_i16m4(vint16m4_t, int8_t, vint8m2_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vwmacc_vx_m)))
vint16m4_t vwmacc_vx_i16m4_m(vbool4_t, vint16m4_t, int8_t, vint8m2_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vwmacc_vx)))
vint16m8_t vwmacc_vx_i16m8(vint16m8_t, int8_t, vint8m4_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vwmacc_vx_m)))
vint16m8_t vwmacc_vx_i16m8_m(vbool2_t, vint16m8_t, int8_t, vint8m4_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vwmacc_vx)))
vint32mf2_t vwmacc_vx_i32mf2(vint32mf2_t, int16_t, vint16mf4_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vwmacc_vx_m)))
vint32mf2_t vwmacc_vx_i32mf2_m(vbool64_t, vint32mf2_t, int16_t, vint16mf4_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vwmacc_vx)))
vint32m1_t vwmacc_vx_i32m1(vint32m1_t, int16_t, vint16mf2_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vwmacc_vx_m)))
vint32m1_t vwmacc_vx_i32m1_m(vbool32_t, vint32m1_t, int16_t, vint16mf2_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vwmacc_vx)))
vint32m2_t vwmacc_vx_i32m2(vint32m2_t, int16_t, vint16m1_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vwmacc_vx_m)))
vint32m2_t vwmacc_vx_i32m2_m(vbool16_t, vint32m2_t, int16_t, vint16m1_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vwmacc_vx)))
vint32m4_t vwmacc_vx_i32m4(vint32m4_t, int16_t, vint16m2_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vwmacc_vx_m)))
vint32m4_t vwmacc_vx_i32m4_m(vbool8_t, vint32m4_t, int16_t, vint16m2_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vwmacc_vx)))
vint32m8_t vwmacc_vx_i32m8(vint32m8_t, int16_t, vint16m4_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vwmacc_vx_m)))
vint32m8_t vwmacc_vx_i32m8_m(vbool4_t, vint32m8_t, int16_t, vint16m4_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vwmaccsu_vv)))
vint16mf4_t vwmaccsu_vv_i16mf4(vint16mf4_t, vint8mf8_t, vuint8mf8_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vwmaccsu_vv_m)))
vint16mf4_t vwmaccsu_vv_i16mf4_m(vbool64_t, vint16mf4_t, vint8mf8_t, vuint8mf8_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vwmaccsu_vv)))
vint16mf2_t vwmaccsu_vv_i16mf2(vint16mf2_t, vint8mf4_t, vuint8mf4_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vwmaccsu_vv_m)))
vint16mf2_t vwmaccsu_vv_i16mf2_m(vbool32_t, vint16mf2_t, vint8mf4_t, vuint8mf4_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vwmaccsu_vv)))
vint16m1_t vwmaccsu_vv_i16m1(vint16m1_t, vint8mf2_t, vuint8mf2_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vwmaccsu_vv_m)))
vint16m1_t vwmaccsu_vv_i16m1_m(vbool16_t, vint16m1_t, vint8mf2_t, vuint8mf2_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vwmaccsu_vv)))
vint16m2_t vwmaccsu_vv_i16m2(vint16m2_t, vint8m1_t, vuint8m1_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vwmaccsu_vv_m)))
vint16m2_t vwmaccsu_vv_i16m2_m(vbool8_t, vint16m2_t, vint8m1_t, vuint8m1_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vwmaccsu_vv)))
vint16m4_t vwmaccsu_vv_i16m4(vint16m4_t, vint8m2_t, vuint8m2_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vwmaccsu_vv_m)))
vint16m4_t vwmaccsu_vv_i16m4_m(vbool4_t, vint16m4_t, vint8m2_t, vuint8m2_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vwmaccsu_vv)))
vint16m8_t vwmaccsu_vv_i16m8(vint16m8_t, vint8m4_t, vuint8m4_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vwmaccsu_vv_m)))
vint16m8_t vwmaccsu_vv_i16m8_m(vbool2_t, vint16m8_t, vint8m4_t, vuint8m4_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vwmaccsu_vv)))
vint32mf2_t vwmaccsu_vv_i32mf2(vint32mf2_t, vint16mf4_t, vuint16mf4_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vwmaccsu_vv_m)))
vint32mf2_t vwmaccsu_vv_i32mf2_m(vbool64_t, vint32mf2_t, vint16mf4_t, vuint16mf4_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vwmaccsu_vv)))
vint32m1_t vwmaccsu_vv_i32m1(vint32m1_t, vint16mf2_t, vuint16mf2_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vwmaccsu_vv_m)))
vint32m1_t vwmaccsu_vv_i32m1_m(vbool32_t, vint32m1_t, vint16mf2_t, vuint16mf2_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vwmaccsu_vv)))
vint32m2_t vwmaccsu_vv_i32m2(vint32m2_t, vint16m1_t, vuint16m1_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vwmaccsu_vv_m)))
vint32m2_t vwmaccsu_vv_i32m2_m(vbool16_t, vint32m2_t, vint16m1_t, vuint16m1_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vwmaccsu_vv)))
vint32m4_t vwmaccsu_vv_i32m4(vint32m4_t, vint16m2_t, vuint16m2_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vwmaccsu_vv_m)))
vint32m4_t vwmaccsu_vv_i32m4_m(vbool8_t, vint32m4_t, vint16m2_t, vuint16m2_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vwmaccsu_vv)))
vint32m8_t vwmaccsu_vv_i32m8(vint32m8_t, vint16m4_t, vuint16m4_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vwmaccsu_vv_m)))
vint32m8_t vwmaccsu_vv_i32m8_m(vbool4_t, vint32m8_t, vint16m4_t, vuint16m4_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vwmaccsu_vx)))
vint16mf4_t vwmaccsu_vx_i16mf4(vint16mf4_t, int8_t, vuint8mf8_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vwmaccsu_vx_m)))
vint16mf4_t vwmaccsu_vx_i16mf4_m(vbool64_t, vint16mf4_t, int8_t, vuint8mf8_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vwmaccsu_vx)))
vint16mf2_t vwmaccsu_vx_i16mf2(vint16mf2_t, int8_t, vuint8mf4_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vwmaccsu_vx_m)))
vint16mf2_t vwmaccsu_vx_i16mf2_m(vbool32_t, vint16mf2_t, int8_t, vuint8mf4_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vwmaccsu_vx)))
vint16m1_t vwmaccsu_vx_i16m1(vint16m1_t, int8_t, vuint8mf2_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vwmaccsu_vx_m)))
vint16m1_t vwmaccsu_vx_i16m1_m(vbool16_t, vint16m1_t, int8_t, vuint8mf2_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vwmaccsu_vx)))
vint16m2_t vwmaccsu_vx_i16m2(vint16m2_t, int8_t, vuint8m1_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vwmaccsu_vx_m)))
vint16m2_t vwmaccsu_vx_i16m2_m(vbool8_t, vint16m2_t, int8_t, vuint8m1_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vwmaccsu_vx)))
vint16m4_t vwmaccsu_vx_i16m4(vint16m4_t, int8_t, vuint8m2_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vwmaccsu_vx_m)))
vint16m4_t vwmaccsu_vx_i16m4_m(vbool4_t, vint16m4_t, int8_t, vuint8m2_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vwmaccsu_vx)))
vint16m8_t vwmaccsu_vx_i16m8(vint16m8_t, int8_t, vuint8m4_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vwmaccsu_vx_m)))
vint16m8_t vwmaccsu_vx_i16m8_m(vbool2_t, vint16m8_t, int8_t, vuint8m4_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vwmaccsu_vx)))
vint32mf2_t vwmaccsu_vx_i32mf2(vint32mf2_t, int16_t, vuint16mf4_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vwmaccsu_vx_m)))
vint32mf2_t vwmaccsu_vx_i32mf2_m(vbool64_t, vint32mf2_t, int16_t, vuint16mf4_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vwmaccsu_vx)))
vint32m1_t vwmaccsu_vx_i32m1(vint32m1_t, int16_t, vuint16mf2_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vwmaccsu_vx_m)))
vint32m1_t vwmaccsu_vx_i32m1_m(vbool32_t, vint32m1_t, int16_t, vuint16mf2_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vwmaccsu_vx)))
vint32m2_t vwmaccsu_vx_i32m2(vint32m2_t, int16_t, vuint16m1_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vwmaccsu_vx_m)))
vint32m2_t vwmaccsu_vx_i32m2_m(vbool16_t, vint32m2_t, int16_t, vuint16m1_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vwmaccsu_vx)))
vint32m4_t vwmaccsu_vx_i32m4(vint32m4_t, int16_t, vuint16m2_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vwmaccsu_vx_m)))
vint32m4_t vwmaccsu_vx_i32m4_m(vbool8_t, vint32m4_t, int16_t, vuint16m2_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vwmaccsu_vx)))
vint32m8_t vwmaccsu_vx_i32m8(vint32m8_t, int16_t, vuint16m4_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vwmaccsu_vx_m)))
vint32m8_t vwmaccsu_vx_i32m8_m(vbool4_t, vint32m8_t, int16_t, vuint16m4_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vwmaccus_vx)))
vint16mf4_t vwmaccus_vx_i16mf4(vint16mf4_t, uint8_t, vint8mf8_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vwmaccus_vx_m)))
vint16mf4_t vwmaccus_vx_i16mf4_m(vbool64_t, vint16mf4_t, uint8_t, vint8mf8_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vwmaccus_vx)))
vint16mf2_t vwmaccus_vx_i16mf2(vint16mf2_t, uint8_t, vint8mf4_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vwmaccus_vx_m)))
vint16mf2_t vwmaccus_vx_i16mf2_m(vbool32_t, vint16mf2_t, uint8_t, vint8mf4_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vwmaccus_vx)))
vint16m1_t vwmaccus_vx_i16m1(vint16m1_t, uint8_t, vint8mf2_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vwmaccus_vx_m)))
vint16m1_t vwmaccus_vx_i16m1_m(vbool16_t, vint16m1_t, uint8_t, vint8mf2_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vwmaccus_vx)))
vint16m2_t vwmaccus_vx_i16m2(vint16m2_t, uint8_t, vint8m1_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vwmaccus_vx_m)))
vint16m2_t vwmaccus_vx_i16m2_m(vbool8_t, vint16m2_t, uint8_t, vint8m1_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vwmaccus_vx)))
vint16m4_t vwmaccus_vx_i16m4(vint16m4_t, uint8_t, vint8m2_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vwmaccus_vx_m)))
vint16m4_t vwmaccus_vx_i16m4_m(vbool4_t, vint16m4_t, uint8_t, vint8m2_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vwmaccus_vx)))
vint16m8_t vwmaccus_vx_i16m8(vint16m8_t, uint8_t, vint8m4_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vwmaccus_vx_m)))
vint16m8_t vwmaccus_vx_i16m8_m(vbool2_t, vint16m8_t, uint8_t, vint8m4_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vwmaccus_vx)))
vint32mf2_t vwmaccus_vx_i32mf2(vint32mf2_t, uint16_t, vint16mf4_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vwmaccus_vx_m)))
vint32mf2_t vwmaccus_vx_i32mf2_m(vbool64_t, vint32mf2_t, uint16_t, vint16mf4_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vwmaccus_vx)))
vint32m1_t vwmaccus_vx_i32m1(vint32m1_t, uint16_t, vint16mf2_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vwmaccus_vx_m)))
vint32m1_t vwmaccus_vx_i32m1_m(vbool32_t, vint32m1_t, uint16_t, vint16mf2_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vwmaccus_vx)))
vint32m2_t vwmaccus_vx_i32m2(vint32m2_t, uint16_t, vint16m1_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vwmaccus_vx_m)))
vint32m2_t vwmaccus_vx_i32m2_m(vbool16_t, vint32m2_t, uint16_t, vint16m1_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vwmaccus_vx)))
vint32m4_t vwmaccus_vx_i32m4(vint32m4_t, uint16_t, vint16m2_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vwmaccus_vx_m)))
vint32m4_t vwmaccus_vx_i32m4_m(vbool8_t, vint32m4_t, uint16_t, vint16m2_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vwmaccus_vx)))
vint32m8_t vwmaccus_vx_i32m8(vint32m8_t, uint16_t, vint16m4_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vwmaccus_vx_m)))
vint32m8_t vwmaccus_vx_i32m8_m(vbool4_t, vint32m8_t, uint16_t, vint16m4_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vmerge_vvm)))
vint8m1_t vmerge_vvm_i8m1(vbool8_t, vint8m1_t, vint8m1_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vmerge_vvm)))
vint8m2_t vmerge_vvm_i8m2(vbool4_t, vint8m2_t, vint8m2_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vmerge_vvm)))
vint8m4_t vmerge_vvm_i8m4(vbool2_t, vint8m4_t, vint8m4_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vmerge_vvm)))
vint8m8_t vmerge_vvm_i8m8(vbool1_t, vint8m8_t, vint8m8_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vmerge_vvm)))
vint8mf2_t vmerge_vvm_i8mf2(vbool16_t, vint8mf2_t, vint8mf2_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vmerge_vvm)))
vint8mf4_t vmerge_vvm_i8mf4(vbool32_t, vint8mf4_t, vint8mf4_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vmerge_vvm)))
vint8mf8_t vmerge_vvm_i8mf8(vbool64_t, vint8mf8_t, vint8mf8_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vmerge_vvm)))
vint16m1_t vmerge_vvm_i16m1(vbool16_t, vint16m1_t, vint16m1_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vmerge_vvm)))
vint16m2_t vmerge_vvm_i16m2(vbool8_t, vint16m2_t, vint16m2_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vmerge_vvm)))
vint16m4_t vmerge_vvm_i16m4(vbool4_t, vint16m4_t, vint16m4_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vmerge_vvm)))
vint16m8_t vmerge_vvm_i16m8(vbool2_t, vint16m8_t, vint16m8_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vmerge_vvm)))
vint16mf2_t vmerge_vvm_i16mf2(vbool32_t, vint16mf2_t, vint16mf2_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vmerge_vvm)))
vint16mf4_t vmerge_vvm_i16mf4(vbool64_t, vint16mf4_t, vint16mf4_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vmerge_vvm)))
vint32m1_t vmerge_vvm_i32m1(vbool32_t, vint32m1_t, vint32m1_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vmerge_vvm)))
vint32m2_t vmerge_vvm_i32m2(vbool16_t, vint32m2_t, vint32m2_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vmerge_vvm)))
vint32m4_t vmerge_vvm_i32m4(vbool8_t, vint32m4_t, vint32m4_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vmerge_vvm)))
vint32m8_t vmerge_vvm_i32m8(vbool4_t, vint32m8_t, vint32m8_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vmerge_vvm)))
vint32mf2_t vmerge_vvm_i32mf2(vbool64_t, vint32mf2_t, vint32mf2_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vmerge_vxm)))
vint8m1_t vmerge_vxm_i8m1(vbool8_t, vint8m1_t, int8_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vmerge_vxm)))
vint8m2_t vmerge_vxm_i8m2(vbool4_t, vint8m2_t, int8_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vmerge_vxm)))
vint8m4_t vmerge_vxm_i8m4(vbool2_t, vint8m4_t, int8_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vmerge_vxm)))
vint8m8_t vmerge_vxm_i8m8(vbool1_t, vint8m8_t, int8_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vmerge_vxm)))
vint8mf2_t vmerge_vxm_i8mf2(vbool16_t, vint8mf2_t, int8_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vmerge_vxm)))
vint8mf4_t vmerge_vxm_i8mf4(vbool32_t, vint8mf4_t, int8_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vmerge_vxm)))
vint8mf8_t vmerge_vxm_i8mf8(vbool64_t, vint8mf8_t, int8_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vmerge_vxm)))
vint16m1_t vmerge_vxm_i16m1(vbool16_t, vint16m1_t, int16_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vmerge_vxm)))
vint16m2_t vmerge_vxm_i16m2(vbool8_t, vint16m2_t, int16_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vmerge_vxm)))
vint16m4_t vmerge_vxm_i16m4(vbool4_t, vint16m4_t, int16_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vmerge_vxm)))
vint16m8_t vmerge_vxm_i16m8(vbool2_t, vint16m8_t, int16_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vmerge_vxm)))
vint16mf2_t vmerge_vxm_i16mf2(vbool32_t, vint16mf2_t, int16_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vmerge_vxm)))
vint16mf4_t vmerge_vxm_i16mf4(vbool64_t, vint16mf4_t, int16_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vmerge_vxm)))
vint32m1_t vmerge_vxm_i32m1(vbool32_t, vint32m1_t, int32_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vmerge_vxm)))
vint32m2_t vmerge_vxm_i32m2(vbool16_t, vint32m2_t, int32_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vmerge_vxm)))
vint32m4_t vmerge_vxm_i32m4(vbool8_t, vint32m4_t, int32_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vmerge_vxm)))
vint32m8_t vmerge_vxm_i32m8(vbool4_t, vint32m8_t, int32_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vmerge_vxm)))
vint32mf2_t vmerge_vxm_i32mf2(vbool64_t, vint32mf2_t, int32_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vsuxei16_v)))
void vsuxei16_v_i16m1(int16_t *, vuint16m1_t, vint16m1_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vsuxei16_v_m)))
void vsuxei16_v_i16m1_m(vbool16_t, int16_t *, vuint16m1_t, vint16m1_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vsuxei16_v)))
void vsuxei16_v_i16m2(int16_t *, vuint16m2_t, vint16m2_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vsuxei16_v_m)))
void vsuxei16_v_i16m2_m(vbool8_t, int16_t *, vuint16m2_t, vint16m2_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vsuxei16_v)))
void vsuxei16_v_i16m4(int16_t *, vuint16m4_t, vint16m4_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vsuxei16_v_m)))
void vsuxei16_v_i16m4_m(vbool4_t, int16_t *, vuint16m4_t, vint16m4_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vsuxei16_v)))
void vsuxei16_v_i16m8(int16_t *, vuint16m8_t, vint16m8_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vsuxei16_v_m)))
void vsuxei16_v_i16m8_m(vbool2_t, int16_t *, vuint16m8_t, vint16m8_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vsuxei16_v)))
void vsuxei16_v_i16mf2(int16_t *, vuint16mf2_t, vint16mf2_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vsuxei16_v_m)))
void vsuxei16_v_i16mf2_m(vbool32_t, int16_t *, vuint16mf2_t, vint16mf2_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vsuxei16_v)))
void vsuxei16_v_i16mf4(int16_t *, vuint16mf4_t, vint16mf4_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vsuxei16_v_m)))
void vsuxei16_v_i16mf4_m(vbool64_t, int16_t *, vuint16mf4_t, vint16mf4_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vmerge_vvm)))
vuint8m1_t vmerge_vvm_u8m1(vbool8_t, vuint8m1_t, vuint8m1_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vmerge_vvm)))
vuint8m2_t vmerge_vvm_u8m2(vbool4_t, vuint8m2_t, vuint8m2_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vmerge_vvm)))
vuint8m4_t vmerge_vvm_u8m4(vbool2_t, vuint8m4_t, vuint8m4_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vmerge_vvm)))
vuint8m8_t vmerge_vvm_u8m8(vbool1_t, vuint8m8_t, vuint8m8_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vmerge_vvm)))
vuint8mf2_t vmerge_vvm_u8mf2(vbool16_t, vuint8mf2_t, vuint8mf2_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vmerge_vvm)))
vuint8mf4_t vmerge_vvm_u8mf4(vbool32_t, vuint8mf4_t, vuint8mf4_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vmerge_vvm)))
vuint8mf8_t vmerge_vvm_u8mf8(vbool64_t, vuint8mf8_t, vuint8mf8_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vmerge_vvm)))
vuint16m1_t vmerge_vvm_u16m1(vbool16_t, vuint16m1_t, vuint16m1_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vmerge_vvm)))
vuint16m2_t vmerge_vvm_u16m2(vbool8_t, vuint16m2_t, vuint16m2_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vmerge_vvm)))
vuint16m4_t vmerge_vvm_u16m4(vbool4_t, vuint16m4_t, vuint16m4_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vmerge_vvm)))
vuint16m8_t vmerge_vvm_u16m8(vbool2_t, vuint16m8_t, vuint16m8_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vmerge_vvm)))
vuint16mf2_t vmerge_vvm_u16mf2(vbool32_t, vuint16mf2_t, vuint16mf2_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vmerge_vvm)))
vuint16mf4_t vmerge_vvm_u16mf4(vbool64_t, vuint16mf4_t, vuint16mf4_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vmerge_vvm)))
vuint32m1_t vmerge_vvm_u32m1(vbool32_t, vuint32m1_t, vuint32m1_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vmerge_vvm)))
vuint32m2_t vmerge_vvm_u32m2(vbool16_t, vuint32m2_t, vuint32m2_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vmerge_vvm)))
vuint32m4_t vmerge_vvm_u32m4(vbool8_t, vuint32m4_t, vuint32m4_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vmerge_vvm)))
vuint32m8_t vmerge_vvm_u32m8(vbool4_t, vuint32m8_t, vuint32m8_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vmerge_vvm)))
vuint32mf2_t vmerge_vvm_u32mf2(vbool64_t, vuint32mf2_t, vuint32mf2_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vmerge_vxm)))
vuint8m1_t vmerge_vxm_u8m1(vbool8_t, vuint8m1_t, uint8_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vmerge_vxm)))
vuint8m2_t vmerge_vxm_u8m2(vbool4_t, vuint8m2_t, uint8_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vmerge_vxm)))
vuint8m4_t vmerge_vxm_u8m4(vbool2_t, vuint8m4_t, uint8_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vmerge_vxm)))
vuint8m8_t vmerge_vxm_u8m8(vbool1_t, vuint8m8_t, uint8_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vmerge_vxm)))
vuint8mf2_t vmerge_vxm_u8mf2(vbool16_t, vuint8mf2_t, uint8_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vmerge_vxm)))
vuint8mf4_t vmerge_vxm_u8mf4(vbool32_t, vuint8mf4_t, uint8_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vmerge_vxm)))
vuint8mf8_t vmerge_vxm_u8mf8(vbool64_t, vuint8mf8_t, uint8_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vmerge_vxm)))
vuint16m1_t vmerge_vxm_u16m1(vbool16_t, vuint16m1_t, uint16_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vmerge_vxm)))
vuint16m2_t vmerge_vxm_u16m2(vbool8_t, vuint16m2_t, uint16_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vmerge_vxm)))
vuint16m4_t vmerge_vxm_u16m4(vbool4_t, vuint16m4_t, uint16_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vmerge_vxm)))
vuint16m8_t vmerge_vxm_u16m8(vbool2_t, vuint16m8_t, uint16_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vmerge_vxm)))
vuint16mf2_t vmerge_vxm_u16mf2(vbool32_t, vuint16mf2_t, uint16_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vmerge_vxm)))
vuint16mf4_t vmerge_vxm_u16mf4(vbool64_t, vuint16mf4_t, uint16_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vmerge_vxm)))
vuint32m1_t vmerge_vxm_u32m1(vbool32_t, vuint32m1_t, uint32_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vmerge_vxm)))
vuint32m2_t vmerge_vxm_u32m2(vbool16_t, vuint32m2_t, uint32_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vmerge_vxm)))
vuint32m4_t vmerge_vxm_u32m4(vbool8_t, vuint32m4_t, uint32_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vmerge_vxm)))
vuint32m8_t vmerge_vxm_u32m8(vbool4_t, vuint32m8_t, uint32_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vmerge_vxm)))
vuint32mf2_t vmerge_vxm_u32mf2(vbool64_t, vuint32mf2_t, uint32_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vmv_v_v)))
vuint8m1_t vmv_v_v_u8m1(vuint8m1_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vmv_v_v)))
vuint8m2_t vmv_v_v_u8m2(vuint8m2_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vmv_v_v)))
vuint8m4_t vmv_v_v_u8m4(vuint8m4_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vmv_v_v)))
vuint8m8_t vmv_v_v_u8m8(vuint8m8_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vmv_v_v)))
vuint8mf2_t vmv_v_v_u8mf2(vuint8mf2_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vmv_v_v)))
vuint8mf4_t vmv_v_v_u8mf4(vuint8mf4_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vmv_v_v)))
vuint8mf8_t vmv_v_v_u8mf8(vuint8mf8_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vmv_v_v)))
vuint16m1_t vmv_v_v_u16m1(vuint16m1_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vmv_v_v)))
vuint16m2_t vmv_v_v_u16m2(vuint16m2_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vmv_v_v)))
vuint16m4_t vmv_v_v_u16m4(vuint16m4_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vmv_v_v)))
vuint16m8_t vmv_v_v_u16m8(vuint16m8_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vmv_v_v)))
vuint16mf2_t vmv_v_v_u16mf2(vuint16mf2_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vmv_v_v)))
vuint16mf4_t vmv_v_v_u16mf4(vuint16mf4_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vmv_v_v)))
vuint32m1_t vmv_v_v_u32m1(vuint32m1_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vmv_v_v)))
vuint32m2_t vmv_v_v_u32m2(vuint32m2_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vmv_v_v)))
vuint32m4_t vmv_v_v_u32m4(vuint32m4_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vmv_v_v)))
vuint32m8_t vmv_v_v_u32m8(vuint32m8_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vmv_v_v)))
vuint32mf2_t vmv_v_v_u32mf2(vuint32mf2_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vmv_v_v)))
vint8m1_t vmv_v_v_i8m1(vint8m1_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vmv_v_v)))
vint8m2_t vmv_v_v_i8m2(vint8m2_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vmv_v_v)))
vint8m4_t vmv_v_v_i8m4(vint8m4_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vmv_v_v)))
vint8m8_t vmv_v_v_i8m8(vint8m8_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vmv_v_v)))
vint8mf2_t vmv_v_v_i8mf2(vint8mf2_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vmv_v_v)))
vint8mf4_t vmv_v_v_i8mf4(vint8mf4_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vmv_v_v)))
vint8mf8_t vmv_v_v_i8mf8(vint8mf8_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vmv_v_v)))
vint16m1_t vmv_v_v_i16m1(vint16m1_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vmv_v_v)))
vint16m2_t vmv_v_v_i16m2(vint16m2_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vmv_v_v)))
vint16m4_t vmv_v_v_i16m4(vint16m4_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vmv_v_v)))
vint16m8_t vmv_v_v_i16m8(vint16m8_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vmv_v_v)))
vint16mf2_t vmv_v_v_i16mf2(vint16mf2_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vmv_v_v)))
vint16mf4_t vmv_v_v_i16mf4(vint16mf4_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vmv_v_v)))
vint32m1_t vmv_v_v_i32m1(vint32m1_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vmv_v_v)))
vint32m2_t vmv_v_v_i32m2(vint32m2_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vmv_v_v)))
vint32m4_t vmv_v_v_i32m4(vint32m4_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vmv_v_v)))
vint32m8_t vmv_v_v_i32m8(vint32m8_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vmv_v_v)))
vint32mf2_t vmv_v_v_i32mf2(vint32mf2_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vmv_v_x)))
vint8m1_t vmv_v_x_i8m1(int8_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vmv_v_x)))
vint8m2_t vmv_v_x_i8m2(int8_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vmv_v_x)))
vint8m4_t vmv_v_x_i8m4(int8_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vmv_v_x)))
vint8m8_t vmv_v_x_i8m8(int8_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vmv_v_x)))
vint8mf2_t vmv_v_x_i8mf2(int8_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vmv_v_x)))
vint8mf4_t vmv_v_x_i8mf4(int8_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vmv_v_x)))
vint8mf8_t vmv_v_x_i8mf8(int8_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vmv_v_x)))
vint16m1_t vmv_v_x_i16m1(int16_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vmv_v_x)))
vint16m2_t vmv_v_x_i16m2(int16_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vmv_v_x)))
vint16m4_t vmv_v_x_i16m4(int16_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vmv_v_x)))
vint16m8_t vmv_v_x_i16m8(int16_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vmv_v_x)))
vint16mf2_t vmv_v_x_i16mf2(int16_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vmv_v_x)))
vint16mf4_t vmv_v_x_i16mf4(int16_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vmv_v_x)))
vint32m1_t vmv_v_x_i32m1(int32_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vmv_v_x)))
vint32m2_t vmv_v_x_i32m2(int32_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vmv_v_x)))
vint32m4_t vmv_v_x_i32m4(int32_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vmv_v_x)))
vint32m8_t vmv_v_x_i32m8(int32_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vmv_v_x)))
vint32mf2_t vmv_v_x_i32mf2(int32_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vmv_v_x)))
vuint8m1_t vmv_v_x_u8m1(uint8_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vmv_v_x)))
vuint8m2_t vmv_v_x_u8m2(uint8_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vmv_v_x)))
vuint8m4_t vmv_v_x_u8m4(uint8_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vmv_v_x)))
vuint8m8_t vmv_v_x_u8m8(uint8_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vmv_v_x)))
vuint8mf2_t vmv_v_x_u8mf2(uint8_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vmv_v_x)))
vuint8mf4_t vmv_v_x_u8mf4(uint8_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vmv_v_x)))
vuint8mf8_t vmv_v_x_u8mf8(uint8_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vmv_v_x)))
vuint16m1_t vmv_v_x_u16m1(uint16_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vmv_v_x)))
vuint16m2_t vmv_v_x_u16m2(uint16_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vmv_v_x)))
vuint16m4_t vmv_v_x_u16m4(uint16_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vmv_v_x)))
vuint16m8_t vmv_v_x_u16m8(uint16_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vmv_v_x)))
vuint16mf2_t vmv_v_x_u16mf2(uint16_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vmv_v_x)))
vuint16mf4_t vmv_v_x_u16mf4(uint16_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vmv_v_x)))
vuint32m1_t vmv_v_x_u32m1(uint32_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vmv_v_x)))
vuint32m2_t vmv_v_x_u32m2(uint32_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vmv_v_x)))
vuint32m4_t vmv_v_x_u32m4(uint32_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vmv_v_x)))
vuint32m8_t vmv_v_x_u32m8(uint32_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vmv_v_x)))
vuint32mf2_t vmv_v_x_u32mf2(uint32_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vsaddu_vv)))
vuint8m1_t vsaddu_vv_u8m1(vuint8m1_t, vuint8m1_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vsaddu_vv_m)))
vuint8m1_t vsaddu_vv_u8m1_m(vbool8_t, vuint8m1_t, vuint8m1_t, vuint8m1_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vsaddu_vv)))
vuint8m2_t vsaddu_vv_u8m2(vuint8m2_t, vuint8m2_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vsaddu_vv_m)))
vuint8m2_t vsaddu_vv_u8m2_m(vbool4_t, vuint8m2_t, vuint8m2_t, vuint8m2_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vsaddu_vv)))
vuint8m4_t vsaddu_vv_u8m4(vuint8m4_t, vuint8m4_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vsaddu_vv_m)))
vuint8m4_t vsaddu_vv_u8m4_m(vbool2_t, vuint8m4_t, vuint8m4_t, vuint8m4_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vsaddu_vv)))
vuint8m8_t vsaddu_vv_u8m8(vuint8m8_t, vuint8m8_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vsaddu_vv_m)))
vuint8m8_t vsaddu_vv_u8m8_m(vbool1_t, vuint8m8_t, vuint8m8_t, vuint8m8_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vsaddu_vv)))
vuint8mf2_t vsaddu_vv_u8mf2(vuint8mf2_t, vuint8mf2_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vsaddu_vv_m)))
vuint8mf2_t vsaddu_vv_u8mf2_m(vbool16_t, vuint8mf2_t, vuint8mf2_t, vuint8mf2_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vsaddu_vv)))
vuint8mf4_t vsaddu_vv_u8mf4(vuint8mf4_t, vuint8mf4_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vsaddu_vv_m)))
vuint8mf4_t vsaddu_vv_u8mf4_m(vbool32_t, vuint8mf4_t, vuint8mf4_t, vuint8mf4_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vsaddu_vv)))
vuint8mf8_t vsaddu_vv_u8mf8(vuint8mf8_t, vuint8mf8_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vsaddu_vv_m)))
vuint8mf8_t vsaddu_vv_u8mf8_m(vbool64_t, vuint8mf8_t, vuint8mf8_t, vuint8mf8_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vsaddu_vv)))
vuint16m1_t vsaddu_vv_u16m1(vuint16m1_t, vuint16m1_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vsaddu_vv_m)))
vuint16m1_t vsaddu_vv_u16m1_m(vbool16_t, vuint16m1_t, vuint16m1_t, vuint16m1_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vsaddu_vv)))
vuint16m2_t vsaddu_vv_u16m2(vuint16m2_t, vuint16m2_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vsaddu_vv_m)))
vuint16m2_t vsaddu_vv_u16m2_m(vbool8_t, vuint16m2_t, vuint16m2_t, vuint16m2_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vsaddu_vv)))
vuint16m4_t vsaddu_vv_u16m4(vuint16m4_t, vuint16m4_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vsaddu_vv_m)))
vuint16m4_t vsaddu_vv_u16m4_m(vbool4_t, vuint16m4_t, vuint16m4_t, vuint16m4_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vsaddu_vv)))
vuint16m8_t vsaddu_vv_u16m8(vuint16m8_t, vuint16m8_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vsaddu_vv_m)))
vuint16m8_t vsaddu_vv_u16m8_m(vbool2_t, vuint16m8_t, vuint16m8_t, vuint16m8_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vsaddu_vv)))
vuint16mf2_t vsaddu_vv_u16mf2(vuint16mf2_t, vuint16mf2_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vsaddu_vv_m)))
vuint16mf2_t vsaddu_vv_u16mf2_m(vbool32_t, vuint16mf2_t, vuint16mf2_t, vuint16mf2_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vsaddu_vv)))
vuint16mf4_t vsaddu_vv_u16mf4(vuint16mf4_t, vuint16mf4_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vsaddu_vv_m)))
vuint16mf4_t vsaddu_vv_u16mf4_m(vbool64_t, vuint16mf4_t, vuint16mf4_t, vuint16mf4_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vsaddu_vv)))
vuint32m1_t vsaddu_vv_u32m1(vuint32m1_t, vuint32m1_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vsaddu_vv_m)))
vuint32m1_t vsaddu_vv_u32m1_m(vbool32_t, vuint32m1_t, vuint32m1_t, vuint32m1_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vsaddu_vv)))
vuint32m2_t vsaddu_vv_u32m2(vuint32m2_t, vuint32m2_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vsaddu_vv_m)))
vuint32m2_t vsaddu_vv_u32m2_m(vbool16_t, vuint32m2_t, vuint32m2_t, vuint32m2_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vsaddu_vv)))
vuint32m4_t vsaddu_vv_u32m4(vuint32m4_t, vuint32m4_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vsaddu_vv_m)))
vuint32m4_t vsaddu_vv_u32m4_m(vbool8_t, vuint32m4_t, vuint32m4_t, vuint32m4_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vsaddu_vv)))
vuint32m8_t vsaddu_vv_u32m8(vuint32m8_t, vuint32m8_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vsaddu_vv_m)))
vuint32m8_t vsaddu_vv_u32m8_m(vbool4_t, vuint32m8_t, vuint32m8_t, vuint32m8_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vsaddu_vv)))
vuint32mf2_t vsaddu_vv_u32mf2(vuint32mf2_t, vuint32mf2_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vsaddu_vv_m)))
vuint32mf2_t vsaddu_vv_u32mf2_m(vbool64_t, vuint32mf2_t, vuint32mf2_t, vuint32mf2_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vsaddu_vx)))
vuint8m1_t vsaddu_vx_u8m1(vuint8m1_t, uint8_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vsaddu_vx_m)))
vuint8m1_t vsaddu_vx_u8m1_m(vbool8_t, vuint8m1_t, vuint8m1_t, uint8_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vsaddu_vx)))
vuint8m2_t vsaddu_vx_u8m2(vuint8m2_t, uint8_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vsaddu_vx_m)))
vuint8m2_t vsaddu_vx_u8m2_m(vbool4_t, vuint8m2_t, vuint8m2_t, uint8_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vsaddu_vx)))
vuint8m4_t vsaddu_vx_u8m4(vuint8m4_t, uint8_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vsaddu_vx_m)))
vuint8m4_t vsaddu_vx_u8m4_m(vbool2_t, vuint8m4_t, vuint8m4_t, uint8_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vsaddu_vx)))
vuint8m8_t vsaddu_vx_u8m8(vuint8m8_t, uint8_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vsaddu_vx_m)))
vuint8m8_t vsaddu_vx_u8m8_m(vbool1_t, vuint8m8_t, vuint8m8_t, uint8_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vsaddu_vx)))
vuint8mf2_t vsaddu_vx_u8mf2(vuint8mf2_t, uint8_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vsaddu_vx_m)))
vuint8mf2_t vsaddu_vx_u8mf2_m(vbool16_t, vuint8mf2_t, vuint8mf2_t, uint8_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vsaddu_vx)))
vuint8mf4_t vsaddu_vx_u8mf4(vuint8mf4_t, uint8_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vsaddu_vx_m)))
vuint8mf4_t vsaddu_vx_u8mf4_m(vbool32_t, vuint8mf4_t, vuint8mf4_t, uint8_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vsaddu_vx)))
vuint8mf8_t vsaddu_vx_u8mf8(vuint8mf8_t, uint8_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vsaddu_vx_m)))
vuint8mf8_t vsaddu_vx_u8mf8_m(vbool64_t, vuint8mf8_t, vuint8mf8_t, uint8_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vsaddu_vx)))
vuint16m1_t vsaddu_vx_u16m1(vuint16m1_t, uint16_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vsaddu_vx_m)))
vuint16m1_t vsaddu_vx_u16m1_m(vbool16_t, vuint16m1_t, vuint16m1_t, uint16_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vsaddu_vx)))
vuint16m2_t vsaddu_vx_u16m2(vuint16m2_t, uint16_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vsaddu_vx_m)))
vuint16m2_t vsaddu_vx_u16m2_m(vbool8_t, vuint16m2_t, vuint16m2_t, uint16_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vsaddu_vx)))
vuint16m4_t vsaddu_vx_u16m4(vuint16m4_t, uint16_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vsaddu_vx_m)))
vuint16m4_t vsaddu_vx_u16m4_m(vbool4_t, vuint16m4_t, vuint16m4_t, uint16_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vsaddu_vx)))
vuint16m8_t vsaddu_vx_u16m8(vuint16m8_t, uint16_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vsaddu_vx_m)))
vuint16m8_t vsaddu_vx_u16m8_m(vbool2_t, vuint16m8_t, vuint16m8_t, uint16_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vsaddu_vx)))
vuint16mf2_t vsaddu_vx_u16mf2(vuint16mf2_t, uint16_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vsaddu_vx_m)))
vuint16mf2_t vsaddu_vx_u16mf2_m(vbool32_t, vuint16mf2_t, vuint16mf2_t, uint16_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vsaddu_vx)))
vuint16mf4_t vsaddu_vx_u16mf4(vuint16mf4_t, uint16_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vsaddu_vx_m)))
vuint16mf4_t vsaddu_vx_u16mf4_m(vbool64_t, vuint16mf4_t, vuint16mf4_t, uint16_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vsaddu_vx)))
vuint32m1_t vsaddu_vx_u32m1(vuint32m1_t, uint32_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vsaddu_vx_m)))
vuint32m1_t vsaddu_vx_u32m1_m(vbool32_t, vuint32m1_t, vuint32m1_t, uint32_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vsaddu_vx)))
vuint32m2_t vsaddu_vx_u32m2(vuint32m2_t, uint32_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vsaddu_vx_m)))
vuint32m2_t vsaddu_vx_u32m2_m(vbool16_t, vuint32m2_t, vuint32m2_t, uint32_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vsaddu_vx)))
vuint32m4_t vsaddu_vx_u32m4(vuint32m4_t, uint32_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vsaddu_vx_m)))
vuint32m4_t vsaddu_vx_u32m4_m(vbool8_t, vuint32m4_t, vuint32m4_t, uint32_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vsaddu_vx)))
vuint32m8_t vsaddu_vx_u32m8(vuint32m8_t, uint32_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vsaddu_vx_m)))
vuint32m8_t vsaddu_vx_u32m8_m(vbool4_t, vuint32m8_t, vuint32m8_t, uint32_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vsaddu_vx)))
vuint32mf2_t vsaddu_vx_u32mf2(vuint32mf2_t, uint32_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vsaddu_vx_m)))
vuint32mf2_t vsaddu_vx_u32mf2_m(vbool64_t, vuint32mf2_t, vuint32mf2_t, uint32_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vsadd_vv)))
vint8m1_t vsadd_vv_i8m1(vint8m1_t, vint8m1_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vsadd_vv_m)))
vint8m1_t vsadd_vv_i8m1_m(vbool8_t, vint8m1_t, vint8m1_t, vint8m1_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vsadd_vv)))
vint8m2_t vsadd_vv_i8m2(vint8m2_t, vint8m2_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vsadd_vv_m)))
vint8m2_t vsadd_vv_i8m2_m(vbool4_t, vint8m2_t, vint8m2_t, vint8m2_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vsadd_vv)))
vint8m4_t vsadd_vv_i8m4(vint8m4_t, vint8m4_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vsadd_vv_m)))
vint8m4_t vsadd_vv_i8m4_m(vbool2_t, vint8m4_t, vint8m4_t, vint8m4_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vsadd_vv)))
vint8m8_t vsadd_vv_i8m8(vint8m8_t, vint8m8_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vsadd_vv_m)))
vint8m8_t vsadd_vv_i8m8_m(vbool1_t, vint8m8_t, vint8m8_t, vint8m8_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vsadd_vv)))
vint8mf2_t vsadd_vv_i8mf2(vint8mf2_t, vint8mf2_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vsadd_vv_m)))
vint8mf2_t vsadd_vv_i8mf2_m(vbool16_t, vint8mf2_t, vint8mf2_t, vint8mf2_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vsadd_vv)))
vint8mf4_t vsadd_vv_i8mf4(vint8mf4_t, vint8mf4_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vsadd_vv_m)))
vint8mf4_t vsadd_vv_i8mf4_m(vbool32_t, vint8mf4_t, vint8mf4_t, vint8mf4_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vsadd_vv)))
vint8mf8_t vsadd_vv_i8mf8(vint8mf8_t, vint8mf8_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vsadd_vv_m)))
vint8mf8_t vsadd_vv_i8mf8_m(vbool64_t, vint8mf8_t, vint8mf8_t, vint8mf8_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vsadd_vv)))
vint16m1_t vsadd_vv_i16m1(vint16m1_t, vint16m1_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vsadd_vv_m)))
vint16m1_t vsadd_vv_i16m1_m(vbool16_t, vint16m1_t, vint16m1_t, vint16m1_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vsadd_vv)))
vint16m2_t vsadd_vv_i16m2(vint16m2_t, vint16m2_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vsadd_vv_m)))
vint16m2_t vsadd_vv_i16m2_m(vbool8_t, vint16m2_t, vint16m2_t, vint16m2_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vsadd_vv)))
vint16m4_t vsadd_vv_i16m4(vint16m4_t, vint16m4_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vsadd_vv_m)))
vint16m4_t vsadd_vv_i16m4_m(vbool4_t, vint16m4_t, vint16m4_t, vint16m4_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vsadd_vv)))
vint16m8_t vsadd_vv_i16m8(vint16m8_t, vint16m8_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vsadd_vv_m)))
vint16m8_t vsadd_vv_i16m8_m(vbool2_t, vint16m8_t, vint16m8_t, vint16m8_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vsadd_vv)))
vint16mf2_t vsadd_vv_i16mf2(vint16mf2_t, vint16mf2_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vsadd_vv_m)))
vint16mf2_t vsadd_vv_i16mf2_m(vbool32_t, vint16mf2_t, vint16mf2_t, vint16mf2_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vsadd_vv)))
vint16mf4_t vsadd_vv_i16mf4(vint16mf4_t, vint16mf4_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vsadd_vv_m)))
vint16mf4_t vsadd_vv_i16mf4_m(vbool64_t, vint16mf4_t, vint16mf4_t, vint16mf4_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vsadd_vv)))
vint32m1_t vsadd_vv_i32m1(vint32m1_t, vint32m1_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vsadd_vv_m)))
vint32m1_t vsadd_vv_i32m1_m(vbool32_t, vint32m1_t, vint32m1_t, vint32m1_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vsadd_vv)))
vint32m2_t vsadd_vv_i32m2(vint32m2_t, vint32m2_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vsadd_vv_m)))
vint32m2_t vsadd_vv_i32m2_m(vbool16_t, vint32m2_t, vint32m2_t, vint32m2_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vsadd_vv)))
vint32m4_t vsadd_vv_i32m4(vint32m4_t, vint32m4_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vsadd_vv_m)))
vint32m4_t vsadd_vv_i32m4_m(vbool8_t, vint32m4_t, vint32m4_t, vint32m4_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vsadd_vv)))
vint32m8_t vsadd_vv_i32m8(vint32m8_t, vint32m8_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vsadd_vv_m)))
vint32m8_t vsadd_vv_i32m8_m(vbool4_t, vint32m8_t, vint32m8_t, vint32m8_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vsadd_vv)))
vint32mf2_t vsadd_vv_i32mf2(vint32mf2_t, vint32mf2_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vsadd_vv_m)))
vint32mf2_t vsadd_vv_i32mf2_m(vbool64_t, vint32mf2_t, vint32mf2_t, vint32mf2_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vsadd_vx)))
vint8m1_t vsadd_vx_i8m1(vint8m1_t, int8_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vsadd_vx_m)))
vint8m1_t vsadd_vx_i8m1_m(vbool8_t, vint8m1_t, vint8m1_t, int8_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vsadd_vx)))
vint8m2_t vsadd_vx_i8m2(vint8m2_t, int8_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vsadd_vx_m)))
vint8m2_t vsadd_vx_i8m2_m(vbool4_t, vint8m2_t, vint8m2_t, int8_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vsadd_vx)))
vint8m4_t vsadd_vx_i8m4(vint8m4_t, int8_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vsadd_vx_m)))
vint8m4_t vsadd_vx_i8m4_m(vbool2_t, vint8m4_t, vint8m4_t, int8_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vsadd_vx)))
vint8m8_t vsadd_vx_i8m8(vint8m8_t, int8_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vsadd_vx_m)))
vint8m8_t vsadd_vx_i8m8_m(vbool1_t, vint8m8_t, vint8m8_t, int8_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vsadd_vx)))
vint8mf2_t vsadd_vx_i8mf2(vint8mf2_t, int8_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vsadd_vx_m)))
vint8mf2_t vsadd_vx_i8mf2_m(vbool16_t, vint8mf2_t, vint8mf2_t, int8_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vsadd_vx)))
vint8mf4_t vsadd_vx_i8mf4(vint8mf4_t, int8_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vsadd_vx_m)))
vint8mf4_t vsadd_vx_i8mf4_m(vbool32_t, vint8mf4_t, vint8mf4_t, int8_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vsadd_vx)))
vint8mf8_t vsadd_vx_i8mf8(vint8mf8_t, int8_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vsadd_vx_m)))
vint8mf8_t vsadd_vx_i8mf8_m(vbool64_t, vint8mf8_t, vint8mf8_t, int8_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vsadd_vx)))
vint16m1_t vsadd_vx_i16m1(vint16m1_t, int16_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vsadd_vx_m)))
vint16m1_t vsadd_vx_i16m1_m(vbool16_t, vint16m1_t, vint16m1_t, int16_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vsadd_vx)))
vint16m2_t vsadd_vx_i16m2(vint16m2_t, int16_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vsadd_vx_m)))
vint16m2_t vsadd_vx_i16m2_m(vbool8_t, vint16m2_t, vint16m2_t, int16_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vsadd_vx)))
vint16m4_t vsadd_vx_i16m4(vint16m4_t, int16_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vsadd_vx_m)))
vint16m4_t vsadd_vx_i16m4_m(vbool4_t, vint16m4_t, vint16m4_t, int16_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vsadd_vx)))
vint16m8_t vsadd_vx_i16m8(vint16m8_t, int16_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vsadd_vx_m)))
vint16m8_t vsadd_vx_i16m8_m(vbool2_t, vint16m8_t, vint16m8_t, int16_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vsadd_vx)))
vint16mf2_t vsadd_vx_i16mf2(vint16mf2_t, int16_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vsadd_vx_m)))
vint16mf2_t vsadd_vx_i16mf2_m(vbool32_t, vint16mf2_t, vint16mf2_t, int16_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vsadd_vx)))
vint16mf4_t vsadd_vx_i16mf4(vint16mf4_t, int16_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vsadd_vx_m)))
vint16mf4_t vsadd_vx_i16mf4_m(vbool64_t, vint16mf4_t, vint16mf4_t, int16_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vsadd_vx)))
vint32m1_t vsadd_vx_i32m1(vint32m1_t, int32_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vsadd_vx_m)))
vint32m1_t vsadd_vx_i32m1_m(vbool32_t, vint32m1_t, vint32m1_t, int32_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vsadd_vx)))
vint32m2_t vsadd_vx_i32m2(vint32m2_t, int32_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vsadd_vx_m)))
vint32m2_t vsadd_vx_i32m2_m(vbool16_t, vint32m2_t, vint32m2_t, int32_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vsadd_vx)))
vint32m4_t vsadd_vx_i32m4(vint32m4_t, int32_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vsadd_vx_m)))
vint32m4_t vsadd_vx_i32m4_m(vbool8_t, vint32m4_t, vint32m4_t, int32_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vsadd_vx)))
vint32m8_t vsadd_vx_i32m8(vint32m8_t, int32_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vsadd_vx_m)))
vint32m8_t vsadd_vx_i32m8_m(vbool4_t, vint32m8_t, vint32m8_t, int32_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vsadd_vx)))
vint32mf2_t vsadd_vx_i32mf2(vint32mf2_t, int32_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vsadd_vx_m)))
vint32mf2_t vsadd_vx_i32mf2_m(vbool64_t, vint32mf2_t, vint32mf2_t, int32_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vsuxei16_v)))
void vsuxei16_v_u16m1(uint16_t *, vuint16m1_t, vuint16m1_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vsuxei16_v_m)))
void vsuxei16_v_u16m1_m(vbool16_t, uint16_t *, vuint16m1_t, vuint16m1_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vsuxei16_v)))
void vsuxei16_v_u16m2(uint16_t *, vuint16m2_t, vuint16m2_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vsuxei16_v_m)))
void vsuxei16_v_u16m2_m(vbool8_t, uint16_t *, vuint16m2_t, vuint16m2_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vsuxei16_v)))
void vsuxei16_v_u16m4(uint16_t *, vuint16m4_t, vuint16m4_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vsuxei16_v_m)))
void vsuxei16_v_u16m4_m(vbool4_t, uint16_t *, vuint16m4_t, vuint16m4_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vsuxei16_v)))
void vsuxei16_v_u16m8(uint16_t *, vuint16m8_t, vuint16m8_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vsuxei16_v_m)))
void vsuxei16_v_u16m8_m(vbool2_t, uint16_t *, vuint16m8_t, vuint16m8_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vsuxei16_v)))
void vsuxei16_v_u16mf2(uint16_t *, vuint16mf2_t, vuint16mf2_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vsuxei16_v_m)))
void vsuxei16_v_u16mf2_m(vbool32_t, uint16_t *, vuint16mf2_t, vuint16mf2_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vsuxei16_v)))
void vsuxei16_v_u16mf4(uint16_t *, vuint16mf4_t, vuint16mf4_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vsuxei16_v_m)))
void vsuxei16_v_u16mf4_m(vbool64_t, uint16_t *, vuint16mf4_t, vuint16mf4_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vssubu_vv)))
vuint8m1_t vssubu_vv_u8m1(vuint8m1_t, vuint8m1_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vssubu_vv_m)))
vuint8m1_t vssubu_vv_u8m1_m(vbool8_t, vuint8m1_t, vuint8m1_t, vuint8m1_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vssubu_vv)))
vuint8m2_t vssubu_vv_u8m2(vuint8m2_t, vuint8m2_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vssubu_vv_m)))
vuint8m2_t vssubu_vv_u8m2_m(vbool4_t, vuint8m2_t, vuint8m2_t, vuint8m2_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vssubu_vv)))
vuint8m4_t vssubu_vv_u8m4(vuint8m4_t, vuint8m4_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vssubu_vv_m)))
vuint8m4_t vssubu_vv_u8m4_m(vbool2_t, vuint8m4_t, vuint8m4_t, vuint8m4_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vssubu_vv)))
vuint8m8_t vssubu_vv_u8m8(vuint8m8_t, vuint8m8_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vssubu_vv_m)))
vuint8m8_t vssubu_vv_u8m8_m(vbool1_t, vuint8m8_t, vuint8m8_t, vuint8m8_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vssubu_vv)))
vuint8mf2_t vssubu_vv_u8mf2(vuint8mf2_t, vuint8mf2_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vssubu_vv_m)))
vuint8mf2_t vssubu_vv_u8mf2_m(vbool16_t, vuint8mf2_t, vuint8mf2_t, vuint8mf2_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vssubu_vv)))
vuint8mf4_t vssubu_vv_u8mf4(vuint8mf4_t, vuint8mf4_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vssubu_vv_m)))
vuint8mf4_t vssubu_vv_u8mf4_m(vbool32_t, vuint8mf4_t, vuint8mf4_t, vuint8mf4_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vssubu_vv)))
vuint8mf8_t vssubu_vv_u8mf8(vuint8mf8_t, vuint8mf8_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vssubu_vv_m)))
vuint8mf8_t vssubu_vv_u8mf8_m(vbool64_t, vuint8mf8_t, vuint8mf8_t, vuint8mf8_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vssubu_vv)))
vuint16m1_t vssubu_vv_u16m1(vuint16m1_t, vuint16m1_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vssubu_vv_m)))
vuint16m1_t vssubu_vv_u16m1_m(vbool16_t, vuint16m1_t, vuint16m1_t, vuint16m1_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vssubu_vv)))
vuint16m2_t vssubu_vv_u16m2(vuint16m2_t, vuint16m2_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vssubu_vv_m)))
vuint16m2_t vssubu_vv_u16m2_m(vbool8_t, vuint16m2_t, vuint16m2_t, vuint16m2_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vssubu_vv)))
vuint16m4_t vssubu_vv_u16m4(vuint16m4_t, vuint16m4_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vssubu_vv_m)))
vuint16m4_t vssubu_vv_u16m4_m(vbool4_t, vuint16m4_t, vuint16m4_t, vuint16m4_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vssubu_vv)))
vuint16m8_t vssubu_vv_u16m8(vuint16m8_t, vuint16m8_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vssubu_vv_m)))
vuint16m8_t vssubu_vv_u16m8_m(vbool2_t, vuint16m8_t, vuint16m8_t, vuint16m8_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vssubu_vv)))
vuint16mf2_t vssubu_vv_u16mf2(vuint16mf2_t, vuint16mf2_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vssubu_vv_m)))
vuint16mf2_t vssubu_vv_u16mf2_m(vbool32_t, vuint16mf2_t, vuint16mf2_t, vuint16mf2_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vssubu_vv)))
vuint16mf4_t vssubu_vv_u16mf4(vuint16mf4_t, vuint16mf4_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vssubu_vv_m)))
vuint16mf4_t vssubu_vv_u16mf4_m(vbool64_t, vuint16mf4_t, vuint16mf4_t, vuint16mf4_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vssubu_vv)))
vuint32m1_t vssubu_vv_u32m1(vuint32m1_t, vuint32m1_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vssubu_vv_m)))
vuint32m1_t vssubu_vv_u32m1_m(vbool32_t, vuint32m1_t, vuint32m1_t, vuint32m1_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vssubu_vv)))
vuint32m2_t vssubu_vv_u32m2(vuint32m2_t, vuint32m2_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vssubu_vv_m)))
vuint32m2_t vssubu_vv_u32m2_m(vbool16_t, vuint32m2_t, vuint32m2_t, vuint32m2_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vssubu_vv)))
vuint32m4_t vssubu_vv_u32m4(vuint32m4_t, vuint32m4_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vssubu_vv_m)))
vuint32m4_t vssubu_vv_u32m4_m(vbool8_t, vuint32m4_t, vuint32m4_t, vuint32m4_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vssubu_vv)))
vuint32m8_t vssubu_vv_u32m8(vuint32m8_t, vuint32m8_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vssubu_vv_m)))
vuint32m8_t vssubu_vv_u32m8_m(vbool4_t, vuint32m8_t, vuint32m8_t, vuint32m8_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vssubu_vv)))
vuint32mf2_t vssubu_vv_u32mf2(vuint32mf2_t, vuint32mf2_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vssubu_vv_m)))
vuint32mf2_t vssubu_vv_u32mf2_m(vbool64_t, vuint32mf2_t, vuint32mf2_t, vuint32mf2_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vssubu_vx)))
vuint8m1_t vssubu_vx_u8m1(vuint8m1_t, uint8_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vssubu_vx_m)))
vuint8m1_t vssubu_vx_u8m1_m(vbool8_t, vuint8m1_t, vuint8m1_t, uint8_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vssubu_vx)))
vuint8m2_t vssubu_vx_u8m2(vuint8m2_t, uint8_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vssubu_vx_m)))
vuint8m2_t vssubu_vx_u8m2_m(vbool4_t, vuint8m2_t, vuint8m2_t, uint8_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vssubu_vx)))
vuint8m4_t vssubu_vx_u8m4(vuint8m4_t, uint8_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vssubu_vx_m)))
vuint8m4_t vssubu_vx_u8m4_m(vbool2_t, vuint8m4_t, vuint8m4_t, uint8_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vssubu_vx)))
vuint8m8_t vssubu_vx_u8m8(vuint8m8_t, uint8_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vssubu_vx_m)))
vuint8m8_t vssubu_vx_u8m8_m(vbool1_t, vuint8m8_t, vuint8m8_t, uint8_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vssubu_vx)))
vuint8mf2_t vssubu_vx_u8mf2(vuint8mf2_t, uint8_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vssubu_vx_m)))
vuint8mf2_t vssubu_vx_u8mf2_m(vbool16_t, vuint8mf2_t, vuint8mf2_t, uint8_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vssubu_vx)))
vuint8mf4_t vssubu_vx_u8mf4(vuint8mf4_t, uint8_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vssubu_vx_m)))
vuint8mf4_t vssubu_vx_u8mf4_m(vbool32_t, vuint8mf4_t, vuint8mf4_t, uint8_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vssubu_vx)))
vuint8mf8_t vssubu_vx_u8mf8(vuint8mf8_t, uint8_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vssubu_vx_m)))
vuint8mf8_t vssubu_vx_u8mf8_m(vbool64_t, vuint8mf8_t, vuint8mf8_t, uint8_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vssubu_vx)))
vuint16m1_t vssubu_vx_u16m1(vuint16m1_t, uint16_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vssubu_vx_m)))
vuint16m1_t vssubu_vx_u16m1_m(vbool16_t, vuint16m1_t, vuint16m1_t, uint16_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vssubu_vx)))
vuint16m2_t vssubu_vx_u16m2(vuint16m2_t, uint16_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vssubu_vx_m)))
vuint16m2_t vssubu_vx_u16m2_m(vbool8_t, vuint16m2_t, vuint16m2_t, uint16_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vssubu_vx)))
vuint16m4_t vssubu_vx_u16m4(vuint16m4_t, uint16_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vssubu_vx_m)))
vuint16m4_t vssubu_vx_u16m4_m(vbool4_t, vuint16m4_t, vuint16m4_t, uint16_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vssubu_vx)))
vuint16m8_t vssubu_vx_u16m8(vuint16m8_t, uint16_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vssubu_vx_m)))
vuint16m8_t vssubu_vx_u16m8_m(vbool2_t, vuint16m8_t, vuint16m8_t, uint16_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vssubu_vx)))
vuint16mf2_t vssubu_vx_u16mf2(vuint16mf2_t, uint16_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vssubu_vx_m)))
vuint16mf2_t vssubu_vx_u16mf2_m(vbool32_t, vuint16mf2_t, vuint16mf2_t, uint16_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vssubu_vx)))
vuint16mf4_t vssubu_vx_u16mf4(vuint16mf4_t, uint16_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vssubu_vx_m)))
vuint16mf4_t vssubu_vx_u16mf4_m(vbool64_t, vuint16mf4_t, vuint16mf4_t, uint16_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vssubu_vx)))
vuint32m1_t vssubu_vx_u32m1(vuint32m1_t, uint32_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vssubu_vx_m)))
vuint32m1_t vssubu_vx_u32m1_m(vbool32_t, vuint32m1_t, vuint32m1_t, uint32_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vssubu_vx)))
vuint32m2_t vssubu_vx_u32m2(vuint32m2_t, uint32_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vssubu_vx_m)))
vuint32m2_t vssubu_vx_u32m2_m(vbool16_t, vuint32m2_t, vuint32m2_t, uint32_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vssubu_vx)))
vuint32m4_t vssubu_vx_u32m4(vuint32m4_t, uint32_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vssubu_vx_m)))
vuint32m4_t vssubu_vx_u32m4_m(vbool8_t, vuint32m4_t, vuint32m4_t, uint32_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vssubu_vx)))
vuint32m8_t vssubu_vx_u32m8(vuint32m8_t, uint32_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vssubu_vx_m)))
vuint32m8_t vssubu_vx_u32m8_m(vbool4_t, vuint32m8_t, vuint32m8_t, uint32_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vssubu_vx)))
vuint32mf2_t vssubu_vx_u32mf2(vuint32mf2_t, uint32_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vssubu_vx_m)))
vuint32mf2_t vssubu_vx_u32mf2_m(vbool64_t, vuint32mf2_t, vuint32mf2_t, uint32_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vssub_vv)))
vint8m1_t vssub_vv_i8m1(vint8m1_t, vint8m1_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vssub_vv_m)))
vint8m1_t vssub_vv_i8m1_m(vbool8_t, vint8m1_t, vint8m1_t, vint8m1_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vssub_vv)))
vint8m2_t vssub_vv_i8m2(vint8m2_t, vint8m2_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vssub_vv_m)))
vint8m2_t vssub_vv_i8m2_m(vbool4_t, vint8m2_t, vint8m2_t, vint8m2_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vssub_vv)))
vint8m4_t vssub_vv_i8m4(vint8m4_t, vint8m4_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vssub_vv_m)))
vint8m4_t vssub_vv_i8m4_m(vbool2_t, vint8m4_t, vint8m4_t, vint8m4_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vssub_vv)))
vint8m8_t vssub_vv_i8m8(vint8m8_t, vint8m8_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vssub_vv_m)))
vint8m8_t vssub_vv_i8m8_m(vbool1_t, vint8m8_t, vint8m8_t, vint8m8_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vssub_vv)))
vint8mf2_t vssub_vv_i8mf2(vint8mf2_t, vint8mf2_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vssub_vv_m)))
vint8mf2_t vssub_vv_i8mf2_m(vbool16_t, vint8mf2_t, vint8mf2_t, vint8mf2_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vssub_vv)))
vint8mf4_t vssub_vv_i8mf4(vint8mf4_t, vint8mf4_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vssub_vv_m)))
vint8mf4_t vssub_vv_i8mf4_m(vbool32_t, vint8mf4_t, vint8mf4_t, vint8mf4_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vssub_vv)))
vint8mf8_t vssub_vv_i8mf8(vint8mf8_t, vint8mf8_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vssub_vv_m)))
vint8mf8_t vssub_vv_i8mf8_m(vbool64_t, vint8mf8_t, vint8mf8_t, vint8mf8_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vssub_vv)))
vint16m1_t vssub_vv_i16m1(vint16m1_t, vint16m1_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vssub_vv_m)))
vint16m1_t vssub_vv_i16m1_m(vbool16_t, vint16m1_t, vint16m1_t, vint16m1_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vssub_vv)))
vint16m2_t vssub_vv_i16m2(vint16m2_t, vint16m2_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vssub_vv_m)))
vint16m2_t vssub_vv_i16m2_m(vbool8_t, vint16m2_t, vint16m2_t, vint16m2_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vssub_vv)))
vint16m4_t vssub_vv_i16m4(vint16m4_t, vint16m4_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vssub_vv_m)))
vint16m4_t vssub_vv_i16m4_m(vbool4_t, vint16m4_t, vint16m4_t, vint16m4_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vssub_vv)))
vint16m8_t vssub_vv_i16m8(vint16m8_t, vint16m8_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vssub_vv_m)))
vint16m8_t vssub_vv_i16m8_m(vbool2_t, vint16m8_t, vint16m8_t, vint16m8_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vssub_vv)))
vint16mf2_t vssub_vv_i16mf2(vint16mf2_t, vint16mf2_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vssub_vv_m)))
vint16mf2_t vssub_vv_i16mf2_m(vbool32_t, vint16mf2_t, vint16mf2_t, vint16mf2_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vssub_vv)))
vint16mf4_t vssub_vv_i16mf4(vint16mf4_t, vint16mf4_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vssub_vv_m)))
vint16mf4_t vssub_vv_i16mf4_m(vbool64_t, vint16mf4_t, vint16mf4_t, vint16mf4_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vssub_vv)))
vint32m1_t vssub_vv_i32m1(vint32m1_t, vint32m1_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vssub_vv_m)))
vint32m1_t vssub_vv_i32m1_m(vbool32_t, vint32m1_t, vint32m1_t, vint32m1_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vssub_vv)))
vint32m2_t vssub_vv_i32m2(vint32m2_t, vint32m2_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vssub_vv_m)))
vint32m2_t vssub_vv_i32m2_m(vbool16_t, vint32m2_t, vint32m2_t, vint32m2_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vssub_vv)))
vint32m4_t vssub_vv_i32m4(vint32m4_t, vint32m4_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vssub_vv_m)))
vint32m4_t vssub_vv_i32m4_m(vbool8_t, vint32m4_t, vint32m4_t, vint32m4_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vssub_vv)))
vint32m8_t vssub_vv_i32m8(vint32m8_t, vint32m8_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vssub_vv_m)))
vint32m8_t vssub_vv_i32m8_m(vbool4_t, vint32m8_t, vint32m8_t, vint32m8_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vssub_vv)))
vint32mf2_t vssub_vv_i32mf2(vint32mf2_t, vint32mf2_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vssub_vv_m)))
vint32mf2_t vssub_vv_i32mf2_m(vbool64_t, vint32mf2_t, vint32mf2_t, vint32mf2_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vssub_vx)))
vint8m1_t vssub_vx_i8m1(vint8m1_t, int8_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vssub_vx_m)))
vint8m1_t vssub_vx_i8m1_m(vbool8_t, vint8m1_t, vint8m1_t, int8_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vssub_vx)))
vint8m2_t vssub_vx_i8m2(vint8m2_t, int8_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vssub_vx_m)))
vint8m2_t vssub_vx_i8m2_m(vbool4_t, vint8m2_t, vint8m2_t, int8_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vssub_vx)))
vint8m4_t vssub_vx_i8m4(vint8m4_t, int8_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vssub_vx_m)))
vint8m4_t vssub_vx_i8m4_m(vbool2_t, vint8m4_t, vint8m4_t, int8_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vssub_vx)))
vint8m8_t vssub_vx_i8m8(vint8m8_t, int8_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vssub_vx_m)))
vint8m8_t vssub_vx_i8m8_m(vbool1_t, vint8m8_t, vint8m8_t, int8_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vssub_vx)))
vint8mf2_t vssub_vx_i8mf2(vint8mf2_t, int8_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vssub_vx_m)))
vint8mf2_t vssub_vx_i8mf2_m(vbool16_t, vint8mf2_t, vint8mf2_t, int8_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vssub_vx)))
vint8mf4_t vssub_vx_i8mf4(vint8mf4_t, int8_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vssub_vx_m)))
vint8mf4_t vssub_vx_i8mf4_m(vbool32_t, vint8mf4_t, vint8mf4_t, int8_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vssub_vx)))
vint8mf8_t vssub_vx_i8mf8(vint8mf8_t, int8_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vssub_vx_m)))
vint8mf8_t vssub_vx_i8mf8_m(vbool64_t, vint8mf8_t, vint8mf8_t, int8_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vssub_vx)))
vint16m1_t vssub_vx_i16m1(vint16m1_t, int16_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vssub_vx_m)))
vint16m1_t vssub_vx_i16m1_m(vbool16_t, vint16m1_t, vint16m1_t, int16_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vssub_vx)))
vint16m2_t vssub_vx_i16m2(vint16m2_t, int16_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vssub_vx_m)))
vint16m2_t vssub_vx_i16m2_m(vbool8_t, vint16m2_t, vint16m2_t, int16_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vssub_vx)))
vint16m4_t vssub_vx_i16m4(vint16m4_t, int16_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vssub_vx_m)))
vint16m4_t vssub_vx_i16m4_m(vbool4_t, vint16m4_t, vint16m4_t, int16_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vssub_vx)))
vint16m8_t vssub_vx_i16m8(vint16m8_t, int16_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vssub_vx_m)))
vint16m8_t vssub_vx_i16m8_m(vbool2_t, vint16m8_t, vint16m8_t, int16_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vssub_vx)))
vint16mf2_t vssub_vx_i16mf2(vint16mf2_t, int16_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vssub_vx_m)))
vint16mf2_t vssub_vx_i16mf2_m(vbool32_t, vint16mf2_t, vint16mf2_t, int16_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vssub_vx)))
vint16mf4_t vssub_vx_i16mf4(vint16mf4_t, int16_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vssub_vx_m)))
vint16mf4_t vssub_vx_i16mf4_m(vbool64_t, vint16mf4_t, vint16mf4_t, int16_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vssub_vx)))
vint32m1_t vssub_vx_i32m1(vint32m1_t, int32_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vssub_vx_m)))
vint32m1_t vssub_vx_i32m1_m(vbool32_t, vint32m1_t, vint32m1_t, int32_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vssub_vx)))
vint32m2_t vssub_vx_i32m2(vint32m2_t, int32_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vssub_vx_m)))
vint32m2_t vssub_vx_i32m2_m(vbool16_t, vint32m2_t, vint32m2_t, int32_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vssub_vx)))
vint32m4_t vssub_vx_i32m4(vint32m4_t, int32_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vssub_vx_m)))
vint32m4_t vssub_vx_i32m4_m(vbool8_t, vint32m4_t, vint32m4_t, int32_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vssub_vx)))
vint32m8_t vssub_vx_i32m8(vint32m8_t, int32_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vssub_vx_m)))
vint32m8_t vssub_vx_i32m8_m(vbool4_t, vint32m8_t, vint32m8_t, int32_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vssub_vx)))
vint32mf2_t vssub_vx_i32mf2(vint32mf2_t, int32_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vssub_vx_m)))
vint32mf2_t vssub_vx_i32mf2_m(vbool64_t, vint32mf2_t, vint32mf2_t, int32_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vaaddu_vv)))
vuint8m1_t vaaddu_vv_u8m1(vuint8m1_t, vuint8m1_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vaaddu_vv_m)))
vuint8m1_t vaaddu_vv_u8m1_m(vbool8_t, vuint8m1_t, vuint8m1_t, vuint8m1_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vaaddu_vv)))
vuint8m2_t vaaddu_vv_u8m2(vuint8m2_t, vuint8m2_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vaaddu_vv_m)))
vuint8m2_t vaaddu_vv_u8m2_m(vbool4_t, vuint8m2_t, vuint8m2_t, vuint8m2_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vaaddu_vv)))
vuint8m4_t vaaddu_vv_u8m4(vuint8m4_t, vuint8m4_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vaaddu_vv_m)))
vuint8m4_t vaaddu_vv_u8m4_m(vbool2_t, vuint8m4_t, vuint8m4_t, vuint8m4_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vaaddu_vv)))
vuint8m8_t vaaddu_vv_u8m8(vuint8m8_t, vuint8m8_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vaaddu_vv_m)))
vuint8m8_t vaaddu_vv_u8m8_m(vbool1_t, vuint8m8_t, vuint8m8_t, vuint8m8_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vaaddu_vv)))
vuint8mf2_t vaaddu_vv_u8mf2(vuint8mf2_t, vuint8mf2_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vaaddu_vv_m)))
vuint8mf2_t vaaddu_vv_u8mf2_m(vbool16_t, vuint8mf2_t, vuint8mf2_t, vuint8mf2_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vaaddu_vv)))
vuint8mf4_t vaaddu_vv_u8mf4(vuint8mf4_t, vuint8mf4_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vaaddu_vv_m)))
vuint8mf4_t vaaddu_vv_u8mf4_m(vbool32_t, vuint8mf4_t, vuint8mf4_t, vuint8mf4_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vaaddu_vv)))
vuint8mf8_t vaaddu_vv_u8mf8(vuint8mf8_t, vuint8mf8_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vaaddu_vv_m)))
vuint8mf8_t vaaddu_vv_u8mf8_m(vbool64_t, vuint8mf8_t, vuint8mf8_t, vuint8mf8_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vaaddu_vv)))
vuint16m1_t vaaddu_vv_u16m1(vuint16m1_t, vuint16m1_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vaaddu_vv_m)))
vuint16m1_t vaaddu_vv_u16m1_m(vbool16_t, vuint16m1_t, vuint16m1_t, vuint16m1_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vaaddu_vv)))
vuint16m2_t vaaddu_vv_u16m2(vuint16m2_t, vuint16m2_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vaaddu_vv_m)))
vuint16m2_t vaaddu_vv_u16m2_m(vbool8_t, vuint16m2_t, vuint16m2_t, vuint16m2_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vaaddu_vv)))
vuint16m4_t vaaddu_vv_u16m4(vuint16m4_t, vuint16m4_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vaaddu_vv_m)))
vuint16m4_t vaaddu_vv_u16m4_m(vbool4_t, vuint16m4_t, vuint16m4_t, vuint16m4_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vaaddu_vv)))
vuint16m8_t vaaddu_vv_u16m8(vuint16m8_t, vuint16m8_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vaaddu_vv_m)))
vuint16m8_t vaaddu_vv_u16m8_m(vbool2_t, vuint16m8_t, vuint16m8_t, vuint16m8_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vaaddu_vv)))
vuint16mf2_t vaaddu_vv_u16mf2(vuint16mf2_t, vuint16mf2_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vaaddu_vv_m)))
vuint16mf2_t vaaddu_vv_u16mf2_m(vbool32_t, vuint16mf2_t, vuint16mf2_t, vuint16mf2_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vaaddu_vv)))
vuint16mf4_t vaaddu_vv_u16mf4(vuint16mf4_t, vuint16mf4_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vaaddu_vv_m)))
vuint16mf4_t vaaddu_vv_u16mf4_m(vbool64_t, vuint16mf4_t, vuint16mf4_t, vuint16mf4_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vaaddu_vv)))
vuint32m1_t vaaddu_vv_u32m1(vuint32m1_t, vuint32m1_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vaaddu_vv_m)))
vuint32m1_t vaaddu_vv_u32m1_m(vbool32_t, vuint32m1_t, vuint32m1_t, vuint32m1_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vaaddu_vv)))
vuint32m2_t vaaddu_vv_u32m2(vuint32m2_t, vuint32m2_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vaaddu_vv_m)))
vuint32m2_t vaaddu_vv_u32m2_m(vbool16_t, vuint32m2_t, vuint32m2_t, vuint32m2_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vaaddu_vv)))
vuint32m4_t vaaddu_vv_u32m4(vuint32m4_t, vuint32m4_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vaaddu_vv_m)))
vuint32m4_t vaaddu_vv_u32m4_m(vbool8_t, vuint32m4_t, vuint32m4_t, vuint32m4_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vaaddu_vv)))
vuint32m8_t vaaddu_vv_u32m8(vuint32m8_t, vuint32m8_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vaaddu_vv_m)))
vuint32m8_t vaaddu_vv_u32m8_m(vbool4_t, vuint32m8_t, vuint32m8_t, vuint32m8_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vaaddu_vv)))
vuint32mf2_t vaaddu_vv_u32mf2(vuint32mf2_t, vuint32mf2_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vaaddu_vv_m)))
vuint32mf2_t vaaddu_vv_u32mf2_m(vbool64_t, vuint32mf2_t, vuint32mf2_t, vuint32mf2_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vaaddu_vx)))
vuint8m1_t vaaddu_vx_u8m1(vuint8m1_t, uint8_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vaaddu_vx_m)))
vuint8m1_t vaaddu_vx_u8m1_m(vbool8_t, vuint8m1_t, vuint8m1_t, uint8_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vaaddu_vx)))
vuint8m2_t vaaddu_vx_u8m2(vuint8m2_t, uint8_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vaaddu_vx_m)))
vuint8m2_t vaaddu_vx_u8m2_m(vbool4_t, vuint8m2_t, vuint8m2_t, uint8_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vaaddu_vx)))
vuint8m4_t vaaddu_vx_u8m4(vuint8m4_t, uint8_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vaaddu_vx_m)))
vuint8m4_t vaaddu_vx_u8m4_m(vbool2_t, vuint8m4_t, vuint8m4_t, uint8_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vaaddu_vx)))
vuint8m8_t vaaddu_vx_u8m8(vuint8m8_t, uint8_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vaaddu_vx_m)))
vuint8m8_t vaaddu_vx_u8m8_m(vbool1_t, vuint8m8_t, vuint8m8_t, uint8_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vaaddu_vx)))
vuint8mf2_t vaaddu_vx_u8mf2(vuint8mf2_t, uint8_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vaaddu_vx_m)))
vuint8mf2_t vaaddu_vx_u8mf2_m(vbool16_t, vuint8mf2_t, vuint8mf2_t, uint8_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vaaddu_vx)))
vuint8mf4_t vaaddu_vx_u8mf4(vuint8mf4_t, uint8_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vaaddu_vx_m)))
vuint8mf4_t vaaddu_vx_u8mf4_m(vbool32_t, vuint8mf4_t, vuint8mf4_t, uint8_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vaaddu_vx)))
vuint8mf8_t vaaddu_vx_u8mf8(vuint8mf8_t, uint8_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vaaddu_vx_m)))
vuint8mf8_t vaaddu_vx_u8mf8_m(vbool64_t, vuint8mf8_t, vuint8mf8_t, uint8_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vaaddu_vx)))
vuint16m1_t vaaddu_vx_u16m1(vuint16m1_t, uint16_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vaaddu_vx_m)))
vuint16m1_t vaaddu_vx_u16m1_m(vbool16_t, vuint16m1_t, vuint16m1_t, uint16_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vaaddu_vx)))
vuint16m2_t vaaddu_vx_u16m2(vuint16m2_t, uint16_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vaaddu_vx_m)))
vuint16m2_t vaaddu_vx_u16m2_m(vbool8_t, vuint16m2_t, vuint16m2_t, uint16_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vaaddu_vx)))
vuint16m4_t vaaddu_vx_u16m4(vuint16m4_t, uint16_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vaaddu_vx_m)))
vuint16m4_t vaaddu_vx_u16m4_m(vbool4_t, vuint16m4_t, vuint16m4_t, uint16_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vaaddu_vx)))
vuint16m8_t vaaddu_vx_u16m8(vuint16m8_t, uint16_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vaaddu_vx_m)))
vuint16m8_t vaaddu_vx_u16m8_m(vbool2_t, vuint16m8_t, vuint16m8_t, uint16_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vaaddu_vx)))
vuint16mf2_t vaaddu_vx_u16mf2(vuint16mf2_t, uint16_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vaaddu_vx_m)))
vuint16mf2_t vaaddu_vx_u16mf2_m(vbool32_t, vuint16mf2_t, vuint16mf2_t, uint16_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vaaddu_vx)))
vuint16mf4_t vaaddu_vx_u16mf4(vuint16mf4_t, uint16_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vaaddu_vx_m)))
vuint16mf4_t vaaddu_vx_u16mf4_m(vbool64_t, vuint16mf4_t, vuint16mf4_t, uint16_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vaaddu_vx)))
vuint32m1_t vaaddu_vx_u32m1(vuint32m1_t, uint32_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vaaddu_vx_m)))
vuint32m1_t vaaddu_vx_u32m1_m(vbool32_t, vuint32m1_t, vuint32m1_t, uint32_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vaaddu_vx)))
vuint32m2_t vaaddu_vx_u32m2(vuint32m2_t, uint32_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vaaddu_vx_m)))
vuint32m2_t vaaddu_vx_u32m2_m(vbool16_t, vuint32m2_t, vuint32m2_t, uint32_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vaaddu_vx)))
vuint32m4_t vaaddu_vx_u32m4(vuint32m4_t, uint32_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vaaddu_vx_m)))
vuint32m4_t vaaddu_vx_u32m4_m(vbool8_t, vuint32m4_t, vuint32m4_t, uint32_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vaaddu_vx)))
vuint32m8_t vaaddu_vx_u32m8(vuint32m8_t, uint32_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vaaddu_vx_m)))
vuint32m8_t vaaddu_vx_u32m8_m(vbool4_t, vuint32m8_t, vuint32m8_t, uint32_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vaaddu_vx)))
vuint32mf2_t vaaddu_vx_u32mf2(vuint32mf2_t, uint32_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vaaddu_vx_m)))
vuint32mf2_t vaaddu_vx_u32mf2_m(vbool64_t, vuint32mf2_t, vuint32mf2_t, uint32_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vaadd_vv)))
vint8m1_t vaadd_vv_i8m1(vint8m1_t, vint8m1_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vaadd_vv_m)))
vint8m1_t vaadd_vv_i8m1_m(vbool8_t, vint8m1_t, vint8m1_t, vint8m1_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vaadd_vv)))
vint8m2_t vaadd_vv_i8m2(vint8m2_t, vint8m2_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vaadd_vv_m)))
vint8m2_t vaadd_vv_i8m2_m(vbool4_t, vint8m2_t, vint8m2_t, vint8m2_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vaadd_vv)))
vint8m4_t vaadd_vv_i8m4(vint8m4_t, vint8m4_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vaadd_vv_m)))
vint8m4_t vaadd_vv_i8m4_m(vbool2_t, vint8m4_t, vint8m4_t, vint8m4_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vaadd_vv)))
vint8m8_t vaadd_vv_i8m8(vint8m8_t, vint8m8_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vaadd_vv_m)))
vint8m8_t vaadd_vv_i8m8_m(vbool1_t, vint8m8_t, vint8m8_t, vint8m8_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vaadd_vv)))
vint8mf2_t vaadd_vv_i8mf2(vint8mf2_t, vint8mf2_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vaadd_vv_m)))
vint8mf2_t vaadd_vv_i8mf2_m(vbool16_t, vint8mf2_t, vint8mf2_t, vint8mf2_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vaadd_vv)))
vint8mf4_t vaadd_vv_i8mf4(vint8mf4_t, vint8mf4_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vaadd_vv_m)))
vint8mf4_t vaadd_vv_i8mf4_m(vbool32_t, vint8mf4_t, vint8mf4_t, vint8mf4_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vaadd_vv)))
vint8mf8_t vaadd_vv_i8mf8(vint8mf8_t, vint8mf8_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vaadd_vv_m)))
vint8mf8_t vaadd_vv_i8mf8_m(vbool64_t, vint8mf8_t, vint8mf8_t, vint8mf8_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vaadd_vv)))
vint16m1_t vaadd_vv_i16m1(vint16m1_t, vint16m1_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vaadd_vv_m)))
vint16m1_t vaadd_vv_i16m1_m(vbool16_t, vint16m1_t, vint16m1_t, vint16m1_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vaadd_vv)))
vint16m2_t vaadd_vv_i16m2(vint16m2_t, vint16m2_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vaadd_vv_m)))
vint16m2_t vaadd_vv_i16m2_m(vbool8_t, vint16m2_t, vint16m2_t, vint16m2_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vaadd_vv)))
vint16m4_t vaadd_vv_i16m4(vint16m4_t, vint16m4_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vaadd_vv_m)))
vint16m4_t vaadd_vv_i16m4_m(vbool4_t, vint16m4_t, vint16m4_t, vint16m4_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vaadd_vv)))
vint16m8_t vaadd_vv_i16m8(vint16m8_t, vint16m8_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vaadd_vv_m)))
vint16m8_t vaadd_vv_i16m8_m(vbool2_t, vint16m8_t, vint16m8_t, vint16m8_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vaadd_vv)))
vint16mf2_t vaadd_vv_i16mf2(vint16mf2_t, vint16mf2_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vaadd_vv_m)))
vint16mf2_t vaadd_vv_i16mf2_m(vbool32_t, vint16mf2_t, vint16mf2_t, vint16mf2_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vaadd_vv)))
vint16mf4_t vaadd_vv_i16mf4(vint16mf4_t, vint16mf4_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vaadd_vv_m)))
vint16mf4_t vaadd_vv_i16mf4_m(vbool64_t, vint16mf4_t, vint16mf4_t, vint16mf4_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vaadd_vv)))
vint32m1_t vaadd_vv_i32m1(vint32m1_t, vint32m1_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vaadd_vv_m)))
vint32m1_t vaadd_vv_i32m1_m(vbool32_t, vint32m1_t, vint32m1_t, vint32m1_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vaadd_vv)))
vint32m2_t vaadd_vv_i32m2(vint32m2_t, vint32m2_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vaadd_vv_m)))
vint32m2_t vaadd_vv_i32m2_m(vbool16_t, vint32m2_t, vint32m2_t, vint32m2_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vaadd_vv)))
vint32m4_t vaadd_vv_i32m4(vint32m4_t, vint32m4_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vaadd_vv_m)))
vint32m4_t vaadd_vv_i32m4_m(vbool8_t, vint32m4_t, vint32m4_t, vint32m4_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vaadd_vv)))
vint32m8_t vaadd_vv_i32m8(vint32m8_t, vint32m8_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vaadd_vv_m)))
vint32m8_t vaadd_vv_i32m8_m(vbool4_t, vint32m8_t, vint32m8_t, vint32m8_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vaadd_vv)))
vint32mf2_t vaadd_vv_i32mf2(vint32mf2_t, vint32mf2_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vaadd_vv_m)))
vint32mf2_t vaadd_vv_i32mf2_m(vbool64_t, vint32mf2_t, vint32mf2_t, vint32mf2_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vaadd_vx)))
vint8m1_t vaadd_vx_i8m1(vint8m1_t, int8_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vaadd_vx_m)))
vint8m1_t vaadd_vx_i8m1_m(vbool8_t, vint8m1_t, vint8m1_t, int8_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vaadd_vx)))
vint8m2_t vaadd_vx_i8m2(vint8m2_t, int8_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vaadd_vx_m)))
vint8m2_t vaadd_vx_i8m2_m(vbool4_t, vint8m2_t, vint8m2_t, int8_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vaadd_vx)))
vint8m4_t vaadd_vx_i8m4(vint8m4_t, int8_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vaadd_vx_m)))
vint8m4_t vaadd_vx_i8m4_m(vbool2_t, vint8m4_t, vint8m4_t, int8_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vaadd_vx)))
vint8m8_t vaadd_vx_i8m8(vint8m8_t, int8_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vaadd_vx_m)))
vint8m8_t vaadd_vx_i8m8_m(vbool1_t, vint8m8_t, vint8m8_t, int8_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vaadd_vx)))
vint8mf2_t vaadd_vx_i8mf2(vint8mf2_t, int8_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vaadd_vx_m)))
vint8mf2_t vaadd_vx_i8mf2_m(vbool16_t, vint8mf2_t, vint8mf2_t, int8_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vaadd_vx)))
vint8mf4_t vaadd_vx_i8mf4(vint8mf4_t, int8_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vaadd_vx_m)))
vint8mf4_t vaadd_vx_i8mf4_m(vbool32_t, vint8mf4_t, vint8mf4_t, int8_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vaadd_vx)))
vint8mf8_t vaadd_vx_i8mf8(vint8mf8_t, int8_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vaadd_vx_m)))
vint8mf8_t vaadd_vx_i8mf8_m(vbool64_t, vint8mf8_t, vint8mf8_t, int8_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vaadd_vx)))
vint16m1_t vaadd_vx_i16m1(vint16m1_t, int16_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vaadd_vx_m)))
vint16m1_t vaadd_vx_i16m1_m(vbool16_t, vint16m1_t, vint16m1_t, int16_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vaadd_vx)))
vint16m2_t vaadd_vx_i16m2(vint16m2_t, int16_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vaadd_vx_m)))
vint16m2_t vaadd_vx_i16m2_m(vbool8_t, vint16m2_t, vint16m2_t, int16_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vaadd_vx)))
vint16m4_t vaadd_vx_i16m4(vint16m4_t, int16_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vaadd_vx_m)))
vint16m4_t vaadd_vx_i16m4_m(vbool4_t, vint16m4_t, vint16m4_t, int16_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vaadd_vx)))
vint16m8_t vaadd_vx_i16m8(vint16m8_t, int16_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vaadd_vx_m)))
vint16m8_t vaadd_vx_i16m8_m(vbool2_t, vint16m8_t, vint16m8_t, int16_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vaadd_vx)))
vint16mf2_t vaadd_vx_i16mf2(vint16mf2_t, int16_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vaadd_vx_m)))
vint16mf2_t vaadd_vx_i16mf2_m(vbool32_t, vint16mf2_t, vint16mf2_t, int16_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vaadd_vx)))
vint16mf4_t vaadd_vx_i16mf4(vint16mf4_t, int16_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vaadd_vx_m)))
vint16mf4_t vaadd_vx_i16mf4_m(vbool64_t, vint16mf4_t, vint16mf4_t, int16_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vaadd_vx)))
vint32m1_t vaadd_vx_i32m1(vint32m1_t, int32_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vaadd_vx_m)))
vint32m1_t vaadd_vx_i32m1_m(vbool32_t, vint32m1_t, vint32m1_t, int32_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vaadd_vx)))
vint32m2_t vaadd_vx_i32m2(vint32m2_t, int32_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vaadd_vx_m)))
vint32m2_t vaadd_vx_i32m2_m(vbool16_t, vint32m2_t, vint32m2_t, int32_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vaadd_vx)))
vint32m4_t vaadd_vx_i32m4(vint32m4_t, int32_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vaadd_vx_m)))
vint32m4_t vaadd_vx_i32m4_m(vbool8_t, vint32m4_t, vint32m4_t, int32_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vaadd_vx)))
vint32m8_t vaadd_vx_i32m8(vint32m8_t, int32_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vaadd_vx_m)))
vint32m8_t vaadd_vx_i32m8_m(vbool4_t, vint32m8_t, vint32m8_t, int32_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vaadd_vx)))
vint32mf2_t vaadd_vx_i32mf2(vint32mf2_t, int32_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vaadd_vx_m)))
vint32mf2_t vaadd_vx_i32mf2_m(vbool64_t, vint32mf2_t, vint32mf2_t, int32_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vasubu_vv)))
vuint8m1_t vasubu_vv_u8m1(vuint8m1_t, vuint8m1_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vasubu_vv_m)))
vuint8m1_t vasubu_vv_u8m1_m(vbool8_t, vuint8m1_t, vuint8m1_t, vuint8m1_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vasubu_vv)))
vuint8m2_t vasubu_vv_u8m2(vuint8m2_t, vuint8m2_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vasubu_vv_m)))
vuint8m2_t vasubu_vv_u8m2_m(vbool4_t, vuint8m2_t, vuint8m2_t, vuint8m2_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vasubu_vv)))
vuint8m4_t vasubu_vv_u8m4(vuint8m4_t, vuint8m4_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vasubu_vv_m)))
vuint8m4_t vasubu_vv_u8m4_m(vbool2_t, vuint8m4_t, vuint8m4_t, vuint8m4_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vasubu_vv)))
vuint8m8_t vasubu_vv_u8m8(vuint8m8_t, vuint8m8_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vasubu_vv_m)))
vuint8m8_t vasubu_vv_u8m8_m(vbool1_t, vuint8m8_t, vuint8m8_t, vuint8m8_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vasubu_vv)))
vuint8mf2_t vasubu_vv_u8mf2(vuint8mf2_t, vuint8mf2_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vasubu_vv_m)))
vuint8mf2_t vasubu_vv_u8mf2_m(vbool16_t, vuint8mf2_t, vuint8mf2_t, vuint8mf2_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vasubu_vv)))
vuint8mf4_t vasubu_vv_u8mf4(vuint8mf4_t, vuint8mf4_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vasubu_vv_m)))
vuint8mf4_t vasubu_vv_u8mf4_m(vbool32_t, vuint8mf4_t, vuint8mf4_t, vuint8mf4_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vasubu_vv)))
vuint8mf8_t vasubu_vv_u8mf8(vuint8mf8_t, vuint8mf8_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vasubu_vv_m)))
vuint8mf8_t vasubu_vv_u8mf8_m(vbool64_t, vuint8mf8_t, vuint8mf8_t, vuint8mf8_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vasubu_vv)))
vuint16m1_t vasubu_vv_u16m1(vuint16m1_t, vuint16m1_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vasubu_vv_m)))
vuint16m1_t vasubu_vv_u16m1_m(vbool16_t, vuint16m1_t, vuint16m1_t, vuint16m1_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vasubu_vv)))
vuint16m2_t vasubu_vv_u16m2(vuint16m2_t, vuint16m2_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vasubu_vv_m)))
vuint16m2_t vasubu_vv_u16m2_m(vbool8_t, vuint16m2_t, vuint16m2_t, vuint16m2_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vasubu_vv)))
vuint16m4_t vasubu_vv_u16m4(vuint16m4_t, vuint16m4_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vasubu_vv_m)))
vuint16m4_t vasubu_vv_u16m4_m(vbool4_t, vuint16m4_t, vuint16m4_t, vuint16m4_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vasubu_vv)))
vuint16m8_t vasubu_vv_u16m8(vuint16m8_t, vuint16m8_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vasubu_vv_m)))
vuint16m8_t vasubu_vv_u16m8_m(vbool2_t, vuint16m8_t, vuint16m8_t, vuint16m8_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vasubu_vv)))
vuint16mf2_t vasubu_vv_u16mf2(vuint16mf2_t, vuint16mf2_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vasubu_vv_m)))
vuint16mf2_t vasubu_vv_u16mf2_m(vbool32_t, vuint16mf2_t, vuint16mf2_t, vuint16mf2_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vasubu_vv)))
vuint16mf4_t vasubu_vv_u16mf4(vuint16mf4_t, vuint16mf4_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vasubu_vv_m)))
vuint16mf4_t vasubu_vv_u16mf4_m(vbool64_t, vuint16mf4_t, vuint16mf4_t, vuint16mf4_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vasubu_vv)))
vuint32m1_t vasubu_vv_u32m1(vuint32m1_t, vuint32m1_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vasubu_vv_m)))
vuint32m1_t vasubu_vv_u32m1_m(vbool32_t, vuint32m1_t, vuint32m1_t, vuint32m1_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vasubu_vv)))
vuint32m2_t vasubu_vv_u32m2(vuint32m2_t, vuint32m2_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vasubu_vv_m)))
vuint32m2_t vasubu_vv_u32m2_m(vbool16_t, vuint32m2_t, vuint32m2_t, vuint32m2_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vasubu_vv)))
vuint32m4_t vasubu_vv_u32m4(vuint32m4_t, vuint32m4_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vasubu_vv_m)))
vuint32m4_t vasubu_vv_u32m4_m(vbool8_t, vuint32m4_t, vuint32m4_t, vuint32m4_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vasubu_vv)))
vuint32m8_t vasubu_vv_u32m8(vuint32m8_t, vuint32m8_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vasubu_vv_m)))
vuint32m8_t vasubu_vv_u32m8_m(vbool4_t, vuint32m8_t, vuint32m8_t, vuint32m8_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vasubu_vv)))
vuint32mf2_t vasubu_vv_u32mf2(vuint32mf2_t, vuint32mf2_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vasubu_vv_m)))
vuint32mf2_t vasubu_vv_u32mf2_m(vbool64_t, vuint32mf2_t, vuint32mf2_t, vuint32mf2_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vasubu_vx)))
vuint8m1_t vasubu_vx_u8m1(vuint8m1_t, uint8_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vasubu_vx_m)))
vuint8m1_t vasubu_vx_u8m1_m(vbool8_t, vuint8m1_t, vuint8m1_t, uint8_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vasubu_vx)))
vuint8m2_t vasubu_vx_u8m2(vuint8m2_t, uint8_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vasubu_vx_m)))
vuint8m2_t vasubu_vx_u8m2_m(vbool4_t, vuint8m2_t, vuint8m2_t, uint8_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vasubu_vx)))
vuint8m4_t vasubu_vx_u8m4(vuint8m4_t, uint8_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vasubu_vx_m)))
vuint8m4_t vasubu_vx_u8m4_m(vbool2_t, vuint8m4_t, vuint8m4_t, uint8_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vasubu_vx)))
vuint8m8_t vasubu_vx_u8m8(vuint8m8_t, uint8_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vasubu_vx_m)))
vuint8m8_t vasubu_vx_u8m8_m(vbool1_t, vuint8m8_t, vuint8m8_t, uint8_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vasubu_vx)))
vuint8mf2_t vasubu_vx_u8mf2(vuint8mf2_t, uint8_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vasubu_vx_m)))
vuint8mf2_t vasubu_vx_u8mf2_m(vbool16_t, vuint8mf2_t, vuint8mf2_t, uint8_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vasubu_vx)))
vuint8mf4_t vasubu_vx_u8mf4(vuint8mf4_t, uint8_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vasubu_vx_m)))
vuint8mf4_t vasubu_vx_u8mf4_m(vbool32_t, vuint8mf4_t, vuint8mf4_t, uint8_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vasubu_vx)))
vuint8mf8_t vasubu_vx_u8mf8(vuint8mf8_t, uint8_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vasubu_vx_m)))
vuint8mf8_t vasubu_vx_u8mf8_m(vbool64_t, vuint8mf8_t, vuint8mf8_t, uint8_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vasubu_vx)))
vuint16m1_t vasubu_vx_u16m1(vuint16m1_t, uint16_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vasubu_vx_m)))
vuint16m1_t vasubu_vx_u16m1_m(vbool16_t, vuint16m1_t, vuint16m1_t, uint16_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vasubu_vx)))
vuint16m2_t vasubu_vx_u16m2(vuint16m2_t, uint16_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vasubu_vx_m)))
vuint16m2_t vasubu_vx_u16m2_m(vbool8_t, vuint16m2_t, vuint16m2_t, uint16_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vasubu_vx)))
vuint16m4_t vasubu_vx_u16m4(vuint16m4_t, uint16_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vasubu_vx_m)))
vuint16m4_t vasubu_vx_u16m4_m(vbool4_t, vuint16m4_t, vuint16m4_t, uint16_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vasubu_vx)))
vuint16m8_t vasubu_vx_u16m8(vuint16m8_t, uint16_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vasubu_vx_m)))
vuint16m8_t vasubu_vx_u16m8_m(vbool2_t, vuint16m8_t, vuint16m8_t, uint16_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vasubu_vx)))
vuint16mf2_t vasubu_vx_u16mf2(vuint16mf2_t, uint16_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vasubu_vx_m)))
vuint16mf2_t vasubu_vx_u16mf2_m(vbool32_t, vuint16mf2_t, vuint16mf2_t, uint16_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vasubu_vx)))
vuint16mf4_t vasubu_vx_u16mf4(vuint16mf4_t, uint16_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vasubu_vx_m)))
vuint16mf4_t vasubu_vx_u16mf4_m(vbool64_t, vuint16mf4_t, vuint16mf4_t, uint16_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vasubu_vx)))
vuint32m1_t vasubu_vx_u32m1(vuint32m1_t, uint32_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vasubu_vx_m)))
vuint32m1_t vasubu_vx_u32m1_m(vbool32_t, vuint32m1_t, vuint32m1_t, uint32_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vasubu_vx)))
vuint32m2_t vasubu_vx_u32m2(vuint32m2_t, uint32_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vasubu_vx_m)))
vuint32m2_t vasubu_vx_u32m2_m(vbool16_t, vuint32m2_t, vuint32m2_t, uint32_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vasubu_vx)))
vuint32m4_t vasubu_vx_u32m4(vuint32m4_t, uint32_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vasubu_vx_m)))
vuint32m4_t vasubu_vx_u32m4_m(vbool8_t, vuint32m4_t, vuint32m4_t, uint32_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vasubu_vx)))
vuint32m8_t vasubu_vx_u32m8(vuint32m8_t, uint32_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vasubu_vx_m)))
vuint32m8_t vasubu_vx_u32m8_m(vbool4_t, vuint32m8_t, vuint32m8_t, uint32_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vasubu_vx)))
vuint32mf2_t vasubu_vx_u32mf2(vuint32mf2_t, uint32_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vasubu_vx_m)))
vuint32mf2_t vasubu_vx_u32mf2_m(vbool64_t, vuint32mf2_t, vuint32mf2_t, uint32_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vsuxei32_v)))
void vsuxei32_v_i16m1(int16_t *, vuint32m2_t, vint16m1_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vsuxei32_v_m)))
void vsuxei32_v_i16m1_m(vbool16_t, int16_t *, vuint32m2_t, vint16m1_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vsuxei32_v)))
void vsuxei32_v_i16m2(int16_t *, vuint32m4_t, vint16m2_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vsuxei32_v_m)))
void vsuxei32_v_i16m2_m(vbool8_t, int16_t *, vuint32m4_t, vint16m2_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vsuxei32_v)))
void vsuxei32_v_i16m4(int16_t *, vuint32m8_t, vint16m4_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vsuxei32_v_m)))
void vsuxei32_v_i16m4_m(vbool4_t, int16_t *, vuint32m8_t, vint16m4_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vsuxei32_v)))
void vsuxei32_v_i16mf2(int16_t *, vuint32m1_t, vint16mf2_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vsuxei32_v_m)))
void vsuxei32_v_i16mf2_m(vbool32_t, int16_t *, vuint32m1_t, vint16mf2_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vsuxei32_v)))
void vsuxei32_v_i16mf4(int16_t *, vuint32mf2_t, vint16mf4_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vsuxei32_v_m)))
void vsuxei32_v_i16mf4_m(vbool64_t, int16_t *, vuint32mf2_t, vint16mf4_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vasub_vv)))
vint8m1_t vasub_vv_i8m1(vint8m1_t, vint8m1_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vasub_vv_m)))
vint8m1_t vasub_vv_i8m1_m(vbool8_t, vint8m1_t, vint8m1_t, vint8m1_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vasub_vv)))
vint8m2_t vasub_vv_i8m2(vint8m2_t, vint8m2_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vasub_vv_m)))
vint8m2_t vasub_vv_i8m2_m(vbool4_t, vint8m2_t, vint8m2_t, vint8m2_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vasub_vv)))
vint8m4_t vasub_vv_i8m4(vint8m4_t, vint8m4_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vasub_vv_m)))
vint8m4_t vasub_vv_i8m4_m(vbool2_t, vint8m4_t, vint8m4_t, vint8m4_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vasub_vv)))
vint8m8_t vasub_vv_i8m8(vint8m8_t, vint8m8_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vasub_vv_m)))
vint8m8_t vasub_vv_i8m8_m(vbool1_t, vint8m8_t, vint8m8_t, vint8m8_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vasub_vv)))
vint8mf2_t vasub_vv_i8mf2(vint8mf2_t, vint8mf2_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vasub_vv_m)))
vint8mf2_t vasub_vv_i8mf2_m(vbool16_t, vint8mf2_t, vint8mf2_t, vint8mf2_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vasub_vv)))
vint8mf4_t vasub_vv_i8mf4(vint8mf4_t, vint8mf4_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vasub_vv_m)))
vint8mf4_t vasub_vv_i8mf4_m(vbool32_t, vint8mf4_t, vint8mf4_t, vint8mf4_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vasub_vv)))
vint8mf8_t vasub_vv_i8mf8(vint8mf8_t, vint8mf8_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vasub_vv_m)))
vint8mf8_t vasub_vv_i8mf8_m(vbool64_t, vint8mf8_t, vint8mf8_t, vint8mf8_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vasub_vv)))
vint16m1_t vasub_vv_i16m1(vint16m1_t, vint16m1_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vasub_vv_m)))
vint16m1_t vasub_vv_i16m1_m(vbool16_t, vint16m1_t, vint16m1_t, vint16m1_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vasub_vv)))
vint16m2_t vasub_vv_i16m2(vint16m2_t, vint16m2_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vasub_vv_m)))
vint16m2_t vasub_vv_i16m2_m(vbool8_t, vint16m2_t, vint16m2_t, vint16m2_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vasub_vv)))
vint16m4_t vasub_vv_i16m4(vint16m4_t, vint16m4_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vasub_vv_m)))
vint16m4_t vasub_vv_i16m4_m(vbool4_t, vint16m4_t, vint16m4_t, vint16m4_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vasub_vv)))
vint16m8_t vasub_vv_i16m8(vint16m8_t, vint16m8_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vasub_vv_m)))
vint16m8_t vasub_vv_i16m8_m(vbool2_t, vint16m8_t, vint16m8_t, vint16m8_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vasub_vv)))
vint16mf2_t vasub_vv_i16mf2(vint16mf2_t, vint16mf2_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vasub_vv_m)))
vint16mf2_t vasub_vv_i16mf2_m(vbool32_t, vint16mf2_t, vint16mf2_t, vint16mf2_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vasub_vv)))
vint16mf4_t vasub_vv_i16mf4(vint16mf4_t, vint16mf4_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vasub_vv_m)))
vint16mf4_t vasub_vv_i16mf4_m(vbool64_t, vint16mf4_t, vint16mf4_t, vint16mf4_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vasub_vv)))
vint32m1_t vasub_vv_i32m1(vint32m1_t, vint32m1_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vasub_vv_m)))
vint32m1_t vasub_vv_i32m1_m(vbool32_t, vint32m1_t, vint32m1_t, vint32m1_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vasub_vv)))
vint32m2_t vasub_vv_i32m2(vint32m2_t, vint32m2_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vasub_vv_m)))
vint32m2_t vasub_vv_i32m2_m(vbool16_t, vint32m2_t, vint32m2_t, vint32m2_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vasub_vv)))
vint32m4_t vasub_vv_i32m4(vint32m4_t, vint32m4_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vasub_vv_m)))
vint32m4_t vasub_vv_i32m4_m(vbool8_t, vint32m4_t, vint32m4_t, vint32m4_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vasub_vv)))
vint32m8_t vasub_vv_i32m8(vint32m8_t, vint32m8_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vasub_vv_m)))
vint32m8_t vasub_vv_i32m8_m(vbool4_t, vint32m8_t, vint32m8_t, vint32m8_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vasub_vv)))
vint32mf2_t vasub_vv_i32mf2(vint32mf2_t, vint32mf2_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vasub_vv_m)))
vint32mf2_t vasub_vv_i32mf2_m(vbool64_t, vint32mf2_t, vint32mf2_t, vint32mf2_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vasub_vx)))
vint8m1_t vasub_vx_i8m1(vint8m1_t, int8_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vasub_vx_m)))
vint8m1_t vasub_vx_i8m1_m(vbool8_t, vint8m1_t, vint8m1_t, int8_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vasub_vx)))
vint8m2_t vasub_vx_i8m2(vint8m2_t, int8_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vasub_vx_m)))
vint8m2_t vasub_vx_i8m2_m(vbool4_t, vint8m2_t, vint8m2_t, int8_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vasub_vx)))
vint8m4_t vasub_vx_i8m4(vint8m4_t, int8_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vasub_vx_m)))
vint8m4_t vasub_vx_i8m4_m(vbool2_t, vint8m4_t, vint8m4_t, int8_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vasub_vx)))
vint8m8_t vasub_vx_i8m8(vint8m8_t, int8_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vasub_vx_m)))
vint8m8_t vasub_vx_i8m8_m(vbool1_t, vint8m8_t, vint8m8_t, int8_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vasub_vx)))
vint8mf2_t vasub_vx_i8mf2(vint8mf2_t, int8_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vasub_vx_m)))
vint8mf2_t vasub_vx_i8mf2_m(vbool16_t, vint8mf2_t, vint8mf2_t, int8_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vasub_vx)))
vint8mf4_t vasub_vx_i8mf4(vint8mf4_t, int8_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vasub_vx_m)))
vint8mf4_t vasub_vx_i8mf4_m(vbool32_t, vint8mf4_t, vint8mf4_t, int8_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vasub_vx)))
vint8mf8_t vasub_vx_i8mf8(vint8mf8_t, int8_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vasub_vx_m)))
vint8mf8_t vasub_vx_i8mf8_m(vbool64_t, vint8mf8_t, vint8mf8_t, int8_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vasub_vx)))
vint16m1_t vasub_vx_i16m1(vint16m1_t, int16_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vasub_vx_m)))
vint16m1_t vasub_vx_i16m1_m(vbool16_t, vint16m1_t, vint16m1_t, int16_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vasub_vx)))
vint16m2_t vasub_vx_i16m2(vint16m2_t, int16_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vasub_vx_m)))
vint16m2_t vasub_vx_i16m2_m(vbool8_t, vint16m2_t, vint16m2_t, int16_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vasub_vx)))
vint16m4_t vasub_vx_i16m4(vint16m4_t, int16_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vasub_vx_m)))
vint16m4_t vasub_vx_i16m4_m(vbool4_t, vint16m4_t, vint16m4_t, int16_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vasub_vx)))
vint16m8_t vasub_vx_i16m8(vint16m8_t, int16_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vasub_vx_m)))
vint16m8_t vasub_vx_i16m8_m(vbool2_t, vint16m8_t, vint16m8_t, int16_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vasub_vx)))
vint16mf2_t vasub_vx_i16mf2(vint16mf2_t, int16_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vasub_vx_m)))
vint16mf2_t vasub_vx_i16mf2_m(vbool32_t, vint16mf2_t, vint16mf2_t, int16_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vasub_vx)))
vint16mf4_t vasub_vx_i16mf4(vint16mf4_t, int16_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vasub_vx_m)))
vint16mf4_t vasub_vx_i16mf4_m(vbool64_t, vint16mf4_t, vint16mf4_t, int16_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vasub_vx)))
vint32m1_t vasub_vx_i32m1(vint32m1_t, int32_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vasub_vx_m)))
vint32m1_t vasub_vx_i32m1_m(vbool32_t, vint32m1_t, vint32m1_t, int32_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vasub_vx)))
vint32m2_t vasub_vx_i32m2(vint32m2_t, int32_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vasub_vx_m)))
vint32m2_t vasub_vx_i32m2_m(vbool16_t, vint32m2_t, vint32m2_t, int32_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vasub_vx)))
vint32m4_t vasub_vx_i32m4(vint32m4_t, int32_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vasub_vx_m)))
vint32m4_t vasub_vx_i32m4_m(vbool8_t, vint32m4_t, vint32m4_t, int32_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vasub_vx)))
vint32m8_t vasub_vx_i32m8(vint32m8_t, int32_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vasub_vx_m)))
vint32m8_t vasub_vx_i32m8_m(vbool4_t, vint32m8_t, vint32m8_t, int32_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vasub_vx)))
vint32mf2_t vasub_vx_i32mf2(vint32mf2_t, int32_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vasub_vx_m)))
vint32mf2_t vasub_vx_i32mf2_m(vbool64_t, vint32mf2_t, vint32mf2_t, int32_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vsmul_vv)))
vint8m1_t vsmul_vv_i8m1(vint8m1_t, vint8m1_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vsmul_vv_m)))
vint8m1_t vsmul_vv_i8m1_m(vbool8_t, vint8m1_t, vint8m1_t, vint8m1_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vsmul_vv)))
vint8m2_t vsmul_vv_i8m2(vint8m2_t, vint8m2_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vsmul_vv_m)))
vint8m2_t vsmul_vv_i8m2_m(vbool4_t, vint8m2_t, vint8m2_t, vint8m2_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vsmul_vv)))
vint8m4_t vsmul_vv_i8m4(vint8m4_t, vint8m4_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vsmul_vv_m)))
vint8m4_t vsmul_vv_i8m4_m(vbool2_t, vint8m4_t, vint8m4_t, vint8m4_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vsmul_vv)))
vint8m8_t vsmul_vv_i8m8(vint8m8_t, vint8m8_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vsmul_vv_m)))
vint8m8_t vsmul_vv_i8m8_m(vbool1_t, vint8m8_t, vint8m8_t, vint8m8_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vsmul_vv)))
vint8mf2_t vsmul_vv_i8mf2(vint8mf2_t, vint8mf2_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vsmul_vv_m)))
vint8mf2_t vsmul_vv_i8mf2_m(vbool16_t, vint8mf2_t, vint8mf2_t, vint8mf2_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vsmul_vv)))
vint8mf4_t vsmul_vv_i8mf4(vint8mf4_t, vint8mf4_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vsmul_vv_m)))
vint8mf4_t vsmul_vv_i8mf4_m(vbool32_t, vint8mf4_t, vint8mf4_t, vint8mf4_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vsmul_vv)))
vint8mf8_t vsmul_vv_i8mf8(vint8mf8_t, vint8mf8_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vsmul_vv_m)))
vint8mf8_t vsmul_vv_i8mf8_m(vbool64_t, vint8mf8_t, vint8mf8_t, vint8mf8_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vsmul_vv)))
vint16m1_t vsmul_vv_i16m1(vint16m1_t, vint16m1_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vsmul_vv_m)))
vint16m1_t vsmul_vv_i16m1_m(vbool16_t, vint16m1_t, vint16m1_t, vint16m1_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vsmul_vv)))
vint16m2_t vsmul_vv_i16m2(vint16m2_t, vint16m2_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vsmul_vv_m)))
vint16m2_t vsmul_vv_i16m2_m(vbool8_t, vint16m2_t, vint16m2_t, vint16m2_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vsmul_vv)))
vint16m4_t vsmul_vv_i16m4(vint16m4_t, vint16m4_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vsmul_vv_m)))
vint16m4_t vsmul_vv_i16m4_m(vbool4_t, vint16m4_t, vint16m4_t, vint16m4_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vsmul_vv)))
vint16m8_t vsmul_vv_i16m8(vint16m8_t, vint16m8_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vsmul_vv_m)))
vint16m8_t vsmul_vv_i16m8_m(vbool2_t, vint16m8_t, vint16m8_t, vint16m8_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vsmul_vv)))
vint16mf2_t vsmul_vv_i16mf2(vint16mf2_t, vint16mf2_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vsmul_vv_m)))
vint16mf2_t vsmul_vv_i16mf2_m(vbool32_t, vint16mf2_t, vint16mf2_t, vint16mf2_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vsmul_vv)))
vint16mf4_t vsmul_vv_i16mf4(vint16mf4_t, vint16mf4_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vsmul_vv_m)))
vint16mf4_t vsmul_vv_i16mf4_m(vbool64_t, vint16mf4_t, vint16mf4_t, vint16mf4_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vsmul_vv)))
vint32m1_t vsmul_vv_i32m1(vint32m1_t, vint32m1_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vsmul_vv_m)))
vint32m1_t vsmul_vv_i32m1_m(vbool32_t, vint32m1_t, vint32m1_t, vint32m1_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vsmul_vv)))
vint32m2_t vsmul_vv_i32m2(vint32m2_t, vint32m2_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vsmul_vv_m)))
vint32m2_t vsmul_vv_i32m2_m(vbool16_t, vint32m2_t, vint32m2_t, vint32m2_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vsmul_vv)))
vint32m4_t vsmul_vv_i32m4(vint32m4_t, vint32m4_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vsmul_vv_m)))
vint32m4_t vsmul_vv_i32m4_m(vbool8_t, vint32m4_t, vint32m4_t, vint32m4_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vsmul_vv)))
vint32m8_t vsmul_vv_i32m8(vint32m8_t, vint32m8_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vsmul_vv_m)))
vint32m8_t vsmul_vv_i32m8_m(vbool4_t, vint32m8_t, vint32m8_t, vint32m8_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vsmul_vv)))
vint32mf2_t vsmul_vv_i32mf2(vint32mf2_t, vint32mf2_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vsmul_vv_m)))
vint32mf2_t vsmul_vv_i32mf2_m(vbool64_t, vint32mf2_t, vint32mf2_t, vint32mf2_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vsmul_vx)))
vint8m1_t vsmul_vx_i8m1(vint8m1_t, int8_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vsmul_vx_m)))
vint8m1_t vsmul_vx_i8m1_m(vbool8_t, vint8m1_t, vint8m1_t, int8_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vsmul_vx)))
vint8m2_t vsmul_vx_i8m2(vint8m2_t, int8_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vsmul_vx_m)))
vint8m2_t vsmul_vx_i8m2_m(vbool4_t, vint8m2_t, vint8m2_t, int8_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vsmul_vx)))
vint8m4_t vsmul_vx_i8m4(vint8m4_t, int8_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vsmul_vx_m)))
vint8m4_t vsmul_vx_i8m4_m(vbool2_t, vint8m4_t, vint8m4_t, int8_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vsmul_vx)))
vint8m8_t vsmul_vx_i8m8(vint8m8_t, int8_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vsmul_vx_m)))
vint8m8_t vsmul_vx_i8m8_m(vbool1_t, vint8m8_t, vint8m8_t, int8_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vsmul_vx)))
vint8mf2_t vsmul_vx_i8mf2(vint8mf2_t, int8_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vsmul_vx_m)))
vint8mf2_t vsmul_vx_i8mf2_m(vbool16_t, vint8mf2_t, vint8mf2_t, int8_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vsmul_vx)))
vint8mf4_t vsmul_vx_i8mf4(vint8mf4_t, int8_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vsmul_vx_m)))
vint8mf4_t vsmul_vx_i8mf4_m(vbool32_t, vint8mf4_t, vint8mf4_t, int8_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vsmul_vx)))
vint8mf8_t vsmul_vx_i8mf8(vint8mf8_t, int8_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vsmul_vx_m)))
vint8mf8_t vsmul_vx_i8mf8_m(vbool64_t, vint8mf8_t, vint8mf8_t, int8_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vsmul_vx)))
vint16m1_t vsmul_vx_i16m1(vint16m1_t, int16_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vsmul_vx_m)))
vint16m1_t vsmul_vx_i16m1_m(vbool16_t, vint16m1_t, vint16m1_t, int16_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vsmul_vx)))
vint16m2_t vsmul_vx_i16m2(vint16m2_t, int16_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vsmul_vx_m)))
vint16m2_t vsmul_vx_i16m2_m(vbool8_t, vint16m2_t, vint16m2_t, int16_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vsmul_vx)))
vint16m4_t vsmul_vx_i16m4(vint16m4_t, int16_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vsmul_vx_m)))
vint16m4_t vsmul_vx_i16m4_m(vbool4_t, vint16m4_t, vint16m4_t, int16_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vsmul_vx)))
vint16m8_t vsmul_vx_i16m8(vint16m8_t, int16_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vsmul_vx_m)))
vint16m8_t vsmul_vx_i16m8_m(vbool2_t, vint16m8_t, vint16m8_t, int16_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vsmul_vx)))
vint16mf2_t vsmul_vx_i16mf2(vint16mf2_t, int16_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vsmul_vx_m)))
vint16mf2_t vsmul_vx_i16mf2_m(vbool32_t, vint16mf2_t, vint16mf2_t, int16_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vsmul_vx)))
vint16mf4_t vsmul_vx_i16mf4(vint16mf4_t, int16_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vsmul_vx_m)))
vint16mf4_t vsmul_vx_i16mf4_m(vbool64_t, vint16mf4_t, vint16mf4_t, int16_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vsmul_vx)))
vint32m1_t vsmul_vx_i32m1(vint32m1_t, int32_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vsmul_vx_m)))
vint32m1_t vsmul_vx_i32m1_m(vbool32_t, vint32m1_t, vint32m1_t, int32_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vsmul_vx)))
vint32m2_t vsmul_vx_i32m2(vint32m2_t, int32_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vsmul_vx_m)))
vint32m2_t vsmul_vx_i32m2_m(vbool16_t, vint32m2_t, vint32m2_t, int32_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vsmul_vx)))
vint32m4_t vsmul_vx_i32m4(vint32m4_t, int32_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vsmul_vx_m)))
vint32m4_t vsmul_vx_i32m4_m(vbool8_t, vint32m4_t, vint32m4_t, int32_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vsmul_vx)))
vint32m8_t vsmul_vx_i32m8(vint32m8_t, int32_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vsmul_vx_m)))
vint32m8_t vsmul_vx_i32m8_m(vbool4_t, vint32m8_t, vint32m8_t, int32_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vsmul_vx)))
vint32mf2_t vsmul_vx_i32mf2(vint32mf2_t, int32_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vsmul_vx_m)))
vint32mf2_t vsmul_vx_i32mf2_m(vbool64_t, vint32mf2_t, vint32mf2_t, int32_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vssrl_vv)))
vuint8m1_t vssrl_vv_u8m1(vuint8m1_t, vuint8m1_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vssrl_vv_m)))
vuint8m1_t vssrl_vv_u8m1_m(vbool8_t, vuint8m1_t, vuint8m1_t, vuint8m1_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vssrl_vv)))
vuint8m2_t vssrl_vv_u8m2(vuint8m2_t, vuint8m2_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vssrl_vv_m)))
vuint8m2_t vssrl_vv_u8m2_m(vbool4_t, vuint8m2_t, vuint8m2_t, vuint8m2_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vssrl_vv)))
vuint8m4_t vssrl_vv_u8m4(vuint8m4_t, vuint8m4_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vssrl_vv_m)))
vuint8m4_t vssrl_vv_u8m4_m(vbool2_t, vuint8m4_t, vuint8m4_t, vuint8m4_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vssrl_vv)))
vuint8m8_t vssrl_vv_u8m8(vuint8m8_t, vuint8m8_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vssrl_vv_m)))
vuint8m8_t vssrl_vv_u8m8_m(vbool1_t, vuint8m8_t, vuint8m8_t, vuint8m8_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vssrl_vv)))
vuint8mf2_t vssrl_vv_u8mf2(vuint8mf2_t, vuint8mf2_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vssrl_vv_m)))
vuint8mf2_t vssrl_vv_u8mf2_m(vbool16_t, vuint8mf2_t, vuint8mf2_t, vuint8mf2_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vssrl_vv)))
vuint8mf4_t vssrl_vv_u8mf4(vuint8mf4_t, vuint8mf4_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vssrl_vv_m)))
vuint8mf4_t vssrl_vv_u8mf4_m(vbool32_t, vuint8mf4_t, vuint8mf4_t, vuint8mf4_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vssrl_vv)))
vuint8mf8_t vssrl_vv_u8mf8(vuint8mf8_t, vuint8mf8_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vssrl_vv_m)))
vuint8mf8_t vssrl_vv_u8mf8_m(vbool64_t, vuint8mf8_t, vuint8mf8_t, vuint8mf8_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vssrl_vv)))
vuint16m1_t vssrl_vv_u16m1(vuint16m1_t, vuint16m1_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vssrl_vv_m)))
vuint16m1_t vssrl_vv_u16m1_m(vbool16_t, vuint16m1_t, vuint16m1_t, vuint16m1_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vssrl_vv)))
vuint16m2_t vssrl_vv_u16m2(vuint16m2_t, vuint16m2_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vssrl_vv_m)))
vuint16m2_t vssrl_vv_u16m2_m(vbool8_t, vuint16m2_t, vuint16m2_t, vuint16m2_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vssrl_vv)))
vuint16m4_t vssrl_vv_u16m4(vuint16m4_t, vuint16m4_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vssrl_vv_m)))
vuint16m4_t vssrl_vv_u16m4_m(vbool4_t, vuint16m4_t, vuint16m4_t, vuint16m4_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vssrl_vv)))
vuint16m8_t vssrl_vv_u16m8(vuint16m8_t, vuint16m8_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vssrl_vv_m)))
vuint16m8_t vssrl_vv_u16m8_m(vbool2_t, vuint16m8_t, vuint16m8_t, vuint16m8_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vssrl_vv)))
vuint16mf2_t vssrl_vv_u16mf2(vuint16mf2_t, vuint16mf2_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vssrl_vv_m)))
vuint16mf2_t vssrl_vv_u16mf2_m(vbool32_t, vuint16mf2_t, vuint16mf2_t, vuint16mf2_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vssrl_vv)))
vuint16mf4_t vssrl_vv_u16mf4(vuint16mf4_t, vuint16mf4_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vssrl_vv_m)))
vuint16mf4_t vssrl_vv_u16mf4_m(vbool64_t, vuint16mf4_t, vuint16mf4_t, vuint16mf4_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vssrl_vv)))
vuint32m1_t vssrl_vv_u32m1(vuint32m1_t, vuint32m1_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vssrl_vv_m)))
vuint32m1_t vssrl_vv_u32m1_m(vbool32_t, vuint32m1_t, vuint32m1_t, vuint32m1_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vssrl_vv)))
vuint32m2_t vssrl_vv_u32m2(vuint32m2_t, vuint32m2_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vssrl_vv_m)))
vuint32m2_t vssrl_vv_u32m2_m(vbool16_t, vuint32m2_t, vuint32m2_t, vuint32m2_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vssrl_vv)))
vuint32m4_t vssrl_vv_u32m4(vuint32m4_t, vuint32m4_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vssrl_vv_m)))
vuint32m4_t vssrl_vv_u32m4_m(vbool8_t, vuint32m4_t, vuint32m4_t, vuint32m4_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vssrl_vv)))
vuint32m8_t vssrl_vv_u32m8(vuint32m8_t, vuint32m8_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vssrl_vv_m)))
vuint32m8_t vssrl_vv_u32m8_m(vbool4_t, vuint32m8_t, vuint32m8_t, vuint32m8_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vssrl_vv)))
vuint32mf2_t vssrl_vv_u32mf2(vuint32mf2_t, vuint32mf2_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vssrl_vv_m)))
vuint32mf2_t vssrl_vv_u32mf2_m(vbool64_t, vuint32mf2_t, vuint32mf2_t, vuint32mf2_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vssrl_vx)))
vuint8m1_t vssrl_vx_u8m1(vuint8m1_t, size_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vssrl_vx_m)))
vuint8m1_t vssrl_vx_u8m1_m(vbool8_t, vuint8m1_t, vuint8m1_t, size_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vssrl_vx)))
vuint8m2_t vssrl_vx_u8m2(vuint8m2_t, size_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vssrl_vx_m)))
vuint8m2_t vssrl_vx_u8m2_m(vbool4_t, vuint8m2_t, vuint8m2_t, size_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vssrl_vx)))
vuint8m4_t vssrl_vx_u8m4(vuint8m4_t, size_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vssrl_vx_m)))
vuint8m4_t vssrl_vx_u8m4_m(vbool2_t, vuint8m4_t, vuint8m4_t, size_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vssrl_vx)))
vuint8m8_t vssrl_vx_u8m8(vuint8m8_t, size_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vssrl_vx_m)))
vuint8m8_t vssrl_vx_u8m8_m(vbool1_t, vuint8m8_t, vuint8m8_t, size_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vssrl_vx)))
vuint8mf2_t vssrl_vx_u8mf2(vuint8mf2_t, size_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vssrl_vx_m)))
vuint8mf2_t vssrl_vx_u8mf2_m(vbool16_t, vuint8mf2_t, vuint8mf2_t, size_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vssrl_vx)))
vuint8mf4_t vssrl_vx_u8mf4(vuint8mf4_t, size_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vssrl_vx_m)))
vuint8mf4_t vssrl_vx_u8mf4_m(vbool32_t, vuint8mf4_t, vuint8mf4_t, size_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vssrl_vx)))
vuint8mf8_t vssrl_vx_u8mf8(vuint8mf8_t, size_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vssrl_vx_m)))
vuint8mf8_t vssrl_vx_u8mf8_m(vbool64_t, vuint8mf8_t, vuint8mf8_t, size_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vssrl_vx)))
vuint16m1_t vssrl_vx_u16m1(vuint16m1_t, size_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vssrl_vx_m)))
vuint16m1_t vssrl_vx_u16m1_m(vbool16_t, vuint16m1_t, vuint16m1_t, size_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vssrl_vx)))
vuint16m2_t vssrl_vx_u16m2(vuint16m2_t, size_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vssrl_vx_m)))
vuint16m2_t vssrl_vx_u16m2_m(vbool8_t, vuint16m2_t, vuint16m2_t, size_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vssrl_vx)))
vuint16m4_t vssrl_vx_u16m4(vuint16m4_t, size_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vssrl_vx_m)))
vuint16m4_t vssrl_vx_u16m4_m(vbool4_t, vuint16m4_t, vuint16m4_t, size_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vssrl_vx)))
vuint16m8_t vssrl_vx_u16m8(vuint16m8_t, size_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vssrl_vx_m)))
vuint16m8_t vssrl_vx_u16m8_m(vbool2_t, vuint16m8_t, vuint16m8_t, size_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vssrl_vx)))
vuint16mf2_t vssrl_vx_u16mf2(vuint16mf2_t, size_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vssrl_vx_m)))
vuint16mf2_t vssrl_vx_u16mf2_m(vbool32_t, vuint16mf2_t, vuint16mf2_t, size_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vssrl_vx)))
vuint16mf4_t vssrl_vx_u16mf4(vuint16mf4_t, size_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vssrl_vx_m)))
vuint16mf4_t vssrl_vx_u16mf4_m(vbool64_t, vuint16mf4_t, vuint16mf4_t, size_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vssrl_vx)))
vuint32m1_t vssrl_vx_u32m1(vuint32m1_t, size_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vssrl_vx_m)))
vuint32m1_t vssrl_vx_u32m1_m(vbool32_t, vuint32m1_t, vuint32m1_t, size_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vssrl_vx)))
vuint32m2_t vssrl_vx_u32m2(vuint32m2_t, size_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vssrl_vx_m)))
vuint32m2_t vssrl_vx_u32m2_m(vbool16_t, vuint32m2_t, vuint32m2_t, size_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vssrl_vx)))
vuint32m4_t vssrl_vx_u32m4(vuint32m4_t, size_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vssrl_vx_m)))
vuint32m4_t vssrl_vx_u32m4_m(vbool8_t, vuint32m4_t, vuint32m4_t, size_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vssrl_vx)))
vuint32m8_t vssrl_vx_u32m8(vuint32m8_t, size_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vssrl_vx_m)))
vuint32m8_t vssrl_vx_u32m8_m(vbool4_t, vuint32m8_t, vuint32m8_t, size_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vssrl_vx)))
vuint32mf2_t vssrl_vx_u32mf2(vuint32mf2_t, size_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vssrl_vx_m)))
vuint32mf2_t vssrl_vx_u32mf2_m(vbool64_t, vuint32mf2_t, vuint32mf2_t, size_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vssra_vv)))
vint8m1_t vssra_vv_i8m1(vint8m1_t, vuint8m1_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vssra_vv_m)))
vint8m1_t vssra_vv_i8m1_m(vbool8_t, vint8m1_t, vint8m1_t, vuint8m1_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vssra_vv)))
vint8m2_t vssra_vv_i8m2(vint8m2_t, vuint8m2_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vssra_vv_m)))
vint8m2_t vssra_vv_i8m2_m(vbool4_t, vint8m2_t, vint8m2_t, vuint8m2_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vssra_vv)))
vint8m4_t vssra_vv_i8m4(vint8m4_t, vuint8m4_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vssra_vv_m)))
vint8m4_t vssra_vv_i8m4_m(vbool2_t, vint8m4_t, vint8m4_t, vuint8m4_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vssra_vv)))
vint8m8_t vssra_vv_i8m8(vint8m8_t, vuint8m8_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vssra_vv_m)))
vint8m8_t vssra_vv_i8m8_m(vbool1_t, vint8m8_t, vint8m8_t, vuint8m8_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vssra_vv)))
vint8mf2_t vssra_vv_i8mf2(vint8mf2_t, vuint8mf2_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vssra_vv_m)))
vint8mf2_t vssra_vv_i8mf2_m(vbool16_t, vint8mf2_t, vint8mf2_t, vuint8mf2_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vssra_vv)))
vint8mf4_t vssra_vv_i8mf4(vint8mf4_t, vuint8mf4_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vssra_vv_m)))
vint8mf4_t vssra_vv_i8mf4_m(vbool32_t, vint8mf4_t, vint8mf4_t, vuint8mf4_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vssra_vv)))
vint8mf8_t vssra_vv_i8mf8(vint8mf8_t, vuint8mf8_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vssra_vv_m)))
vint8mf8_t vssra_vv_i8mf8_m(vbool64_t, vint8mf8_t, vint8mf8_t, vuint8mf8_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vssra_vv)))
vint16m1_t vssra_vv_i16m1(vint16m1_t, vuint16m1_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vssra_vv_m)))
vint16m1_t vssra_vv_i16m1_m(vbool16_t, vint16m1_t, vint16m1_t, vuint16m1_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vssra_vv)))
vint16m2_t vssra_vv_i16m2(vint16m2_t, vuint16m2_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vssra_vv_m)))
vint16m2_t vssra_vv_i16m2_m(vbool8_t, vint16m2_t, vint16m2_t, vuint16m2_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vssra_vv)))
vint16m4_t vssra_vv_i16m4(vint16m4_t, vuint16m4_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vssra_vv_m)))
vint16m4_t vssra_vv_i16m4_m(vbool4_t, vint16m4_t, vint16m4_t, vuint16m4_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vssra_vv)))
vint16m8_t vssra_vv_i16m8(vint16m8_t, vuint16m8_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vssra_vv_m)))
vint16m8_t vssra_vv_i16m8_m(vbool2_t, vint16m8_t, vint16m8_t, vuint16m8_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vssra_vv)))
vint16mf2_t vssra_vv_i16mf2(vint16mf2_t, vuint16mf2_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vssra_vv_m)))
vint16mf2_t vssra_vv_i16mf2_m(vbool32_t, vint16mf2_t, vint16mf2_t, vuint16mf2_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vssra_vv)))
vint16mf4_t vssra_vv_i16mf4(vint16mf4_t, vuint16mf4_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vssra_vv_m)))
vint16mf4_t vssra_vv_i16mf4_m(vbool64_t, vint16mf4_t, vint16mf4_t, vuint16mf4_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vssra_vv)))
vint32m1_t vssra_vv_i32m1(vint32m1_t, vuint32m1_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vssra_vv_m)))
vint32m1_t vssra_vv_i32m1_m(vbool32_t, vint32m1_t, vint32m1_t, vuint32m1_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vssra_vv)))
vint32m2_t vssra_vv_i32m2(vint32m2_t, vuint32m2_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vssra_vv_m)))
vint32m2_t vssra_vv_i32m2_m(vbool16_t, vint32m2_t, vint32m2_t, vuint32m2_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vssra_vv)))
vint32m4_t vssra_vv_i32m4(vint32m4_t, vuint32m4_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vssra_vv_m)))
vint32m4_t vssra_vv_i32m4_m(vbool8_t, vint32m4_t, vint32m4_t, vuint32m4_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vssra_vv)))
vint32m8_t vssra_vv_i32m8(vint32m8_t, vuint32m8_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vssra_vv_m)))
vint32m8_t vssra_vv_i32m8_m(vbool4_t, vint32m8_t, vint32m8_t, vuint32m8_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vssra_vv)))
vint32mf2_t vssra_vv_i32mf2(vint32mf2_t, vuint32mf2_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vssra_vv_m)))
vint32mf2_t vssra_vv_i32mf2_m(vbool64_t, vint32mf2_t, vint32mf2_t, vuint32mf2_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vssra_vx)))
vint8m1_t vssra_vx_i8m1(vint8m1_t, size_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vssra_vx_m)))
vint8m1_t vssra_vx_i8m1_m(vbool8_t, vint8m1_t, vint8m1_t, size_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vssra_vx)))
vint8m2_t vssra_vx_i8m2(vint8m2_t, size_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vssra_vx_m)))
vint8m2_t vssra_vx_i8m2_m(vbool4_t, vint8m2_t, vint8m2_t, size_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vssra_vx)))
vint8m4_t vssra_vx_i8m4(vint8m4_t, size_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vssra_vx_m)))
vint8m4_t vssra_vx_i8m4_m(vbool2_t, vint8m4_t, vint8m4_t, size_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vssra_vx)))
vint8m8_t vssra_vx_i8m8(vint8m8_t, size_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vssra_vx_m)))
vint8m8_t vssra_vx_i8m8_m(vbool1_t, vint8m8_t, vint8m8_t, size_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vssra_vx)))
vint8mf2_t vssra_vx_i8mf2(vint8mf2_t, size_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vssra_vx_m)))
vint8mf2_t vssra_vx_i8mf2_m(vbool16_t, vint8mf2_t, vint8mf2_t, size_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vssra_vx)))
vint8mf4_t vssra_vx_i8mf4(vint8mf4_t, size_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vssra_vx_m)))
vint8mf4_t vssra_vx_i8mf4_m(vbool32_t, vint8mf4_t, vint8mf4_t, size_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vssra_vx)))
vint8mf8_t vssra_vx_i8mf8(vint8mf8_t, size_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vssra_vx_m)))
vint8mf8_t vssra_vx_i8mf8_m(vbool64_t, vint8mf8_t, vint8mf8_t, size_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vssra_vx)))
vint16m1_t vssra_vx_i16m1(vint16m1_t, size_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vssra_vx_m)))
vint16m1_t vssra_vx_i16m1_m(vbool16_t, vint16m1_t, vint16m1_t, size_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vssra_vx)))
vint16m2_t vssra_vx_i16m2(vint16m2_t, size_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vssra_vx_m)))
vint16m2_t vssra_vx_i16m2_m(vbool8_t, vint16m2_t, vint16m2_t, size_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vssra_vx)))
vint16m4_t vssra_vx_i16m4(vint16m4_t, size_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vssra_vx_m)))
vint16m4_t vssra_vx_i16m4_m(vbool4_t, vint16m4_t, vint16m4_t, size_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vssra_vx)))
vint16m8_t vssra_vx_i16m8(vint16m8_t, size_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vssra_vx_m)))
vint16m8_t vssra_vx_i16m8_m(vbool2_t, vint16m8_t, vint16m8_t, size_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vssra_vx)))
vint16mf2_t vssra_vx_i16mf2(vint16mf2_t, size_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vssra_vx_m)))
vint16mf2_t vssra_vx_i16mf2_m(vbool32_t, vint16mf2_t, vint16mf2_t, size_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vssra_vx)))
vint16mf4_t vssra_vx_i16mf4(vint16mf4_t, size_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vssra_vx_m)))
vint16mf4_t vssra_vx_i16mf4_m(vbool64_t, vint16mf4_t, vint16mf4_t, size_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vssra_vx)))
vint32m1_t vssra_vx_i32m1(vint32m1_t, size_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vssra_vx_m)))
vint32m1_t vssra_vx_i32m1_m(vbool32_t, vint32m1_t, vint32m1_t, size_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vssra_vx)))
vint32m2_t vssra_vx_i32m2(vint32m2_t, size_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vssra_vx_m)))
vint32m2_t vssra_vx_i32m2_m(vbool16_t, vint32m2_t, vint32m2_t, size_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vssra_vx)))
vint32m4_t vssra_vx_i32m4(vint32m4_t, size_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vssra_vx_m)))
vint32m4_t vssra_vx_i32m4_m(vbool8_t, vint32m4_t, vint32m4_t, size_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vssra_vx)))
vint32m8_t vssra_vx_i32m8(vint32m8_t, size_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vssra_vx_m)))
vint32m8_t vssra_vx_i32m8_m(vbool4_t, vint32m8_t, vint32m8_t, size_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vssra_vx)))
vint32mf2_t vssra_vx_i32mf2(vint32mf2_t, size_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vssra_vx_m)))
vint32mf2_t vssra_vx_i32mf2_m(vbool64_t, vint32mf2_t, vint32mf2_t, size_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vnclipu_wv)))
vuint8m1_t vnclipu_wv_u8m1(vuint16m2_t, vuint8m1_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vnclipu_wv_m)))
vuint8m1_t vnclipu_wv_u8m1_m(vbool8_t, vuint8m1_t, vuint16m2_t, vuint8m1_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vnclipu_wv)))
vuint8m2_t vnclipu_wv_u8m2(vuint16m4_t, vuint8m2_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vnclipu_wv_m)))
vuint8m2_t vnclipu_wv_u8m2_m(vbool4_t, vuint8m2_t, vuint16m4_t, vuint8m2_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vnclipu_wv)))
vuint8m4_t vnclipu_wv_u8m4(vuint16m8_t, vuint8m4_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vnclipu_wv_m)))
vuint8m4_t vnclipu_wv_u8m4_m(vbool2_t, vuint8m4_t, vuint16m8_t, vuint8m4_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vnclipu_wv)))
vuint8mf2_t vnclipu_wv_u8mf2(vuint16m1_t, vuint8mf2_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vnclipu_wv_m)))
vuint8mf2_t vnclipu_wv_u8mf2_m(vbool16_t, vuint8mf2_t, vuint16m1_t, vuint8mf2_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vnclipu_wv)))
vuint8mf4_t vnclipu_wv_u8mf4(vuint16mf2_t, vuint8mf4_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vnclipu_wv_m)))
vuint8mf4_t vnclipu_wv_u8mf4_m(vbool32_t, vuint8mf4_t, vuint16mf2_t, vuint8mf4_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vnclipu_wv)))
vuint8mf8_t vnclipu_wv_u8mf8(vuint16mf4_t, vuint8mf8_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vnclipu_wv_m)))
vuint8mf8_t vnclipu_wv_u8mf8_m(vbool64_t, vuint8mf8_t, vuint16mf4_t, vuint8mf8_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vnclipu_wv)))
vuint16m1_t vnclipu_wv_u16m1(vuint32m2_t, vuint16m1_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vnclipu_wv_m)))
vuint16m1_t vnclipu_wv_u16m1_m(vbool16_t, vuint16m1_t, vuint32m2_t, vuint16m1_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vnclipu_wv)))
vuint16m2_t vnclipu_wv_u16m2(vuint32m4_t, vuint16m2_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vnclipu_wv_m)))
vuint16m2_t vnclipu_wv_u16m2_m(vbool8_t, vuint16m2_t, vuint32m4_t, vuint16m2_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vnclipu_wv)))
vuint16m4_t vnclipu_wv_u16m4(vuint32m8_t, vuint16m4_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vnclipu_wv_m)))
vuint16m4_t vnclipu_wv_u16m4_m(vbool4_t, vuint16m4_t, vuint32m8_t, vuint16m4_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vnclipu_wv)))
vuint16mf2_t vnclipu_wv_u16mf2(vuint32m1_t, vuint16mf2_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vnclipu_wv_m)))
vuint16mf2_t vnclipu_wv_u16mf2_m(vbool32_t, vuint16mf2_t, vuint32m1_t, vuint16mf2_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vnclipu_wv)))
vuint16mf4_t vnclipu_wv_u16mf4(vuint32mf2_t, vuint16mf4_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vnclipu_wv_m)))
vuint16mf4_t vnclipu_wv_u16mf4_m(vbool64_t, vuint16mf4_t, vuint32mf2_t, vuint16mf4_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vnclipu_wx)))
vuint8m1_t vnclipu_wx_u8m1(vuint16m2_t, size_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vnclipu_wx_m)))
vuint8m1_t vnclipu_wx_u8m1_m(vbool8_t, vuint8m1_t, vuint16m2_t, size_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vnclipu_wx)))
vuint8m2_t vnclipu_wx_u8m2(vuint16m4_t, size_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vnclipu_wx_m)))
vuint8m2_t vnclipu_wx_u8m2_m(vbool4_t, vuint8m2_t, vuint16m4_t, size_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vnclipu_wx)))
vuint8m4_t vnclipu_wx_u8m4(vuint16m8_t, size_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vnclipu_wx_m)))
vuint8m4_t vnclipu_wx_u8m4_m(vbool2_t, vuint8m4_t, vuint16m8_t, size_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vnclipu_wx)))
vuint8mf2_t vnclipu_wx_u8mf2(vuint16m1_t, size_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vnclipu_wx_m)))
vuint8mf2_t vnclipu_wx_u8mf2_m(vbool16_t, vuint8mf2_t, vuint16m1_t, size_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vnclipu_wx)))
vuint8mf4_t vnclipu_wx_u8mf4(vuint16mf2_t, size_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vnclipu_wx_m)))
vuint8mf4_t vnclipu_wx_u8mf4_m(vbool32_t, vuint8mf4_t, vuint16mf2_t, size_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vnclipu_wx)))
vuint8mf8_t vnclipu_wx_u8mf8(vuint16mf4_t, size_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vnclipu_wx_m)))
vuint8mf8_t vnclipu_wx_u8mf8_m(vbool64_t, vuint8mf8_t, vuint16mf4_t, size_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vnclipu_wx)))
vuint16m1_t vnclipu_wx_u16m1(vuint32m2_t, size_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vnclipu_wx_m)))
vuint16m1_t vnclipu_wx_u16m1_m(vbool16_t, vuint16m1_t, vuint32m2_t, size_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vnclipu_wx)))
vuint16m2_t vnclipu_wx_u16m2(vuint32m4_t, size_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vnclipu_wx_m)))
vuint16m2_t vnclipu_wx_u16m2_m(vbool8_t, vuint16m2_t, vuint32m4_t, size_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vnclipu_wx)))
vuint16m4_t vnclipu_wx_u16m4(vuint32m8_t, size_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vnclipu_wx_m)))
vuint16m4_t vnclipu_wx_u16m4_m(vbool4_t, vuint16m4_t, vuint32m8_t, size_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vnclipu_wx)))
vuint16mf2_t vnclipu_wx_u16mf2(vuint32m1_t, size_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vnclipu_wx_m)))
vuint16mf2_t vnclipu_wx_u16mf2_m(vbool32_t, vuint16mf2_t, vuint32m1_t, size_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vnclipu_wx)))
vuint16mf4_t vnclipu_wx_u16mf4(vuint32mf2_t, size_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vnclipu_wx_m)))
vuint16mf4_t vnclipu_wx_u16mf4_m(vbool64_t, vuint16mf4_t, vuint32mf2_t, size_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vsuxei32_v)))
void vsuxei32_v_u16m1(uint16_t *, vuint32m2_t, vuint16m1_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vsuxei32_v_m)))
void vsuxei32_v_u16m1_m(vbool16_t, uint16_t *, vuint32m2_t, vuint16m1_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vsuxei32_v)))
void vsuxei32_v_u16m2(uint16_t *, vuint32m4_t, vuint16m2_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vsuxei32_v_m)))
void vsuxei32_v_u16m2_m(vbool8_t, uint16_t *, vuint32m4_t, vuint16m2_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vsuxei32_v)))
void vsuxei32_v_u16m4(uint16_t *, vuint32m8_t, vuint16m4_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vsuxei32_v_m)))
void vsuxei32_v_u16m4_m(vbool4_t, uint16_t *, vuint32m8_t, vuint16m4_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vsuxei32_v)))
void vsuxei32_v_u16mf2(uint16_t *, vuint32m1_t, vuint16mf2_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vsuxei32_v_m)))
void vsuxei32_v_u16mf2_m(vbool32_t, uint16_t *, vuint32m1_t, vuint16mf2_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vsuxei32_v)))
void vsuxei32_v_u16mf4(uint16_t *, vuint32mf2_t, vuint16mf4_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vsuxei32_v_m)))
void vsuxei32_v_u16mf4_m(vbool64_t, uint16_t *, vuint32mf2_t, vuint16mf4_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vnclip_wv)))
vint8m1_t vnclip_wv_i8m1(vint16m2_t, vuint8m1_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vnclip_wv_m)))
vint8m1_t vnclip_wv_i8m1_m(vbool8_t, vint8m1_t, vint16m2_t, vuint8m1_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vnclip_wv)))
vint8m2_t vnclip_wv_i8m2(vint16m4_t, vuint8m2_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vnclip_wv_m)))
vint8m2_t vnclip_wv_i8m2_m(vbool4_t, vint8m2_t, vint16m4_t, vuint8m2_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vnclip_wv)))
vint8m4_t vnclip_wv_i8m4(vint16m8_t, vuint8m4_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vnclip_wv_m)))
vint8m4_t vnclip_wv_i8m4_m(vbool2_t, vint8m4_t, vint16m8_t, vuint8m4_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vnclip_wv)))
vint8mf2_t vnclip_wv_i8mf2(vint16m1_t, vuint8mf2_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vnclip_wv_m)))
vint8mf2_t vnclip_wv_i8mf2_m(vbool16_t, vint8mf2_t, vint16m1_t, vuint8mf2_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vnclip_wv)))
vint8mf4_t vnclip_wv_i8mf4(vint16mf2_t, vuint8mf4_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vnclip_wv_m)))
vint8mf4_t vnclip_wv_i8mf4_m(vbool32_t, vint8mf4_t, vint16mf2_t, vuint8mf4_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vnclip_wv)))
vint8mf8_t vnclip_wv_i8mf8(vint16mf4_t, vuint8mf8_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vnclip_wv_m)))
vint8mf8_t vnclip_wv_i8mf8_m(vbool64_t, vint8mf8_t, vint16mf4_t, vuint8mf8_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vnclip_wv)))
vint16m1_t vnclip_wv_i16m1(vint32m2_t, vuint16m1_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vnclip_wv_m)))
vint16m1_t vnclip_wv_i16m1_m(vbool16_t, vint16m1_t, vint32m2_t, vuint16m1_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vnclip_wv)))
vint16m2_t vnclip_wv_i16m2(vint32m4_t, vuint16m2_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vnclip_wv_m)))
vint16m2_t vnclip_wv_i16m2_m(vbool8_t, vint16m2_t, vint32m4_t, vuint16m2_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vnclip_wv)))
vint16m4_t vnclip_wv_i16m4(vint32m8_t, vuint16m4_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vnclip_wv_m)))
vint16m4_t vnclip_wv_i16m4_m(vbool4_t, vint16m4_t, vint32m8_t, vuint16m4_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vnclip_wv)))
vint16mf2_t vnclip_wv_i16mf2(vint32m1_t, vuint16mf2_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vnclip_wv_m)))
vint16mf2_t vnclip_wv_i16mf2_m(vbool32_t, vint16mf2_t, vint32m1_t, vuint16mf2_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vnclip_wv)))
vint16mf4_t vnclip_wv_i16mf4(vint32mf2_t, vuint16mf4_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vnclip_wv_m)))
vint16mf4_t vnclip_wv_i16mf4_m(vbool64_t, vint16mf4_t, vint32mf2_t, vuint16mf4_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vnclip_wx)))
vint8m1_t vnclip_wx_i8m1(vint16m2_t, size_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vnclip_wx_m)))
vint8m1_t vnclip_wx_i8m1_m(vbool8_t, vint8m1_t, vint16m2_t, size_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vnclip_wx)))
vint8m2_t vnclip_wx_i8m2(vint16m4_t, size_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vnclip_wx_m)))
vint8m2_t vnclip_wx_i8m2_m(vbool4_t, vint8m2_t, vint16m4_t, size_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vnclip_wx)))
vint8m4_t vnclip_wx_i8m4(vint16m8_t, size_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vnclip_wx_m)))
vint8m4_t vnclip_wx_i8m4_m(vbool2_t, vint8m4_t, vint16m8_t, size_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vnclip_wx)))
vint8mf2_t vnclip_wx_i8mf2(vint16m1_t, size_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vnclip_wx_m)))
vint8mf2_t vnclip_wx_i8mf2_m(vbool16_t, vint8mf2_t, vint16m1_t, size_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vnclip_wx)))
vint8mf4_t vnclip_wx_i8mf4(vint16mf2_t, size_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vnclip_wx_m)))
vint8mf4_t vnclip_wx_i8mf4_m(vbool32_t, vint8mf4_t, vint16mf2_t, size_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vnclip_wx)))
vint8mf8_t vnclip_wx_i8mf8(vint16mf4_t, size_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vnclip_wx_m)))
vint8mf8_t vnclip_wx_i8mf8_m(vbool64_t, vint8mf8_t, vint16mf4_t, size_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vnclip_wx)))
vint16m1_t vnclip_wx_i16m1(vint32m2_t, size_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vnclip_wx_m)))
vint16m1_t vnclip_wx_i16m1_m(vbool16_t, vint16m1_t, vint32m2_t, size_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vnclip_wx)))
vint16m2_t vnclip_wx_i16m2(vint32m4_t, size_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vnclip_wx_m)))
vint16m2_t vnclip_wx_i16m2_m(vbool8_t, vint16m2_t, vint32m4_t, size_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vnclip_wx)))
vint16m4_t vnclip_wx_i16m4(vint32m8_t, size_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vnclip_wx_m)))
vint16m4_t vnclip_wx_i16m4_m(vbool4_t, vint16m4_t, vint32m8_t, size_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vnclip_wx)))
vint16mf2_t vnclip_wx_i16mf2(vint32m1_t, size_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vnclip_wx_m)))
vint16mf2_t vnclip_wx_i16mf2_m(vbool32_t, vint16mf2_t, vint32m1_t, size_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vnclip_wx)))
vint16mf4_t vnclip_wx_i16mf4(vint32mf2_t, size_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vnclip_wx_m)))
vint16mf4_t vnclip_wx_i16mf4_m(vbool64_t, vint16mf4_t, vint32mf2_t, size_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vse8_v)))
void vse8_v_u8m1(uint8_t *, vuint8m1_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vse8_v_m)))
void vse8_v_u8m1_m(vbool8_t, uint8_t *, vuint8m1_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vse8_v)))
void vse8_v_u8m2(uint8_t *, vuint8m2_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vse8_v_m)))
void vse8_v_u8m2_m(vbool4_t, uint8_t *, vuint8m2_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vse8_v)))
void vse8_v_u8m4(uint8_t *, vuint8m4_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vse8_v_m)))
void vse8_v_u8m4_m(vbool2_t, uint8_t *, vuint8m4_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vse8_v)))
void vse8_v_u8m8(uint8_t *, vuint8m8_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vse8_v_m)))
void vse8_v_u8m8_m(vbool1_t, uint8_t *, vuint8m8_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vse8_v)))
void vse8_v_u8mf2(uint8_t *, vuint8mf2_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vse8_v_m)))
void vse8_v_u8mf2_m(vbool16_t, uint8_t *, vuint8mf2_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vse8_v)))
void vse8_v_u8mf4(uint8_t *, vuint8mf4_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vse8_v_m)))
void vse8_v_u8mf4_m(vbool32_t, uint8_t *, vuint8mf4_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vse8_v)))
void vse8_v_u8mf8(uint8_t *, vuint8mf8_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vse8_v_m)))
void vse8_v_u8mf8_m(vbool64_t, uint8_t *, vuint8mf8_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vsuxei8_v)))
void vsuxei8_v_i32m1(int32_t *, vuint8mf4_t, vint32m1_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vsuxei8_v_m)))
void vsuxei8_v_i32m1_m(vbool32_t, int32_t *, vuint8mf4_t, vint32m1_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vsuxei8_v)))
void vsuxei8_v_i32m2(int32_t *, vuint8mf2_t, vint32m2_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vsuxei8_v_m)))
void vsuxei8_v_i32m2_m(vbool16_t, int32_t *, vuint8mf2_t, vint32m2_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vsuxei8_v)))
void vsuxei8_v_i32m4(int32_t *, vuint8m1_t, vint32m4_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vsuxei8_v_m)))
void vsuxei8_v_i32m4_m(vbool8_t, int32_t *, vuint8m1_t, vint32m4_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vsuxei8_v)))
void vsuxei8_v_i32m8(int32_t *, vuint8m2_t, vint32m8_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vsuxei8_v_m)))
void vsuxei8_v_i32m8_m(vbool4_t, int32_t *, vuint8m2_t, vint32m8_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vsuxei8_v)))
void vsuxei8_v_i32mf2(int32_t *, vuint8mf8_t, vint32mf2_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vsuxei8_v_m)))
void vsuxei8_v_i32mf2_m(vbool64_t, int32_t *, vuint8mf8_t, vint32mf2_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vsuxei8_v)))
void vsuxei8_v_u32m1(uint32_t *, vuint8mf4_t, vuint32m1_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vsuxei8_v_m)))
void vsuxei8_v_u32m1_m(vbool32_t, uint32_t *, vuint8mf4_t, vuint32m1_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vsuxei8_v)))
void vsuxei8_v_u32m2(uint32_t *, vuint8mf2_t, vuint32m2_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vsuxei8_v_m)))
void vsuxei8_v_u32m2_m(vbool16_t, uint32_t *, vuint8mf2_t, vuint32m2_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vsuxei8_v)))
void vsuxei8_v_u32m4(uint32_t *, vuint8m1_t, vuint32m4_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vsuxei8_v_m)))
void vsuxei8_v_u32m4_m(vbool8_t, uint32_t *, vuint8m1_t, vuint32m4_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vsuxei8_v)))
void vsuxei8_v_u32m8(uint32_t *, vuint8m2_t, vuint32m8_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vsuxei8_v_m)))
void vsuxei8_v_u32m8_m(vbool4_t, uint32_t *, vuint8m2_t, vuint32m8_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vsuxei8_v)))
void vsuxei8_v_u32mf2(uint32_t *, vuint8mf8_t, vuint32mf2_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vsuxei8_v_m)))
void vsuxei8_v_u32mf2_m(vbool64_t, uint32_t *, vuint8mf8_t, vuint32mf2_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vsuxei16_v)))
void vsuxei16_v_i32m1(int32_t *, vuint16mf2_t, vint32m1_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vsuxei16_v_m)))
void vsuxei16_v_i32m1_m(vbool32_t, int32_t *, vuint16mf2_t, vint32m1_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vsuxei16_v)))
void vsuxei16_v_i32m2(int32_t *, vuint16m1_t, vint32m2_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vsuxei16_v_m)))
void vsuxei16_v_i32m2_m(vbool16_t, int32_t *, vuint16m1_t, vint32m2_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vsuxei16_v)))
void vsuxei16_v_i32m4(int32_t *, vuint16m2_t, vint32m4_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vsuxei16_v_m)))
void vsuxei16_v_i32m4_m(vbool8_t, int32_t *, vuint16m2_t, vint32m4_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vsuxei16_v)))
void vsuxei16_v_i32m8(int32_t *, vuint16m4_t, vint32m8_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vsuxei16_v_m)))
void vsuxei16_v_i32m8_m(vbool4_t, int32_t *, vuint16m4_t, vint32m8_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vsuxei16_v)))
void vsuxei16_v_i32mf2(int32_t *, vuint16mf4_t, vint32mf2_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vsuxei16_v_m)))
void vsuxei16_v_i32mf2_m(vbool64_t, int32_t *, vuint16mf4_t, vint32mf2_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vsuxei16_v)))
void vsuxei16_v_u32m1(uint32_t *, vuint16mf2_t, vuint32m1_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vsuxei16_v_m)))
void vsuxei16_v_u32m1_m(vbool32_t, uint32_t *, vuint16mf2_t, vuint32m1_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vsuxei16_v)))
void vsuxei16_v_u32m2(uint32_t *, vuint16m1_t, vuint32m2_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vsuxei16_v_m)))
void vsuxei16_v_u32m2_m(vbool16_t, uint32_t *, vuint16m1_t, vuint32m2_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vsuxei16_v)))
void vsuxei16_v_u32m4(uint32_t *, vuint16m2_t, vuint32m4_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vsuxei16_v_m)))
void vsuxei16_v_u32m4_m(vbool8_t, uint32_t *, vuint16m2_t, vuint32m4_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vsuxei16_v)))
void vsuxei16_v_u32m8(uint32_t *, vuint16m4_t, vuint32m8_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vsuxei16_v_m)))
void vsuxei16_v_u32m8_m(vbool4_t, uint32_t *, vuint16m4_t, vuint32m8_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vsuxei16_v)))
void vsuxei16_v_u32mf2(uint32_t *, vuint16mf4_t, vuint32mf2_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vsuxei16_v_m)))
void vsuxei16_v_u32mf2_m(vbool64_t, uint32_t *, vuint16mf4_t, vuint32mf2_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vsuxei32_v)))
void vsuxei32_v_i32m1(int32_t *, vuint32m1_t, vint32m1_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vsuxei32_v_m)))
void vsuxei32_v_i32m1_m(vbool32_t, int32_t *, vuint32m1_t, vint32m1_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vsuxei32_v)))
void vsuxei32_v_i32m2(int32_t *, vuint32m2_t, vint32m2_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vsuxei32_v_m)))
void vsuxei32_v_i32m2_m(vbool16_t, int32_t *, vuint32m2_t, vint32m2_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vsuxei32_v)))
void vsuxei32_v_i32m4(int32_t *, vuint32m4_t, vint32m4_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vsuxei32_v_m)))
void vsuxei32_v_i32m4_m(vbool8_t, int32_t *, vuint32m4_t, vint32m4_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vsuxei32_v)))
void vsuxei32_v_i32m8(int32_t *, vuint32m8_t, vint32m8_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vsuxei32_v_m)))
void vsuxei32_v_i32m8_m(vbool4_t, int32_t *, vuint32m8_t, vint32m8_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vsuxei32_v)))
void vsuxei32_v_i32mf2(int32_t *, vuint32mf2_t, vint32mf2_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vsuxei32_v_m)))
void vsuxei32_v_i32mf2_m(vbool64_t, int32_t *, vuint32mf2_t, vint32mf2_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vredsum_vs)))
vint8m1_t vredsum_vs_i8m1_i8m1(vint8m1_t, vint8m1_t, vint8m1_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vredsum_vs_m)))
vint8m1_t vredsum_vs_i8m1_i8m1_m(vbool8_t, vint8m1_t, vint8m1_t, vint8m1_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vredsum_vs)))
vint8m1_t vredsum_vs_i8m2_i8m1(vint8m1_t, vint8m2_t, vint8m1_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vredsum_vs_m)))
vint8m1_t vredsum_vs_i8m2_i8m1_m(vbool4_t, vint8m1_t, vint8m2_t, vint8m1_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vredsum_vs)))
vint8m1_t vredsum_vs_i8m4_i8m1(vint8m1_t, vint8m4_t, vint8m1_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vredsum_vs_m)))
vint8m1_t vredsum_vs_i8m4_i8m1_m(vbool2_t, vint8m1_t, vint8m4_t, vint8m1_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vredsum_vs)))
vint8m1_t vredsum_vs_i8m8_i8m1(vint8m1_t, vint8m8_t, vint8m1_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vredsum_vs_m)))
vint8m1_t vredsum_vs_i8m8_i8m1_m(vbool1_t, vint8m1_t, vint8m8_t, vint8m1_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vredsum_vs)))
vint8m1_t vredsum_vs_i8mf2_i8m1(vint8m1_t, vint8mf2_t, vint8m1_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vredsum_vs_m)))
vint8m1_t vredsum_vs_i8mf2_i8m1_m(vbool16_t, vint8m1_t, vint8mf2_t, vint8m1_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vredsum_vs)))
vint8m1_t vredsum_vs_i8mf4_i8m1(vint8m1_t, vint8mf4_t, vint8m1_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vredsum_vs_m)))
vint8m1_t vredsum_vs_i8mf4_i8m1_m(vbool32_t, vint8m1_t, vint8mf4_t, vint8m1_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vredsum_vs)))
vint8m1_t vredsum_vs_i8mf8_i8m1(vint8m1_t, vint8mf8_t, vint8m1_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vredsum_vs_m)))
vint8m1_t vredsum_vs_i8mf8_i8m1_m(vbool64_t, vint8m1_t, vint8mf8_t, vint8m1_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vredsum_vs)))
vint16m1_t vredsum_vs_i16m1_i16m1(vint16m1_t, vint16m1_t, vint16m1_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vredsum_vs_m)))
vint16m1_t vredsum_vs_i16m1_i16m1_m(vbool16_t, vint16m1_t, vint16m1_t, vint16m1_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vredsum_vs)))
vint16m1_t vredsum_vs_i16m2_i16m1(vint16m1_t, vint16m2_t, vint16m1_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vredsum_vs_m)))
vint16m1_t vredsum_vs_i16m2_i16m1_m(vbool8_t, vint16m1_t, vint16m2_t, vint16m1_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vredsum_vs)))
vint16m1_t vredsum_vs_i16m4_i16m1(vint16m1_t, vint16m4_t, vint16m1_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vredsum_vs_m)))
vint16m1_t vredsum_vs_i16m4_i16m1_m(vbool4_t, vint16m1_t, vint16m4_t, vint16m1_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vredsum_vs)))
vint16m1_t vredsum_vs_i16m8_i16m1(vint16m1_t, vint16m8_t, vint16m1_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vredsum_vs_m)))
vint16m1_t vredsum_vs_i16m8_i16m1_m(vbool2_t, vint16m1_t, vint16m8_t, vint16m1_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vredsum_vs)))
vint16m1_t vredsum_vs_i16mf2_i16m1(vint16m1_t, vint16mf2_t, vint16m1_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vredsum_vs_m)))
vint16m1_t vredsum_vs_i16mf2_i16m1_m(vbool32_t, vint16m1_t, vint16mf2_t, vint16m1_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vredsum_vs)))
vint16m1_t vredsum_vs_i16mf4_i16m1(vint16m1_t, vint16mf4_t, vint16m1_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vredsum_vs_m)))
vint16m1_t vredsum_vs_i16mf4_i16m1_m(vbool64_t, vint16m1_t, vint16mf4_t, vint16m1_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vredsum_vs)))
vint32m1_t vredsum_vs_i32m1_i32m1(vint32m1_t, vint32m1_t, vint32m1_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vredsum_vs_m)))
vint32m1_t vredsum_vs_i32m1_i32m1_m(vbool32_t, vint32m1_t, vint32m1_t, vint32m1_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vredsum_vs)))
vint32m1_t vredsum_vs_i32m2_i32m1(vint32m1_t, vint32m2_t, vint32m1_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vredsum_vs_m)))
vint32m1_t vredsum_vs_i32m2_i32m1_m(vbool16_t, vint32m1_t, vint32m2_t, vint32m1_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vredsum_vs)))
vint32m1_t vredsum_vs_i32m4_i32m1(vint32m1_t, vint32m4_t, vint32m1_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vredsum_vs_m)))
vint32m1_t vredsum_vs_i32m4_i32m1_m(vbool8_t, vint32m1_t, vint32m4_t, vint32m1_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vredsum_vs)))
vint32m1_t vredsum_vs_i32m8_i32m1(vint32m1_t, vint32m8_t, vint32m1_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vredsum_vs_m)))
vint32m1_t vredsum_vs_i32m8_i32m1_m(vbool4_t, vint32m1_t, vint32m8_t, vint32m1_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vredsum_vs)))
vint32m1_t vredsum_vs_i32mf2_i32m1(vint32m1_t, vint32mf2_t, vint32m1_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vredsum_vs_m)))
vint32m1_t vredsum_vs_i32mf2_i32m1_m(vbool64_t, vint32m1_t, vint32mf2_t, vint32m1_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vredsum_vs)))
vuint8m1_t vredsum_vs_u8m1_u8m1(vuint8m1_t, vuint8m1_t, vuint8m1_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vredsum_vs_m)))
vuint8m1_t vredsum_vs_u8m1_u8m1_m(vbool8_t, vuint8m1_t, vuint8m1_t, vuint8m1_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vredsum_vs)))
vuint8m1_t vredsum_vs_u8m2_u8m1(vuint8m1_t, vuint8m2_t, vuint8m1_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vredsum_vs_m)))
vuint8m1_t vredsum_vs_u8m2_u8m1_m(vbool4_t, vuint8m1_t, vuint8m2_t, vuint8m1_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vredsum_vs)))
vuint8m1_t vredsum_vs_u8m4_u8m1(vuint8m1_t, vuint8m4_t, vuint8m1_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vredsum_vs_m)))
vuint8m1_t vredsum_vs_u8m4_u8m1_m(vbool2_t, vuint8m1_t, vuint8m4_t, vuint8m1_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vredsum_vs)))
vuint8m1_t vredsum_vs_u8m8_u8m1(vuint8m1_t, vuint8m8_t, vuint8m1_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vredsum_vs_m)))
vuint8m1_t vredsum_vs_u8m8_u8m1_m(vbool1_t, vuint8m1_t, vuint8m8_t, vuint8m1_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vredsum_vs)))
vuint8m1_t vredsum_vs_u8mf2_u8m1(vuint8m1_t, vuint8mf2_t, vuint8m1_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vredsum_vs_m)))
vuint8m1_t vredsum_vs_u8mf2_u8m1_m(vbool16_t, vuint8m1_t, vuint8mf2_t, vuint8m1_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vredsum_vs)))
vuint8m1_t vredsum_vs_u8mf4_u8m1(vuint8m1_t, vuint8mf4_t, vuint8m1_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vredsum_vs_m)))
vuint8m1_t vredsum_vs_u8mf4_u8m1_m(vbool32_t, vuint8m1_t, vuint8mf4_t, vuint8m1_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vredsum_vs)))
vuint8m1_t vredsum_vs_u8mf8_u8m1(vuint8m1_t, vuint8mf8_t, vuint8m1_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vredsum_vs_m)))
vuint8m1_t vredsum_vs_u8mf8_u8m1_m(vbool64_t, vuint8m1_t, vuint8mf8_t, vuint8m1_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vredsum_vs)))
vuint16m1_t vredsum_vs_u16m1_u16m1(vuint16m1_t, vuint16m1_t, vuint16m1_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vredsum_vs_m)))
vuint16m1_t vredsum_vs_u16m1_u16m1_m(vbool16_t, vuint16m1_t, vuint16m1_t, vuint16m1_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vredsum_vs)))
vuint16m1_t vredsum_vs_u16m2_u16m1(vuint16m1_t, vuint16m2_t, vuint16m1_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vredsum_vs_m)))
vuint16m1_t vredsum_vs_u16m2_u16m1_m(vbool8_t, vuint16m1_t, vuint16m2_t, vuint16m1_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vredsum_vs)))
vuint16m1_t vredsum_vs_u16m4_u16m1(vuint16m1_t, vuint16m4_t, vuint16m1_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vredsum_vs_m)))
vuint16m1_t vredsum_vs_u16m4_u16m1_m(vbool4_t, vuint16m1_t, vuint16m4_t, vuint16m1_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vredsum_vs)))
vuint16m1_t vredsum_vs_u16m8_u16m1(vuint16m1_t, vuint16m8_t, vuint16m1_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vredsum_vs_m)))
vuint16m1_t vredsum_vs_u16m8_u16m1_m(vbool2_t, vuint16m1_t, vuint16m8_t, vuint16m1_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vredsum_vs)))
vuint16m1_t vredsum_vs_u16mf2_u16m1(vuint16m1_t, vuint16mf2_t, vuint16m1_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vredsum_vs_m)))
vuint16m1_t vredsum_vs_u16mf2_u16m1_m(vbool32_t, vuint16m1_t, vuint16mf2_t, vuint16m1_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vredsum_vs)))
vuint16m1_t vredsum_vs_u16mf4_u16m1(vuint16m1_t, vuint16mf4_t, vuint16m1_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vredsum_vs_m)))
vuint16m1_t vredsum_vs_u16mf4_u16m1_m(vbool64_t, vuint16m1_t, vuint16mf4_t, vuint16m1_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vredsum_vs)))
vuint32m1_t vredsum_vs_u32m1_u32m1(vuint32m1_t, vuint32m1_t, vuint32m1_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vredsum_vs_m)))
vuint32m1_t vredsum_vs_u32m1_u32m1_m(vbool32_t, vuint32m1_t, vuint32m1_t, vuint32m1_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vredsum_vs)))
vuint32m1_t vredsum_vs_u32m2_u32m1(vuint32m1_t, vuint32m2_t, vuint32m1_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vredsum_vs_m)))
vuint32m1_t vredsum_vs_u32m2_u32m1_m(vbool16_t, vuint32m1_t, vuint32m2_t, vuint32m1_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vredsum_vs)))
vuint32m1_t vredsum_vs_u32m4_u32m1(vuint32m1_t, vuint32m4_t, vuint32m1_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vredsum_vs_m)))
vuint32m1_t vredsum_vs_u32m4_u32m1_m(vbool8_t, vuint32m1_t, vuint32m4_t, vuint32m1_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vredsum_vs)))
vuint32m1_t vredsum_vs_u32m8_u32m1(vuint32m1_t, vuint32m8_t, vuint32m1_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vredsum_vs_m)))
vuint32m1_t vredsum_vs_u32m8_u32m1_m(vbool4_t, vuint32m1_t, vuint32m8_t, vuint32m1_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vredsum_vs)))
vuint32m1_t vredsum_vs_u32mf2_u32m1(vuint32m1_t, vuint32mf2_t, vuint32m1_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vredsum_vs_m)))
vuint32m1_t vredsum_vs_u32mf2_u32m1_m(vbool64_t, vuint32m1_t, vuint32mf2_t, vuint32m1_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vredmaxu_vs)))
vuint8m1_t vredmaxu_vs_u8m1_u8m1(vuint8m1_t, vuint8m1_t, vuint8m1_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vredmaxu_vs_m)))
vuint8m1_t vredmaxu_vs_u8m1_u8m1_m(vbool8_t, vuint8m1_t, vuint8m1_t, vuint8m1_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vredmaxu_vs)))
vuint8m1_t vredmaxu_vs_u8m2_u8m1(vuint8m1_t, vuint8m2_t, vuint8m1_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vredmaxu_vs_m)))
vuint8m1_t vredmaxu_vs_u8m2_u8m1_m(vbool4_t, vuint8m1_t, vuint8m2_t, vuint8m1_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vredmaxu_vs)))
vuint8m1_t vredmaxu_vs_u8m4_u8m1(vuint8m1_t, vuint8m4_t, vuint8m1_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vredmaxu_vs_m)))
vuint8m1_t vredmaxu_vs_u8m4_u8m1_m(vbool2_t, vuint8m1_t, vuint8m4_t, vuint8m1_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vredmaxu_vs)))
vuint8m1_t vredmaxu_vs_u8m8_u8m1(vuint8m1_t, vuint8m8_t, vuint8m1_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vredmaxu_vs_m)))
vuint8m1_t vredmaxu_vs_u8m8_u8m1_m(vbool1_t, vuint8m1_t, vuint8m8_t, vuint8m1_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vredmaxu_vs)))
vuint8m1_t vredmaxu_vs_u8mf2_u8m1(vuint8m1_t, vuint8mf2_t, vuint8m1_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vredmaxu_vs_m)))
vuint8m1_t vredmaxu_vs_u8mf2_u8m1_m(vbool16_t, vuint8m1_t, vuint8mf2_t, vuint8m1_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vredmaxu_vs)))
vuint8m1_t vredmaxu_vs_u8mf4_u8m1(vuint8m1_t, vuint8mf4_t, vuint8m1_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vredmaxu_vs_m)))
vuint8m1_t vredmaxu_vs_u8mf4_u8m1_m(vbool32_t, vuint8m1_t, vuint8mf4_t, vuint8m1_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vredmaxu_vs)))
vuint8m1_t vredmaxu_vs_u8mf8_u8m1(vuint8m1_t, vuint8mf8_t, vuint8m1_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vredmaxu_vs_m)))
vuint8m1_t vredmaxu_vs_u8mf8_u8m1_m(vbool64_t, vuint8m1_t, vuint8mf8_t, vuint8m1_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vredmaxu_vs)))
vuint16m1_t vredmaxu_vs_u16m1_u16m1(vuint16m1_t, vuint16m1_t, vuint16m1_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vredmaxu_vs_m)))
vuint16m1_t vredmaxu_vs_u16m1_u16m1_m(vbool16_t, vuint16m1_t, vuint16m1_t, vuint16m1_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vredmaxu_vs)))
vuint16m1_t vredmaxu_vs_u16m2_u16m1(vuint16m1_t, vuint16m2_t, vuint16m1_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vredmaxu_vs_m)))
vuint16m1_t vredmaxu_vs_u16m2_u16m1_m(vbool8_t, vuint16m1_t, vuint16m2_t, vuint16m1_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vredmaxu_vs)))
vuint16m1_t vredmaxu_vs_u16m4_u16m1(vuint16m1_t, vuint16m4_t, vuint16m1_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vredmaxu_vs_m)))
vuint16m1_t vredmaxu_vs_u16m4_u16m1_m(vbool4_t, vuint16m1_t, vuint16m4_t, vuint16m1_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vredmaxu_vs)))
vuint16m1_t vredmaxu_vs_u16m8_u16m1(vuint16m1_t, vuint16m8_t, vuint16m1_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vredmaxu_vs_m)))
vuint16m1_t vredmaxu_vs_u16m8_u16m1_m(vbool2_t, vuint16m1_t, vuint16m8_t, vuint16m1_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vredmaxu_vs)))
vuint16m1_t vredmaxu_vs_u16mf2_u16m1(vuint16m1_t, vuint16mf2_t, vuint16m1_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vredmaxu_vs_m)))
vuint16m1_t vredmaxu_vs_u16mf2_u16m1_m(vbool32_t, vuint16m1_t, vuint16mf2_t, vuint16m1_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vredmaxu_vs)))
vuint16m1_t vredmaxu_vs_u16mf4_u16m1(vuint16m1_t, vuint16mf4_t, vuint16m1_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vredmaxu_vs_m)))
vuint16m1_t vredmaxu_vs_u16mf4_u16m1_m(vbool64_t, vuint16m1_t, vuint16mf4_t, vuint16m1_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vredmaxu_vs)))
vuint32m1_t vredmaxu_vs_u32m1_u32m1(vuint32m1_t, vuint32m1_t, vuint32m1_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vredmaxu_vs_m)))
vuint32m1_t vredmaxu_vs_u32m1_u32m1_m(vbool32_t, vuint32m1_t, vuint32m1_t, vuint32m1_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vredmaxu_vs)))
vuint32m1_t vredmaxu_vs_u32m2_u32m1(vuint32m1_t, vuint32m2_t, vuint32m1_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vredmaxu_vs_m)))
vuint32m1_t vredmaxu_vs_u32m2_u32m1_m(vbool16_t, vuint32m1_t, vuint32m2_t, vuint32m1_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vredmaxu_vs)))
vuint32m1_t vredmaxu_vs_u32m4_u32m1(vuint32m1_t, vuint32m4_t, vuint32m1_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vredmaxu_vs_m)))
vuint32m1_t vredmaxu_vs_u32m4_u32m1_m(vbool8_t, vuint32m1_t, vuint32m4_t, vuint32m1_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vredmaxu_vs)))
vuint32m1_t vredmaxu_vs_u32m8_u32m1(vuint32m1_t, vuint32m8_t, vuint32m1_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vredmaxu_vs_m)))
vuint32m1_t vredmaxu_vs_u32m8_u32m1_m(vbool4_t, vuint32m1_t, vuint32m8_t, vuint32m1_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vredmaxu_vs)))
vuint32m1_t vredmaxu_vs_u32mf2_u32m1(vuint32m1_t, vuint32mf2_t, vuint32m1_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vredmaxu_vs_m)))
vuint32m1_t vredmaxu_vs_u32mf2_u32m1_m(vbool64_t, vuint32m1_t, vuint32mf2_t, vuint32m1_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vredmax_vs)))
vint8m1_t vredmax_vs_i8m1_i8m1(vint8m1_t, vint8m1_t, vint8m1_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vredmax_vs_m)))
vint8m1_t vredmax_vs_i8m1_i8m1_m(vbool8_t, vint8m1_t, vint8m1_t, vint8m1_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vredmax_vs)))
vint8m1_t vredmax_vs_i8m2_i8m1(vint8m1_t, vint8m2_t, vint8m1_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vredmax_vs_m)))
vint8m1_t vredmax_vs_i8m2_i8m1_m(vbool4_t, vint8m1_t, vint8m2_t, vint8m1_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vredmax_vs)))
vint8m1_t vredmax_vs_i8m4_i8m1(vint8m1_t, vint8m4_t, vint8m1_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vredmax_vs_m)))
vint8m1_t vredmax_vs_i8m4_i8m1_m(vbool2_t, vint8m1_t, vint8m4_t, vint8m1_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vredmax_vs)))
vint8m1_t vredmax_vs_i8m8_i8m1(vint8m1_t, vint8m8_t, vint8m1_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vredmax_vs_m)))
vint8m1_t vredmax_vs_i8m8_i8m1_m(vbool1_t, vint8m1_t, vint8m8_t, vint8m1_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vredmax_vs)))
vint8m1_t vredmax_vs_i8mf2_i8m1(vint8m1_t, vint8mf2_t, vint8m1_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vredmax_vs_m)))
vint8m1_t vredmax_vs_i8mf2_i8m1_m(vbool16_t, vint8m1_t, vint8mf2_t, vint8m1_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vredmax_vs)))
vint8m1_t vredmax_vs_i8mf4_i8m1(vint8m1_t, vint8mf4_t, vint8m1_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vredmax_vs_m)))
vint8m1_t vredmax_vs_i8mf4_i8m1_m(vbool32_t, vint8m1_t, vint8mf4_t, vint8m1_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vredmax_vs)))
vint8m1_t vredmax_vs_i8mf8_i8m1(vint8m1_t, vint8mf8_t, vint8m1_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vredmax_vs_m)))
vint8m1_t vredmax_vs_i8mf8_i8m1_m(vbool64_t, vint8m1_t, vint8mf8_t, vint8m1_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vredmax_vs)))
vint16m1_t vredmax_vs_i16m1_i16m1(vint16m1_t, vint16m1_t, vint16m1_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vredmax_vs_m)))
vint16m1_t vredmax_vs_i16m1_i16m1_m(vbool16_t, vint16m1_t, vint16m1_t, vint16m1_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vredmax_vs)))
vint16m1_t vredmax_vs_i16m2_i16m1(vint16m1_t, vint16m2_t, vint16m1_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vredmax_vs_m)))
vint16m1_t vredmax_vs_i16m2_i16m1_m(vbool8_t, vint16m1_t, vint16m2_t, vint16m1_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vredmax_vs)))
vint16m1_t vredmax_vs_i16m4_i16m1(vint16m1_t, vint16m4_t, vint16m1_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vredmax_vs_m)))
vint16m1_t vredmax_vs_i16m4_i16m1_m(vbool4_t, vint16m1_t, vint16m4_t, vint16m1_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vredmax_vs)))
vint16m1_t vredmax_vs_i16m8_i16m1(vint16m1_t, vint16m8_t, vint16m1_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vredmax_vs_m)))
vint16m1_t vredmax_vs_i16m8_i16m1_m(vbool2_t, vint16m1_t, vint16m8_t, vint16m1_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vredmax_vs)))
vint16m1_t vredmax_vs_i16mf2_i16m1(vint16m1_t, vint16mf2_t, vint16m1_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vredmax_vs_m)))
vint16m1_t vredmax_vs_i16mf2_i16m1_m(vbool32_t, vint16m1_t, vint16mf2_t, vint16m1_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vredmax_vs)))
vint16m1_t vredmax_vs_i16mf4_i16m1(vint16m1_t, vint16mf4_t, vint16m1_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vredmax_vs_m)))
vint16m1_t vredmax_vs_i16mf4_i16m1_m(vbool64_t, vint16m1_t, vint16mf4_t, vint16m1_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vredmax_vs)))
vint32m1_t vredmax_vs_i32m1_i32m1(vint32m1_t, vint32m1_t, vint32m1_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vredmax_vs_m)))
vint32m1_t vredmax_vs_i32m1_i32m1_m(vbool32_t, vint32m1_t, vint32m1_t, vint32m1_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vredmax_vs)))
vint32m1_t vredmax_vs_i32m2_i32m1(vint32m1_t, vint32m2_t, vint32m1_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vredmax_vs_m)))
vint32m1_t vredmax_vs_i32m2_i32m1_m(vbool16_t, vint32m1_t, vint32m2_t, vint32m1_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vredmax_vs)))
vint32m1_t vredmax_vs_i32m4_i32m1(vint32m1_t, vint32m4_t, vint32m1_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vredmax_vs_m)))
vint32m1_t vredmax_vs_i32m4_i32m1_m(vbool8_t, vint32m1_t, vint32m4_t, vint32m1_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vredmax_vs)))
vint32m1_t vredmax_vs_i32m8_i32m1(vint32m1_t, vint32m8_t, vint32m1_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vredmax_vs_m)))
vint32m1_t vredmax_vs_i32m8_i32m1_m(vbool4_t, vint32m1_t, vint32m8_t, vint32m1_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vredmax_vs)))
vint32m1_t vredmax_vs_i32mf2_i32m1(vint32m1_t, vint32mf2_t, vint32m1_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vredmax_vs_m)))
vint32m1_t vredmax_vs_i32mf2_i32m1_m(vbool64_t, vint32m1_t, vint32mf2_t, vint32m1_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vredminu_vs)))
vuint8m1_t vredminu_vs_u8m1_u8m1(vuint8m1_t, vuint8m1_t, vuint8m1_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vredminu_vs_m)))
vuint8m1_t vredminu_vs_u8m1_u8m1_m(vbool8_t, vuint8m1_t, vuint8m1_t, vuint8m1_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vredminu_vs)))
vuint8m1_t vredminu_vs_u8m2_u8m1(vuint8m1_t, vuint8m2_t, vuint8m1_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vredminu_vs_m)))
vuint8m1_t vredminu_vs_u8m2_u8m1_m(vbool4_t, vuint8m1_t, vuint8m2_t, vuint8m1_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vredminu_vs)))
vuint8m1_t vredminu_vs_u8m4_u8m1(vuint8m1_t, vuint8m4_t, vuint8m1_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vredminu_vs_m)))
vuint8m1_t vredminu_vs_u8m4_u8m1_m(vbool2_t, vuint8m1_t, vuint8m4_t, vuint8m1_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vredminu_vs)))
vuint8m1_t vredminu_vs_u8m8_u8m1(vuint8m1_t, vuint8m8_t, vuint8m1_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vredminu_vs_m)))
vuint8m1_t vredminu_vs_u8m8_u8m1_m(vbool1_t, vuint8m1_t, vuint8m8_t, vuint8m1_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vredminu_vs)))
vuint8m1_t vredminu_vs_u8mf2_u8m1(vuint8m1_t, vuint8mf2_t, vuint8m1_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vredminu_vs_m)))
vuint8m1_t vredminu_vs_u8mf2_u8m1_m(vbool16_t, vuint8m1_t, vuint8mf2_t, vuint8m1_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vredminu_vs)))
vuint8m1_t vredminu_vs_u8mf4_u8m1(vuint8m1_t, vuint8mf4_t, vuint8m1_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vredminu_vs_m)))
vuint8m1_t vredminu_vs_u8mf4_u8m1_m(vbool32_t, vuint8m1_t, vuint8mf4_t, vuint8m1_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vredminu_vs)))
vuint8m1_t vredminu_vs_u8mf8_u8m1(vuint8m1_t, vuint8mf8_t, vuint8m1_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vredminu_vs_m)))
vuint8m1_t vredminu_vs_u8mf8_u8m1_m(vbool64_t, vuint8m1_t, vuint8mf8_t, vuint8m1_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vredminu_vs)))
vuint16m1_t vredminu_vs_u16m1_u16m1(vuint16m1_t, vuint16m1_t, vuint16m1_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vredminu_vs_m)))
vuint16m1_t vredminu_vs_u16m1_u16m1_m(vbool16_t, vuint16m1_t, vuint16m1_t, vuint16m1_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vredminu_vs)))
vuint16m1_t vredminu_vs_u16m2_u16m1(vuint16m1_t, vuint16m2_t, vuint16m1_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vredminu_vs_m)))
vuint16m1_t vredminu_vs_u16m2_u16m1_m(vbool8_t, vuint16m1_t, vuint16m2_t, vuint16m1_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vredminu_vs)))
vuint16m1_t vredminu_vs_u16m4_u16m1(vuint16m1_t, vuint16m4_t, vuint16m1_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vredminu_vs_m)))
vuint16m1_t vredminu_vs_u16m4_u16m1_m(vbool4_t, vuint16m1_t, vuint16m4_t, vuint16m1_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vredminu_vs)))
vuint16m1_t vredminu_vs_u16m8_u16m1(vuint16m1_t, vuint16m8_t, vuint16m1_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vredminu_vs_m)))
vuint16m1_t vredminu_vs_u16m8_u16m1_m(vbool2_t, vuint16m1_t, vuint16m8_t, vuint16m1_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vredminu_vs)))
vuint16m1_t vredminu_vs_u16mf2_u16m1(vuint16m1_t, vuint16mf2_t, vuint16m1_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vredminu_vs_m)))
vuint16m1_t vredminu_vs_u16mf2_u16m1_m(vbool32_t, vuint16m1_t, vuint16mf2_t, vuint16m1_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vredminu_vs)))
vuint16m1_t vredminu_vs_u16mf4_u16m1(vuint16m1_t, vuint16mf4_t, vuint16m1_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vredminu_vs_m)))
vuint16m1_t vredminu_vs_u16mf4_u16m1_m(vbool64_t, vuint16m1_t, vuint16mf4_t, vuint16m1_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vredminu_vs)))
vuint32m1_t vredminu_vs_u32m1_u32m1(vuint32m1_t, vuint32m1_t, vuint32m1_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vredminu_vs_m)))
vuint32m1_t vredminu_vs_u32m1_u32m1_m(vbool32_t, vuint32m1_t, vuint32m1_t, vuint32m1_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vredminu_vs)))
vuint32m1_t vredminu_vs_u32m2_u32m1(vuint32m1_t, vuint32m2_t, vuint32m1_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vredminu_vs_m)))
vuint32m1_t vredminu_vs_u32m2_u32m1_m(vbool16_t, vuint32m1_t, vuint32m2_t, vuint32m1_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vredminu_vs)))
vuint32m1_t vredminu_vs_u32m4_u32m1(vuint32m1_t, vuint32m4_t, vuint32m1_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vredminu_vs_m)))
vuint32m1_t vredminu_vs_u32m4_u32m1_m(vbool8_t, vuint32m1_t, vuint32m4_t, vuint32m1_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vredminu_vs)))
vuint32m1_t vredminu_vs_u32m8_u32m1(vuint32m1_t, vuint32m8_t, vuint32m1_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vredminu_vs_m)))
vuint32m1_t vredminu_vs_u32m8_u32m1_m(vbool4_t, vuint32m1_t, vuint32m8_t, vuint32m1_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vredminu_vs)))
vuint32m1_t vredminu_vs_u32mf2_u32m1(vuint32m1_t, vuint32mf2_t, vuint32m1_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vredminu_vs_m)))
vuint32m1_t vredminu_vs_u32mf2_u32m1_m(vbool64_t, vuint32m1_t, vuint32mf2_t, vuint32m1_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vredmin_vs)))
vint8m1_t vredmin_vs_i8m1_i8m1(vint8m1_t, vint8m1_t, vint8m1_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vredmin_vs_m)))
vint8m1_t vredmin_vs_i8m1_i8m1_m(vbool8_t, vint8m1_t, vint8m1_t, vint8m1_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vredmin_vs)))
vint8m1_t vredmin_vs_i8m2_i8m1(vint8m1_t, vint8m2_t, vint8m1_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vredmin_vs_m)))
vint8m1_t vredmin_vs_i8m2_i8m1_m(vbool4_t, vint8m1_t, vint8m2_t, vint8m1_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vredmin_vs)))
vint8m1_t vredmin_vs_i8m4_i8m1(vint8m1_t, vint8m4_t, vint8m1_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vredmin_vs_m)))
vint8m1_t vredmin_vs_i8m4_i8m1_m(vbool2_t, vint8m1_t, vint8m4_t, vint8m1_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vredmin_vs)))
vint8m1_t vredmin_vs_i8m8_i8m1(vint8m1_t, vint8m8_t, vint8m1_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vredmin_vs_m)))
vint8m1_t vredmin_vs_i8m8_i8m1_m(vbool1_t, vint8m1_t, vint8m8_t, vint8m1_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vredmin_vs)))
vint8m1_t vredmin_vs_i8mf2_i8m1(vint8m1_t, vint8mf2_t, vint8m1_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vredmin_vs_m)))
vint8m1_t vredmin_vs_i8mf2_i8m1_m(vbool16_t, vint8m1_t, vint8mf2_t, vint8m1_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vredmin_vs)))
vint8m1_t vredmin_vs_i8mf4_i8m1(vint8m1_t, vint8mf4_t, vint8m1_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vredmin_vs_m)))
vint8m1_t vredmin_vs_i8mf4_i8m1_m(vbool32_t, vint8m1_t, vint8mf4_t, vint8m1_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vredmin_vs)))
vint8m1_t vredmin_vs_i8mf8_i8m1(vint8m1_t, vint8mf8_t, vint8m1_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vredmin_vs_m)))
vint8m1_t vredmin_vs_i8mf8_i8m1_m(vbool64_t, vint8m1_t, vint8mf8_t, vint8m1_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vredmin_vs)))
vint16m1_t vredmin_vs_i16m1_i16m1(vint16m1_t, vint16m1_t, vint16m1_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vredmin_vs_m)))
vint16m1_t vredmin_vs_i16m1_i16m1_m(vbool16_t, vint16m1_t, vint16m1_t, vint16m1_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vredmin_vs)))
vint16m1_t vredmin_vs_i16m2_i16m1(vint16m1_t, vint16m2_t, vint16m1_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vredmin_vs_m)))
vint16m1_t vredmin_vs_i16m2_i16m1_m(vbool8_t, vint16m1_t, vint16m2_t, vint16m1_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vredmin_vs)))
vint16m1_t vredmin_vs_i16m4_i16m1(vint16m1_t, vint16m4_t, vint16m1_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vredmin_vs_m)))
vint16m1_t vredmin_vs_i16m4_i16m1_m(vbool4_t, vint16m1_t, vint16m4_t, vint16m1_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vredmin_vs)))
vint16m1_t vredmin_vs_i16m8_i16m1(vint16m1_t, vint16m8_t, vint16m1_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vredmin_vs_m)))
vint16m1_t vredmin_vs_i16m8_i16m1_m(vbool2_t, vint16m1_t, vint16m8_t, vint16m1_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vredmin_vs)))
vint16m1_t vredmin_vs_i16mf2_i16m1(vint16m1_t, vint16mf2_t, vint16m1_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vredmin_vs_m)))
vint16m1_t vredmin_vs_i16mf2_i16m1_m(vbool32_t, vint16m1_t, vint16mf2_t, vint16m1_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vredmin_vs)))
vint16m1_t vredmin_vs_i16mf4_i16m1(vint16m1_t, vint16mf4_t, vint16m1_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vredmin_vs_m)))
vint16m1_t vredmin_vs_i16mf4_i16m1_m(vbool64_t, vint16m1_t, vint16mf4_t, vint16m1_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vredmin_vs)))
vint32m1_t vredmin_vs_i32m1_i32m1(vint32m1_t, vint32m1_t, vint32m1_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vredmin_vs_m)))
vint32m1_t vredmin_vs_i32m1_i32m1_m(vbool32_t, vint32m1_t, vint32m1_t, vint32m1_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vredmin_vs)))
vint32m1_t vredmin_vs_i32m2_i32m1(vint32m1_t, vint32m2_t, vint32m1_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vredmin_vs_m)))
vint32m1_t vredmin_vs_i32m2_i32m1_m(vbool16_t, vint32m1_t, vint32m2_t, vint32m1_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vredmin_vs)))
vint32m1_t vredmin_vs_i32m4_i32m1(vint32m1_t, vint32m4_t, vint32m1_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vredmin_vs_m)))
vint32m1_t vredmin_vs_i32m4_i32m1_m(vbool8_t, vint32m1_t, vint32m4_t, vint32m1_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vredmin_vs)))
vint32m1_t vredmin_vs_i32m8_i32m1(vint32m1_t, vint32m8_t, vint32m1_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vredmin_vs_m)))
vint32m1_t vredmin_vs_i32m8_i32m1_m(vbool4_t, vint32m1_t, vint32m8_t, vint32m1_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vredmin_vs)))
vint32m1_t vredmin_vs_i32mf2_i32m1(vint32m1_t, vint32mf2_t, vint32m1_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vredmin_vs_m)))
vint32m1_t vredmin_vs_i32mf2_i32m1_m(vbool64_t, vint32m1_t, vint32mf2_t, vint32m1_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vredand_vs)))
vint8m1_t vredand_vs_i8m1_i8m1(vint8m1_t, vint8m1_t, vint8m1_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vredand_vs_m)))
vint8m1_t vredand_vs_i8m1_i8m1_m(vbool8_t, vint8m1_t, vint8m1_t, vint8m1_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vredand_vs)))
vint8m1_t vredand_vs_i8m2_i8m1(vint8m1_t, vint8m2_t, vint8m1_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vredand_vs_m)))
vint8m1_t vredand_vs_i8m2_i8m1_m(vbool4_t, vint8m1_t, vint8m2_t, vint8m1_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vredand_vs)))
vint8m1_t vredand_vs_i8m4_i8m1(vint8m1_t, vint8m4_t, vint8m1_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vredand_vs_m)))
vint8m1_t vredand_vs_i8m4_i8m1_m(vbool2_t, vint8m1_t, vint8m4_t, vint8m1_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vredand_vs)))
vint8m1_t vredand_vs_i8m8_i8m1(vint8m1_t, vint8m8_t, vint8m1_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vredand_vs_m)))
vint8m1_t vredand_vs_i8m8_i8m1_m(vbool1_t, vint8m1_t, vint8m8_t, vint8m1_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vredand_vs)))
vint8m1_t vredand_vs_i8mf2_i8m1(vint8m1_t, vint8mf2_t, vint8m1_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vredand_vs_m)))
vint8m1_t vredand_vs_i8mf2_i8m1_m(vbool16_t, vint8m1_t, vint8mf2_t, vint8m1_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vredand_vs)))
vint8m1_t vredand_vs_i8mf4_i8m1(vint8m1_t, vint8mf4_t, vint8m1_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vredand_vs_m)))
vint8m1_t vredand_vs_i8mf4_i8m1_m(vbool32_t, vint8m1_t, vint8mf4_t, vint8m1_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vredand_vs)))
vint8m1_t vredand_vs_i8mf8_i8m1(vint8m1_t, vint8mf8_t, vint8m1_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vredand_vs_m)))
vint8m1_t vredand_vs_i8mf8_i8m1_m(vbool64_t, vint8m1_t, vint8mf8_t, vint8m1_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vredand_vs)))
vint16m1_t vredand_vs_i16m1_i16m1(vint16m1_t, vint16m1_t, vint16m1_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vredand_vs_m)))
vint16m1_t vredand_vs_i16m1_i16m1_m(vbool16_t, vint16m1_t, vint16m1_t, vint16m1_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vredand_vs)))
vint16m1_t vredand_vs_i16m2_i16m1(vint16m1_t, vint16m2_t, vint16m1_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vredand_vs_m)))
vint16m1_t vredand_vs_i16m2_i16m1_m(vbool8_t, vint16m1_t, vint16m2_t, vint16m1_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vredand_vs)))
vint16m1_t vredand_vs_i16m4_i16m1(vint16m1_t, vint16m4_t, vint16m1_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vredand_vs_m)))
vint16m1_t vredand_vs_i16m4_i16m1_m(vbool4_t, vint16m1_t, vint16m4_t, vint16m1_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vredand_vs)))
vint16m1_t vredand_vs_i16m8_i16m1(vint16m1_t, vint16m8_t, vint16m1_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vredand_vs_m)))
vint16m1_t vredand_vs_i16m8_i16m1_m(vbool2_t, vint16m1_t, vint16m8_t, vint16m1_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vredand_vs)))
vint16m1_t vredand_vs_i16mf2_i16m1(vint16m1_t, vint16mf2_t, vint16m1_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vredand_vs_m)))
vint16m1_t vredand_vs_i16mf2_i16m1_m(vbool32_t, vint16m1_t, vint16mf2_t, vint16m1_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vredand_vs)))
vint16m1_t vredand_vs_i16mf4_i16m1(vint16m1_t, vint16mf4_t, vint16m1_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vredand_vs_m)))
vint16m1_t vredand_vs_i16mf4_i16m1_m(vbool64_t, vint16m1_t, vint16mf4_t, vint16m1_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vredand_vs)))
vint32m1_t vredand_vs_i32m1_i32m1(vint32m1_t, vint32m1_t, vint32m1_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vredand_vs_m)))
vint32m1_t vredand_vs_i32m1_i32m1_m(vbool32_t, vint32m1_t, vint32m1_t, vint32m1_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vredand_vs)))
vint32m1_t vredand_vs_i32m2_i32m1(vint32m1_t, vint32m2_t, vint32m1_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vredand_vs_m)))
vint32m1_t vredand_vs_i32m2_i32m1_m(vbool16_t, vint32m1_t, vint32m2_t, vint32m1_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vredand_vs)))
vint32m1_t vredand_vs_i32m4_i32m1(vint32m1_t, vint32m4_t, vint32m1_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vredand_vs_m)))
vint32m1_t vredand_vs_i32m4_i32m1_m(vbool8_t, vint32m1_t, vint32m4_t, vint32m1_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vredand_vs)))
vint32m1_t vredand_vs_i32m8_i32m1(vint32m1_t, vint32m8_t, vint32m1_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vredand_vs_m)))
vint32m1_t vredand_vs_i32m8_i32m1_m(vbool4_t, vint32m1_t, vint32m8_t, vint32m1_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vredand_vs)))
vint32m1_t vredand_vs_i32mf2_i32m1(vint32m1_t, vint32mf2_t, vint32m1_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vredand_vs_m)))
vint32m1_t vredand_vs_i32mf2_i32m1_m(vbool64_t, vint32m1_t, vint32mf2_t, vint32m1_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vredand_vs)))
vuint8m1_t vredand_vs_u8m1_u8m1(vuint8m1_t, vuint8m1_t, vuint8m1_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vredand_vs_m)))
vuint8m1_t vredand_vs_u8m1_u8m1_m(vbool8_t, vuint8m1_t, vuint8m1_t, vuint8m1_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vredand_vs)))
vuint8m1_t vredand_vs_u8m2_u8m1(vuint8m1_t, vuint8m2_t, vuint8m1_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vredand_vs_m)))
vuint8m1_t vredand_vs_u8m2_u8m1_m(vbool4_t, vuint8m1_t, vuint8m2_t, vuint8m1_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vredand_vs)))
vuint8m1_t vredand_vs_u8m4_u8m1(vuint8m1_t, vuint8m4_t, vuint8m1_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vredand_vs_m)))
vuint8m1_t vredand_vs_u8m4_u8m1_m(vbool2_t, vuint8m1_t, vuint8m4_t, vuint8m1_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vredand_vs)))
vuint8m1_t vredand_vs_u8m8_u8m1(vuint8m1_t, vuint8m8_t, vuint8m1_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vredand_vs_m)))
vuint8m1_t vredand_vs_u8m8_u8m1_m(vbool1_t, vuint8m1_t, vuint8m8_t, vuint8m1_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vredand_vs)))
vuint8m1_t vredand_vs_u8mf2_u8m1(vuint8m1_t, vuint8mf2_t, vuint8m1_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vredand_vs_m)))
vuint8m1_t vredand_vs_u8mf2_u8m1_m(vbool16_t, vuint8m1_t, vuint8mf2_t, vuint8m1_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vredand_vs)))
vuint8m1_t vredand_vs_u8mf4_u8m1(vuint8m1_t, vuint8mf4_t, vuint8m1_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vredand_vs_m)))
vuint8m1_t vredand_vs_u8mf4_u8m1_m(vbool32_t, vuint8m1_t, vuint8mf4_t, vuint8m1_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vredand_vs)))
vuint8m1_t vredand_vs_u8mf8_u8m1(vuint8m1_t, vuint8mf8_t, vuint8m1_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vredand_vs_m)))
vuint8m1_t vredand_vs_u8mf8_u8m1_m(vbool64_t, vuint8m1_t, vuint8mf8_t, vuint8m1_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vredand_vs)))
vuint16m1_t vredand_vs_u16m1_u16m1(vuint16m1_t, vuint16m1_t, vuint16m1_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vredand_vs_m)))
vuint16m1_t vredand_vs_u16m1_u16m1_m(vbool16_t, vuint16m1_t, vuint16m1_t, vuint16m1_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vredand_vs)))
vuint16m1_t vredand_vs_u16m2_u16m1(vuint16m1_t, vuint16m2_t, vuint16m1_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vredand_vs_m)))
vuint16m1_t vredand_vs_u16m2_u16m1_m(vbool8_t, vuint16m1_t, vuint16m2_t, vuint16m1_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vredand_vs)))
vuint16m1_t vredand_vs_u16m4_u16m1(vuint16m1_t, vuint16m4_t, vuint16m1_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vredand_vs_m)))
vuint16m1_t vredand_vs_u16m4_u16m1_m(vbool4_t, vuint16m1_t, vuint16m4_t, vuint16m1_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vredand_vs)))
vuint16m1_t vredand_vs_u16m8_u16m1(vuint16m1_t, vuint16m8_t, vuint16m1_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vredand_vs_m)))
vuint16m1_t vredand_vs_u16m8_u16m1_m(vbool2_t, vuint16m1_t, vuint16m8_t, vuint16m1_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vredand_vs)))
vuint16m1_t vredand_vs_u16mf2_u16m1(vuint16m1_t, vuint16mf2_t, vuint16m1_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vredand_vs_m)))
vuint16m1_t vredand_vs_u16mf2_u16m1_m(vbool32_t, vuint16m1_t, vuint16mf2_t, vuint16m1_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vredand_vs)))
vuint16m1_t vredand_vs_u16mf4_u16m1(vuint16m1_t, vuint16mf4_t, vuint16m1_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vredand_vs_m)))
vuint16m1_t vredand_vs_u16mf4_u16m1_m(vbool64_t, vuint16m1_t, vuint16mf4_t, vuint16m1_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vredand_vs)))
vuint32m1_t vredand_vs_u32m1_u32m1(vuint32m1_t, vuint32m1_t, vuint32m1_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vredand_vs_m)))
vuint32m1_t vredand_vs_u32m1_u32m1_m(vbool32_t, vuint32m1_t, vuint32m1_t, vuint32m1_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vredand_vs)))
vuint32m1_t vredand_vs_u32m2_u32m1(vuint32m1_t, vuint32m2_t, vuint32m1_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vredand_vs_m)))
vuint32m1_t vredand_vs_u32m2_u32m1_m(vbool16_t, vuint32m1_t, vuint32m2_t, vuint32m1_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vredand_vs)))
vuint32m1_t vredand_vs_u32m4_u32m1(vuint32m1_t, vuint32m4_t, vuint32m1_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vredand_vs_m)))
vuint32m1_t vredand_vs_u32m4_u32m1_m(vbool8_t, vuint32m1_t, vuint32m4_t, vuint32m1_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vredand_vs)))
vuint32m1_t vredand_vs_u32m8_u32m1(vuint32m1_t, vuint32m8_t, vuint32m1_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vredand_vs_m)))
vuint32m1_t vredand_vs_u32m8_u32m1_m(vbool4_t, vuint32m1_t, vuint32m8_t, vuint32m1_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vredand_vs)))
vuint32m1_t vredand_vs_u32mf2_u32m1(vuint32m1_t, vuint32mf2_t, vuint32m1_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vredand_vs_m)))
vuint32m1_t vredand_vs_u32mf2_u32m1_m(vbool64_t, vuint32m1_t, vuint32mf2_t, vuint32m1_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vsuxei32_v)))
void vsuxei32_v_u32m1(uint32_t *, vuint32m1_t, vuint32m1_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vsuxei32_v_m)))
void vsuxei32_v_u32m1_m(vbool32_t, uint32_t *, vuint32m1_t, vuint32m1_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vsuxei32_v)))
void vsuxei32_v_u32m2(uint32_t *, vuint32m2_t, vuint32m2_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vsuxei32_v_m)))
void vsuxei32_v_u32m2_m(vbool16_t, uint32_t *, vuint32m2_t, vuint32m2_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vsuxei32_v)))
void vsuxei32_v_u32m4(uint32_t *, vuint32m4_t, vuint32m4_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vsuxei32_v_m)))
void vsuxei32_v_u32m4_m(vbool8_t, uint32_t *, vuint32m4_t, vuint32m4_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vsuxei32_v)))
void vsuxei32_v_u32m8(uint32_t *, vuint32m8_t, vuint32m8_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vsuxei32_v_m)))
void vsuxei32_v_u32m8_m(vbool4_t, uint32_t *, vuint32m8_t, vuint32m8_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vsuxei32_v)))
void vsuxei32_v_u32mf2(uint32_t *, vuint32mf2_t, vuint32mf2_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vsuxei32_v_m)))
void vsuxei32_v_u32mf2_m(vbool64_t, uint32_t *, vuint32mf2_t, vuint32mf2_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vredor_vs)))
vint8m1_t vredor_vs_i8m1_i8m1(vint8m1_t, vint8m1_t, vint8m1_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vredor_vs_m)))
vint8m1_t vredor_vs_i8m1_i8m1_m(vbool8_t, vint8m1_t, vint8m1_t, vint8m1_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vredor_vs)))
vint8m1_t vredor_vs_i8m2_i8m1(vint8m1_t, vint8m2_t, vint8m1_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vredor_vs_m)))
vint8m1_t vredor_vs_i8m2_i8m1_m(vbool4_t, vint8m1_t, vint8m2_t, vint8m1_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vredor_vs)))
vint8m1_t vredor_vs_i8m4_i8m1(vint8m1_t, vint8m4_t, vint8m1_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vredor_vs_m)))
vint8m1_t vredor_vs_i8m4_i8m1_m(vbool2_t, vint8m1_t, vint8m4_t, vint8m1_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vredor_vs)))
vint8m1_t vredor_vs_i8m8_i8m1(vint8m1_t, vint8m8_t, vint8m1_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vredor_vs_m)))
vint8m1_t vredor_vs_i8m8_i8m1_m(vbool1_t, vint8m1_t, vint8m8_t, vint8m1_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vredor_vs)))
vint8m1_t vredor_vs_i8mf2_i8m1(vint8m1_t, vint8mf2_t, vint8m1_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vredor_vs_m)))
vint8m1_t vredor_vs_i8mf2_i8m1_m(vbool16_t, vint8m1_t, vint8mf2_t, vint8m1_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vredor_vs)))
vint8m1_t vredor_vs_i8mf4_i8m1(vint8m1_t, vint8mf4_t, vint8m1_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vredor_vs_m)))
vint8m1_t vredor_vs_i8mf4_i8m1_m(vbool32_t, vint8m1_t, vint8mf4_t, vint8m1_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vredor_vs)))
vint8m1_t vredor_vs_i8mf8_i8m1(vint8m1_t, vint8mf8_t, vint8m1_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vredor_vs_m)))
vint8m1_t vredor_vs_i8mf8_i8m1_m(vbool64_t, vint8m1_t, vint8mf8_t, vint8m1_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vredor_vs)))
vint16m1_t vredor_vs_i16m1_i16m1(vint16m1_t, vint16m1_t, vint16m1_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vredor_vs_m)))
vint16m1_t vredor_vs_i16m1_i16m1_m(vbool16_t, vint16m1_t, vint16m1_t, vint16m1_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vredor_vs)))
vint16m1_t vredor_vs_i16m2_i16m1(vint16m1_t, vint16m2_t, vint16m1_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vredor_vs_m)))
vint16m1_t vredor_vs_i16m2_i16m1_m(vbool8_t, vint16m1_t, vint16m2_t, vint16m1_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vredor_vs)))
vint16m1_t vredor_vs_i16m4_i16m1(vint16m1_t, vint16m4_t, vint16m1_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vredor_vs_m)))
vint16m1_t vredor_vs_i16m4_i16m1_m(vbool4_t, vint16m1_t, vint16m4_t, vint16m1_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vredor_vs)))
vint16m1_t vredor_vs_i16m8_i16m1(vint16m1_t, vint16m8_t, vint16m1_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vredor_vs_m)))
vint16m1_t vredor_vs_i16m8_i16m1_m(vbool2_t, vint16m1_t, vint16m8_t, vint16m1_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vredor_vs)))
vint16m1_t vredor_vs_i16mf2_i16m1(vint16m1_t, vint16mf2_t, vint16m1_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vredor_vs_m)))
vint16m1_t vredor_vs_i16mf2_i16m1_m(vbool32_t, vint16m1_t, vint16mf2_t, vint16m1_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vredor_vs)))
vint16m1_t vredor_vs_i16mf4_i16m1(vint16m1_t, vint16mf4_t, vint16m1_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vredor_vs_m)))
vint16m1_t vredor_vs_i16mf4_i16m1_m(vbool64_t, vint16m1_t, vint16mf4_t, vint16m1_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vredor_vs)))
vint32m1_t vredor_vs_i32m1_i32m1(vint32m1_t, vint32m1_t, vint32m1_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vredor_vs_m)))
vint32m1_t vredor_vs_i32m1_i32m1_m(vbool32_t, vint32m1_t, vint32m1_t, vint32m1_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vredor_vs)))
vint32m1_t vredor_vs_i32m2_i32m1(vint32m1_t, vint32m2_t, vint32m1_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vredor_vs_m)))
vint32m1_t vredor_vs_i32m2_i32m1_m(vbool16_t, vint32m1_t, vint32m2_t, vint32m1_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vredor_vs)))
vint32m1_t vredor_vs_i32m4_i32m1(vint32m1_t, vint32m4_t, vint32m1_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vredor_vs_m)))
vint32m1_t vredor_vs_i32m4_i32m1_m(vbool8_t, vint32m1_t, vint32m4_t, vint32m1_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vredor_vs)))
vint32m1_t vredor_vs_i32m8_i32m1(vint32m1_t, vint32m8_t, vint32m1_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vredor_vs_m)))
vint32m1_t vredor_vs_i32m8_i32m1_m(vbool4_t, vint32m1_t, vint32m8_t, vint32m1_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vredor_vs)))
vint32m1_t vredor_vs_i32mf2_i32m1(vint32m1_t, vint32mf2_t, vint32m1_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vredor_vs_m)))
vint32m1_t vredor_vs_i32mf2_i32m1_m(vbool64_t, vint32m1_t, vint32mf2_t, vint32m1_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vredor_vs)))
vuint8m1_t vredor_vs_u8m1_u8m1(vuint8m1_t, vuint8m1_t, vuint8m1_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vredor_vs_m)))
vuint8m1_t vredor_vs_u8m1_u8m1_m(vbool8_t, vuint8m1_t, vuint8m1_t, vuint8m1_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vredor_vs)))
vuint8m1_t vredor_vs_u8m2_u8m1(vuint8m1_t, vuint8m2_t, vuint8m1_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vredor_vs_m)))
vuint8m1_t vredor_vs_u8m2_u8m1_m(vbool4_t, vuint8m1_t, vuint8m2_t, vuint8m1_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vredor_vs)))
vuint8m1_t vredor_vs_u8m4_u8m1(vuint8m1_t, vuint8m4_t, vuint8m1_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vredor_vs_m)))
vuint8m1_t vredor_vs_u8m4_u8m1_m(vbool2_t, vuint8m1_t, vuint8m4_t, vuint8m1_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vredor_vs)))
vuint8m1_t vredor_vs_u8m8_u8m1(vuint8m1_t, vuint8m8_t, vuint8m1_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vredor_vs_m)))
vuint8m1_t vredor_vs_u8m8_u8m1_m(vbool1_t, vuint8m1_t, vuint8m8_t, vuint8m1_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vredor_vs)))
vuint8m1_t vredor_vs_u8mf2_u8m1(vuint8m1_t, vuint8mf2_t, vuint8m1_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vredor_vs_m)))
vuint8m1_t vredor_vs_u8mf2_u8m1_m(vbool16_t, vuint8m1_t, vuint8mf2_t, vuint8m1_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vredor_vs)))
vuint8m1_t vredor_vs_u8mf4_u8m1(vuint8m1_t, vuint8mf4_t, vuint8m1_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vredor_vs_m)))
vuint8m1_t vredor_vs_u8mf4_u8m1_m(vbool32_t, vuint8m1_t, vuint8mf4_t, vuint8m1_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vredor_vs)))
vuint8m1_t vredor_vs_u8mf8_u8m1(vuint8m1_t, vuint8mf8_t, vuint8m1_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vredor_vs_m)))
vuint8m1_t vredor_vs_u8mf8_u8m1_m(vbool64_t, vuint8m1_t, vuint8mf8_t, vuint8m1_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vredor_vs)))
vuint16m1_t vredor_vs_u16m1_u16m1(vuint16m1_t, vuint16m1_t, vuint16m1_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vredor_vs_m)))
vuint16m1_t vredor_vs_u16m1_u16m1_m(vbool16_t, vuint16m1_t, vuint16m1_t, vuint16m1_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vredor_vs)))
vuint16m1_t vredor_vs_u16m2_u16m1(vuint16m1_t, vuint16m2_t, vuint16m1_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vredor_vs_m)))
vuint16m1_t vredor_vs_u16m2_u16m1_m(vbool8_t, vuint16m1_t, vuint16m2_t, vuint16m1_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vredor_vs)))
vuint16m1_t vredor_vs_u16m4_u16m1(vuint16m1_t, vuint16m4_t, vuint16m1_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vredor_vs_m)))
vuint16m1_t vredor_vs_u16m4_u16m1_m(vbool4_t, vuint16m1_t, vuint16m4_t, vuint16m1_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vredor_vs)))
vuint16m1_t vredor_vs_u16m8_u16m1(vuint16m1_t, vuint16m8_t, vuint16m1_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vredor_vs_m)))
vuint16m1_t vredor_vs_u16m8_u16m1_m(vbool2_t, vuint16m1_t, vuint16m8_t, vuint16m1_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vredor_vs)))
vuint16m1_t vredor_vs_u16mf2_u16m1(vuint16m1_t, vuint16mf2_t, vuint16m1_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vredor_vs_m)))
vuint16m1_t vredor_vs_u16mf2_u16m1_m(vbool32_t, vuint16m1_t, vuint16mf2_t, vuint16m1_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vredor_vs)))
vuint16m1_t vredor_vs_u16mf4_u16m1(vuint16m1_t, vuint16mf4_t, vuint16m1_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vredor_vs_m)))
vuint16m1_t vredor_vs_u16mf4_u16m1_m(vbool64_t, vuint16m1_t, vuint16mf4_t, vuint16m1_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vredor_vs)))
vuint32m1_t vredor_vs_u32m1_u32m1(vuint32m1_t, vuint32m1_t, vuint32m1_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vredor_vs_m)))
vuint32m1_t vredor_vs_u32m1_u32m1_m(vbool32_t, vuint32m1_t, vuint32m1_t, vuint32m1_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vredor_vs)))
vuint32m1_t vredor_vs_u32m2_u32m1(vuint32m1_t, vuint32m2_t, vuint32m1_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vredor_vs_m)))
vuint32m1_t vredor_vs_u32m2_u32m1_m(vbool16_t, vuint32m1_t, vuint32m2_t, vuint32m1_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vredor_vs)))
vuint32m1_t vredor_vs_u32m4_u32m1(vuint32m1_t, vuint32m4_t, vuint32m1_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vredor_vs_m)))
vuint32m1_t vredor_vs_u32m4_u32m1_m(vbool8_t, vuint32m1_t, vuint32m4_t, vuint32m1_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vredor_vs)))
vuint32m1_t vredor_vs_u32m8_u32m1(vuint32m1_t, vuint32m8_t, vuint32m1_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vredor_vs_m)))
vuint32m1_t vredor_vs_u32m8_u32m1_m(vbool4_t, vuint32m1_t, vuint32m8_t, vuint32m1_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vredor_vs)))
vuint32m1_t vredor_vs_u32mf2_u32m1(vuint32m1_t, vuint32mf2_t, vuint32m1_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vredor_vs_m)))
vuint32m1_t vredor_vs_u32mf2_u32m1_m(vbool64_t, vuint32m1_t, vuint32mf2_t, vuint32m1_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vredxor_vs)))
vint8m1_t vredxor_vs_i8m1_i8m1(vint8m1_t, vint8m1_t, vint8m1_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vredxor_vs_m)))
vint8m1_t vredxor_vs_i8m1_i8m1_m(vbool8_t, vint8m1_t, vint8m1_t, vint8m1_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vredxor_vs)))
vint8m1_t vredxor_vs_i8m2_i8m1(vint8m1_t, vint8m2_t, vint8m1_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vredxor_vs_m)))
vint8m1_t vredxor_vs_i8m2_i8m1_m(vbool4_t, vint8m1_t, vint8m2_t, vint8m1_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vredxor_vs)))
vint8m1_t vredxor_vs_i8m4_i8m1(vint8m1_t, vint8m4_t, vint8m1_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vredxor_vs_m)))
vint8m1_t vredxor_vs_i8m4_i8m1_m(vbool2_t, vint8m1_t, vint8m4_t, vint8m1_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vredxor_vs)))
vint8m1_t vredxor_vs_i8m8_i8m1(vint8m1_t, vint8m8_t, vint8m1_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vredxor_vs_m)))
vint8m1_t vredxor_vs_i8m8_i8m1_m(vbool1_t, vint8m1_t, vint8m8_t, vint8m1_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vredxor_vs)))
vint8m1_t vredxor_vs_i8mf2_i8m1(vint8m1_t, vint8mf2_t, vint8m1_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vredxor_vs_m)))
vint8m1_t vredxor_vs_i8mf2_i8m1_m(vbool16_t, vint8m1_t, vint8mf2_t, vint8m1_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vredxor_vs)))
vint8m1_t vredxor_vs_i8mf4_i8m1(vint8m1_t, vint8mf4_t, vint8m1_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vredxor_vs_m)))
vint8m1_t vredxor_vs_i8mf4_i8m1_m(vbool32_t, vint8m1_t, vint8mf4_t, vint8m1_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vredxor_vs)))
vint8m1_t vredxor_vs_i8mf8_i8m1(vint8m1_t, vint8mf8_t, vint8m1_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vredxor_vs_m)))
vint8m1_t vredxor_vs_i8mf8_i8m1_m(vbool64_t, vint8m1_t, vint8mf8_t, vint8m1_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vredxor_vs)))
vint16m1_t vredxor_vs_i16m1_i16m1(vint16m1_t, vint16m1_t, vint16m1_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vredxor_vs_m)))
vint16m1_t vredxor_vs_i16m1_i16m1_m(vbool16_t, vint16m1_t, vint16m1_t, vint16m1_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vredxor_vs)))
vint16m1_t vredxor_vs_i16m2_i16m1(vint16m1_t, vint16m2_t, vint16m1_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vredxor_vs_m)))
vint16m1_t vredxor_vs_i16m2_i16m1_m(vbool8_t, vint16m1_t, vint16m2_t, vint16m1_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vredxor_vs)))
vint16m1_t vredxor_vs_i16m4_i16m1(vint16m1_t, vint16m4_t, vint16m1_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vredxor_vs_m)))
vint16m1_t vredxor_vs_i16m4_i16m1_m(vbool4_t, vint16m1_t, vint16m4_t, vint16m1_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vredxor_vs)))
vint16m1_t vredxor_vs_i16m8_i16m1(vint16m1_t, vint16m8_t, vint16m1_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vredxor_vs_m)))
vint16m1_t vredxor_vs_i16m8_i16m1_m(vbool2_t, vint16m1_t, vint16m8_t, vint16m1_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vredxor_vs)))
vint16m1_t vredxor_vs_i16mf2_i16m1(vint16m1_t, vint16mf2_t, vint16m1_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vredxor_vs_m)))
vint16m1_t vredxor_vs_i16mf2_i16m1_m(vbool32_t, vint16m1_t, vint16mf2_t, vint16m1_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vredxor_vs)))
vint16m1_t vredxor_vs_i16mf4_i16m1(vint16m1_t, vint16mf4_t, vint16m1_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vredxor_vs_m)))
vint16m1_t vredxor_vs_i16mf4_i16m1_m(vbool64_t, vint16m1_t, vint16mf4_t, vint16m1_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vredxor_vs)))
vint32m1_t vredxor_vs_i32m1_i32m1(vint32m1_t, vint32m1_t, vint32m1_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vredxor_vs_m)))
vint32m1_t vredxor_vs_i32m1_i32m1_m(vbool32_t, vint32m1_t, vint32m1_t, vint32m1_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vredxor_vs)))
vint32m1_t vredxor_vs_i32m2_i32m1(vint32m1_t, vint32m2_t, vint32m1_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vredxor_vs_m)))
vint32m1_t vredxor_vs_i32m2_i32m1_m(vbool16_t, vint32m1_t, vint32m2_t, vint32m1_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vredxor_vs)))
vint32m1_t vredxor_vs_i32m4_i32m1(vint32m1_t, vint32m4_t, vint32m1_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vredxor_vs_m)))
vint32m1_t vredxor_vs_i32m4_i32m1_m(vbool8_t, vint32m1_t, vint32m4_t, vint32m1_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vredxor_vs)))
vint32m1_t vredxor_vs_i32m8_i32m1(vint32m1_t, vint32m8_t, vint32m1_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vredxor_vs_m)))
vint32m1_t vredxor_vs_i32m8_i32m1_m(vbool4_t, vint32m1_t, vint32m8_t, vint32m1_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vredxor_vs)))
vint32m1_t vredxor_vs_i32mf2_i32m1(vint32m1_t, vint32mf2_t, vint32m1_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vredxor_vs_m)))
vint32m1_t vredxor_vs_i32mf2_i32m1_m(vbool64_t, vint32m1_t, vint32mf2_t, vint32m1_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vredxor_vs)))
vuint8m1_t vredxor_vs_u8m1_u8m1(vuint8m1_t, vuint8m1_t, vuint8m1_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vredxor_vs_m)))
vuint8m1_t vredxor_vs_u8m1_u8m1_m(vbool8_t, vuint8m1_t, vuint8m1_t, vuint8m1_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vredxor_vs)))
vuint8m1_t vredxor_vs_u8m2_u8m1(vuint8m1_t, vuint8m2_t, vuint8m1_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vredxor_vs_m)))
vuint8m1_t vredxor_vs_u8m2_u8m1_m(vbool4_t, vuint8m1_t, vuint8m2_t, vuint8m1_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vredxor_vs)))
vuint8m1_t vredxor_vs_u8m4_u8m1(vuint8m1_t, vuint8m4_t, vuint8m1_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vredxor_vs_m)))
vuint8m1_t vredxor_vs_u8m4_u8m1_m(vbool2_t, vuint8m1_t, vuint8m4_t, vuint8m1_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vredxor_vs)))
vuint8m1_t vredxor_vs_u8m8_u8m1(vuint8m1_t, vuint8m8_t, vuint8m1_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vredxor_vs_m)))
vuint8m1_t vredxor_vs_u8m8_u8m1_m(vbool1_t, vuint8m1_t, vuint8m8_t, vuint8m1_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vredxor_vs)))
vuint8m1_t vredxor_vs_u8mf2_u8m1(vuint8m1_t, vuint8mf2_t, vuint8m1_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vredxor_vs_m)))
vuint8m1_t vredxor_vs_u8mf2_u8m1_m(vbool16_t, vuint8m1_t, vuint8mf2_t, vuint8m1_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vredxor_vs)))
vuint8m1_t vredxor_vs_u8mf4_u8m1(vuint8m1_t, vuint8mf4_t, vuint8m1_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vredxor_vs_m)))
vuint8m1_t vredxor_vs_u8mf4_u8m1_m(vbool32_t, vuint8m1_t, vuint8mf4_t, vuint8m1_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vredxor_vs)))
vuint8m1_t vredxor_vs_u8mf8_u8m1(vuint8m1_t, vuint8mf8_t, vuint8m1_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vredxor_vs_m)))
vuint8m1_t vredxor_vs_u8mf8_u8m1_m(vbool64_t, vuint8m1_t, vuint8mf8_t, vuint8m1_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vredxor_vs)))
vuint16m1_t vredxor_vs_u16m1_u16m1(vuint16m1_t, vuint16m1_t, vuint16m1_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vredxor_vs_m)))
vuint16m1_t vredxor_vs_u16m1_u16m1_m(vbool16_t, vuint16m1_t, vuint16m1_t, vuint16m1_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vredxor_vs)))
vuint16m1_t vredxor_vs_u16m2_u16m1(vuint16m1_t, vuint16m2_t, vuint16m1_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vredxor_vs_m)))
vuint16m1_t vredxor_vs_u16m2_u16m1_m(vbool8_t, vuint16m1_t, vuint16m2_t, vuint16m1_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vredxor_vs)))
vuint16m1_t vredxor_vs_u16m4_u16m1(vuint16m1_t, vuint16m4_t, vuint16m1_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vredxor_vs_m)))
vuint16m1_t vredxor_vs_u16m4_u16m1_m(vbool4_t, vuint16m1_t, vuint16m4_t, vuint16m1_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vredxor_vs)))
vuint16m1_t vredxor_vs_u16m8_u16m1(vuint16m1_t, vuint16m8_t, vuint16m1_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vredxor_vs_m)))
vuint16m1_t vredxor_vs_u16m8_u16m1_m(vbool2_t, vuint16m1_t, vuint16m8_t, vuint16m1_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vredxor_vs)))
vuint16m1_t vredxor_vs_u16mf2_u16m1(vuint16m1_t, vuint16mf2_t, vuint16m1_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vredxor_vs_m)))
vuint16m1_t vredxor_vs_u16mf2_u16m1_m(vbool32_t, vuint16m1_t, vuint16mf2_t, vuint16m1_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vredxor_vs)))
vuint16m1_t vredxor_vs_u16mf4_u16m1(vuint16m1_t, vuint16mf4_t, vuint16m1_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vredxor_vs_m)))
vuint16m1_t vredxor_vs_u16mf4_u16m1_m(vbool64_t, vuint16m1_t, vuint16mf4_t, vuint16m1_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vredxor_vs)))
vuint32m1_t vredxor_vs_u32m1_u32m1(vuint32m1_t, vuint32m1_t, vuint32m1_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vredxor_vs_m)))
vuint32m1_t vredxor_vs_u32m1_u32m1_m(vbool32_t, vuint32m1_t, vuint32m1_t, vuint32m1_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vredxor_vs)))
vuint32m1_t vredxor_vs_u32m2_u32m1(vuint32m1_t, vuint32m2_t, vuint32m1_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vredxor_vs_m)))
vuint32m1_t vredxor_vs_u32m2_u32m1_m(vbool16_t, vuint32m1_t, vuint32m2_t, vuint32m1_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vredxor_vs)))
vuint32m1_t vredxor_vs_u32m4_u32m1(vuint32m1_t, vuint32m4_t, vuint32m1_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vredxor_vs_m)))
vuint32m1_t vredxor_vs_u32m4_u32m1_m(vbool8_t, vuint32m1_t, vuint32m4_t, vuint32m1_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vredxor_vs)))
vuint32m1_t vredxor_vs_u32m8_u32m1(vuint32m1_t, vuint32m8_t, vuint32m1_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vredxor_vs_m)))
vuint32m1_t vredxor_vs_u32m8_u32m1_m(vbool4_t, vuint32m1_t, vuint32m8_t, vuint32m1_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vredxor_vs)))
vuint32m1_t vredxor_vs_u32mf2_u32m1(vuint32m1_t, vuint32mf2_t, vuint32m1_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vredxor_vs_m)))
vuint32m1_t vredxor_vs_u32mf2_u32m1_m(vbool64_t, vuint32m1_t, vuint32mf2_t, vuint32m1_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vwredsum_vs)))
vint16m1_t vwredsum_vs_i8m1_i16m1(vint16m1_t, vint8m1_t, vint16m1_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vwredsum_vs_m)))
vint16m1_t vwredsum_vs_i8m1_i16m1_m(vbool8_t, vint16m1_t, vint8m1_t, vint16m1_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vwredsum_vs)))
vint16m1_t vwredsum_vs_i8m2_i16m1(vint16m1_t, vint8m2_t, vint16m1_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vwredsum_vs_m)))
vint16m1_t vwredsum_vs_i8m2_i16m1_m(vbool4_t, vint16m1_t, vint8m2_t, vint16m1_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vwredsum_vs)))
vint16m1_t vwredsum_vs_i8m4_i16m1(vint16m1_t, vint8m4_t, vint16m1_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vwredsum_vs_m)))
vint16m1_t vwredsum_vs_i8m4_i16m1_m(vbool2_t, vint16m1_t, vint8m4_t, vint16m1_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vwredsum_vs)))
vint16m1_t vwredsum_vs_i8m8_i16m1(vint16m1_t, vint8m8_t, vint16m1_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vwredsum_vs_m)))
vint16m1_t vwredsum_vs_i8m8_i16m1_m(vbool1_t, vint16m1_t, vint8m8_t, vint16m1_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vwredsum_vs)))
vint16m1_t vwredsum_vs_i8mf2_i16m1(vint16m1_t, vint8mf2_t, vint16m1_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vwredsum_vs_m)))
vint16m1_t vwredsum_vs_i8mf2_i16m1_m(vbool16_t, vint16m1_t, vint8mf2_t, vint16m1_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vwredsum_vs)))
vint16m1_t vwredsum_vs_i8mf4_i16m1(vint16m1_t, vint8mf4_t, vint16m1_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vwredsum_vs_m)))
vint16m1_t vwredsum_vs_i8mf4_i16m1_m(vbool32_t, vint16m1_t, vint8mf4_t, vint16m1_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vwredsum_vs)))
vint16m1_t vwredsum_vs_i8mf8_i16m1(vint16m1_t, vint8mf8_t, vint16m1_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vwredsum_vs_m)))
vint16m1_t vwredsum_vs_i8mf8_i16m1_m(vbool64_t, vint16m1_t, vint8mf8_t, vint16m1_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vwredsum_vs)))
vint32m1_t vwredsum_vs_i16m1_i32m1(vint32m1_t, vint16m1_t, vint32m1_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vwredsum_vs_m)))
vint32m1_t vwredsum_vs_i16m1_i32m1_m(vbool16_t, vint32m1_t, vint16m1_t, vint32m1_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vwredsum_vs)))
vint32m1_t vwredsum_vs_i16m2_i32m1(vint32m1_t, vint16m2_t, vint32m1_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vwredsum_vs_m)))
vint32m1_t vwredsum_vs_i16m2_i32m1_m(vbool8_t, vint32m1_t, vint16m2_t, vint32m1_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vwredsum_vs)))
vint32m1_t vwredsum_vs_i16m4_i32m1(vint32m1_t, vint16m4_t, vint32m1_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vwredsum_vs_m)))
vint32m1_t vwredsum_vs_i16m4_i32m1_m(vbool4_t, vint32m1_t, vint16m4_t, vint32m1_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vwredsum_vs)))
vint32m1_t vwredsum_vs_i16m8_i32m1(vint32m1_t, vint16m8_t, vint32m1_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vwredsum_vs_m)))
vint32m1_t vwredsum_vs_i16m8_i32m1_m(vbool2_t, vint32m1_t, vint16m8_t, vint32m1_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vwredsum_vs)))
vint32m1_t vwredsum_vs_i16mf2_i32m1(vint32m1_t, vint16mf2_t, vint32m1_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vwredsum_vs_m)))
vint32m1_t vwredsum_vs_i16mf2_i32m1_m(vbool32_t, vint32m1_t, vint16mf2_t, vint32m1_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vwredsum_vs)))
vint32m1_t vwredsum_vs_i16mf4_i32m1(vint32m1_t, vint16mf4_t, vint32m1_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vwredsum_vs_m)))
vint32m1_t vwredsum_vs_i16mf4_i32m1_m(vbool64_t, vint32m1_t, vint16mf4_t, vint32m1_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vwredsumu_vs)))
vuint16m1_t vwredsumu_vs_u8m1_u16m1(vuint16m1_t, vuint8m1_t, vuint16m1_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vwredsumu_vs_m)))
vuint16m1_t vwredsumu_vs_u8m1_u16m1_m(vbool8_t, vuint16m1_t, vuint8m1_t, vuint16m1_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vwredsumu_vs)))
vuint16m1_t vwredsumu_vs_u8m2_u16m1(vuint16m1_t, vuint8m2_t, vuint16m1_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vwredsumu_vs_m)))
vuint16m1_t vwredsumu_vs_u8m2_u16m1_m(vbool4_t, vuint16m1_t, vuint8m2_t, vuint16m1_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vwredsumu_vs)))
vuint16m1_t vwredsumu_vs_u8m4_u16m1(vuint16m1_t, vuint8m4_t, vuint16m1_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vwredsumu_vs_m)))
vuint16m1_t vwredsumu_vs_u8m4_u16m1_m(vbool2_t, vuint16m1_t, vuint8m4_t, vuint16m1_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vwredsumu_vs)))
vuint16m1_t vwredsumu_vs_u8m8_u16m1(vuint16m1_t, vuint8m8_t, vuint16m1_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vwredsumu_vs_m)))
vuint16m1_t vwredsumu_vs_u8m8_u16m1_m(vbool1_t, vuint16m1_t, vuint8m8_t, vuint16m1_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vwredsumu_vs)))
vuint16m1_t vwredsumu_vs_u8mf2_u16m1(vuint16m1_t, vuint8mf2_t, vuint16m1_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vwredsumu_vs_m)))
vuint16m1_t vwredsumu_vs_u8mf2_u16m1_m(vbool16_t, vuint16m1_t, vuint8mf2_t, vuint16m1_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vwredsumu_vs)))
vuint16m1_t vwredsumu_vs_u8mf4_u16m1(vuint16m1_t, vuint8mf4_t, vuint16m1_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vwredsumu_vs_m)))
vuint16m1_t vwredsumu_vs_u8mf4_u16m1_m(vbool32_t, vuint16m1_t, vuint8mf4_t, vuint16m1_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vwredsumu_vs)))
vuint16m1_t vwredsumu_vs_u8mf8_u16m1(vuint16m1_t, vuint8mf8_t, vuint16m1_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vwredsumu_vs_m)))
vuint16m1_t vwredsumu_vs_u8mf8_u16m1_m(vbool64_t, vuint16m1_t, vuint8mf8_t, vuint16m1_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vwredsumu_vs)))
vuint32m1_t vwredsumu_vs_u16m1_u32m1(vuint32m1_t, vuint16m1_t, vuint32m1_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vwredsumu_vs_m)))
vuint32m1_t vwredsumu_vs_u16m1_u32m1_m(vbool16_t, vuint32m1_t, vuint16m1_t, vuint32m1_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vwredsumu_vs)))
vuint32m1_t vwredsumu_vs_u16m2_u32m1(vuint32m1_t, vuint16m2_t, vuint32m1_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vwredsumu_vs_m)))
vuint32m1_t vwredsumu_vs_u16m2_u32m1_m(vbool8_t, vuint32m1_t, vuint16m2_t, vuint32m1_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vwredsumu_vs)))
vuint32m1_t vwredsumu_vs_u16m4_u32m1(vuint32m1_t, vuint16m4_t, vuint32m1_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vwredsumu_vs_m)))
vuint32m1_t vwredsumu_vs_u16m4_u32m1_m(vbool4_t, vuint32m1_t, vuint16m4_t, vuint32m1_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vwredsumu_vs)))
vuint32m1_t vwredsumu_vs_u16m8_u32m1(vuint32m1_t, vuint16m8_t, vuint32m1_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vwredsumu_vs_m)))
vuint32m1_t vwredsumu_vs_u16m8_u32m1_m(vbool2_t, vuint32m1_t, vuint16m8_t, vuint32m1_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vwredsumu_vs)))
vuint32m1_t vwredsumu_vs_u16mf2_u32m1(vuint32m1_t, vuint16mf2_t, vuint32m1_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vwredsumu_vs_m)))
vuint32m1_t vwredsumu_vs_u16mf2_u32m1_m(vbool32_t, vuint32m1_t, vuint16mf2_t, vuint32m1_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vwredsumu_vs)))
vuint32m1_t vwredsumu_vs_u16mf4_u32m1(vuint32m1_t, vuint16mf4_t, vuint32m1_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vwredsumu_vs_m)))
vuint32m1_t vwredsumu_vs_u16mf4_u32m1_m(vbool64_t, vuint32m1_t, vuint16mf4_t, vuint32m1_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vmnot_m)))
vbool8_t vmnot_m_b8(vbool8_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vmnot_m)))
vbool4_t vmnot_m_b4(vbool4_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vmnot_m)))
vbool2_t vmnot_m_b2(vbool2_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vmnot_m)))
vbool1_t vmnot_m_b1(vbool1_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vmnot_m)))
vbool16_t vmnot_m_b16(vbool16_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vmnot_m)))
vbool32_t vmnot_m_b32(vbool32_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vmnot_m)))
vbool64_t vmnot_m_b64(vbool64_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_viota_m)))
vuint8m1_t viota_m_u8m1(vbool8_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_viota_m_m)))
vuint8m1_t viota_m_u8m1_m(vbool8_t, vuint8m1_t, vbool8_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_viota_m)))
vuint8m2_t viota_m_u8m2(vbool4_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_viota_m_m)))
vuint8m2_t viota_m_u8m2_m(vbool4_t, vuint8m2_t, vbool4_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_viota_m)))
vuint8m4_t viota_m_u8m4(vbool2_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_viota_m_m)))
vuint8m4_t viota_m_u8m4_m(vbool2_t, vuint8m4_t, vbool2_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_viota_m)))
vuint8m8_t viota_m_u8m8(vbool1_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_viota_m_m)))
vuint8m8_t viota_m_u8m8_m(vbool1_t, vuint8m8_t, vbool1_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_viota_m)))
vuint8mf2_t viota_m_u8mf2(vbool16_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_viota_m_m)))
vuint8mf2_t viota_m_u8mf2_m(vbool16_t, vuint8mf2_t, vbool16_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_viota_m)))
vuint8mf4_t viota_m_u8mf4(vbool32_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_viota_m_m)))
vuint8mf4_t viota_m_u8mf4_m(vbool32_t, vuint8mf4_t, vbool32_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_viota_m)))
vuint8mf8_t viota_m_u8mf8(vbool64_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_viota_m_m)))
vuint8mf8_t viota_m_u8mf8_m(vbool64_t, vuint8mf8_t, vbool64_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_viota_m)))
vuint16m1_t viota_m_u16m1(vbool16_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_viota_m_m)))
vuint16m1_t viota_m_u16m1_m(vbool16_t, vuint16m1_t, vbool16_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_viota_m)))
vuint16m2_t viota_m_u16m2(vbool8_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_viota_m_m)))
vuint16m2_t viota_m_u16m2_m(vbool8_t, vuint16m2_t, vbool8_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_viota_m)))
vuint16m4_t viota_m_u16m4(vbool4_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_viota_m_m)))
vuint16m4_t viota_m_u16m4_m(vbool4_t, vuint16m4_t, vbool4_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_viota_m)))
vuint16m8_t viota_m_u16m8(vbool2_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_viota_m_m)))
vuint16m8_t viota_m_u16m8_m(vbool2_t, vuint16m8_t, vbool2_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_viota_m)))
vuint16mf2_t viota_m_u16mf2(vbool32_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_viota_m_m)))
vuint16mf2_t viota_m_u16mf2_m(vbool32_t, vuint16mf2_t, vbool32_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_viota_m)))
vuint16mf4_t viota_m_u16mf4(vbool64_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_viota_m_m)))
vuint16mf4_t viota_m_u16mf4_m(vbool64_t, vuint16mf4_t, vbool64_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_viota_m)))
vuint32m1_t viota_m_u32m1(vbool32_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_viota_m_m)))
vuint32m1_t viota_m_u32m1_m(vbool32_t, vuint32m1_t, vbool32_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_viota_m)))
vuint32m2_t viota_m_u32m2(vbool16_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_viota_m_m)))
vuint32m2_t viota_m_u32m2_m(vbool16_t, vuint32m2_t, vbool16_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_viota_m)))
vuint32m4_t viota_m_u32m4(vbool8_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_viota_m_m)))
vuint32m4_t viota_m_u32m4_m(vbool8_t, vuint32m4_t, vbool8_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_viota_m)))
vuint32m8_t viota_m_u32m8(vbool4_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_viota_m_m)))
vuint32m8_t viota_m_u32m8_m(vbool4_t, vuint32m8_t, vbool4_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_viota_m)))
vuint32mf2_t viota_m_u32mf2(vbool64_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_viota_m_m)))
vuint32mf2_t viota_m_u32mf2_m(vbool64_t, vuint32mf2_t, vbool64_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vid_v)))
vint8m1_t vid_v_i8m1(size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vid_v_m)))
vint8m1_t vid_v_i8m1_m(vbool8_t, vint8m1_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vid_v)))
vint8m2_t vid_v_i8m2(size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vid_v_m)))
vint8m2_t vid_v_i8m2_m(vbool4_t, vint8m2_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vid_v)))
vint8m4_t vid_v_i8m4(size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vid_v_m)))
vint8m4_t vid_v_i8m4_m(vbool2_t, vint8m4_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vid_v)))
vint8m8_t vid_v_i8m8(size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vid_v_m)))
vint8m8_t vid_v_i8m8_m(vbool1_t, vint8m8_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vid_v)))
vint8mf2_t vid_v_i8mf2(size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vid_v_m)))
vint8mf2_t vid_v_i8mf2_m(vbool16_t, vint8mf2_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vid_v)))
vint8mf4_t vid_v_i8mf4(size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vid_v_m)))
vint8mf4_t vid_v_i8mf4_m(vbool32_t, vint8mf4_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vid_v)))
vint8mf8_t vid_v_i8mf8(size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vid_v_m)))
vint8mf8_t vid_v_i8mf8_m(vbool64_t, vint8mf8_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vid_v)))
vint16m1_t vid_v_i16m1(size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vid_v_m)))
vint16m1_t vid_v_i16m1_m(vbool16_t, vint16m1_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vid_v)))
vint16m2_t vid_v_i16m2(size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vid_v_m)))
vint16m2_t vid_v_i16m2_m(vbool8_t, vint16m2_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vid_v)))
vint16m4_t vid_v_i16m4(size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vid_v_m)))
vint16m4_t vid_v_i16m4_m(vbool4_t, vint16m4_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vid_v)))
vint16m8_t vid_v_i16m8(size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vid_v_m)))
vint16m8_t vid_v_i16m8_m(vbool2_t, vint16m8_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vid_v)))
vint16mf2_t vid_v_i16mf2(size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vid_v_m)))
vint16mf2_t vid_v_i16mf2_m(vbool32_t, vint16mf2_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vid_v)))
vint16mf4_t vid_v_i16mf4(size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vid_v_m)))
vint16mf4_t vid_v_i16mf4_m(vbool64_t, vint16mf4_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vid_v)))
vint32m1_t vid_v_i32m1(size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vid_v_m)))
vint32m1_t vid_v_i32m1_m(vbool32_t, vint32m1_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vid_v)))
vint32m2_t vid_v_i32m2(size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vid_v_m)))
vint32m2_t vid_v_i32m2_m(vbool16_t, vint32m2_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vid_v)))
vint32m4_t vid_v_i32m4(size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vid_v_m)))
vint32m4_t vid_v_i32m4_m(vbool8_t, vint32m4_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vid_v)))
vint32m8_t vid_v_i32m8(size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vid_v_m)))
vint32m8_t vid_v_i32m8_m(vbool4_t, vint32m8_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vid_v)))
vint32mf2_t vid_v_i32mf2(size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vid_v_m)))
vint32mf2_t vid_v_i32mf2_m(vbool64_t, vint32mf2_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vid_v)))
vuint8m1_t vid_v_u8m1(size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vid_v_m)))
vuint8m1_t vid_v_u8m1_m(vbool8_t, vuint8m1_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vid_v)))
vuint8m2_t vid_v_u8m2(size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vid_v_m)))
vuint8m2_t vid_v_u8m2_m(vbool4_t, vuint8m2_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vid_v)))
vuint8m4_t vid_v_u8m4(size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vid_v_m)))
vuint8m4_t vid_v_u8m4_m(vbool2_t, vuint8m4_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vid_v)))
vuint8m8_t vid_v_u8m8(size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vid_v_m)))
vuint8m8_t vid_v_u8m8_m(vbool1_t, vuint8m8_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vid_v)))
vuint8mf2_t vid_v_u8mf2(size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vid_v_m)))
vuint8mf2_t vid_v_u8mf2_m(vbool16_t, vuint8mf2_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vid_v)))
vuint8mf4_t vid_v_u8mf4(size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vid_v_m)))
vuint8mf4_t vid_v_u8mf4_m(vbool32_t, vuint8mf4_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vid_v)))
vuint8mf8_t vid_v_u8mf8(size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vid_v_m)))
vuint8mf8_t vid_v_u8mf8_m(vbool64_t, vuint8mf8_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vid_v)))
vuint16m1_t vid_v_u16m1(size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vid_v_m)))
vuint16m1_t vid_v_u16m1_m(vbool16_t, vuint16m1_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vid_v)))
vuint16m2_t vid_v_u16m2(size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vid_v_m)))
vuint16m2_t vid_v_u16m2_m(vbool8_t, vuint16m2_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vid_v)))
vuint16m4_t vid_v_u16m4(size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vid_v_m)))
vuint16m4_t vid_v_u16m4_m(vbool4_t, vuint16m4_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vid_v)))
vuint16m8_t vid_v_u16m8(size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vid_v_m)))
vuint16m8_t vid_v_u16m8_m(vbool2_t, vuint16m8_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vid_v)))
vuint16mf2_t vid_v_u16mf2(size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vid_v_m)))
vuint16mf2_t vid_v_u16mf2_m(vbool32_t, vuint16mf2_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vid_v)))
vuint16mf4_t vid_v_u16mf4(size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vid_v_m)))
vuint16mf4_t vid_v_u16mf4_m(vbool64_t, vuint16mf4_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vid_v)))
vuint32m1_t vid_v_u32m1(size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vid_v_m)))
vuint32m1_t vid_v_u32m1_m(vbool32_t, vuint32m1_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vid_v)))
vuint32m2_t vid_v_u32m2(size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vid_v_m)))
vuint32m2_t vid_v_u32m2_m(vbool16_t, vuint32m2_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vid_v)))
vuint32m4_t vid_v_u32m4(size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vid_v_m)))
vuint32m4_t vid_v_u32m4_m(vbool8_t, vuint32m4_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vid_v)))
vuint32m8_t vid_v_u32m8(size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vid_v_m)))
vuint32m8_t vid_v_u32m8_m(vbool4_t, vuint32m8_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vid_v)))
vuint32mf2_t vid_v_u32mf2(size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vid_v_m)))
vuint32mf2_t vid_v_u32mf2_m(vbool64_t, vuint32mf2_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vmv_x_s)))
int8_t vmv_x_s_i8m1_i8(vint8m1_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vmv_x_s)))
int8_t vmv_x_s_i8m2_i8(vint8m2_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vmv_x_s)))
int8_t vmv_x_s_i8m4_i8(vint8m4_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vmv_x_s)))
int8_t vmv_x_s_i8m8_i8(vint8m8_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vmv_x_s)))
int8_t vmv_x_s_i8mf2_i8(vint8mf2_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vmv_x_s)))
int8_t vmv_x_s_i8mf4_i8(vint8mf4_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vmv_x_s)))
int8_t vmv_x_s_i8mf8_i8(vint8mf8_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vmv_x_s)))
int16_t vmv_x_s_i16m1_i16(vint16m1_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vmv_x_s)))
int16_t vmv_x_s_i16m2_i16(vint16m2_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vmv_x_s)))
int16_t vmv_x_s_i16m4_i16(vint16m4_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vmv_x_s)))
int16_t vmv_x_s_i16m8_i16(vint16m8_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vmv_x_s)))
int16_t vmv_x_s_i16mf2_i16(vint16mf2_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vmv_x_s)))
int16_t vmv_x_s_i16mf4_i16(vint16mf4_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vmv_x_s)))
int32_t vmv_x_s_i32m1_i32(vint32m1_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vmv_x_s)))
int32_t vmv_x_s_i32m2_i32(vint32m2_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vmv_x_s)))
int32_t vmv_x_s_i32m4_i32(vint32m4_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vmv_x_s)))
int32_t vmv_x_s_i32m8_i32(vint32m8_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vmv_x_s)))
int32_t vmv_x_s_i32mf2_i32(vint32mf2_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vmv_x_s)))
uint8_t vmv_x_s_u8m1_u8(vuint8m1_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vmv_x_s)))
uint8_t vmv_x_s_u8m2_u8(vuint8m2_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vmv_x_s)))
uint8_t vmv_x_s_u8m4_u8(vuint8m4_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vmv_x_s)))
uint8_t vmv_x_s_u8m8_u8(vuint8m8_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vmv_x_s)))
uint8_t vmv_x_s_u8mf2_u8(vuint8mf2_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vmv_x_s)))
uint8_t vmv_x_s_u8mf4_u8(vuint8mf4_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vmv_x_s)))
uint8_t vmv_x_s_u8mf8_u8(vuint8mf8_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vmv_x_s)))
uint16_t vmv_x_s_u16m1_u16(vuint16m1_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vmv_x_s)))
uint16_t vmv_x_s_u16m2_u16(vuint16m2_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vmv_x_s)))
uint16_t vmv_x_s_u16m4_u16(vuint16m4_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vmv_x_s)))
uint16_t vmv_x_s_u16m8_u16(vuint16m8_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vmv_x_s)))
uint16_t vmv_x_s_u16mf2_u16(vuint16mf2_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vmv_x_s)))
uint16_t vmv_x_s_u16mf4_u16(vuint16mf4_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vmv_x_s)))
uint32_t vmv_x_s_u32m1_u32(vuint32m1_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vmv_x_s)))
uint32_t vmv_x_s_u32m2_u32(vuint32m2_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vmv_x_s)))
uint32_t vmv_x_s_u32m4_u32(vuint32m4_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vmv_x_s)))
uint32_t vmv_x_s_u32m8_u32(vuint32m8_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vmv_x_s)))
uint32_t vmv_x_s_u32mf2_u32(vuint32mf2_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vmv_s_x)))
vint8m1_t vmv_s_x_i8m1(vint8m1_t, int8_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vmv_s_x)))
vint8m2_t vmv_s_x_i8m2(vint8m2_t, int8_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vmv_s_x)))
vint8m4_t vmv_s_x_i8m4(vint8m4_t, int8_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vmv_s_x)))
vint8m8_t vmv_s_x_i8m8(vint8m8_t, int8_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vmv_s_x)))
vint8mf2_t vmv_s_x_i8mf2(vint8mf2_t, int8_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vmv_s_x)))
vint8mf4_t vmv_s_x_i8mf4(vint8mf4_t, int8_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vmv_s_x)))
vint8mf8_t vmv_s_x_i8mf8(vint8mf8_t, int8_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vmv_s_x)))
vint16m1_t vmv_s_x_i16m1(vint16m1_t, int16_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vmv_s_x)))
vint16m2_t vmv_s_x_i16m2(vint16m2_t, int16_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vmv_s_x)))
vint16m4_t vmv_s_x_i16m4(vint16m4_t, int16_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vmv_s_x)))
vint16m8_t vmv_s_x_i16m8(vint16m8_t, int16_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vmv_s_x)))
vint16mf2_t vmv_s_x_i16mf2(vint16mf2_t, int16_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vmv_s_x)))
vint16mf4_t vmv_s_x_i16mf4(vint16mf4_t, int16_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vmv_s_x)))
vint32m1_t vmv_s_x_i32m1(vint32m1_t, int32_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vmv_s_x)))
vint32m2_t vmv_s_x_i32m2(vint32m2_t, int32_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vmv_s_x)))
vint32m4_t vmv_s_x_i32m4(vint32m4_t, int32_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vmv_s_x)))
vint32m8_t vmv_s_x_i32m8(vint32m8_t, int32_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vmv_s_x)))
vint32mf2_t vmv_s_x_i32mf2(vint32mf2_t, int32_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vmv_s_x)))
vuint8m1_t vmv_s_x_u8m1(vuint8m1_t, uint8_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vmv_s_x)))
vuint8m2_t vmv_s_x_u8m2(vuint8m2_t, uint8_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vmv_s_x)))
vuint8m4_t vmv_s_x_u8m4(vuint8m4_t, uint8_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vmv_s_x)))
vuint8m8_t vmv_s_x_u8m8(vuint8m8_t, uint8_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vmv_s_x)))
vuint8mf2_t vmv_s_x_u8mf2(vuint8mf2_t, uint8_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vmv_s_x)))
vuint8mf4_t vmv_s_x_u8mf4(vuint8mf4_t, uint8_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vmv_s_x)))
vuint8mf8_t vmv_s_x_u8mf8(vuint8mf8_t, uint8_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vmv_s_x)))
vuint16m1_t vmv_s_x_u16m1(vuint16m1_t, uint16_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vmv_s_x)))
vuint16m2_t vmv_s_x_u16m2(vuint16m2_t, uint16_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vmv_s_x)))
vuint16m4_t vmv_s_x_u16m4(vuint16m4_t, uint16_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vmv_s_x)))
vuint16m8_t vmv_s_x_u16m8(vuint16m8_t, uint16_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vmv_s_x)))
vuint16mf2_t vmv_s_x_u16mf2(vuint16mf2_t, uint16_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vmv_s_x)))
vuint16mf4_t vmv_s_x_u16mf4(vuint16mf4_t, uint16_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vmv_s_x)))
vuint32m1_t vmv_s_x_u32m1(vuint32m1_t, uint32_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vmv_s_x)))
vuint32m2_t vmv_s_x_u32m2(vuint32m2_t, uint32_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vmv_s_x)))
vuint32m4_t vmv_s_x_u32m4(vuint32m4_t, uint32_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vmv_s_x)))
vuint32m8_t vmv_s_x_u32m8(vuint32m8_t, uint32_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vmv_s_x)))
vuint32mf2_t vmv_s_x_u32mf2(vuint32mf2_t, uint32_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vfmv_s_x)))
vuint16m1_t vfmv_s_x_u16m1(vuint16m1_t, uint16_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vfmv_s_x)))
vuint16m2_t vfmv_s_x_u16m2(vuint16m2_t, uint16_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vfmv_s_x)))
vuint16m4_t vfmv_s_x_u16m4(vuint16m4_t, uint16_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vfmv_s_x)))
vuint16m8_t vfmv_s_x_u16m8(vuint16m8_t, uint16_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vfmv_s_x)))
vuint16mf2_t vfmv_s_x_u16mf2(vuint16mf2_t, uint16_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vfmv_s_x)))
vuint16mf4_t vfmv_s_x_u16mf4(vuint16mf4_t, uint16_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vfmv_s_x)))
vuint32m1_t vfmv_s_x_u32m1(vuint32m1_t, uint32_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vfmv_s_x)))
vuint32m2_t vfmv_s_x_u32m2(vuint32m2_t, uint32_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vfmv_s_x)))
vuint32m4_t vfmv_s_x_u32m4(vuint32m4_t, uint32_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vfmv_s_x)))
vuint32m8_t vfmv_s_x_u32m8(vuint32m8_t, uint32_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vfmv_s_x)))
vuint32mf2_t vfmv_s_x_u32mf2(vuint32mf2_t, uint32_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vslideup_vx)))
vint8m1_t vslideup_vx_i8m1(vint8m1_t, vint8m1_t, size_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vslideup_vx_m)))
vint8m1_t vslideup_vx_i8m1_m(vbool8_t, vint8m1_t, vint8m1_t, size_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vslideup_vx)))
vint8m2_t vslideup_vx_i8m2(vint8m2_t, vint8m2_t, size_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vslideup_vx_m)))
vint8m2_t vslideup_vx_i8m2_m(vbool4_t, vint8m2_t, vint8m2_t, size_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vslideup_vx)))
vint8m4_t vslideup_vx_i8m4(vint8m4_t, vint8m4_t, size_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vslideup_vx_m)))
vint8m4_t vslideup_vx_i8m4_m(vbool2_t, vint8m4_t, vint8m4_t, size_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vslideup_vx)))
vint8m8_t vslideup_vx_i8m8(vint8m8_t, vint8m8_t, size_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vslideup_vx_m)))
vint8m8_t vslideup_vx_i8m8_m(vbool1_t, vint8m8_t, vint8m8_t, size_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vslideup_vx)))
vint8mf2_t vslideup_vx_i8mf2(vint8mf2_t, vint8mf2_t, size_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vslideup_vx_m)))
vint8mf2_t vslideup_vx_i8mf2_m(vbool16_t, vint8mf2_t, vint8mf2_t, size_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vslideup_vx)))
vint8mf4_t vslideup_vx_i8mf4(vint8mf4_t, vint8mf4_t, size_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vslideup_vx_m)))
vint8mf4_t vslideup_vx_i8mf4_m(vbool32_t, vint8mf4_t, vint8mf4_t, size_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vslideup_vx)))
vint8mf8_t vslideup_vx_i8mf8(vint8mf8_t, vint8mf8_t, size_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vslideup_vx_m)))
vint8mf8_t vslideup_vx_i8mf8_m(vbool64_t, vint8mf8_t, vint8mf8_t, size_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vslideup_vx)))
vint16m1_t vslideup_vx_i16m1(vint16m1_t, vint16m1_t, size_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vslideup_vx_m)))
vint16m1_t vslideup_vx_i16m1_m(vbool16_t, vint16m1_t, vint16m1_t, size_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vslideup_vx)))
vint16m2_t vslideup_vx_i16m2(vint16m2_t, vint16m2_t, size_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vslideup_vx_m)))
vint16m2_t vslideup_vx_i16m2_m(vbool8_t, vint16m2_t, vint16m2_t, size_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vslideup_vx)))
vint16m4_t vslideup_vx_i16m4(vint16m4_t, vint16m4_t, size_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vslideup_vx_m)))
vint16m4_t vslideup_vx_i16m4_m(vbool4_t, vint16m4_t, vint16m4_t, size_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vslideup_vx)))
vint16m8_t vslideup_vx_i16m8(vint16m8_t, vint16m8_t, size_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vslideup_vx_m)))
vint16m8_t vslideup_vx_i16m8_m(vbool2_t, vint16m8_t, vint16m8_t, size_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vslideup_vx)))
vint16mf2_t vslideup_vx_i16mf2(vint16mf2_t, vint16mf2_t, size_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vslideup_vx_m)))
vint16mf2_t vslideup_vx_i16mf2_m(vbool32_t, vint16mf2_t, vint16mf2_t, size_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vslideup_vx)))
vint16mf4_t vslideup_vx_i16mf4(vint16mf4_t, vint16mf4_t, size_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vslideup_vx_m)))
vint16mf4_t vslideup_vx_i16mf4_m(vbool64_t, vint16mf4_t, vint16mf4_t, size_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vslideup_vx)))
vint32m1_t vslideup_vx_i32m1(vint32m1_t, vint32m1_t, size_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vslideup_vx_m)))
vint32m1_t vslideup_vx_i32m1_m(vbool32_t, vint32m1_t, vint32m1_t, size_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vslideup_vx)))
vint32m2_t vslideup_vx_i32m2(vint32m2_t, vint32m2_t, size_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vslideup_vx_m)))
vint32m2_t vslideup_vx_i32m2_m(vbool16_t, vint32m2_t, vint32m2_t, size_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vslideup_vx)))
vint32m4_t vslideup_vx_i32m4(vint32m4_t, vint32m4_t, size_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vslideup_vx_m)))
vint32m4_t vslideup_vx_i32m4_m(vbool8_t, vint32m4_t, vint32m4_t, size_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vslideup_vx)))
vint32m8_t vslideup_vx_i32m8(vint32m8_t, vint32m8_t, size_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vslideup_vx_m)))
vint32m8_t vslideup_vx_i32m8_m(vbool4_t, vint32m8_t, vint32m8_t, size_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vslideup_vx)))
vint32mf2_t vslideup_vx_i32mf2(vint32mf2_t, vint32mf2_t, size_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vslideup_vx_m)))
vint32mf2_t vslideup_vx_i32mf2_m(vbool64_t, vint32mf2_t, vint32mf2_t, size_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vslideup_vx)))
vuint8m1_t vslideup_vx_u8m1(vuint8m1_t, vuint8m1_t, size_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vslideup_vx_m)))
vuint8m1_t vslideup_vx_u8m1_m(vbool8_t, vuint8m1_t, vuint8m1_t, size_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vslideup_vx)))
vuint8m2_t vslideup_vx_u8m2(vuint8m2_t, vuint8m2_t, size_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vslideup_vx_m)))
vuint8m2_t vslideup_vx_u8m2_m(vbool4_t, vuint8m2_t, vuint8m2_t, size_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vslideup_vx)))
vuint8m4_t vslideup_vx_u8m4(vuint8m4_t, vuint8m4_t, size_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vslideup_vx_m)))
vuint8m4_t vslideup_vx_u8m4_m(vbool2_t, vuint8m4_t, vuint8m4_t, size_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vslideup_vx)))
vuint8m8_t vslideup_vx_u8m8(vuint8m8_t, vuint8m8_t, size_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vslideup_vx_m)))
vuint8m8_t vslideup_vx_u8m8_m(vbool1_t, vuint8m8_t, vuint8m8_t, size_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vslideup_vx)))
vuint8mf2_t vslideup_vx_u8mf2(vuint8mf2_t, vuint8mf2_t, size_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vslideup_vx_m)))
vuint8mf2_t vslideup_vx_u8mf2_m(vbool16_t, vuint8mf2_t, vuint8mf2_t, size_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vslideup_vx)))
vuint8mf4_t vslideup_vx_u8mf4(vuint8mf4_t, vuint8mf4_t, size_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vslideup_vx_m)))
vuint8mf4_t vslideup_vx_u8mf4_m(vbool32_t, vuint8mf4_t, vuint8mf4_t, size_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vslideup_vx)))
vuint8mf8_t vslideup_vx_u8mf8(vuint8mf8_t, vuint8mf8_t, size_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vslideup_vx_m)))
vuint8mf8_t vslideup_vx_u8mf8_m(vbool64_t, vuint8mf8_t, vuint8mf8_t, size_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vslideup_vx)))
vuint16m1_t vslideup_vx_u16m1(vuint16m1_t, vuint16m1_t, size_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vslideup_vx_m)))
vuint16m1_t vslideup_vx_u16m1_m(vbool16_t, vuint16m1_t, vuint16m1_t, size_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vslideup_vx)))
vuint16m2_t vslideup_vx_u16m2(vuint16m2_t, vuint16m2_t, size_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vslideup_vx_m)))
vuint16m2_t vslideup_vx_u16m2_m(vbool8_t, vuint16m2_t, vuint16m2_t, size_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vslideup_vx)))
vuint16m4_t vslideup_vx_u16m4(vuint16m4_t, vuint16m4_t, size_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vslideup_vx_m)))
vuint16m4_t vslideup_vx_u16m4_m(vbool4_t, vuint16m4_t, vuint16m4_t, size_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vslideup_vx)))
vuint16m8_t vslideup_vx_u16m8(vuint16m8_t, vuint16m8_t, size_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vslideup_vx_m)))
vuint16m8_t vslideup_vx_u16m8_m(vbool2_t, vuint16m8_t, vuint16m8_t, size_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vslideup_vx)))
vuint16mf2_t vslideup_vx_u16mf2(vuint16mf2_t, vuint16mf2_t, size_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vslideup_vx_m)))
vuint16mf2_t vslideup_vx_u16mf2_m(vbool32_t, vuint16mf2_t, vuint16mf2_t, size_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vslideup_vx)))
vuint16mf4_t vslideup_vx_u16mf4(vuint16mf4_t, vuint16mf4_t, size_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vslideup_vx_m)))
vuint16mf4_t vslideup_vx_u16mf4_m(vbool64_t, vuint16mf4_t, vuint16mf4_t, size_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vslideup_vx)))
vuint32m1_t vslideup_vx_u32m1(vuint32m1_t, vuint32m1_t, size_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vslideup_vx_m)))
vuint32m1_t vslideup_vx_u32m1_m(vbool32_t, vuint32m1_t, vuint32m1_t, size_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vslideup_vx)))
vuint32m2_t vslideup_vx_u32m2(vuint32m2_t, vuint32m2_t, size_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vslideup_vx_m)))
vuint32m2_t vslideup_vx_u32m2_m(vbool16_t, vuint32m2_t, vuint32m2_t, size_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vslideup_vx)))
vuint32m4_t vslideup_vx_u32m4(vuint32m4_t, vuint32m4_t, size_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vslideup_vx_m)))
vuint32m4_t vslideup_vx_u32m4_m(vbool8_t, vuint32m4_t, vuint32m4_t, size_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vslideup_vx)))
vuint32m8_t vslideup_vx_u32m8(vuint32m8_t, vuint32m8_t, size_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vslideup_vx_m)))
vuint32m8_t vslideup_vx_u32m8_m(vbool4_t, vuint32m8_t, vuint32m8_t, size_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vslideup_vx)))
vuint32mf2_t vslideup_vx_u32mf2(vuint32mf2_t, vuint32mf2_t, size_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vslideup_vx_m)))
vuint32mf2_t vslideup_vx_u32mf2_m(vbool64_t, vuint32mf2_t, vuint32mf2_t, size_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vslidedown_vx)))
vint8m1_t vslidedown_vx_i8m1(vint8m1_t, vint8m1_t, size_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vslidedown_vx_m)))
vint8m1_t vslidedown_vx_i8m1_m(vbool8_t, vint8m1_t, vint8m1_t, size_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vslidedown_vx)))
vint8m2_t vslidedown_vx_i8m2(vint8m2_t, vint8m2_t, size_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vslidedown_vx_m)))
vint8m2_t vslidedown_vx_i8m2_m(vbool4_t, vint8m2_t, vint8m2_t, size_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vslidedown_vx)))
vint8m4_t vslidedown_vx_i8m4(vint8m4_t, vint8m4_t, size_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vslidedown_vx_m)))
vint8m4_t vslidedown_vx_i8m4_m(vbool2_t, vint8m4_t, vint8m4_t, size_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vslidedown_vx)))
vint8m8_t vslidedown_vx_i8m8(vint8m8_t, vint8m8_t, size_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vslidedown_vx_m)))
vint8m8_t vslidedown_vx_i8m8_m(vbool1_t, vint8m8_t, vint8m8_t, size_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vslidedown_vx)))
vint8mf2_t vslidedown_vx_i8mf2(vint8mf2_t, vint8mf2_t, size_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vslidedown_vx_m)))
vint8mf2_t vslidedown_vx_i8mf2_m(vbool16_t, vint8mf2_t, vint8mf2_t, size_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vslidedown_vx)))
vint8mf4_t vslidedown_vx_i8mf4(vint8mf4_t, vint8mf4_t, size_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vslidedown_vx_m)))
vint8mf4_t vslidedown_vx_i8mf4_m(vbool32_t, vint8mf4_t, vint8mf4_t, size_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vslidedown_vx)))
vint8mf8_t vslidedown_vx_i8mf8(vint8mf8_t, vint8mf8_t, size_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vslidedown_vx_m)))
vint8mf8_t vslidedown_vx_i8mf8_m(vbool64_t, vint8mf8_t, vint8mf8_t, size_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vslidedown_vx)))
vint16m1_t vslidedown_vx_i16m1(vint16m1_t, vint16m1_t, size_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vslidedown_vx_m)))
vint16m1_t vslidedown_vx_i16m1_m(vbool16_t, vint16m1_t, vint16m1_t, size_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vslidedown_vx)))
vint16m2_t vslidedown_vx_i16m2(vint16m2_t, vint16m2_t, size_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vslidedown_vx_m)))
vint16m2_t vslidedown_vx_i16m2_m(vbool8_t, vint16m2_t, vint16m2_t, size_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vslidedown_vx)))
vint16m4_t vslidedown_vx_i16m4(vint16m4_t, vint16m4_t, size_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vslidedown_vx_m)))
vint16m4_t vslidedown_vx_i16m4_m(vbool4_t, vint16m4_t, vint16m4_t, size_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vslidedown_vx)))
vint16m8_t vslidedown_vx_i16m8(vint16m8_t, vint16m8_t, size_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vslidedown_vx_m)))
vint16m8_t vslidedown_vx_i16m8_m(vbool2_t, vint16m8_t, vint16m8_t, size_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vslidedown_vx)))
vint16mf2_t vslidedown_vx_i16mf2(vint16mf2_t, vint16mf2_t, size_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vslidedown_vx_m)))
vint16mf2_t vslidedown_vx_i16mf2_m(vbool32_t, vint16mf2_t, vint16mf2_t, size_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vslidedown_vx)))
vint16mf4_t vslidedown_vx_i16mf4(vint16mf4_t, vint16mf4_t, size_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vslidedown_vx_m)))
vint16mf4_t vslidedown_vx_i16mf4_m(vbool64_t, vint16mf4_t, vint16mf4_t, size_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vslidedown_vx)))
vint32m1_t vslidedown_vx_i32m1(vint32m1_t, vint32m1_t, size_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vslidedown_vx_m)))
vint32m1_t vslidedown_vx_i32m1_m(vbool32_t, vint32m1_t, vint32m1_t, size_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vslidedown_vx)))
vint32m2_t vslidedown_vx_i32m2(vint32m2_t, vint32m2_t, size_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vslidedown_vx_m)))
vint32m2_t vslidedown_vx_i32m2_m(vbool16_t, vint32m2_t, vint32m2_t, size_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vslidedown_vx)))
vint32m4_t vslidedown_vx_i32m4(vint32m4_t, vint32m4_t, size_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vslidedown_vx_m)))
vint32m4_t vslidedown_vx_i32m4_m(vbool8_t, vint32m4_t, vint32m4_t, size_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vslidedown_vx)))
vint32m8_t vslidedown_vx_i32m8(vint32m8_t, vint32m8_t, size_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vslidedown_vx_m)))
vint32m8_t vslidedown_vx_i32m8_m(vbool4_t, vint32m8_t, vint32m8_t, size_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vslidedown_vx)))
vint32mf2_t vslidedown_vx_i32mf2(vint32mf2_t, vint32mf2_t, size_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vslidedown_vx_m)))
vint32mf2_t vslidedown_vx_i32mf2_m(vbool64_t, vint32mf2_t, vint32mf2_t, size_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vslidedown_vx)))
vuint8m1_t vslidedown_vx_u8m1(vuint8m1_t, vuint8m1_t, size_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vslidedown_vx_m)))
vuint8m1_t vslidedown_vx_u8m1_m(vbool8_t, vuint8m1_t, vuint8m1_t, size_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vslidedown_vx)))
vuint8m2_t vslidedown_vx_u8m2(vuint8m2_t, vuint8m2_t, size_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vslidedown_vx_m)))
vuint8m2_t vslidedown_vx_u8m2_m(vbool4_t, vuint8m2_t, vuint8m2_t, size_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vslidedown_vx)))
vuint8m4_t vslidedown_vx_u8m4(vuint8m4_t, vuint8m4_t, size_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vslidedown_vx_m)))
vuint8m4_t vslidedown_vx_u8m4_m(vbool2_t, vuint8m4_t, vuint8m4_t, size_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vslidedown_vx)))
vuint8m8_t vslidedown_vx_u8m8(vuint8m8_t, vuint8m8_t, size_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vslidedown_vx_m)))
vuint8m8_t vslidedown_vx_u8m8_m(vbool1_t, vuint8m8_t, vuint8m8_t, size_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vslidedown_vx)))
vuint8mf2_t vslidedown_vx_u8mf2(vuint8mf2_t, vuint8mf2_t, size_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vslidedown_vx_m)))
vuint8mf2_t vslidedown_vx_u8mf2_m(vbool16_t, vuint8mf2_t, vuint8mf2_t, size_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vslidedown_vx)))
vuint8mf4_t vslidedown_vx_u8mf4(vuint8mf4_t, vuint8mf4_t, size_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vslidedown_vx_m)))
vuint8mf4_t vslidedown_vx_u8mf4_m(vbool32_t, vuint8mf4_t, vuint8mf4_t, size_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vslidedown_vx)))
vuint8mf8_t vslidedown_vx_u8mf8(vuint8mf8_t, vuint8mf8_t, size_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vslidedown_vx_m)))
vuint8mf8_t vslidedown_vx_u8mf8_m(vbool64_t, vuint8mf8_t, vuint8mf8_t, size_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vslidedown_vx)))
vuint16m1_t vslidedown_vx_u16m1(vuint16m1_t, vuint16m1_t, size_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vslidedown_vx_m)))
vuint16m1_t vslidedown_vx_u16m1_m(vbool16_t, vuint16m1_t, vuint16m1_t, size_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vslidedown_vx)))
vuint16m2_t vslidedown_vx_u16m2(vuint16m2_t, vuint16m2_t, size_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vslidedown_vx_m)))
vuint16m2_t vslidedown_vx_u16m2_m(vbool8_t, vuint16m2_t, vuint16m2_t, size_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vslidedown_vx)))
vuint16m4_t vslidedown_vx_u16m4(vuint16m4_t, vuint16m4_t, size_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vslidedown_vx_m)))
vuint16m4_t vslidedown_vx_u16m4_m(vbool4_t, vuint16m4_t, vuint16m4_t, size_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vslidedown_vx)))
vuint16m8_t vslidedown_vx_u16m8(vuint16m8_t, vuint16m8_t, size_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vslidedown_vx_m)))
vuint16m8_t vslidedown_vx_u16m8_m(vbool2_t, vuint16m8_t, vuint16m8_t, size_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vslidedown_vx)))
vuint16mf2_t vslidedown_vx_u16mf2(vuint16mf2_t, vuint16mf2_t, size_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vslidedown_vx_m)))
vuint16mf2_t vslidedown_vx_u16mf2_m(vbool32_t, vuint16mf2_t, vuint16mf2_t, size_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vslidedown_vx)))
vuint16mf4_t vslidedown_vx_u16mf4(vuint16mf4_t, vuint16mf4_t, size_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vslidedown_vx_m)))
vuint16mf4_t vslidedown_vx_u16mf4_m(vbool64_t, vuint16mf4_t, vuint16mf4_t, size_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vslidedown_vx)))
vuint32m1_t vslidedown_vx_u32m1(vuint32m1_t, vuint32m1_t, size_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vslidedown_vx_m)))
vuint32m1_t vslidedown_vx_u32m1_m(vbool32_t, vuint32m1_t, vuint32m1_t, size_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vslidedown_vx)))
vuint32m2_t vslidedown_vx_u32m2(vuint32m2_t, vuint32m2_t, size_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vslidedown_vx_m)))
vuint32m2_t vslidedown_vx_u32m2_m(vbool16_t, vuint32m2_t, vuint32m2_t, size_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vslidedown_vx)))
vuint32m4_t vslidedown_vx_u32m4(vuint32m4_t, vuint32m4_t, size_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vslidedown_vx_m)))
vuint32m4_t vslidedown_vx_u32m4_m(vbool8_t, vuint32m4_t, vuint32m4_t, size_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vslidedown_vx)))
vuint32m8_t vslidedown_vx_u32m8(vuint32m8_t, vuint32m8_t, size_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vslidedown_vx_m)))
vuint32m8_t vslidedown_vx_u32m8_m(vbool4_t, vuint32m8_t, vuint32m8_t, size_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vslidedown_vx)))
vuint32mf2_t vslidedown_vx_u32mf2(vuint32mf2_t, vuint32mf2_t, size_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vslidedown_vx_m)))
vuint32mf2_t vslidedown_vx_u32mf2_m(vbool64_t, vuint32mf2_t, vuint32mf2_t, size_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vslide1up_vx)))
vint8m1_t vslide1up_vx_i8m1(vint8m1_t, int8_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vslide1up_vx_m)))
vint8m1_t vslide1up_vx_i8m1_m(vbool8_t, vint8m1_t, vint8m1_t, int8_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vslide1up_vx)))
vint8m2_t vslide1up_vx_i8m2(vint8m2_t, int8_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vslide1up_vx_m)))
vint8m2_t vslide1up_vx_i8m2_m(vbool4_t, vint8m2_t, vint8m2_t, int8_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vslide1up_vx)))
vint8m4_t vslide1up_vx_i8m4(vint8m4_t, int8_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vslide1up_vx_m)))
vint8m4_t vslide1up_vx_i8m4_m(vbool2_t, vint8m4_t, vint8m4_t, int8_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vslide1up_vx)))
vint8m8_t vslide1up_vx_i8m8(vint8m8_t, int8_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vslide1up_vx_m)))
vint8m8_t vslide1up_vx_i8m8_m(vbool1_t, vint8m8_t, vint8m8_t, int8_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vslide1up_vx)))
vint8mf2_t vslide1up_vx_i8mf2(vint8mf2_t, int8_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vslide1up_vx_m)))
vint8mf2_t vslide1up_vx_i8mf2_m(vbool16_t, vint8mf2_t, vint8mf2_t, int8_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vslide1up_vx)))
vint8mf4_t vslide1up_vx_i8mf4(vint8mf4_t, int8_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vslide1up_vx_m)))
vint8mf4_t vslide1up_vx_i8mf4_m(vbool32_t, vint8mf4_t, vint8mf4_t, int8_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vslide1up_vx)))
vint8mf8_t vslide1up_vx_i8mf8(vint8mf8_t, int8_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vslide1up_vx_m)))
vint8mf8_t vslide1up_vx_i8mf8_m(vbool64_t, vint8mf8_t, vint8mf8_t, int8_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vslide1up_vx)))
vint16m1_t vslide1up_vx_i16m1(vint16m1_t, int16_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vslide1up_vx_m)))
vint16m1_t vslide1up_vx_i16m1_m(vbool16_t, vint16m1_t, vint16m1_t, int16_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vslide1up_vx)))
vint16m2_t vslide1up_vx_i16m2(vint16m2_t, int16_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vslide1up_vx_m)))
vint16m2_t vslide1up_vx_i16m2_m(vbool8_t, vint16m2_t, vint16m2_t, int16_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vslide1up_vx)))
vint16m4_t vslide1up_vx_i16m4(vint16m4_t, int16_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vslide1up_vx_m)))
vint16m4_t vslide1up_vx_i16m4_m(vbool4_t, vint16m4_t, vint16m4_t, int16_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vslide1up_vx)))
vint16m8_t vslide1up_vx_i16m8(vint16m8_t, int16_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vslide1up_vx_m)))
vint16m8_t vslide1up_vx_i16m8_m(vbool2_t, vint16m8_t, vint16m8_t, int16_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vslide1up_vx)))
vint16mf2_t vslide1up_vx_i16mf2(vint16mf2_t, int16_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vslide1up_vx_m)))
vint16mf2_t vslide1up_vx_i16mf2_m(vbool32_t, vint16mf2_t, vint16mf2_t, int16_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vslide1up_vx)))
vint16mf4_t vslide1up_vx_i16mf4(vint16mf4_t, int16_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vslide1up_vx_m)))
vint16mf4_t vslide1up_vx_i16mf4_m(vbool64_t, vint16mf4_t, vint16mf4_t, int16_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vslide1up_vx)))
vint32m1_t vslide1up_vx_i32m1(vint32m1_t, int32_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vslide1up_vx_m)))
vint32m1_t vslide1up_vx_i32m1_m(vbool32_t, vint32m1_t, vint32m1_t, int32_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vslide1up_vx)))
vint32m2_t vslide1up_vx_i32m2(vint32m2_t, int32_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vslide1up_vx_m)))
vint32m2_t vslide1up_vx_i32m2_m(vbool16_t, vint32m2_t, vint32m2_t, int32_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vslide1up_vx)))
vint32m4_t vslide1up_vx_i32m4(vint32m4_t, int32_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vslide1up_vx_m)))
vint32m4_t vslide1up_vx_i32m4_m(vbool8_t, vint32m4_t, vint32m4_t, int32_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vslide1up_vx)))
vint32m8_t vslide1up_vx_i32m8(vint32m8_t, int32_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vslide1up_vx_m)))
vint32m8_t vslide1up_vx_i32m8_m(vbool4_t, vint32m8_t, vint32m8_t, int32_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vslide1up_vx)))
vint32mf2_t vslide1up_vx_i32mf2(vint32mf2_t, int32_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vslide1up_vx_m)))
vint32mf2_t vslide1up_vx_i32mf2_m(vbool64_t, vint32mf2_t, vint32mf2_t, int32_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vslide1up_vx)))
vuint8m1_t vslide1up_vx_u8m1(vuint8m1_t, int8_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vslide1up_vx_m)))
vuint8m1_t vslide1up_vx_u8m1_m(vbool8_t, vuint8m1_t, vuint8m1_t, int8_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vslide1up_vx)))
vuint8m2_t vslide1up_vx_u8m2(vuint8m2_t, int8_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vslide1up_vx_m)))
vuint8m2_t vslide1up_vx_u8m2_m(vbool4_t, vuint8m2_t, vuint8m2_t, int8_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vslide1up_vx)))
vuint8m4_t vslide1up_vx_u8m4(vuint8m4_t, int8_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vslide1up_vx_m)))
vuint8m4_t vslide1up_vx_u8m4_m(vbool2_t, vuint8m4_t, vuint8m4_t, int8_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vslide1up_vx)))
vuint8m8_t vslide1up_vx_u8m8(vuint8m8_t, int8_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vslide1up_vx_m)))
vuint8m8_t vslide1up_vx_u8m8_m(vbool1_t, vuint8m8_t, vuint8m8_t, int8_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vslide1up_vx)))
vuint8mf2_t vslide1up_vx_u8mf2(vuint8mf2_t, int8_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vslide1up_vx_m)))
vuint8mf2_t vslide1up_vx_u8mf2_m(vbool16_t, vuint8mf2_t, vuint8mf2_t, int8_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vslide1up_vx)))
vuint8mf4_t vslide1up_vx_u8mf4(vuint8mf4_t, int8_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vslide1up_vx_m)))
vuint8mf4_t vslide1up_vx_u8mf4_m(vbool32_t, vuint8mf4_t, vuint8mf4_t, int8_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vslide1up_vx)))
vuint8mf8_t vslide1up_vx_u8mf8(vuint8mf8_t, int8_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vslide1up_vx_m)))
vuint8mf8_t vslide1up_vx_u8mf8_m(vbool64_t, vuint8mf8_t, vuint8mf8_t, int8_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vslide1up_vx)))
vuint16m1_t vslide1up_vx_u16m1(vuint16m1_t, int16_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vslide1up_vx_m)))
vuint16m1_t vslide1up_vx_u16m1_m(vbool16_t, vuint16m1_t, vuint16m1_t, int16_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vslide1up_vx)))
vuint16m2_t vslide1up_vx_u16m2(vuint16m2_t, int16_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vslide1up_vx_m)))
vuint16m2_t vslide1up_vx_u16m2_m(vbool8_t, vuint16m2_t, vuint16m2_t, int16_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vslide1up_vx)))
vuint16m4_t vslide1up_vx_u16m4(vuint16m4_t, int16_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vslide1up_vx_m)))
vuint16m4_t vslide1up_vx_u16m4_m(vbool4_t, vuint16m4_t, vuint16m4_t, int16_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vslide1up_vx)))
vuint16m8_t vslide1up_vx_u16m8(vuint16m8_t, int16_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vslide1up_vx_m)))
vuint16m8_t vslide1up_vx_u16m8_m(vbool2_t, vuint16m8_t, vuint16m8_t, int16_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vslide1up_vx)))
vuint16mf2_t vslide1up_vx_u16mf2(vuint16mf2_t, int16_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vslide1up_vx_m)))
vuint16mf2_t vslide1up_vx_u16mf2_m(vbool32_t, vuint16mf2_t, vuint16mf2_t, int16_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vslide1up_vx)))
vuint16mf4_t vslide1up_vx_u16mf4(vuint16mf4_t, int16_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vslide1up_vx_m)))
vuint16mf4_t vslide1up_vx_u16mf4_m(vbool64_t, vuint16mf4_t, vuint16mf4_t, int16_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vslide1up_vx)))
vuint32m1_t vslide1up_vx_u32m1(vuint32m1_t, int32_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vslide1up_vx_m)))
vuint32m1_t vslide1up_vx_u32m1_m(vbool32_t, vuint32m1_t, vuint32m1_t, int32_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vslide1up_vx)))
vuint32m2_t vslide1up_vx_u32m2(vuint32m2_t, int32_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vslide1up_vx_m)))
vuint32m2_t vslide1up_vx_u32m2_m(vbool16_t, vuint32m2_t, vuint32m2_t, int32_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vslide1up_vx)))
vuint32m4_t vslide1up_vx_u32m4(vuint32m4_t, int32_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vslide1up_vx_m)))
vuint32m4_t vslide1up_vx_u32m4_m(vbool8_t, vuint32m4_t, vuint32m4_t, int32_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vslide1up_vx)))
vuint32m8_t vslide1up_vx_u32m8(vuint32m8_t, int32_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vslide1up_vx_m)))
vuint32m8_t vslide1up_vx_u32m8_m(vbool4_t, vuint32m8_t, vuint32m8_t, int32_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vslide1up_vx)))
vuint32mf2_t vslide1up_vx_u32mf2(vuint32mf2_t, int32_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vslide1up_vx_m)))
vuint32mf2_t vslide1up_vx_u32mf2_m(vbool64_t, vuint32mf2_t, vuint32mf2_t, int32_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vsse8_v)))
void vsse8_v_i8m1(int8_t *, ptrdiff_t, vint8m1_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vsse8_v_m)))
void vsse8_v_i8m1_m(vbool8_t, int8_t *, ptrdiff_t, vint8m1_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vsse8_v)))
void vsse8_v_i8m2(int8_t *, ptrdiff_t, vint8m2_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vsse8_v_m)))
void vsse8_v_i8m2_m(vbool4_t, int8_t *, ptrdiff_t, vint8m2_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vsse8_v)))
void vsse8_v_i8m4(int8_t *, ptrdiff_t, vint8m4_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vsse8_v_m)))
void vsse8_v_i8m4_m(vbool2_t, int8_t *, ptrdiff_t, vint8m4_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vsse8_v)))
void vsse8_v_i8m8(int8_t *, ptrdiff_t, vint8m8_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vsse8_v_m)))
void vsse8_v_i8m8_m(vbool1_t, int8_t *, ptrdiff_t, vint8m8_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vsse8_v)))
void vsse8_v_i8mf2(int8_t *, ptrdiff_t, vint8mf2_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vsse8_v_m)))
void vsse8_v_i8mf2_m(vbool16_t, int8_t *, ptrdiff_t, vint8mf2_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vsse8_v)))
void vsse8_v_i8mf4(int8_t *, ptrdiff_t, vint8mf4_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vsse8_v_m)))
void vsse8_v_i8mf4_m(vbool32_t, int8_t *, ptrdiff_t, vint8mf4_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vsse8_v)))
void vsse8_v_i8mf8(int8_t *, ptrdiff_t, vint8mf8_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vsse8_v_m)))
void vsse8_v_i8mf8_m(vbool64_t, int8_t *, ptrdiff_t, vint8mf8_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vslide1down_vx)))
vint8m1_t vslide1down_vx_i8m1(vint8m1_t, int8_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vslide1down_vx_m)))
vint8m1_t vslide1down_vx_i8m1_m(vbool8_t, vint8m1_t, vint8m1_t, int8_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vslide1down_vx)))
vint8m2_t vslide1down_vx_i8m2(vint8m2_t, int8_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vslide1down_vx_m)))
vint8m2_t vslide1down_vx_i8m2_m(vbool4_t, vint8m2_t, vint8m2_t, int8_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vslide1down_vx)))
vint8m4_t vslide1down_vx_i8m4(vint8m4_t, int8_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vslide1down_vx_m)))
vint8m4_t vslide1down_vx_i8m4_m(vbool2_t, vint8m4_t, vint8m4_t, int8_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vslide1down_vx)))
vint8m8_t vslide1down_vx_i8m8(vint8m8_t, int8_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vslide1down_vx_m)))
vint8m8_t vslide1down_vx_i8m8_m(vbool1_t, vint8m8_t, vint8m8_t, int8_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vslide1down_vx)))
vint8mf2_t vslide1down_vx_i8mf2(vint8mf2_t, int8_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vslide1down_vx_m)))
vint8mf2_t vslide1down_vx_i8mf2_m(vbool16_t, vint8mf2_t, vint8mf2_t, int8_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vslide1down_vx)))
vint8mf4_t vslide1down_vx_i8mf4(vint8mf4_t, int8_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vslide1down_vx_m)))
vint8mf4_t vslide1down_vx_i8mf4_m(vbool32_t, vint8mf4_t, vint8mf4_t, int8_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vslide1down_vx)))
vint8mf8_t vslide1down_vx_i8mf8(vint8mf8_t, int8_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vslide1down_vx_m)))
vint8mf8_t vslide1down_vx_i8mf8_m(vbool64_t, vint8mf8_t, vint8mf8_t, int8_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vslide1down_vx)))
vint16m1_t vslide1down_vx_i16m1(vint16m1_t, int16_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vslide1down_vx_m)))
vint16m1_t vslide1down_vx_i16m1_m(vbool16_t, vint16m1_t, vint16m1_t, int16_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vslide1down_vx)))
vint16m2_t vslide1down_vx_i16m2(vint16m2_t, int16_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vslide1down_vx_m)))
vint16m2_t vslide1down_vx_i16m2_m(vbool8_t, vint16m2_t, vint16m2_t, int16_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vslide1down_vx)))
vint16m4_t vslide1down_vx_i16m4(vint16m4_t, int16_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vslide1down_vx_m)))
vint16m4_t vslide1down_vx_i16m4_m(vbool4_t, vint16m4_t, vint16m4_t, int16_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vslide1down_vx)))
vint16m8_t vslide1down_vx_i16m8(vint16m8_t, int16_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vslide1down_vx_m)))
vint16m8_t vslide1down_vx_i16m8_m(vbool2_t, vint16m8_t, vint16m8_t, int16_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vslide1down_vx)))
vint16mf2_t vslide1down_vx_i16mf2(vint16mf2_t, int16_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vslide1down_vx_m)))
vint16mf2_t vslide1down_vx_i16mf2_m(vbool32_t, vint16mf2_t, vint16mf2_t, int16_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vslide1down_vx)))
vint16mf4_t vslide1down_vx_i16mf4(vint16mf4_t, int16_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vslide1down_vx_m)))
vint16mf4_t vslide1down_vx_i16mf4_m(vbool64_t, vint16mf4_t, vint16mf4_t, int16_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vslide1down_vx)))
vint32m1_t vslide1down_vx_i32m1(vint32m1_t, int32_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vslide1down_vx_m)))
vint32m1_t vslide1down_vx_i32m1_m(vbool32_t, vint32m1_t, vint32m1_t, int32_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vslide1down_vx)))
vint32m2_t vslide1down_vx_i32m2(vint32m2_t, int32_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vslide1down_vx_m)))
vint32m2_t vslide1down_vx_i32m2_m(vbool16_t, vint32m2_t, vint32m2_t, int32_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vslide1down_vx)))
vint32m4_t vslide1down_vx_i32m4(vint32m4_t, int32_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vslide1down_vx_m)))
vint32m4_t vslide1down_vx_i32m4_m(vbool8_t, vint32m4_t, vint32m4_t, int32_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vslide1down_vx)))
vint32m8_t vslide1down_vx_i32m8(vint32m8_t, int32_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vslide1down_vx_m)))
vint32m8_t vslide1down_vx_i32m8_m(vbool4_t, vint32m8_t, vint32m8_t, int32_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vslide1down_vx)))
vint32mf2_t vslide1down_vx_i32mf2(vint32mf2_t, int32_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vslide1down_vx_m)))
vint32mf2_t vslide1down_vx_i32mf2_m(vbool64_t, vint32mf2_t, vint32mf2_t, int32_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vslide1down_vx)))
vuint8m1_t vslide1down_vx_u8m1(vuint8m1_t, int8_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vslide1down_vx_m)))
vuint8m1_t vslide1down_vx_u8m1_m(vbool8_t, vuint8m1_t, vuint8m1_t, int8_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vslide1down_vx)))
vuint8m2_t vslide1down_vx_u8m2(vuint8m2_t, int8_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vslide1down_vx_m)))
vuint8m2_t vslide1down_vx_u8m2_m(vbool4_t, vuint8m2_t, vuint8m2_t, int8_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vslide1down_vx)))
vuint8m4_t vslide1down_vx_u8m4(vuint8m4_t, int8_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vslide1down_vx_m)))
vuint8m4_t vslide1down_vx_u8m4_m(vbool2_t, vuint8m4_t, vuint8m4_t, int8_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vslide1down_vx)))
vuint8m8_t vslide1down_vx_u8m8(vuint8m8_t, int8_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vslide1down_vx_m)))
vuint8m8_t vslide1down_vx_u8m8_m(vbool1_t, vuint8m8_t, vuint8m8_t, int8_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vslide1down_vx)))
vuint8mf2_t vslide1down_vx_u8mf2(vuint8mf2_t, int8_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vslide1down_vx_m)))
vuint8mf2_t vslide1down_vx_u8mf2_m(vbool16_t, vuint8mf2_t, vuint8mf2_t, int8_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vslide1down_vx)))
vuint8mf4_t vslide1down_vx_u8mf4(vuint8mf4_t, int8_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vslide1down_vx_m)))
vuint8mf4_t vslide1down_vx_u8mf4_m(vbool32_t, vuint8mf4_t, vuint8mf4_t, int8_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vslide1down_vx)))
vuint8mf8_t vslide1down_vx_u8mf8(vuint8mf8_t, int8_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vslide1down_vx_m)))
vuint8mf8_t vslide1down_vx_u8mf8_m(vbool64_t, vuint8mf8_t, vuint8mf8_t, int8_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vslide1down_vx)))
vuint16m1_t vslide1down_vx_u16m1(vuint16m1_t, int16_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vslide1down_vx_m)))
vuint16m1_t vslide1down_vx_u16m1_m(vbool16_t, vuint16m1_t, vuint16m1_t, int16_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vslide1down_vx)))
vuint16m2_t vslide1down_vx_u16m2(vuint16m2_t, int16_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vslide1down_vx_m)))
vuint16m2_t vslide1down_vx_u16m2_m(vbool8_t, vuint16m2_t, vuint16m2_t, int16_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vslide1down_vx)))
vuint16m4_t vslide1down_vx_u16m4(vuint16m4_t, int16_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vslide1down_vx_m)))
vuint16m4_t vslide1down_vx_u16m4_m(vbool4_t, vuint16m4_t, vuint16m4_t, int16_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vslide1down_vx)))
vuint16m8_t vslide1down_vx_u16m8(vuint16m8_t, int16_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vslide1down_vx_m)))
vuint16m8_t vslide1down_vx_u16m8_m(vbool2_t, vuint16m8_t, vuint16m8_t, int16_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vslide1down_vx)))
vuint16mf2_t vslide1down_vx_u16mf2(vuint16mf2_t, int16_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vslide1down_vx_m)))
vuint16mf2_t vslide1down_vx_u16mf2_m(vbool32_t, vuint16mf2_t, vuint16mf2_t, int16_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vslide1down_vx)))
vuint16mf4_t vslide1down_vx_u16mf4(vuint16mf4_t, int16_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vslide1down_vx_m)))
vuint16mf4_t vslide1down_vx_u16mf4_m(vbool64_t, vuint16mf4_t, vuint16mf4_t, int16_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vslide1down_vx)))
vuint32m1_t vslide1down_vx_u32m1(vuint32m1_t, int32_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vslide1down_vx_m)))
vuint32m1_t vslide1down_vx_u32m1_m(vbool32_t, vuint32m1_t, vuint32m1_t, int32_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vslide1down_vx)))
vuint32m2_t vslide1down_vx_u32m2(vuint32m2_t, int32_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vslide1down_vx_m)))
vuint32m2_t vslide1down_vx_u32m2_m(vbool16_t, vuint32m2_t, vuint32m2_t, int32_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vslide1down_vx)))
vuint32m4_t vslide1down_vx_u32m4(vuint32m4_t, int32_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vslide1down_vx_m)))
vuint32m4_t vslide1down_vx_u32m4_m(vbool8_t, vuint32m4_t, vuint32m4_t, int32_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vslide1down_vx)))
vuint32m8_t vslide1down_vx_u32m8(vuint32m8_t, int32_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vslide1down_vx_m)))
vuint32m8_t vslide1down_vx_u32m8_m(vbool4_t, vuint32m8_t, vuint32m8_t, int32_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vslide1down_vx)))
vuint32mf2_t vslide1down_vx_u32mf2(vuint32mf2_t, int32_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vslide1down_vx_m)))
vuint32mf2_t vslide1down_vx_u32mf2_m(vbool64_t, vuint32mf2_t, vuint32mf2_t, int32_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vrgather_vv)))
vint8m1_t vrgather_vv_i8m1(vint8m1_t, vuint8m1_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vrgather_vv_m)))
vint8m1_t vrgather_vv_i8m1_m(vbool8_t, vint8m1_t, vint8m1_t, vuint8m1_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vrgather_vv)))
vint8m2_t vrgather_vv_i8m2(vint8m2_t, vuint8m2_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vrgather_vv_m)))
vint8m2_t vrgather_vv_i8m2_m(vbool4_t, vint8m2_t, vint8m2_t, vuint8m2_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vrgather_vv)))
vint8m4_t vrgather_vv_i8m4(vint8m4_t, vuint8m4_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vrgather_vv_m)))
vint8m4_t vrgather_vv_i8m4_m(vbool2_t, vint8m4_t, vint8m4_t, vuint8m4_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vrgather_vv)))
vint8m8_t vrgather_vv_i8m8(vint8m8_t, vuint8m8_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vrgather_vv_m)))
vint8m8_t vrgather_vv_i8m8_m(vbool1_t, vint8m8_t, vint8m8_t, vuint8m8_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vrgather_vv)))
vint8mf2_t vrgather_vv_i8mf2(vint8mf2_t, vuint8mf2_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vrgather_vv_m)))
vint8mf2_t vrgather_vv_i8mf2_m(vbool16_t, vint8mf2_t, vint8mf2_t, vuint8mf2_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vrgather_vv)))
vint8mf4_t vrgather_vv_i8mf4(vint8mf4_t, vuint8mf4_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vrgather_vv_m)))
vint8mf4_t vrgather_vv_i8mf4_m(vbool32_t, vint8mf4_t, vint8mf4_t, vuint8mf4_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vrgather_vv)))
vint8mf8_t vrgather_vv_i8mf8(vint8mf8_t, vuint8mf8_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vrgather_vv_m)))
vint8mf8_t vrgather_vv_i8mf8_m(vbool64_t, vint8mf8_t, vint8mf8_t, vuint8mf8_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vrgather_vv)))
vint16m1_t vrgather_vv_i16m1(vint16m1_t, vuint16m1_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vrgather_vv_m)))
vint16m1_t vrgather_vv_i16m1_m(vbool16_t, vint16m1_t, vint16m1_t, vuint16m1_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vrgather_vv)))
vint16m2_t vrgather_vv_i16m2(vint16m2_t, vuint16m2_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vrgather_vv_m)))
vint16m2_t vrgather_vv_i16m2_m(vbool8_t, vint16m2_t, vint16m2_t, vuint16m2_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vrgather_vv)))
vint16m4_t vrgather_vv_i16m4(vint16m4_t, vuint16m4_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vrgather_vv_m)))
vint16m4_t vrgather_vv_i16m4_m(vbool4_t, vint16m4_t, vint16m4_t, vuint16m4_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vrgather_vv)))
vint16m8_t vrgather_vv_i16m8(vint16m8_t, vuint16m8_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vrgather_vv_m)))
vint16m8_t vrgather_vv_i16m8_m(vbool2_t, vint16m8_t, vint16m8_t, vuint16m8_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vrgather_vv)))
vint16mf2_t vrgather_vv_i16mf2(vint16mf2_t, vuint16mf2_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vrgather_vv_m)))
vint16mf2_t vrgather_vv_i16mf2_m(vbool32_t, vint16mf2_t, vint16mf2_t, vuint16mf2_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vrgather_vv)))
vint16mf4_t vrgather_vv_i16mf4(vint16mf4_t, vuint16mf4_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vrgather_vv_m)))
vint16mf4_t vrgather_vv_i16mf4_m(vbool64_t, vint16mf4_t, vint16mf4_t, vuint16mf4_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vrgather_vv)))
vint32m1_t vrgather_vv_i32m1(vint32m1_t, vuint32m1_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vrgather_vv_m)))
vint32m1_t vrgather_vv_i32m1_m(vbool32_t, vint32m1_t, vint32m1_t, vuint32m1_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vrgather_vv)))
vint32m2_t vrgather_vv_i32m2(vint32m2_t, vuint32m2_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vrgather_vv_m)))
vint32m2_t vrgather_vv_i32m2_m(vbool16_t, vint32m2_t, vint32m2_t, vuint32m2_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vrgather_vv)))
vint32m4_t vrgather_vv_i32m4(vint32m4_t, vuint32m4_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vrgather_vv_m)))
vint32m4_t vrgather_vv_i32m4_m(vbool8_t, vint32m4_t, vint32m4_t, vuint32m4_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vrgather_vv)))
vint32m8_t vrgather_vv_i32m8(vint32m8_t, vuint32m8_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vrgather_vv_m)))
vint32m8_t vrgather_vv_i32m8_m(vbool4_t, vint32m8_t, vint32m8_t, vuint32m8_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vrgather_vv)))
vint32mf2_t vrgather_vv_i32mf2(vint32mf2_t, vuint32mf2_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vrgather_vv_m)))
vint32mf2_t vrgather_vv_i32mf2_m(vbool64_t, vint32mf2_t, vint32mf2_t, vuint32mf2_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vrgather_vx)))
vint8m1_t vrgather_vx_i8m1(vint8m1_t, size_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vrgather_vx_m)))
vint8m1_t vrgather_vx_i8m1_m(vbool8_t, vint8m1_t, vint8m1_t, size_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vrgather_vx)))
vint8m2_t vrgather_vx_i8m2(vint8m2_t, size_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vrgather_vx_m)))
vint8m2_t vrgather_vx_i8m2_m(vbool4_t, vint8m2_t, vint8m2_t, size_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vrgather_vx)))
vint8m4_t vrgather_vx_i8m4(vint8m4_t, size_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vrgather_vx_m)))
vint8m4_t vrgather_vx_i8m4_m(vbool2_t, vint8m4_t, vint8m4_t, size_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vrgather_vx)))
vint8m8_t vrgather_vx_i8m8(vint8m8_t, size_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vrgather_vx_m)))
vint8m8_t vrgather_vx_i8m8_m(vbool1_t, vint8m8_t, vint8m8_t, size_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vrgather_vx)))
vint8mf2_t vrgather_vx_i8mf2(vint8mf2_t, size_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vrgather_vx_m)))
vint8mf2_t vrgather_vx_i8mf2_m(vbool16_t, vint8mf2_t, vint8mf2_t, size_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vrgather_vx)))
vint8mf4_t vrgather_vx_i8mf4(vint8mf4_t, size_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vrgather_vx_m)))
vint8mf4_t vrgather_vx_i8mf4_m(vbool32_t, vint8mf4_t, vint8mf4_t, size_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vrgather_vx)))
vint8mf8_t vrgather_vx_i8mf8(vint8mf8_t, size_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vrgather_vx_m)))
vint8mf8_t vrgather_vx_i8mf8_m(vbool64_t, vint8mf8_t, vint8mf8_t, size_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vrgather_vx)))
vint16m1_t vrgather_vx_i16m1(vint16m1_t, size_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vrgather_vx_m)))
vint16m1_t vrgather_vx_i16m1_m(vbool16_t, vint16m1_t, vint16m1_t, size_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vrgather_vx)))
vint16m2_t vrgather_vx_i16m2(vint16m2_t, size_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vrgather_vx_m)))
vint16m2_t vrgather_vx_i16m2_m(vbool8_t, vint16m2_t, vint16m2_t, size_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vrgather_vx)))
vint16m4_t vrgather_vx_i16m4(vint16m4_t, size_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vrgather_vx_m)))
vint16m4_t vrgather_vx_i16m4_m(vbool4_t, vint16m4_t, vint16m4_t, size_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vrgather_vx)))
vint16m8_t vrgather_vx_i16m8(vint16m8_t, size_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vrgather_vx_m)))
vint16m8_t vrgather_vx_i16m8_m(vbool2_t, vint16m8_t, vint16m8_t, size_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vrgather_vx)))
vint16mf2_t vrgather_vx_i16mf2(vint16mf2_t, size_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vrgather_vx_m)))
vint16mf2_t vrgather_vx_i16mf2_m(vbool32_t, vint16mf2_t, vint16mf2_t, size_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vrgather_vx)))
vint16mf4_t vrgather_vx_i16mf4(vint16mf4_t, size_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vrgather_vx_m)))
vint16mf4_t vrgather_vx_i16mf4_m(vbool64_t, vint16mf4_t, vint16mf4_t, size_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vrgather_vx)))
vint32m1_t vrgather_vx_i32m1(vint32m1_t, size_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vrgather_vx_m)))
vint32m1_t vrgather_vx_i32m1_m(vbool32_t, vint32m1_t, vint32m1_t, size_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vrgather_vx)))
vint32m2_t vrgather_vx_i32m2(vint32m2_t, size_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vrgather_vx_m)))
vint32m2_t vrgather_vx_i32m2_m(vbool16_t, vint32m2_t, vint32m2_t, size_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vrgather_vx)))
vint32m4_t vrgather_vx_i32m4(vint32m4_t, size_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vrgather_vx_m)))
vint32m4_t vrgather_vx_i32m4_m(vbool8_t, vint32m4_t, vint32m4_t, size_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vrgather_vx)))
vint32m8_t vrgather_vx_i32m8(vint32m8_t, size_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vrgather_vx_m)))
vint32m8_t vrgather_vx_i32m8_m(vbool4_t, vint32m8_t, vint32m8_t, size_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vrgather_vx)))
vint32mf2_t vrgather_vx_i32mf2(vint32mf2_t, size_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vrgather_vx_m)))
vint32mf2_t vrgather_vx_i32mf2_m(vbool64_t, vint32mf2_t, vint32mf2_t, size_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vrgatherei16_vv)))
vint8m1_t vrgatherei16_vv_i8m1(vint8m1_t, vuint16m2_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vrgatherei16_vv_m)))
vint8m1_t vrgatherei16_vv_i8m1_m(vbool8_t, vint8m1_t, vint8m1_t, vuint16m2_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vrgatherei16_vv)))
vint8m2_t vrgatherei16_vv_i8m2(vint8m2_t, vuint16m4_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vrgatherei16_vv_m)))
vint8m2_t vrgatherei16_vv_i8m2_m(vbool4_t, vint8m2_t, vint8m2_t, vuint16m4_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vrgatherei16_vv)))
vint8m4_t vrgatherei16_vv_i8m4(vint8m4_t, vuint16m8_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vrgatherei16_vv_m)))
vint8m4_t vrgatherei16_vv_i8m4_m(vbool2_t, vint8m4_t, vint8m4_t, vuint16m8_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vrgatherei16_vv)))
vint8mf2_t vrgatherei16_vv_i8mf2(vint8mf2_t, vuint16m1_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vrgatherei16_vv_m)))
vint8mf2_t vrgatherei16_vv_i8mf2_m(vbool16_t, vint8mf2_t, vint8mf2_t, vuint16m1_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vrgatherei16_vv)))
vint8mf4_t vrgatherei16_vv_i8mf4(vint8mf4_t, vuint16mf2_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vrgatherei16_vv_m)))
vint8mf4_t vrgatherei16_vv_i8mf4_m(vbool32_t, vint8mf4_t, vint8mf4_t, vuint16mf2_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vrgatherei16_vv)))
vint8mf8_t vrgatherei16_vv_i8mf8(vint8mf8_t, vuint16mf4_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vrgatherei16_vv_m)))
vint8mf8_t vrgatherei16_vv_i8mf8_m(vbool64_t, vint8mf8_t, vint8mf8_t, vuint16mf4_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vrgatherei16_vv)))
vint16m1_t vrgatherei16_vv_i16m1(vint16m1_t, vuint16m1_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vrgatherei16_vv_m)))
vint16m1_t vrgatherei16_vv_i16m1_m(vbool16_t, vint16m1_t, vint16m1_t, vuint16m1_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vrgatherei16_vv)))
vint16m2_t vrgatherei16_vv_i16m2(vint16m2_t, vuint16m2_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vrgatherei16_vv_m)))
vint16m2_t vrgatherei16_vv_i16m2_m(vbool8_t, vint16m2_t, vint16m2_t, vuint16m2_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vrgatherei16_vv)))
vint16m4_t vrgatherei16_vv_i16m4(vint16m4_t, vuint16m4_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vrgatherei16_vv_m)))
vint16m4_t vrgatherei16_vv_i16m4_m(vbool4_t, vint16m4_t, vint16m4_t, vuint16m4_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vrgatherei16_vv)))
vint16m8_t vrgatherei16_vv_i16m8(vint16m8_t, vuint16m8_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vrgatherei16_vv_m)))
vint16m8_t vrgatherei16_vv_i16m8_m(vbool2_t, vint16m8_t, vint16m8_t, vuint16m8_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vrgatherei16_vv)))
vint16mf2_t vrgatherei16_vv_i16mf2(vint16mf2_t, vuint16mf2_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vrgatherei16_vv_m)))
vint16mf2_t vrgatherei16_vv_i16mf2_m(vbool32_t, vint16mf2_t, vint16mf2_t, vuint16mf2_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vrgatherei16_vv)))
vint16mf4_t vrgatherei16_vv_i16mf4(vint16mf4_t, vuint16mf4_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vrgatherei16_vv_m)))
vint16mf4_t vrgatherei16_vv_i16mf4_m(vbool64_t, vint16mf4_t, vint16mf4_t, vuint16mf4_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vrgatherei16_vv)))
vint32m1_t vrgatherei16_vv_i32m1(vint32m1_t, vuint16mf2_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vrgatherei16_vv_m)))
vint32m1_t vrgatherei16_vv_i32m1_m(vbool32_t, vint32m1_t, vint32m1_t, vuint16mf2_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vrgatherei16_vv)))
vint32m2_t vrgatherei16_vv_i32m2(vint32m2_t, vuint16m1_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vrgatherei16_vv_m)))
vint32m2_t vrgatherei16_vv_i32m2_m(vbool16_t, vint32m2_t, vint32m2_t, vuint16m1_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vrgatherei16_vv)))
vint32m4_t vrgatherei16_vv_i32m4(vint32m4_t, vuint16m2_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vrgatherei16_vv_m)))
vint32m4_t vrgatherei16_vv_i32m4_m(vbool8_t, vint32m4_t, vint32m4_t, vuint16m2_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vrgatherei16_vv)))
vint32m8_t vrgatherei16_vv_i32m8(vint32m8_t, vuint16m4_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vrgatherei16_vv_m)))
vint32m8_t vrgatherei16_vv_i32m8_m(vbool4_t, vint32m8_t, vint32m8_t, vuint16m4_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vrgatherei16_vv)))
vint32mf2_t vrgatherei16_vv_i32mf2(vint32mf2_t, vuint16mf4_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vrgatherei16_vv_m)))
vint32mf2_t vrgatherei16_vv_i32mf2_m(vbool64_t, vint32mf2_t, vint32mf2_t, vuint16mf4_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vrgather_vv)))
vuint8m1_t vrgather_vv_u8m1(vuint8m1_t, vuint8m1_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vrgather_vv_m)))
vuint8m1_t vrgather_vv_u8m1_m(vbool8_t, vuint8m1_t, vuint8m1_t, vuint8m1_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vrgather_vv)))
vuint8m2_t vrgather_vv_u8m2(vuint8m2_t, vuint8m2_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vrgather_vv_m)))
vuint8m2_t vrgather_vv_u8m2_m(vbool4_t, vuint8m2_t, vuint8m2_t, vuint8m2_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vrgather_vv)))
vuint8m4_t vrgather_vv_u8m4(vuint8m4_t, vuint8m4_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vrgather_vv_m)))
vuint8m4_t vrgather_vv_u8m4_m(vbool2_t, vuint8m4_t, vuint8m4_t, vuint8m4_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vrgather_vv)))
vuint8m8_t vrgather_vv_u8m8(vuint8m8_t, vuint8m8_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vrgather_vv_m)))
vuint8m8_t vrgather_vv_u8m8_m(vbool1_t, vuint8m8_t, vuint8m8_t, vuint8m8_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vrgather_vv)))
vuint8mf2_t vrgather_vv_u8mf2(vuint8mf2_t, vuint8mf2_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vrgather_vv_m)))
vuint8mf2_t vrgather_vv_u8mf2_m(vbool16_t, vuint8mf2_t, vuint8mf2_t, vuint8mf2_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vrgather_vv)))
vuint8mf4_t vrgather_vv_u8mf4(vuint8mf4_t, vuint8mf4_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vrgather_vv_m)))
vuint8mf4_t vrgather_vv_u8mf4_m(vbool32_t, vuint8mf4_t, vuint8mf4_t, vuint8mf4_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vrgather_vv)))
vuint8mf8_t vrgather_vv_u8mf8(vuint8mf8_t, vuint8mf8_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vrgather_vv_m)))
vuint8mf8_t vrgather_vv_u8mf8_m(vbool64_t, vuint8mf8_t, vuint8mf8_t, vuint8mf8_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vrgather_vv)))
vuint16m1_t vrgather_vv_u16m1(vuint16m1_t, vuint16m1_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vrgather_vv_m)))
vuint16m1_t vrgather_vv_u16m1_m(vbool16_t, vuint16m1_t, vuint16m1_t, vuint16m1_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vrgather_vv)))
vuint16m2_t vrgather_vv_u16m2(vuint16m2_t, vuint16m2_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vrgather_vv_m)))
vuint16m2_t vrgather_vv_u16m2_m(vbool8_t, vuint16m2_t, vuint16m2_t, vuint16m2_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vrgather_vv)))
vuint16m4_t vrgather_vv_u16m4(vuint16m4_t, vuint16m4_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vrgather_vv_m)))
vuint16m4_t vrgather_vv_u16m4_m(vbool4_t, vuint16m4_t, vuint16m4_t, vuint16m4_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vrgather_vv)))
vuint16m8_t vrgather_vv_u16m8(vuint16m8_t, vuint16m8_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vrgather_vv_m)))
vuint16m8_t vrgather_vv_u16m8_m(vbool2_t, vuint16m8_t, vuint16m8_t, vuint16m8_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vrgather_vv)))
vuint16mf2_t vrgather_vv_u16mf2(vuint16mf2_t, vuint16mf2_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vrgather_vv_m)))
vuint16mf2_t vrgather_vv_u16mf2_m(vbool32_t, vuint16mf2_t, vuint16mf2_t, vuint16mf2_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vrgather_vv)))
vuint16mf4_t vrgather_vv_u16mf4(vuint16mf4_t, vuint16mf4_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vrgather_vv_m)))
vuint16mf4_t vrgather_vv_u16mf4_m(vbool64_t, vuint16mf4_t, vuint16mf4_t, vuint16mf4_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vrgather_vv)))
vuint32m1_t vrgather_vv_u32m1(vuint32m1_t, vuint32m1_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vrgather_vv_m)))
vuint32m1_t vrgather_vv_u32m1_m(vbool32_t, vuint32m1_t, vuint32m1_t, vuint32m1_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vrgather_vv)))
vuint32m2_t vrgather_vv_u32m2(vuint32m2_t, vuint32m2_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vrgather_vv_m)))
vuint32m2_t vrgather_vv_u32m2_m(vbool16_t, vuint32m2_t, vuint32m2_t, vuint32m2_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vrgather_vv)))
vuint32m4_t vrgather_vv_u32m4(vuint32m4_t, vuint32m4_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vrgather_vv_m)))
vuint32m4_t vrgather_vv_u32m4_m(vbool8_t, vuint32m4_t, vuint32m4_t, vuint32m4_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vrgather_vv)))
vuint32m8_t vrgather_vv_u32m8(vuint32m8_t, vuint32m8_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vrgather_vv_m)))
vuint32m8_t vrgather_vv_u32m8_m(vbool4_t, vuint32m8_t, vuint32m8_t, vuint32m8_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vrgather_vv)))
vuint32mf2_t vrgather_vv_u32mf2(vuint32mf2_t, vuint32mf2_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vrgather_vv_m)))
vuint32mf2_t vrgather_vv_u32mf2_m(vbool64_t, vuint32mf2_t, vuint32mf2_t, vuint32mf2_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vrgather_vx)))
vuint8m1_t vrgather_vx_u8m1(vuint8m1_t, size_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vrgather_vx_m)))
vuint8m1_t vrgather_vx_u8m1_m(vbool8_t, vuint8m1_t, vuint8m1_t, size_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vrgather_vx)))
vuint8m2_t vrgather_vx_u8m2(vuint8m2_t, size_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vrgather_vx_m)))
vuint8m2_t vrgather_vx_u8m2_m(vbool4_t, vuint8m2_t, vuint8m2_t, size_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vrgather_vx)))
vuint8m4_t vrgather_vx_u8m4(vuint8m4_t, size_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vrgather_vx_m)))
vuint8m4_t vrgather_vx_u8m4_m(vbool2_t, vuint8m4_t, vuint8m4_t, size_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vrgather_vx)))
vuint8m8_t vrgather_vx_u8m8(vuint8m8_t, size_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vrgather_vx_m)))
vuint8m8_t vrgather_vx_u8m8_m(vbool1_t, vuint8m8_t, vuint8m8_t, size_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vrgather_vx)))
vuint8mf2_t vrgather_vx_u8mf2(vuint8mf2_t, size_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vrgather_vx_m)))
vuint8mf2_t vrgather_vx_u8mf2_m(vbool16_t, vuint8mf2_t, vuint8mf2_t, size_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vrgather_vx)))
vuint8mf4_t vrgather_vx_u8mf4(vuint8mf4_t, size_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vrgather_vx_m)))
vuint8mf4_t vrgather_vx_u8mf4_m(vbool32_t, vuint8mf4_t, vuint8mf4_t, size_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vrgather_vx)))
vuint8mf8_t vrgather_vx_u8mf8(vuint8mf8_t, size_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vrgather_vx_m)))
vuint8mf8_t vrgather_vx_u8mf8_m(vbool64_t, vuint8mf8_t, vuint8mf8_t, size_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vrgather_vx)))
vuint16m1_t vrgather_vx_u16m1(vuint16m1_t, size_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vrgather_vx_m)))
vuint16m1_t vrgather_vx_u16m1_m(vbool16_t, vuint16m1_t, vuint16m1_t, size_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vrgather_vx)))
vuint16m2_t vrgather_vx_u16m2(vuint16m2_t, size_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vrgather_vx_m)))
vuint16m2_t vrgather_vx_u16m2_m(vbool8_t, vuint16m2_t, vuint16m2_t, size_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vrgather_vx)))
vuint16m4_t vrgather_vx_u16m4(vuint16m4_t, size_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vrgather_vx_m)))
vuint16m4_t vrgather_vx_u16m4_m(vbool4_t, vuint16m4_t, vuint16m4_t, size_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vrgather_vx)))
vuint16m8_t vrgather_vx_u16m8(vuint16m8_t, size_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vrgather_vx_m)))
vuint16m8_t vrgather_vx_u16m8_m(vbool2_t, vuint16m8_t, vuint16m8_t, size_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vrgather_vx)))
vuint16mf2_t vrgather_vx_u16mf2(vuint16mf2_t, size_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vrgather_vx_m)))
vuint16mf2_t vrgather_vx_u16mf2_m(vbool32_t, vuint16mf2_t, vuint16mf2_t, size_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vrgather_vx)))
vuint16mf4_t vrgather_vx_u16mf4(vuint16mf4_t, size_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vrgather_vx_m)))
vuint16mf4_t vrgather_vx_u16mf4_m(vbool64_t, vuint16mf4_t, vuint16mf4_t, size_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vrgather_vx)))
vuint32m1_t vrgather_vx_u32m1(vuint32m1_t, size_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vrgather_vx_m)))
vuint32m1_t vrgather_vx_u32m1_m(vbool32_t, vuint32m1_t, vuint32m1_t, size_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vrgather_vx)))
vuint32m2_t vrgather_vx_u32m2(vuint32m2_t, size_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vrgather_vx_m)))
vuint32m2_t vrgather_vx_u32m2_m(vbool16_t, vuint32m2_t, vuint32m2_t, size_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vrgather_vx)))
vuint32m4_t vrgather_vx_u32m4(vuint32m4_t, size_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vrgather_vx_m)))
vuint32m4_t vrgather_vx_u32m4_m(vbool8_t, vuint32m4_t, vuint32m4_t, size_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vrgather_vx)))
vuint32m8_t vrgather_vx_u32m8(vuint32m8_t, size_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vrgather_vx_m)))
vuint32m8_t vrgather_vx_u32m8_m(vbool4_t, vuint32m8_t, vuint32m8_t, size_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vrgather_vx)))
vuint32mf2_t vrgather_vx_u32mf2(vuint32mf2_t, size_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vrgather_vx_m)))
vuint32mf2_t vrgather_vx_u32mf2_m(vbool64_t, vuint32mf2_t, vuint32mf2_t, size_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vrgatherei16_vv)))
vuint8m1_t vrgatherei16_vv_u8m1(vuint8m1_t, vuint16m2_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vrgatherei16_vv_m)))
vuint8m1_t vrgatherei16_vv_u8m1_m(vbool8_t, vuint8m1_t, vuint8m1_t, vuint16m2_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vrgatherei16_vv)))
vuint8m2_t vrgatherei16_vv_u8m2(vuint8m2_t, vuint16m4_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vrgatherei16_vv_m)))
vuint8m2_t vrgatherei16_vv_u8m2_m(vbool4_t, vuint8m2_t, vuint8m2_t, vuint16m4_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vrgatherei16_vv)))
vuint8m4_t vrgatherei16_vv_u8m4(vuint8m4_t, vuint16m8_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vrgatherei16_vv_m)))
vuint8m4_t vrgatherei16_vv_u8m4_m(vbool2_t, vuint8m4_t, vuint8m4_t, vuint16m8_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vrgatherei16_vv)))
vuint8mf2_t vrgatherei16_vv_u8mf2(vuint8mf2_t, vuint16m1_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vrgatherei16_vv_m)))
vuint8mf2_t vrgatherei16_vv_u8mf2_m(vbool16_t, vuint8mf2_t, vuint8mf2_t, vuint16m1_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vrgatherei16_vv)))
vuint8mf4_t vrgatherei16_vv_u8mf4(vuint8mf4_t, vuint16mf2_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vrgatherei16_vv_m)))
vuint8mf4_t vrgatherei16_vv_u8mf4_m(vbool32_t, vuint8mf4_t, vuint8mf4_t, vuint16mf2_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vrgatherei16_vv)))
vuint8mf8_t vrgatherei16_vv_u8mf8(vuint8mf8_t, vuint16mf4_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vrgatherei16_vv_m)))
vuint8mf8_t vrgatherei16_vv_u8mf8_m(vbool64_t, vuint8mf8_t, vuint8mf8_t, vuint16mf4_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vrgatherei16_vv)))
vuint16m1_t vrgatherei16_vv_u16m1(vuint16m1_t, vuint16m1_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vrgatherei16_vv_m)))
vuint16m1_t vrgatherei16_vv_u16m1_m(vbool16_t, vuint16m1_t, vuint16m1_t, vuint16m1_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vrgatherei16_vv)))
vuint16m2_t vrgatherei16_vv_u16m2(vuint16m2_t, vuint16m2_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vrgatherei16_vv_m)))
vuint16m2_t vrgatherei16_vv_u16m2_m(vbool8_t, vuint16m2_t, vuint16m2_t, vuint16m2_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vrgatherei16_vv)))
vuint16m4_t vrgatherei16_vv_u16m4(vuint16m4_t, vuint16m4_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vrgatherei16_vv_m)))
vuint16m4_t vrgatherei16_vv_u16m4_m(vbool4_t, vuint16m4_t, vuint16m4_t, vuint16m4_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vrgatherei16_vv)))
vuint16m8_t vrgatherei16_vv_u16m8(vuint16m8_t, vuint16m8_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vrgatherei16_vv_m)))
vuint16m8_t vrgatherei16_vv_u16m8_m(vbool2_t, vuint16m8_t, vuint16m8_t, vuint16m8_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vrgatherei16_vv)))
vuint16mf2_t vrgatherei16_vv_u16mf2(vuint16mf2_t, vuint16mf2_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vrgatherei16_vv_m)))
vuint16mf2_t vrgatherei16_vv_u16mf2_m(vbool32_t, vuint16mf2_t, vuint16mf2_t, vuint16mf2_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vrgatherei16_vv)))
vuint16mf4_t vrgatherei16_vv_u16mf4(vuint16mf4_t, vuint16mf4_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vrgatherei16_vv_m)))
vuint16mf4_t vrgatherei16_vv_u16mf4_m(vbool64_t, vuint16mf4_t, vuint16mf4_t, vuint16mf4_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vrgatherei16_vv)))
vuint32m1_t vrgatherei16_vv_u32m1(vuint32m1_t, vuint16mf2_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vrgatherei16_vv_m)))
vuint32m1_t vrgatherei16_vv_u32m1_m(vbool32_t, vuint32m1_t, vuint32m1_t, vuint16mf2_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vrgatherei16_vv)))
vuint32m2_t vrgatherei16_vv_u32m2(vuint32m2_t, vuint16m1_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vrgatherei16_vv_m)))
vuint32m2_t vrgatherei16_vv_u32m2_m(vbool16_t, vuint32m2_t, vuint32m2_t, vuint16m1_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vrgatherei16_vv)))
vuint32m4_t vrgatherei16_vv_u32m4(vuint32m4_t, vuint16m2_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vrgatherei16_vv_m)))
vuint32m4_t vrgatherei16_vv_u32m4_m(vbool8_t, vuint32m4_t, vuint32m4_t, vuint16m2_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vrgatherei16_vv)))
vuint32m8_t vrgatherei16_vv_u32m8(vuint32m8_t, vuint16m4_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vrgatherei16_vv_m)))
vuint32m8_t vrgatherei16_vv_u32m8_m(vbool4_t, vuint32m8_t, vuint32m8_t, vuint16m4_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vrgatherei16_vv)))
vuint32mf2_t vrgatherei16_vv_u32mf2(vuint32mf2_t, vuint16mf4_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vrgatherei16_vv_m)))
vuint32mf2_t vrgatherei16_vv_u32mf2_m(vbool64_t, vuint32mf2_t, vuint32mf2_t, vuint16mf4_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vcompress_vm)))
vint8m1_t vcompress_vm_i8m1(vbool8_t, vint8m1_t, vint8m1_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vcompress_vm)))
vint8m2_t vcompress_vm_i8m2(vbool4_t, vint8m2_t, vint8m2_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vcompress_vm)))
vint8m4_t vcompress_vm_i8m4(vbool2_t, vint8m4_t, vint8m4_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vcompress_vm)))
vint8m8_t vcompress_vm_i8m8(vbool1_t, vint8m8_t, vint8m8_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vcompress_vm)))
vint8mf2_t vcompress_vm_i8mf2(vbool16_t, vint8mf2_t, vint8mf2_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vcompress_vm)))
vint8mf4_t vcompress_vm_i8mf4(vbool32_t, vint8mf4_t, vint8mf4_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vcompress_vm)))
vint8mf8_t vcompress_vm_i8mf8(vbool64_t, vint8mf8_t, vint8mf8_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vcompress_vm)))
vint16m1_t vcompress_vm_i16m1(vbool16_t, vint16m1_t, vint16m1_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vcompress_vm)))
vint16m2_t vcompress_vm_i16m2(vbool8_t, vint16m2_t, vint16m2_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vcompress_vm)))
vint16m4_t vcompress_vm_i16m4(vbool4_t, vint16m4_t, vint16m4_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vcompress_vm)))
vint16m8_t vcompress_vm_i16m8(vbool2_t, vint16m8_t, vint16m8_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vcompress_vm)))
vint16mf2_t vcompress_vm_i16mf2(vbool32_t, vint16mf2_t, vint16mf2_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vcompress_vm)))
vint16mf4_t vcompress_vm_i16mf4(vbool64_t, vint16mf4_t, vint16mf4_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vcompress_vm)))
vint32m1_t vcompress_vm_i32m1(vbool32_t, vint32m1_t, vint32m1_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vcompress_vm)))
vint32m2_t vcompress_vm_i32m2(vbool16_t, vint32m2_t, vint32m2_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vcompress_vm)))
vint32m4_t vcompress_vm_i32m4(vbool8_t, vint32m4_t, vint32m4_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vcompress_vm)))
vint32m8_t vcompress_vm_i32m8(vbool4_t, vint32m8_t, vint32m8_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vcompress_vm)))
vint32mf2_t vcompress_vm_i32mf2(vbool64_t, vint32mf2_t, vint32mf2_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vcompress_vm)))
vuint8m1_t vcompress_vm_u8m1(vbool8_t, vuint8m1_t, vuint8m1_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vcompress_vm)))
vuint8m2_t vcompress_vm_u8m2(vbool4_t, vuint8m2_t, vuint8m2_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vcompress_vm)))
vuint8m4_t vcompress_vm_u8m4(vbool2_t, vuint8m4_t, vuint8m4_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vcompress_vm)))
vuint8m8_t vcompress_vm_u8m8(vbool1_t, vuint8m8_t, vuint8m8_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vcompress_vm)))
vuint8mf2_t vcompress_vm_u8mf2(vbool16_t, vuint8mf2_t, vuint8mf2_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vcompress_vm)))
vuint8mf4_t vcompress_vm_u8mf4(vbool32_t, vuint8mf4_t, vuint8mf4_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vcompress_vm)))
vuint8mf8_t vcompress_vm_u8mf8(vbool64_t, vuint8mf8_t, vuint8mf8_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vcompress_vm)))
vuint16m1_t vcompress_vm_u16m1(vbool16_t, vuint16m1_t, vuint16m1_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vcompress_vm)))
vuint16m2_t vcompress_vm_u16m2(vbool8_t, vuint16m2_t, vuint16m2_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vcompress_vm)))
vuint16m4_t vcompress_vm_u16m4(vbool4_t, vuint16m4_t, vuint16m4_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vcompress_vm)))
vuint16m8_t vcompress_vm_u16m8(vbool2_t, vuint16m8_t, vuint16m8_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vcompress_vm)))
vuint16mf2_t vcompress_vm_u16mf2(vbool32_t, vuint16mf2_t, vuint16mf2_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vcompress_vm)))
vuint16mf4_t vcompress_vm_u16mf4(vbool64_t, vuint16mf4_t, vuint16mf4_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vcompress_vm)))
vuint32m1_t vcompress_vm_u32m1(vbool32_t, vuint32m1_t, vuint32m1_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vcompress_vm)))
vuint32m2_t vcompress_vm_u32m2(vbool16_t, vuint32m2_t, vuint32m2_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vcompress_vm)))
vuint32m4_t vcompress_vm_u32m4(vbool8_t, vuint32m4_t, vuint32m4_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vcompress_vm)))
vuint32m8_t vcompress_vm_u32m8(vbool4_t, vuint32m8_t, vuint32m8_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vcompress_vm)))
vuint32mf2_t vcompress_vm_u32mf2(vbool64_t, vuint32mf2_t, vuint32mf2_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vget_v)))
vint8m1_t vget_v_i8m2_i8m1(vint8m2_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vget_v)))
vint8m1_t vget_v_i8m4_i8m1(vint8m4_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vget_v)))
vint8m1_t vget_v_i8m8_i8m1(vint8m8_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vget_v)))
vint16m1_t vget_v_i16m2_i16m1(vint16m2_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vget_v)))
vint16m1_t vget_v_i16m4_i16m1(vint16m4_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vget_v)))
vint16m1_t vget_v_i16m8_i16m1(vint16m8_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vget_v)))
vint32m1_t vget_v_i32m2_i32m1(vint32m2_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vget_v)))
vint32m1_t vget_v_i32m4_i32m1(vint32m4_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vget_v)))
vint32m1_t vget_v_i32m8_i32m1(vint32m8_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vget_v)))
vuint8m1_t vget_v_u8m2_u8m1(vuint8m2_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vget_v)))
vuint8m1_t vget_v_u8m4_u8m1(vuint8m4_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vget_v)))
vuint8m1_t vget_v_u8m8_u8m1(vuint8m8_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vget_v)))
vuint16m1_t vget_v_u16m2_u16m1(vuint16m2_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vget_v)))
vuint16m1_t vget_v_u16m4_u16m1(vuint16m4_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vget_v)))
vuint16m1_t vget_v_u16m8_u16m1(vuint16m8_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vget_v)))
vuint32m1_t vget_v_u32m2_u32m1(vuint32m2_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vget_v)))
vuint32m1_t vget_v_u32m4_u32m1(vuint32m4_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vget_v)))
vuint32m1_t vget_v_u32m8_u32m1(vuint32m8_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vget_v)))
vint8m2_t vget_v_i8m4_i8m2(vint8m4_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vget_v)))
vint8m2_t vget_v_i8m8_i8m2(vint8m8_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vget_v)))
vint16m2_t vget_v_i16m4_i16m2(vint16m4_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vget_v)))
vint16m2_t vget_v_i16m8_i16m2(vint16m8_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vget_v)))
vint32m2_t vget_v_i32m4_i32m2(vint32m4_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vget_v)))
vint32m2_t vget_v_i32m8_i32m2(vint32m8_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vget_v)))
vuint8m2_t vget_v_u8m4_u8m2(vuint8m4_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vget_v)))
vuint8m2_t vget_v_u8m8_u8m2(vuint8m8_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vget_v)))
vuint16m2_t vget_v_u16m4_u16m2(vuint16m4_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vget_v)))
vuint16m2_t vget_v_u16m8_u16m2(vuint16m8_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vget_v)))
vuint32m2_t vget_v_u32m4_u32m2(vuint32m4_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vget_v)))
vuint32m2_t vget_v_u32m8_u32m2(vuint32m8_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vget_v)))
vint8m4_t vget_v_i8m8_i8m4(vint8m8_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vget_v)))
vint16m4_t vget_v_i16m8_i16m4(vint16m8_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vget_v)))
vint32m4_t vget_v_i32m8_i32m4(vint32m8_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vget_v)))
vuint8m4_t vget_v_u8m8_u8m4(vuint8m8_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vget_v)))
vuint16m4_t vget_v_u16m8_u16m4(vuint16m8_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vget_v)))
vuint32m4_t vget_v_u32m8_u32m4(vuint32m8_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vset_v)))
vint8m2_t vset_v_i8m1_i8m2(vint8m2_t, size_t, vint8m1_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vset_v)))
vint16m2_t vset_v_i16m1_i16m2(vint16m2_t, size_t, vint16m1_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vset_v)))
vint32m2_t vset_v_i32m1_i32m2(vint32m2_t, size_t, vint32m1_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vset_v)))
vuint8m2_t vset_v_u8m1_u8m2(vuint8m2_t, size_t, vuint8m1_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vset_v)))
vuint16m2_t vset_v_u16m1_u16m2(vuint16m2_t, size_t, vuint16m1_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vset_v)))
vuint32m2_t vset_v_u32m1_u32m2(vuint32m2_t, size_t, vuint32m1_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vset_v)))
vint8m4_t vset_v_i8m1_i8m4(vint8m4_t, size_t, vint8m1_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vset_v)))
vint8m4_t vset_v_i8m2_i8m4(vint8m4_t, size_t, vint8m2_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vset_v)))
vint16m4_t vset_v_i16m1_i16m4(vint16m4_t, size_t, vint16m1_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vset_v)))
vint16m4_t vset_v_i16m2_i16m4(vint16m4_t, size_t, vint16m2_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vset_v)))
vint32m4_t vset_v_i32m1_i32m4(vint32m4_t, size_t, vint32m1_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vset_v)))
vint32m4_t vset_v_i32m2_i32m4(vint32m4_t, size_t, vint32m2_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vset_v)))
vuint8m4_t vset_v_u8m1_u8m4(vuint8m4_t, size_t, vuint8m1_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vset_v)))
vuint8m4_t vset_v_u8m2_u8m4(vuint8m4_t, size_t, vuint8m2_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vset_v)))
vuint16m4_t vset_v_u16m1_u16m4(vuint16m4_t, size_t, vuint16m1_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vset_v)))
vuint16m4_t vset_v_u16m2_u16m4(vuint16m4_t, size_t, vuint16m2_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vset_v)))
vuint32m4_t vset_v_u32m1_u32m4(vuint32m4_t, size_t, vuint32m1_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vset_v)))
vuint32m4_t vset_v_u32m2_u32m4(vuint32m4_t, size_t, vuint32m2_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vset_v)))
vint8m8_t vset_v_i8m1_i8m8(vint8m8_t, size_t, vint8m1_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vset_v)))
vint8m8_t vset_v_i8m2_i8m8(vint8m8_t, size_t, vint8m2_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vset_v)))
vint8m8_t vset_v_i8m4_i8m8(vint8m8_t, size_t, vint8m4_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vset_v)))
vint16m8_t vset_v_i16m1_i16m8(vint16m8_t, size_t, vint16m1_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vset_v)))
vint16m8_t vset_v_i16m2_i16m8(vint16m8_t, size_t, vint16m2_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vset_v)))
vint16m8_t vset_v_i16m4_i16m8(vint16m8_t, size_t, vint16m4_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vset_v)))
vint32m8_t vset_v_i32m1_i32m8(vint32m8_t, size_t, vint32m1_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vset_v)))
vint32m8_t vset_v_i32m2_i32m8(vint32m8_t, size_t, vint32m2_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vset_v)))
vint32m8_t vset_v_i32m4_i32m8(vint32m8_t, size_t, vint32m4_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vset_v)))
vuint8m8_t vset_v_u8m1_u8m8(vuint8m8_t, size_t, vuint8m1_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vset_v)))
vuint8m8_t vset_v_u8m2_u8m8(vuint8m8_t, size_t, vuint8m2_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vset_v)))
vuint8m8_t vset_v_u8m4_u8m8(vuint8m8_t, size_t, vuint8m4_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vset_v)))
vuint16m8_t vset_v_u16m1_u16m8(vuint16m8_t, size_t, vuint16m1_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vset_v)))
vuint16m8_t vset_v_u16m2_u16m8(vuint16m8_t, size_t, vuint16m2_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vset_v)))
vuint16m8_t vset_v_u16m4_u16m8(vuint16m8_t, size_t, vuint16m4_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vset_v)))
vuint32m8_t vset_v_u32m1_u32m8(vuint32m8_t, size_t, vuint32m1_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vset_v)))
vuint32m8_t vset_v_u32m2_u32m8(vuint32m8_t, size_t, vuint32m2_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vset_v)))
vuint32m8_t vset_v_u32m4_u32m8(vuint32m8_t, size_t, vuint32m4_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vsse8_v)))
void vsse8_v_u8m1(uint8_t *, ptrdiff_t, vuint8m1_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vsse8_v_m)))
void vsse8_v_u8m1_m(vbool8_t, uint8_t *, ptrdiff_t, vuint8m1_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vsse8_v)))
void vsse8_v_u8m2(uint8_t *, ptrdiff_t, vuint8m2_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vsse8_v_m)))
void vsse8_v_u8m2_m(vbool4_t, uint8_t *, ptrdiff_t, vuint8m2_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vsse8_v)))
void vsse8_v_u8m4(uint8_t *, ptrdiff_t, vuint8m4_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vsse8_v_m)))
void vsse8_v_u8m4_m(vbool2_t, uint8_t *, ptrdiff_t, vuint8m4_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vsse8_v)))
void vsse8_v_u8m8(uint8_t *, ptrdiff_t, vuint8m8_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vsse8_v_m)))
void vsse8_v_u8m8_m(vbool1_t, uint8_t *, ptrdiff_t, vuint8m8_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vsse8_v)))
void vsse8_v_u8mf2(uint8_t *, ptrdiff_t, vuint8mf2_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vsse8_v_m)))
void vsse8_v_u8mf2_m(vbool16_t, uint8_t *, ptrdiff_t, vuint8mf2_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vsse8_v)))
void vsse8_v_u8mf4(uint8_t *, ptrdiff_t, vuint8mf4_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vsse8_v_m)))
void vsse8_v_u8mf4_m(vbool32_t, uint8_t *, ptrdiff_t, vuint8mf4_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vsse8_v)))
void vsse8_v_u8mf8(uint8_t *, ptrdiff_t, vuint8mf8_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vsse8_v_m)))
void vsse8_v_u8mf8_m(vbool64_t, uint8_t *, ptrdiff_t, vuint8mf8_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vsuxei8_v)))
void vsuxei8_v_i8m1(int8_t *, vuint8m1_t, vint8m1_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vsuxei8_v_m)))
void vsuxei8_v_i8m1_m(vbool8_t, int8_t *, vuint8m1_t, vint8m1_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vsuxei8_v)))
void vsuxei8_v_i8m2(int8_t *, vuint8m2_t, vint8m2_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vsuxei8_v_m)))
void vsuxei8_v_i8m2_m(vbool4_t, int8_t *, vuint8m2_t, vint8m2_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vsuxei8_v)))
void vsuxei8_v_i8m4(int8_t *, vuint8m4_t, vint8m4_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vsuxei8_v_m)))
void vsuxei8_v_i8m4_m(vbool2_t, int8_t *, vuint8m4_t, vint8m4_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vsuxei8_v)))
void vsuxei8_v_i8m8(int8_t *, vuint8m8_t, vint8m8_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vsuxei8_v_m)))
void vsuxei8_v_i8m8_m(vbool1_t, int8_t *, vuint8m8_t, vint8m8_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vsuxei8_v)))
void vsuxei8_v_i8mf2(int8_t *, vuint8mf2_t, vint8mf2_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vsuxei8_v_m)))
void vsuxei8_v_i8mf2_m(vbool16_t, int8_t *, vuint8mf2_t, vint8mf2_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vsuxei8_v)))
void vsuxei8_v_i8mf4(int8_t *, vuint8mf4_t, vint8mf4_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vsuxei8_v_m)))
void vsuxei8_v_i8mf4_m(vbool32_t, int8_t *, vuint8mf4_t, vint8mf4_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vsuxei8_v)))
void vsuxei8_v_i8mf8(int8_t *, vuint8mf8_t, vint8mf8_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vsuxei8_v_m)))
void vsuxei8_v_i8mf8_m(vbool64_t, int8_t *, vuint8mf8_t, vint8mf8_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vsoxei8_v)))
void vsoxei8_v_i8m1(int8_t *, vuint8m1_t, vint8m1_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vsoxei8_v_m)))
void vsoxei8_v_i8m1_m(vbool8_t, int8_t *, vuint8m1_t, vint8m1_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vsoxei8_v)))
void vsoxei8_v_i8m2(int8_t *, vuint8m2_t, vint8m2_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vsoxei8_v_m)))
void vsoxei8_v_i8m2_m(vbool4_t, int8_t *, vuint8m2_t, vint8m2_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vsoxei8_v)))
void vsoxei8_v_i8m4(int8_t *, vuint8m4_t, vint8m4_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vsoxei8_v_m)))
void vsoxei8_v_i8m4_m(vbool2_t, int8_t *, vuint8m4_t, vint8m4_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vsoxei8_v)))
void vsoxei8_v_i8m8(int8_t *, vuint8m8_t, vint8m8_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vsoxei8_v_m)))
void vsoxei8_v_i8m8_m(vbool1_t, int8_t *, vuint8m8_t, vint8m8_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vsoxei8_v)))
void vsoxei8_v_i8mf2(int8_t *, vuint8mf2_t, vint8mf2_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vsoxei8_v_m)))
void vsoxei8_v_i8mf2_m(vbool16_t, int8_t *, vuint8mf2_t, vint8mf2_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vsoxei8_v)))
void vsoxei8_v_i8mf4(int8_t *, vuint8mf4_t, vint8mf4_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vsoxei8_v_m)))
void vsoxei8_v_i8mf4_m(vbool32_t, int8_t *, vuint8mf4_t, vint8mf4_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vsoxei8_v)))
void vsoxei8_v_i8mf8(int8_t *, vuint8mf8_t, vint8mf8_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vsoxei8_v_m)))
void vsoxei8_v_i8mf8_m(vbool64_t, int8_t *, vuint8mf8_t, vint8mf8_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vsoxei8_v)))
void vsoxei8_v_u8m1(uint8_t *, vuint8m1_t, vuint8m1_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vsoxei8_v_m)))
void vsoxei8_v_u8m1_m(vbool8_t, uint8_t *, vuint8m1_t, vuint8m1_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vsoxei8_v)))
void vsoxei8_v_u8m2(uint8_t *, vuint8m2_t, vuint8m2_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vsoxei8_v_m)))
void vsoxei8_v_u8m2_m(vbool4_t, uint8_t *, vuint8m2_t, vuint8m2_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vsoxei8_v)))
void vsoxei8_v_u8m4(uint8_t *, vuint8m4_t, vuint8m4_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vsoxei8_v_m)))
void vsoxei8_v_u8m4_m(vbool2_t, uint8_t *, vuint8m4_t, vuint8m4_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vsoxei8_v)))
void vsoxei8_v_u8m8(uint8_t *, vuint8m8_t, vuint8m8_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vsoxei8_v_m)))
void vsoxei8_v_u8m8_m(vbool1_t, uint8_t *, vuint8m8_t, vuint8m8_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vsoxei8_v)))
void vsoxei8_v_u8mf2(uint8_t *, vuint8mf2_t, vuint8mf2_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vsoxei8_v_m)))
void vsoxei8_v_u8mf2_m(vbool16_t, uint8_t *, vuint8mf2_t, vuint8mf2_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vsoxei8_v)))
void vsoxei8_v_u8mf4(uint8_t *, vuint8mf4_t, vuint8mf4_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vsoxei8_v_m)))
void vsoxei8_v_u8mf4_m(vbool32_t, uint8_t *, vuint8mf4_t, vuint8mf4_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vsoxei8_v)))
void vsoxei8_v_u8mf8(uint8_t *, vuint8mf8_t, vuint8mf8_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vsoxei8_v_m)))
void vsoxei8_v_u8mf8_m(vbool64_t, uint8_t *, vuint8mf8_t, vuint8mf8_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vsoxei16_v)))
void vsoxei16_v_i8m1(int8_t *, vuint16m2_t, vint8m1_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vsoxei16_v_m)))
void vsoxei16_v_i8m1_m(vbool8_t, int8_t *, vuint16m2_t, vint8m1_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vsoxei16_v)))
void vsoxei16_v_i8m2(int8_t *, vuint16m4_t, vint8m2_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vsoxei16_v_m)))
void vsoxei16_v_i8m2_m(vbool4_t, int8_t *, vuint16m4_t, vint8m2_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vsoxei16_v)))
void vsoxei16_v_i8m4(int8_t *, vuint16m8_t, vint8m4_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vsoxei16_v_m)))
void vsoxei16_v_i8m4_m(vbool2_t, int8_t *, vuint16m8_t, vint8m4_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vsoxei16_v)))
void vsoxei16_v_i8mf2(int8_t *, vuint16m1_t, vint8mf2_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vsoxei16_v_m)))
void vsoxei16_v_i8mf2_m(vbool16_t, int8_t *, vuint16m1_t, vint8mf2_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vsoxei16_v)))
void vsoxei16_v_i8mf4(int8_t *, vuint16mf2_t, vint8mf4_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vsoxei16_v_m)))
void vsoxei16_v_i8mf4_m(vbool32_t, int8_t *, vuint16mf2_t, vint8mf4_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vsoxei16_v)))
void vsoxei16_v_i8mf8(int8_t *, vuint16mf4_t, vint8mf8_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vsoxei16_v_m)))
void vsoxei16_v_i8mf8_m(vbool64_t, int8_t *, vuint16mf4_t, vint8mf8_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vsoxei16_v)))
void vsoxei16_v_u8m1(uint8_t *, vuint16m2_t, vuint8m1_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vsoxei16_v_m)))
void vsoxei16_v_u8m1_m(vbool8_t, uint8_t *, vuint16m2_t, vuint8m1_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vsoxei16_v)))
void vsoxei16_v_u8m2(uint8_t *, vuint16m4_t, vuint8m2_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vsoxei16_v_m)))
void vsoxei16_v_u8m2_m(vbool4_t, uint8_t *, vuint16m4_t, vuint8m2_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vsoxei16_v)))
void vsoxei16_v_u8m4(uint8_t *, vuint16m8_t, vuint8m4_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vsoxei16_v_m)))
void vsoxei16_v_u8m4_m(vbool2_t, uint8_t *, vuint16m8_t, vuint8m4_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vsoxei16_v)))
void vsoxei16_v_u8mf2(uint8_t *, vuint16m1_t, vuint8mf2_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vsoxei16_v_m)))
void vsoxei16_v_u8mf2_m(vbool16_t, uint8_t *, vuint16m1_t, vuint8mf2_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vsoxei16_v)))
void vsoxei16_v_u8mf4(uint8_t *, vuint16mf2_t, vuint8mf4_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vsoxei16_v_m)))
void vsoxei16_v_u8mf4_m(vbool32_t, uint8_t *, vuint16mf2_t, vuint8mf4_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vsoxei16_v)))
void vsoxei16_v_u8mf8(uint8_t *, vuint16mf4_t, vuint8mf8_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vsoxei16_v_m)))
void vsoxei16_v_u8mf8_m(vbool64_t, uint8_t *, vuint16mf4_t, vuint8mf8_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vsoxei32_v)))
void vsoxei32_v_i8m1(int8_t *, vuint32m4_t, vint8m1_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vsoxei32_v_m)))
void vsoxei32_v_i8m1_m(vbool8_t, int8_t *, vuint32m4_t, vint8m1_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vsoxei32_v)))
void vsoxei32_v_i8m2(int8_t *, vuint32m8_t, vint8m2_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vsoxei32_v_m)))
void vsoxei32_v_i8m2_m(vbool4_t, int8_t *, vuint32m8_t, vint8m2_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vsoxei32_v)))
void vsoxei32_v_i8mf2(int8_t *, vuint32m2_t, vint8mf2_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vsoxei32_v_m)))
void vsoxei32_v_i8mf2_m(vbool16_t, int8_t *, vuint32m2_t, vint8mf2_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vsoxei32_v)))
void vsoxei32_v_i8mf4(int8_t *, vuint32m1_t, vint8mf4_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vsoxei32_v_m)))
void vsoxei32_v_i8mf4_m(vbool32_t, int8_t *, vuint32m1_t, vint8mf4_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vsoxei32_v)))
void vsoxei32_v_i8mf8(int8_t *, vuint32mf2_t, vint8mf8_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vsoxei32_v_m)))
void vsoxei32_v_i8mf8_m(vbool64_t, int8_t *, vuint32mf2_t, vint8mf8_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vsoxei32_v)))
void vsoxei32_v_u8m1(uint8_t *, vuint32m4_t, vuint8m1_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vsoxei32_v_m)))
void vsoxei32_v_u8m1_m(vbool8_t, uint8_t *, vuint32m4_t, vuint8m1_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vsoxei32_v)))
void vsoxei32_v_u8m2(uint8_t *, vuint32m8_t, vuint8m2_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vsoxei32_v_m)))
void vsoxei32_v_u8m2_m(vbool4_t, uint8_t *, vuint32m8_t, vuint8m2_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vsoxei32_v)))
void vsoxei32_v_u8mf2(uint8_t *, vuint32m2_t, vuint8mf2_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vsoxei32_v_m)))
void vsoxei32_v_u8mf2_m(vbool16_t, uint8_t *, vuint32m2_t, vuint8mf2_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vsoxei32_v)))
void vsoxei32_v_u8mf4(uint8_t *, vuint32m1_t, vuint8mf4_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vsoxei32_v_m)))
void vsoxei32_v_u8mf4_m(vbool32_t, uint8_t *, vuint32m1_t, vuint8mf4_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vsoxei32_v)))
void vsoxei32_v_u8mf8(uint8_t *, vuint32mf2_t, vuint8mf8_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vsoxei32_v_m)))
void vsoxei32_v_u8mf8_m(vbool64_t, uint8_t *, vuint32mf2_t, vuint8mf8_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vsoxei8_v)))
void vsoxei8_v_i16m1(int16_t *, vuint8mf2_t, vint16m1_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vsoxei8_v_m)))
void vsoxei8_v_i16m1_m(vbool16_t, int16_t *, vuint8mf2_t, vint16m1_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vsoxei8_v)))
void vsoxei8_v_i16m2(int16_t *, vuint8m1_t, vint16m2_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vsoxei8_v_m)))
void vsoxei8_v_i16m2_m(vbool8_t, int16_t *, vuint8m1_t, vint16m2_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vsoxei8_v)))
void vsoxei8_v_i16m4(int16_t *, vuint8m2_t, vint16m4_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vsoxei8_v_m)))
void vsoxei8_v_i16m4_m(vbool4_t, int16_t *, vuint8m2_t, vint16m4_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vsoxei8_v)))
void vsoxei8_v_i16m8(int16_t *, vuint8m4_t, vint16m8_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vsoxei8_v_m)))
void vsoxei8_v_i16m8_m(vbool2_t, int16_t *, vuint8m4_t, vint16m8_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vsoxei8_v)))
void vsoxei8_v_i16mf2(int16_t *, vuint8mf4_t, vint16mf2_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vsoxei8_v_m)))
void vsoxei8_v_i16mf2_m(vbool32_t, int16_t *, vuint8mf4_t, vint16mf2_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vsoxei8_v)))
void vsoxei8_v_i16mf4(int16_t *, vuint8mf8_t, vint16mf4_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vsoxei8_v_m)))
void vsoxei8_v_i16mf4_m(vbool64_t, int16_t *, vuint8mf8_t, vint16mf4_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vsuxei8_v)))
void vsuxei8_v_u8m1(uint8_t *, vuint8m1_t, vuint8m1_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vsuxei8_v_m)))
void vsuxei8_v_u8m1_m(vbool8_t, uint8_t *, vuint8m1_t, vuint8m1_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vsuxei8_v)))
void vsuxei8_v_u8m2(uint8_t *, vuint8m2_t, vuint8m2_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vsuxei8_v_m)))
void vsuxei8_v_u8m2_m(vbool4_t, uint8_t *, vuint8m2_t, vuint8m2_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vsuxei8_v)))
void vsuxei8_v_u8m4(uint8_t *, vuint8m4_t, vuint8m4_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vsuxei8_v_m)))
void vsuxei8_v_u8m4_m(vbool2_t, uint8_t *, vuint8m4_t, vuint8m4_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vsuxei8_v)))
void vsuxei8_v_u8m8(uint8_t *, vuint8m8_t, vuint8m8_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vsuxei8_v_m)))
void vsuxei8_v_u8m8_m(vbool1_t, uint8_t *, vuint8m8_t, vuint8m8_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vsuxei8_v)))
void vsuxei8_v_u8mf2(uint8_t *, vuint8mf2_t, vuint8mf2_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vsuxei8_v_m)))
void vsuxei8_v_u8mf2_m(vbool16_t, uint8_t *, vuint8mf2_t, vuint8mf2_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vsuxei8_v)))
void vsuxei8_v_u8mf4(uint8_t *, vuint8mf4_t, vuint8mf4_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vsuxei8_v_m)))
void vsuxei8_v_u8mf4_m(vbool32_t, uint8_t *, vuint8mf4_t, vuint8mf4_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vsuxei8_v)))
void vsuxei8_v_u8mf8(uint8_t *, vuint8mf8_t, vuint8mf8_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vsuxei8_v_m)))
void vsuxei8_v_u8mf8_m(vbool64_t, uint8_t *, vuint8mf8_t, vuint8mf8_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vsoxei8_v)))
void vsoxei8_v_u16m1(uint16_t *, vuint8mf2_t, vuint16m1_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vsoxei8_v_m)))
void vsoxei8_v_u16m1_m(vbool16_t, uint16_t *, vuint8mf2_t, vuint16m1_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vsoxei8_v)))
void vsoxei8_v_u16m2(uint16_t *, vuint8m1_t, vuint16m2_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vsoxei8_v_m)))
void vsoxei8_v_u16m2_m(vbool8_t, uint16_t *, vuint8m1_t, vuint16m2_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vsoxei8_v)))
void vsoxei8_v_u16m4(uint16_t *, vuint8m2_t, vuint16m4_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vsoxei8_v_m)))
void vsoxei8_v_u16m4_m(vbool4_t, uint16_t *, vuint8m2_t, vuint16m4_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vsoxei8_v)))
void vsoxei8_v_u16m8(uint16_t *, vuint8m4_t, vuint16m8_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vsoxei8_v_m)))
void vsoxei8_v_u16m8_m(vbool2_t, uint16_t *, vuint8m4_t, vuint16m8_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vsoxei8_v)))
void vsoxei8_v_u16mf2(uint16_t *, vuint8mf4_t, vuint16mf2_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vsoxei8_v_m)))
void vsoxei8_v_u16mf2_m(vbool32_t, uint16_t *, vuint8mf4_t, vuint16mf2_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vsoxei8_v)))
void vsoxei8_v_u16mf4(uint16_t *, vuint8mf8_t, vuint16mf4_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vsoxei8_v_m)))
void vsoxei8_v_u16mf4_m(vbool64_t, uint16_t *, vuint8mf8_t, vuint16mf4_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vsoxei16_v)))
void vsoxei16_v_i16m1(int16_t *, vuint16m1_t, vint16m1_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vsoxei16_v_m)))
void vsoxei16_v_i16m1_m(vbool16_t, int16_t *, vuint16m1_t, vint16m1_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vsoxei16_v)))
void vsoxei16_v_i16m2(int16_t *, vuint16m2_t, vint16m2_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vsoxei16_v_m)))
void vsoxei16_v_i16m2_m(vbool8_t, int16_t *, vuint16m2_t, vint16m2_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vsoxei16_v)))
void vsoxei16_v_i16m4(int16_t *, vuint16m4_t, vint16m4_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vsoxei16_v_m)))
void vsoxei16_v_i16m4_m(vbool4_t, int16_t *, vuint16m4_t, vint16m4_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vsoxei16_v)))
void vsoxei16_v_i16m8(int16_t *, vuint16m8_t, vint16m8_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vsoxei16_v_m)))
void vsoxei16_v_i16m8_m(vbool2_t, int16_t *, vuint16m8_t, vint16m8_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vsoxei16_v)))
void vsoxei16_v_i16mf2(int16_t *, vuint16mf2_t, vint16mf2_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vsoxei16_v_m)))
void vsoxei16_v_i16mf2_m(vbool32_t, int16_t *, vuint16mf2_t, vint16mf2_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vsoxei16_v)))
void vsoxei16_v_i16mf4(int16_t *, vuint16mf4_t, vint16mf4_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vsoxei16_v_m)))
void vsoxei16_v_i16mf4_m(vbool64_t, int16_t *, vuint16mf4_t, vint16mf4_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vsoxei16_v)))
void vsoxei16_v_u16m1(uint16_t *, vuint16m1_t, vuint16m1_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vsoxei16_v_m)))
void vsoxei16_v_u16m1_m(vbool16_t, uint16_t *, vuint16m1_t, vuint16m1_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vsoxei16_v)))
void vsoxei16_v_u16m2(uint16_t *, vuint16m2_t, vuint16m2_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vsoxei16_v_m)))
void vsoxei16_v_u16m2_m(vbool8_t, uint16_t *, vuint16m2_t, vuint16m2_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vsoxei16_v)))
void vsoxei16_v_u16m4(uint16_t *, vuint16m4_t, vuint16m4_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vsoxei16_v_m)))
void vsoxei16_v_u16m4_m(vbool4_t, uint16_t *, vuint16m4_t, vuint16m4_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vsoxei16_v)))
void vsoxei16_v_u16m8(uint16_t *, vuint16m8_t, vuint16m8_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vsoxei16_v_m)))
void vsoxei16_v_u16m8_m(vbool2_t, uint16_t *, vuint16m8_t, vuint16m8_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vsoxei16_v)))
void vsoxei16_v_u16mf2(uint16_t *, vuint16mf2_t, vuint16mf2_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vsoxei16_v_m)))
void vsoxei16_v_u16mf2_m(vbool32_t, uint16_t *, vuint16mf2_t, vuint16mf2_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vsoxei16_v)))
void vsoxei16_v_u16mf4(uint16_t *, vuint16mf4_t, vuint16mf4_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vsoxei16_v_m)))
void vsoxei16_v_u16mf4_m(vbool64_t, uint16_t *, vuint16mf4_t, vuint16mf4_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vsoxei32_v)))
void vsoxei32_v_i16m1(int16_t *, vuint32m2_t, vint16m1_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vsoxei32_v_m)))
void vsoxei32_v_i16m1_m(vbool16_t, int16_t *, vuint32m2_t, vint16m1_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vsoxei32_v)))
void vsoxei32_v_i16m2(int16_t *, vuint32m4_t, vint16m2_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vsoxei32_v_m)))
void vsoxei32_v_i16m2_m(vbool8_t, int16_t *, vuint32m4_t, vint16m2_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vsoxei32_v)))
void vsoxei32_v_i16m4(int16_t *, vuint32m8_t, vint16m4_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vsoxei32_v_m)))
void vsoxei32_v_i16m4_m(vbool4_t, int16_t *, vuint32m8_t, vint16m4_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vsoxei32_v)))
void vsoxei32_v_i16mf2(int16_t *, vuint32m1_t, vint16mf2_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vsoxei32_v_m)))
void vsoxei32_v_i16mf2_m(vbool32_t, int16_t *, vuint32m1_t, vint16mf2_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vsoxei32_v)))
void vsoxei32_v_i16mf4(int16_t *, vuint32mf2_t, vint16mf4_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vsoxei32_v_m)))
void vsoxei32_v_i16mf4_m(vbool64_t, int16_t *, vuint32mf2_t, vint16mf4_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vsoxei32_v)))
void vsoxei32_v_u16m1(uint16_t *, vuint32m2_t, vuint16m1_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vsoxei32_v_m)))
void vsoxei32_v_u16m1_m(vbool16_t, uint16_t *, vuint32m2_t, vuint16m1_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vsoxei32_v)))
void vsoxei32_v_u16m2(uint16_t *, vuint32m4_t, vuint16m2_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vsoxei32_v_m)))
void vsoxei32_v_u16m2_m(vbool8_t, uint16_t *, vuint32m4_t, vuint16m2_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vsoxei32_v)))
void vsoxei32_v_u16m4(uint16_t *, vuint32m8_t, vuint16m4_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vsoxei32_v_m)))
void vsoxei32_v_u16m4_m(vbool4_t, uint16_t *, vuint32m8_t, vuint16m4_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vsoxei32_v)))
void vsoxei32_v_u16mf2(uint16_t *, vuint32m1_t, vuint16mf2_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vsoxei32_v_m)))
void vsoxei32_v_u16mf2_m(vbool32_t, uint16_t *, vuint32m1_t, vuint16mf2_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vsoxei32_v)))
void vsoxei32_v_u16mf4(uint16_t *, vuint32mf2_t, vuint16mf4_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vsoxei32_v_m)))
void vsoxei32_v_u16mf4_m(vbool64_t, uint16_t *, vuint32mf2_t, vuint16mf4_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vsoxei8_v)))
void vsoxei8_v_i32m1(int32_t *, vuint8mf4_t, vint32m1_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vsoxei8_v_m)))
void vsoxei8_v_i32m1_m(vbool32_t, int32_t *, vuint8mf4_t, vint32m1_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vsoxei8_v)))
void vsoxei8_v_i32m2(int32_t *, vuint8mf2_t, vint32m2_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vsoxei8_v_m)))
void vsoxei8_v_i32m2_m(vbool16_t, int32_t *, vuint8mf2_t, vint32m2_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vsoxei8_v)))
void vsoxei8_v_i32m4(int32_t *, vuint8m1_t, vint32m4_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vsoxei8_v_m)))
void vsoxei8_v_i32m4_m(vbool8_t, int32_t *, vuint8m1_t, vint32m4_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vsoxei8_v)))
void vsoxei8_v_i32m8(int32_t *, vuint8m2_t, vint32m8_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vsoxei8_v_m)))
void vsoxei8_v_i32m8_m(vbool4_t, int32_t *, vuint8m2_t, vint32m8_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vsoxei8_v)))
void vsoxei8_v_i32mf2(int32_t *, vuint8mf8_t, vint32mf2_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vsoxei8_v_m)))
void vsoxei8_v_i32mf2_m(vbool64_t, int32_t *, vuint8mf8_t, vint32mf2_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vsoxei8_v)))
void vsoxei8_v_u32m1(uint32_t *, vuint8mf4_t, vuint32m1_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vsoxei8_v_m)))
void vsoxei8_v_u32m1_m(vbool32_t, uint32_t *, vuint8mf4_t, vuint32m1_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vsoxei8_v)))
void vsoxei8_v_u32m2(uint32_t *, vuint8mf2_t, vuint32m2_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vsoxei8_v_m)))
void vsoxei8_v_u32m2_m(vbool16_t, uint32_t *, vuint8mf2_t, vuint32m2_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vsoxei8_v)))
void vsoxei8_v_u32m4(uint32_t *, vuint8m1_t, vuint32m4_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vsoxei8_v_m)))
void vsoxei8_v_u32m4_m(vbool8_t, uint32_t *, vuint8m1_t, vuint32m4_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vsoxei8_v)))
void vsoxei8_v_u32m8(uint32_t *, vuint8m2_t, vuint32m8_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vsoxei8_v_m)))
void vsoxei8_v_u32m8_m(vbool4_t, uint32_t *, vuint8m2_t, vuint32m8_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vsoxei8_v)))
void vsoxei8_v_u32mf2(uint32_t *, vuint8mf8_t, vuint32mf2_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vsoxei8_v_m)))
void vsoxei8_v_u32mf2_m(vbool64_t, uint32_t *, vuint8mf8_t, vuint32mf2_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vsoxei16_v)))
void vsoxei16_v_i32m1(int32_t *, vuint16mf2_t, vint32m1_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vsoxei16_v_m)))
void vsoxei16_v_i32m1_m(vbool32_t, int32_t *, vuint16mf2_t, vint32m1_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vsoxei16_v)))
void vsoxei16_v_i32m2(int32_t *, vuint16m1_t, vint32m2_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vsoxei16_v_m)))
void vsoxei16_v_i32m2_m(vbool16_t, int32_t *, vuint16m1_t, vint32m2_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vsoxei16_v)))
void vsoxei16_v_i32m4(int32_t *, vuint16m2_t, vint32m4_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vsoxei16_v_m)))
void vsoxei16_v_i32m4_m(vbool8_t, int32_t *, vuint16m2_t, vint32m4_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vsoxei16_v)))
void vsoxei16_v_i32m8(int32_t *, vuint16m4_t, vint32m8_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vsoxei16_v_m)))
void vsoxei16_v_i32m8_m(vbool4_t, int32_t *, vuint16m4_t, vint32m8_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vsoxei16_v)))
void vsoxei16_v_i32mf2(int32_t *, vuint16mf4_t, vint32mf2_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vsoxei16_v_m)))
void vsoxei16_v_i32mf2_m(vbool64_t, int32_t *, vuint16mf4_t, vint32mf2_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vsoxei16_v)))
void vsoxei16_v_u32m1(uint32_t *, vuint16mf2_t, vuint32m1_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vsoxei16_v_m)))
void vsoxei16_v_u32m1_m(vbool32_t, uint32_t *, vuint16mf2_t, vuint32m1_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vsoxei16_v)))
void vsoxei16_v_u32m2(uint32_t *, vuint16m1_t, vuint32m2_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vsoxei16_v_m)))
void vsoxei16_v_u32m2_m(vbool16_t, uint32_t *, vuint16m1_t, vuint32m2_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vsoxei16_v)))
void vsoxei16_v_u32m4(uint32_t *, vuint16m2_t, vuint32m4_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vsoxei16_v_m)))
void vsoxei16_v_u32m4_m(vbool8_t, uint32_t *, vuint16m2_t, vuint32m4_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vsoxei16_v)))
void vsoxei16_v_u32m8(uint32_t *, vuint16m4_t, vuint32m8_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vsoxei16_v_m)))
void vsoxei16_v_u32m8_m(vbool4_t, uint32_t *, vuint16m4_t, vuint32m8_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vsoxei16_v)))
void vsoxei16_v_u32mf2(uint32_t *, vuint16mf4_t, vuint32mf2_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vsoxei16_v_m)))
void vsoxei16_v_u32mf2_m(vbool64_t, uint32_t *, vuint16mf4_t, vuint32mf2_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vsoxei32_v)))
void vsoxei32_v_i32m1(int32_t *, vuint32m1_t, vint32m1_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vsoxei32_v_m)))
void vsoxei32_v_i32m1_m(vbool32_t, int32_t *, vuint32m1_t, vint32m1_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vsoxei32_v)))
void vsoxei32_v_i32m2(int32_t *, vuint32m2_t, vint32m2_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vsoxei32_v_m)))
void vsoxei32_v_i32m2_m(vbool16_t, int32_t *, vuint32m2_t, vint32m2_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vsoxei32_v)))
void vsoxei32_v_i32m4(int32_t *, vuint32m4_t, vint32m4_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vsoxei32_v_m)))
void vsoxei32_v_i32m4_m(vbool8_t, int32_t *, vuint32m4_t, vint32m4_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vsoxei32_v)))
void vsoxei32_v_i32m8(int32_t *, vuint32m8_t, vint32m8_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vsoxei32_v_m)))
void vsoxei32_v_i32m8_m(vbool4_t, int32_t *, vuint32m8_t, vint32m8_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vsoxei32_v)))
void vsoxei32_v_i32mf2(int32_t *, vuint32mf2_t, vint32mf2_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vsoxei32_v_m)))
void vsoxei32_v_i32mf2_m(vbool64_t, int32_t *, vuint32mf2_t, vint32mf2_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vsoxei32_v)))
void vsoxei32_v_u32m1(uint32_t *, vuint32m1_t, vuint32m1_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vsoxei32_v_m)))
void vsoxei32_v_u32m1_m(vbool32_t, uint32_t *, vuint32m1_t, vuint32m1_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vsoxei32_v)))
void vsoxei32_v_u32m2(uint32_t *, vuint32m2_t, vuint32m2_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vsoxei32_v_m)))
void vsoxei32_v_u32m2_m(vbool16_t, uint32_t *, vuint32m2_t, vuint32m2_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vsoxei32_v)))
void vsoxei32_v_u32m4(uint32_t *, vuint32m4_t, vuint32m4_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vsoxei32_v_m)))
void vsoxei32_v_u32m4_m(vbool8_t, uint32_t *, vuint32m4_t, vuint32m4_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vsoxei32_v)))
void vsoxei32_v_u32m8(uint32_t *, vuint32m8_t, vuint32m8_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vsoxei32_v_m)))
void vsoxei32_v_u32m8_m(vbool4_t, uint32_t *, vuint32m8_t, vuint32m8_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vsoxei32_v)))
void vsoxei32_v_u32mf2(uint32_t *, vuint32mf2_t, vuint32mf2_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vsoxei32_v_m)))
void vsoxei32_v_u32mf2_m(vbool64_t, uint32_t *, vuint32mf2_t, vuint32mf2_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vlseg2e8_v)))
void vlseg2e8_v_i8m1(vint8m1_t *, vint8m1_t *, const int8_t *, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vlseg2e8_v_m)))
void vlseg2e8_v_i8m1_m(vint8m1_t *, vint8m1_t *, vbool8_t, vint8m1_t, vint8m1_t, const int8_t *, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vlseg2e8_v)))
void vlseg2e8_v_i8m2(vint8m2_t *, vint8m2_t *, const int8_t *, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vlseg2e8_v_m)))
void vlseg2e8_v_i8m2_m(vint8m2_t *, vint8m2_t *, vbool4_t, vint8m2_t, vint8m2_t, const int8_t *, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vlseg2e8_v)))
void vlseg2e8_v_i8m4(vint8m4_t *, vint8m4_t *, const int8_t *, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vlseg2e8_v_m)))
void vlseg2e8_v_i8m4_m(vint8m4_t *, vint8m4_t *, vbool2_t, vint8m4_t, vint8m4_t, const int8_t *, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vlseg2e8_v)))
void vlseg2e8_v_i8mf2(vint8mf2_t *, vint8mf2_t *, const int8_t *, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vlseg2e8_v_m)))
void vlseg2e8_v_i8mf2_m(vint8mf2_t *, vint8mf2_t *, vbool16_t, vint8mf2_t, vint8mf2_t, const int8_t *, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vlseg2e8_v)))
void vlseg2e8_v_i8mf4(vint8mf4_t *, vint8mf4_t *, const int8_t *, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vlseg2e8_v_m)))
void vlseg2e8_v_i8mf4_m(vint8mf4_t *, vint8mf4_t *, vbool32_t, vint8mf4_t, vint8mf4_t, const int8_t *, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vlseg2e8_v)))
void vlseg2e8_v_i8mf8(vint8mf8_t *, vint8mf8_t *, const int8_t *, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vlseg2e8_v_m)))
void vlseg2e8_v_i8mf8_m(vint8mf8_t *, vint8mf8_t *, vbool64_t, vint8mf8_t, vint8mf8_t, const int8_t *, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vle16ff_v)))
vint16m1_t vle16ff_v_i16m1(const int16_t *, size_t *, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vle16ff_v_m)))
vint16m1_t vle16ff_v_i16m1_m(vbool16_t, vint16m1_t, const int16_t *, size_t *, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vle16ff_v)))
vint16m2_t vle16ff_v_i16m2(const int16_t *, size_t *, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vle16ff_v_m)))
vint16m2_t vle16ff_v_i16m2_m(vbool8_t, vint16m2_t, const int16_t *, size_t *, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vle16ff_v)))
vint16m4_t vle16ff_v_i16m4(const int16_t *, size_t *, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vle16ff_v_m)))
vint16m4_t vle16ff_v_i16m4_m(vbool4_t, vint16m4_t, const int16_t *, size_t *, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vle16ff_v)))
vint16m8_t vle16ff_v_i16m8(const int16_t *, size_t *, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vle16ff_v_m)))
vint16m8_t vle16ff_v_i16m8_m(vbool2_t, vint16m8_t, const int16_t *, size_t *, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vle16ff_v)))
vint16mf2_t vle16ff_v_i16mf2(const int16_t *, size_t *, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vle16ff_v_m)))
vint16mf2_t vle16ff_v_i16mf2_m(vbool32_t, vint16mf2_t, const int16_t *, size_t *, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vle16ff_v)))
vint16mf4_t vle16ff_v_i16mf4(const int16_t *, size_t *, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vle16ff_v_m)))
vint16mf4_t vle16ff_v_i16mf4_m(vbool64_t, vint16mf4_t, const int16_t *, size_t *, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vle16ff_v)))
vuint16m1_t vle16ff_v_u16m1(const uint16_t *, size_t *, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vle16ff_v_m)))
vuint16m1_t vle16ff_v_u16m1_m(vbool16_t, vuint16m1_t, const uint16_t *, size_t *, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vle16ff_v)))
vuint16m2_t vle16ff_v_u16m2(const uint16_t *, size_t *, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vle16ff_v_m)))
vuint16m2_t vle16ff_v_u16m2_m(vbool8_t, vuint16m2_t, const uint16_t *, size_t *, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vle16ff_v)))
vuint16m4_t vle16ff_v_u16m4(const uint16_t *, size_t *, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vle16ff_v_m)))
vuint16m4_t vle16ff_v_u16m4_m(vbool4_t, vuint16m4_t, const uint16_t *, size_t *, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vle16ff_v)))
vuint16m8_t vle16ff_v_u16m8(const uint16_t *, size_t *, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vle16ff_v_m)))
vuint16m8_t vle16ff_v_u16m8_m(vbool2_t, vuint16m8_t, const uint16_t *, size_t *, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vle16ff_v)))
vuint16mf2_t vle16ff_v_u16mf2(const uint16_t *, size_t *, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vle16ff_v_m)))
vuint16mf2_t vle16ff_v_u16mf2_m(vbool32_t, vuint16mf2_t, const uint16_t *, size_t *, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vle16ff_v)))
vuint16mf4_t vle16ff_v_u16mf4(const uint16_t *, size_t *, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vle16ff_v_m)))
vuint16mf4_t vle16ff_v_u16mf4_m(vbool64_t, vuint16mf4_t, const uint16_t *, size_t *, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vle32ff_v)))
vint32m1_t vle32ff_v_i32m1(const int32_t *, size_t *, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vle32ff_v_m)))
vint32m1_t vle32ff_v_i32m1_m(vbool32_t, vint32m1_t, const int32_t *, size_t *, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vle32ff_v)))
vint32m2_t vle32ff_v_i32m2(const int32_t *, size_t *, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vle32ff_v_m)))
vint32m2_t vle32ff_v_i32m2_m(vbool16_t, vint32m2_t, const int32_t *, size_t *, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vle32ff_v)))
vint32m4_t vle32ff_v_i32m4(const int32_t *, size_t *, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vle32ff_v_m)))
vint32m4_t vle32ff_v_i32m4_m(vbool8_t, vint32m4_t, const int32_t *, size_t *, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vle32ff_v)))
vint32m8_t vle32ff_v_i32m8(const int32_t *, size_t *, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vle32ff_v_m)))
vint32m8_t vle32ff_v_i32m8_m(vbool4_t, vint32m8_t, const int32_t *, size_t *, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vle32ff_v)))
vint32mf2_t vle32ff_v_i32mf2(const int32_t *, size_t *, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vle32ff_v_m)))
vint32mf2_t vle32ff_v_i32mf2_m(vbool64_t, vint32mf2_t, const int32_t *, size_t *, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vle32ff_v)))
vuint32m1_t vle32ff_v_u32m1(const uint32_t *, size_t *, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vle32ff_v_m)))
vuint32m1_t vle32ff_v_u32m1_m(vbool32_t, vuint32m1_t, const uint32_t *, size_t *, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vle32ff_v)))
vuint32m2_t vle32ff_v_u32m2(const uint32_t *, size_t *, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vle32ff_v_m)))
vuint32m2_t vle32ff_v_u32m2_m(vbool16_t, vuint32m2_t, const uint32_t *, size_t *, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vle32ff_v)))
vuint32m4_t vle32ff_v_u32m4(const uint32_t *, size_t *, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vle32ff_v_m)))
vuint32m4_t vle32ff_v_u32m4_m(vbool8_t, vuint32m4_t, const uint32_t *, size_t *, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vle32ff_v)))
vuint32m8_t vle32ff_v_u32m8(const uint32_t *, size_t *, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vle32ff_v_m)))
vuint32m8_t vle32ff_v_u32m8_m(vbool4_t, vuint32m8_t, const uint32_t *, size_t *, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vle32ff_v)))
vuint32mf2_t vle32ff_v_u32mf2(const uint32_t *, size_t *, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vle32ff_v_m)))
vuint32mf2_t vle32ff_v_u32mf2_m(vbool64_t, vuint32mf2_t, const uint32_t *, size_t *, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vlseg2e8_v)))
void vlseg2e8_v_u8m1(vuint8m1_t *, vuint8m1_t *, const uint8_t *, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vlseg2e8_v_m)))
void vlseg2e8_v_u8m1_m(vuint8m1_t *, vuint8m1_t *, vbool8_t, vuint8m1_t, vuint8m1_t, const uint8_t *, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vlseg2e8_v)))
void vlseg2e8_v_u8m2(vuint8m2_t *, vuint8m2_t *, const uint8_t *, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vlseg2e8_v_m)))
void vlseg2e8_v_u8m2_m(vuint8m2_t *, vuint8m2_t *, vbool4_t, vuint8m2_t, vuint8m2_t, const uint8_t *, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vlseg2e8_v)))
void vlseg2e8_v_u8m4(vuint8m4_t *, vuint8m4_t *, const uint8_t *, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vlseg2e8_v_m)))
void vlseg2e8_v_u8m4_m(vuint8m4_t *, vuint8m4_t *, vbool2_t, vuint8m4_t, vuint8m4_t, const uint8_t *, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vlseg2e8_v)))
void vlseg2e8_v_u8mf2(vuint8mf2_t *, vuint8mf2_t *, const uint8_t *, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vlseg2e8_v_m)))
void vlseg2e8_v_u8mf2_m(vuint8mf2_t *, vuint8mf2_t *, vbool16_t, vuint8mf2_t, vuint8mf2_t, const uint8_t *, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vlseg2e8_v)))
void vlseg2e8_v_u8mf4(vuint8mf4_t *, vuint8mf4_t *, const uint8_t *, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vlseg2e8_v_m)))
void vlseg2e8_v_u8mf4_m(vuint8mf4_t *, vuint8mf4_t *, vbool32_t, vuint8mf4_t, vuint8mf4_t, const uint8_t *, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vlseg2e8_v)))
void vlseg2e8_v_u8mf8(vuint8mf8_t *, vuint8mf8_t *, const uint8_t *, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vlseg2e8_v_m)))
void vlseg2e8_v_u8mf8_m(vuint8mf8_t *, vuint8mf8_t *, vbool64_t, vuint8mf8_t, vuint8mf8_t, const uint8_t *, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vlseg3e8_v)))
void vlseg3e8_v_i8m1(vint8m1_t *, vint8m1_t *, vint8m1_t *, const int8_t *, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vlseg3e8_v_m)))
void vlseg3e8_v_i8m1_m(vint8m1_t *, vint8m1_t *, vint8m1_t *, vbool8_t, vint8m1_t, vint8m1_t, vint8m1_t, const int8_t *, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vlseg3e8_v)))
void vlseg3e8_v_i8m2(vint8m2_t *, vint8m2_t *, vint8m2_t *, const int8_t *, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vlseg3e8_v_m)))
void vlseg3e8_v_i8m2_m(vint8m2_t *, vint8m2_t *, vint8m2_t *, vbool4_t, vint8m2_t, vint8m2_t, vint8m2_t, const int8_t *, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vlseg3e8_v)))
void vlseg3e8_v_i8mf2(vint8mf2_t *, vint8mf2_t *, vint8mf2_t *, const int8_t *, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vlseg3e8_v_m)))
void vlseg3e8_v_i8mf2_m(vint8mf2_t *, vint8mf2_t *, vint8mf2_t *, vbool16_t, vint8mf2_t, vint8mf2_t, vint8mf2_t, const int8_t *, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vlseg3e8_v)))
void vlseg3e8_v_i8mf4(vint8mf4_t *, vint8mf4_t *, vint8mf4_t *, const int8_t *, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vlseg3e8_v_m)))
void vlseg3e8_v_i8mf4_m(vint8mf4_t *, vint8mf4_t *, vint8mf4_t *, vbool32_t, vint8mf4_t, vint8mf4_t, vint8mf4_t, const int8_t *, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vlseg3e8_v)))
void vlseg3e8_v_i8mf8(vint8mf8_t *, vint8mf8_t *, vint8mf8_t *, const int8_t *, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vlseg3e8_v_m)))
void vlseg3e8_v_i8mf8_m(vint8mf8_t *, vint8mf8_t *, vint8mf8_t *, vbool64_t, vint8mf8_t, vint8mf8_t, vint8mf8_t, const int8_t *, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vlseg3e8_v)))
void vlseg3e8_v_u8m1(vuint8m1_t *, vuint8m1_t *, vuint8m1_t *, const uint8_t *, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vlseg3e8_v_m)))
void vlseg3e8_v_u8m1_m(vuint8m1_t *, vuint8m1_t *, vuint8m1_t *, vbool8_t, vuint8m1_t, vuint8m1_t, vuint8m1_t, const uint8_t *, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vlseg3e8_v)))
void vlseg3e8_v_u8m2(vuint8m2_t *, vuint8m2_t *, vuint8m2_t *, const uint8_t *, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vlseg3e8_v_m)))
void vlseg3e8_v_u8m2_m(vuint8m2_t *, vuint8m2_t *, vuint8m2_t *, vbool4_t, vuint8m2_t, vuint8m2_t, vuint8m2_t, const uint8_t *, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vlseg3e8_v)))
void vlseg3e8_v_u8mf2(vuint8mf2_t *, vuint8mf2_t *, vuint8mf2_t *, const uint8_t *, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vlseg3e8_v_m)))
void vlseg3e8_v_u8mf2_m(vuint8mf2_t *, vuint8mf2_t *, vuint8mf2_t *, vbool16_t, vuint8mf2_t, vuint8mf2_t, vuint8mf2_t, const uint8_t *, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vlseg3e8_v)))
void vlseg3e8_v_u8mf4(vuint8mf4_t *, vuint8mf4_t *, vuint8mf4_t *, const uint8_t *, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vlseg3e8_v_m)))
void vlseg3e8_v_u8mf4_m(vuint8mf4_t *, vuint8mf4_t *, vuint8mf4_t *, vbool32_t, vuint8mf4_t, vuint8mf4_t, vuint8mf4_t, const uint8_t *, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vlseg3e8_v)))
void vlseg3e8_v_u8mf8(vuint8mf8_t *, vuint8mf8_t *, vuint8mf8_t *, const uint8_t *, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vlseg3e8_v_m)))
void vlseg3e8_v_u8mf8_m(vuint8mf8_t *, vuint8mf8_t *, vuint8mf8_t *, vbool64_t, vuint8mf8_t, vuint8mf8_t, vuint8mf8_t, const uint8_t *, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vlseg4e8_v)))
void vlseg4e8_v_i8m1(vint8m1_t *, vint8m1_t *, vint8m1_t *, vint8m1_t *, const int8_t *, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vlseg4e8_v_m)))
void vlseg4e8_v_i8m1_m(vint8m1_t *, vint8m1_t *, vint8m1_t *, vint8m1_t *, vbool8_t, vint8m1_t, vint8m1_t, vint8m1_t, vint8m1_t, const int8_t *, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vlseg4e8_v)))
void vlseg4e8_v_i8m2(vint8m2_t *, vint8m2_t *, vint8m2_t *, vint8m2_t *, const int8_t *, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vlseg4e8_v_m)))
void vlseg4e8_v_i8m2_m(vint8m2_t *, vint8m2_t *, vint8m2_t *, vint8m2_t *, vbool4_t, vint8m2_t, vint8m2_t, vint8m2_t, vint8m2_t, const int8_t *, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vlseg4e8_v)))
void vlseg4e8_v_i8mf2(vint8mf2_t *, vint8mf2_t *, vint8mf2_t *, vint8mf2_t *, const int8_t *, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vlseg4e8_v_m)))
void vlseg4e8_v_i8mf2_m(vint8mf2_t *, vint8mf2_t *, vint8mf2_t *, vint8mf2_t *, vbool16_t, vint8mf2_t, vint8mf2_t, vint8mf2_t, vint8mf2_t, const int8_t *, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vlseg4e8_v)))
void vlseg4e8_v_i8mf4(vint8mf4_t *, vint8mf4_t *, vint8mf4_t *, vint8mf4_t *, const int8_t *, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vlseg4e8_v_m)))
void vlseg4e8_v_i8mf4_m(vint8mf4_t *, vint8mf4_t *, vint8mf4_t *, vint8mf4_t *, vbool32_t, vint8mf4_t, vint8mf4_t, vint8mf4_t, vint8mf4_t, const int8_t *, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vlseg4e8_v)))
void vlseg4e8_v_i8mf8(vint8mf8_t *, vint8mf8_t *, vint8mf8_t *, vint8mf8_t *, const int8_t *, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vlseg4e8_v_m)))
void vlseg4e8_v_i8mf8_m(vint8mf8_t *, vint8mf8_t *, vint8mf8_t *, vint8mf8_t *, vbool64_t, vint8mf8_t, vint8mf8_t, vint8mf8_t, vint8mf8_t, const int8_t *, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vlseg4e8_v)))
void vlseg4e8_v_u8m1(vuint8m1_t *, vuint8m1_t *, vuint8m1_t *, vuint8m1_t *, const uint8_t *, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vlseg4e8_v_m)))
void vlseg4e8_v_u8m1_m(vuint8m1_t *, vuint8m1_t *, vuint8m1_t *, vuint8m1_t *, vbool8_t, vuint8m1_t, vuint8m1_t, vuint8m1_t, vuint8m1_t, const uint8_t *, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vlseg4e8_v)))
void vlseg4e8_v_u8m2(vuint8m2_t *, vuint8m2_t *, vuint8m2_t *, vuint8m2_t *, const uint8_t *, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vlseg4e8_v_m)))
void vlseg4e8_v_u8m2_m(vuint8m2_t *, vuint8m2_t *, vuint8m2_t *, vuint8m2_t *, vbool4_t, vuint8m2_t, vuint8m2_t, vuint8m2_t, vuint8m2_t, const uint8_t *, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vlseg4e8_v)))
void vlseg4e8_v_u8mf2(vuint8mf2_t *, vuint8mf2_t *, vuint8mf2_t *, vuint8mf2_t *, const uint8_t *, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vlseg4e8_v_m)))
void vlseg4e8_v_u8mf2_m(vuint8mf2_t *, vuint8mf2_t *, vuint8mf2_t *, vuint8mf2_t *, vbool16_t, vuint8mf2_t, vuint8mf2_t, vuint8mf2_t, vuint8mf2_t, const uint8_t *, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vlseg4e8_v)))
void vlseg4e8_v_u8mf4(vuint8mf4_t *, vuint8mf4_t *, vuint8mf4_t *, vuint8mf4_t *, const uint8_t *, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vlseg4e8_v_m)))
void vlseg4e8_v_u8mf4_m(vuint8mf4_t *, vuint8mf4_t *, vuint8mf4_t *, vuint8mf4_t *, vbool32_t, vuint8mf4_t, vuint8mf4_t, vuint8mf4_t, vuint8mf4_t, const uint8_t *, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vlseg4e8_v)))
void vlseg4e8_v_u8mf8(vuint8mf8_t *, vuint8mf8_t *, vuint8mf8_t *, vuint8mf8_t *, const uint8_t *, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vlseg4e8_v_m)))
void vlseg4e8_v_u8mf8_m(vuint8mf8_t *, vuint8mf8_t *, vuint8mf8_t *, vuint8mf8_t *, vbool64_t, vuint8mf8_t, vuint8mf8_t, vuint8mf8_t, vuint8mf8_t, const uint8_t *, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vlseg5e8_v)))
void vlseg5e8_v_i8m1(vint8m1_t *, vint8m1_t *, vint8m1_t *, vint8m1_t *, vint8m1_t *, const int8_t *, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vlseg5e8_v_m)))
void vlseg5e8_v_i8m1_m(vint8m1_t *, vint8m1_t *, vint8m1_t *, vint8m1_t *, vint8m1_t *, vbool8_t, vint8m1_t, vint8m1_t, vint8m1_t, vint8m1_t, vint8m1_t, const int8_t *, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vlseg5e8_v)))
void vlseg5e8_v_i8mf2(vint8mf2_t *, vint8mf2_t *, vint8mf2_t *, vint8mf2_t *, vint8mf2_t *, const int8_t *, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vlseg5e8_v_m)))
void vlseg5e8_v_i8mf2_m(vint8mf2_t *, vint8mf2_t *, vint8mf2_t *, vint8mf2_t *, vint8mf2_t *, vbool16_t, vint8mf2_t, vint8mf2_t, vint8mf2_t, vint8mf2_t, vint8mf2_t, const int8_t *, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vlseg5e8_v)))
void vlseg5e8_v_i8mf4(vint8mf4_t *, vint8mf4_t *, vint8mf4_t *, vint8mf4_t *, vint8mf4_t *, const int8_t *, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vlseg5e8_v_m)))
void vlseg5e8_v_i8mf4_m(vint8mf4_t *, vint8mf4_t *, vint8mf4_t *, vint8mf4_t *, vint8mf4_t *, vbool32_t, vint8mf4_t, vint8mf4_t, vint8mf4_t, vint8mf4_t, vint8mf4_t, const int8_t *, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vlseg5e8_v)))
void vlseg5e8_v_i8mf8(vint8mf8_t *, vint8mf8_t *, vint8mf8_t *, vint8mf8_t *, vint8mf8_t *, const int8_t *, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vlseg5e8_v_m)))
void vlseg5e8_v_i8mf8_m(vint8mf8_t *, vint8mf8_t *, vint8mf8_t *, vint8mf8_t *, vint8mf8_t *, vbool64_t, vint8mf8_t, vint8mf8_t, vint8mf8_t, vint8mf8_t, vint8mf8_t, const int8_t *, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vle8_v)))
vint8m1_t vle8_v_i8m1(const int8_t *, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vle8_v_m)))
vint8m1_t vle8_v_i8m1_m(vbool8_t, vint8m1_t, const int8_t *, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vle8_v)))
vint8m2_t vle8_v_i8m2(const int8_t *, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vle8_v_m)))
vint8m2_t vle8_v_i8m2_m(vbool4_t, vint8m2_t, const int8_t *, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vle8_v)))
vint8m4_t vle8_v_i8m4(const int8_t *, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vle8_v_m)))
vint8m4_t vle8_v_i8m4_m(vbool2_t, vint8m4_t, const int8_t *, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vle8_v)))
vint8m8_t vle8_v_i8m8(const int8_t *, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vle8_v_m)))
vint8m8_t vle8_v_i8m8_m(vbool1_t, vint8m8_t, const int8_t *, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vle8_v)))
vint8mf2_t vle8_v_i8mf2(const int8_t *, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vle8_v_m)))
vint8mf2_t vle8_v_i8mf2_m(vbool16_t, vint8mf2_t, const int8_t *, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vle8_v)))
vint8mf4_t vle8_v_i8mf4(const int8_t *, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vle8_v_m)))
vint8mf4_t vle8_v_i8mf4_m(vbool32_t, vint8mf4_t, const int8_t *, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vle8_v)))
vint8mf8_t vle8_v_i8mf8(const int8_t *, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vle8_v_m)))
vint8mf8_t vle8_v_i8mf8_m(vbool64_t, vint8mf8_t, const int8_t *, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vlseg5e8_v)))
void vlseg5e8_v_u8m1(vuint8m1_t *, vuint8m1_t *, vuint8m1_t *, vuint8m1_t *, vuint8m1_t *, const uint8_t *, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vlseg5e8_v_m)))
void vlseg5e8_v_u8m1_m(vuint8m1_t *, vuint8m1_t *, vuint8m1_t *, vuint8m1_t *, vuint8m1_t *, vbool8_t, vuint8m1_t, vuint8m1_t, vuint8m1_t, vuint8m1_t, vuint8m1_t, const uint8_t *, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vlseg5e8_v)))
void vlseg5e8_v_u8mf2(vuint8mf2_t *, vuint8mf2_t *, vuint8mf2_t *, vuint8mf2_t *, vuint8mf2_t *, const uint8_t *, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vlseg5e8_v_m)))
void vlseg5e8_v_u8mf2_m(vuint8mf2_t *, vuint8mf2_t *, vuint8mf2_t *, vuint8mf2_t *, vuint8mf2_t *, vbool16_t, vuint8mf2_t, vuint8mf2_t, vuint8mf2_t, vuint8mf2_t, vuint8mf2_t, const uint8_t *, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vlseg5e8_v)))
void vlseg5e8_v_u8mf4(vuint8mf4_t *, vuint8mf4_t *, vuint8mf4_t *, vuint8mf4_t *, vuint8mf4_t *, const uint8_t *, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vlseg5e8_v_m)))
void vlseg5e8_v_u8mf4_m(vuint8mf4_t *, vuint8mf4_t *, vuint8mf4_t *, vuint8mf4_t *, vuint8mf4_t *, vbool32_t, vuint8mf4_t, vuint8mf4_t, vuint8mf4_t, vuint8mf4_t, vuint8mf4_t, const uint8_t *, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vlseg5e8_v)))
void vlseg5e8_v_u8mf8(vuint8mf8_t *, vuint8mf8_t *, vuint8mf8_t *, vuint8mf8_t *, vuint8mf8_t *, const uint8_t *, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vlseg5e8_v_m)))
void vlseg5e8_v_u8mf8_m(vuint8mf8_t *, vuint8mf8_t *, vuint8mf8_t *, vuint8mf8_t *, vuint8mf8_t *, vbool64_t, vuint8mf8_t, vuint8mf8_t, vuint8mf8_t, vuint8mf8_t, vuint8mf8_t, const uint8_t *, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vlseg6e8_v)))
void vlseg6e8_v_i8m1(vint8m1_t *, vint8m1_t *, vint8m1_t *, vint8m1_t *, vint8m1_t *, vint8m1_t *, const int8_t *, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vlseg6e8_v_m)))
void vlseg6e8_v_i8m1_m(vint8m1_t *, vint8m1_t *, vint8m1_t *, vint8m1_t *, vint8m1_t *, vint8m1_t *, vbool8_t, vint8m1_t, vint8m1_t, vint8m1_t, vint8m1_t, vint8m1_t, vint8m1_t, const int8_t *, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vlseg6e8_v)))
void vlseg6e8_v_i8mf2(vint8mf2_t *, vint8mf2_t *, vint8mf2_t *, vint8mf2_t *, vint8mf2_t *, vint8mf2_t *, const int8_t *, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vlseg6e8_v_m)))
void vlseg6e8_v_i8mf2_m(vint8mf2_t *, vint8mf2_t *, vint8mf2_t *, vint8mf2_t *, vint8mf2_t *, vint8mf2_t *, vbool16_t, vint8mf2_t, vint8mf2_t, vint8mf2_t, vint8mf2_t, vint8mf2_t, vint8mf2_t, const int8_t *, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vlseg6e8_v)))
void vlseg6e8_v_i8mf4(vint8mf4_t *, vint8mf4_t *, vint8mf4_t *, vint8mf4_t *, vint8mf4_t *, vint8mf4_t *, const int8_t *, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vlseg6e8_v_m)))
void vlseg6e8_v_i8mf4_m(vint8mf4_t *, vint8mf4_t *, vint8mf4_t *, vint8mf4_t *, vint8mf4_t *, vint8mf4_t *, vbool32_t, vint8mf4_t, vint8mf4_t, vint8mf4_t, vint8mf4_t, vint8mf4_t, vint8mf4_t, const int8_t *, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vlseg6e8_v)))
void vlseg6e8_v_i8mf8(vint8mf8_t *, vint8mf8_t *, vint8mf8_t *, vint8mf8_t *, vint8mf8_t *, vint8mf8_t *, const int8_t *, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vlseg6e8_v_m)))
void vlseg6e8_v_i8mf8_m(vint8mf8_t *, vint8mf8_t *, vint8mf8_t *, vint8mf8_t *, vint8mf8_t *, vint8mf8_t *, vbool64_t, vint8mf8_t, vint8mf8_t, vint8mf8_t, vint8mf8_t, vint8mf8_t, vint8mf8_t, const int8_t *, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vlseg6e8_v)))
void vlseg6e8_v_u8m1(vuint8m1_t *, vuint8m1_t *, vuint8m1_t *, vuint8m1_t *, vuint8m1_t *, vuint8m1_t *, const uint8_t *, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vlseg6e8_v_m)))
void vlseg6e8_v_u8m1_m(vuint8m1_t *, vuint8m1_t *, vuint8m1_t *, vuint8m1_t *, vuint8m1_t *, vuint8m1_t *, vbool8_t, vuint8m1_t, vuint8m1_t, vuint8m1_t, vuint8m1_t, vuint8m1_t, vuint8m1_t, const uint8_t *, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vlseg6e8_v)))
void vlseg6e8_v_u8mf2(vuint8mf2_t *, vuint8mf2_t *, vuint8mf2_t *, vuint8mf2_t *, vuint8mf2_t *, vuint8mf2_t *, const uint8_t *, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vlseg6e8_v_m)))
void vlseg6e8_v_u8mf2_m(vuint8mf2_t *, vuint8mf2_t *, vuint8mf2_t *, vuint8mf2_t *, vuint8mf2_t *, vuint8mf2_t *, vbool16_t, vuint8mf2_t, vuint8mf2_t, vuint8mf2_t, vuint8mf2_t, vuint8mf2_t, vuint8mf2_t, const uint8_t *, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vlseg6e8_v)))
void vlseg6e8_v_u8mf4(vuint8mf4_t *, vuint8mf4_t *, vuint8mf4_t *, vuint8mf4_t *, vuint8mf4_t *, vuint8mf4_t *, const uint8_t *, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vlseg6e8_v_m)))
void vlseg6e8_v_u8mf4_m(vuint8mf4_t *, vuint8mf4_t *, vuint8mf4_t *, vuint8mf4_t *, vuint8mf4_t *, vuint8mf4_t *, vbool32_t, vuint8mf4_t, vuint8mf4_t, vuint8mf4_t, vuint8mf4_t, vuint8mf4_t, vuint8mf4_t, const uint8_t *, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vlseg6e8_v)))
void vlseg6e8_v_u8mf8(vuint8mf8_t *, vuint8mf8_t *, vuint8mf8_t *, vuint8mf8_t *, vuint8mf8_t *, vuint8mf8_t *, const uint8_t *, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vlseg6e8_v_m)))
void vlseg6e8_v_u8mf8_m(vuint8mf8_t *, vuint8mf8_t *, vuint8mf8_t *, vuint8mf8_t *, vuint8mf8_t *, vuint8mf8_t *, vbool64_t, vuint8mf8_t, vuint8mf8_t, vuint8mf8_t, vuint8mf8_t, vuint8mf8_t, vuint8mf8_t, const uint8_t *, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vlseg7e8_v)))
void vlseg7e8_v_i8m1(vint8m1_t *, vint8m1_t *, vint8m1_t *, vint8m1_t *, vint8m1_t *, vint8m1_t *, vint8m1_t *, const int8_t *, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vlseg7e8_v_m)))
void vlseg7e8_v_i8m1_m(vint8m1_t *, vint8m1_t *, vint8m1_t *, vint8m1_t *, vint8m1_t *, vint8m1_t *, vint8m1_t *, vbool8_t, vint8m1_t, vint8m1_t, vint8m1_t, vint8m1_t, vint8m1_t, vint8m1_t, vint8m1_t, const int8_t *, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vlseg7e8_v)))
void vlseg7e8_v_i8mf2(vint8mf2_t *, vint8mf2_t *, vint8mf2_t *, vint8mf2_t *, vint8mf2_t *, vint8mf2_t *, vint8mf2_t *, const int8_t *, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vlseg7e8_v_m)))
void vlseg7e8_v_i8mf2_m(vint8mf2_t *, vint8mf2_t *, vint8mf2_t *, vint8mf2_t *, vint8mf2_t *, vint8mf2_t *, vint8mf2_t *, vbool16_t, vint8mf2_t, vint8mf2_t, vint8mf2_t, vint8mf2_t, vint8mf2_t, vint8mf2_t, vint8mf2_t, const int8_t *, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vlseg7e8_v)))
void vlseg7e8_v_i8mf4(vint8mf4_t *, vint8mf4_t *, vint8mf4_t *, vint8mf4_t *, vint8mf4_t *, vint8mf4_t *, vint8mf4_t *, const int8_t *, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vlseg7e8_v_m)))
void vlseg7e8_v_i8mf4_m(vint8mf4_t *, vint8mf4_t *, vint8mf4_t *, vint8mf4_t *, vint8mf4_t *, vint8mf4_t *, vint8mf4_t *, vbool32_t, vint8mf4_t, vint8mf4_t, vint8mf4_t, vint8mf4_t, vint8mf4_t, vint8mf4_t, vint8mf4_t, const int8_t *, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vlseg7e8_v)))
void vlseg7e8_v_i8mf8(vint8mf8_t *, vint8mf8_t *, vint8mf8_t *, vint8mf8_t *, vint8mf8_t *, vint8mf8_t *, vint8mf8_t *, const int8_t *, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vlseg7e8_v_m)))
void vlseg7e8_v_i8mf8_m(vint8mf8_t *, vint8mf8_t *, vint8mf8_t *, vint8mf8_t *, vint8mf8_t *, vint8mf8_t *, vint8mf8_t *, vbool64_t, vint8mf8_t, vint8mf8_t, vint8mf8_t, vint8mf8_t, vint8mf8_t, vint8mf8_t, vint8mf8_t, const int8_t *, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vlseg7e8_v)))
void vlseg7e8_v_u8m1(vuint8m1_t *, vuint8m1_t *, vuint8m1_t *, vuint8m1_t *, vuint8m1_t *, vuint8m1_t *, vuint8m1_t *, const uint8_t *, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vlseg7e8_v_m)))
void vlseg7e8_v_u8m1_m(vuint8m1_t *, vuint8m1_t *, vuint8m1_t *, vuint8m1_t *, vuint8m1_t *, vuint8m1_t *, vuint8m1_t *, vbool8_t, vuint8m1_t, vuint8m1_t, vuint8m1_t, vuint8m1_t, vuint8m1_t, vuint8m1_t, vuint8m1_t, const uint8_t *, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vlseg7e8_v)))
void vlseg7e8_v_u8mf2(vuint8mf2_t *, vuint8mf2_t *, vuint8mf2_t *, vuint8mf2_t *, vuint8mf2_t *, vuint8mf2_t *, vuint8mf2_t *, const uint8_t *, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vlseg7e8_v_m)))
void vlseg7e8_v_u8mf2_m(vuint8mf2_t *, vuint8mf2_t *, vuint8mf2_t *, vuint8mf2_t *, vuint8mf2_t *, vuint8mf2_t *, vuint8mf2_t *, vbool16_t, vuint8mf2_t, vuint8mf2_t, vuint8mf2_t, vuint8mf2_t, vuint8mf2_t, vuint8mf2_t, vuint8mf2_t, const uint8_t *, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vlseg7e8_v)))
void vlseg7e8_v_u8mf4(vuint8mf4_t *, vuint8mf4_t *, vuint8mf4_t *, vuint8mf4_t *, vuint8mf4_t *, vuint8mf4_t *, vuint8mf4_t *, const uint8_t *, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vlseg7e8_v_m)))
void vlseg7e8_v_u8mf4_m(vuint8mf4_t *, vuint8mf4_t *, vuint8mf4_t *, vuint8mf4_t *, vuint8mf4_t *, vuint8mf4_t *, vuint8mf4_t *, vbool32_t, vuint8mf4_t, vuint8mf4_t, vuint8mf4_t, vuint8mf4_t, vuint8mf4_t, vuint8mf4_t, vuint8mf4_t, const uint8_t *, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vlseg7e8_v)))
void vlseg7e8_v_u8mf8(vuint8mf8_t *, vuint8mf8_t *, vuint8mf8_t *, vuint8mf8_t *, vuint8mf8_t *, vuint8mf8_t *, vuint8mf8_t *, const uint8_t *, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vlseg7e8_v_m)))
void vlseg7e8_v_u8mf8_m(vuint8mf8_t *, vuint8mf8_t *, vuint8mf8_t *, vuint8mf8_t *, vuint8mf8_t *, vuint8mf8_t *, vuint8mf8_t *, vbool64_t, vuint8mf8_t, vuint8mf8_t, vuint8mf8_t, vuint8mf8_t, vuint8mf8_t, vuint8mf8_t, vuint8mf8_t, const uint8_t *, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vlseg8e8_v)))
void vlseg8e8_v_i8m1(vint8m1_t *, vint8m1_t *, vint8m1_t *, vint8m1_t *, vint8m1_t *, vint8m1_t *, vint8m1_t *, vint8m1_t *, const int8_t *, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vlseg8e8_v_m)))
void vlseg8e8_v_i8m1_m(vint8m1_t *, vint8m1_t *, vint8m1_t *, vint8m1_t *, vint8m1_t *, vint8m1_t *, vint8m1_t *, vint8m1_t *, vbool8_t, vint8m1_t, vint8m1_t, vint8m1_t, vint8m1_t, vint8m1_t, vint8m1_t, vint8m1_t, vint8m1_t, const int8_t *, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vlseg8e8_v)))
void vlseg8e8_v_i8mf2(vint8mf2_t *, vint8mf2_t *, vint8mf2_t *, vint8mf2_t *, vint8mf2_t *, vint8mf2_t *, vint8mf2_t *, vint8mf2_t *, const int8_t *, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vlseg8e8_v_m)))
void vlseg8e8_v_i8mf2_m(vint8mf2_t *, vint8mf2_t *, vint8mf2_t *, vint8mf2_t *, vint8mf2_t *, vint8mf2_t *, vint8mf2_t *, vint8mf2_t *, vbool16_t, vint8mf2_t, vint8mf2_t, vint8mf2_t, vint8mf2_t, vint8mf2_t, vint8mf2_t, vint8mf2_t, vint8mf2_t, const int8_t *, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vlseg8e8_v)))
void vlseg8e8_v_i8mf4(vint8mf4_t *, vint8mf4_t *, vint8mf4_t *, vint8mf4_t *, vint8mf4_t *, vint8mf4_t *, vint8mf4_t *, vint8mf4_t *, const int8_t *, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vlseg8e8_v_m)))
void vlseg8e8_v_i8mf4_m(vint8mf4_t *, vint8mf4_t *, vint8mf4_t *, vint8mf4_t *, vint8mf4_t *, vint8mf4_t *, vint8mf4_t *, vint8mf4_t *, vbool32_t, vint8mf4_t, vint8mf4_t, vint8mf4_t, vint8mf4_t, vint8mf4_t, vint8mf4_t, vint8mf4_t, vint8mf4_t, const int8_t *, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vlseg8e8_v)))
void vlseg8e8_v_i8mf8(vint8mf8_t *, vint8mf8_t *, vint8mf8_t *, vint8mf8_t *, vint8mf8_t *, vint8mf8_t *, vint8mf8_t *, vint8mf8_t *, const int8_t *, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vlseg8e8_v_m)))
void vlseg8e8_v_i8mf8_m(vint8mf8_t *, vint8mf8_t *, vint8mf8_t *, vint8mf8_t *, vint8mf8_t *, vint8mf8_t *, vint8mf8_t *, vint8mf8_t *, vbool64_t, vint8mf8_t, vint8mf8_t, vint8mf8_t, vint8mf8_t, vint8mf8_t, vint8mf8_t, vint8mf8_t, vint8mf8_t, const int8_t *, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vlseg8e8_v)))
void vlseg8e8_v_u8m1(vuint8m1_t *, vuint8m1_t *, vuint8m1_t *, vuint8m1_t *, vuint8m1_t *, vuint8m1_t *, vuint8m1_t *, vuint8m1_t *, const uint8_t *, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vlseg8e8_v_m)))
void vlseg8e8_v_u8m1_m(vuint8m1_t *, vuint8m1_t *, vuint8m1_t *, vuint8m1_t *, vuint8m1_t *, vuint8m1_t *, vuint8m1_t *, vuint8m1_t *, vbool8_t, vuint8m1_t, vuint8m1_t, vuint8m1_t, vuint8m1_t, vuint8m1_t, vuint8m1_t, vuint8m1_t, vuint8m1_t, const uint8_t *, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vlseg8e8_v)))
void vlseg8e8_v_u8mf2(vuint8mf2_t *, vuint8mf2_t *, vuint8mf2_t *, vuint8mf2_t *, vuint8mf2_t *, vuint8mf2_t *, vuint8mf2_t *, vuint8mf2_t *, const uint8_t *, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vlseg8e8_v_m)))
void vlseg8e8_v_u8mf2_m(vuint8mf2_t *, vuint8mf2_t *, vuint8mf2_t *, vuint8mf2_t *, vuint8mf2_t *, vuint8mf2_t *, vuint8mf2_t *, vuint8mf2_t *, vbool16_t, vuint8mf2_t, vuint8mf2_t, vuint8mf2_t, vuint8mf2_t, vuint8mf2_t, vuint8mf2_t, vuint8mf2_t, vuint8mf2_t, const uint8_t *, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vlseg8e8_v)))
void vlseg8e8_v_u8mf4(vuint8mf4_t *, vuint8mf4_t *, vuint8mf4_t *, vuint8mf4_t *, vuint8mf4_t *, vuint8mf4_t *, vuint8mf4_t *, vuint8mf4_t *, const uint8_t *, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vlseg8e8_v_m)))
void vlseg8e8_v_u8mf4_m(vuint8mf4_t *, vuint8mf4_t *, vuint8mf4_t *, vuint8mf4_t *, vuint8mf4_t *, vuint8mf4_t *, vuint8mf4_t *, vuint8mf4_t *, vbool32_t, vuint8mf4_t, vuint8mf4_t, vuint8mf4_t, vuint8mf4_t, vuint8mf4_t, vuint8mf4_t, vuint8mf4_t, vuint8mf4_t, const uint8_t *, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vlseg8e8_v)))
void vlseg8e8_v_u8mf8(vuint8mf8_t *, vuint8mf8_t *, vuint8mf8_t *, vuint8mf8_t *, vuint8mf8_t *, vuint8mf8_t *, vuint8mf8_t *, vuint8mf8_t *, const uint8_t *, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vlseg8e8_v_m)))
void vlseg8e8_v_u8mf8_m(vuint8mf8_t *, vuint8mf8_t *, vuint8mf8_t *, vuint8mf8_t *, vuint8mf8_t *, vuint8mf8_t *, vuint8mf8_t *, vuint8mf8_t *, vbool64_t, vuint8mf8_t, vuint8mf8_t, vuint8mf8_t, vuint8mf8_t, vuint8mf8_t, vuint8mf8_t, vuint8mf8_t, vuint8mf8_t, const uint8_t *, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vlseg2e16_v)))
void vlseg2e16_v_i16m1(vint16m1_t *, vint16m1_t *, const int16_t *, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vlseg2e16_v_m)))
void vlseg2e16_v_i16m1_m(vint16m1_t *, vint16m1_t *, vbool16_t, vint16m1_t, vint16m1_t, const int16_t *, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vlseg2e16_v)))
void vlseg2e16_v_i16m2(vint16m2_t *, vint16m2_t *, const int16_t *, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vlseg2e16_v_m)))
void vlseg2e16_v_i16m2_m(vint16m2_t *, vint16m2_t *, vbool8_t, vint16m2_t, vint16m2_t, const int16_t *, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vlseg2e16_v)))
void vlseg2e16_v_i16m4(vint16m4_t *, vint16m4_t *, const int16_t *, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vlseg2e16_v_m)))
void vlseg2e16_v_i16m4_m(vint16m4_t *, vint16m4_t *, vbool4_t, vint16m4_t, vint16m4_t, const int16_t *, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vlseg2e16_v)))
void vlseg2e16_v_i16mf2(vint16mf2_t *, vint16mf2_t *, const int16_t *, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vlseg2e16_v_m)))
void vlseg2e16_v_i16mf2_m(vint16mf2_t *, vint16mf2_t *, vbool32_t, vint16mf2_t, vint16mf2_t, const int16_t *, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vlseg2e16_v)))
void vlseg2e16_v_i16mf4(vint16mf4_t *, vint16mf4_t *, const int16_t *, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vlseg2e16_v_m)))
void vlseg2e16_v_i16mf4_m(vint16mf4_t *, vint16mf4_t *, vbool64_t, vint16mf4_t, vint16mf4_t, const int16_t *, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vlseg2e16_v)))
void vlseg2e16_v_u16m1(vuint16m1_t *, vuint16m1_t *, const uint16_t *, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vlseg2e16_v_m)))
void vlseg2e16_v_u16m1_m(vuint16m1_t *, vuint16m1_t *, vbool16_t, vuint16m1_t, vuint16m1_t, const uint16_t *, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vlseg2e16_v)))
void vlseg2e16_v_u16m2(vuint16m2_t *, vuint16m2_t *, const uint16_t *, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vlseg2e16_v_m)))
void vlseg2e16_v_u16m2_m(vuint16m2_t *, vuint16m2_t *, vbool8_t, vuint16m2_t, vuint16m2_t, const uint16_t *, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vlseg2e16_v)))
void vlseg2e16_v_u16m4(vuint16m4_t *, vuint16m4_t *, const uint16_t *, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vlseg2e16_v_m)))
void vlseg2e16_v_u16m4_m(vuint16m4_t *, vuint16m4_t *, vbool4_t, vuint16m4_t, vuint16m4_t, const uint16_t *, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vlseg2e16_v)))
void vlseg2e16_v_u16mf2(vuint16mf2_t *, vuint16mf2_t *, const uint16_t *, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vlseg2e16_v_m)))
void vlseg2e16_v_u16mf2_m(vuint16mf2_t *, vuint16mf2_t *, vbool32_t, vuint16mf2_t, vuint16mf2_t, const uint16_t *, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vlseg2e16_v)))
void vlseg2e16_v_u16mf4(vuint16mf4_t *, vuint16mf4_t *, const uint16_t *, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vlseg2e16_v_m)))
void vlseg2e16_v_u16mf4_m(vuint16mf4_t *, vuint16mf4_t *, vbool64_t, vuint16mf4_t, vuint16mf4_t, const uint16_t *, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vlseg3e16_v)))
void vlseg3e16_v_i16m1(vint16m1_t *, vint16m1_t *, vint16m1_t *, const int16_t *, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vlseg3e16_v_m)))
void vlseg3e16_v_i16m1_m(vint16m1_t *, vint16m1_t *, vint16m1_t *, vbool16_t, vint16m1_t, vint16m1_t, vint16m1_t, const int16_t *, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vlseg3e16_v)))
void vlseg3e16_v_i16m2(vint16m2_t *, vint16m2_t *, vint16m2_t *, const int16_t *, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vlseg3e16_v_m)))
void vlseg3e16_v_i16m2_m(vint16m2_t *, vint16m2_t *, vint16m2_t *, vbool8_t, vint16m2_t, vint16m2_t, vint16m2_t, const int16_t *, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vlseg3e16_v)))
void vlseg3e16_v_i16mf2(vint16mf2_t *, vint16mf2_t *, vint16mf2_t *, const int16_t *, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vlseg3e16_v_m)))
void vlseg3e16_v_i16mf2_m(vint16mf2_t *, vint16mf2_t *, vint16mf2_t *, vbool32_t, vint16mf2_t, vint16mf2_t, vint16mf2_t, const int16_t *, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vlseg3e16_v)))
void vlseg3e16_v_i16mf4(vint16mf4_t *, vint16mf4_t *, vint16mf4_t *, const int16_t *, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vlseg3e16_v_m)))
void vlseg3e16_v_i16mf4_m(vint16mf4_t *, vint16mf4_t *, vint16mf4_t *, vbool64_t, vint16mf4_t, vint16mf4_t, vint16mf4_t, const int16_t *, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vlseg3e16_v)))
void vlseg3e16_v_u16m1(vuint16m1_t *, vuint16m1_t *, vuint16m1_t *, const uint16_t *, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vlseg3e16_v_m)))
void vlseg3e16_v_u16m1_m(vuint16m1_t *, vuint16m1_t *, vuint16m1_t *, vbool16_t, vuint16m1_t, vuint16m1_t, vuint16m1_t, const uint16_t *, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vlseg3e16_v)))
void vlseg3e16_v_u16m2(vuint16m2_t *, vuint16m2_t *, vuint16m2_t *, const uint16_t *, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vlseg3e16_v_m)))
void vlseg3e16_v_u16m2_m(vuint16m2_t *, vuint16m2_t *, vuint16m2_t *, vbool8_t, vuint16m2_t, vuint16m2_t, vuint16m2_t, const uint16_t *, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vlseg3e16_v)))
void vlseg3e16_v_u16mf2(vuint16mf2_t *, vuint16mf2_t *, vuint16mf2_t *, const uint16_t *, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vlseg3e16_v_m)))
void vlseg3e16_v_u16mf2_m(vuint16mf2_t *, vuint16mf2_t *, vuint16mf2_t *, vbool32_t, vuint16mf2_t, vuint16mf2_t, vuint16mf2_t, const uint16_t *, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vlseg3e16_v)))
void vlseg3e16_v_u16mf4(vuint16mf4_t *, vuint16mf4_t *, vuint16mf4_t *, const uint16_t *, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vlseg3e16_v_m)))
void vlseg3e16_v_u16mf4_m(vuint16mf4_t *, vuint16mf4_t *, vuint16mf4_t *, vbool64_t, vuint16mf4_t, vuint16mf4_t, vuint16mf4_t, const uint16_t *, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vlseg4e16_v)))
void vlseg4e16_v_i16m1(vint16m1_t *, vint16m1_t *, vint16m1_t *, vint16m1_t *, const int16_t *, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vlseg4e16_v_m)))
void vlseg4e16_v_i16m1_m(vint16m1_t *, vint16m1_t *, vint16m1_t *, vint16m1_t *, vbool16_t, vint16m1_t, vint16m1_t, vint16m1_t, vint16m1_t, const int16_t *, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vlseg4e16_v)))
void vlseg4e16_v_i16m2(vint16m2_t *, vint16m2_t *, vint16m2_t *, vint16m2_t *, const int16_t *, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vlseg4e16_v_m)))
void vlseg4e16_v_i16m2_m(vint16m2_t *, vint16m2_t *, vint16m2_t *, vint16m2_t *, vbool8_t, vint16m2_t, vint16m2_t, vint16m2_t, vint16m2_t, const int16_t *, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vlseg4e16_v)))
void vlseg4e16_v_i16mf2(vint16mf2_t *, vint16mf2_t *, vint16mf2_t *, vint16mf2_t *, const int16_t *, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vlseg4e16_v_m)))
void vlseg4e16_v_i16mf2_m(vint16mf2_t *, vint16mf2_t *, vint16mf2_t *, vint16mf2_t *, vbool32_t, vint16mf2_t, vint16mf2_t, vint16mf2_t, vint16mf2_t, const int16_t *, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vlseg4e16_v)))
void vlseg4e16_v_i16mf4(vint16mf4_t *, vint16mf4_t *, vint16mf4_t *, vint16mf4_t *, const int16_t *, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vlseg4e16_v_m)))
void vlseg4e16_v_i16mf4_m(vint16mf4_t *, vint16mf4_t *, vint16mf4_t *, vint16mf4_t *, vbool64_t, vint16mf4_t, vint16mf4_t, vint16mf4_t, vint16mf4_t, const int16_t *, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vlseg4e16_v)))
void vlseg4e16_v_u16m1(vuint16m1_t *, vuint16m1_t *, vuint16m1_t *, vuint16m1_t *, const uint16_t *, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vlseg4e16_v_m)))
void vlseg4e16_v_u16m1_m(vuint16m1_t *, vuint16m1_t *, vuint16m1_t *, vuint16m1_t *, vbool16_t, vuint16m1_t, vuint16m1_t, vuint16m1_t, vuint16m1_t, const uint16_t *, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vlseg4e16_v)))
void vlseg4e16_v_u16m2(vuint16m2_t *, vuint16m2_t *, vuint16m2_t *, vuint16m2_t *, const uint16_t *, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vlseg4e16_v_m)))
void vlseg4e16_v_u16m2_m(vuint16m2_t *, vuint16m2_t *, vuint16m2_t *, vuint16m2_t *, vbool8_t, vuint16m2_t, vuint16m2_t, vuint16m2_t, vuint16m2_t, const uint16_t *, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vlseg4e16_v)))
void vlseg4e16_v_u16mf2(vuint16mf2_t *, vuint16mf2_t *, vuint16mf2_t *, vuint16mf2_t *, const uint16_t *, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vlseg4e16_v_m)))
void vlseg4e16_v_u16mf2_m(vuint16mf2_t *, vuint16mf2_t *, vuint16mf2_t *, vuint16mf2_t *, vbool32_t, vuint16mf2_t, vuint16mf2_t, vuint16mf2_t, vuint16mf2_t, const uint16_t *, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vlseg4e16_v)))
void vlseg4e16_v_u16mf4(vuint16mf4_t *, vuint16mf4_t *, vuint16mf4_t *, vuint16mf4_t *, const uint16_t *, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vlseg4e16_v_m)))
void vlseg4e16_v_u16mf4_m(vuint16mf4_t *, vuint16mf4_t *, vuint16mf4_t *, vuint16mf4_t *, vbool64_t, vuint16mf4_t, vuint16mf4_t, vuint16mf4_t, vuint16mf4_t, const uint16_t *, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vlseg5e16_v)))
void vlseg5e16_v_i16m1(vint16m1_t *, vint16m1_t *, vint16m1_t *, vint16m1_t *, vint16m1_t *, const int16_t *, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vlseg5e16_v_m)))
void vlseg5e16_v_i16m1_m(vint16m1_t *, vint16m1_t *, vint16m1_t *, vint16m1_t *, vint16m1_t *, vbool16_t, vint16m1_t, vint16m1_t, vint16m1_t, vint16m1_t, vint16m1_t, const int16_t *, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vlseg5e16_v)))
void vlseg5e16_v_i16mf2(vint16mf2_t *, vint16mf2_t *, vint16mf2_t *, vint16mf2_t *, vint16mf2_t *, const int16_t *, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vlseg5e16_v_m)))
void vlseg5e16_v_i16mf2_m(vint16mf2_t *, vint16mf2_t *, vint16mf2_t *, vint16mf2_t *, vint16mf2_t *, vbool32_t, vint16mf2_t, vint16mf2_t, vint16mf2_t, vint16mf2_t, vint16mf2_t, const int16_t *, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vlseg5e16_v)))
void vlseg5e16_v_i16mf4(vint16mf4_t *, vint16mf4_t *, vint16mf4_t *, vint16mf4_t *, vint16mf4_t *, const int16_t *, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vlseg5e16_v_m)))
void vlseg5e16_v_i16mf4_m(vint16mf4_t *, vint16mf4_t *, vint16mf4_t *, vint16mf4_t *, vint16mf4_t *, vbool64_t, vint16mf4_t, vint16mf4_t, vint16mf4_t, vint16mf4_t, vint16mf4_t, const int16_t *, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vlseg5e16_v)))
void vlseg5e16_v_u16m1(vuint16m1_t *, vuint16m1_t *, vuint16m1_t *, vuint16m1_t *, vuint16m1_t *, const uint16_t *, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vlseg5e16_v_m)))
void vlseg5e16_v_u16m1_m(vuint16m1_t *, vuint16m1_t *, vuint16m1_t *, vuint16m1_t *, vuint16m1_t *, vbool16_t, vuint16m1_t, vuint16m1_t, vuint16m1_t, vuint16m1_t, vuint16m1_t, const uint16_t *, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vlseg5e16_v)))
void vlseg5e16_v_u16mf2(vuint16mf2_t *, vuint16mf2_t *, vuint16mf2_t *, vuint16mf2_t *, vuint16mf2_t *, const uint16_t *, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vlseg5e16_v_m)))
void vlseg5e16_v_u16mf2_m(vuint16mf2_t *, vuint16mf2_t *, vuint16mf2_t *, vuint16mf2_t *, vuint16mf2_t *, vbool32_t, vuint16mf2_t, vuint16mf2_t, vuint16mf2_t, vuint16mf2_t, vuint16mf2_t, const uint16_t *, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vlseg5e16_v)))
void vlseg5e16_v_u16mf4(vuint16mf4_t *, vuint16mf4_t *, vuint16mf4_t *, vuint16mf4_t *, vuint16mf4_t *, const uint16_t *, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vlseg5e16_v_m)))
void vlseg5e16_v_u16mf4_m(vuint16mf4_t *, vuint16mf4_t *, vuint16mf4_t *, vuint16mf4_t *, vuint16mf4_t *, vbool64_t, vuint16mf4_t, vuint16mf4_t, vuint16mf4_t, vuint16mf4_t, vuint16mf4_t, const uint16_t *, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vlseg6e16_v)))
void vlseg6e16_v_i16m1(vint16m1_t *, vint16m1_t *, vint16m1_t *, vint16m1_t *, vint16m1_t *, vint16m1_t *, const int16_t *, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vlseg6e16_v_m)))
void vlseg6e16_v_i16m1_m(vint16m1_t *, vint16m1_t *, vint16m1_t *, vint16m1_t *, vint16m1_t *, vint16m1_t *, vbool16_t, vint16m1_t, vint16m1_t, vint16m1_t, vint16m1_t, vint16m1_t, vint16m1_t, const int16_t *, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vlseg6e16_v)))
void vlseg6e16_v_i16mf2(vint16mf2_t *, vint16mf2_t *, vint16mf2_t *, vint16mf2_t *, vint16mf2_t *, vint16mf2_t *, const int16_t *, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vlseg6e16_v_m)))
void vlseg6e16_v_i16mf2_m(vint16mf2_t *, vint16mf2_t *, vint16mf2_t *, vint16mf2_t *, vint16mf2_t *, vint16mf2_t *, vbool32_t, vint16mf2_t, vint16mf2_t, vint16mf2_t, vint16mf2_t, vint16mf2_t, vint16mf2_t, const int16_t *, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vlseg6e16_v)))
void vlseg6e16_v_i16mf4(vint16mf4_t *, vint16mf4_t *, vint16mf4_t *, vint16mf4_t *, vint16mf4_t *, vint16mf4_t *, const int16_t *, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vlseg6e16_v_m)))
void vlseg6e16_v_i16mf4_m(vint16mf4_t *, vint16mf4_t *, vint16mf4_t *, vint16mf4_t *, vint16mf4_t *, vint16mf4_t *, vbool64_t, vint16mf4_t, vint16mf4_t, vint16mf4_t, vint16mf4_t, vint16mf4_t, vint16mf4_t, const int16_t *, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vlseg6e16_v)))
void vlseg6e16_v_u16m1(vuint16m1_t *, vuint16m1_t *, vuint16m1_t *, vuint16m1_t *, vuint16m1_t *, vuint16m1_t *, const uint16_t *, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vlseg6e16_v_m)))
void vlseg6e16_v_u16m1_m(vuint16m1_t *, vuint16m1_t *, vuint16m1_t *, vuint16m1_t *, vuint16m1_t *, vuint16m1_t *, vbool16_t, vuint16m1_t, vuint16m1_t, vuint16m1_t, vuint16m1_t, vuint16m1_t, vuint16m1_t, const uint16_t *, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vlseg6e16_v)))
void vlseg6e16_v_u16mf2(vuint16mf2_t *, vuint16mf2_t *, vuint16mf2_t *, vuint16mf2_t *, vuint16mf2_t *, vuint16mf2_t *, const uint16_t *, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vlseg6e16_v_m)))
void vlseg6e16_v_u16mf2_m(vuint16mf2_t *, vuint16mf2_t *, vuint16mf2_t *, vuint16mf2_t *, vuint16mf2_t *, vuint16mf2_t *, vbool32_t, vuint16mf2_t, vuint16mf2_t, vuint16mf2_t, vuint16mf2_t, vuint16mf2_t, vuint16mf2_t, const uint16_t *, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vlseg6e16_v)))
void vlseg6e16_v_u16mf4(vuint16mf4_t *, vuint16mf4_t *, vuint16mf4_t *, vuint16mf4_t *, vuint16mf4_t *, vuint16mf4_t *, const uint16_t *, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vlseg6e16_v_m)))
void vlseg6e16_v_u16mf4_m(vuint16mf4_t *, vuint16mf4_t *, vuint16mf4_t *, vuint16mf4_t *, vuint16mf4_t *, vuint16mf4_t *, vbool64_t, vuint16mf4_t, vuint16mf4_t, vuint16mf4_t, vuint16mf4_t, vuint16mf4_t, vuint16mf4_t, const uint16_t *, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vlseg7e16_v)))
void vlseg7e16_v_i16m1(vint16m1_t *, vint16m1_t *, vint16m1_t *, vint16m1_t *, vint16m1_t *, vint16m1_t *, vint16m1_t *, const int16_t *, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vlseg7e16_v_m)))
void vlseg7e16_v_i16m1_m(vint16m1_t *, vint16m1_t *, vint16m1_t *, vint16m1_t *, vint16m1_t *, vint16m1_t *, vint16m1_t *, vbool16_t, vint16m1_t, vint16m1_t, vint16m1_t, vint16m1_t, vint16m1_t, vint16m1_t, vint16m1_t, const int16_t *, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vlseg7e16_v)))
void vlseg7e16_v_i16mf2(vint16mf2_t *, vint16mf2_t *, vint16mf2_t *, vint16mf2_t *, vint16mf2_t *, vint16mf2_t *, vint16mf2_t *, const int16_t *, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vlseg7e16_v_m)))
void vlseg7e16_v_i16mf2_m(vint16mf2_t *, vint16mf2_t *, vint16mf2_t *, vint16mf2_t *, vint16mf2_t *, vint16mf2_t *, vint16mf2_t *, vbool32_t, vint16mf2_t, vint16mf2_t, vint16mf2_t, vint16mf2_t, vint16mf2_t, vint16mf2_t, vint16mf2_t, const int16_t *, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vlseg7e16_v)))
void vlseg7e16_v_i16mf4(vint16mf4_t *, vint16mf4_t *, vint16mf4_t *, vint16mf4_t *, vint16mf4_t *, vint16mf4_t *, vint16mf4_t *, const int16_t *, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vlseg7e16_v_m)))
void vlseg7e16_v_i16mf4_m(vint16mf4_t *, vint16mf4_t *, vint16mf4_t *, vint16mf4_t *, vint16mf4_t *, vint16mf4_t *, vint16mf4_t *, vbool64_t, vint16mf4_t, vint16mf4_t, vint16mf4_t, vint16mf4_t, vint16mf4_t, vint16mf4_t, vint16mf4_t, const int16_t *, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vlseg7e16_v)))
void vlseg7e16_v_u16m1(vuint16m1_t *, vuint16m1_t *, vuint16m1_t *, vuint16m1_t *, vuint16m1_t *, vuint16m1_t *, vuint16m1_t *, const uint16_t *, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vlseg7e16_v_m)))
void vlseg7e16_v_u16m1_m(vuint16m1_t *, vuint16m1_t *, vuint16m1_t *, vuint16m1_t *, vuint16m1_t *, vuint16m1_t *, vuint16m1_t *, vbool16_t, vuint16m1_t, vuint16m1_t, vuint16m1_t, vuint16m1_t, vuint16m1_t, vuint16m1_t, vuint16m1_t, const uint16_t *, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vlseg7e16_v)))
void vlseg7e16_v_u16mf2(vuint16mf2_t *, vuint16mf2_t *, vuint16mf2_t *, vuint16mf2_t *, vuint16mf2_t *, vuint16mf2_t *, vuint16mf2_t *, const uint16_t *, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vlseg7e16_v_m)))
void vlseg7e16_v_u16mf2_m(vuint16mf2_t *, vuint16mf2_t *, vuint16mf2_t *, vuint16mf2_t *, vuint16mf2_t *, vuint16mf2_t *, vuint16mf2_t *, vbool32_t, vuint16mf2_t, vuint16mf2_t, vuint16mf2_t, vuint16mf2_t, vuint16mf2_t, vuint16mf2_t, vuint16mf2_t, const uint16_t *, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vlseg7e16_v)))
void vlseg7e16_v_u16mf4(vuint16mf4_t *, vuint16mf4_t *, vuint16mf4_t *, vuint16mf4_t *, vuint16mf4_t *, vuint16mf4_t *, vuint16mf4_t *, const uint16_t *, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vlseg7e16_v_m)))
void vlseg7e16_v_u16mf4_m(vuint16mf4_t *, vuint16mf4_t *, vuint16mf4_t *, vuint16mf4_t *, vuint16mf4_t *, vuint16mf4_t *, vuint16mf4_t *, vbool64_t, vuint16mf4_t, vuint16mf4_t, vuint16mf4_t, vuint16mf4_t, vuint16mf4_t, vuint16mf4_t, vuint16mf4_t, const uint16_t *, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vlseg8e16_v)))
void vlseg8e16_v_i16m1(vint16m1_t *, vint16m1_t *, vint16m1_t *, vint16m1_t *, vint16m1_t *, vint16m1_t *, vint16m1_t *, vint16m1_t *, const int16_t *, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vlseg8e16_v_m)))
void vlseg8e16_v_i16m1_m(vint16m1_t *, vint16m1_t *, vint16m1_t *, vint16m1_t *, vint16m1_t *, vint16m1_t *, vint16m1_t *, vint16m1_t *, vbool16_t, vint16m1_t, vint16m1_t, vint16m1_t, vint16m1_t, vint16m1_t, vint16m1_t, vint16m1_t, vint16m1_t, const int16_t *, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vlseg8e16_v)))
void vlseg8e16_v_i16mf2(vint16mf2_t *, vint16mf2_t *, vint16mf2_t *, vint16mf2_t *, vint16mf2_t *, vint16mf2_t *, vint16mf2_t *, vint16mf2_t *, const int16_t *, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vlseg8e16_v_m)))
void vlseg8e16_v_i16mf2_m(vint16mf2_t *, vint16mf2_t *, vint16mf2_t *, vint16mf2_t *, vint16mf2_t *, vint16mf2_t *, vint16mf2_t *, vint16mf2_t *, vbool32_t, vint16mf2_t, vint16mf2_t, vint16mf2_t, vint16mf2_t, vint16mf2_t, vint16mf2_t, vint16mf2_t, vint16mf2_t, const int16_t *, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vlseg8e16_v)))
void vlseg8e16_v_i16mf4(vint16mf4_t *, vint16mf4_t *, vint16mf4_t *, vint16mf4_t *, vint16mf4_t *, vint16mf4_t *, vint16mf4_t *, vint16mf4_t *, const int16_t *, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vlseg8e16_v_m)))
void vlseg8e16_v_i16mf4_m(vint16mf4_t *, vint16mf4_t *, vint16mf4_t *, vint16mf4_t *, vint16mf4_t *, vint16mf4_t *, vint16mf4_t *, vint16mf4_t *, vbool64_t, vint16mf4_t, vint16mf4_t, vint16mf4_t, vint16mf4_t, vint16mf4_t, vint16mf4_t, vint16mf4_t, vint16mf4_t, const int16_t *, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vlseg8e16_v)))
void vlseg8e16_v_u16m1(vuint16m1_t *, vuint16m1_t *, vuint16m1_t *, vuint16m1_t *, vuint16m1_t *, vuint16m1_t *, vuint16m1_t *, vuint16m1_t *, const uint16_t *, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vlseg8e16_v_m)))
void vlseg8e16_v_u16m1_m(vuint16m1_t *, vuint16m1_t *, vuint16m1_t *, vuint16m1_t *, vuint16m1_t *, vuint16m1_t *, vuint16m1_t *, vuint16m1_t *, vbool16_t, vuint16m1_t, vuint16m1_t, vuint16m1_t, vuint16m1_t, vuint16m1_t, vuint16m1_t, vuint16m1_t, vuint16m1_t, const uint16_t *, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vlseg8e16_v)))
void vlseg8e16_v_u16mf2(vuint16mf2_t *, vuint16mf2_t *, vuint16mf2_t *, vuint16mf2_t *, vuint16mf2_t *, vuint16mf2_t *, vuint16mf2_t *, vuint16mf2_t *, const uint16_t *, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vlseg8e16_v_m)))
void vlseg8e16_v_u16mf2_m(vuint16mf2_t *, vuint16mf2_t *, vuint16mf2_t *, vuint16mf2_t *, vuint16mf2_t *, vuint16mf2_t *, vuint16mf2_t *, vuint16mf2_t *, vbool32_t, vuint16mf2_t, vuint16mf2_t, vuint16mf2_t, vuint16mf2_t, vuint16mf2_t, vuint16mf2_t, vuint16mf2_t, vuint16mf2_t, const uint16_t *, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vlseg8e16_v)))
void vlseg8e16_v_u16mf4(vuint16mf4_t *, vuint16mf4_t *, vuint16mf4_t *, vuint16mf4_t *, vuint16mf4_t *, vuint16mf4_t *, vuint16mf4_t *, vuint16mf4_t *, const uint16_t *, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vlseg8e16_v_m)))
void vlseg8e16_v_u16mf4_m(vuint16mf4_t *, vuint16mf4_t *, vuint16mf4_t *, vuint16mf4_t *, vuint16mf4_t *, vuint16mf4_t *, vuint16mf4_t *, vuint16mf4_t *, vbool64_t, vuint16mf4_t, vuint16mf4_t, vuint16mf4_t, vuint16mf4_t, vuint16mf4_t, vuint16mf4_t, vuint16mf4_t, vuint16mf4_t, const uint16_t *, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vlseg2e32_v)))
void vlseg2e32_v_i32m1(vint32m1_t *, vint32m1_t *, const int32_t *, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vlseg2e32_v_m)))
void vlseg2e32_v_i32m1_m(vint32m1_t *, vint32m1_t *, vbool32_t, vint32m1_t, vint32m1_t, const int32_t *, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vlseg2e32_v)))
void vlseg2e32_v_i32m2(vint32m2_t *, vint32m2_t *, const int32_t *, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vlseg2e32_v_m)))
void vlseg2e32_v_i32m2_m(vint32m2_t *, vint32m2_t *, vbool16_t, vint32m2_t, vint32m2_t, const int32_t *, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vlseg2e32_v)))
void vlseg2e32_v_i32m4(vint32m4_t *, vint32m4_t *, const int32_t *, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vlseg2e32_v_m)))
void vlseg2e32_v_i32m4_m(vint32m4_t *, vint32m4_t *, vbool8_t, vint32m4_t, vint32m4_t, const int32_t *, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vlseg2e32_v)))
void vlseg2e32_v_i32mf2(vint32mf2_t *, vint32mf2_t *, const int32_t *, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vlseg2e32_v_m)))
void vlseg2e32_v_i32mf2_m(vint32mf2_t *, vint32mf2_t *, vbool64_t, vint32mf2_t, vint32mf2_t, const int32_t *, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vlseg2e32_v)))
void vlseg2e32_v_u32m1(vuint32m1_t *, vuint32m1_t *, const uint32_t *, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vlseg2e32_v_m)))
void vlseg2e32_v_u32m1_m(vuint32m1_t *, vuint32m1_t *, vbool32_t, vuint32m1_t, vuint32m1_t, const uint32_t *, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vlseg2e32_v)))
void vlseg2e32_v_u32m2(vuint32m2_t *, vuint32m2_t *, const uint32_t *, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vlseg2e32_v_m)))
void vlseg2e32_v_u32m2_m(vuint32m2_t *, vuint32m2_t *, vbool16_t, vuint32m2_t, vuint32m2_t, const uint32_t *, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vlseg2e32_v)))
void vlseg2e32_v_u32m4(vuint32m4_t *, vuint32m4_t *, const uint32_t *, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vlseg2e32_v_m)))
void vlseg2e32_v_u32m4_m(vuint32m4_t *, vuint32m4_t *, vbool8_t, vuint32m4_t, vuint32m4_t, const uint32_t *, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vlseg2e32_v)))
void vlseg2e32_v_u32mf2(vuint32mf2_t *, vuint32mf2_t *, const uint32_t *, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vlseg2e32_v_m)))
void vlseg2e32_v_u32mf2_m(vuint32mf2_t *, vuint32mf2_t *, vbool64_t, vuint32mf2_t, vuint32mf2_t, const uint32_t *, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vlseg3e32_v)))
void vlseg3e32_v_i32m1(vint32m1_t *, vint32m1_t *, vint32m1_t *, const int32_t *, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vlseg3e32_v_m)))
void vlseg3e32_v_i32m1_m(vint32m1_t *, vint32m1_t *, vint32m1_t *, vbool32_t, vint32m1_t, vint32m1_t, vint32m1_t, const int32_t *, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vlseg3e32_v)))
void vlseg3e32_v_i32m2(vint32m2_t *, vint32m2_t *, vint32m2_t *, const int32_t *, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vlseg3e32_v_m)))
void vlseg3e32_v_i32m2_m(vint32m2_t *, vint32m2_t *, vint32m2_t *, vbool16_t, vint32m2_t, vint32m2_t, vint32m2_t, const int32_t *, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vlseg3e32_v)))
void vlseg3e32_v_i32mf2(vint32mf2_t *, vint32mf2_t *, vint32mf2_t *, const int32_t *, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vlseg3e32_v_m)))
void vlseg3e32_v_i32mf2_m(vint32mf2_t *, vint32mf2_t *, vint32mf2_t *, vbool64_t, vint32mf2_t, vint32mf2_t, vint32mf2_t, const int32_t *, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vlseg3e32_v)))
void vlseg3e32_v_u32m1(vuint32m1_t *, vuint32m1_t *, vuint32m1_t *, const uint32_t *, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vlseg3e32_v_m)))
void vlseg3e32_v_u32m1_m(vuint32m1_t *, vuint32m1_t *, vuint32m1_t *, vbool32_t, vuint32m1_t, vuint32m1_t, vuint32m1_t, const uint32_t *, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vlseg3e32_v)))
void vlseg3e32_v_u32m2(vuint32m2_t *, vuint32m2_t *, vuint32m2_t *, const uint32_t *, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vlseg3e32_v_m)))
void vlseg3e32_v_u32m2_m(vuint32m2_t *, vuint32m2_t *, vuint32m2_t *, vbool16_t, vuint32m2_t, vuint32m2_t, vuint32m2_t, const uint32_t *, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vlseg3e32_v)))
void vlseg3e32_v_u32mf2(vuint32mf2_t *, vuint32mf2_t *, vuint32mf2_t *, const uint32_t *, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vlseg3e32_v_m)))
void vlseg3e32_v_u32mf2_m(vuint32mf2_t *, vuint32mf2_t *, vuint32mf2_t *, vbool64_t, vuint32mf2_t, vuint32mf2_t, vuint32mf2_t, const uint32_t *, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vlseg4e32_v)))
void vlseg4e32_v_i32m1(vint32m1_t *, vint32m1_t *, vint32m1_t *, vint32m1_t *, const int32_t *, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vlseg4e32_v_m)))
void vlseg4e32_v_i32m1_m(vint32m1_t *, vint32m1_t *, vint32m1_t *, vint32m1_t *, vbool32_t, vint32m1_t, vint32m1_t, vint32m1_t, vint32m1_t, const int32_t *, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vlseg4e32_v)))
void vlseg4e32_v_i32m2(vint32m2_t *, vint32m2_t *, vint32m2_t *, vint32m2_t *, const int32_t *, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vlseg4e32_v_m)))
void vlseg4e32_v_i32m2_m(vint32m2_t *, vint32m2_t *, vint32m2_t *, vint32m2_t *, vbool16_t, vint32m2_t, vint32m2_t, vint32m2_t, vint32m2_t, const int32_t *, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vlseg4e32_v)))
void vlseg4e32_v_i32mf2(vint32mf2_t *, vint32mf2_t *, vint32mf2_t *, vint32mf2_t *, const int32_t *, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vlseg4e32_v_m)))
void vlseg4e32_v_i32mf2_m(vint32mf2_t *, vint32mf2_t *, vint32mf2_t *, vint32mf2_t *, vbool64_t, vint32mf2_t, vint32mf2_t, vint32mf2_t, vint32mf2_t, const int32_t *, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vlseg4e32_v)))
void vlseg4e32_v_u32m1(vuint32m1_t *, vuint32m1_t *, vuint32m1_t *, vuint32m1_t *, const uint32_t *, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vlseg4e32_v_m)))
void vlseg4e32_v_u32m1_m(vuint32m1_t *, vuint32m1_t *, vuint32m1_t *, vuint32m1_t *, vbool32_t, vuint32m1_t, vuint32m1_t, vuint32m1_t, vuint32m1_t, const uint32_t *, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vlseg4e32_v)))
void vlseg4e32_v_u32m2(vuint32m2_t *, vuint32m2_t *, vuint32m2_t *, vuint32m2_t *, const uint32_t *, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vlseg4e32_v_m)))
void vlseg4e32_v_u32m2_m(vuint32m2_t *, vuint32m2_t *, vuint32m2_t *, vuint32m2_t *, vbool16_t, vuint32m2_t, vuint32m2_t, vuint32m2_t, vuint32m2_t, const uint32_t *, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vlseg4e32_v)))
void vlseg4e32_v_u32mf2(vuint32mf2_t *, vuint32mf2_t *, vuint32mf2_t *, vuint32mf2_t *, const uint32_t *, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vlseg4e32_v_m)))
void vlseg4e32_v_u32mf2_m(vuint32mf2_t *, vuint32mf2_t *, vuint32mf2_t *, vuint32mf2_t *, vbool64_t, vuint32mf2_t, vuint32mf2_t, vuint32mf2_t, vuint32mf2_t, const uint32_t *, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vlseg5e32_v)))
void vlseg5e32_v_i32m1(vint32m1_t *, vint32m1_t *, vint32m1_t *, vint32m1_t *, vint32m1_t *, const int32_t *, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vlseg5e32_v_m)))
void vlseg5e32_v_i32m1_m(vint32m1_t *, vint32m1_t *, vint32m1_t *, vint32m1_t *, vint32m1_t *, vbool32_t, vint32m1_t, vint32m1_t, vint32m1_t, vint32m1_t, vint32m1_t, const int32_t *, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vlseg5e32_v)))
void vlseg5e32_v_i32mf2(vint32mf2_t *, vint32mf2_t *, vint32mf2_t *, vint32mf2_t *, vint32mf2_t *, const int32_t *, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vlseg5e32_v_m)))
void vlseg5e32_v_i32mf2_m(vint32mf2_t *, vint32mf2_t *, vint32mf2_t *, vint32mf2_t *, vint32mf2_t *, vbool64_t, vint32mf2_t, vint32mf2_t, vint32mf2_t, vint32mf2_t, vint32mf2_t, const int32_t *, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vlseg5e32_v)))
void vlseg5e32_v_u32m1(vuint32m1_t *, vuint32m1_t *, vuint32m1_t *, vuint32m1_t *, vuint32m1_t *, const uint32_t *, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vlseg5e32_v_m)))
void vlseg5e32_v_u32m1_m(vuint32m1_t *, vuint32m1_t *, vuint32m1_t *, vuint32m1_t *, vuint32m1_t *, vbool32_t, vuint32m1_t, vuint32m1_t, vuint32m1_t, vuint32m1_t, vuint32m1_t, const uint32_t *, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vlseg5e32_v)))
void vlseg5e32_v_u32mf2(vuint32mf2_t *, vuint32mf2_t *, vuint32mf2_t *, vuint32mf2_t *, vuint32mf2_t *, const uint32_t *, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vlseg5e32_v_m)))
void vlseg5e32_v_u32mf2_m(vuint32mf2_t *, vuint32mf2_t *, vuint32mf2_t *, vuint32mf2_t *, vuint32mf2_t *, vbool64_t, vuint32mf2_t, vuint32mf2_t, vuint32mf2_t, vuint32mf2_t, vuint32mf2_t, const uint32_t *, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vlseg6e32_v)))
void vlseg6e32_v_i32m1(vint32m1_t *, vint32m1_t *, vint32m1_t *, vint32m1_t *, vint32m1_t *, vint32m1_t *, const int32_t *, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vlseg6e32_v_m)))
void vlseg6e32_v_i32m1_m(vint32m1_t *, vint32m1_t *, vint32m1_t *, vint32m1_t *, vint32m1_t *, vint32m1_t *, vbool32_t, vint32m1_t, vint32m1_t, vint32m1_t, vint32m1_t, vint32m1_t, vint32m1_t, const int32_t *, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vlseg6e32_v)))
void vlseg6e32_v_i32mf2(vint32mf2_t *, vint32mf2_t *, vint32mf2_t *, vint32mf2_t *, vint32mf2_t *, vint32mf2_t *, const int32_t *, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vlseg6e32_v_m)))
void vlseg6e32_v_i32mf2_m(vint32mf2_t *, vint32mf2_t *, vint32mf2_t *, vint32mf2_t *, vint32mf2_t *, vint32mf2_t *, vbool64_t, vint32mf2_t, vint32mf2_t, vint32mf2_t, vint32mf2_t, vint32mf2_t, vint32mf2_t, const int32_t *, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vlseg6e32_v)))
void vlseg6e32_v_u32m1(vuint32m1_t *, vuint32m1_t *, vuint32m1_t *, vuint32m1_t *, vuint32m1_t *, vuint32m1_t *, const uint32_t *, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vlseg6e32_v_m)))
void vlseg6e32_v_u32m1_m(vuint32m1_t *, vuint32m1_t *, vuint32m1_t *, vuint32m1_t *, vuint32m1_t *, vuint32m1_t *, vbool32_t, vuint32m1_t, vuint32m1_t, vuint32m1_t, vuint32m1_t, vuint32m1_t, vuint32m1_t, const uint32_t *, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vlseg6e32_v)))
void vlseg6e32_v_u32mf2(vuint32mf2_t *, vuint32mf2_t *, vuint32mf2_t *, vuint32mf2_t *, vuint32mf2_t *, vuint32mf2_t *, const uint32_t *, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vlseg6e32_v_m)))
void vlseg6e32_v_u32mf2_m(vuint32mf2_t *, vuint32mf2_t *, vuint32mf2_t *, vuint32mf2_t *, vuint32mf2_t *, vuint32mf2_t *, vbool64_t, vuint32mf2_t, vuint32mf2_t, vuint32mf2_t, vuint32mf2_t, vuint32mf2_t, vuint32mf2_t, const uint32_t *, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vlseg7e32_v)))
void vlseg7e32_v_i32m1(vint32m1_t *, vint32m1_t *, vint32m1_t *, vint32m1_t *, vint32m1_t *, vint32m1_t *, vint32m1_t *, const int32_t *, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vlseg7e32_v_m)))
void vlseg7e32_v_i32m1_m(vint32m1_t *, vint32m1_t *, vint32m1_t *, vint32m1_t *, vint32m1_t *, vint32m1_t *, vint32m1_t *, vbool32_t, vint32m1_t, vint32m1_t, vint32m1_t, vint32m1_t, vint32m1_t, vint32m1_t, vint32m1_t, const int32_t *, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vlseg7e32_v)))
void vlseg7e32_v_i32mf2(vint32mf2_t *, vint32mf2_t *, vint32mf2_t *, vint32mf2_t *, vint32mf2_t *, vint32mf2_t *, vint32mf2_t *, const int32_t *, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vlseg7e32_v_m)))
void vlseg7e32_v_i32mf2_m(vint32mf2_t *, vint32mf2_t *, vint32mf2_t *, vint32mf2_t *, vint32mf2_t *, vint32mf2_t *, vint32mf2_t *, vbool64_t, vint32mf2_t, vint32mf2_t, vint32mf2_t, vint32mf2_t, vint32mf2_t, vint32mf2_t, vint32mf2_t, const int32_t *, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vlseg7e32_v)))
void vlseg7e32_v_u32m1(vuint32m1_t *, vuint32m1_t *, vuint32m1_t *, vuint32m1_t *, vuint32m1_t *, vuint32m1_t *, vuint32m1_t *, const uint32_t *, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vlseg7e32_v_m)))
void vlseg7e32_v_u32m1_m(vuint32m1_t *, vuint32m1_t *, vuint32m1_t *, vuint32m1_t *, vuint32m1_t *, vuint32m1_t *, vuint32m1_t *, vbool32_t, vuint32m1_t, vuint32m1_t, vuint32m1_t, vuint32m1_t, vuint32m1_t, vuint32m1_t, vuint32m1_t, const uint32_t *, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vlseg7e32_v)))
void vlseg7e32_v_u32mf2(vuint32mf2_t *, vuint32mf2_t *, vuint32mf2_t *, vuint32mf2_t *, vuint32mf2_t *, vuint32mf2_t *, vuint32mf2_t *, const uint32_t *, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vlseg7e32_v_m)))
void vlseg7e32_v_u32mf2_m(vuint32mf2_t *, vuint32mf2_t *, vuint32mf2_t *, vuint32mf2_t *, vuint32mf2_t *, vuint32mf2_t *, vuint32mf2_t *, vbool64_t, vuint32mf2_t, vuint32mf2_t, vuint32mf2_t, vuint32mf2_t, vuint32mf2_t, vuint32mf2_t, vuint32mf2_t, const uint32_t *, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vlseg8e32_v)))
void vlseg8e32_v_i32m1(vint32m1_t *, vint32m1_t *, vint32m1_t *, vint32m1_t *, vint32m1_t *, vint32m1_t *, vint32m1_t *, vint32m1_t *, const int32_t *, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vlseg8e32_v_m)))
void vlseg8e32_v_i32m1_m(vint32m1_t *, vint32m1_t *, vint32m1_t *, vint32m1_t *, vint32m1_t *, vint32m1_t *, vint32m1_t *, vint32m1_t *, vbool32_t, vint32m1_t, vint32m1_t, vint32m1_t, vint32m1_t, vint32m1_t, vint32m1_t, vint32m1_t, vint32m1_t, const int32_t *, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vlseg8e32_v)))
void vlseg8e32_v_i32mf2(vint32mf2_t *, vint32mf2_t *, vint32mf2_t *, vint32mf2_t *, vint32mf2_t *, vint32mf2_t *, vint32mf2_t *, vint32mf2_t *, const int32_t *, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vlseg8e32_v_m)))
void vlseg8e32_v_i32mf2_m(vint32mf2_t *, vint32mf2_t *, vint32mf2_t *, vint32mf2_t *, vint32mf2_t *, vint32mf2_t *, vint32mf2_t *, vint32mf2_t *, vbool64_t, vint32mf2_t, vint32mf2_t, vint32mf2_t, vint32mf2_t, vint32mf2_t, vint32mf2_t, vint32mf2_t, vint32mf2_t, const int32_t *, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vlseg8e32_v)))
void vlseg8e32_v_u32m1(vuint32m1_t *, vuint32m1_t *, vuint32m1_t *, vuint32m1_t *, vuint32m1_t *, vuint32m1_t *, vuint32m1_t *, vuint32m1_t *, const uint32_t *, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vlseg8e32_v_m)))
void vlseg8e32_v_u32m1_m(vuint32m1_t *, vuint32m1_t *, vuint32m1_t *, vuint32m1_t *, vuint32m1_t *, vuint32m1_t *, vuint32m1_t *, vuint32m1_t *, vbool32_t, vuint32m1_t, vuint32m1_t, vuint32m1_t, vuint32m1_t, vuint32m1_t, vuint32m1_t, vuint32m1_t, vuint32m1_t, const uint32_t *, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vlseg8e32_v)))
void vlseg8e32_v_u32mf2(vuint32mf2_t *, vuint32mf2_t *, vuint32mf2_t *, vuint32mf2_t *, vuint32mf2_t *, vuint32mf2_t *, vuint32mf2_t *, vuint32mf2_t *, const uint32_t *, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vlseg8e32_v_m)))
void vlseg8e32_v_u32mf2_m(vuint32mf2_t *, vuint32mf2_t *, vuint32mf2_t *, vuint32mf2_t *, vuint32mf2_t *, vuint32mf2_t *, vuint32mf2_t *, vuint32mf2_t *, vbool64_t, vuint32mf2_t, vuint32mf2_t, vuint32mf2_t, vuint32mf2_t, vuint32mf2_t, vuint32mf2_t, vuint32mf2_t, vuint32mf2_t, const uint32_t *, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vlseg3e8ff_v)))
void vlseg3e8ff_v_i8m1(vint8m1_t *, vint8m1_t *, vint8m1_t *, const int8_t *, size_t *, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vlseg3e8ff_v_m)))
void vlseg3e8ff_v_i8m1_m(vint8m1_t *, vint8m1_t *, vint8m1_t *, vbool8_t, vint8m1_t, vint8m1_t, vint8m1_t, const int8_t *, size_t *, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vlseg3e8ff_v)))
void vlseg3e8ff_v_i8m2(vint8m2_t *, vint8m2_t *, vint8m2_t *, const int8_t *, size_t *, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vlseg3e8ff_v_m)))
void vlseg3e8ff_v_i8m2_m(vint8m2_t *, vint8m2_t *, vint8m2_t *, vbool4_t, vint8m2_t, vint8m2_t, vint8m2_t, const int8_t *, size_t *, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vlseg3e8ff_v)))
void vlseg3e8ff_v_i8mf2(vint8mf2_t *, vint8mf2_t *, vint8mf2_t *, const int8_t *, size_t *, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vlseg3e8ff_v_m)))
void vlseg3e8ff_v_i8mf2_m(vint8mf2_t *, vint8mf2_t *, vint8mf2_t *, vbool16_t, vint8mf2_t, vint8mf2_t, vint8mf2_t, const int8_t *, size_t *, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vlseg3e8ff_v)))
void vlseg3e8ff_v_i8mf4(vint8mf4_t *, vint8mf4_t *, vint8mf4_t *, const int8_t *, size_t *, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vlseg3e8ff_v_m)))
void vlseg3e8ff_v_i8mf4_m(vint8mf4_t *, vint8mf4_t *, vint8mf4_t *, vbool32_t, vint8mf4_t, vint8mf4_t, vint8mf4_t, const int8_t *, size_t *, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vlseg3e8ff_v)))
void vlseg3e8ff_v_i8mf8(vint8mf8_t *, vint8mf8_t *, vint8mf8_t *, const int8_t *, size_t *, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vlseg3e8ff_v_m)))
void vlseg3e8ff_v_i8mf8_m(vint8mf8_t *, vint8mf8_t *, vint8mf8_t *, vbool64_t, vint8mf8_t, vint8mf8_t, vint8mf8_t, const int8_t *, size_t *, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vlseg3e8ff_v)))
void vlseg3e8ff_v_u8m1(vuint8m1_t *, vuint8m1_t *, vuint8m1_t *, const uint8_t *, size_t *, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vlseg3e8ff_v_m)))
void vlseg3e8ff_v_u8m1_m(vuint8m1_t *, vuint8m1_t *, vuint8m1_t *, vbool8_t, vuint8m1_t, vuint8m1_t, vuint8m1_t, const uint8_t *, size_t *, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vlseg3e8ff_v)))
void vlseg3e8ff_v_u8m2(vuint8m2_t *, vuint8m2_t *, vuint8m2_t *, const uint8_t *, size_t *, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vlseg3e8ff_v_m)))
void vlseg3e8ff_v_u8m2_m(vuint8m2_t *, vuint8m2_t *, vuint8m2_t *, vbool4_t, vuint8m2_t, vuint8m2_t, vuint8m2_t, const uint8_t *, size_t *, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vlseg3e8ff_v)))
void vlseg3e8ff_v_u8mf2(vuint8mf2_t *, vuint8mf2_t *, vuint8mf2_t *, const uint8_t *, size_t *, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vlseg3e8ff_v_m)))
void vlseg3e8ff_v_u8mf2_m(vuint8mf2_t *, vuint8mf2_t *, vuint8mf2_t *, vbool16_t, vuint8mf2_t, vuint8mf2_t, vuint8mf2_t, const uint8_t *, size_t *, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vlseg3e8ff_v)))
void vlseg3e8ff_v_u8mf4(vuint8mf4_t *, vuint8mf4_t *, vuint8mf4_t *, const uint8_t *, size_t *, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vlseg3e8ff_v_m)))
void vlseg3e8ff_v_u8mf4_m(vuint8mf4_t *, vuint8mf4_t *, vuint8mf4_t *, vbool32_t, vuint8mf4_t, vuint8mf4_t, vuint8mf4_t, const uint8_t *, size_t *, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vlseg3e8ff_v)))
void vlseg3e8ff_v_u8mf8(vuint8mf8_t *, vuint8mf8_t *, vuint8mf8_t *, const uint8_t *, size_t *, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vlseg3e8ff_v_m)))
void vlseg3e8ff_v_u8mf8_m(vuint8mf8_t *, vuint8mf8_t *, vuint8mf8_t *, vbool64_t, vuint8mf8_t, vuint8mf8_t, vuint8mf8_t, const uint8_t *, size_t *, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vlseg4e8ff_v)))
void vlseg4e8ff_v_i8m1(vint8m1_t *, vint8m1_t *, vint8m1_t *, vint8m1_t *, const int8_t *, size_t *, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vlseg4e8ff_v_m)))
void vlseg4e8ff_v_i8m1_m(vint8m1_t *, vint8m1_t *, vint8m1_t *, vint8m1_t *, vbool8_t, vint8m1_t, vint8m1_t, vint8m1_t, vint8m1_t, const int8_t *, size_t *, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vlseg4e8ff_v)))
void vlseg4e8ff_v_i8m2(vint8m2_t *, vint8m2_t *, vint8m2_t *, vint8m2_t *, const int8_t *, size_t *, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vlseg4e8ff_v_m)))
void vlseg4e8ff_v_i8m2_m(vint8m2_t *, vint8m2_t *, vint8m2_t *, vint8m2_t *, vbool4_t, vint8m2_t, vint8m2_t, vint8m2_t, vint8m2_t, const int8_t *, size_t *, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vlseg4e8ff_v)))
void vlseg4e8ff_v_i8mf2(vint8mf2_t *, vint8mf2_t *, vint8mf2_t *, vint8mf2_t *, const int8_t *, size_t *, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vlseg4e8ff_v_m)))
void vlseg4e8ff_v_i8mf2_m(vint8mf2_t *, vint8mf2_t *, vint8mf2_t *, vint8mf2_t *, vbool16_t, vint8mf2_t, vint8mf2_t, vint8mf2_t, vint8mf2_t, const int8_t *, size_t *, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vlseg4e8ff_v)))
void vlseg4e8ff_v_i8mf4(vint8mf4_t *, vint8mf4_t *, vint8mf4_t *, vint8mf4_t *, const int8_t *, size_t *, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vlseg4e8ff_v_m)))
void vlseg4e8ff_v_i8mf4_m(vint8mf4_t *, vint8mf4_t *, vint8mf4_t *, vint8mf4_t *, vbool32_t, vint8mf4_t, vint8mf4_t, vint8mf4_t, vint8mf4_t, const int8_t *, size_t *, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vlseg4e8ff_v)))
void vlseg4e8ff_v_i8mf8(vint8mf8_t *, vint8mf8_t *, vint8mf8_t *, vint8mf8_t *, const int8_t *, size_t *, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vlseg4e8ff_v_m)))
void vlseg4e8ff_v_i8mf8_m(vint8mf8_t *, vint8mf8_t *, vint8mf8_t *, vint8mf8_t *, vbool64_t, vint8mf8_t, vint8mf8_t, vint8mf8_t, vint8mf8_t, const int8_t *, size_t *, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vlseg4e8ff_v)))
void vlseg4e8ff_v_u8m1(vuint8m1_t *, vuint8m1_t *, vuint8m1_t *, vuint8m1_t *, const uint8_t *, size_t *, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vlseg4e8ff_v_m)))
void vlseg4e8ff_v_u8m1_m(vuint8m1_t *, vuint8m1_t *, vuint8m1_t *, vuint8m1_t *, vbool8_t, vuint8m1_t, vuint8m1_t, vuint8m1_t, vuint8m1_t, const uint8_t *, size_t *, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vlseg4e8ff_v)))
void vlseg4e8ff_v_u8m2(vuint8m2_t *, vuint8m2_t *, vuint8m2_t *, vuint8m2_t *, const uint8_t *, size_t *, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vlseg4e8ff_v_m)))
void vlseg4e8ff_v_u8m2_m(vuint8m2_t *, vuint8m2_t *, vuint8m2_t *, vuint8m2_t *, vbool4_t, vuint8m2_t, vuint8m2_t, vuint8m2_t, vuint8m2_t, const uint8_t *, size_t *, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vlseg4e8ff_v)))
void vlseg4e8ff_v_u8mf2(vuint8mf2_t *, vuint8mf2_t *, vuint8mf2_t *, vuint8mf2_t *, const uint8_t *, size_t *, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vlseg4e8ff_v_m)))
void vlseg4e8ff_v_u8mf2_m(vuint8mf2_t *, vuint8mf2_t *, vuint8mf2_t *, vuint8mf2_t *, vbool16_t, vuint8mf2_t, vuint8mf2_t, vuint8mf2_t, vuint8mf2_t, const uint8_t *, size_t *, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vlseg4e8ff_v)))
void vlseg4e8ff_v_u8mf4(vuint8mf4_t *, vuint8mf4_t *, vuint8mf4_t *, vuint8mf4_t *, const uint8_t *, size_t *, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vlseg4e8ff_v_m)))
void vlseg4e8ff_v_u8mf4_m(vuint8mf4_t *, vuint8mf4_t *, vuint8mf4_t *, vuint8mf4_t *, vbool32_t, vuint8mf4_t, vuint8mf4_t, vuint8mf4_t, vuint8mf4_t, const uint8_t *, size_t *, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vlseg4e8ff_v)))
void vlseg4e8ff_v_u8mf8(vuint8mf8_t *, vuint8mf8_t *, vuint8mf8_t *, vuint8mf8_t *, const uint8_t *, size_t *, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vlseg4e8ff_v_m)))
void vlseg4e8ff_v_u8mf8_m(vuint8mf8_t *, vuint8mf8_t *, vuint8mf8_t *, vuint8mf8_t *, vbool64_t, vuint8mf8_t, vuint8mf8_t, vuint8mf8_t, vuint8mf8_t, const uint8_t *, size_t *, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vlseg5e8ff_v)))
void vlseg5e8ff_v_i8m1(vint8m1_t *, vint8m1_t *, vint8m1_t *, vint8m1_t *, vint8m1_t *, const int8_t *, size_t *, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vlseg5e8ff_v_m)))
void vlseg5e8ff_v_i8m1_m(vint8m1_t *, vint8m1_t *, vint8m1_t *, vint8m1_t *, vint8m1_t *, vbool8_t, vint8m1_t, vint8m1_t, vint8m1_t, vint8m1_t, vint8m1_t, const int8_t *, size_t *, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vlseg5e8ff_v)))
void vlseg5e8ff_v_i8mf2(vint8mf2_t *, vint8mf2_t *, vint8mf2_t *, vint8mf2_t *, vint8mf2_t *, const int8_t *, size_t *, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vlseg5e8ff_v_m)))
void vlseg5e8ff_v_i8mf2_m(vint8mf2_t *, vint8mf2_t *, vint8mf2_t *, vint8mf2_t *, vint8mf2_t *, vbool16_t, vint8mf2_t, vint8mf2_t, vint8mf2_t, vint8mf2_t, vint8mf2_t, const int8_t *, size_t *, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vlseg5e8ff_v)))
void vlseg5e8ff_v_i8mf4(vint8mf4_t *, vint8mf4_t *, vint8mf4_t *, vint8mf4_t *, vint8mf4_t *, const int8_t *, size_t *, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vlseg5e8ff_v_m)))
void vlseg5e8ff_v_i8mf4_m(vint8mf4_t *, vint8mf4_t *, vint8mf4_t *, vint8mf4_t *, vint8mf4_t *, vbool32_t, vint8mf4_t, vint8mf4_t, vint8mf4_t, vint8mf4_t, vint8mf4_t, const int8_t *, size_t *, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vlseg5e8ff_v)))
void vlseg5e8ff_v_i8mf8(vint8mf8_t *, vint8mf8_t *, vint8mf8_t *, vint8mf8_t *, vint8mf8_t *, const int8_t *, size_t *, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vlseg5e8ff_v_m)))
void vlseg5e8ff_v_i8mf8_m(vint8mf8_t *, vint8mf8_t *, vint8mf8_t *, vint8mf8_t *, vint8mf8_t *, vbool64_t, vint8mf8_t, vint8mf8_t, vint8mf8_t, vint8mf8_t, vint8mf8_t, const int8_t *, size_t *, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vlseg5e8ff_v)))
void vlseg5e8ff_v_u8m1(vuint8m1_t *, vuint8m1_t *, vuint8m1_t *, vuint8m1_t *, vuint8m1_t *, const uint8_t *, size_t *, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vlseg5e8ff_v_m)))
void vlseg5e8ff_v_u8m1_m(vuint8m1_t *, vuint8m1_t *, vuint8m1_t *, vuint8m1_t *, vuint8m1_t *, vbool8_t, vuint8m1_t, vuint8m1_t, vuint8m1_t, vuint8m1_t, vuint8m1_t, const uint8_t *, size_t *, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vlseg5e8ff_v)))
void vlseg5e8ff_v_u8mf2(vuint8mf2_t *, vuint8mf2_t *, vuint8mf2_t *, vuint8mf2_t *, vuint8mf2_t *, const uint8_t *, size_t *, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vlseg5e8ff_v_m)))
void vlseg5e8ff_v_u8mf2_m(vuint8mf2_t *, vuint8mf2_t *, vuint8mf2_t *, vuint8mf2_t *, vuint8mf2_t *, vbool16_t, vuint8mf2_t, vuint8mf2_t, vuint8mf2_t, vuint8mf2_t, vuint8mf2_t, const uint8_t *, size_t *, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vlseg5e8ff_v)))
void vlseg5e8ff_v_u8mf4(vuint8mf4_t *, vuint8mf4_t *, vuint8mf4_t *, vuint8mf4_t *, vuint8mf4_t *, const uint8_t *, size_t *, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vlseg5e8ff_v_m)))
void vlseg5e8ff_v_u8mf4_m(vuint8mf4_t *, vuint8mf4_t *, vuint8mf4_t *, vuint8mf4_t *, vuint8mf4_t *, vbool32_t, vuint8mf4_t, vuint8mf4_t, vuint8mf4_t, vuint8mf4_t, vuint8mf4_t, const uint8_t *, size_t *, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vlseg5e8ff_v)))
void vlseg5e8ff_v_u8mf8(vuint8mf8_t *, vuint8mf8_t *, vuint8mf8_t *, vuint8mf8_t *, vuint8mf8_t *, const uint8_t *, size_t *, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vlseg5e8ff_v_m)))
void vlseg5e8ff_v_u8mf8_m(vuint8mf8_t *, vuint8mf8_t *, vuint8mf8_t *, vuint8mf8_t *, vuint8mf8_t *, vbool64_t, vuint8mf8_t, vuint8mf8_t, vuint8mf8_t, vuint8mf8_t, vuint8mf8_t, const uint8_t *, size_t *, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vlseg6e8ff_v)))
void vlseg6e8ff_v_i8m1(vint8m1_t *, vint8m1_t *, vint8m1_t *, vint8m1_t *, vint8m1_t *, vint8m1_t *, const int8_t *, size_t *, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vlseg6e8ff_v_m)))
void vlseg6e8ff_v_i8m1_m(vint8m1_t *, vint8m1_t *, vint8m1_t *, vint8m1_t *, vint8m1_t *, vint8m1_t *, vbool8_t, vint8m1_t, vint8m1_t, vint8m1_t, vint8m1_t, vint8m1_t, vint8m1_t, const int8_t *, size_t *, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vlseg6e8ff_v)))
void vlseg6e8ff_v_i8mf2(vint8mf2_t *, vint8mf2_t *, vint8mf2_t *, vint8mf2_t *, vint8mf2_t *, vint8mf2_t *, const int8_t *, size_t *, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vlseg6e8ff_v_m)))
void vlseg6e8ff_v_i8mf2_m(vint8mf2_t *, vint8mf2_t *, vint8mf2_t *, vint8mf2_t *, vint8mf2_t *, vint8mf2_t *, vbool16_t, vint8mf2_t, vint8mf2_t, vint8mf2_t, vint8mf2_t, vint8mf2_t, vint8mf2_t, const int8_t *, size_t *, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vlseg6e8ff_v)))
void vlseg6e8ff_v_i8mf4(vint8mf4_t *, vint8mf4_t *, vint8mf4_t *, vint8mf4_t *, vint8mf4_t *, vint8mf4_t *, const int8_t *, size_t *, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vlseg6e8ff_v_m)))
void vlseg6e8ff_v_i8mf4_m(vint8mf4_t *, vint8mf4_t *, vint8mf4_t *, vint8mf4_t *, vint8mf4_t *, vint8mf4_t *, vbool32_t, vint8mf4_t, vint8mf4_t, vint8mf4_t, vint8mf4_t, vint8mf4_t, vint8mf4_t, const int8_t *, size_t *, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vlseg6e8ff_v)))
void vlseg6e8ff_v_i8mf8(vint8mf8_t *, vint8mf8_t *, vint8mf8_t *, vint8mf8_t *, vint8mf8_t *, vint8mf8_t *, const int8_t *, size_t *, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vlseg6e8ff_v_m)))
void vlseg6e8ff_v_i8mf8_m(vint8mf8_t *, vint8mf8_t *, vint8mf8_t *, vint8mf8_t *, vint8mf8_t *, vint8mf8_t *, vbool64_t, vint8mf8_t, vint8mf8_t, vint8mf8_t, vint8mf8_t, vint8mf8_t, vint8mf8_t, const int8_t *, size_t *, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vlseg6e8ff_v)))
void vlseg6e8ff_v_u8m1(vuint8m1_t *, vuint8m1_t *, vuint8m1_t *, vuint8m1_t *, vuint8m1_t *, vuint8m1_t *, const uint8_t *, size_t *, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vlseg6e8ff_v_m)))
void vlseg6e8ff_v_u8m1_m(vuint8m1_t *, vuint8m1_t *, vuint8m1_t *, vuint8m1_t *, vuint8m1_t *, vuint8m1_t *, vbool8_t, vuint8m1_t, vuint8m1_t, vuint8m1_t, vuint8m1_t, vuint8m1_t, vuint8m1_t, const uint8_t *, size_t *, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vlseg6e8ff_v)))
void vlseg6e8ff_v_u8mf2(vuint8mf2_t *, vuint8mf2_t *, vuint8mf2_t *, vuint8mf2_t *, vuint8mf2_t *, vuint8mf2_t *, const uint8_t *, size_t *, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vlseg6e8ff_v_m)))
void vlseg6e8ff_v_u8mf2_m(vuint8mf2_t *, vuint8mf2_t *, vuint8mf2_t *, vuint8mf2_t *, vuint8mf2_t *, vuint8mf2_t *, vbool16_t, vuint8mf2_t, vuint8mf2_t, vuint8mf2_t, vuint8mf2_t, vuint8mf2_t, vuint8mf2_t, const uint8_t *, size_t *, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vlseg6e8ff_v)))
void vlseg6e8ff_v_u8mf4(vuint8mf4_t *, vuint8mf4_t *, vuint8mf4_t *, vuint8mf4_t *, vuint8mf4_t *, vuint8mf4_t *, const uint8_t *, size_t *, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vlseg6e8ff_v_m)))
void vlseg6e8ff_v_u8mf4_m(vuint8mf4_t *, vuint8mf4_t *, vuint8mf4_t *, vuint8mf4_t *, vuint8mf4_t *, vuint8mf4_t *, vbool32_t, vuint8mf4_t, vuint8mf4_t, vuint8mf4_t, vuint8mf4_t, vuint8mf4_t, vuint8mf4_t, const uint8_t *, size_t *, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vlseg6e8ff_v)))
void vlseg6e8ff_v_u8mf8(vuint8mf8_t *, vuint8mf8_t *, vuint8mf8_t *, vuint8mf8_t *, vuint8mf8_t *, vuint8mf8_t *, const uint8_t *, size_t *, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vlseg6e8ff_v_m)))
void vlseg6e8ff_v_u8mf8_m(vuint8mf8_t *, vuint8mf8_t *, vuint8mf8_t *, vuint8mf8_t *, vuint8mf8_t *, vuint8mf8_t *, vbool64_t, vuint8mf8_t, vuint8mf8_t, vuint8mf8_t, vuint8mf8_t, vuint8mf8_t, vuint8mf8_t, const uint8_t *, size_t *, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vlseg7e8ff_v)))
void vlseg7e8ff_v_i8m1(vint8m1_t *, vint8m1_t *, vint8m1_t *, vint8m1_t *, vint8m1_t *, vint8m1_t *, vint8m1_t *, const int8_t *, size_t *, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vlseg7e8ff_v_m)))
void vlseg7e8ff_v_i8m1_m(vint8m1_t *, vint8m1_t *, vint8m1_t *, vint8m1_t *, vint8m1_t *, vint8m1_t *, vint8m1_t *, vbool8_t, vint8m1_t, vint8m1_t, vint8m1_t, vint8m1_t, vint8m1_t, vint8m1_t, vint8m1_t, const int8_t *, size_t *, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vlseg7e8ff_v)))
void vlseg7e8ff_v_i8mf2(vint8mf2_t *, vint8mf2_t *, vint8mf2_t *, vint8mf2_t *, vint8mf2_t *, vint8mf2_t *, vint8mf2_t *, const int8_t *, size_t *, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vlseg7e8ff_v_m)))
void vlseg7e8ff_v_i8mf2_m(vint8mf2_t *, vint8mf2_t *, vint8mf2_t *, vint8mf2_t *, vint8mf2_t *, vint8mf2_t *, vint8mf2_t *, vbool16_t, vint8mf2_t, vint8mf2_t, vint8mf2_t, vint8mf2_t, vint8mf2_t, vint8mf2_t, vint8mf2_t, const int8_t *, size_t *, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vlseg7e8ff_v)))
void vlseg7e8ff_v_i8mf4(vint8mf4_t *, vint8mf4_t *, vint8mf4_t *, vint8mf4_t *, vint8mf4_t *, vint8mf4_t *, vint8mf4_t *, const int8_t *, size_t *, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vlseg7e8ff_v_m)))
void vlseg7e8ff_v_i8mf4_m(vint8mf4_t *, vint8mf4_t *, vint8mf4_t *, vint8mf4_t *, vint8mf4_t *, vint8mf4_t *, vint8mf4_t *, vbool32_t, vint8mf4_t, vint8mf4_t, vint8mf4_t, vint8mf4_t, vint8mf4_t, vint8mf4_t, vint8mf4_t, const int8_t *, size_t *, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vlseg7e8ff_v)))
void vlseg7e8ff_v_i8mf8(vint8mf8_t *, vint8mf8_t *, vint8mf8_t *, vint8mf8_t *, vint8mf8_t *, vint8mf8_t *, vint8mf8_t *, const int8_t *, size_t *, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vlseg7e8ff_v_m)))
void vlseg7e8ff_v_i8mf8_m(vint8mf8_t *, vint8mf8_t *, vint8mf8_t *, vint8mf8_t *, vint8mf8_t *, vint8mf8_t *, vint8mf8_t *, vbool64_t, vint8mf8_t, vint8mf8_t, vint8mf8_t, vint8mf8_t, vint8mf8_t, vint8mf8_t, vint8mf8_t, const int8_t *, size_t *, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vlseg7e8ff_v)))
void vlseg7e8ff_v_u8m1(vuint8m1_t *, vuint8m1_t *, vuint8m1_t *, vuint8m1_t *, vuint8m1_t *, vuint8m1_t *, vuint8m1_t *, const uint8_t *, size_t *, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vlseg7e8ff_v_m)))
void vlseg7e8ff_v_u8m1_m(vuint8m1_t *, vuint8m1_t *, vuint8m1_t *, vuint8m1_t *, vuint8m1_t *, vuint8m1_t *, vuint8m1_t *, vbool8_t, vuint8m1_t, vuint8m1_t, vuint8m1_t, vuint8m1_t, vuint8m1_t, vuint8m1_t, vuint8m1_t, const uint8_t *, size_t *, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vlseg7e8ff_v)))
void vlseg7e8ff_v_u8mf2(vuint8mf2_t *, vuint8mf2_t *, vuint8mf2_t *, vuint8mf2_t *, vuint8mf2_t *, vuint8mf2_t *, vuint8mf2_t *, const uint8_t *, size_t *, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vlseg7e8ff_v_m)))
void vlseg7e8ff_v_u8mf2_m(vuint8mf2_t *, vuint8mf2_t *, vuint8mf2_t *, vuint8mf2_t *, vuint8mf2_t *, vuint8mf2_t *, vuint8mf2_t *, vbool16_t, vuint8mf2_t, vuint8mf2_t, vuint8mf2_t, vuint8mf2_t, vuint8mf2_t, vuint8mf2_t, vuint8mf2_t, const uint8_t *, size_t *, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vlseg7e8ff_v)))
void vlseg7e8ff_v_u8mf4(vuint8mf4_t *, vuint8mf4_t *, vuint8mf4_t *, vuint8mf4_t *, vuint8mf4_t *, vuint8mf4_t *, vuint8mf4_t *, const uint8_t *, size_t *, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vlseg7e8ff_v_m)))
void vlseg7e8ff_v_u8mf4_m(vuint8mf4_t *, vuint8mf4_t *, vuint8mf4_t *, vuint8mf4_t *, vuint8mf4_t *, vuint8mf4_t *, vuint8mf4_t *, vbool32_t, vuint8mf4_t, vuint8mf4_t, vuint8mf4_t, vuint8mf4_t, vuint8mf4_t, vuint8mf4_t, vuint8mf4_t, const uint8_t *, size_t *, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vlseg7e8ff_v)))
void vlseg7e8ff_v_u8mf8(vuint8mf8_t *, vuint8mf8_t *, vuint8mf8_t *, vuint8mf8_t *, vuint8mf8_t *, vuint8mf8_t *, vuint8mf8_t *, const uint8_t *, size_t *, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vlseg7e8ff_v_m)))
void vlseg7e8ff_v_u8mf8_m(vuint8mf8_t *, vuint8mf8_t *, vuint8mf8_t *, vuint8mf8_t *, vuint8mf8_t *, vuint8mf8_t *, vuint8mf8_t *, vbool64_t, vuint8mf8_t, vuint8mf8_t, vuint8mf8_t, vuint8mf8_t, vuint8mf8_t, vuint8mf8_t, vuint8mf8_t, const uint8_t *, size_t *, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vlseg8e8ff_v)))
void vlseg8e8ff_v_i8m1(vint8m1_t *, vint8m1_t *, vint8m1_t *, vint8m1_t *, vint8m1_t *, vint8m1_t *, vint8m1_t *, vint8m1_t *, const int8_t *, size_t *, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vlseg8e8ff_v_m)))
void vlseg8e8ff_v_i8m1_m(vint8m1_t *, vint8m1_t *, vint8m1_t *, vint8m1_t *, vint8m1_t *, vint8m1_t *, vint8m1_t *, vint8m1_t *, vbool8_t, vint8m1_t, vint8m1_t, vint8m1_t, vint8m1_t, vint8m1_t, vint8m1_t, vint8m1_t, vint8m1_t, const int8_t *, size_t *, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vlseg8e8ff_v)))
void vlseg8e8ff_v_i8mf2(vint8mf2_t *, vint8mf2_t *, vint8mf2_t *, vint8mf2_t *, vint8mf2_t *, vint8mf2_t *, vint8mf2_t *, vint8mf2_t *, const int8_t *, size_t *, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vlseg8e8ff_v_m)))
void vlseg8e8ff_v_i8mf2_m(vint8mf2_t *, vint8mf2_t *, vint8mf2_t *, vint8mf2_t *, vint8mf2_t *, vint8mf2_t *, vint8mf2_t *, vint8mf2_t *, vbool16_t, vint8mf2_t, vint8mf2_t, vint8mf2_t, vint8mf2_t, vint8mf2_t, vint8mf2_t, vint8mf2_t, vint8mf2_t, const int8_t *, size_t *, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vlseg8e8ff_v)))
void vlseg8e8ff_v_i8mf4(vint8mf4_t *, vint8mf4_t *, vint8mf4_t *, vint8mf4_t *, vint8mf4_t *, vint8mf4_t *, vint8mf4_t *, vint8mf4_t *, const int8_t *, size_t *, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vlseg8e8ff_v_m)))
void vlseg8e8ff_v_i8mf4_m(vint8mf4_t *, vint8mf4_t *, vint8mf4_t *, vint8mf4_t *, vint8mf4_t *, vint8mf4_t *, vint8mf4_t *, vint8mf4_t *, vbool32_t, vint8mf4_t, vint8mf4_t, vint8mf4_t, vint8mf4_t, vint8mf4_t, vint8mf4_t, vint8mf4_t, vint8mf4_t, const int8_t *, size_t *, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vlseg8e8ff_v)))
void vlseg8e8ff_v_i8mf8(vint8mf8_t *, vint8mf8_t *, vint8mf8_t *, vint8mf8_t *, vint8mf8_t *, vint8mf8_t *, vint8mf8_t *, vint8mf8_t *, const int8_t *, size_t *, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vlseg8e8ff_v_m)))
void vlseg8e8ff_v_i8mf8_m(vint8mf8_t *, vint8mf8_t *, vint8mf8_t *, vint8mf8_t *, vint8mf8_t *, vint8mf8_t *, vint8mf8_t *, vint8mf8_t *, vbool64_t, vint8mf8_t, vint8mf8_t, vint8mf8_t, vint8mf8_t, vint8mf8_t, vint8mf8_t, vint8mf8_t, vint8mf8_t, const int8_t *, size_t *, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vlseg8e8ff_v)))
void vlseg8e8ff_v_u8m1(vuint8m1_t *, vuint8m1_t *, vuint8m1_t *, vuint8m1_t *, vuint8m1_t *, vuint8m1_t *, vuint8m1_t *, vuint8m1_t *, const uint8_t *, size_t *, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vlseg8e8ff_v_m)))
void vlseg8e8ff_v_u8m1_m(vuint8m1_t *, vuint8m1_t *, vuint8m1_t *, vuint8m1_t *, vuint8m1_t *, vuint8m1_t *, vuint8m1_t *, vuint8m1_t *, vbool8_t, vuint8m1_t, vuint8m1_t, vuint8m1_t, vuint8m1_t, vuint8m1_t, vuint8m1_t, vuint8m1_t, vuint8m1_t, const uint8_t *, size_t *, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vlseg8e8ff_v)))
void vlseg8e8ff_v_u8mf2(vuint8mf2_t *, vuint8mf2_t *, vuint8mf2_t *, vuint8mf2_t *, vuint8mf2_t *, vuint8mf2_t *, vuint8mf2_t *, vuint8mf2_t *, const uint8_t *, size_t *, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vlseg8e8ff_v_m)))
void vlseg8e8ff_v_u8mf2_m(vuint8mf2_t *, vuint8mf2_t *, vuint8mf2_t *, vuint8mf2_t *, vuint8mf2_t *, vuint8mf2_t *, vuint8mf2_t *, vuint8mf2_t *, vbool16_t, vuint8mf2_t, vuint8mf2_t, vuint8mf2_t, vuint8mf2_t, vuint8mf2_t, vuint8mf2_t, vuint8mf2_t, vuint8mf2_t, const uint8_t *, size_t *, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vlseg8e8ff_v)))
void vlseg8e8ff_v_u8mf4(vuint8mf4_t *, vuint8mf4_t *, vuint8mf4_t *, vuint8mf4_t *, vuint8mf4_t *, vuint8mf4_t *, vuint8mf4_t *, vuint8mf4_t *, const uint8_t *, size_t *, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vlseg8e8ff_v_m)))
void vlseg8e8ff_v_u8mf4_m(vuint8mf4_t *, vuint8mf4_t *, vuint8mf4_t *, vuint8mf4_t *, vuint8mf4_t *, vuint8mf4_t *, vuint8mf4_t *, vuint8mf4_t *, vbool32_t, vuint8mf4_t, vuint8mf4_t, vuint8mf4_t, vuint8mf4_t, vuint8mf4_t, vuint8mf4_t, vuint8mf4_t, vuint8mf4_t, const uint8_t *, size_t *, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vlseg8e8ff_v)))
void vlseg8e8ff_v_u8mf8(vuint8mf8_t *, vuint8mf8_t *, vuint8mf8_t *, vuint8mf8_t *, vuint8mf8_t *, vuint8mf8_t *, vuint8mf8_t *, vuint8mf8_t *, const uint8_t *, size_t *, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vlseg8e8ff_v_m)))
void vlseg8e8ff_v_u8mf8_m(vuint8mf8_t *, vuint8mf8_t *, vuint8mf8_t *, vuint8mf8_t *, vuint8mf8_t *, vuint8mf8_t *, vuint8mf8_t *, vuint8mf8_t *, vbool64_t, vuint8mf8_t, vuint8mf8_t, vuint8mf8_t, vuint8mf8_t, vuint8mf8_t, vuint8mf8_t, vuint8mf8_t, vuint8mf8_t, const uint8_t *, size_t *, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vlseg2e16ff_v)))
void vlseg2e16ff_v_i16m1(vint16m1_t *, vint16m1_t *, const int16_t *, size_t *, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vlseg2e16ff_v_m)))
void vlseg2e16ff_v_i16m1_m(vint16m1_t *, vint16m1_t *, vbool16_t, vint16m1_t, vint16m1_t, const int16_t *, size_t *, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vlseg2e16ff_v)))
void vlseg2e16ff_v_i16m2(vint16m2_t *, vint16m2_t *, const int16_t *, size_t *, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vlseg2e16ff_v_m)))
void vlseg2e16ff_v_i16m2_m(vint16m2_t *, vint16m2_t *, vbool8_t, vint16m2_t, vint16m2_t, const int16_t *, size_t *, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vlseg2e16ff_v)))
void vlseg2e16ff_v_i16m4(vint16m4_t *, vint16m4_t *, const int16_t *, size_t *, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vlseg2e16ff_v_m)))
void vlseg2e16ff_v_i16m4_m(vint16m4_t *, vint16m4_t *, vbool4_t, vint16m4_t, vint16m4_t, const int16_t *, size_t *, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vlseg2e16ff_v)))
void vlseg2e16ff_v_i16mf2(vint16mf2_t *, vint16mf2_t *, const int16_t *, size_t *, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vlseg2e16ff_v_m)))
void vlseg2e16ff_v_i16mf2_m(vint16mf2_t *, vint16mf2_t *, vbool32_t, vint16mf2_t, vint16mf2_t, const int16_t *, size_t *, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vlseg2e16ff_v)))
void vlseg2e16ff_v_i16mf4(vint16mf4_t *, vint16mf4_t *, const int16_t *, size_t *, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vlseg2e16ff_v_m)))
void vlseg2e16ff_v_i16mf4_m(vint16mf4_t *, vint16mf4_t *, vbool64_t, vint16mf4_t, vint16mf4_t, const int16_t *, size_t *, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vlseg2e16ff_v)))
void vlseg2e16ff_v_u16m1(vuint16m1_t *, vuint16m1_t *, const uint16_t *, size_t *, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vlseg2e16ff_v_m)))
void vlseg2e16ff_v_u16m1_m(vuint16m1_t *, vuint16m1_t *, vbool16_t, vuint16m1_t, vuint16m1_t, const uint16_t *, size_t *, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vlseg2e16ff_v)))
void vlseg2e16ff_v_u16m2(vuint16m2_t *, vuint16m2_t *, const uint16_t *, size_t *, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vlseg2e16ff_v_m)))
void vlseg2e16ff_v_u16m2_m(vuint16m2_t *, vuint16m2_t *, vbool8_t, vuint16m2_t, vuint16m2_t, const uint16_t *, size_t *, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vlseg2e16ff_v)))
void vlseg2e16ff_v_u16m4(vuint16m4_t *, vuint16m4_t *, const uint16_t *, size_t *, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vlseg2e16ff_v_m)))
void vlseg2e16ff_v_u16m4_m(vuint16m4_t *, vuint16m4_t *, vbool4_t, vuint16m4_t, vuint16m4_t, const uint16_t *, size_t *, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vlseg2e16ff_v)))
void vlseg2e16ff_v_u16mf2(vuint16mf2_t *, vuint16mf2_t *, const uint16_t *, size_t *, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vlseg2e16ff_v_m)))
void vlseg2e16ff_v_u16mf2_m(vuint16mf2_t *, vuint16mf2_t *, vbool32_t, vuint16mf2_t, vuint16mf2_t, const uint16_t *, size_t *, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vlseg2e16ff_v)))
void vlseg2e16ff_v_u16mf4(vuint16mf4_t *, vuint16mf4_t *, const uint16_t *, size_t *, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vlseg2e16ff_v_m)))
void vlseg2e16ff_v_u16mf4_m(vuint16mf4_t *, vuint16mf4_t *, vbool64_t, vuint16mf4_t, vuint16mf4_t, const uint16_t *, size_t *, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vlseg3e16ff_v)))
void vlseg3e16ff_v_i16m1(vint16m1_t *, vint16m1_t *, vint16m1_t *, const int16_t *, size_t *, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vlseg3e16ff_v_m)))
void vlseg3e16ff_v_i16m1_m(vint16m1_t *, vint16m1_t *, vint16m1_t *, vbool16_t, vint16m1_t, vint16m1_t, vint16m1_t, const int16_t *, size_t *, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vlseg3e16ff_v)))
void vlseg3e16ff_v_i16m2(vint16m2_t *, vint16m2_t *, vint16m2_t *, const int16_t *, size_t *, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vlseg3e16ff_v_m)))
void vlseg3e16ff_v_i16m2_m(vint16m2_t *, vint16m2_t *, vint16m2_t *, vbool8_t, vint16m2_t, vint16m2_t, vint16m2_t, const int16_t *, size_t *, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vlseg3e16ff_v)))
void vlseg3e16ff_v_i16mf2(vint16mf2_t *, vint16mf2_t *, vint16mf2_t *, const int16_t *, size_t *, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vlseg3e16ff_v_m)))
void vlseg3e16ff_v_i16mf2_m(vint16mf2_t *, vint16mf2_t *, vint16mf2_t *, vbool32_t, vint16mf2_t, vint16mf2_t, vint16mf2_t, const int16_t *, size_t *, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vlseg3e16ff_v)))
void vlseg3e16ff_v_i16mf4(vint16mf4_t *, vint16mf4_t *, vint16mf4_t *, const int16_t *, size_t *, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vlseg3e16ff_v_m)))
void vlseg3e16ff_v_i16mf4_m(vint16mf4_t *, vint16mf4_t *, vint16mf4_t *, vbool64_t, vint16mf4_t, vint16mf4_t, vint16mf4_t, const int16_t *, size_t *, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vlseg3e16ff_v)))
void vlseg3e16ff_v_u16m1(vuint16m1_t *, vuint16m1_t *, vuint16m1_t *, const uint16_t *, size_t *, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vlseg3e16ff_v_m)))
void vlseg3e16ff_v_u16m1_m(vuint16m1_t *, vuint16m1_t *, vuint16m1_t *, vbool16_t, vuint16m1_t, vuint16m1_t, vuint16m1_t, const uint16_t *, size_t *, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vlseg3e16ff_v)))
void vlseg3e16ff_v_u16m2(vuint16m2_t *, vuint16m2_t *, vuint16m2_t *, const uint16_t *, size_t *, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vlseg3e16ff_v_m)))
void vlseg3e16ff_v_u16m2_m(vuint16m2_t *, vuint16m2_t *, vuint16m2_t *, vbool8_t, vuint16m2_t, vuint16m2_t, vuint16m2_t, const uint16_t *, size_t *, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vlseg3e16ff_v)))
void vlseg3e16ff_v_u16mf2(vuint16mf2_t *, vuint16mf2_t *, vuint16mf2_t *, const uint16_t *, size_t *, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vlseg3e16ff_v_m)))
void vlseg3e16ff_v_u16mf2_m(vuint16mf2_t *, vuint16mf2_t *, vuint16mf2_t *, vbool32_t, vuint16mf2_t, vuint16mf2_t, vuint16mf2_t, const uint16_t *, size_t *, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vlseg3e16ff_v)))
void vlseg3e16ff_v_u16mf4(vuint16mf4_t *, vuint16mf4_t *, vuint16mf4_t *, const uint16_t *, size_t *, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vlseg3e16ff_v_m)))
void vlseg3e16ff_v_u16mf4_m(vuint16mf4_t *, vuint16mf4_t *, vuint16mf4_t *, vbool64_t, vuint16mf4_t, vuint16mf4_t, vuint16mf4_t, const uint16_t *, size_t *, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vlseg4e16ff_v)))
void vlseg4e16ff_v_i16m1(vint16m1_t *, vint16m1_t *, vint16m1_t *, vint16m1_t *, const int16_t *, size_t *, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vlseg4e16ff_v_m)))
void vlseg4e16ff_v_i16m1_m(vint16m1_t *, vint16m1_t *, vint16m1_t *, vint16m1_t *, vbool16_t, vint16m1_t, vint16m1_t, vint16m1_t, vint16m1_t, const int16_t *, size_t *, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vlseg4e16ff_v)))
void vlseg4e16ff_v_i16m2(vint16m2_t *, vint16m2_t *, vint16m2_t *, vint16m2_t *, const int16_t *, size_t *, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vlseg4e16ff_v_m)))
void vlseg4e16ff_v_i16m2_m(vint16m2_t *, vint16m2_t *, vint16m2_t *, vint16m2_t *, vbool8_t, vint16m2_t, vint16m2_t, vint16m2_t, vint16m2_t, const int16_t *, size_t *, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vlseg4e16ff_v)))
void vlseg4e16ff_v_i16mf2(vint16mf2_t *, vint16mf2_t *, vint16mf2_t *, vint16mf2_t *, const int16_t *, size_t *, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vlseg4e16ff_v_m)))
void vlseg4e16ff_v_i16mf2_m(vint16mf2_t *, vint16mf2_t *, vint16mf2_t *, vint16mf2_t *, vbool32_t, vint16mf2_t, vint16mf2_t, vint16mf2_t, vint16mf2_t, const int16_t *, size_t *, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vlseg4e16ff_v)))
void vlseg4e16ff_v_i16mf4(vint16mf4_t *, vint16mf4_t *, vint16mf4_t *, vint16mf4_t *, const int16_t *, size_t *, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vlseg4e16ff_v_m)))
void vlseg4e16ff_v_i16mf4_m(vint16mf4_t *, vint16mf4_t *, vint16mf4_t *, vint16mf4_t *, vbool64_t, vint16mf4_t, vint16mf4_t, vint16mf4_t, vint16mf4_t, const int16_t *, size_t *, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vlseg4e16ff_v)))
void vlseg4e16ff_v_u16m1(vuint16m1_t *, vuint16m1_t *, vuint16m1_t *, vuint16m1_t *, const uint16_t *, size_t *, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vlseg4e16ff_v_m)))
void vlseg4e16ff_v_u16m1_m(vuint16m1_t *, vuint16m1_t *, vuint16m1_t *, vuint16m1_t *, vbool16_t, vuint16m1_t, vuint16m1_t, vuint16m1_t, vuint16m1_t, const uint16_t *, size_t *, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vlseg4e16ff_v)))
void vlseg4e16ff_v_u16m2(vuint16m2_t *, vuint16m2_t *, vuint16m2_t *, vuint16m2_t *, const uint16_t *, size_t *, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vlseg4e16ff_v_m)))
void vlseg4e16ff_v_u16m2_m(vuint16m2_t *, vuint16m2_t *, vuint16m2_t *, vuint16m2_t *, vbool8_t, vuint16m2_t, vuint16m2_t, vuint16m2_t, vuint16m2_t, const uint16_t *, size_t *, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vlseg4e16ff_v)))
void vlseg4e16ff_v_u16mf2(vuint16mf2_t *, vuint16mf2_t *, vuint16mf2_t *, vuint16mf2_t *, const uint16_t *, size_t *, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vlseg4e16ff_v_m)))
void vlseg4e16ff_v_u16mf2_m(vuint16mf2_t *, vuint16mf2_t *, vuint16mf2_t *, vuint16mf2_t *, vbool32_t, vuint16mf2_t, vuint16mf2_t, vuint16mf2_t, vuint16mf2_t, const uint16_t *, size_t *, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vlseg4e16ff_v)))
void vlseg4e16ff_v_u16mf4(vuint16mf4_t *, vuint16mf4_t *, vuint16mf4_t *, vuint16mf4_t *, const uint16_t *, size_t *, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vlseg4e16ff_v_m)))
void vlseg4e16ff_v_u16mf4_m(vuint16mf4_t *, vuint16mf4_t *, vuint16mf4_t *, vuint16mf4_t *, vbool64_t, vuint16mf4_t, vuint16mf4_t, vuint16mf4_t, vuint16mf4_t, const uint16_t *, size_t *, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vlseg5e16ff_v)))
void vlseg5e16ff_v_i16m1(vint16m1_t *, vint16m1_t *, vint16m1_t *, vint16m1_t *, vint16m1_t *, const int16_t *, size_t *, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vlseg5e16ff_v_m)))
void vlseg5e16ff_v_i16m1_m(vint16m1_t *, vint16m1_t *, vint16m1_t *, vint16m1_t *, vint16m1_t *, vbool16_t, vint16m1_t, vint16m1_t, vint16m1_t, vint16m1_t, vint16m1_t, const int16_t *, size_t *, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vlseg5e16ff_v)))
void vlseg5e16ff_v_i16mf2(vint16mf2_t *, vint16mf2_t *, vint16mf2_t *, vint16mf2_t *, vint16mf2_t *, const int16_t *, size_t *, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vlseg5e16ff_v_m)))
void vlseg5e16ff_v_i16mf2_m(vint16mf2_t *, vint16mf2_t *, vint16mf2_t *, vint16mf2_t *, vint16mf2_t *, vbool32_t, vint16mf2_t, vint16mf2_t, vint16mf2_t, vint16mf2_t, vint16mf2_t, const int16_t *, size_t *, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vlseg5e16ff_v)))
void vlseg5e16ff_v_i16mf4(vint16mf4_t *, vint16mf4_t *, vint16mf4_t *, vint16mf4_t *, vint16mf4_t *, const int16_t *, size_t *, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vlseg5e16ff_v_m)))
void vlseg5e16ff_v_i16mf4_m(vint16mf4_t *, vint16mf4_t *, vint16mf4_t *, vint16mf4_t *, vint16mf4_t *, vbool64_t, vint16mf4_t, vint16mf4_t, vint16mf4_t, vint16mf4_t, vint16mf4_t, const int16_t *, size_t *, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vlseg5e16ff_v)))
void vlseg5e16ff_v_u16m1(vuint16m1_t *, vuint16m1_t *, vuint16m1_t *, vuint16m1_t *, vuint16m1_t *, const uint16_t *, size_t *, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vlseg5e16ff_v_m)))
void vlseg5e16ff_v_u16m1_m(vuint16m1_t *, vuint16m1_t *, vuint16m1_t *, vuint16m1_t *, vuint16m1_t *, vbool16_t, vuint16m1_t, vuint16m1_t, vuint16m1_t, vuint16m1_t, vuint16m1_t, const uint16_t *, size_t *, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vlseg5e16ff_v)))
void vlseg5e16ff_v_u16mf2(vuint16mf2_t *, vuint16mf2_t *, vuint16mf2_t *, vuint16mf2_t *, vuint16mf2_t *, const uint16_t *, size_t *, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vlseg5e16ff_v_m)))
void vlseg5e16ff_v_u16mf2_m(vuint16mf2_t *, vuint16mf2_t *, vuint16mf2_t *, vuint16mf2_t *, vuint16mf2_t *, vbool32_t, vuint16mf2_t, vuint16mf2_t, vuint16mf2_t, vuint16mf2_t, vuint16mf2_t, const uint16_t *, size_t *, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vlseg5e16ff_v)))
void vlseg5e16ff_v_u16mf4(vuint16mf4_t *, vuint16mf4_t *, vuint16mf4_t *, vuint16mf4_t *, vuint16mf4_t *, const uint16_t *, size_t *, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vlseg5e16ff_v_m)))
void vlseg5e16ff_v_u16mf4_m(vuint16mf4_t *, vuint16mf4_t *, vuint16mf4_t *, vuint16mf4_t *, vuint16mf4_t *, vbool64_t, vuint16mf4_t, vuint16mf4_t, vuint16mf4_t, vuint16mf4_t, vuint16mf4_t, const uint16_t *, size_t *, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vlseg6e16ff_v)))
void vlseg6e16ff_v_i16m1(vint16m1_t *, vint16m1_t *, vint16m1_t *, vint16m1_t *, vint16m1_t *, vint16m1_t *, const int16_t *, size_t *, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vlseg6e16ff_v_m)))
void vlseg6e16ff_v_i16m1_m(vint16m1_t *, vint16m1_t *, vint16m1_t *, vint16m1_t *, vint16m1_t *, vint16m1_t *, vbool16_t, vint16m1_t, vint16m1_t, vint16m1_t, vint16m1_t, vint16m1_t, vint16m1_t, const int16_t *, size_t *, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vlseg6e16ff_v)))
void vlseg6e16ff_v_i16mf2(vint16mf2_t *, vint16mf2_t *, vint16mf2_t *, vint16mf2_t *, vint16mf2_t *, vint16mf2_t *, const int16_t *, size_t *, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vlseg6e16ff_v_m)))
void vlseg6e16ff_v_i16mf2_m(vint16mf2_t *, vint16mf2_t *, vint16mf2_t *, vint16mf2_t *, vint16mf2_t *, vint16mf2_t *, vbool32_t, vint16mf2_t, vint16mf2_t, vint16mf2_t, vint16mf2_t, vint16mf2_t, vint16mf2_t, const int16_t *, size_t *, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vlseg6e16ff_v)))
void vlseg6e16ff_v_i16mf4(vint16mf4_t *, vint16mf4_t *, vint16mf4_t *, vint16mf4_t *, vint16mf4_t *, vint16mf4_t *, const int16_t *, size_t *, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vlseg6e16ff_v_m)))
void vlseg6e16ff_v_i16mf4_m(vint16mf4_t *, vint16mf4_t *, vint16mf4_t *, vint16mf4_t *, vint16mf4_t *, vint16mf4_t *, vbool64_t, vint16mf4_t, vint16mf4_t, vint16mf4_t, vint16mf4_t, vint16mf4_t, vint16mf4_t, const int16_t *, size_t *, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vlseg6e16ff_v)))
void vlseg6e16ff_v_u16m1(vuint16m1_t *, vuint16m1_t *, vuint16m1_t *, vuint16m1_t *, vuint16m1_t *, vuint16m1_t *, const uint16_t *, size_t *, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vlseg6e16ff_v_m)))
void vlseg6e16ff_v_u16m1_m(vuint16m1_t *, vuint16m1_t *, vuint16m1_t *, vuint16m1_t *, vuint16m1_t *, vuint16m1_t *, vbool16_t, vuint16m1_t, vuint16m1_t, vuint16m1_t, vuint16m1_t, vuint16m1_t, vuint16m1_t, const uint16_t *, size_t *, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vlseg6e16ff_v)))
void vlseg6e16ff_v_u16mf2(vuint16mf2_t *, vuint16mf2_t *, vuint16mf2_t *, vuint16mf2_t *, vuint16mf2_t *, vuint16mf2_t *, const uint16_t *, size_t *, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vlseg6e16ff_v_m)))
void vlseg6e16ff_v_u16mf2_m(vuint16mf2_t *, vuint16mf2_t *, vuint16mf2_t *, vuint16mf2_t *, vuint16mf2_t *, vuint16mf2_t *, vbool32_t, vuint16mf2_t, vuint16mf2_t, vuint16mf2_t, vuint16mf2_t, vuint16mf2_t, vuint16mf2_t, const uint16_t *, size_t *, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vlseg6e16ff_v)))
void vlseg6e16ff_v_u16mf4(vuint16mf4_t *, vuint16mf4_t *, vuint16mf4_t *, vuint16mf4_t *, vuint16mf4_t *, vuint16mf4_t *, const uint16_t *, size_t *, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vlseg6e16ff_v_m)))
void vlseg6e16ff_v_u16mf4_m(vuint16mf4_t *, vuint16mf4_t *, vuint16mf4_t *, vuint16mf4_t *, vuint16mf4_t *, vuint16mf4_t *, vbool64_t, vuint16mf4_t, vuint16mf4_t, vuint16mf4_t, vuint16mf4_t, vuint16mf4_t, vuint16mf4_t, const uint16_t *, size_t *, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vlseg7e16ff_v)))
void vlseg7e16ff_v_i16m1(vint16m1_t *, vint16m1_t *, vint16m1_t *, vint16m1_t *, vint16m1_t *, vint16m1_t *, vint16m1_t *, const int16_t *, size_t *, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vlseg7e16ff_v_m)))
void vlseg7e16ff_v_i16m1_m(vint16m1_t *, vint16m1_t *, vint16m1_t *, vint16m1_t *, vint16m1_t *, vint16m1_t *, vint16m1_t *, vbool16_t, vint16m1_t, vint16m1_t, vint16m1_t, vint16m1_t, vint16m1_t, vint16m1_t, vint16m1_t, const int16_t *, size_t *, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vlseg7e16ff_v)))
void vlseg7e16ff_v_i16mf2(vint16mf2_t *, vint16mf2_t *, vint16mf2_t *, vint16mf2_t *, vint16mf2_t *, vint16mf2_t *, vint16mf2_t *, const int16_t *, size_t *, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vlseg7e16ff_v_m)))
void vlseg7e16ff_v_i16mf2_m(vint16mf2_t *, vint16mf2_t *, vint16mf2_t *, vint16mf2_t *, vint16mf2_t *, vint16mf2_t *, vint16mf2_t *, vbool32_t, vint16mf2_t, vint16mf2_t, vint16mf2_t, vint16mf2_t, vint16mf2_t, vint16mf2_t, vint16mf2_t, const int16_t *, size_t *, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vlseg7e16ff_v)))
void vlseg7e16ff_v_i16mf4(vint16mf4_t *, vint16mf4_t *, vint16mf4_t *, vint16mf4_t *, vint16mf4_t *, vint16mf4_t *, vint16mf4_t *, const int16_t *, size_t *, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vlseg7e16ff_v_m)))
void vlseg7e16ff_v_i16mf4_m(vint16mf4_t *, vint16mf4_t *, vint16mf4_t *, vint16mf4_t *, vint16mf4_t *, vint16mf4_t *, vint16mf4_t *, vbool64_t, vint16mf4_t, vint16mf4_t, vint16mf4_t, vint16mf4_t, vint16mf4_t, vint16mf4_t, vint16mf4_t, const int16_t *, size_t *, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vlseg7e16ff_v)))
void vlseg7e16ff_v_u16m1(vuint16m1_t *, vuint16m1_t *, vuint16m1_t *, vuint16m1_t *, vuint16m1_t *, vuint16m1_t *, vuint16m1_t *, const uint16_t *, size_t *, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vlseg7e16ff_v_m)))
void vlseg7e16ff_v_u16m1_m(vuint16m1_t *, vuint16m1_t *, vuint16m1_t *, vuint16m1_t *, vuint16m1_t *, vuint16m1_t *, vuint16m1_t *, vbool16_t, vuint16m1_t, vuint16m1_t, vuint16m1_t, vuint16m1_t, vuint16m1_t, vuint16m1_t, vuint16m1_t, const uint16_t *, size_t *, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vlseg7e16ff_v)))
void vlseg7e16ff_v_u16mf2(vuint16mf2_t *, vuint16mf2_t *, vuint16mf2_t *, vuint16mf2_t *, vuint16mf2_t *, vuint16mf2_t *, vuint16mf2_t *, const uint16_t *, size_t *, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vlseg7e16ff_v_m)))
void vlseg7e16ff_v_u16mf2_m(vuint16mf2_t *, vuint16mf2_t *, vuint16mf2_t *, vuint16mf2_t *, vuint16mf2_t *, vuint16mf2_t *, vuint16mf2_t *, vbool32_t, vuint16mf2_t, vuint16mf2_t, vuint16mf2_t, vuint16mf2_t, vuint16mf2_t, vuint16mf2_t, vuint16mf2_t, const uint16_t *, size_t *, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vlseg7e16ff_v)))
void vlseg7e16ff_v_u16mf4(vuint16mf4_t *, vuint16mf4_t *, vuint16mf4_t *, vuint16mf4_t *, vuint16mf4_t *, vuint16mf4_t *, vuint16mf4_t *, const uint16_t *, size_t *, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vlseg7e16ff_v_m)))
void vlseg7e16ff_v_u16mf4_m(vuint16mf4_t *, vuint16mf4_t *, vuint16mf4_t *, vuint16mf4_t *, vuint16mf4_t *, vuint16mf4_t *, vuint16mf4_t *, vbool64_t, vuint16mf4_t, vuint16mf4_t, vuint16mf4_t, vuint16mf4_t, vuint16mf4_t, vuint16mf4_t, vuint16mf4_t, const uint16_t *, size_t *, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vlseg8e16ff_v)))
void vlseg8e16ff_v_i16m1(vint16m1_t *, vint16m1_t *, vint16m1_t *, vint16m1_t *, vint16m1_t *, vint16m1_t *, vint16m1_t *, vint16m1_t *, const int16_t *, size_t *, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vlseg8e16ff_v_m)))
void vlseg8e16ff_v_i16m1_m(vint16m1_t *, vint16m1_t *, vint16m1_t *, vint16m1_t *, vint16m1_t *, vint16m1_t *, vint16m1_t *, vint16m1_t *, vbool16_t, vint16m1_t, vint16m1_t, vint16m1_t, vint16m1_t, vint16m1_t, vint16m1_t, vint16m1_t, vint16m1_t, const int16_t *, size_t *, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vlseg8e16ff_v)))
void vlseg8e16ff_v_i16mf2(vint16mf2_t *, vint16mf2_t *, vint16mf2_t *, vint16mf2_t *, vint16mf2_t *, vint16mf2_t *, vint16mf2_t *, vint16mf2_t *, const int16_t *, size_t *, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vlseg8e16ff_v_m)))
void vlseg8e16ff_v_i16mf2_m(vint16mf2_t *, vint16mf2_t *, vint16mf2_t *, vint16mf2_t *, vint16mf2_t *, vint16mf2_t *, vint16mf2_t *, vint16mf2_t *, vbool32_t, vint16mf2_t, vint16mf2_t, vint16mf2_t, vint16mf2_t, vint16mf2_t, vint16mf2_t, vint16mf2_t, vint16mf2_t, const int16_t *, size_t *, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vlseg8e16ff_v)))
void vlseg8e16ff_v_i16mf4(vint16mf4_t *, vint16mf4_t *, vint16mf4_t *, vint16mf4_t *, vint16mf4_t *, vint16mf4_t *, vint16mf4_t *, vint16mf4_t *, const int16_t *, size_t *, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vlseg8e16ff_v_m)))
void vlseg8e16ff_v_i16mf4_m(vint16mf4_t *, vint16mf4_t *, vint16mf4_t *, vint16mf4_t *, vint16mf4_t *, vint16mf4_t *, vint16mf4_t *, vint16mf4_t *, vbool64_t, vint16mf4_t, vint16mf4_t, vint16mf4_t, vint16mf4_t, vint16mf4_t, vint16mf4_t, vint16mf4_t, vint16mf4_t, const int16_t *, size_t *, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vlseg8e16ff_v)))
void vlseg8e16ff_v_u16m1(vuint16m1_t *, vuint16m1_t *, vuint16m1_t *, vuint16m1_t *, vuint16m1_t *, vuint16m1_t *, vuint16m1_t *, vuint16m1_t *, const uint16_t *, size_t *, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vlseg8e16ff_v_m)))
void vlseg8e16ff_v_u16m1_m(vuint16m1_t *, vuint16m1_t *, vuint16m1_t *, vuint16m1_t *, vuint16m1_t *, vuint16m1_t *, vuint16m1_t *, vuint16m1_t *, vbool16_t, vuint16m1_t, vuint16m1_t, vuint16m1_t, vuint16m1_t, vuint16m1_t, vuint16m1_t, vuint16m1_t, vuint16m1_t, const uint16_t *, size_t *, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vlseg8e16ff_v)))
void vlseg8e16ff_v_u16mf2(vuint16mf2_t *, vuint16mf2_t *, vuint16mf2_t *, vuint16mf2_t *, vuint16mf2_t *, vuint16mf2_t *, vuint16mf2_t *, vuint16mf2_t *, const uint16_t *, size_t *, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vlseg8e16ff_v_m)))
void vlseg8e16ff_v_u16mf2_m(vuint16mf2_t *, vuint16mf2_t *, vuint16mf2_t *, vuint16mf2_t *, vuint16mf2_t *, vuint16mf2_t *, vuint16mf2_t *, vuint16mf2_t *, vbool32_t, vuint16mf2_t, vuint16mf2_t, vuint16mf2_t, vuint16mf2_t, vuint16mf2_t, vuint16mf2_t, vuint16mf2_t, vuint16mf2_t, const uint16_t *, size_t *, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vlseg8e16ff_v)))
void vlseg8e16ff_v_u16mf4(vuint16mf4_t *, vuint16mf4_t *, vuint16mf4_t *, vuint16mf4_t *, vuint16mf4_t *, vuint16mf4_t *, vuint16mf4_t *, vuint16mf4_t *, const uint16_t *, size_t *, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vlseg8e16ff_v_m)))
void vlseg8e16ff_v_u16mf4_m(vuint16mf4_t *, vuint16mf4_t *, vuint16mf4_t *, vuint16mf4_t *, vuint16mf4_t *, vuint16mf4_t *, vuint16mf4_t *, vuint16mf4_t *, vbool64_t, vuint16mf4_t, vuint16mf4_t, vuint16mf4_t, vuint16mf4_t, vuint16mf4_t, vuint16mf4_t, vuint16mf4_t, vuint16mf4_t, const uint16_t *, size_t *, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vlseg2e32ff_v)))
void vlseg2e32ff_v_i32m1(vint32m1_t *, vint32m1_t *, const int32_t *, size_t *, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vlseg2e32ff_v_m)))
void vlseg2e32ff_v_i32m1_m(vint32m1_t *, vint32m1_t *, vbool32_t, vint32m1_t, vint32m1_t, const int32_t *, size_t *, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vlseg2e32ff_v)))
void vlseg2e32ff_v_i32m2(vint32m2_t *, vint32m2_t *, const int32_t *, size_t *, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vlseg2e32ff_v_m)))
void vlseg2e32ff_v_i32m2_m(vint32m2_t *, vint32m2_t *, vbool16_t, vint32m2_t, vint32m2_t, const int32_t *, size_t *, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vlseg2e32ff_v)))
void vlseg2e32ff_v_i32m4(vint32m4_t *, vint32m4_t *, const int32_t *, size_t *, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vlseg2e32ff_v_m)))
void vlseg2e32ff_v_i32m4_m(vint32m4_t *, vint32m4_t *, vbool8_t, vint32m4_t, vint32m4_t, const int32_t *, size_t *, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vlseg2e32ff_v)))
void vlseg2e32ff_v_i32mf2(vint32mf2_t *, vint32mf2_t *, const int32_t *, size_t *, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vlseg2e32ff_v_m)))
void vlseg2e32ff_v_i32mf2_m(vint32mf2_t *, vint32mf2_t *, vbool64_t, vint32mf2_t, vint32mf2_t, const int32_t *, size_t *, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vlseg2e32ff_v)))
void vlseg2e32ff_v_u32m1(vuint32m1_t *, vuint32m1_t *, const uint32_t *, size_t *, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vlseg2e32ff_v_m)))
void vlseg2e32ff_v_u32m1_m(vuint32m1_t *, vuint32m1_t *, vbool32_t, vuint32m1_t, vuint32m1_t, const uint32_t *, size_t *, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vlseg2e32ff_v)))
void vlseg2e32ff_v_u32m2(vuint32m2_t *, vuint32m2_t *, const uint32_t *, size_t *, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vlseg2e32ff_v_m)))
void vlseg2e32ff_v_u32m2_m(vuint32m2_t *, vuint32m2_t *, vbool16_t, vuint32m2_t, vuint32m2_t, const uint32_t *, size_t *, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vlseg2e32ff_v)))
void vlseg2e32ff_v_u32m4(vuint32m4_t *, vuint32m4_t *, const uint32_t *, size_t *, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vlseg2e32ff_v_m)))
void vlseg2e32ff_v_u32m4_m(vuint32m4_t *, vuint32m4_t *, vbool8_t, vuint32m4_t, vuint32m4_t, const uint32_t *, size_t *, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vlseg2e32ff_v)))
void vlseg2e32ff_v_u32mf2(vuint32mf2_t *, vuint32mf2_t *, const uint32_t *, size_t *, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vlseg2e32ff_v_m)))
void vlseg2e32ff_v_u32mf2_m(vuint32mf2_t *, vuint32mf2_t *, vbool64_t, vuint32mf2_t, vuint32mf2_t, const uint32_t *, size_t *, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vlseg3e32ff_v)))
void vlseg3e32ff_v_i32m1(vint32m1_t *, vint32m1_t *, vint32m1_t *, const int32_t *, size_t *, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vlseg3e32ff_v_m)))
void vlseg3e32ff_v_i32m1_m(vint32m1_t *, vint32m1_t *, vint32m1_t *, vbool32_t, vint32m1_t, vint32m1_t, vint32m1_t, const int32_t *, size_t *, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vlseg3e32ff_v)))
void vlseg3e32ff_v_i32m2(vint32m2_t *, vint32m2_t *, vint32m2_t *, const int32_t *, size_t *, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vlseg3e32ff_v_m)))
void vlseg3e32ff_v_i32m2_m(vint32m2_t *, vint32m2_t *, vint32m2_t *, vbool16_t, vint32m2_t, vint32m2_t, vint32m2_t, const int32_t *, size_t *, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vlseg3e32ff_v)))
void vlseg3e32ff_v_i32mf2(vint32mf2_t *, vint32mf2_t *, vint32mf2_t *, const int32_t *, size_t *, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vlseg3e32ff_v_m)))
void vlseg3e32ff_v_i32mf2_m(vint32mf2_t *, vint32mf2_t *, vint32mf2_t *, vbool64_t, vint32mf2_t, vint32mf2_t, vint32mf2_t, const int32_t *, size_t *, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vle8_v)))
vuint8m1_t vle8_v_u8m1(const uint8_t *, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vle8_v_m)))
vuint8m1_t vle8_v_u8m1_m(vbool8_t, vuint8m1_t, const uint8_t *, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vle8_v)))
vuint8m2_t vle8_v_u8m2(const uint8_t *, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vle8_v_m)))
vuint8m2_t vle8_v_u8m2_m(vbool4_t, vuint8m2_t, const uint8_t *, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vle8_v)))
vuint8m4_t vle8_v_u8m4(const uint8_t *, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vle8_v_m)))
vuint8m4_t vle8_v_u8m4_m(vbool2_t, vuint8m4_t, const uint8_t *, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vle8_v)))
vuint8m8_t vle8_v_u8m8(const uint8_t *, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vle8_v_m)))
vuint8m8_t vle8_v_u8m8_m(vbool1_t, vuint8m8_t, const uint8_t *, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vle8_v)))
vuint8mf2_t vle8_v_u8mf2(const uint8_t *, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vle8_v_m)))
vuint8mf2_t vle8_v_u8mf2_m(vbool16_t, vuint8mf2_t, const uint8_t *, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vle8_v)))
vuint8mf4_t vle8_v_u8mf4(const uint8_t *, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vle8_v_m)))
vuint8mf4_t vle8_v_u8mf4_m(vbool32_t, vuint8mf4_t, const uint8_t *, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vle8_v)))
vuint8mf8_t vle8_v_u8mf8(const uint8_t *, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vle8_v_m)))
vuint8mf8_t vle8_v_u8mf8_m(vbool64_t, vuint8mf8_t, const uint8_t *, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vlseg3e32ff_v)))
void vlseg3e32ff_v_u32m1(vuint32m1_t *, vuint32m1_t *, vuint32m1_t *, const uint32_t *, size_t *, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vlseg3e32ff_v_m)))
void vlseg3e32ff_v_u32m1_m(vuint32m1_t *, vuint32m1_t *, vuint32m1_t *, vbool32_t, vuint32m1_t, vuint32m1_t, vuint32m1_t, const uint32_t *, size_t *, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vlseg3e32ff_v)))
void vlseg3e32ff_v_u32m2(vuint32m2_t *, vuint32m2_t *, vuint32m2_t *, const uint32_t *, size_t *, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vlseg3e32ff_v_m)))
void vlseg3e32ff_v_u32m2_m(vuint32m2_t *, vuint32m2_t *, vuint32m2_t *, vbool16_t, vuint32m2_t, vuint32m2_t, vuint32m2_t, const uint32_t *, size_t *, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vlseg3e32ff_v)))
void vlseg3e32ff_v_u32mf2(vuint32mf2_t *, vuint32mf2_t *, vuint32mf2_t *, const uint32_t *, size_t *, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vlseg3e32ff_v_m)))
void vlseg3e32ff_v_u32mf2_m(vuint32mf2_t *, vuint32mf2_t *, vuint32mf2_t *, vbool64_t, vuint32mf2_t, vuint32mf2_t, vuint32mf2_t, const uint32_t *, size_t *, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vlseg4e32ff_v)))
void vlseg4e32ff_v_i32m1(vint32m1_t *, vint32m1_t *, vint32m1_t *, vint32m1_t *, const int32_t *, size_t *, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vlseg4e32ff_v_m)))
void vlseg4e32ff_v_i32m1_m(vint32m1_t *, vint32m1_t *, vint32m1_t *, vint32m1_t *, vbool32_t, vint32m1_t, vint32m1_t, vint32m1_t, vint32m1_t, const int32_t *, size_t *, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vlseg4e32ff_v)))
void vlseg4e32ff_v_i32m2(vint32m2_t *, vint32m2_t *, vint32m2_t *, vint32m2_t *, const int32_t *, size_t *, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vlseg4e32ff_v_m)))
void vlseg4e32ff_v_i32m2_m(vint32m2_t *, vint32m2_t *, vint32m2_t *, vint32m2_t *, vbool16_t, vint32m2_t, vint32m2_t, vint32m2_t, vint32m2_t, const int32_t *, size_t *, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vlseg4e32ff_v)))
void vlseg4e32ff_v_i32mf2(vint32mf2_t *, vint32mf2_t *, vint32mf2_t *, vint32mf2_t *, const int32_t *, size_t *, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vlseg4e32ff_v_m)))
void vlseg4e32ff_v_i32mf2_m(vint32mf2_t *, vint32mf2_t *, vint32mf2_t *, vint32mf2_t *, vbool64_t, vint32mf2_t, vint32mf2_t, vint32mf2_t, vint32mf2_t, const int32_t *, size_t *, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vlseg4e32ff_v)))
void vlseg4e32ff_v_u32m1(vuint32m1_t *, vuint32m1_t *, vuint32m1_t *, vuint32m1_t *, const uint32_t *, size_t *, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vlseg4e32ff_v_m)))
void vlseg4e32ff_v_u32m1_m(vuint32m1_t *, vuint32m1_t *, vuint32m1_t *, vuint32m1_t *, vbool32_t, vuint32m1_t, vuint32m1_t, vuint32m1_t, vuint32m1_t, const uint32_t *, size_t *, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vlseg4e32ff_v)))
void vlseg4e32ff_v_u32m2(vuint32m2_t *, vuint32m2_t *, vuint32m2_t *, vuint32m2_t *, const uint32_t *, size_t *, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vlseg4e32ff_v_m)))
void vlseg4e32ff_v_u32m2_m(vuint32m2_t *, vuint32m2_t *, vuint32m2_t *, vuint32m2_t *, vbool16_t, vuint32m2_t, vuint32m2_t, vuint32m2_t, vuint32m2_t, const uint32_t *, size_t *, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vlseg4e32ff_v)))
void vlseg4e32ff_v_u32mf2(vuint32mf2_t *, vuint32mf2_t *, vuint32mf2_t *, vuint32mf2_t *, const uint32_t *, size_t *, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vlseg4e32ff_v_m)))
void vlseg4e32ff_v_u32mf2_m(vuint32mf2_t *, vuint32mf2_t *, vuint32mf2_t *, vuint32mf2_t *, vbool64_t, vuint32mf2_t, vuint32mf2_t, vuint32mf2_t, vuint32mf2_t, const uint32_t *, size_t *, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vlseg5e32ff_v)))
void vlseg5e32ff_v_i32m1(vint32m1_t *, vint32m1_t *, vint32m1_t *, vint32m1_t *, vint32m1_t *, const int32_t *, size_t *, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vlseg5e32ff_v_m)))
void vlseg5e32ff_v_i32m1_m(vint32m1_t *, vint32m1_t *, vint32m1_t *, vint32m1_t *, vint32m1_t *, vbool32_t, vint32m1_t, vint32m1_t, vint32m1_t, vint32m1_t, vint32m1_t, const int32_t *, size_t *, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vlseg5e32ff_v)))
void vlseg5e32ff_v_i32mf2(vint32mf2_t *, vint32mf2_t *, vint32mf2_t *, vint32mf2_t *, vint32mf2_t *, const int32_t *, size_t *, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vlseg5e32ff_v_m)))
void vlseg5e32ff_v_i32mf2_m(vint32mf2_t *, vint32mf2_t *, vint32mf2_t *, vint32mf2_t *, vint32mf2_t *, vbool64_t, vint32mf2_t, vint32mf2_t, vint32mf2_t, vint32mf2_t, vint32mf2_t, const int32_t *, size_t *, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vlseg5e32ff_v)))
void vlseg5e32ff_v_u32m1(vuint32m1_t *, vuint32m1_t *, vuint32m1_t *, vuint32m1_t *, vuint32m1_t *, const uint32_t *, size_t *, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vlseg5e32ff_v_m)))
void vlseg5e32ff_v_u32m1_m(vuint32m1_t *, vuint32m1_t *, vuint32m1_t *, vuint32m1_t *, vuint32m1_t *, vbool32_t, vuint32m1_t, vuint32m1_t, vuint32m1_t, vuint32m1_t, vuint32m1_t, const uint32_t *, size_t *, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vlseg5e32ff_v)))
void vlseg5e32ff_v_u32mf2(vuint32mf2_t *, vuint32mf2_t *, vuint32mf2_t *, vuint32mf2_t *, vuint32mf2_t *, const uint32_t *, size_t *, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vlseg5e32ff_v_m)))
void vlseg5e32ff_v_u32mf2_m(vuint32mf2_t *, vuint32mf2_t *, vuint32mf2_t *, vuint32mf2_t *, vuint32mf2_t *, vbool64_t, vuint32mf2_t, vuint32mf2_t, vuint32mf2_t, vuint32mf2_t, vuint32mf2_t, const uint32_t *, size_t *, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vlseg6e32ff_v)))
void vlseg6e32ff_v_i32m1(vint32m1_t *, vint32m1_t *, vint32m1_t *, vint32m1_t *, vint32m1_t *, vint32m1_t *, const int32_t *, size_t *, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vlseg6e32ff_v_m)))
void vlseg6e32ff_v_i32m1_m(vint32m1_t *, vint32m1_t *, vint32m1_t *, vint32m1_t *, vint32m1_t *, vint32m1_t *, vbool32_t, vint32m1_t, vint32m1_t, vint32m1_t, vint32m1_t, vint32m1_t, vint32m1_t, const int32_t *, size_t *, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vlseg6e32ff_v)))
void vlseg6e32ff_v_i32mf2(vint32mf2_t *, vint32mf2_t *, vint32mf2_t *, vint32mf2_t *, vint32mf2_t *, vint32mf2_t *, const int32_t *, size_t *, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vlseg6e32ff_v_m)))
void vlseg6e32ff_v_i32mf2_m(vint32mf2_t *, vint32mf2_t *, vint32mf2_t *, vint32mf2_t *, vint32mf2_t *, vint32mf2_t *, vbool64_t, vint32mf2_t, vint32mf2_t, vint32mf2_t, vint32mf2_t, vint32mf2_t, vint32mf2_t, const int32_t *, size_t *, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vlseg6e32ff_v)))
void vlseg6e32ff_v_u32m1(vuint32m1_t *, vuint32m1_t *, vuint32m1_t *, vuint32m1_t *, vuint32m1_t *, vuint32m1_t *, const uint32_t *, size_t *, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vlseg6e32ff_v_m)))
void vlseg6e32ff_v_u32m1_m(vuint32m1_t *, vuint32m1_t *, vuint32m1_t *, vuint32m1_t *, vuint32m1_t *, vuint32m1_t *, vbool32_t, vuint32m1_t, vuint32m1_t, vuint32m1_t, vuint32m1_t, vuint32m1_t, vuint32m1_t, const uint32_t *, size_t *, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vlseg6e32ff_v)))
void vlseg6e32ff_v_u32mf2(vuint32mf2_t *, vuint32mf2_t *, vuint32mf2_t *, vuint32mf2_t *, vuint32mf2_t *, vuint32mf2_t *, const uint32_t *, size_t *, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vlseg6e32ff_v_m)))
void vlseg6e32ff_v_u32mf2_m(vuint32mf2_t *, vuint32mf2_t *, vuint32mf2_t *, vuint32mf2_t *, vuint32mf2_t *, vuint32mf2_t *, vbool64_t, vuint32mf2_t, vuint32mf2_t, vuint32mf2_t, vuint32mf2_t, vuint32mf2_t, vuint32mf2_t, const uint32_t *, size_t *, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vlseg7e32ff_v)))
void vlseg7e32ff_v_i32m1(vint32m1_t *, vint32m1_t *, vint32m1_t *, vint32m1_t *, vint32m1_t *, vint32m1_t *, vint32m1_t *, const int32_t *, size_t *, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vlseg7e32ff_v_m)))
void vlseg7e32ff_v_i32m1_m(vint32m1_t *, vint32m1_t *, vint32m1_t *, vint32m1_t *, vint32m1_t *, vint32m1_t *, vint32m1_t *, vbool32_t, vint32m1_t, vint32m1_t, vint32m1_t, vint32m1_t, vint32m1_t, vint32m1_t, vint32m1_t, const int32_t *, size_t *, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vlseg7e32ff_v)))
void vlseg7e32ff_v_i32mf2(vint32mf2_t *, vint32mf2_t *, vint32mf2_t *, vint32mf2_t *, vint32mf2_t *, vint32mf2_t *, vint32mf2_t *, const int32_t *, size_t *, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vlseg7e32ff_v_m)))
void vlseg7e32ff_v_i32mf2_m(vint32mf2_t *, vint32mf2_t *, vint32mf2_t *, vint32mf2_t *, vint32mf2_t *, vint32mf2_t *, vint32mf2_t *, vbool64_t, vint32mf2_t, vint32mf2_t, vint32mf2_t, vint32mf2_t, vint32mf2_t, vint32mf2_t, vint32mf2_t, const int32_t *, size_t *, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vlseg7e32ff_v)))
void vlseg7e32ff_v_u32m1(vuint32m1_t *, vuint32m1_t *, vuint32m1_t *, vuint32m1_t *, vuint32m1_t *, vuint32m1_t *, vuint32m1_t *, const uint32_t *, size_t *, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vlseg7e32ff_v_m)))
void vlseg7e32ff_v_u32m1_m(vuint32m1_t *, vuint32m1_t *, vuint32m1_t *, vuint32m1_t *, vuint32m1_t *, vuint32m1_t *, vuint32m1_t *, vbool32_t, vuint32m1_t, vuint32m1_t, vuint32m1_t, vuint32m1_t, vuint32m1_t, vuint32m1_t, vuint32m1_t, const uint32_t *, size_t *, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vlseg7e32ff_v)))
void vlseg7e32ff_v_u32mf2(vuint32mf2_t *, vuint32mf2_t *, vuint32mf2_t *, vuint32mf2_t *, vuint32mf2_t *, vuint32mf2_t *, vuint32mf2_t *, const uint32_t *, size_t *, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vlseg7e32ff_v_m)))
void vlseg7e32ff_v_u32mf2_m(vuint32mf2_t *, vuint32mf2_t *, vuint32mf2_t *, vuint32mf2_t *, vuint32mf2_t *, vuint32mf2_t *, vuint32mf2_t *, vbool64_t, vuint32mf2_t, vuint32mf2_t, vuint32mf2_t, vuint32mf2_t, vuint32mf2_t, vuint32mf2_t, vuint32mf2_t, const uint32_t *, size_t *, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vlseg8e32ff_v)))
void vlseg8e32ff_v_i32m1(vint32m1_t *, vint32m1_t *, vint32m1_t *, vint32m1_t *, vint32m1_t *, vint32m1_t *, vint32m1_t *, vint32m1_t *, const int32_t *, size_t *, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vlseg8e32ff_v_m)))
void vlseg8e32ff_v_i32m1_m(vint32m1_t *, vint32m1_t *, vint32m1_t *, vint32m1_t *, vint32m1_t *, vint32m1_t *, vint32m1_t *, vint32m1_t *, vbool32_t, vint32m1_t, vint32m1_t, vint32m1_t, vint32m1_t, vint32m1_t, vint32m1_t, vint32m1_t, vint32m1_t, const int32_t *, size_t *, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vlseg8e32ff_v)))
void vlseg8e32ff_v_i32mf2(vint32mf2_t *, vint32mf2_t *, vint32mf2_t *, vint32mf2_t *, vint32mf2_t *, vint32mf2_t *, vint32mf2_t *, vint32mf2_t *, const int32_t *, size_t *, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vlseg8e32ff_v_m)))
void vlseg8e32ff_v_i32mf2_m(vint32mf2_t *, vint32mf2_t *, vint32mf2_t *, vint32mf2_t *, vint32mf2_t *, vint32mf2_t *, vint32mf2_t *, vint32mf2_t *, vbool64_t, vint32mf2_t, vint32mf2_t, vint32mf2_t, vint32mf2_t, vint32mf2_t, vint32mf2_t, vint32mf2_t, vint32mf2_t, const int32_t *, size_t *, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vlseg8e32ff_v)))
void vlseg8e32ff_v_u32m1(vuint32m1_t *, vuint32m1_t *, vuint32m1_t *, vuint32m1_t *, vuint32m1_t *, vuint32m1_t *, vuint32m1_t *, vuint32m1_t *, const uint32_t *, size_t *, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vlseg8e32ff_v_m)))
void vlseg8e32ff_v_u32m1_m(vuint32m1_t *, vuint32m1_t *, vuint32m1_t *, vuint32m1_t *, vuint32m1_t *, vuint32m1_t *, vuint32m1_t *, vuint32m1_t *, vbool32_t, vuint32m1_t, vuint32m1_t, vuint32m1_t, vuint32m1_t, vuint32m1_t, vuint32m1_t, vuint32m1_t, vuint32m1_t, const uint32_t *, size_t *, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vlseg8e32ff_v)))
void vlseg8e32ff_v_u32mf2(vuint32mf2_t *, vuint32mf2_t *, vuint32mf2_t *, vuint32mf2_t *, vuint32mf2_t *, vuint32mf2_t *, vuint32mf2_t *, vuint32mf2_t *, const uint32_t *, size_t *, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vlseg8e32ff_v_m)))
void vlseg8e32ff_v_u32mf2_m(vuint32mf2_t *, vuint32mf2_t *, vuint32mf2_t *, vuint32mf2_t *, vuint32mf2_t *, vuint32mf2_t *, vuint32mf2_t *, vuint32mf2_t *, vbool64_t, vuint32mf2_t, vuint32mf2_t, vuint32mf2_t, vuint32mf2_t, vuint32mf2_t, vuint32mf2_t, vuint32mf2_t, vuint32mf2_t, const uint32_t *, size_t *, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vlseg2e8ff_v)))
void vlseg2e8ff_v_i8m1(vint8m1_t *, vint8m1_t *, const int8_t *, size_t *, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vlseg2e8ff_v_m)))
void vlseg2e8ff_v_i8m1_m(vint8m1_t *, vint8m1_t *, vbool8_t, vint8m1_t, vint8m1_t, const int8_t *, size_t *, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vlseg2e8ff_v)))
void vlseg2e8ff_v_i8m2(vint8m2_t *, vint8m2_t *, const int8_t *, size_t *, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vlseg2e8ff_v_m)))
void vlseg2e8ff_v_i8m2_m(vint8m2_t *, vint8m2_t *, vbool4_t, vint8m2_t, vint8m2_t, const int8_t *, size_t *, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vlseg2e8ff_v)))
void vlseg2e8ff_v_i8m4(vint8m4_t *, vint8m4_t *, const int8_t *, size_t *, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vlseg2e8ff_v_m)))
void vlseg2e8ff_v_i8m4_m(vint8m4_t *, vint8m4_t *, vbool2_t, vint8m4_t, vint8m4_t, const int8_t *, size_t *, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vlseg2e8ff_v)))
void vlseg2e8ff_v_i8mf2(vint8mf2_t *, vint8mf2_t *, const int8_t *, size_t *, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vlseg2e8ff_v_m)))
void vlseg2e8ff_v_i8mf2_m(vint8mf2_t *, vint8mf2_t *, vbool16_t, vint8mf2_t, vint8mf2_t, const int8_t *, size_t *, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vlseg2e8ff_v)))
void vlseg2e8ff_v_i8mf4(vint8mf4_t *, vint8mf4_t *, const int8_t *, size_t *, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vlseg2e8ff_v_m)))
void vlseg2e8ff_v_i8mf4_m(vint8mf4_t *, vint8mf4_t *, vbool32_t, vint8mf4_t, vint8mf4_t, const int8_t *, size_t *, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vlseg2e8ff_v)))
void vlseg2e8ff_v_i8mf8(vint8mf8_t *, vint8mf8_t *, const int8_t *, size_t *, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vlseg2e8ff_v_m)))
void vlseg2e8ff_v_i8mf8_m(vint8mf8_t *, vint8mf8_t *, vbool64_t, vint8mf8_t, vint8mf8_t, const int8_t *, size_t *, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vlsseg3e8_v)))
void vlsseg3e8_v_i8m1(vint8m1_t *, vint8m1_t *, vint8m1_t *, const int8_t *, ptrdiff_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vlsseg3e8_v_m)))
void vlsseg3e8_v_i8m1_m(vint8m1_t *, vint8m1_t *, vint8m1_t *, vbool8_t, vint8m1_t, vint8m1_t, vint8m1_t, const int8_t *, ptrdiff_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vlsseg3e8_v)))
void vlsseg3e8_v_i8m2(vint8m2_t *, vint8m2_t *, vint8m2_t *, const int8_t *, ptrdiff_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vlsseg3e8_v_m)))
void vlsseg3e8_v_i8m2_m(vint8m2_t *, vint8m2_t *, vint8m2_t *, vbool4_t, vint8m2_t, vint8m2_t, vint8m2_t, const int8_t *, ptrdiff_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vlsseg3e8_v)))
void vlsseg3e8_v_i8mf2(vint8mf2_t *, vint8mf2_t *, vint8mf2_t *, const int8_t *, ptrdiff_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vlsseg3e8_v_m)))
void vlsseg3e8_v_i8mf2_m(vint8mf2_t *, vint8mf2_t *, vint8mf2_t *, vbool16_t, vint8mf2_t, vint8mf2_t, vint8mf2_t, const int8_t *, ptrdiff_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vlsseg3e8_v)))
void vlsseg3e8_v_i8mf4(vint8mf4_t *, vint8mf4_t *, vint8mf4_t *, const int8_t *, ptrdiff_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vlsseg3e8_v_m)))
void vlsseg3e8_v_i8mf4_m(vint8mf4_t *, vint8mf4_t *, vint8mf4_t *, vbool32_t, vint8mf4_t, vint8mf4_t, vint8mf4_t, const int8_t *, ptrdiff_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vlsseg3e8_v)))
void vlsseg3e8_v_i8mf8(vint8mf8_t *, vint8mf8_t *, vint8mf8_t *, const int8_t *, ptrdiff_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vlsseg3e8_v_m)))
void vlsseg3e8_v_i8mf8_m(vint8mf8_t *, vint8mf8_t *, vint8mf8_t *, vbool64_t, vint8mf8_t, vint8mf8_t, vint8mf8_t, const int8_t *, ptrdiff_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vlsseg3e8_v)))
void vlsseg3e8_v_u8m1(vuint8m1_t *, vuint8m1_t *, vuint8m1_t *, const uint8_t *, ptrdiff_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vlsseg3e8_v_m)))
void vlsseg3e8_v_u8m1_m(vuint8m1_t *, vuint8m1_t *, vuint8m1_t *, vbool8_t, vuint8m1_t, vuint8m1_t, vuint8m1_t, const uint8_t *, ptrdiff_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vlsseg3e8_v)))
void vlsseg3e8_v_u8m2(vuint8m2_t *, vuint8m2_t *, vuint8m2_t *, const uint8_t *, ptrdiff_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vlsseg3e8_v_m)))
void vlsseg3e8_v_u8m2_m(vuint8m2_t *, vuint8m2_t *, vuint8m2_t *, vbool4_t, vuint8m2_t, vuint8m2_t, vuint8m2_t, const uint8_t *, ptrdiff_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vlsseg3e8_v)))
void vlsseg3e8_v_u8mf2(vuint8mf2_t *, vuint8mf2_t *, vuint8mf2_t *, const uint8_t *, ptrdiff_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vlsseg3e8_v_m)))
void vlsseg3e8_v_u8mf2_m(vuint8mf2_t *, vuint8mf2_t *, vuint8mf2_t *, vbool16_t, vuint8mf2_t, vuint8mf2_t, vuint8mf2_t, const uint8_t *, ptrdiff_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vlsseg3e8_v)))
void vlsseg3e8_v_u8mf4(vuint8mf4_t *, vuint8mf4_t *, vuint8mf4_t *, const uint8_t *, ptrdiff_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vlsseg3e8_v_m)))
void vlsseg3e8_v_u8mf4_m(vuint8mf4_t *, vuint8mf4_t *, vuint8mf4_t *, vbool32_t, vuint8mf4_t, vuint8mf4_t, vuint8mf4_t, const uint8_t *, ptrdiff_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vlsseg3e8_v)))
void vlsseg3e8_v_u8mf8(vuint8mf8_t *, vuint8mf8_t *, vuint8mf8_t *, const uint8_t *, ptrdiff_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vlsseg3e8_v_m)))
void vlsseg3e8_v_u8mf8_m(vuint8mf8_t *, vuint8mf8_t *, vuint8mf8_t *, vbool64_t, vuint8mf8_t, vuint8mf8_t, vuint8mf8_t, const uint8_t *, ptrdiff_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vlsseg4e8_v)))
void vlsseg4e8_v_i8m1(vint8m1_t *, vint8m1_t *, vint8m1_t *, vint8m1_t *, const int8_t *, ptrdiff_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vlsseg4e8_v_m)))
void vlsseg4e8_v_i8m1_m(vint8m1_t *, vint8m1_t *, vint8m1_t *, vint8m1_t *, vbool8_t, vint8m1_t, vint8m1_t, vint8m1_t, vint8m1_t, const int8_t *, ptrdiff_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vlsseg4e8_v)))
void vlsseg4e8_v_i8m2(vint8m2_t *, vint8m2_t *, vint8m2_t *, vint8m2_t *, const int8_t *, ptrdiff_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vlsseg4e8_v_m)))
void vlsseg4e8_v_i8m2_m(vint8m2_t *, vint8m2_t *, vint8m2_t *, vint8m2_t *, vbool4_t, vint8m2_t, vint8m2_t, vint8m2_t, vint8m2_t, const int8_t *, ptrdiff_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vlsseg4e8_v)))
void vlsseg4e8_v_i8mf2(vint8mf2_t *, vint8mf2_t *, vint8mf2_t *, vint8mf2_t *, const int8_t *, ptrdiff_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vlsseg4e8_v_m)))
void vlsseg4e8_v_i8mf2_m(vint8mf2_t *, vint8mf2_t *, vint8mf2_t *, vint8mf2_t *, vbool16_t, vint8mf2_t, vint8mf2_t, vint8mf2_t, vint8mf2_t, const int8_t *, ptrdiff_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vlsseg4e8_v)))
void vlsseg4e8_v_i8mf4(vint8mf4_t *, vint8mf4_t *, vint8mf4_t *, vint8mf4_t *, const int8_t *, ptrdiff_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vlsseg4e8_v_m)))
void vlsseg4e8_v_i8mf4_m(vint8mf4_t *, vint8mf4_t *, vint8mf4_t *, vint8mf4_t *, vbool32_t, vint8mf4_t, vint8mf4_t, vint8mf4_t, vint8mf4_t, const int8_t *, ptrdiff_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vlsseg4e8_v)))
void vlsseg4e8_v_i8mf8(vint8mf8_t *, vint8mf8_t *, vint8mf8_t *, vint8mf8_t *, const int8_t *, ptrdiff_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vlsseg4e8_v_m)))
void vlsseg4e8_v_i8mf8_m(vint8mf8_t *, vint8mf8_t *, vint8mf8_t *, vint8mf8_t *, vbool64_t, vint8mf8_t, vint8mf8_t, vint8mf8_t, vint8mf8_t, const int8_t *, ptrdiff_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vlseg2e8ff_v)))
void vlseg2e8ff_v_u8m1(vuint8m1_t *, vuint8m1_t *, const uint8_t *, size_t *, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vlseg2e8ff_v_m)))
void vlseg2e8ff_v_u8m1_m(vuint8m1_t *, vuint8m1_t *, vbool8_t, vuint8m1_t, vuint8m1_t, const uint8_t *, size_t *, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vlseg2e8ff_v)))
void vlseg2e8ff_v_u8m2(vuint8m2_t *, vuint8m2_t *, const uint8_t *, size_t *, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vlseg2e8ff_v_m)))
void vlseg2e8ff_v_u8m2_m(vuint8m2_t *, vuint8m2_t *, vbool4_t, vuint8m2_t, vuint8m2_t, const uint8_t *, size_t *, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vlseg2e8ff_v)))
void vlseg2e8ff_v_u8m4(vuint8m4_t *, vuint8m4_t *, const uint8_t *, size_t *, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vlseg2e8ff_v_m)))
void vlseg2e8ff_v_u8m4_m(vuint8m4_t *, vuint8m4_t *, vbool2_t, vuint8m4_t, vuint8m4_t, const uint8_t *, size_t *, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vlseg2e8ff_v)))
void vlseg2e8ff_v_u8mf2(vuint8mf2_t *, vuint8mf2_t *, const uint8_t *, size_t *, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vlseg2e8ff_v_m)))
void vlseg2e8ff_v_u8mf2_m(vuint8mf2_t *, vuint8mf2_t *, vbool16_t, vuint8mf2_t, vuint8mf2_t, const uint8_t *, size_t *, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vlseg2e8ff_v)))
void vlseg2e8ff_v_u8mf4(vuint8mf4_t *, vuint8mf4_t *, const uint8_t *, size_t *, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vlseg2e8ff_v_m)))
void vlseg2e8ff_v_u8mf4_m(vuint8mf4_t *, vuint8mf4_t *, vbool32_t, vuint8mf4_t, vuint8mf4_t, const uint8_t *, size_t *, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vlseg2e8ff_v)))
void vlseg2e8ff_v_u8mf8(vuint8mf8_t *, vuint8mf8_t *, const uint8_t *, size_t *, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vlseg2e8ff_v_m)))
void vlseg2e8ff_v_u8mf8_m(vuint8mf8_t *, vuint8mf8_t *, vbool64_t, vuint8mf8_t, vuint8mf8_t, const uint8_t *, size_t *, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vlsseg4e8_v)))
void vlsseg4e8_v_u8m1(vuint8m1_t *, vuint8m1_t *, vuint8m1_t *, vuint8m1_t *, const uint8_t *, ptrdiff_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vlsseg4e8_v_m)))
void vlsseg4e8_v_u8m1_m(vuint8m1_t *, vuint8m1_t *, vuint8m1_t *, vuint8m1_t *, vbool8_t, vuint8m1_t, vuint8m1_t, vuint8m1_t, vuint8m1_t, const uint8_t *, ptrdiff_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vlsseg4e8_v)))
void vlsseg4e8_v_u8m2(vuint8m2_t *, vuint8m2_t *, vuint8m2_t *, vuint8m2_t *, const uint8_t *, ptrdiff_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vlsseg4e8_v_m)))
void vlsseg4e8_v_u8m2_m(vuint8m2_t *, vuint8m2_t *, vuint8m2_t *, vuint8m2_t *, vbool4_t, vuint8m2_t, vuint8m2_t, vuint8m2_t, vuint8m2_t, const uint8_t *, ptrdiff_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vlsseg4e8_v)))
void vlsseg4e8_v_u8mf2(vuint8mf2_t *, vuint8mf2_t *, vuint8mf2_t *, vuint8mf2_t *, const uint8_t *, ptrdiff_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vlsseg4e8_v_m)))
void vlsseg4e8_v_u8mf2_m(vuint8mf2_t *, vuint8mf2_t *, vuint8mf2_t *, vuint8mf2_t *, vbool16_t, vuint8mf2_t, vuint8mf2_t, vuint8mf2_t, vuint8mf2_t, const uint8_t *, ptrdiff_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vlsseg4e8_v)))
void vlsseg4e8_v_u8mf4(vuint8mf4_t *, vuint8mf4_t *, vuint8mf4_t *, vuint8mf4_t *, const uint8_t *, ptrdiff_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vlsseg4e8_v_m)))
void vlsseg4e8_v_u8mf4_m(vuint8mf4_t *, vuint8mf4_t *, vuint8mf4_t *, vuint8mf4_t *, vbool32_t, vuint8mf4_t, vuint8mf4_t, vuint8mf4_t, vuint8mf4_t, const uint8_t *, ptrdiff_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vlsseg4e8_v)))
void vlsseg4e8_v_u8mf8(vuint8mf8_t *, vuint8mf8_t *, vuint8mf8_t *, vuint8mf8_t *, const uint8_t *, ptrdiff_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vlsseg4e8_v_m)))
void vlsseg4e8_v_u8mf8_m(vuint8mf8_t *, vuint8mf8_t *, vuint8mf8_t *, vuint8mf8_t *, vbool64_t, vuint8mf8_t, vuint8mf8_t, vuint8mf8_t, vuint8mf8_t, const uint8_t *, ptrdiff_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vlsseg5e8_v)))
void vlsseg5e8_v_i8m1(vint8m1_t *, vint8m1_t *, vint8m1_t *, vint8m1_t *, vint8m1_t *, const int8_t *, ptrdiff_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vlsseg5e8_v_m)))
void vlsseg5e8_v_i8m1_m(vint8m1_t *, vint8m1_t *, vint8m1_t *, vint8m1_t *, vint8m1_t *, vbool8_t, vint8m1_t, vint8m1_t, vint8m1_t, vint8m1_t, vint8m1_t, const int8_t *, ptrdiff_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vlsseg5e8_v)))
void vlsseg5e8_v_i8mf2(vint8mf2_t *, vint8mf2_t *, vint8mf2_t *, vint8mf2_t *, vint8mf2_t *, const int8_t *, ptrdiff_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vlsseg5e8_v_m)))
void vlsseg5e8_v_i8mf2_m(vint8mf2_t *, vint8mf2_t *, vint8mf2_t *, vint8mf2_t *, vint8mf2_t *, vbool16_t, vint8mf2_t, vint8mf2_t, vint8mf2_t, vint8mf2_t, vint8mf2_t, const int8_t *, ptrdiff_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vlsseg5e8_v)))
void vlsseg5e8_v_i8mf4(vint8mf4_t *, vint8mf4_t *, vint8mf4_t *, vint8mf4_t *, vint8mf4_t *, const int8_t *, ptrdiff_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vlsseg5e8_v_m)))
void vlsseg5e8_v_i8mf4_m(vint8mf4_t *, vint8mf4_t *, vint8mf4_t *, vint8mf4_t *, vint8mf4_t *, vbool32_t, vint8mf4_t, vint8mf4_t, vint8mf4_t, vint8mf4_t, vint8mf4_t, const int8_t *, ptrdiff_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vlsseg5e8_v)))
void vlsseg5e8_v_i8mf8(vint8mf8_t *, vint8mf8_t *, vint8mf8_t *, vint8mf8_t *, vint8mf8_t *, const int8_t *, ptrdiff_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vlsseg5e8_v_m)))
void vlsseg5e8_v_i8mf8_m(vint8mf8_t *, vint8mf8_t *, vint8mf8_t *, vint8mf8_t *, vint8mf8_t *, vbool64_t, vint8mf8_t, vint8mf8_t, vint8mf8_t, vint8mf8_t, vint8mf8_t, const int8_t *, ptrdiff_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vlsseg5e8_v)))
void vlsseg5e8_v_u8m1(vuint8m1_t *, vuint8m1_t *, vuint8m1_t *, vuint8m1_t *, vuint8m1_t *, const uint8_t *, ptrdiff_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vlsseg5e8_v_m)))
void vlsseg5e8_v_u8m1_m(vuint8m1_t *, vuint8m1_t *, vuint8m1_t *, vuint8m1_t *, vuint8m1_t *, vbool8_t, vuint8m1_t, vuint8m1_t, vuint8m1_t, vuint8m1_t, vuint8m1_t, const uint8_t *, ptrdiff_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vlsseg5e8_v)))
void vlsseg5e8_v_u8mf2(vuint8mf2_t *, vuint8mf2_t *, vuint8mf2_t *, vuint8mf2_t *, vuint8mf2_t *, const uint8_t *, ptrdiff_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vlsseg5e8_v_m)))
void vlsseg5e8_v_u8mf2_m(vuint8mf2_t *, vuint8mf2_t *, vuint8mf2_t *, vuint8mf2_t *, vuint8mf2_t *, vbool16_t, vuint8mf2_t, vuint8mf2_t, vuint8mf2_t, vuint8mf2_t, vuint8mf2_t, const uint8_t *, ptrdiff_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vlsseg5e8_v)))
void vlsseg5e8_v_u8mf4(vuint8mf4_t *, vuint8mf4_t *, vuint8mf4_t *, vuint8mf4_t *, vuint8mf4_t *, const uint8_t *, ptrdiff_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vlsseg5e8_v_m)))
void vlsseg5e8_v_u8mf4_m(vuint8mf4_t *, vuint8mf4_t *, vuint8mf4_t *, vuint8mf4_t *, vuint8mf4_t *, vbool32_t, vuint8mf4_t, vuint8mf4_t, vuint8mf4_t, vuint8mf4_t, vuint8mf4_t, const uint8_t *, ptrdiff_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vlsseg5e8_v)))
void vlsseg5e8_v_u8mf8(vuint8mf8_t *, vuint8mf8_t *, vuint8mf8_t *, vuint8mf8_t *, vuint8mf8_t *, const uint8_t *, ptrdiff_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vlsseg5e8_v_m)))
void vlsseg5e8_v_u8mf8_m(vuint8mf8_t *, vuint8mf8_t *, vuint8mf8_t *, vuint8mf8_t *, vuint8mf8_t *, vbool64_t, vuint8mf8_t, vuint8mf8_t, vuint8mf8_t, vuint8mf8_t, vuint8mf8_t, const uint8_t *, ptrdiff_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vlsseg6e8_v)))
void vlsseg6e8_v_i8m1(vint8m1_t *, vint8m1_t *, vint8m1_t *, vint8m1_t *, vint8m1_t *, vint8m1_t *, const int8_t *, ptrdiff_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vlsseg6e8_v_m)))
void vlsseg6e8_v_i8m1_m(vint8m1_t *, vint8m1_t *, vint8m1_t *, vint8m1_t *, vint8m1_t *, vint8m1_t *, vbool8_t, vint8m1_t, vint8m1_t, vint8m1_t, vint8m1_t, vint8m1_t, vint8m1_t, const int8_t *, ptrdiff_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vlsseg6e8_v)))
void vlsseg6e8_v_i8mf2(vint8mf2_t *, vint8mf2_t *, vint8mf2_t *, vint8mf2_t *, vint8mf2_t *, vint8mf2_t *, const int8_t *, ptrdiff_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vlsseg6e8_v_m)))
void vlsseg6e8_v_i8mf2_m(vint8mf2_t *, vint8mf2_t *, vint8mf2_t *, vint8mf2_t *, vint8mf2_t *, vint8mf2_t *, vbool16_t, vint8mf2_t, vint8mf2_t, vint8mf2_t, vint8mf2_t, vint8mf2_t, vint8mf2_t, const int8_t *, ptrdiff_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vlsseg6e8_v)))
void vlsseg6e8_v_i8mf4(vint8mf4_t *, vint8mf4_t *, vint8mf4_t *, vint8mf4_t *, vint8mf4_t *, vint8mf4_t *, const int8_t *, ptrdiff_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vlsseg6e8_v_m)))
void vlsseg6e8_v_i8mf4_m(vint8mf4_t *, vint8mf4_t *, vint8mf4_t *, vint8mf4_t *, vint8mf4_t *, vint8mf4_t *, vbool32_t, vint8mf4_t, vint8mf4_t, vint8mf4_t, vint8mf4_t, vint8mf4_t, vint8mf4_t, const int8_t *, ptrdiff_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vlsseg6e8_v)))
void vlsseg6e8_v_i8mf8(vint8mf8_t *, vint8mf8_t *, vint8mf8_t *, vint8mf8_t *, vint8mf8_t *, vint8mf8_t *, const int8_t *, ptrdiff_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vlsseg6e8_v_m)))
void vlsseg6e8_v_i8mf8_m(vint8mf8_t *, vint8mf8_t *, vint8mf8_t *, vint8mf8_t *, vint8mf8_t *, vint8mf8_t *, vbool64_t, vint8mf8_t, vint8mf8_t, vint8mf8_t, vint8mf8_t, vint8mf8_t, vint8mf8_t, const int8_t *, ptrdiff_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vlsseg6e8_v)))
void vlsseg6e8_v_u8m1(vuint8m1_t *, vuint8m1_t *, vuint8m1_t *, vuint8m1_t *, vuint8m1_t *, vuint8m1_t *, const uint8_t *, ptrdiff_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vlsseg6e8_v_m)))
void vlsseg6e8_v_u8m1_m(vuint8m1_t *, vuint8m1_t *, vuint8m1_t *, vuint8m1_t *, vuint8m1_t *, vuint8m1_t *, vbool8_t, vuint8m1_t, vuint8m1_t, vuint8m1_t, vuint8m1_t, vuint8m1_t, vuint8m1_t, const uint8_t *, ptrdiff_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vlsseg6e8_v)))
void vlsseg6e8_v_u8mf2(vuint8mf2_t *, vuint8mf2_t *, vuint8mf2_t *, vuint8mf2_t *, vuint8mf2_t *, vuint8mf2_t *, const uint8_t *, ptrdiff_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vlsseg6e8_v_m)))
void vlsseg6e8_v_u8mf2_m(vuint8mf2_t *, vuint8mf2_t *, vuint8mf2_t *, vuint8mf2_t *, vuint8mf2_t *, vuint8mf2_t *, vbool16_t, vuint8mf2_t, vuint8mf2_t, vuint8mf2_t, vuint8mf2_t, vuint8mf2_t, vuint8mf2_t, const uint8_t *, ptrdiff_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vlsseg6e8_v)))
void vlsseg6e8_v_u8mf4(vuint8mf4_t *, vuint8mf4_t *, vuint8mf4_t *, vuint8mf4_t *, vuint8mf4_t *, vuint8mf4_t *, const uint8_t *, ptrdiff_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vlsseg6e8_v_m)))
void vlsseg6e8_v_u8mf4_m(vuint8mf4_t *, vuint8mf4_t *, vuint8mf4_t *, vuint8mf4_t *, vuint8mf4_t *, vuint8mf4_t *, vbool32_t, vuint8mf4_t, vuint8mf4_t, vuint8mf4_t, vuint8mf4_t, vuint8mf4_t, vuint8mf4_t, const uint8_t *, ptrdiff_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vlsseg6e8_v)))
void vlsseg6e8_v_u8mf8(vuint8mf8_t *, vuint8mf8_t *, vuint8mf8_t *, vuint8mf8_t *, vuint8mf8_t *, vuint8mf8_t *, const uint8_t *, ptrdiff_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vlsseg6e8_v_m)))
void vlsseg6e8_v_u8mf8_m(vuint8mf8_t *, vuint8mf8_t *, vuint8mf8_t *, vuint8mf8_t *, vuint8mf8_t *, vuint8mf8_t *, vbool64_t, vuint8mf8_t, vuint8mf8_t, vuint8mf8_t, vuint8mf8_t, vuint8mf8_t, vuint8mf8_t, const uint8_t *, ptrdiff_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vlsseg7e8_v)))
void vlsseg7e8_v_i8m1(vint8m1_t *, vint8m1_t *, vint8m1_t *, vint8m1_t *, vint8m1_t *, vint8m1_t *, vint8m1_t *, const int8_t *, ptrdiff_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vlsseg7e8_v_m)))
void vlsseg7e8_v_i8m1_m(vint8m1_t *, vint8m1_t *, vint8m1_t *, vint8m1_t *, vint8m1_t *, vint8m1_t *, vint8m1_t *, vbool8_t, vint8m1_t, vint8m1_t, vint8m1_t, vint8m1_t, vint8m1_t, vint8m1_t, vint8m1_t, const int8_t *, ptrdiff_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vlsseg7e8_v)))
void vlsseg7e8_v_i8mf2(vint8mf2_t *, vint8mf2_t *, vint8mf2_t *, vint8mf2_t *, vint8mf2_t *, vint8mf2_t *, vint8mf2_t *, const int8_t *, ptrdiff_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vlsseg7e8_v_m)))
void vlsseg7e8_v_i8mf2_m(vint8mf2_t *, vint8mf2_t *, vint8mf2_t *, vint8mf2_t *, vint8mf2_t *, vint8mf2_t *, vint8mf2_t *, vbool16_t, vint8mf2_t, vint8mf2_t, vint8mf2_t, vint8mf2_t, vint8mf2_t, vint8mf2_t, vint8mf2_t, const int8_t *, ptrdiff_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vlsseg7e8_v)))
void vlsseg7e8_v_i8mf4(vint8mf4_t *, vint8mf4_t *, vint8mf4_t *, vint8mf4_t *, vint8mf4_t *, vint8mf4_t *, vint8mf4_t *, const int8_t *, ptrdiff_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vlsseg7e8_v_m)))
void vlsseg7e8_v_i8mf4_m(vint8mf4_t *, vint8mf4_t *, vint8mf4_t *, vint8mf4_t *, vint8mf4_t *, vint8mf4_t *, vint8mf4_t *, vbool32_t, vint8mf4_t, vint8mf4_t, vint8mf4_t, vint8mf4_t, vint8mf4_t, vint8mf4_t, vint8mf4_t, const int8_t *, ptrdiff_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vlsseg7e8_v)))
void vlsseg7e8_v_i8mf8(vint8mf8_t *, vint8mf8_t *, vint8mf8_t *, vint8mf8_t *, vint8mf8_t *, vint8mf8_t *, vint8mf8_t *, const int8_t *, ptrdiff_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vlsseg7e8_v_m)))
void vlsseg7e8_v_i8mf8_m(vint8mf8_t *, vint8mf8_t *, vint8mf8_t *, vint8mf8_t *, vint8mf8_t *, vint8mf8_t *, vint8mf8_t *, vbool64_t, vint8mf8_t, vint8mf8_t, vint8mf8_t, vint8mf8_t, vint8mf8_t, vint8mf8_t, vint8mf8_t, const int8_t *, ptrdiff_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vlsseg7e8_v)))
void vlsseg7e8_v_u8m1(vuint8m1_t *, vuint8m1_t *, vuint8m1_t *, vuint8m1_t *, vuint8m1_t *, vuint8m1_t *, vuint8m1_t *, const uint8_t *, ptrdiff_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vlsseg7e8_v_m)))
void vlsseg7e8_v_u8m1_m(vuint8m1_t *, vuint8m1_t *, vuint8m1_t *, vuint8m1_t *, vuint8m1_t *, vuint8m1_t *, vuint8m1_t *, vbool8_t, vuint8m1_t, vuint8m1_t, vuint8m1_t, vuint8m1_t, vuint8m1_t, vuint8m1_t, vuint8m1_t, const uint8_t *, ptrdiff_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vlsseg7e8_v)))
void vlsseg7e8_v_u8mf2(vuint8mf2_t *, vuint8mf2_t *, vuint8mf2_t *, vuint8mf2_t *, vuint8mf2_t *, vuint8mf2_t *, vuint8mf2_t *, const uint8_t *, ptrdiff_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vlsseg7e8_v_m)))
void vlsseg7e8_v_u8mf2_m(vuint8mf2_t *, vuint8mf2_t *, vuint8mf2_t *, vuint8mf2_t *, vuint8mf2_t *, vuint8mf2_t *, vuint8mf2_t *, vbool16_t, vuint8mf2_t, vuint8mf2_t, vuint8mf2_t, vuint8mf2_t, vuint8mf2_t, vuint8mf2_t, vuint8mf2_t, const uint8_t *, ptrdiff_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vlsseg7e8_v)))
void vlsseg7e8_v_u8mf4(vuint8mf4_t *, vuint8mf4_t *, vuint8mf4_t *, vuint8mf4_t *, vuint8mf4_t *, vuint8mf4_t *, vuint8mf4_t *, const uint8_t *, ptrdiff_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vlsseg7e8_v_m)))
void vlsseg7e8_v_u8mf4_m(vuint8mf4_t *, vuint8mf4_t *, vuint8mf4_t *, vuint8mf4_t *, vuint8mf4_t *, vuint8mf4_t *, vuint8mf4_t *, vbool32_t, vuint8mf4_t, vuint8mf4_t, vuint8mf4_t, vuint8mf4_t, vuint8mf4_t, vuint8mf4_t, vuint8mf4_t, const uint8_t *, ptrdiff_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vlsseg7e8_v)))
void vlsseg7e8_v_u8mf8(vuint8mf8_t *, vuint8mf8_t *, vuint8mf8_t *, vuint8mf8_t *, vuint8mf8_t *, vuint8mf8_t *, vuint8mf8_t *, const uint8_t *, ptrdiff_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vlsseg7e8_v_m)))
void vlsseg7e8_v_u8mf8_m(vuint8mf8_t *, vuint8mf8_t *, vuint8mf8_t *, vuint8mf8_t *, vuint8mf8_t *, vuint8mf8_t *, vuint8mf8_t *, vbool64_t, vuint8mf8_t, vuint8mf8_t, vuint8mf8_t, vuint8mf8_t, vuint8mf8_t, vuint8mf8_t, vuint8mf8_t, const uint8_t *, ptrdiff_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vlsseg8e8_v)))
void vlsseg8e8_v_i8m1(vint8m1_t *, vint8m1_t *, vint8m1_t *, vint8m1_t *, vint8m1_t *, vint8m1_t *, vint8m1_t *, vint8m1_t *, const int8_t *, ptrdiff_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vlsseg8e8_v_m)))
void vlsseg8e8_v_i8m1_m(vint8m1_t *, vint8m1_t *, vint8m1_t *, vint8m1_t *, vint8m1_t *, vint8m1_t *, vint8m1_t *, vint8m1_t *, vbool8_t, vint8m1_t, vint8m1_t, vint8m1_t, vint8m1_t, vint8m1_t, vint8m1_t, vint8m1_t, vint8m1_t, const int8_t *, ptrdiff_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vlsseg8e8_v)))
void vlsseg8e8_v_i8mf2(vint8mf2_t *, vint8mf2_t *, vint8mf2_t *, vint8mf2_t *, vint8mf2_t *, vint8mf2_t *, vint8mf2_t *, vint8mf2_t *, const int8_t *, ptrdiff_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vlsseg8e8_v_m)))
void vlsseg8e8_v_i8mf2_m(vint8mf2_t *, vint8mf2_t *, vint8mf2_t *, vint8mf2_t *, vint8mf2_t *, vint8mf2_t *, vint8mf2_t *, vint8mf2_t *, vbool16_t, vint8mf2_t, vint8mf2_t, vint8mf2_t, vint8mf2_t, vint8mf2_t, vint8mf2_t, vint8mf2_t, vint8mf2_t, const int8_t *, ptrdiff_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vlsseg8e8_v)))
void vlsseg8e8_v_i8mf4(vint8mf4_t *, vint8mf4_t *, vint8mf4_t *, vint8mf4_t *, vint8mf4_t *, vint8mf4_t *, vint8mf4_t *, vint8mf4_t *, const int8_t *, ptrdiff_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vlsseg8e8_v_m)))
void vlsseg8e8_v_i8mf4_m(vint8mf4_t *, vint8mf4_t *, vint8mf4_t *, vint8mf4_t *, vint8mf4_t *, vint8mf4_t *, vint8mf4_t *, vint8mf4_t *, vbool32_t, vint8mf4_t, vint8mf4_t, vint8mf4_t, vint8mf4_t, vint8mf4_t, vint8mf4_t, vint8mf4_t, vint8mf4_t, const int8_t *, ptrdiff_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vlsseg8e8_v)))
void vlsseg8e8_v_i8mf8(vint8mf8_t *, vint8mf8_t *, vint8mf8_t *, vint8mf8_t *, vint8mf8_t *, vint8mf8_t *, vint8mf8_t *, vint8mf8_t *, const int8_t *, ptrdiff_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vlsseg8e8_v_m)))
void vlsseg8e8_v_i8mf8_m(vint8mf8_t *, vint8mf8_t *, vint8mf8_t *, vint8mf8_t *, vint8mf8_t *, vint8mf8_t *, vint8mf8_t *, vint8mf8_t *, vbool64_t, vint8mf8_t, vint8mf8_t, vint8mf8_t, vint8mf8_t, vint8mf8_t, vint8mf8_t, vint8mf8_t, vint8mf8_t, const int8_t *, ptrdiff_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vlsseg8e8_v)))
void vlsseg8e8_v_u8m1(vuint8m1_t *, vuint8m1_t *, vuint8m1_t *, vuint8m1_t *, vuint8m1_t *, vuint8m1_t *, vuint8m1_t *, vuint8m1_t *, const uint8_t *, ptrdiff_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vlsseg8e8_v_m)))
void vlsseg8e8_v_u8m1_m(vuint8m1_t *, vuint8m1_t *, vuint8m1_t *, vuint8m1_t *, vuint8m1_t *, vuint8m1_t *, vuint8m1_t *, vuint8m1_t *, vbool8_t, vuint8m1_t, vuint8m1_t, vuint8m1_t, vuint8m1_t, vuint8m1_t, vuint8m1_t, vuint8m1_t, vuint8m1_t, const uint8_t *, ptrdiff_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vlsseg8e8_v)))
void vlsseg8e8_v_u8mf2(vuint8mf2_t *, vuint8mf2_t *, vuint8mf2_t *, vuint8mf2_t *, vuint8mf2_t *, vuint8mf2_t *, vuint8mf2_t *, vuint8mf2_t *, const uint8_t *, ptrdiff_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vlsseg8e8_v_m)))
void vlsseg8e8_v_u8mf2_m(vuint8mf2_t *, vuint8mf2_t *, vuint8mf2_t *, vuint8mf2_t *, vuint8mf2_t *, vuint8mf2_t *, vuint8mf2_t *, vuint8mf2_t *, vbool16_t, vuint8mf2_t, vuint8mf2_t, vuint8mf2_t, vuint8mf2_t, vuint8mf2_t, vuint8mf2_t, vuint8mf2_t, vuint8mf2_t, const uint8_t *, ptrdiff_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vlsseg8e8_v)))
void vlsseg8e8_v_u8mf4(vuint8mf4_t *, vuint8mf4_t *, vuint8mf4_t *, vuint8mf4_t *, vuint8mf4_t *, vuint8mf4_t *, vuint8mf4_t *, vuint8mf4_t *, const uint8_t *, ptrdiff_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vlsseg8e8_v_m)))
void vlsseg8e8_v_u8mf4_m(vuint8mf4_t *, vuint8mf4_t *, vuint8mf4_t *, vuint8mf4_t *, vuint8mf4_t *, vuint8mf4_t *, vuint8mf4_t *, vuint8mf4_t *, vbool32_t, vuint8mf4_t, vuint8mf4_t, vuint8mf4_t, vuint8mf4_t, vuint8mf4_t, vuint8mf4_t, vuint8mf4_t, vuint8mf4_t, const uint8_t *, ptrdiff_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vlsseg8e8_v)))
void vlsseg8e8_v_u8mf8(vuint8mf8_t *, vuint8mf8_t *, vuint8mf8_t *, vuint8mf8_t *, vuint8mf8_t *, vuint8mf8_t *, vuint8mf8_t *, vuint8mf8_t *, const uint8_t *, ptrdiff_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vlsseg8e8_v_m)))
void vlsseg8e8_v_u8mf8_m(vuint8mf8_t *, vuint8mf8_t *, vuint8mf8_t *, vuint8mf8_t *, vuint8mf8_t *, vuint8mf8_t *, vuint8mf8_t *, vuint8mf8_t *, vbool64_t, vuint8mf8_t, vuint8mf8_t, vuint8mf8_t, vuint8mf8_t, vuint8mf8_t, vuint8mf8_t, vuint8mf8_t, vuint8mf8_t, const uint8_t *, ptrdiff_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vlsseg2e16_v)))
void vlsseg2e16_v_i16m1(vint16m1_t *, vint16m1_t *, const int16_t *, ptrdiff_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vlsseg2e16_v_m)))
void vlsseg2e16_v_i16m1_m(vint16m1_t *, vint16m1_t *, vbool16_t, vint16m1_t, vint16m1_t, const int16_t *, ptrdiff_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vlsseg2e16_v)))
void vlsseg2e16_v_i16m2(vint16m2_t *, vint16m2_t *, const int16_t *, ptrdiff_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vlsseg2e16_v_m)))
void vlsseg2e16_v_i16m2_m(vint16m2_t *, vint16m2_t *, vbool8_t, vint16m2_t, vint16m2_t, const int16_t *, ptrdiff_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vlsseg2e16_v)))
void vlsseg2e16_v_i16m4(vint16m4_t *, vint16m4_t *, const int16_t *, ptrdiff_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vlsseg2e16_v_m)))
void vlsseg2e16_v_i16m4_m(vint16m4_t *, vint16m4_t *, vbool4_t, vint16m4_t, vint16m4_t, const int16_t *, ptrdiff_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vlsseg2e16_v)))
void vlsseg2e16_v_i16mf2(vint16mf2_t *, vint16mf2_t *, const int16_t *, ptrdiff_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vlsseg2e16_v_m)))
void vlsseg2e16_v_i16mf2_m(vint16mf2_t *, vint16mf2_t *, vbool32_t, vint16mf2_t, vint16mf2_t, const int16_t *, ptrdiff_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vlsseg2e16_v)))
void vlsseg2e16_v_i16mf4(vint16mf4_t *, vint16mf4_t *, const int16_t *, ptrdiff_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vlsseg2e16_v_m)))
void vlsseg2e16_v_i16mf4_m(vint16mf4_t *, vint16mf4_t *, vbool64_t, vint16mf4_t, vint16mf4_t, const int16_t *, ptrdiff_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vlsseg2e8_v)))
void vlsseg2e8_v_i8m1(vint8m1_t *, vint8m1_t *, const int8_t *, ptrdiff_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vlsseg2e8_v_m)))
void vlsseg2e8_v_i8m1_m(vint8m1_t *, vint8m1_t *, vbool8_t, vint8m1_t, vint8m1_t, const int8_t *, ptrdiff_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vlsseg2e8_v)))
void vlsseg2e8_v_i8m2(vint8m2_t *, vint8m2_t *, const int8_t *, ptrdiff_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vlsseg2e8_v_m)))
void vlsseg2e8_v_i8m2_m(vint8m2_t *, vint8m2_t *, vbool4_t, vint8m2_t, vint8m2_t, const int8_t *, ptrdiff_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vlsseg2e8_v)))
void vlsseg2e8_v_i8m4(vint8m4_t *, vint8m4_t *, const int8_t *, ptrdiff_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vlsseg2e8_v_m)))
void vlsseg2e8_v_i8m4_m(vint8m4_t *, vint8m4_t *, vbool2_t, vint8m4_t, vint8m4_t, const int8_t *, ptrdiff_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vlsseg2e8_v)))
void vlsseg2e8_v_i8mf2(vint8mf2_t *, vint8mf2_t *, const int8_t *, ptrdiff_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vlsseg2e8_v_m)))
void vlsseg2e8_v_i8mf2_m(vint8mf2_t *, vint8mf2_t *, vbool16_t, vint8mf2_t, vint8mf2_t, const int8_t *, ptrdiff_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vlsseg2e8_v)))
void vlsseg2e8_v_i8mf4(vint8mf4_t *, vint8mf4_t *, const int8_t *, ptrdiff_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vlsseg2e8_v_m)))
void vlsseg2e8_v_i8mf4_m(vint8mf4_t *, vint8mf4_t *, vbool32_t, vint8mf4_t, vint8mf4_t, const int8_t *, ptrdiff_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vlsseg2e8_v)))
void vlsseg2e8_v_i8mf8(vint8mf8_t *, vint8mf8_t *, const int8_t *, ptrdiff_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vlsseg2e8_v_m)))
void vlsseg2e8_v_i8mf8_m(vint8mf8_t *, vint8mf8_t *, vbool64_t, vint8mf8_t, vint8mf8_t, const int8_t *, ptrdiff_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vlsseg2e16_v)))
void vlsseg2e16_v_u16m1(vuint16m1_t *, vuint16m1_t *, const uint16_t *, ptrdiff_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vlsseg2e16_v_m)))
void vlsseg2e16_v_u16m1_m(vuint16m1_t *, vuint16m1_t *, vbool16_t, vuint16m1_t, vuint16m1_t, const uint16_t *, ptrdiff_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vlsseg2e16_v)))
void vlsseg2e16_v_u16m2(vuint16m2_t *, vuint16m2_t *, const uint16_t *, ptrdiff_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vlsseg2e16_v_m)))
void vlsseg2e16_v_u16m2_m(vuint16m2_t *, vuint16m2_t *, vbool8_t, vuint16m2_t, vuint16m2_t, const uint16_t *, ptrdiff_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vlsseg2e16_v)))
void vlsseg2e16_v_u16m4(vuint16m4_t *, vuint16m4_t *, const uint16_t *, ptrdiff_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vlsseg2e16_v_m)))
void vlsseg2e16_v_u16m4_m(vuint16m4_t *, vuint16m4_t *, vbool4_t, vuint16m4_t, vuint16m4_t, const uint16_t *, ptrdiff_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vlsseg2e16_v)))
void vlsseg2e16_v_u16mf2(vuint16mf2_t *, vuint16mf2_t *, const uint16_t *, ptrdiff_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vlsseg2e16_v_m)))
void vlsseg2e16_v_u16mf2_m(vuint16mf2_t *, vuint16mf2_t *, vbool32_t, vuint16mf2_t, vuint16mf2_t, const uint16_t *, ptrdiff_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vlsseg2e16_v)))
void vlsseg2e16_v_u16mf4(vuint16mf4_t *, vuint16mf4_t *, const uint16_t *, ptrdiff_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vlsseg2e16_v_m)))
void vlsseg2e16_v_u16mf4_m(vuint16mf4_t *, vuint16mf4_t *, vbool64_t, vuint16mf4_t, vuint16mf4_t, const uint16_t *, ptrdiff_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vlsseg3e16_v)))
void vlsseg3e16_v_i16m1(vint16m1_t *, vint16m1_t *, vint16m1_t *, const int16_t *, ptrdiff_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vlsseg3e16_v_m)))
void vlsseg3e16_v_i16m1_m(vint16m1_t *, vint16m1_t *, vint16m1_t *, vbool16_t, vint16m1_t, vint16m1_t, vint16m1_t, const int16_t *, ptrdiff_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vlsseg3e16_v)))
void vlsseg3e16_v_i16m2(vint16m2_t *, vint16m2_t *, vint16m2_t *, const int16_t *, ptrdiff_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vlsseg3e16_v_m)))
void vlsseg3e16_v_i16m2_m(vint16m2_t *, vint16m2_t *, vint16m2_t *, vbool8_t, vint16m2_t, vint16m2_t, vint16m2_t, const int16_t *, ptrdiff_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vlsseg3e16_v)))
void vlsseg3e16_v_i16mf2(vint16mf2_t *, vint16mf2_t *, vint16mf2_t *, const int16_t *, ptrdiff_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vlsseg3e16_v_m)))
void vlsseg3e16_v_i16mf2_m(vint16mf2_t *, vint16mf2_t *, vint16mf2_t *, vbool32_t, vint16mf2_t, vint16mf2_t, vint16mf2_t, const int16_t *, ptrdiff_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vlsseg3e16_v)))
void vlsseg3e16_v_i16mf4(vint16mf4_t *, vint16mf4_t *, vint16mf4_t *, const int16_t *, ptrdiff_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vlsseg3e16_v_m)))
void vlsseg3e16_v_i16mf4_m(vint16mf4_t *, vint16mf4_t *, vint16mf4_t *, vbool64_t, vint16mf4_t, vint16mf4_t, vint16mf4_t, const int16_t *, ptrdiff_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vlsseg3e16_v)))
void vlsseg3e16_v_u16m1(vuint16m1_t *, vuint16m1_t *, vuint16m1_t *, const uint16_t *, ptrdiff_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vlsseg3e16_v_m)))
void vlsseg3e16_v_u16m1_m(vuint16m1_t *, vuint16m1_t *, vuint16m1_t *, vbool16_t, vuint16m1_t, vuint16m1_t, vuint16m1_t, const uint16_t *, ptrdiff_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vlsseg3e16_v)))
void vlsseg3e16_v_u16m2(vuint16m2_t *, vuint16m2_t *, vuint16m2_t *, const uint16_t *, ptrdiff_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vlsseg3e16_v_m)))
void vlsseg3e16_v_u16m2_m(vuint16m2_t *, vuint16m2_t *, vuint16m2_t *, vbool8_t, vuint16m2_t, vuint16m2_t, vuint16m2_t, const uint16_t *, ptrdiff_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vlsseg3e16_v)))
void vlsseg3e16_v_u16mf2(vuint16mf2_t *, vuint16mf2_t *, vuint16mf2_t *, const uint16_t *, ptrdiff_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vlsseg3e16_v_m)))
void vlsseg3e16_v_u16mf2_m(vuint16mf2_t *, vuint16mf2_t *, vuint16mf2_t *, vbool32_t, vuint16mf2_t, vuint16mf2_t, vuint16mf2_t, const uint16_t *, ptrdiff_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vlsseg3e16_v)))
void vlsseg3e16_v_u16mf4(vuint16mf4_t *, vuint16mf4_t *, vuint16mf4_t *, const uint16_t *, ptrdiff_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vlsseg3e16_v_m)))
void vlsseg3e16_v_u16mf4_m(vuint16mf4_t *, vuint16mf4_t *, vuint16mf4_t *, vbool64_t, vuint16mf4_t, vuint16mf4_t, vuint16mf4_t, const uint16_t *, ptrdiff_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vlsseg4e16_v)))
void vlsseg4e16_v_i16m1(vint16m1_t *, vint16m1_t *, vint16m1_t *, vint16m1_t *, const int16_t *, ptrdiff_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vlsseg4e16_v_m)))
void vlsseg4e16_v_i16m1_m(vint16m1_t *, vint16m1_t *, vint16m1_t *, vint16m1_t *, vbool16_t, vint16m1_t, vint16m1_t, vint16m1_t, vint16m1_t, const int16_t *, ptrdiff_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vlsseg4e16_v)))
void vlsseg4e16_v_i16m2(vint16m2_t *, vint16m2_t *, vint16m2_t *, vint16m2_t *, const int16_t *, ptrdiff_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vlsseg4e16_v_m)))
void vlsseg4e16_v_i16m2_m(vint16m2_t *, vint16m2_t *, vint16m2_t *, vint16m2_t *, vbool8_t, vint16m2_t, vint16m2_t, vint16m2_t, vint16m2_t, const int16_t *, ptrdiff_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vlsseg4e16_v)))
void vlsseg4e16_v_i16mf2(vint16mf2_t *, vint16mf2_t *, vint16mf2_t *, vint16mf2_t *, const int16_t *, ptrdiff_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vlsseg4e16_v_m)))
void vlsseg4e16_v_i16mf2_m(vint16mf2_t *, vint16mf2_t *, vint16mf2_t *, vint16mf2_t *, vbool32_t, vint16mf2_t, vint16mf2_t, vint16mf2_t, vint16mf2_t, const int16_t *, ptrdiff_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vlsseg4e16_v)))
void vlsseg4e16_v_i16mf4(vint16mf4_t *, vint16mf4_t *, vint16mf4_t *, vint16mf4_t *, const int16_t *, ptrdiff_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vlsseg4e16_v_m)))
void vlsseg4e16_v_i16mf4_m(vint16mf4_t *, vint16mf4_t *, vint16mf4_t *, vint16mf4_t *, vbool64_t, vint16mf4_t, vint16mf4_t, vint16mf4_t, vint16mf4_t, const int16_t *, ptrdiff_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vlsseg4e16_v)))
void vlsseg4e16_v_u16m1(vuint16m1_t *, vuint16m1_t *, vuint16m1_t *, vuint16m1_t *, const uint16_t *, ptrdiff_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vlsseg4e16_v_m)))
void vlsseg4e16_v_u16m1_m(vuint16m1_t *, vuint16m1_t *, vuint16m1_t *, vuint16m1_t *, vbool16_t, vuint16m1_t, vuint16m1_t, vuint16m1_t, vuint16m1_t, const uint16_t *, ptrdiff_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vlsseg4e16_v)))
void vlsseg4e16_v_u16m2(vuint16m2_t *, vuint16m2_t *, vuint16m2_t *, vuint16m2_t *, const uint16_t *, ptrdiff_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vlsseg4e16_v_m)))
void vlsseg4e16_v_u16m2_m(vuint16m2_t *, vuint16m2_t *, vuint16m2_t *, vuint16m2_t *, vbool8_t, vuint16m2_t, vuint16m2_t, vuint16m2_t, vuint16m2_t, const uint16_t *, ptrdiff_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vlsseg4e16_v)))
void vlsseg4e16_v_u16mf2(vuint16mf2_t *, vuint16mf2_t *, vuint16mf2_t *, vuint16mf2_t *, const uint16_t *, ptrdiff_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vlsseg4e16_v_m)))
void vlsseg4e16_v_u16mf2_m(vuint16mf2_t *, vuint16mf2_t *, vuint16mf2_t *, vuint16mf2_t *, vbool32_t, vuint16mf2_t, vuint16mf2_t, vuint16mf2_t, vuint16mf2_t, const uint16_t *, ptrdiff_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vlsseg4e16_v)))
void vlsseg4e16_v_u16mf4(vuint16mf4_t *, vuint16mf4_t *, vuint16mf4_t *, vuint16mf4_t *, const uint16_t *, ptrdiff_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vlsseg4e16_v_m)))
void vlsseg4e16_v_u16mf4_m(vuint16mf4_t *, vuint16mf4_t *, vuint16mf4_t *, vuint16mf4_t *, vbool64_t, vuint16mf4_t, vuint16mf4_t, vuint16mf4_t, vuint16mf4_t, const uint16_t *, ptrdiff_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vlsseg5e16_v)))
void vlsseg5e16_v_i16m1(vint16m1_t *, vint16m1_t *, vint16m1_t *, vint16m1_t *, vint16m1_t *, const int16_t *, ptrdiff_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vlsseg5e16_v_m)))
void vlsseg5e16_v_i16m1_m(vint16m1_t *, vint16m1_t *, vint16m1_t *, vint16m1_t *, vint16m1_t *, vbool16_t, vint16m1_t, vint16m1_t, vint16m1_t, vint16m1_t, vint16m1_t, const int16_t *, ptrdiff_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vlsseg5e16_v)))
void vlsseg5e16_v_i16mf2(vint16mf2_t *, vint16mf2_t *, vint16mf2_t *, vint16mf2_t *, vint16mf2_t *, const int16_t *, ptrdiff_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vlsseg5e16_v_m)))
void vlsseg5e16_v_i16mf2_m(vint16mf2_t *, vint16mf2_t *, vint16mf2_t *, vint16mf2_t *, vint16mf2_t *, vbool32_t, vint16mf2_t, vint16mf2_t, vint16mf2_t, vint16mf2_t, vint16mf2_t, const int16_t *, ptrdiff_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vlsseg5e16_v)))
void vlsseg5e16_v_i16mf4(vint16mf4_t *, vint16mf4_t *, vint16mf4_t *, vint16mf4_t *, vint16mf4_t *, const int16_t *, ptrdiff_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vlsseg5e16_v_m)))
void vlsseg5e16_v_i16mf4_m(vint16mf4_t *, vint16mf4_t *, vint16mf4_t *, vint16mf4_t *, vint16mf4_t *, vbool64_t, vint16mf4_t, vint16mf4_t, vint16mf4_t, vint16mf4_t, vint16mf4_t, const int16_t *, ptrdiff_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vlsseg5e16_v)))
void vlsseg5e16_v_u16m1(vuint16m1_t *, vuint16m1_t *, vuint16m1_t *, vuint16m1_t *, vuint16m1_t *, const uint16_t *, ptrdiff_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vlsseg5e16_v_m)))
void vlsseg5e16_v_u16m1_m(vuint16m1_t *, vuint16m1_t *, vuint16m1_t *, vuint16m1_t *, vuint16m1_t *, vbool16_t, vuint16m1_t, vuint16m1_t, vuint16m1_t, vuint16m1_t, vuint16m1_t, const uint16_t *, ptrdiff_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vlsseg5e16_v)))
void vlsseg5e16_v_u16mf2(vuint16mf2_t *, vuint16mf2_t *, vuint16mf2_t *, vuint16mf2_t *, vuint16mf2_t *, const uint16_t *, ptrdiff_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vlsseg5e16_v_m)))
void vlsseg5e16_v_u16mf2_m(vuint16mf2_t *, vuint16mf2_t *, vuint16mf2_t *, vuint16mf2_t *, vuint16mf2_t *, vbool32_t, vuint16mf2_t, vuint16mf2_t, vuint16mf2_t, vuint16mf2_t, vuint16mf2_t, const uint16_t *, ptrdiff_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vlsseg5e16_v)))
void vlsseg5e16_v_u16mf4(vuint16mf4_t *, vuint16mf4_t *, vuint16mf4_t *, vuint16mf4_t *, vuint16mf4_t *, const uint16_t *, ptrdiff_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vlsseg5e16_v_m)))
void vlsseg5e16_v_u16mf4_m(vuint16mf4_t *, vuint16mf4_t *, vuint16mf4_t *, vuint16mf4_t *, vuint16mf4_t *, vbool64_t, vuint16mf4_t, vuint16mf4_t, vuint16mf4_t, vuint16mf4_t, vuint16mf4_t, const uint16_t *, ptrdiff_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vlsseg6e16_v)))
void vlsseg6e16_v_i16m1(vint16m1_t *, vint16m1_t *, vint16m1_t *, vint16m1_t *, vint16m1_t *, vint16m1_t *, const int16_t *, ptrdiff_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vlsseg6e16_v_m)))
void vlsseg6e16_v_i16m1_m(vint16m1_t *, vint16m1_t *, vint16m1_t *, vint16m1_t *, vint16m1_t *, vint16m1_t *, vbool16_t, vint16m1_t, vint16m1_t, vint16m1_t, vint16m1_t, vint16m1_t, vint16m1_t, const int16_t *, ptrdiff_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vlsseg6e16_v)))
void vlsseg6e16_v_i16mf2(vint16mf2_t *, vint16mf2_t *, vint16mf2_t *, vint16mf2_t *, vint16mf2_t *, vint16mf2_t *, const int16_t *, ptrdiff_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vlsseg6e16_v_m)))
void vlsseg6e16_v_i16mf2_m(vint16mf2_t *, vint16mf2_t *, vint16mf2_t *, vint16mf2_t *, vint16mf2_t *, vint16mf2_t *, vbool32_t, vint16mf2_t, vint16mf2_t, vint16mf2_t, vint16mf2_t, vint16mf2_t, vint16mf2_t, const int16_t *, ptrdiff_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vlsseg6e16_v)))
void vlsseg6e16_v_i16mf4(vint16mf4_t *, vint16mf4_t *, vint16mf4_t *, vint16mf4_t *, vint16mf4_t *, vint16mf4_t *, const int16_t *, ptrdiff_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vlsseg6e16_v_m)))
void vlsseg6e16_v_i16mf4_m(vint16mf4_t *, vint16mf4_t *, vint16mf4_t *, vint16mf4_t *, vint16mf4_t *, vint16mf4_t *, vbool64_t, vint16mf4_t, vint16mf4_t, vint16mf4_t, vint16mf4_t, vint16mf4_t, vint16mf4_t, const int16_t *, ptrdiff_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vlsseg6e16_v)))
void vlsseg6e16_v_u16m1(vuint16m1_t *, vuint16m1_t *, vuint16m1_t *, vuint16m1_t *, vuint16m1_t *, vuint16m1_t *, const uint16_t *, ptrdiff_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vlsseg6e16_v_m)))
void vlsseg6e16_v_u16m1_m(vuint16m1_t *, vuint16m1_t *, vuint16m1_t *, vuint16m1_t *, vuint16m1_t *, vuint16m1_t *, vbool16_t, vuint16m1_t, vuint16m1_t, vuint16m1_t, vuint16m1_t, vuint16m1_t, vuint16m1_t, const uint16_t *, ptrdiff_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vlsseg6e16_v)))
void vlsseg6e16_v_u16mf2(vuint16mf2_t *, vuint16mf2_t *, vuint16mf2_t *, vuint16mf2_t *, vuint16mf2_t *, vuint16mf2_t *, const uint16_t *, ptrdiff_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vlsseg6e16_v_m)))
void vlsseg6e16_v_u16mf2_m(vuint16mf2_t *, vuint16mf2_t *, vuint16mf2_t *, vuint16mf2_t *, vuint16mf2_t *, vuint16mf2_t *, vbool32_t, vuint16mf2_t, vuint16mf2_t, vuint16mf2_t, vuint16mf2_t, vuint16mf2_t, vuint16mf2_t, const uint16_t *, ptrdiff_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vlsseg6e16_v)))
void vlsseg6e16_v_u16mf4(vuint16mf4_t *, vuint16mf4_t *, vuint16mf4_t *, vuint16mf4_t *, vuint16mf4_t *, vuint16mf4_t *, const uint16_t *, ptrdiff_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vlsseg6e16_v_m)))
void vlsseg6e16_v_u16mf4_m(vuint16mf4_t *, vuint16mf4_t *, vuint16mf4_t *, vuint16mf4_t *, vuint16mf4_t *, vuint16mf4_t *, vbool64_t, vuint16mf4_t, vuint16mf4_t, vuint16mf4_t, vuint16mf4_t, vuint16mf4_t, vuint16mf4_t, const uint16_t *, ptrdiff_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vlsseg7e16_v)))
void vlsseg7e16_v_i16m1(vint16m1_t *, vint16m1_t *, vint16m1_t *, vint16m1_t *, vint16m1_t *, vint16m1_t *, vint16m1_t *, const int16_t *, ptrdiff_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vlsseg7e16_v_m)))
void vlsseg7e16_v_i16m1_m(vint16m1_t *, vint16m1_t *, vint16m1_t *, vint16m1_t *, vint16m1_t *, vint16m1_t *, vint16m1_t *, vbool16_t, vint16m1_t, vint16m1_t, vint16m1_t, vint16m1_t, vint16m1_t, vint16m1_t, vint16m1_t, const int16_t *, ptrdiff_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vlsseg7e16_v)))
void vlsseg7e16_v_i16mf2(vint16mf2_t *, vint16mf2_t *, vint16mf2_t *, vint16mf2_t *, vint16mf2_t *, vint16mf2_t *, vint16mf2_t *, const int16_t *, ptrdiff_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vlsseg7e16_v_m)))
void vlsseg7e16_v_i16mf2_m(vint16mf2_t *, vint16mf2_t *, vint16mf2_t *, vint16mf2_t *, vint16mf2_t *, vint16mf2_t *, vint16mf2_t *, vbool32_t, vint16mf2_t, vint16mf2_t, vint16mf2_t, vint16mf2_t, vint16mf2_t, vint16mf2_t, vint16mf2_t, const int16_t *, ptrdiff_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vlsseg7e16_v)))
void vlsseg7e16_v_i16mf4(vint16mf4_t *, vint16mf4_t *, vint16mf4_t *, vint16mf4_t *, vint16mf4_t *, vint16mf4_t *, vint16mf4_t *, const int16_t *, ptrdiff_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vlsseg7e16_v_m)))
void vlsseg7e16_v_i16mf4_m(vint16mf4_t *, vint16mf4_t *, vint16mf4_t *, vint16mf4_t *, vint16mf4_t *, vint16mf4_t *, vint16mf4_t *, vbool64_t, vint16mf4_t, vint16mf4_t, vint16mf4_t, vint16mf4_t, vint16mf4_t, vint16mf4_t, vint16mf4_t, const int16_t *, ptrdiff_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vlsseg2e8_v)))
void vlsseg2e8_v_u8m1(vuint8m1_t *, vuint8m1_t *, const uint8_t *, ptrdiff_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vlsseg2e8_v_m)))
void vlsseg2e8_v_u8m1_m(vuint8m1_t *, vuint8m1_t *, vbool8_t, vuint8m1_t, vuint8m1_t, const uint8_t *, ptrdiff_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vlsseg2e8_v)))
void vlsseg2e8_v_u8m2(vuint8m2_t *, vuint8m2_t *, const uint8_t *, ptrdiff_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vlsseg2e8_v_m)))
void vlsseg2e8_v_u8m2_m(vuint8m2_t *, vuint8m2_t *, vbool4_t, vuint8m2_t, vuint8m2_t, const uint8_t *, ptrdiff_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vlsseg2e8_v)))
void vlsseg2e8_v_u8m4(vuint8m4_t *, vuint8m4_t *, const uint8_t *, ptrdiff_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vlsseg2e8_v_m)))
void vlsseg2e8_v_u8m4_m(vuint8m4_t *, vuint8m4_t *, vbool2_t, vuint8m4_t, vuint8m4_t, const uint8_t *, ptrdiff_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vlsseg2e8_v)))
void vlsseg2e8_v_u8mf2(vuint8mf2_t *, vuint8mf2_t *, const uint8_t *, ptrdiff_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vlsseg2e8_v_m)))
void vlsseg2e8_v_u8mf2_m(vuint8mf2_t *, vuint8mf2_t *, vbool16_t, vuint8mf2_t, vuint8mf2_t, const uint8_t *, ptrdiff_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vlsseg2e8_v)))
void vlsseg2e8_v_u8mf4(vuint8mf4_t *, vuint8mf4_t *, const uint8_t *, ptrdiff_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vlsseg2e8_v_m)))
void vlsseg2e8_v_u8mf4_m(vuint8mf4_t *, vuint8mf4_t *, vbool32_t, vuint8mf4_t, vuint8mf4_t, const uint8_t *, ptrdiff_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vlsseg2e8_v)))
void vlsseg2e8_v_u8mf8(vuint8mf8_t *, vuint8mf8_t *, const uint8_t *, ptrdiff_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vlsseg2e8_v_m)))
void vlsseg2e8_v_u8mf8_m(vuint8mf8_t *, vuint8mf8_t *, vbool64_t, vuint8mf8_t, vuint8mf8_t, const uint8_t *, ptrdiff_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vlsseg7e16_v)))
void vlsseg7e16_v_u16m1(vuint16m1_t *, vuint16m1_t *, vuint16m1_t *, vuint16m1_t *, vuint16m1_t *, vuint16m1_t *, vuint16m1_t *, const uint16_t *, ptrdiff_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vlsseg7e16_v_m)))
void vlsseg7e16_v_u16m1_m(vuint16m1_t *, vuint16m1_t *, vuint16m1_t *, vuint16m1_t *, vuint16m1_t *, vuint16m1_t *, vuint16m1_t *, vbool16_t, vuint16m1_t, vuint16m1_t, vuint16m1_t, vuint16m1_t, vuint16m1_t, vuint16m1_t, vuint16m1_t, const uint16_t *, ptrdiff_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vlsseg7e16_v)))
void vlsseg7e16_v_u16mf2(vuint16mf2_t *, vuint16mf2_t *, vuint16mf2_t *, vuint16mf2_t *, vuint16mf2_t *, vuint16mf2_t *, vuint16mf2_t *, const uint16_t *, ptrdiff_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vlsseg7e16_v_m)))
void vlsseg7e16_v_u16mf2_m(vuint16mf2_t *, vuint16mf2_t *, vuint16mf2_t *, vuint16mf2_t *, vuint16mf2_t *, vuint16mf2_t *, vuint16mf2_t *, vbool32_t, vuint16mf2_t, vuint16mf2_t, vuint16mf2_t, vuint16mf2_t, vuint16mf2_t, vuint16mf2_t, vuint16mf2_t, const uint16_t *, ptrdiff_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vlsseg7e16_v)))
void vlsseg7e16_v_u16mf4(vuint16mf4_t *, vuint16mf4_t *, vuint16mf4_t *, vuint16mf4_t *, vuint16mf4_t *, vuint16mf4_t *, vuint16mf4_t *, const uint16_t *, ptrdiff_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vlsseg7e16_v_m)))
void vlsseg7e16_v_u16mf4_m(vuint16mf4_t *, vuint16mf4_t *, vuint16mf4_t *, vuint16mf4_t *, vuint16mf4_t *, vuint16mf4_t *, vuint16mf4_t *, vbool64_t, vuint16mf4_t, vuint16mf4_t, vuint16mf4_t, vuint16mf4_t, vuint16mf4_t, vuint16mf4_t, vuint16mf4_t, const uint16_t *, ptrdiff_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vlsseg8e16_v)))
void vlsseg8e16_v_i16m1(vint16m1_t *, vint16m1_t *, vint16m1_t *, vint16m1_t *, vint16m1_t *, vint16m1_t *, vint16m1_t *, vint16m1_t *, const int16_t *, ptrdiff_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vlsseg8e16_v_m)))
void vlsseg8e16_v_i16m1_m(vint16m1_t *, vint16m1_t *, vint16m1_t *, vint16m1_t *, vint16m1_t *, vint16m1_t *, vint16m1_t *, vint16m1_t *, vbool16_t, vint16m1_t, vint16m1_t, vint16m1_t, vint16m1_t, vint16m1_t, vint16m1_t, vint16m1_t, vint16m1_t, const int16_t *, ptrdiff_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vlsseg8e16_v)))
void vlsseg8e16_v_i16mf2(vint16mf2_t *, vint16mf2_t *, vint16mf2_t *, vint16mf2_t *, vint16mf2_t *, vint16mf2_t *, vint16mf2_t *, vint16mf2_t *, const int16_t *, ptrdiff_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vlsseg8e16_v_m)))
void vlsseg8e16_v_i16mf2_m(vint16mf2_t *, vint16mf2_t *, vint16mf2_t *, vint16mf2_t *, vint16mf2_t *, vint16mf2_t *, vint16mf2_t *, vint16mf2_t *, vbool32_t, vint16mf2_t, vint16mf2_t, vint16mf2_t, vint16mf2_t, vint16mf2_t, vint16mf2_t, vint16mf2_t, vint16mf2_t, const int16_t *, ptrdiff_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vlsseg8e16_v)))
void vlsseg8e16_v_i16mf4(vint16mf4_t *, vint16mf4_t *, vint16mf4_t *, vint16mf4_t *, vint16mf4_t *, vint16mf4_t *, vint16mf4_t *, vint16mf4_t *, const int16_t *, ptrdiff_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vlsseg8e16_v_m)))
void vlsseg8e16_v_i16mf4_m(vint16mf4_t *, vint16mf4_t *, vint16mf4_t *, vint16mf4_t *, vint16mf4_t *, vint16mf4_t *, vint16mf4_t *, vint16mf4_t *, vbool64_t, vint16mf4_t, vint16mf4_t, vint16mf4_t, vint16mf4_t, vint16mf4_t, vint16mf4_t, vint16mf4_t, vint16mf4_t, const int16_t *, ptrdiff_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vlsseg8e16_v)))
void vlsseg8e16_v_u16m1(vuint16m1_t *, vuint16m1_t *, vuint16m1_t *, vuint16m1_t *, vuint16m1_t *, vuint16m1_t *, vuint16m1_t *, vuint16m1_t *, const uint16_t *, ptrdiff_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vlsseg8e16_v_m)))
void vlsseg8e16_v_u16m1_m(vuint16m1_t *, vuint16m1_t *, vuint16m1_t *, vuint16m1_t *, vuint16m1_t *, vuint16m1_t *, vuint16m1_t *, vuint16m1_t *, vbool16_t, vuint16m1_t, vuint16m1_t, vuint16m1_t, vuint16m1_t, vuint16m1_t, vuint16m1_t, vuint16m1_t, vuint16m1_t, const uint16_t *, ptrdiff_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vlsseg8e16_v)))
void vlsseg8e16_v_u16mf2(vuint16mf2_t *, vuint16mf2_t *, vuint16mf2_t *, vuint16mf2_t *, vuint16mf2_t *, vuint16mf2_t *, vuint16mf2_t *, vuint16mf2_t *, const uint16_t *, ptrdiff_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vlsseg8e16_v_m)))
void vlsseg8e16_v_u16mf2_m(vuint16mf2_t *, vuint16mf2_t *, vuint16mf2_t *, vuint16mf2_t *, vuint16mf2_t *, vuint16mf2_t *, vuint16mf2_t *, vuint16mf2_t *, vbool32_t, vuint16mf2_t, vuint16mf2_t, vuint16mf2_t, vuint16mf2_t, vuint16mf2_t, vuint16mf2_t, vuint16mf2_t, vuint16mf2_t, const uint16_t *, ptrdiff_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vlsseg8e16_v)))
void vlsseg8e16_v_u16mf4(vuint16mf4_t *, vuint16mf4_t *, vuint16mf4_t *, vuint16mf4_t *, vuint16mf4_t *, vuint16mf4_t *, vuint16mf4_t *, vuint16mf4_t *, const uint16_t *, ptrdiff_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vlsseg8e16_v_m)))
void vlsseg8e16_v_u16mf4_m(vuint16mf4_t *, vuint16mf4_t *, vuint16mf4_t *, vuint16mf4_t *, vuint16mf4_t *, vuint16mf4_t *, vuint16mf4_t *, vuint16mf4_t *, vbool64_t, vuint16mf4_t, vuint16mf4_t, vuint16mf4_t, vuint16mf4_t, vuint16mf4_t, vuint16mf4_t, vuint16mf4_t, vuint16mf4_t, const uint16_t *, ptrdiff_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vlsseg2e32_v)))
void vlsseg2e32_v_i32m1(vint32m1_t *, vint32m1_t *, const int32_t *, ptrdiff_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vlsseg2e32_v_m)))
void vlsseg2e32_v_i32m1_m(vint32m1_t *, vint32m1_t *, vbool32_t, vint32m1_t, vint32m1_t, const int32_t *, ptrdiff_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vlsseg2e32_v)))
void vlsseg2e32_v_i32m2(vint32m2_t *, vint32m2_t *, const int32_t *, ptrdiff_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vlsseg2e32_v_m)))
void vlsseg2e32_v_i32m2_m(vint32m2_t *, vint32m2_t *, vbool16_t, vint32m2_t, vint32m2_t, const int32_t *, ptrdiff_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vlsseg2e32_v)))
void vlsseg2e32_v_i32m4(vint32m4_t *, vint32m4_t *, const int32_t *, ptrdiff_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vlsseg2e32_v_m)))
void vlsseg2e32_v_i32m4_m(vint32m4_t *, vint32m4_t *, vbool8_t, vint32m4_t, vint32m4_t, const int32_t *, ptrdiff_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vlsseg2e32_v)))
void vlsseg2e32_v_i32mf2(vint32mf2_t *, vint32mf2_t *, const int32_t *, ptrdiff_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vlsseg2e32_v_m)))
void vlsseg2e32_v_i32mf2_m(vint32mf2_t *, vint32mf2_t *, vbool64_t, vint32mf2_t, vint32mf2_t, const int32_t *, ptrdiff_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vlsseg2e32_v)))
void vlsseg2e32_v_u32m1(vuint32m1_t *, vuint32m1_t *, const uint32_t *, ptrdiff_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vlsseg2e32_v_m)))
void vlsseg2e32_v_u32m1_m(vuint32m1_t *, vuint32m1_t *, vbool32_t, vuint32m1_t, vuint32m1_t, const uint32_t *, ptrdiff_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vlsseg2e32_v)))
void vlsseg2e32_v_u32m2(vuint32m2_t *, vuint32m2_t *, const uint32_t *, ptrdiff_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vlsseg2e32_v_m)))
void vlsseg2e32_v_u32m2_m(vuint32m2_t *, vuint32m2_t *, vbool16_t, vuint32m2_t, vuint32m2_t, const uint32_t *, ptrdiff_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vlsseg2e32_v)))
void vlsseg2e32_v_u32m4(vuint32m4_t *, vuint32m4_t *, const uint32_t *, ptrdiff_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vlsseg2e32_v_m)))
void vlsseg2e32_v_u32m4_m(vuint32m4_t *, vuint32m4_t *, vbool8_t, vuint32m4_t, vuint32m4_t, const uint32_t *, ptrdiff_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vlsseg2e32_v)))
void vlsseg2e32_v_u32mf2(vuint32mf2_t *, vuint32mf2_t *, const uint32_t *, ptrdiff_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vlsseg2e32_v_m)))
void vlsseg2e32_v_u32mf2_m(vuint32mf2_t *, vuint32mf2_t *, vbool64_t, vuint32mf2_t, vuint32mf2_t, const uint32_t *, ptrdiff_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vlsseg3e32_v)))
void vlsseg3e32_v_i32m1(vint32m1_t *, vint32m1_t *, vint32m1_t *, const int32_t *, ptrdiff_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vlsseg3e32_v_m)))
void vlsseg3e32_v_i32m1_m(vint32m1_t *, vint32m1_t *, vint32m1_t *, vbool32_t, vint32m1_t, vint32m1_t, vint32m1_t, const int32_t *, ptrdiff_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vlsseg3e32_v)))
void vlsseg3e32_v_i32m2(vint32m2_t *, vint32m2_t *, vint32m2_t *, const int32_t *, ptrdiff_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vlsseg3e32_v_m)))
void vlsseg3e32_v_i32m2_m(vint32m2_t *, vint32m2_t *, vint32m2_t *, vbool16_t, vint32m2_t, vint32m2_t, vint32m2_t, const int32_t *, ptrdiff_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vlsseg3e32_v)))
void vlsseg3e32_v_i32mf2(vint32mf2_t *, vint32mf2_t *, vint32mf2_t *, const int32_t *, ptrdiff_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vlsseg3e32_v_m)))
void vlsseg3e32_v_i32mf2_m(vint32mf2_t *, vint32mf2_t *, vint32mf2_t *, vbool64_t, vint32mf2_t, vint32mf2_t, vint32mf2_t, const int32_t *, ptrdiff_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vlsseg3e32_v)))
void vlsseg3e32_v_u32m1(vuint32m1_t *, vuint32m1_t *, vuint32m1_t *, const uint32_t *, ptrdiff_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vlsseg3e32_v_m)))
void vlsseg3e32_v_u32m1_m(vuint32m1_t *, vuint32m1_t *, vuint32m1_t *, vbool32_t, vuint32m1_t, vuint32m1_t, vuint32m1_t, const uint32_t *, ptrdiff_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vlsseg3e32_v)))
void vlsseg3e32_v_u32m2(vuint32m2_t *, vuint32m2_t *, vuint32m2_t *, const uint32_t *, ptrdiff_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vlsseg3e32_v_m)))
void vlsseg3e32_v_u32m2_m(vuint32m2_t *, vuint32m2_t *, vuint32m2_t *, vbool16_t, vuint32m2_t, vuint32m2_t, vuint32m2_t, const uint32_t *, ptrdiff_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vlsseg3e32_v)))
void vlsseg3e32_v_u32mf2(vuint32mf2_t *, vuint32mf2_t *, vuint32mf2_t *, const uint32_t *, ptrdiff_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vlsseg3e32_v_m)))
void vlsseg3e32_v_u32mf2_m(vuint32mf2_t *, vuint32mf2_t *, vuint32mf2_t *, vbool64_t, vuint32mf2_t, vuint32mf2_t, vuint32mf2_t, const uint32_t *, ptrdiff_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vlsseg4e32_v)))
void vlsseg4e32_v_i32m1(vint32m1_t *, vint32m1_t *, vint32m1_t *, vint32m1_t *, const int32_t *, ptrdiff_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vlsseg4e32_v_m)))
void vlsseg4e32_v_i32m1_m(vint32m1_t *, vint32m1_t *, vint32m1_t *, vint32m1_t *, vbool32_t, vint32m1_t, vint32m1_t, vint32m1_t, vint32m1_t, const int32_t *, ptrdiff_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vlsseg4e32_v)))
void vlsseg4e32_v_i32m2(vint32m2_t *, vint32m2_t *, vint32m2_t *, vint32m2_t *, const int32_t *, ptrdiff_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vlsseg4e32_v_m)))
void vlsseg4e32_v_i32m2_m(vint32m2_t *, vint32m2_t *, vint32m2_t *, vint32m2_t *, vbool16_t, vint32m2_t, vint32m2_t, vint32m2_t, vint32m2_t, const int32_t *, ptrdiff_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vlsseg4e32_v)))
void vlsseg4e32_v_i32mf2(vint32mf2_t *, vint32mf2_t *, vint32mf2_t *, vint32mf2_t *, const int32_t *, ptrdiff_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vlsseg4e32_v_m)))
void vlsseg4e32_v_i32mf2_m(vint32mf2_t *, vint32mf2_t *, vint32mf2_t *, vint32mf2_t *, vbool64_t, vint32mf2_t, vint32mf2_t, vint32mf2_t, vint32mf2_t, const int32_t *, ptrdiff_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vlsseg4e32_v)))
void vlsseg4e32_v_u32m1(vuint32m1_t *, vuint32m1_t *, vuint32m1_t *, vuint32m1_t *, const uint32_t *, ptrdiff_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vlsseg4e32_v_m)))
void vlsseg4e32_v_u32m1_m(vuint32m1_t *, vuint32m1_t *, vuint32m1_t *, vuint32m1_t *, vbool32_t, vuint32m1_t, vuint32m1_t, vuint32m1_t, vuint32m1_t, const uint32_t *, ptrdiff_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vlsseg4e32_v)))
void vlsseg4e32_v_u32m2(vuint32m2_t *, vuint32m2_t *, vuint32m2_t *, vuint32m2_t *, const uint32_t *, ptrdiff_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vlsseg4e32_v_m)))
void vlsseg4e32_v_u32m2_m(vuint32m2_t *, vuint32m2_t *, vuint32m2_t *, vuint32m2_t *, vbool16_t, vuint32m2_t, vuint32m2_t, vuint32m2_t, vuint32m2_t, const uint32_t *, ptrdiff_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vlsseg4e32_v)))
void vlsseg4e32_v_u32mf2(vuint32mf2_t *, vuint32mf2_t *, vuint32mf2_t *, vuint32mf2_t *, const uint32_t *, ptrdiff_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vlsseg4e32_v_m)))
void vlsseg4e32_v_u32mf2_m(vuint32mf2_t *, vuint32mf2_t *, vuint32mf2_t *, vuint32mf2_t *, vbool64_t, vuint32mf2_t, vuint32mf2_t, vuint32mf2_t, vuint32mf2_t, const uint32_t *, ptrdiff_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vlsseg5e32_v)))
void vlsseg5e32_v_i32m1(vint32m1_t *, vint32m1_t *, vint32m1_t *, vint32m1_t *, vint32m1_t *, const int32_t *, ptrdiff_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vlsseg5e32_v_m)))
void vlsseg5e32_v_i32m1_m(vint32m1_t *, vint32m1_t *, vint32m1_t *, vint32m1_t *, vint32m1_t *, vbool32_t, vint32m1_t, vint32m1_t, vint32m1_t, vint32m1_t, vint32m1_t, const int32_t *, ptrdiff_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vlsseg5e32_v)))
void vlsseg5e32_v_i32mf2(vint32mf2_t *, vint32mf2_t *, vint32mf2_t *, vint32mf2_t *, vint32mf2_t *, const int32_t *, ptrdiff_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vlsseg5e32_v_m)))
void vlsseg5e32_v_i32mf2_m(vint32mf2_t *, vint32mf2_t *, vint32mf2_t *, vint32mf2_t *, vint32mf2_t *, vbool64_t, vint32mf2_t, vint32mf2_t, vint32mf2_t, vint32mf2_t, vint32mf2_t, const int32_t *, ptrdiff_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vluxseg2ei8_v)))
void vluxseg2ei8_v_i8m1(vint8m1_t *, vint8m1_t *, const int8_t *, vuint8m1_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vluxseg2ei8_v_m)))
void vluxseg2ei8_v_i8m1_m(vint8m1_t *, vint8m1_t *, vbool8_t, vint8m1_t, vint8m1_t, const int8_t *, vuint8m1_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vluxseg2ei8_v)))
void vluxseg2ei8_v_i8m2(vint8m2_t *, vint8m2_t *, const int8_t *, vuint8m2_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vluxseg2ei8_v_m)))
void vluxseg2ei8_v_i8m2_m(vint8m2_t *, vint8m2_t *, vbool4_t, vint8m2_t, vint8m2_t, const int8_t *, vuint8m2_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vluxseg2ei8_v)))
void vluxseg2ei8_v_i8m4(vint8m4_t *, vint8m4_t *, const int8_t *, vuint8m4_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vluxseg2ei8_v_m)))
void vluxseg2ei8_v_i8m4_m(vint8m4_t *, vint8m4_t *, vbool2_t, vint8m4_t, vint8m4_t, const int8_t *, vuint8m4_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vluxseg2ei8_v)))
void vluxseg2ei8_v_i8mf2(vint8mf2_t *, vint8mf2_t *, const int8_t *, vuint8mf2_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vluxseg2ei8_v_m)))
void vluxseg2ei8_v_i8mf2_m(vint8mf2_t *, vint8mf2_t *, vbool16_t, vint8mf2_t, vint8mf2_t, const int8_t *, vuint8mf2_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vluxseg2ei8_v)))
void vluxseg2ei8_v_i8mf4(vint8mf4_t *, vint8mf4_t *, const int8_t *, vuint8mf4_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vluxseg2ei8_v_m)))
void vluxseg2ei8_v_i8mf4_m(vint8mf4_t *, vint8mf4_t *, vbool32_t, vint8mf4_t, vint8mf4_t, const int8_t *, vuint8mf4_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vluxseg2ei8_v)))
void vluxseg2ei8_v_i8mf8(vint8mf8_t *, vint8mf8_t *, const int8_t *, vuint8mf8_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vluxseg2ei8_v_m)))
void vluxseg2ei8_v_i8mf8_m(vint8mf8_t *, vint8mf8_t *, vbool64_t, vint8mf8_t, vint8mf8_t, const int8_t *, vuint8mf8_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vlsseg5e32_v)))
void vlsseg5e32_v_u32m1(vuint32m1_t *, vuint32m1_t *, vuint32m1_t *, vuint32m1_t *, vuint32m1_t *, const uint32_t *, ptrdiff_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vlsseg5e32_v_m)))
void vlsseg5e32_v_u32m1_m(vuint32m1_t *, vuint32m1_t *, vuint32m1_t *, vuint32m1_t *, vuint32m1_t *, vbool32_t, vuint32m1_t, vuint32m1_t, vuint32m1_t, vuint32m1_t, vuint32m1_t, const uint32_t *, ptrdiff_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vlsseg5e32_v)))
void vlsseg5e32_v_u32mf2(vuint32mf2_t *, vuint32mf2_t *, vuint32mf2_t *, vuint32mf2_t *, vuint32mf2_t *, const uint32_t *, ptrdiff_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vlsseg5e32_v_m)))
void vlsseg5e32_v_u32mf2_m(vuint32mf2_t *, vuint32mf2_t *, vuint32mf2_t *, vuint32mf2_t *, vuint32mf2_t *, vbool64_t, vuint32mf2_t, vuint32mf2_t, vuint32mf2_t, vuint32mf2_t, vuint32mf2_t, const uint32_t *, ptrdiff_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vlsseg6e32_v)))
void vlsseg6e32_v_i32m1(vint32m1_t *, vint32m1_t *, vint32m1_t *, vint32m1_t *, vint32m1_t *, vint32m1_t *, const int32_t *, ptrdiff_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vlsseg6e32_v_m)))
void vlsseg6e32_v_i32m1_m(vint32m1_t *, vint32m1_t *, vint32m1_t *, vint32m1_t *, vint32m1_t *, vint32m1_t *, vbool32_t, vint32m1_t, vint32m1_t, vint32m1_t, vint32m1_t, vint32m1_t, vint32m1_t, const int32_t *, ptrdiff_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vlsseg6e32_v)))
void vlsseg6e32_v_i32mf2(vint32mf2_t *, vint32mf2_t *, vint32mf2_t *, vint32mf2_t *, vint32mf2_t *, vint32mf2_t *, const int32_t *, ptrdiff_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vlsseg6e32_v_m)))
void vlsseg6e32_v_i32mf2_m(vint32mf2_t *, vint32mf2_t *, vint32mf2_t *, vint32mf2_t *, vint32mf2_t *, vint32mf2_t *, vbool64_t, vint32mf2_t, vint32mf2_t, vint32mf2_t, vint32mf2_t, vint32mf2_t, vint32mf2_t, const int32_t *, ptrdiff_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vlsseg6e32_v)))
void vlsseg6e32_v_u32m1(vuint32m1_t *, vuint32m1_t *, vuint32m1_t *, vuint32m1_t *, vuint32m1_t *, vuint32m1_t *, const uint32_t *, ptrdiff_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vlsseg6e32_v_m)))
void vlsseg6e32_v_u32m1_m(vuint32m1_t *, vuint32m1_t *, vuint32m1_t *, vuint32m1_t *, vuint32m1_t *, vuint32m1_t *, vbool32_t, vuint32m1_t, vuint32m1_t, vuint32m1_t, vuint32m1_t, vuint32m1_t, vuint32m1_t, const uint32_t *, ptrdiff_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vlsseg6e32_v)))
void vlsseg6e32_v_u32mf2(vuint32mf2_t *, vuint32mf2_t *, vuint32mf2_t *, vuint32mf2_t *, vuint32mf2_t *, vuint32mf2_t *, const uint32_t *, ptrdiff_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vlsseg6e32_v_m)))
void vlsseg6e32_v_u32mf2_m(vuint32mf2_t *, vuint32mf2_t *, vuint32mf2_t *, vuint32mf2_t *, vuint32mf2_t *, vuint32mf2_t *, vbool64_t, vuint32mf2_t, vuint32mf2_t, vuint32mf2_t, vuint32mf2_t, vuint32mf2_t, vuint32mf2_t, const uint32_t *, ptrdiff_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vlsseg7e32_v)))
void vlsseg7e32_v_i32m1(vint32m1_t *, vint32m1_t *, vint32m1_t *, vint32m1_t *, vint32m1_t *, vint32m1_t *, vint32m1_t *, const int32_t *, ptrdiff_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vlsseg7e32_v_m)))
void vlsseg7e32_v_i32m1_m(vint32m1_t *, vint32m1_t *, vint32m1_t *, vint32m1_t *, vint32m1_t *, vint32m1_t *, vint32m1_t *, vbool32_t, vint32m1_t, vint32m1_t, vint32m1_t, vint32m1_t, vint32m1_t, vint32m1_t, vint32m1_t, const int32_t *, ptrdiff_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vlsseg7e32_v)))
void vlsseg7e32_v_i32mf2(vint32mf2_t *, vint32mf2_t *, vint32mf2_t *, vint32mf2_t *, vint32mf2_t *, vint32mf2_t *, vint32mf2_t *, const int32_t *, ptrdiff_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vlsseg7e32_v_m)))
void vlsseg7e32_v_i32mf2_m(vint32mf2_t *, vint32mf2_t *, vint32mf2_t *, vint32mf2_t *, vint32mf2_t *, vint32mf2_t *, vint32mf2_t *, vbool64_t, vint32mf2_t, vint32mf2_t, vint32mf2_t, vint32mf2_t, vint32mf2_t, vint32mf2_t, vint32mf2_t, const int32_t *, ptrdiff_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vlsseg7e32_v)))
void vlsseg7e32_v_u32m1(vuint32m1_t *, vuint32m1_t *, vuint32m1_t *, vuint32m1_t *, vuint32m1_t *, vuint32m1_t *, vuint32m1_t *, const uint32_t *, ptrdiff_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vlsseg7e32_v_m)))
void vlsseg7e32_v_u32m1_m(vuint32m1_t *, vuint32m1_t *, vuint32m1_t *, vuint32m1_t *, vuint32m1_t *, vuint32m1_t *, vuint32m1_t *, vbool32_t, vuint32m1_t, vuint32m1_t, vuint32m1_t, vuint32m1_t, vuint32m1_t, vuint32m1_t, vuint32m1_t, const uint32_t *, ptrdiff_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vlsseg7e32_v)))
void vlsseg7e32_v_u32mf2(vuint32mf2_t *, vuint32mf2_t *, vuint32mf2_t *, vuint32mf2_t *, vuint32mf2_t *, vuint32mf2_t *, vuint32mf2_t *, const uint32_t *, ptrdiff_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vlsseg7e32_v_m)))
void vlsseg7e32_v_u32mf2_m(vuint32mf2_t *, vuint32mf2_t *, vuint32mf2_t *, vuint32mf2_t *, vuint32mf2_t *, vuint32mf2_t *, vuint32mf2_t *, vbool64_t, vuint32mf2_t, vuint32mf2_t, vuint32mf2_t, vuint32mf2_t, vuint32mf2_t, vuint32mf2_t, vuint32mf2_t, const uint32_t *, ptrdiff_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vlsseg8e32_v)))
void vlsseg8e32_v_i32m1(vint32m1_t *, vint32m1_t *, vint32m1_t *, vint32m1_t *, vint32m1_t *, vint32m1_t *, vint32m1_t *, vint32m1_t *, const int32_t *, ptrdiff_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vlsseg8e32_v_m)))
void vlsseg8e32_v_i32m1_m(vint32m1_t *, vint32m1_t *, vint32m1_t *, vint32m1_t *, vint32m1_t *, vint32m1_t *, vint32m1_t *, vint32m1_t *, vbool32_t, vint32m1_t, vint32m1_t, vint32m1_t, vint32m1_t, vint32m1_t, vint32m1_t, vint32m1_t, vint32m1_t, const int32_t *, ptrdiff_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vlsseg8e32_v)))
void vlsseg8e32_v_i32mf2(vint32mf2_t *, vint32mf2_t *, vint32mf2_t *, vint32mf2_t *, vint32mf2_t *, vint32mf2_t *, vint32mf2_t *, vint32mf2_t *, const int32_t *, ptrdiff_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vlsseg8e32_v_m)))
void vlsseg8e32_v_i32mf2_m(vint32mf2_t *, vint32mf2_t *, vint32mf2_t *, vint32mf2_t *, vint32mf2_t *, vint32mf2_t *, vint32mf2_t *, vint32mf2_t *, vbool64_t, vint32mf2_t, vint32mf2_t, vint32mf2_t, vint32mf2_t, vint32mf2_t, vint32mf2_t, vint32mf2_t, vint32mf2_t, const int32_t *, ptrdiff_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vlsseg8e32_v)))
void vlsseg8e32_v_u32m1(vuint32m1_t *, vuint32m1_t *, vuint32m1_t *, vuint32m1_t *, vuint32m1_t *, vuint32m1_t *, vuint32m1_t *, vuint32m1_t *, const uint32_t *, ptrdiff_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vlsseg8e32_v_m)))
void vlsseg8e32_v_u32m1_m(vuint32m1_t *, vuint32m1_t *, vuint32m1_t *, vuint32m1_t *, vuint32m1_t *, vuint32m1_t *, vuint32m1_t *, vuint32m1_t *, vbool32_t, vuint32m1_t, vuint32m1_t, vuint32m1_t, vuint32m1_t, vuint32m1_t, vuint32m1_t, vuint32m1_t, vuint32m1_t, const uint32_t *, ptrdiff_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vlsseg8e32_v)))
void vlsseg8e32_v_u32mf2(vuint32mf2_t *, vuint32mf2_t *, vuint32mf2_t *, vuint32mf2_t *, vuint32mf2_t *, vuint32mf2_t *, vuint32mf2_t *, vuint32mf2_t *, const uint32_t *, ptrdiff_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vlsseg8e32_v_m)))
void vlsseg8e32_v_u32mf2_m(vuint32mf2_t *, vuint32mf2_t *, vuint32mf2_t *, vuint32mf2_t *, vuint32mf2_t *, vuint32mf2_t *, vuint32mf2_t *, vuint32mf2_t *, vbool64_t, vuint32mf2_t, vuint32mf2_t, vuint32mf2_t, vuint32mf2_t, vuint32mf2_t, vuint32mf2_t, vuint32mf2_t, vuint32mf2_t, const uint32_t *, ptrdiff_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vluxseg2ei8_v)))
void vluxseg2ei8_v_u8m1(vuint8m1_t *, vuint8m1_t *, const uint8_t *, vuint8m1_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vluxseg2ei8_v_m)))
void vluxseg2ei8_v_u8m1_m(vuint8m1_t *, vuint8m1_t *, vbool8_t, vuint8m1_t, vuint8m1_t, const uint8_t *, vuint8m1_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vluxseg2ei8_v)))
void vluxseg2ei8_v_u8m2(vuint8m2_t *, vuint8m2_t *, const uint8_t *, vuint8m2_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vluxseg2ei8_v_m)))
void vluxseg2ei8_v_u8m2_m(vuint8m2_t *, vuint8m2_t *, vbool4_t, vuint8m2_t, vuint8m2_t, const uint8_t *, vuint8m2_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vluxseg2ei8_v)))
void vluxseg2ei8_v_u8m4(vuint8m4_t *, vuint8m4_t *, const uint8_t *, vuint8m4_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vluxseg2ei8_v_m)))
void vluxseg2ei8_v_u8m4_m(vuint8m4_t *, vuint8m4_t *, vbool2_t, vuint8m4_t, vuint8m4_t, const uint8_t *, vuint8m4_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vluxseg2ei8_v)))
void vluxseg2ei8_v_u8mf2(vuint8mf2_t *, vuint8mf2_t *, const uint8_t *, vuint8mf2_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vluxseg2ei8_v_m)))
void vluxseg2ei8_v_u8mf2_m(vuint8mf2_t *, vuint8mf2_t *, vbool16_t, vuint8mf2_t, vuint8mf2_t, const uint8_t *, vuint8mf2_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vluxseg2ei8_v)))
void vluxseg2ei8_v_u8mf4(vuint8mf4_t *, vuint8mf4_t *, const uint8_t *, vuint8mf4_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vluxseg2ei8_v_m)))
void vluxseg2ei8_v_u8mf4_m(vuint8mf4_t *, vuint8mf4_t *, vbool32_t, vuint8mf4_t, vuint8mf4_t, const uint8_t *, vuint8mf4_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vluxseg2ei8_v)))
void vluxseg2ei8_v_u8mf8(vuint8mf8_t *, vuint8mf8_t *, const uint8_t *, vuint8mf8_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vluxseg2ei8_v_m)))
void vluxseg2ei8_v_u8mf8_m(vuint8mf8_t *, vuint8mf8_t *, vbool64_t, vuint8mf8_t, vuint8mf8_t, const uint8_t *, vuint8mf8_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vle8ff_v)))
vint8m1_t vle8ff_v_i8m1(const int8_t *, size_t *, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vle8ff_v_m)))
vint8m1_t vle8ff_v_i8m1_m(vbool8_t, vint8m1_t, const int8_t *, size_t *, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vle8ff_v)))
vint8m2_t vle8ff_v_i8m2(const int8_t *, size_t *, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vle8ff_v_m)))
vint8m2_t vle8ff_v_i8m2_m(vbool4_t, vint8m2_t, const int8_t *, size_t *, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vle8ff_v)))
vint8m4_t vle8ff_v_i8m4(const int8_t *, size_t *, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vle8ff_v_m)))
vint8m4_t vle8ff_v_i8m4_m(vbool2_t, vint8m4_t, const int8_t *, size_t *, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vle8ff_v)))
vint8m8_t vle8ff_v_i8m8(const int8_t *, size_t *, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vle8ff_v_m)))
vint8m8_t vle8ff_v_i8m8_m(vbool1_t, vint8m8_t, const int8_t *, size_t *, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vle8ff_v)))
vint8mf2_t vle8ff_v_i8mf2(const int8_t *, size_t *, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vle8ff_v_m)))
vint8mf2_t vle8ff_v_i8mf2_m(vbool16_t, vint8mf2_t, const int8_t *, size_t *, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vle8ff_v)))
vint8mf4_t vle8ff_v_i8mf4(const int8_t *, size_t *, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vle8ff_v_m)))
vint8mf4_t vle8ff_v_i8mf4_m(vbool32_t, vint8mf4_t, const int8_t *, size_t *, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vle8ff_v)))
vint8mf8_t vle8ff_v_i8mf8(const int8_t *, size_t *, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vle8ff_v_m)))
vint8mf8_t vle8ff_v_i8mf8_m(vbool64_t, vint8mf8_t, const int8_t *, size_t *, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vsseg2e8_v)))
void vsseg2e8_v_i8m1(int8_t *, vint8m1_t, vint8m1_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vsseg2e8_v_m)))
void vsseg2e8_v_i8m1_m(vbool8_t, int8_t *, vint8m1_t, vint8m1_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vsseg2e8_v)))
void vsseg2e8_v_i8m2(int8_t *, vint8m2_t, vint8m2_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vsseg2e8_v_m)))
void vsseg2e8_v_i8m2_m(vbool4_t, int8_t *, vint8m2_t, vint8m2_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vsseg2e8_v)))
void vsseg2e8_v_i8m4(int8_t *, vint8m4_t, vint8m4_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vsseg2e8_v_m)))
void vsseg2e8_v_i8m4_m(vbool2_t, int8_t *, vint8m4_t, vint8m4_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vsseg2e8_v)))
void vsseg2e8_v_i8mf2(int8_t *, vint8mf2_t, vint8mf2_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vsseg2e8_v_m)))
void vsseg2e8_v_i8mf2_m(vbool16_t, int8_t *, vint8mf2_t, vint8mf2_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vsseg2e8_v)))
void vsseg2e8_v_i8mf4(int8_t *, vint8mf4_t, vint8mf4_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vsseg2e8_v_m)))
void vsseg2e8_v_i8mf4_m(vbool32_t, int8_t *, vint8mf4_t, vint8mf4_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vsseg2e8_v)))
void vsseg2e8_v_i8mf8(int8_t *, vint8mf8_t, vint8mf8_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vsseg2e8_v_m)))
void vsseg2e8_v_i8mf8_m(vbool64_t, int8_t *, vint8mf8_t, vint8mf8_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vsseg2e8_v)))
void vsseg2e8_v_u8m1(uint8_t *, vuint8m1_t, vuint8m1_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vsseg2e8_v_m)))
void vsseg2e8_v_u8m1_m(vbool8_t, uint8_t *, vuint8m1_t, vuint8m1_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vsseg2e8_v)))
void vsseg2e8_v_u8m2(uint8_t *, vuint8m2_t, vuint8m2_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vsseg2e8_v_m)))
void vsseg2e8_v_u8m2_m(vbool4_t, uint8_t *, vuint8m2_t, vuint8m2_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vsseg2e8_v)))
void vsseg2e8_v_u8m4(uint8_t *, vuint8m4_t, vuint8m4_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vsseg2e8_v_m)))
void vsseg2e8_v_u8m4_m(vbool2_t, uint8_t *, vuint8m4_t, vuint8m4_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vsseg2e8_v)))
void vsseg2e8_v_u8mf2(uint8_t *, vuint8mf2_t, vuint8mf2_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vsseg2e8_v_m)))
void vsseg2e8_v_u8mf2_m(vbool16_t, uint8_t *, vuint8mf2_t, vuint8mf2_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vsseg2e8_v)))
void vsseg2e8_v_u8mf4(uint8_t *, vuint8mf4_t, vuint8mf4_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vsseg2e8_v_m)))
void vsseg2e8_v_u8mf4_m(vbool32_t, uint8_t *, vuint8mf4_t, vuint8mf4_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vsseg2e8_v)))
void vsseg2e8_v_u8mf8(uint8_t *, vuint8mf8_t, vuint8mf8_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vsseg2e8_v_m)))
void vsseg2e8_v_u8mf8_m(vbool64_t, uint8_t *, vuint8mf8_t, vuint8mf8_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vluxseg3ei8_v)))
void vluxseg3ei8_v_i8m1(vint8m1_t *, vint8m1_t *, vint8m1_t *, const int8_t *, vuint8m1_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vluxseg3ei8_v_m)))
void vluxseg3ei8_v_i8m1_m(vint8m1_t *, vint8m1_t *, vint8m1_t *, vbool8_t, vint8m1_t, vint8m1_t, vint8m1_t, const int8_t *, vuint8m1_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vluxseg3ei8_v)))
void vluxseg3ei8_v_i8m2(vint8m2_t *, vint8m2_t *, vint8m2_t *, const int8_t *, vuint8m2_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vluxseg3ei8_v_m)))
void vluxseg3ei8_v_i8m2_m(vint8m2_t *, vint8m2_t *, vint8m2_t *, vbool4_t, vint8m2_t, vint8m2_t, vint8m2_t, const int8_t *, vuint8m2_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vluxseg3ei8_v)))
void vluxseg3ei8_v_i8mf2(vint8mf2_t *, vint8mf2_t *, vint8mf2_t *, const int8_t *, vuint8mf2_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vluxseg3ei8_v_m)))
void vluxseg3ei8_v_i8mf2_m(vint8mf2_t *, vint8mf2_t *, vint8mf2_t *, vbool16_t, vint8mf2_t, vint8mf2_t, vint8mf2_t, const int8_t *, vuint8mf2_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vluxseg3ei8_v)))
void vluxseg3ei8_v_i8mf4(vint8mf4_t *, vint8mf4_t *, vint8mf4_t *, const int8_t *, vuint8mf4_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vluxseg3ei8_v_m)))
void vluxseg3ei8_v_i8mf4_m(vint8mf4_t *, vint8mf4_t *, vint8mf4_t *, vbool32_t, vint8mf4_t, vint8mf4_t, vint8mf4_t, const int8_t *, vuint8mf4_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vluxseg3ei8_v)))
void vluxseg3ei8_v_i8mf8(vint8mf8_t *, vint8mf8_t *, vint8mf8_t *, const int8_t *, vuint8mf8_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vluxseg3ei8_v_m)))
void vluxseg3ei8_v_i8mf8_m(vint8mf8_t *, vint8mf8_t *, vint8mf8_t *, vbool64_t, vint8mf8_t, vint8mf8_t, vint8mf8_t, const int8_t *, vuint8mf8_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vluxseg3ei8_v)))
void vluxseg3ei8_v_u8m1(vuint8m1_t *, vuint8m1_t *, vuint8m1_t *, const uint8_t *, vuint8m1_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vluxseg3ei8_v_m)))
void vluxseg3ei8_v_u8m1_m(vuint8m1_t *, vuint8m1_t *, vuint8m1_t *, vbool8_t, vuint8m1_t, vuint8m1_t, vuint8m1_t, const uint8_t *, vuint8m1_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vluxseg3ei8_v)))
void vluxseg3ei8_v_u8m2(vuint8m2_t *, vuint8m2_t *, vuint8m2_t *, const uint8_t *, vuint8m2_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vluxseg3ei8_v_m)))
void vluxseg3ei8_v_u8m2_m(vuint8m2_t *, vuint8m2_t *, vuint8m2_t *, vbool4_t, vuint8m2_t, vuint8m2_t, vuint8m2_t, const uint8_t *, vuint8m2_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vluxseg3ei8_v)))
void vluxseg3ei8_v_u8mf2(vuint8mf2_t *, vuint8mf2_t *, vuint8mf2_t *, const uint8_t *, vuint8mf2_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vluxseg3ei8_v_m)))
void vluxseg3ei8_v_u8mf2_m(vuint8mf2_t *, vuint8mf2_t *, vuint8mf2_t *, vbool16_t, vuint8mf2_t, vuint8mf2_t, vuint8mf2_t, const uint8_t *, vuint8mf2_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vluxseg3ei8_v)))
void vluxseg3ei8_v_u8mf4(vuint8mf4_t *, vuint8mf4_t *, vuint8mf4_t *, const uint8_t *, vuint8mf4_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vluxseg3ei8_v_m)))
void vluxseg3ei8_v_u8mf4_m(vuint8mf4_t *, vuint8mf4_t *, vuint8mf4_t *, vbool32_t, vuint8mf4_t, vuint8mf4_t, vuint8mf4_t, const uint8_t *, vuint8mf4_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vluxseg3ei8_v)))
void vluxseg3ei8_v_u8mf8(vuint8mf8_t *, vuint8mf8_t *, vuint8mf8_t *, const uint8_t *, vuint8mf8_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vluxseg3ei8_v_m)))
void vluxseg3ei8_v_u8mf8_m(vuint8mf8_t *, vuint8mf8_t *, vuint8mf8_t *, vbool64_t, vuint8mf8_t, vuint8mf8_t, vuint8mf8_t, const uint8_t *, vuint8mf8_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vluxseg4ei8_v)))
void vluxseg4ei8_v_i8m1(vint8m1_t *, vint8m1_t *, vint8m1_t *, vint8m1_t *, const int8_t *, vuint8m1_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vluxseg4ei8_v_m)))
void vluxseg4ei8_v_i8m1_m(vint8m1_t *, vint8m1_t *, vint8m1_t *, vint8m1_t *, vbool8_t, vint8m1_t, vint8m1_t, vint8m1_t, vint8m1_t, const int8_t *, vuint8m1_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vluxseg4ei8_v)))
void vluxseg4ei8_v_i8m2(vint8m2_t *, vint8m2_t *, vint8m2_t *, vint8m2_t *, const int8_t *, vuint8m2_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vluxseg4ei8_v_m)))
void vluxseg4ei8_v_i8m2_m(vint8m2_t *, vint8m2_t *, vint8m2_t *, vint8m2_t *, vbool4_t, vint8m2_t, vint8m2_t, vint8m2_t, vint8m2_t, const int8_t *, vuint8m2_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vluxseg4ei8_v)))
void vluxseg4ei8_v_i8mf2(vint8mf2_t *, vint8mf2_t *, vint8mf2_t *, vint8mf2_t *, const int8_t *, vuint8mf2_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vluxseg4ei8_v_m)))
void vluxseg4ei8_v_i8mf2_m(vint8mf2_t *, vint8mf2_t *, vint8mf2_t *, vint8mf2_t *, vbool16_t, vint8mf2_t, vint8mf2_t, vint8mf2_t, vint8mf2_t, const int8_t *, vuint8mf2_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vluxseg4ei8_v)))
void vluxseg4ei8_v_i8mf4(vint8mf4_t *, vint8mf4_t *, vint8mf4_t *, vint8mf4_t *, const int8_t *, vuint8mf4_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vluxseg4ei8_v_m)))
void vluxseg4ei8_v_i8mf4_m(vint8mf4_t *, vint8mf4_t *, vint8mf4_t *, vint8mf4_t *, vbool32_t, vint8mf4_t, vint8mf4_t, vint8mf4_t, vint8mf4_t, const int8_t *, vuint8mf4_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vluxseg4ei8_v)))
void vluxseg4ei8_v_i8mf8(vint8mf8_t *, vint8mf8_t *, vint8mf8_t *, vint8mf8_t *, const int8_t *, vuint8mf8_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vluxseg4ei8_v_m)))
void vluxseg4ei8_v_i8mf8_m(vint8mf8_t *, vint8mf8_t *, vint8mf8_t *, vint8mf8_t *, vbool64_t, vint8mf8_t, vint8mf8_t, vint8mf8_t, vint8mf8_t, const int8_t *, vuint8mf8_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vluxseg4ei8_v)))
void vluxseg4ei8_v_u8m1(vuint8m1_t *, vuint8m1_t *, vuint8m1_t *, vuint8m1_t *, const uint8_t *, vuint8m1_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vluxseg4ei8_v_m)))
void vluxseg4ei8_v_u8m1_m(vuint8m1_t *, vuint8m1_t *, vuint8m1_t *, vuint8m1_t *, vbool8_t, vuint8m1_t, vuint8m1_t, vuint8m1_t, vuint8m1_t, const uint8_t *, vuint8m1_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vluxseg4ei8_v)))
void vluxseg4ei8_v_u8m2(vuint8m2_t *, vuint8m2_t *, vuint8m2_t *, vuint8m2_t *, const uint8_t *, vuint8m2_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vluxseg4ei8_v_m)))
void vluxseg4ei8_v_u8m2_m(vuint8m2_t *, vuint8m2_t *, vuint8m2_t *, vuint8m2_t *, vbool4_t, vuint8m2_t, vuint8m2_t, vuint8m2_t, vuint8m2_t, const uint8_t *, vuint8m2_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vluxseg4ei8_v)))
void vluxseg4ei8_v_u8mf2(vuint8mf2_t *, vuint8mf2_t *, vuint8mf2_t *, vuint8mf2_t *, const uint8_t *, vuint8mf2_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vluxseg4ei8_v_m)))
void vluxseg4ei8_v_u8mf2_m(vuint8mf2_t *, vuint8mf2_t *, vuint8mf2_t *, vuint8mf2_t *, vbool16_t, vuint8mf2_t, vuint8mf2_t, vuint8mf2_t, vuint8mf2_t, const uint8_t *, vuint8mf2_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vluxseg4ei8_v)))
void vluxseg4ei8_v_u8mf4(vuint8mf4_t *, vuint8mf4_t *, vuint8mf4_t *, vuint8mf4_t *, const uint8_t *, vuint8mf4_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vluxseg4ei8_v_m)))
void vluxseg4ei8_v_u8mf4_m(vuint8mf4_t *, vuint8mf4_t *, vuint8mf4_t *, vuint8mf4_t *, vbool32_t, vuint8mf4_t, vuint8mf4_t, vuint8mf4_t, vuint8mf4_t, const uint8_t *, vuint8mf4_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vluxseg4ei8_v)))
void vluxseg4ei8_v_u8mf8(vuint8mf8_t *, vuint8mf8_t *, vuint8mf8_t *, vuint8mf8_t *, const uint8_t *, vuint8mf8_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vluxseg4ei8_v_m)))
void vluxseg4ei8_v_u8mf8_m(vuint8mf8_t *, vuint8mf8_t *, vuint8mf8_t *, vuint8mf8_t *, vbool64_t, vuint8mf8_t, vuint8mf8_t, vuint8mf8_t, vuint8mf8_t, const uint8_t *, vuint8mf8_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vluxseg5ei8_v)))
void vluxseg5ei8_v_i8m1(vint8m1_t *, vint8m1_t *, vint8m1_t *, vint8m1_t *, vint8m1_t *, const int8_t *, vuint8m1_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vluxseg5ei8_v_m)))
void vluxseg5ei8_v_i8m1_m(vint8m1_t *, vint8m1_t *, vint8m1_t *, vint8m1_t *, vint8m1_t *, vbool8_t, vint8m1_t, vint8m1_t, vint8m1_t, vint8m1_t, vint8m1_t, const int8_t *, vuint8m1_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vluxseg5ei8_v)))
void vluxseg5ei8_v_i8mf2(vint8mf2_t *, vint8mf2_t *, vint8mf2_t *, vint8mf2_t *, vint8mf2_t *, const int8_t *, vuint8mf2_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vluxseg5ei8_v_m)))
void vluxseg5ei8_v_i8mf2_m(vint8mf2_t *, vint8mf2_t *, vint8mf2_t *, vint8mf2_t *, vint8mf2_t *, vbool16_t, vint8mf2_t, vint8mf2_t, vint8mf2_t, vint8mf2_t, vint8mf2_t, const int8_t *, vuint8mf2_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vluxseg5ei8_v)))
void vluxseg5ei8_v_i8mf4(vint8mf4_t *, vint8mf4_t *, vint8mf4_t *, vint8mf4_t *, vint8mf4_t *, const int8_t *, vuint8mf4_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vluxseg5ei8_v_m)))
void vluxseg5ei8_v_i8mf4_m(vint8mf4_t *, vint8mf4_t *, vint8mf4_t *, vint8mf4_t *, vint8mf4_t *, vbool32_t, vint8mf4_t, vint8mf4_t, vint8mf4_t, vint8mf4_t, vint8mf4_t, const int8_t *, vuint8mf4_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vluxseg5ei8_v)))
void vluxseg5ei8_v_i8mf8(vint8mf8_t *, vint8mf8_t *, vint8mf8_t *, vint8mf8_t *, vint8mf8_t *, const int8_t *, vuint8mf8_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vluxseg5ei8_v_m)))
void vluxseg5ei8_v_i8mf8_m(vint8mf8_t *, vint8mf8_t *, vint8mf8_t *, vint8mf8_t *, vint8mf8_t *, vbool64_t, vint8mf8_t, vint8mf8_t, vint8mf8_t, vint8mf8_t, vint8mf8_t, const int8_t *, vuint8mf8_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vluxseg5ei8_v)))
void vluxseg5ei8_v_u8m1(vuint8m1_t *, vuint8m1_t *, vuint8m1_t *, vuint8m1_t *, vuint8m1_t *, const uint8_t *, vuint8m1_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vluxseg5ei8_v_m)))
void vluxseg5ei8_v_u8m1_m(vuint8m1_t *, vuint8m1_t *, vuint8m1_t *, vuint8m1_t *, vuint8m1_t *, vbool8_t, vuint8m1_t, vuint8m1_t, vuint8m1_t, vuint8m1_t, vuint8m1_t, const uint8_t *, vuint8m1_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vluxseg5ei8_v)))
void vluxseg5ei8_v_u8mf2(vuint8mf2_t *, vuint8mf2_t *, vuint8mf2_t *, vuint8mf2_t *, vuint8mf2_t *, const uint8_t *, vuint8mf2_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vluxseg5ei8_v_m)))
void vluxseg5ei8_v_u8mf2_m(vuint8mf2_t *, vuint8mf2_t *, vuint8mf2_t *, vuint8mf2_t *, vuint8mf2_t *, vbool16_t, vuint8mf2_t, vuint8mf2_t, vuint8mf2_t, vuint8mf2_t, vuint8mf2_t, const uint8_t *, vuint8mf2_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vluxseg5ei8_v)))
void vluxseg5ei8_v_u8mf4(vuint8mf4_t *, vuint8mf4_t *, vuint8mf4_t *, vuint8mf4_t *, vuint8mf4_t *, const uint8_t *, vuint8mf4_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vluxseg5ei8_v_m)))
void vluxseg5ei8_v_u8mf4_m(vuint8mf4_t *, vuint8mf4_t *, vuint8mf4_t *, vuint8mf4_t *, vuint8mf4_t *, vbool32_t, vuint8mf4_t, vuint8mf4_t, vuint8mf4_t, vuint8mf4_t, vuint8mf4_t, const uint8_t *, vuint8mf4_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vluxseg5ei8_v)))
void vluxseg5ei8_v_u8mf8(vuint8mf8_t *, vuint8mf8_t *, vuint8mf8_t *, vuint8mf8_t *, vuint8mf8_t *, const uint8_t *, vuint8mf8_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vluxseg5ei8_v_m)))
void vluxseg5ei8_v_u8mf8_m(vuint8mf8_t *, vuint8mf8_t *, vuint8mf8_t *, vuint8mf8_t *, vuint8mf8_t *, vbool64_t, vuint8mf8_t, vuint8mf8_t, vuint8mf8_t, vuint8mf8_t, vuint8mf8_t, const uint8_t *, vuint8mf8_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vluxseg6ei8_v)))
void vluxseg6ei8_v_i8m1(vint8m1_t *, vint8m1_t *, vint8m1_t *, vint8m1_t *, vint8m1_t *, vint8m1_t *, const int8_t *, vuint8m1_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vluxseg6ei8_v_m)))
void vluxseg6ei8_v_i8m1_m(vint8m1_t *, vint8m1_t *, vint8m1_t *, vint8m1_t *, vint8m1_t *, vint8m1_t *, vbool8_t, vint8m1_t, vint8m1_t, vint8m1_t, vint8m1_t, vint8m1_t, vint8m1_t, const int8_t *, vuint8m1_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vluxseg6ei8_v)))
void vluxseg6ei8_v_i8mf2(vint8mf2_t *, vint8mf2_t *, vint8mf2_t *, vint8mf2_t *, vint8mf2_t *, vint8mf2_t *, const int8_t *, vuint8mf2_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vluxseg6ei8_v_m)))
void vluxseg6ei8_v_i8mf2_m(vint8mf2_t *, vint8mf2_t *, vint8mf2_t *, vint8mf2_t *, vint8mf2_t *, vint8mf2_t *, vbool16_t, vint8mf2_t, vint8mf2_t, vint8mf2_t, vint8mf2_t, vint8mf2_t, vint8mf2_t, const int8_t *, vuint8mf2_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vluxseg6ei8_v)))
void vluxseg6ei8_v_i8mf4(vint8mf4_t *, vint8mf4_t *, vint8mf4_t *, vint8mf4_t *, vint8mf4_t *, vint8mf4_t *, const int8_t *, vuint8mf4_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vluxseg6ei8_v_m)))
void vluxseg6ei8_v_i8mf4_m(vint8mf4_t *, vint8mf4_t *, vint8mf4_t *, vint8mf4_t *, vint8mf4_t *, vint8mf4_t *, vbool32_t, vint8mf4_t, vint8mf4_t, vint8mf4_t, vint8mf4_t, vint8mf4_t, vint8mf4_t, const int8_t *, vuint8mf4_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vluxseg6ei8_v)))
void vluxseg6ei8_v_i8mf8(vint8mf8_t *, vint8mf8_t *, vint8mf8_t *, vint8mf8_t *, vint8mf8_t *, vint8mf8_t *, const int8_t *, vuint8mf8_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vluxseg6ei8_v_m)))
void vluxseg6ei8_v_i8mf8_m(vint8mf8_t *, vint8mf8_t *, vint8mf8_t *, vint8mf8_t *, vint8mf8_t *, vint8mf8_t *, vbool64_t, vint8mf8_t, vint8mf8_t, vint8mf8_t, vint8mf8_t, vint8mf8_t, vint8mf8_t, const int8_t *, vuint8mf8_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vluxseg6ei8_v)))
void vluxseg6ei8_v_u8m1(vuint8m1_t *, vuint8m1_t *, vuint8m1_t *, vuint8m1_t *, vuint8m1_t *, vuint8m1_t *, const uint8_t *, vuint8m1_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vluxseg6ei8_v_m)))
void vluxseg6ei8_v_u8m1_m(vuint8m1_t *, vuint8m1_t *, vuint8m1_t *, vuint8m1_t *, vuint8m1_t *, vuint8m1_t *, vbool8_t, vuint8m1_t, vuint8m1_t, vuint8m1_t, vuint8m1_t, vuint8m1_t, vuint8m1_t, const uint8_t *, vuint8m1_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vluxseg6ei8_v)))
void vluxseg6ei8_v_u8mf2(vuint8mf2_t *, vuint8mf2_t *, vuint8mf2_t *, vuint8mf2_t *, vuint8mf2_t *, vuint8mf2_t *, const uint8_t *, vuint8mf2_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vluxseg6ei8_v_m)))
void vluxseg6ei8_v_u8mf2_m(vuint8mf2_t *, vuint8mf2_t *, vuint8mf2_t *, vuint8mf2_t *, vuint8mf2_t *, vuint8mf2_t *, vbool16_t, vuint8mf2_t, vuint8mf2_t, vuint8mf2_t, vuint8mf2_t, vuint8mf2_t, vuint8mf2_t, const uint8_t *, vuint8mf2_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vluxseg6ei8_v)))
void vluxseg6ei8_v_u8mf4(vuint8mf4_t *, vuint8mf4_t *, vuint8mf4_t *, vuint8mf4_t *, vuint8mf4_t *, vuint8mf4_t *, const uint8_t *, vuint8mf4_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vluxseg6ei8_v_m)))
void vluxseg6ei8_v_u8mf4_m(vuint8mf4_t *, vuint8mf4_t *, vuint8mf4_t *, vuint8mf4_t *, vuint8mf4_t *, vuint8mf4_t *, vbool32_t, vuint8mf4_t, vuint8mf4_t, vuint8mf4_t, vuint8mf4_t, vuint8mf4_t, vuint8mf4_t, const uint8_t *, vuint8mf4_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vluxseg6ei8_v)))
void vluxseg6ei8_v_u8mf8(vuint8mf8_t *, vuint8mf8_t *, vuint8mf8_t *, vuint8mf8_t *, vuint8mf8_t *, vuint8mf8_t *, const uint8_t *, vuint8mf8_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vluxseg6ei8_v_m)))
void vluxseg6ei8_v_u8mf8_m(vuint8mf8_t *, vuint8mf8_t *, vuint8mf8_t *, vuint8mf8_t *, vuint8mf8_t *, vuint8mf8_t *, vbool64_t, vuint8mf8_t, vuint8mf8_t, vuint8mf8_t, vuint8mf8_t, vuint8mf8_t, vuint8mf8_t, const uint8_t *, vuint8mf8_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vluxseg7ei8_v)))
void vluxseg7ei8_v_i8m1(vint8m1_t *, vint8m1_t *, vint8m1_t *, vint8m1_t *, vint8m1_t *, vint8m1_t *, vint8m1_t *, const int8_t *, vuint8m1_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vluxseg7ei8_v_m)))
void vluxseg7ei8_v_i8m1_m(vint8m1_t *, vint8m1_t *, vint8m1_t *, vint8m1_t *, vint8m1_t *, vint8m1_t *, vint8m1_t *, vbool8_t, vint8m1_t, vint8m1_t, vint8m1_t, vint8m1_t, vint8m1_t, vint8m1_t, vint8m1_t, const int8_t *, vuint8m1_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vluxseg7ei8_v)))
void vluxseg7ei8_v_i8mf2(vint8mf2_t *, vint8mf2_t *, vint8mf2_t *, vint8mf2_t *, vint8mf2_t *, vint8mf2_t *, vint8mf2_t *, const int8_t *, vuint8mf2_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vluxseg7ei8_v_m)))
void vluxseg7ei8_v_i8mf2_m(vint8mf2_t *, vint8mf2_t *, vint8mf2_t *, vint8mf2_t *, vint8mf2_t *, vint8mf2_t *, vint8mf2_t *, vbool16_t, vint8mf2_t, vint8mf2_t, vint8mf2_t, vint8mf2_t, vint8mf2_t, vint8mf2_t, vint8mf2_t, const int8_t *, vuint8mf2_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vluxseg7ei8_v)))
void vluxseg7ei8_v_i8mf4(vint8mf4_t *, vint8mf4_t *, vint8mf4_t *, vint8mf4_t *, vint8mf4_t *, vint8mf4_t *, vint8mf4_t *, const int8_t *, vuint8mf4_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vluxseg7ei8_v_m)))
void vluxseg7ei8_v_i8mf4_m(vint8mf4_t *, vint8mf4_t *, vint8mf4_t *, vint8mf4_t *, vint8mf4_t *, vint8mf4_t *, vint8mf4_t *, vbool32_t, vint8mf4_t, vint8mf4_t, vint8mf4_t, vint8mf4_t, vint8mf4_t, vint8mf4_t, vint8mf4_t, const int8_t *, vuint8mf4_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vluxseg7ei8_v)))
void vluxseg7ei8_v_i8mf8(vint8mf8_t *, vint8mf8_t *, vint8mf8_t *, vint8mf8_t *, vint8mf8_t *, vint8mf8_t *, vint8mf8_t *, const int8_t *, vuint8mf8_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vluxseg7ei8_v_m)))
void vluxseg7ei8_v_i8mf8_m(vint8mf8_t *, vint8mf8_t *, vint8mf8_t *, vint8mf8_t *, vint8mf8_t *, vint8mf8_t *, vint8mf8_t *, vbool64_t, vint8mf8_t, vint8mf8_t, vint8mf8_t, vint8mf8_t, vint8mf8_t, vint8mf8_t, vint8mf8_t, const int8_t *, vuint8mf8_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vluxseg7ei8_v)))
void vluxseg7ei8_v_u8m1(vuint8m1_t *, vuint8m1_t *, vuint8m1_t *, vuint8m1_t *, vuint8m1_t *, vuint8m1_t *, vuint8m1_t *, const uint8_t *, vuint8m1_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vluxseg7ei8_v_m)))
void vluxseg7ei8_v_u8m1_m(vuint8m1_t *, vuint8m1_t *, vuint8m1_t *, vuint8m1_t *, vuint8m1_t *, vuint8m1_t *, vuint8m1_t *, vbool8_t, vuint8m1_t, vuint8m1_t, vuint8m1_t, vuint8m1_t, vuint8m1_t, vuint8m1_t, vuint8m1_t, const uint8_t *, vuint8m1_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vluxseg7ei8_v)))
void vluxseg7ei8_v_u8mf2(vuint8mf2_t *, vuint8mf2_t *, vuint8mf2_t *, vuint8mf2_t *, vuint8mf2_t *, vuint8mf2_t *, vuint8mf2_t *, const uint8_t *, vuint8mf2_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vluxseg7ei8_v_m)))
void vluxseg7ei8_v_u8mf2_m(vuint8mf2_t *, vuint8mf2_t *, vuint8mf2_t *, vuint8mf2_t *, vuint8mf2_t *, vuint8mf2_t *, vuint8mf2_t *, vbool16_t, vuint8mf2_t, vuint8mf2_t, vuint8mf2_t, vuint8mf2_t, vuint8mf2_t, vuint8mf2_t, vuint8mf2_t, const uint8_t *, vuint8mf2_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vluxseg7ei8_v)))
void vluxseg7ei8_v_u8mf4(vuint8mf4_t *, vuint8mf4_t *, vuint8mf4_t *, vuint8mf4_t *, vuint8mf4_t *, vuint8mf4_t *, vuint8mf4_t *, const uint8_t *, vuint8mf4_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vluxseg7ei8_v_m)))
void vluxseg7ei8_v_u8mf4_m(vuint8mf4_t *, vuint8mf4_t *, vuint8mf4_t *, vuint8mf4_t *, vuint8mf4_t *, vuint8mf4_t *, vuint8mf4_t *, vbool32_t, vuint8mf4_t, vuint8mf4_t, vuint8mf4_t, vuint8mf4_t, vuint8mf4_t, vuint8mf4_t, vuint8mf4_t, const uint8_t *, vuint8mf4_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vluxseg7ei8_v)))
void vluxseg7ei8_v_u8mf8(vuint8mf8_t *, vuint8mf8_t *, vuint8mf8_t *, vuint8mf8_t *, vuint8mf8_t *, vuint8mf8_t *, vuint8mf8_t *, const uint8_t *, vuint8mf8_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vluxseg7ei8_v_m)))
void vluxseg7ei8_v_u8mf8_m(vuint8mf8_t *, vuint8mf8_t *, vuint8mf8_t *, vuint8mf8_t *, vuint8mf8_t *, vuint8mf8_t *, vuint8mf8_t *, vbool64_t, vuint8mf8_t, vuint8mf8_t, vuint8mf8_t, vuint8mf8_t, vuint8mf8_t, vuint8mf8_t, vuint8mf8_t, const uint8_t *, vuint8mf8_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vluxseg8ei8_v)))
void vluxseg8ei8_v_i8m1(vint8m1_t *, vint8m1_t *, vint8m1_t *, vint8m1_t *, vint8m1_t *, vint8m1_t *, vint8m1_t *, vint8m1_t *, const int8_t *, vuint8m1_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vluxseg8ei8_v_m)))
void vluxseg8ei8_v_i8m1_m(vint8m1_t *, vint8m1_t *, vint8m1_t *, vint8m1_t *, vint8m1_t *, vint8m1_t *, vint8m1_t *, vint8m1_t *, vbool8_t, vint8m1_t, vint8m1_t, vint8m1_t, vint8m1_t, vint8m1_t, vint8m1_t, vint8m1_t, vint8m1_t, const int8_t *, vuint8m1_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vluxseg8ei8_v)))
void vluxseg8ei8_v_i8mf2(vint8mf2_t *, vint8mf2_t *, vint8mf2_t *, vint8mf2_t *, vint8mf2_t *, vint8mf2_t *, vint8mf2_t *, vint8mf2_t *, const int8_t *, vuint8mf2_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vluxseg8ei8_v_m)))
void vluxseg8ei8_v_i8mf2_m(vint8mf2_t *, vint8mf2_t *, vint8mf2_t *, vint8mf2_t *, vint8mf2_t *, vint8mf2_t *, vint8mf2_t *, vint8mf2_t *, vbool16_t, vint8mf2_t, vint8mf2_t, vint8mf2_t, vint8mf2_t, vint8mf2_t, vint8mf2_t, vint8mf2_t, vint8mf2_t, const int8_t *, vuint8mf2_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vluxseg8ei8_v)))
void vluxseg8ei8_v_i8mf4(vint8mf4_t *, vint8mf4_t *, vint8mf4_t *, vint8mf4_t *, vint8mf4_t *, vint8mf4_t *, vint8mf4_t *, vint8mf4_t *, const int8_t *, vuint8mf4_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vluxseg8ei8_v_m)))
void vluxseg8ei8_v_i8mf4_m(vint8mf4_t *, vint8mf4_t *, vint8mf4_t *, vint8mf4_t *, vint8mf4_t *, vint8mf4_t *, vint8mf4_t *, vint8mf4_t *, vbool32_t, vint8mf4_t, vint8mf4_t, vint8mf4_t, vint8mf4_t, vint8mf4_t, vint8mf4_t, vint8mf4_t, vint8mf4_t, const int8_t *, vuint8mf4_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vluxseg8ei8_v)))
void vluxseg8ei8_v_i8mf8(vint8mf8_t *, vint8mf8_t *, vint8mf8_t *, vint8mf8_t *, vint8mf8_t *, vint8mf8_t *, vint8mf8_t *, vint8mf8_t *, const int8_t *, vuint8mf8_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vluxseg8ei8_v_m)))
void vluxseg8ei8_v_i8mf8_m(vint8mf8_t *, vint8mf8_t *, vint8mf8_t *, vint8mf8_t *, vint8mf8_t *, vint8mf8_t *, vint8mf8_t *, vint8mf8_t *, vbool64_t, vint8mf8_t, vint8mf8_t, vint8mf8_t, vint8mf8_t, vint8mf8_t, vint8mf8_t, vint8mf8_t, vint8mf8_t, const int8_t *, vuint8mf8_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vluxseg8ei8_v)))
void vluxseg8ei8_v_u8m1(vuint8m1_t *, vuint8m1_t *, vuint8m1_t *, vuint8m1_t *, vuint8m1_t *, vuint8m1_t *, vuint8m1_t *, vuint8m1_t *, const uint8_t *, vuint8m1_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vluxseg8ei8_v_m)))
void vluxseg8ei8_v_u8m1_m(vuint8m1_t *, vuint8m1_t *, vuint8m1_t *, vuint8m1_t *, vuint8m1_t *, vuint8m1_t *, vuint8m1_t *, vuint8m1_t *, vbool8_t, vuint8m1_t, vuint8m1_t, vuint8m1_t, vuint8m1_t, vuint8m1_t, vuint8m1_t, vuint8m1_t, vuint8m1_t, const uint8_t *, vuint8m1_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vluxseg8ei8_v)))
void vluxseg8ei8_v_u8mf2(vuint8mf2_t *, vuint8mf2_t *, vuint8mf2_t *, vuint8mf2_t *, vuint8mf2_t *, vuint8mf2_t *, vuint8mf2_t *, vuint8mf2_t *, const uint8_t *, vuint8mf2_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vluxseg8ei8_v_m)))
void vluxseg8ei8_v_u8mf2_m(vuint8mf2_t *, vuint8mf2_t *, vuint8mf2_t *, vuint8mf2_t *, vuint8mf2_t *, vuint8mf2_t *, vuint8mf2_t *, vuint8mf2_t *, vbool16_t, vuint8mf2_t, vuint8mf2_t, vuint8mf2_t, vuint8mf2_t, vuint8mf2_t, vuint8mf2_t, vuint8mf2_t, vuint8mf2_t, const uint8_t *, vuint8mf2_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vluxseg8ei8_v)))
void vluxseg8ei8_v_u8mf4(vuint8mf4_t *, vuint8mf4_t *, vuint8mf4_t *, vuint8mf4_t *, vuint8mf4_t *, vuint8mf4_t *, vuint8mf4_t *, vuint8mf4_t *, const uint8_t *, vuint8mf4_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vluxseg8ei8_v_m)))
void vluxseg8ei8_v_u8mf4_m(vuint8mf4_t *, vuint8mf4_t *, vuint8mf4_t *, vuint8mf4_t *, vuint8mf4_t *, vuint8mf4_t *, vuint8mf4_t *, vuint8mf4_t *, vbool32_t, vuint8mf4_t, vuint8mf4_t, vuint8mf4_t, vuint8mf4_t, vuint8mf4_t, vuint8mf4_t, vuint8mf4_t, vuint8mf4_t, const uint8_t *, vuint8mf4_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vluxseg8ei8_v)))
void vluxseg8ei8_v_u8mf8(vuint8mf8_t *, vuint8mf8_t *, vuint8mf8_t *, vuint8mf8_t *, vuint8mf8_t *, vuint8mf8_t *, vuint8mf8_t *, vuint8mf8_t *, const uint8_t *, vuint8mf8_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vluxseg8ei8_v_m)))
void vluxseg8ei8_v_u8mf8_m(vuint8mf8_t *, vuint8mf8_t *, vuint8mf8_t *, vuint8mf8_t *, vuint8mf8_t *, vuint8mf8_t *, vuint8mf8_t *, vuint8mf8_t *, vbool64_t, vuint8mf8_t, vuint8mf8_t, vuint8mf8_t, vuint8mf8_t, vuint8mf8_t, vuint8mf8_t, vuint8mf8_t, vuint8mf8_t, const uint8_t *, vuint8mf8_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vluxseg2ei16_v)))
void vluxseg2ei16_v_i8m1(vint8m1_t *, vint8m1_t *, const int8_t *, vuint16m2_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vluxseg2ei16_v_m)))
void vluxseg2ei16_v_i8m1_m(vint8m1_t *, vint8m1_t *, vbool8_t, vint8m1_t, vint8m1_t, const int8_t *, vuint16m2_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vluxseg2ei16_v)))
void vluxseg2ei16_v_i8m2(vint8m2_t *, vint8m2_t *, const int8_t *, vuint16m4_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vluxseg2ei16_v_m)))
void vluxseg2ei16_v_i8m2_m(vint8m2_t *, vint8m2_t *, vbool4_t, vint8m2_t, vint8m2_t, const int8_t *, vuint16m4_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vluxseg2ei16_v)))
void vluxseg2ei16_v_i8m4(vint8m4_t *, vint8m4_t *, const int8_t *, vuint16m8_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vluxseg2ei16_v_m)))
void vluxseg2ei16_v_i8m4_m(vint8m4_t *, vint8m4_t *, vbool2_t, vint8m4_t, vint8m4_t, const int8_t *, vuint16m8_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vluxseg2ei16_v)))
void vluxseg2ei16_v_i8mf2(vint8mf2_t *, vint8mf2_t *, const int8_t *, vuint16m1_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vluxseg2ei16_v_m)))
void vluxseg2ei16_v_i8mf2_m(vint8mf2_t *, vint8mf2_t *, vbool16_t, vint8mf2_t, vint8mf2_t, const int8_t *, vuint16m1_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vluxseg2ei16_v)))
void vluxseg2ei16_v_i8mf4(vint8mf4_t *, vint8mf4_t *, const int8_t *, vuint16mf2_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vluxseg2ei16_v_m)))
void vluxseg2ei16_v_i8mf4_m(vint8mf4_t *, vint8mf4_t *, vbool32_t, vint8mf4_t, vint8mf4_t, const int8_t *, vuint16mf2_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vluxseg2ei16_v)))
void vluxseg2ei16_v_i8mf8(vint8mf8_t *, vint8mf8_t *, const int8_t *, vuint16mf4_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vluxseg2ei16_v_m)))
void vluxseg2ei16_v_i8mf8_m(vint8mf8_t *, vint8mf8_t *, vbool64_t, vint8mf8_t, vint8mf8_t, const int8_t *, vuint16mf4_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vluxseg2ei16_v)))
void vluxseg2ei16_v_u8m1(vuint8m1_t *, vuint8m1_t *, const uint8_t *, vuint16m2_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vluxseg2ei16_v_m)))
void vluxseg2ei16_v_u8m1_m(vuint8m1_t *, vuint8m1_t *, vbool8_t, vuint8m1_t, vuint8m1_t, const uint8_t *, vuint16m2_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vluxseg2ei16_v)))
void vluxseg2ei16_v_u8m2(vuint8m2_t *, vuint8m2_t *, const uint8_t *, vuint16m4_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vluxseg2ei16_v_m)))
void vluxseg2ei16_v_u8m2_m(vuint8m2_t *, vuint8m2_t *, vbool4_t, vuint8m2_t, vuint8m2_t, const uint8_t *, vuint16m4_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vluxseg2ei16_v)))
void vluxseg2ei16_v_u8m4(vuint8m4_t *, vuint8m4_t *, const uint8_t *, vuint16m8_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vluxseg2ei16_v_m)))
void vluxseg2ei16_v_u8m4_m(vuint8m4_t *, vuint8m4_t *, vbool2_t, vuint8m4_t, vuint8m4_t, const uint8_t *, vuint16m8_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vluxseg2ei16_v)))
void vluxseg2ei16_v_u8mf2(vuint8mf2_t *, vuint8mf2_t *, const uint8_t *, vuint16m1_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vluxseg2ei16_v_m)))
void vluxseg2ei16_v_u8mf2_m(vuint8mf2_t *, vuint8mf2_t *, vbool16_t, vuint8mf2_t, vuint8mf2_t, const uint8_t *, vuint16m1_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vluxseg2ei16_v)))
void vluxseg2ei16_v_u8mf4(vuint8mf4_t *, vuint8mf4_t *, const uint8_t *, vuint16mf2_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vluxseg2ei16_v_m)))
void vluxseg2ei16_v_u8mf4_m(vuint8mf4_t *, vuint8mf4_t *, vbool32_t, vuint8mf4_t, vuint8mf4_t, const uint8_t *, vuint16mf2_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vluxseg2ei16_v)))
void vluxseg2ei16_v_u8mf8(vuint8mf8_t *, vuint8mf8_t *, const uint8_t *, vuint16mf4_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vluxseg2ei16_v_m)))
void vluxseg2ei16_v_u8mf8_m(vuint8mf8_t *, vuint8mf8_t *, vbool64_t, vuint8mf8_t, vuint8mf8_t, const uint8_t *, vuint16mf4_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vluxseg3ei16_v)))
void vluxseg3ei16_v_i8m1(vint8m1_t *, vint8m1_t *, vint8m1_t *, const int8_t *, vuint16m2_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vluxseg3ei16_v_m)))
void vluxseg3ei16_v_i8m1_m(vint8m1_t *, vint8m1_t *, vint8m1_t *, vbool8_t, vint8m1_t, vint8m1_t, vint8m1_t, const int8_t *, vuint16m2_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vluxseg3ei16_v)))
void vluxseg3ei16_v_i8m2(vint8m2_t *, vint8m2_t *, vint8m2_t *, const int8_t *, vuint16m4_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vluxseg3ei16_v_m)))
void vluxseg3ei16_v_i8m2_m(vint8m2_t *, vint8m2_t *, vint8m2_t *, vbool4_t, vint8m2_t, vint8m2_t, vint8m2_t, const int8_t *, vuint16m4_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vluxseg3ei16_v)))
void vluxseg3ei16_v_i8mf2(vint8mf2_t *, vint8mf2_t *, vint8mf2_t *, const int8_t *, vuint16m1_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vluxseg3ei16_v_m)))
void vluxseg3ei16_v_i8mf2_m(vint8mf2_t *, vint8mf2_t *, vint8mf2_t *, vbool16_t, vint8mf2_t, vint8mf2_t, vint8mf2_t, const int8_t *, vuint16m1_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vluxseg3ei16_v)))
void vluxseg3ei16_v_i8mf4(vint8mf4_t *, vint8mf4_t *, vint8mf4_t *, const int8_t *, vuint16mf2_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vluxseg3ei16_v_m)))
void vluxseg3ei16_v_i8mf4_m(vint8mf4_t *, vint8mf4_t *, vint8mf4_t *, vbool32_t, vint8mf4_t, vint8mf4_t, vint8mf4_t, const int8_t *, vuint16mf2_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vluxseg3ei16_v)))
void vluxseg3ei16_v_i8mf8(vint8mf8_t *, vint8mf8_t *, vint8mf8_t *, const int8_t *, vuint16mf4_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vluxseg3ei16_v_m)))
void vluxseg3ei16_v_i8mf8_m(vint8mf8_t *, vint8mf8_t *, vint8mf8_t *, vbool64_t, vint8mf8_t, vint8mf8_t, vint8mf8_t, const int8_t *, vuint16mf4_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vluxseg3ei16_v)))
void vluxseg3ei16_v_u8m1(vuint8m1_t *, vuint8m1_t *, vuint8m1_t *, const uint8_t *, vuint16m2_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vluxseg3ei16_v_m)))
void vluxseg3ei16_v_u8m1_m(vuint8m1_t *, vuint8m1_t *, vuint8m1_t *, vbool8_t, vuint8m1_t, vuint8m1_t, vuint8m1_t, const uint8_t *, vuint16m2_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vluxseg3ei16_v)))
void vluxseg3ei16_v_u8m2(vuint8m2_t *, vuint8m2_t *, vuint8m2_t *, const uint8_t *, vuint16m4_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vluxseg3ei16_v_m)))
void vluxseg3ei16_v_u8m2_m(vuint8m2_t *, vuint8m2_t *, vuint8m2_t *, vbool4_t, vuint8m2_t, vuint8m2_t, vuint8m2_t, const uint8_t *, vuint16m4_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vluxseg3ei16_v)))
void vluxseg3ei16_v_u8mf2(vuint8mf2_t *, vuint8mf2_t *, vuint8mf2_t *, const uint8_t *, vuint16m1_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vluxseg3ei16_v_m)))
void vluxseg3ei16_v_u8mf2_m(vuint8mf2_t *, vuint8mf2_t *, vuint8mf2_t *, vbool16_t, vuint8mf2_t, vuint8mf2_t, vuint8mf2_t, const uint8_t *, vuint16m1_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vluxseg3ei16_v)))
void vluxseg3ei16_v_u8mf4(vuint8mf4_t *, vuint8mf4_t *, vuint8mf4_t *, const uint8_t *, vuint16mf2_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vluxseg3ei16_v_m)))
void vluxseg3ei16_v_u8mf4_m(vuint8mf4_t *, vuint8mf4_t *, vuint8mf4_t *, vbool32_t, vuint8mf4_t, vuint8mf4_t, vuint8mf4_t, const uint8_t *, vuint16mf2_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vluxseg3ei16_v)))
void vluxseg3ei16_v_u8mf8(vuint8mf8_t *, vuint8mf8_t *, vuint8mf8_t *, const uint8_t *, vuint16mf4_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vluxseg3ei16_v_m)))
void vluxseg3ei16_v_u8mf8_m(vuint8mf8_t *, vuint8mf8_t *, vuint8mf8_t *, vbool64_t, vuint8mf8_t, vuint8mf8_t, vuint8mf8_t, const uint8_t *, vuint16mf4_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vluxseg4ei16_v)))
void vluxseg4ei16_v_i8m1(vint8m1_t *, vint8m1_t *, vint8m1_t *, vint8m1_t *, const int8_t *, vuint16m2_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vluxseg4ei16_v_m)))
void vluxseg4ei16_v_i8m1_m(vint8m1_t *, vint8m1_t *, vint8m1_t *, vint8m1_t *, vbool8_t, vint8m1_t, vint8m1_t, vint8m1_t, vint8m1_t, const int8_t *, vuint16m2_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vluxseg4ei16_v)))
void vluxseg4ei16_v_i8m2(vint8m2_t *, vint8m2_t *, vint8m2_t *, vint8m2_t *, const int8_t *, vuint16m4_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vluxseg4ei16_v_m)))
void vluxseg4ei16_v_i8m2_m(vint8m2_t *, vint8m2_t *, vint8m2_t *, vint8m2_t *, vbool4_t, vint8m2_t, vint8m2_t, vint8m2_t, vint8m2_t, const int8_t *, vuint16m4_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vluxseg4ei16_v)))
void vluxseg4ei16_v_i8mf2(vint8mf2_t *, vint8mf2_t *, vint8mf2_t *, vint8mf2_t *, const int8_t *, vuint16m1_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vluxseg4ei16_v_m)))
void vluxseg4ei16_v_i8mf2_m(vint8mf2_t *, vint8mf2_t *, vint8mf2_t *, vint8mf2_t *, vbool16_t, vint8mf2_t, vint8mf2_t, vint8mf2_t, vint8mf2_t, const int8_t *, vuint16m1_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vluxseg4ei16_v)))
void vluxseg4ei16_v_i8mf4(vint8mf4_t *, vint8mf4_t *, vint8mf4_t *, vint8mf4_t *, const int8_t *, vuint16mf2_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vluxseg4ei16_v_m)))
void vluxseg4ei16_v_i8mf4_m(vint8mf4_t *, vint8mf4_t *, vint8mf4_t *, vint8mf4_t *, vbool32_t, vint8mf4_t, vint8mf4_t, vint8mf4_t, vint8mf4_t, const int8_t *, vuint16mf2_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vluxseg4ei16_v)))
void vluxseg4ei16_v_i8mf8(vint8mf8_t *, vint8mf8_t *, vint8mf8_t *, vint8mf8_t *, const int8_t *, vuint16mf4_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vluxseg4ei16_v_m)))
void vluxseg4ei16_v_i8mf8_m(vint8mf8_t *, vint8mf8_t *, vint8mf8_t *, vint8mf8_t *, vbool64_t, vint8mf8_t, vint8mf8_t, vint8mf8_t, vint8mf8_t, const int8_t *, vuint16mf4_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vluxseg4ei16_v)))
void vluxseg4ei16_v_u8m1(vuint8m1_t *, vuint8m1_t *, vuint8m1_t *, vuint8m1_t *, const uint8_t *, vuint16m2_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vluxseg4ei16_v_m)))
void vluxseg4ei16_v_u8m1_m(vuint8m1_t *, vuint8m1_t *, vuint8m1_t *, vuint8m1_t *, vbool8_t, vuint8m1_t, vuint8m1_t, vuint8m1_t, vuint8m1_t, const uint8_t *, vuint16m2_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vluxseg4ei16_v)))
void vluxseg4ei16_v_u8m2(vuint8m2_t *, vuint8m2_t *, vuint8m2_t *, vuint8m2_t *, const uint8_t *, vuint16m4_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vluxseg4ei16_v_m)))
void vluxseg4ei16_v_u8m2_m(vuint8m2_t *, vuint8m2_t *, vuint8m2_t *, vuint8m2_t *, vbool4_t, vuint8m2_t, vuint8m2_t, vuint8m2_t, vuint8m2_t, const uint8_t *, vuint16m4_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vluxseg4ei16_v)))
void vluxseg4ei16_v_u8mf2(vuint8mf2_t *, vuint8mf2_t *, vuint8mf2_t *, vuint8mf2_t *, const uint8_t *, vuint16m1_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vluxseg4ei16_v_m)))
void vluxseg4ei16_v_u8mf2_m(vuint8mf2_t *, vuint8mf2_t *, vuint8mf2_t *, vuint8mf2_t *, vbool16_t, vuint8mf2_t, vuint8mf2_t, vuint8mf2_t, vuint8mf2_t, const uint8_t *, vuint16m1_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vluxseg4ei16_v)))
void vluxseg4ei16_v_u8mf4(vuint8mf4_t *, vuint8mf4_t *, vuint8mf4_t *, vuint8mf4_t *, const uint8_t *, vuint16mf2_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vluxseg4ei16_v_m)))
void vluxseg4ei16_v_u8mf4_m(vuint8mf4_t *, vuint8mf4_t *, vuint8mf4_t *, vuint8mf4_t *, vbool32_t, vuint8mf4_t, vuint8mf4_t, vuint8mf4_t, vuint8mf4_t, const uint8_t *, vuint16mf2_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vluxseg4ei16_v)))
void vluxseg4ei16_v_u8mf8(vuint8mf8_t *, vuint8mf8_t *, vuint8mf8_t *, vuint8mf8_t *, const uint8_t *, vuint16mf4_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vluxseg4ei16_v_m)))
void vluxseg4ei16_v_u8mf8_m(vuint8mf8_t *, vuint8mf8_t *, vuint8mf8_t *, vuint8mf8_t *, vbool64_t, vuint8mf8_t, vuint8mf8_t, vuint8mf8_t, vuint8mf8_t, const uint8_t *, vuint16mf4_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vluxseg5ei16_v)))
void vluxseg5ei16_v_i8m1(vint8m1_t *, vint8m1_t *, vint8m1_t *, vint8m1_t *, vint8m1_t *, const int8_t *, vuint16m2_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vluxseg5ei16_v_m)))
void vluxseg5ei16_v_i8m1_m(vint8m1_t *, vint8m1_t *, vint8m1_t *, vint8m1_t *, vint8m1_t *, vbool8_t, vint8m1_t, vint8m1_t, vint8m1_t, vint8m1_t, vint8m1_t, const int8_t *, vuint16m2_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vluxseg5ei16_v)))
void vluxseg5ei16_v_i8mf2(vint8mf2_t *, vint8mf2_t *, vint8mf2_t *, vint8mf2_t *, vint8mf2_t *, const int8_t *, vuint16m1_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vluxseg5ei16_v_m)))
void vluxseg5ei16_v_i8mf2_m(vint8mf2_t *, vint8mf2_t *, vint8mf2_t *, vint8mf2_t *, vint8mf2_t *, vbool16_t, vint8mf2_t, vint8mf2_t, vint8mf2_t, vint8mf2_t, vint8mf2_t, const int8_t *, vuint16m1_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vluxseg5ei16_v)))
void vluxseg5ei16_v_i8mf4(vint8mf4_t *, vint8mf4_t *, vint8mf4_t *, vint8mf4_t *, vint8mf4_t *, const int8_t *, vuint16mf2_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vluxseg5ei16_v_m)))
void vluxseg5ei16_v_i8mf4_m(vint8mf4_t *, vint8mf4_t *, vint8mf4_t *, vint8mf4_t *, vint8mf4_t *, vbool32_t, vint8mf4_t, vint8mf4_t, vint8mf4_t, vint8mf4_t, vint8mf4_t, const int8_t *, vuint16mf2_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vluxseg5ei16_v)))
void vluxseg5ei16_v_i8mf8(vint8mf8_t *, vint8mf8_t *, vint8mf8_t *, vint8mf8_t *, vint8mf8_t *, const int8_t *, vuint16mf4_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vluxseg5ei16_v_m)))
void vluxseg5ei16_v_i8mf8_m(vint8mf8_t *, vint8mf8_t *, vint8mf8_t *, vint8mf8_t *, vint8mf8_t *, vbool64_t, vint8mf8_t, vint8mf8_t, vint8mf8_t, vint8mf8_t, vint8mf8_t, const int8_t *, vuint16mf4_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vluxseg5ei16_v)))
void vluxseg5ei16_v_u8m1(vuint8m1_t *, vuint8m1_t *, vuint8m1_t *, vuint8m1_t *, vuint8m1_t *, const uint8_t *, vuint16m2_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vluxseg5ei16_v_m)))
void vluxseg5ei16_v_u8m1_m(vuint8m1_t *, vuint8m1_t *, vuint8m1_t *, vuint8m1_t *, vuint8m1_t *, vbool8_t, vuint8m1_t, vuint8m1_t, vuint8m1_t, vuint8m1_t, vuint8m1_t, const uint8_t *, vuint16m2_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vluxseg5ei16_v)))
void vluxseg5ei16_v_u8mf2(vuint8mf2_t *, vuint8mf2_t *, vuint8mf2_t *, vuint8mf2_t *, vuint8mf2_t *, const uint8_t *, vuint16m1_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vluxseg5ei16_v_m)))
void vluxseg5ei16_v_u8mf2_m(vuint8mf2_t *, vuint8mf2_t *, vuint8mf2_t *, vuint8mf2_t *, vuint8mf2_t *, vbool16_t, vuint8mf2_t, vuint8mf2_t, vuint8mf2_t, vuint8mf2_t, vuint8mf2_t, const uint8_t *, vuint16m1_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vluxseg5ei16_v)))
void vluxseg5ei16_v_u8mf4(vuint8mf4_t *, vuint8mf4_t *, vuint8mf4_t *, vuint8mf4_t *, vuint8mf4_t *, const uint8_t *, vuint16mf2_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vluxseg5ei16_v_m)))
void vluxseg5ei16_v_u8mf4_m(vuint8mf4_t *, vuint8mf4_t *, vuint8mf4_t *, vuint8mf4_t *, vuint8mf4_t *, vbool32_t, vuint8mf4_t, vuint8mf4_t, vuint8mf4_t, vuint8mf4_t, vuint8mf4_t, const uint8_t *, vuint16mf2_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vluxseg5ei16_v)))
void vluxseg5ei16_v_u8mf8(vuint8mf8_t *, vuint8mf8_t *, vuint8mf8_t *, vuint8mf8_t *, vuint8mf8_t *, const uint8_t *, vuint16mf4_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vluxseg5ei16_v_m)))
void vluxseg5ei16_v_u8mf8_m(vuint8mf8_t *, vuint8mf8_t *, vuint8mf8_t *, vuint8mf8_t *, vuint8mf8_t *, vbool64_t, vuint8mf8_t, vuint8mf8_t, vuint8mf8_t, vuint8mf8_t, vuint8mf8_t, const uint8_t *, vuint16mf4_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vluxseg6ei16_v)))
void vluxseg6ei16_v_i8m1(vint8m1_t *, vint8m1_t *, vint8m1_t *, vint8m1_t *, vint8m1_t *, vint8m1_t *, const int8_t *, vuint16m2_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vluxseg6ei16_v_m)))
void vluxseg6ei16_v_i8m1_m(vint8m1_t *, vint8m1_t *, vint8m1_t *, vint8m1_t *, vint8m1_t *, vint8m1_t *, vbool8_t, vint8m1_t, vint8m1_t, vint8m1_t, vint8m1_t, vint8m1_t, vint8m1_t, const int8_t *, vuint16m2_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vluxseg6ei16_v)))
void vluxseg6ei16_v_i8mf2(vint8mf2_t *, vint8mf2_t *, vint8mf2_t *, vint8mf2_t *, vint8mf2_t *, vint8mf2_t *, const int8_t *, vuint16m1_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vluxseg6ei16_v_m)))
void vluxseg6ei16_v_i8mf2_m(vint8mf2_t *, vint8mf2_t *, vint8mf2_t *, vint8mf2_t *, vint8mf2_t *, vint8mf2_t *, vbool16_t, vint8mf2_t, vint8mf2_t, vint8mf2_t, vint8mf2_t, vint8mf2_t, vint8mf2_t, const int8_t *, vuint16m1_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vluxseg6ei16_v)))
void vluxseg6ei16_v_i8mf4(vint8mf4_t *, vint8mf4_t *, vint8mf4_t *, vint8mf4_t *, vint8mf4_t *, vint8mf4_t *, const int8_t *, vuint16mf2_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vluxseg6ei16_v_m)))
void vluxseg6ei16_v_i8mf4_m(vint8mf4_t *, vint8mf4_t *, vint8mf4_t *, vint8mf4_t *, vint8mf4_t *, vint8mf4_t *, vbool32_t, vint8mf4_t, vint8mf4_t, vint8mf4_t, vint8mf4_t, vint8mf4_t, vint8mf4_t, const int8_t *, vuint16mf2_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vluxseg6ei16_v)))
void vluxseg6ei16_v_i8mf8(vint8mf8_t *, vint8mf8_t *, vint8mf8_t *, vint8mf8_t *, vint8mf8_t *, vint8mf8_t *, const int8_t *, vuint16mf4_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vluxseg6ei16_v_m)))
void vluxseg6ei16_v_i8mf8_m(vint8mf8_t *, vint8mf8_t *, vint8mf8_t *, vint8mf8_t *, vint8mf8_t *, vint8mf8_t *, vbool64_t, vint8mf8_t, vint8mf8_t, vint8mf8_t, vint8mf8_t, vint8mf8_t, vint8mf8_t, const int8_t *, vuint16mf4_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vluxseg6ei16_v)))
void vluxseg6ei16_v_u8m1(vuint8m1_t *, vuint8m1_t *, vuint8m1_t *, vuint8m1_t *, vuint8m1_t *, vuint8m1_t *, const uint8_t *, vuint16m2_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vluxseg6ei16_v_m)))
void vluxseg6ei16_v_u8m1_m(vuint8m1_t *, vuint8m1_t *, vuint8m1_t *, vuint8m1_t *, vuint8m1_t *, vuint8m1_t *, vbool8_t, vuint8m1_t, vuint8m1_t, vuint8m1_t, vuint8m1_t, vuint8m1_t, vuint8m1_t, const uint8_t *, vuint16m2_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vluxseg6ei16_v)))
void vluxseg6ei16_v_u8mf2(vuint8mf2_t *, vuint8mf2_t *, vuint8mf2_t *, vuint8mf2_t *, vuint8mf2_t *, vuint8mf2_t *, const uint8_t *, vuint16m1_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vluxseg6ei16_v_m)))
void vluxseg6ei16_v_u8mf2_m(vuint8mf2_t *, vuint8mf2_t *, vuint8mf2_t *, vuint8mf2_t *, vuint8mf2_t *, vuint8mf2_t *, vbool16_t, vuint8mf2_t, vuint8mf2_t, vuint8mf2_t, vuint8mf2_t, vuint8mf2_t, vuint8mf2_t, const uint8_t *, vuint16m1_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vluxseg6ei16_v)))
void vluxseg6ei16_v_u8mf4(vuint8mf4_t *, vuint8mf4_t *, vuint8mf4_t *, vuint8mf4_t *, vuint8mf4_t *, vuint8mf4_t *, const uint8_t *, vuint16mf2_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vluxseg6ei16_v_m)))
void vluxseg6ei16_v_u8mf4_m(vuint8mf4_t *, vuint8mf4_t *, vuint8mf4_t *, vuint8mf4_t *, vuint8mf4_t *, vuint8mf4_t *, vbool32_t, vuint8mf4_t, vuint8mf4_t, vuint8mf4_t, vuint8mf4_t, vuint8mf4_t, vuint8mf4_t, const uint8_t *, vuint16mf2_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vluxseg6ei16_v)))
void vluxseg6ei16_v_u8mf8(vuint8mf8_t *, vuint8mf8_t *, vuint8mf8_t *, vuint8mf8_t *, vuint8mf8_t *, vuint8mf8_t *, const uint8_t *, vuint16mf4_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vluxseg6ei16_v_m)))
void vluxseg6ei16_v_u8mf8_m(vuint8mf8_t *, vuint8mf8_t *, vuint8mf8_t *, vuint8mf8_t *, vuint8mf8_t *, vuint8mf8_t *, vbool64_t, vuint8mf8_t, vuint8mf8_t, vuint8mf8_t, vuint8mf8_t, vuint8mf8_t, vuint8mf8_t, const uint8_t *, vuint16mf4_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vluxseg7ei16_v)))
void vluxseg7ei16_v_i8m1(vint8m1_t *, vint8m1_t *, vint8m1_t *, vint8m1_t *, vint8m1_t *, vint8m1_t *, vint8m1_t *, const int8_t *, vuint16m2_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vluxseg7ei16_v_m)))
void vluxseg7ei16_v_i8m1_m(vint8m1_t *, vint8m1_t *, vint8m1_t *, vint8m1_t *, vint8m1_t *, vint8m1_t *, vint8m1_t *, vbool8_t, vint8m1_t, vint8m1_t, vint8m1_t, vint8m1_t, vint8m1_t, vint8m1_t, vint8m1_t, const int8_t *, vuint16m2_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vluxseg7ei16_v)))
void vluxseg7ei16_v_i8mf2(vint8mf2_t *, vint8mf2_t *, vint8mf2_t *, vint8mf2_t *, vint8mf2_t *, vint8mf2_t *, vint8mf2_t *, const int8_t *, vuint16m1_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vluxseg7ei16_v_m)))
void vluxseg7ei16_v_i8mf2_m(vint8mf2_t *, vint8mf2_t *, vint8mf2_t *, vint8mf2_t *, vint8mf2_t *, vint8mf2_t *, vint8mf2_t *, vbool16_t, vint8mf2_t, vint8mf2_t, vint8mf2_t, vint8mf2_t, vint8mf2_t, vint8mf2_t, vint8mf2_t, const int8_t *, vuint16m1_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vluxseg7ei16_v)))
void vluxseg7ei16_v_i8mf4(vint8mf4_t *, vint8mf4_t *, vint8mf4_t *, vint8mf4_t *, vint8mf4_t *, vint8mf4_t *, vint8mf4_t *, const int8_t *, vuint16mf2_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vluxseg7ei16_v_m)))
void vluxseg7ei16_v_i8mf4_m(vint8mf4_t *, vint8mf4_t *, vint8mf4_t *, vint8mf4_t *, vint8mf4_t *, vint8mf4_t *, vint8mf4_t *, vbool32_t, vint8mf4_t, vint8mf4_t, vint8mf4_t, vint8mf4_t, vint8mf4_t, vint8mf4_t, vint8mf4_t, const int8_t *, vuint16mf2_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vluxseg7ei16_v)))
void vluxseg7ei16_v_i8mf8(vint8mf8_t *, vint8mf8_t *, vint8mf8_t *, vint8mf8_t *, vint8mf8_t *, vint8mf8_t *, vint8mf8_t *, const int8_t *, vuint16mf4_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vluxseg7ei16_v_m)))
void vluxseg7ei16_v_i8mf8_m(vint8mf8_t *, vint8mf8_t *, vint8mf8_t *, vint8mf8_t *, vint8mf8_t *, vint8mf8_t *, vint8mf8_t *, vbool64_t, vint8mf8_t, vint8mf8_t, vint8mf8_t, vint8mf8_t, vint8mf8_t, vint8mf8_t, vint8mf8_t, const int8_t *, vuint16mf4_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vluxseg7ei16_v)))
void vluxseg7ei16_v_u8m1(vuint8m1_t *, vuint8m1_t *, vuint8m1_t *, vuint8m1_t *, vuint8m1_t *, vuint8m1_t *, vuint8m1_t *, const uint8_t *, vuint16m2_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vluxseg7ei16_v_m)))
void vluxseg7ei16_v_u8m1_m(vuint8m1_t *, vuint8m1_t *, vuint8m1_t *, vuint8m1_t *, vuint8m1_t *, vuint8m1_t *, vuint8m1_t *, vbool8_t, vuint8m1_t, vuint8m1_t, vuint8m1_t, vuint8m1_t, vuint8m1_t, vuint8m1_t, vuint8m1_t, const uint8_t *, vuint16m2_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vluxseg7ei16_v)))
void vluxseg7ei16_v_u8mf2(vuint8mf2_t *, vuint8mf2_t *, vuint8mf2_t *, vuint8mf2_t *, vuint8mf2_t *, vuint8mf2_t *, vuint8mf2_t *, const uint8_t *, vuint16m1_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vluxseg7ei16_v_m)))
void vluxseg7ei16_v_u8mf2_m(vuint8mf2_t *, vuint8mf2_t *, vuint8mf2_t *, vuint8mf2_t *, vuint8mf2_t *, vuint8mf2_t *, vuint8mf2_t *, vbool16_t, vuint8mf2_t, vuint8mf2_t, vuint8mf2_t, vuint8mf2_t, vuint8mf2_t, vuint8mf2_t, vuint8mf2_t, const uint8_t *, vuint16m1_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vluxseg7ei16_v)))
void vluxseg7ei16_v_u8mf4(vuint8mf4_t *, vuint8mf4_t *, vuint8mf4_t *, vuint8mf4_t *, vuint8mf4_t *, vuint8mf4_t *, vuint8mf4_t *, const uint8_t *, vuint16mf2_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vluxseg7ei16_v_m)))
void vluxseg7ei16_v_u8mf4_m(vuint8mf4_t *, vuint8mf4_t *, vuint8mf4_t *, vuint8mf4_t *, vuint8mf4_t *, vuint8mf4_t *, vuint8mf4_t *, vbool32_t, vuint8mf4_t, vuint8mf4_t, vuint8mf4_t, vuint8mf4_t, vuint8mf4_t, vuint8mf4_t, vuint8mf4_t, const uint8_t *, vuint16mf2_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vluxseg7ei16_v)))
void vluxseg7ei16_v_u8mf8(vuint8mf8_t *, vuint8mf8_t *, vuint8mf8_t *, vuint8mf8_t *, vuint8mf8_t *, vuint8mf8_t *, vuint8mf8_t *, const uint8_t *, vuint16mf4_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vluxseg7ei16_v_m)))
void vluxseg7ei16_v_u8mf8_m(vuint8mf8_t *, vuint8mf8_t *, vuint8mf8_t *, vuint8mf8_t *, vuint8mf8_t *, vuint8mf8_t *, vuint8mf8_t *, vbool64_t, vuint8mf8_t, vuint8mf8_t, vuint8mf8_t, vuint8mf8_t, vuint8mf8_t, vuint8mf8_t, vuint8mf8_t, const uint8_t *, vuint16mf4_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vluxseg8ei16_v)))
void vluxseg8ei16_v_i8m1(vint8m1_t *, vint8m1_t *, vint8m1_t *, vint8m1_t *, vint8m1_t *, vint8m1_t *, vint8m1_t *, vint8m1_t *, const int8_t *, vuint16m2_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vluxseg8ei16_v_m)))
void vluxseg8ei16_v_i8m1_m(vint8m1_t *, vint8m1_t *, vint8m1_t *, vint8m1_t *, vint8m1_t *, vint8m1_t *, vint8m1_t *, vint8m1_t *, vbool8_t, vint8m1_t, vint8m1_t, vint8m1_t, vint8m1_t, vint8m1_t, vint8m1_t, vint8m1_t, vint8m1_t, const int8_t *, vuint16m2_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vluxseg8ei16_v)))
void vluxseg8ei16_v_i8mf2(vint8mf2_t *, vint8mf2_t *, vint8mf2_t *, vint8mf2_t *, vint8mf2_t *, vint8mf2_t *, vint8mf2_t *, vint8mf2_t *, const int8_t *, vuint16m1_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vluxseg8ei16_v_m)))
void vluxseg8ei16_v_i8mf2_m(vint8mf2_t *, vint8mf2_t *, vint8mf2_t *, vint8mf2_t *, vint8mf2_t *, vint8mf2_t *, vint8mf2_t *, vint8mf2_t *, vbool16_t, vint8mf2_t, vint8mf2_t, vint8mf2_t, vint8mf2_t, vint8mf2_t, vint8mf2_t, vint8mf2_t, vint8mf2_t, const int8_t *, vuint16m1_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vluxseg8ei16_v)))
void vluxseg8ei16_v_i8mf4(vint8mf4_t *, vint8mf4_t *, vint8mf4_t *, vint8mf4_t *, vint8mf4_t *, vint8mf4_t *, vint8mf4_t *, vint8mf4_t *, const int8_t *, vuint16mf2_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vluxseg8ei16_v_m)))
void vluxseg8ei16_v_i8mf4_m(vint8mf4_t *, vint8mf4_t *, vint8mf4_t *, vint8mf4_t *, vint8mf4_t *, vint8mf4_t *, vint8mf4_t *, vint8mf4_t *, vbool32_t, vint8mf4_t, vint8mf4_t, vint8mf4_t, vint8mf4_t, vint8mf4_t, vint8mf4_t, vint8mf4_t, vint8mf4_t, const int8_t *, vuint16mf2_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vluxseg8ei16_v)))
void vluxseg8ei16_v_i8mf8(vint8mf8_t *, vint8mf8_t *, vint8mf8_t *, vint8mf8_t *, vint8mf8_t *, vint8mf8_t *, vint8mf8_t *, vint8mf8_t *, const int8_t *, vuint16mf4_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vluxseg8ei16_v_m)))
void vluxseg8ei16_v_i8mf8_m(vint8mf8_t *, vint8mf8_t *, vint8mf8_t *, vint8mf8_t *, vint8mf8_t *, vint8mf8_t *, vint8mf8_t *, vint8mf8_t *, vbool64_t, vint8mf8_t, vint8mf8_t, vint8mf8_t, vint8mf8_t, vint8mf8_t, vint8mf8_t, vint8mf8_t, vint8mf8_t, const int8_t *, vuint16mf4_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vluxseg8ei16_v)))
void vluxseg8ei16_v_u8m1(vuint8m1_t *, vuint8m1_t *, vuint8m1_t *, vuint8m1_t *, vuint8m1_t *, vuint8m1_t *, vuint8m1_t *, vuint8m1_t *, const uint8_t *, vuint16m2_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vluxseg8ei16_v_m)))
void vluxseg8ei16_v_u8m1_m(vuint8m1_t *, vuint8m1_t *, vuint8m1_t *, vuint8m1_t *, vuint8m1_t *, vuint8m1_t *, vuint8m1_t *, vuint8m1_t *, vbool8_t, vuint8m1_t, vuint8m1_t, vuint8m1_t, vuint8m1_t, vuint8m1_t, vuint8m1_t, vuint8m1_t, vuint8m1_t, const uint8_t *, vuint16m2_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vluxseg8ei16_v)))
void vluxseg8ei16_v_u8mf2(vuint8mf2_t *, vuint8mf2_t *, vuint8mf2_t *, vuint8mf2_t *, vuint8mf2_t *, vuint8mf2_t *, vuint8mf2_t *, vuint8mf2_t *, const uint8_t *, vuint16m1_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vluxseg8ei16_v_m)))
void vluxseg8ei16_v_u8mf2_m(vuint8mf2_t *, vuint8mf2_t *, vuint8mf2_t *, vuint8mf2_t *, vuint8mf2_t *, vuint8mf2_t *, vuint8mf2_t *, vuint8mf2_t *, vbool16_t, vuint8mf2_t, vuint8mf2_t, vuint8mf2_t, vuint8mf2_t, vuint8mf2_t, vuint8mf2_t, vuint8mf2_t, vuint8mf2_t, const uint8_t *, vuint16m1_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vluxseg8ei16_v)))
void vluxseg8ei16_v_u8mf4(vuint8mf4_t *, vuint8mf4_t *, vuint8mf4_t *, vuint8mf4_t *, vuint8mf4_t *, vuint8mf4_t *, vuint8mf4_t *, vuint8mf4_t *, const uint8_t *, vuint16mf2_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vluxseg8ei16_v_m)))
void vluxseg8ei16_v_u8mf4_m(vuint8mf4_t *, vuint8mf4_t *, vuint8mf4_t *, vuint8mf4_t *, vuint8mf4_t *, vuint8mf4_t *, vuint8mf4_t *, vuint8mf4_t *, vbool32_t, vuint8mf4_t, vuint8mf4_t, vuint8mf4_t, vuint8mf4_t, vuint8mf4_t, vuint8mf4_t, vuint8mf4_t, vuint8mf4_t, const uint8_t *, vuint16mf2_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vluxseg8ei16_v)))
void vluxseg8ei16_v_u8mf8(vuint8mf8_t *, vuint8mf8_t *, vuint8mf8_t *, vuint8mf8_t *, vuint8mf8_t *, vuint8mf8_t *, vuint8mf8_t *, vuint8mf8_t *, const uint8_t *, vuint16mf4_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vluxseg8ei16_v_m)))
void vluxseg8ei16_v_u8mf8_m(vuint8mf8_t *, vuint8mf8_t *, vuint8mf8_t *, vuint8mf8_t *, vuint8mf8_t *, vuint8mf8_t *, vuint8mf8_t *, vuint8mf8_t *, vbool64_t, vuint8mf8_t, vuint8mf8_t, vuint8mf8_t, vuint8mf8_t, vuint8mf8_t, vuint8mf8_t, vuint8mf8_t, vuint8mf8_t, const uint8_t *, vuint16mf4_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vluxseg2ei32_v)))
void vluxseg2ei32_v_i8m1(vint8m1_t *, vint8m1_t *, const int8_t *, vuint32m4_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vluxseg2ei32_v_m)))
void vluxseg2ei32_v_i8m1_m(vint8m1_t *, vint8m1_t *, vbool8_t, vint8m1_t, vint8m1_t, const int8_t *, vuint32m4_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vluxseg2ei32_v)))
void vluxseg2ei32_v_i8m2(vint8m2_t *, vint8m2_t *, const int8_t *, vuint32m8_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vluxseg2ei32_v_m)))
void vluxseg2ei32_v_i8m2_m(vint8m2_t *, vint8m2_t *, vbool4_t, vint8m2_t, vint8m2_t, const int8_t *, vuint32m8_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vluxseg2ei32_v)))
void vluxseg2ei32_v_i8mf2(vint8mf2_t *, vint8mf2_t *, const int8_t *, vuint32m2_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vluxseg2ei32_v_m)))
void vluxseg2ei32_v_i8mf2_m(vint8mf2_t *, vint8mf2_t *, vbool16_t, vint8mf2_t, vint8mf2_t, const int8_t *, vuint32m2_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vluxseg2ei32_v)))
void vluxseg2ei32_v_i8mf4(vint8mf4_t *, vint8mf4_t *, const int8_t *, vuint32m1_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vluxseg2ei32_v_m)))
void vluxseg2ei32_v_i8mf4_m(vint8mf4_t *, vint8mf4_t *, vbool32_t, vint8mf4_t, vint8mf4_t, const int8_t *, vuint32m1_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vluxseg2ei32_v)))
void vluxseg2ei32_v_i8mf8(vint8mf8_t *, vint8mf8_t *, const int8_t *, vuint32mf2_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vluxseg2ei32_v_m)))
void vluxseg2ei32_v_i8mf8_m(vint8mf8_t *, vint8mf8_t *, vbool64_t, vint8mf8_t, vint8mf8_t, const int8_t *, vuint32mf2_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vluxseg2ei32_v)))
void vluxseg2ei32_v_u8m1(vuint8m1_t *, vuint8m1_t *, const uint8_t *, vuint32m4_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vluxseg2ei32_v_m)))
void vluxseg2ei32_v_u8m1_m(vuint8m1_t *, vuint8m1_t *, vbool8_t, vuint8m1_t, vuint8m1_t, const uint8_t *, vuint32m4_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vluxseg2ei32_v)))
void vluxseg2ei32_v_u8m2(vuint8m2_t *, vuint8m2_t *, const uint8_t *, vuint32m8_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vluxseg2ei32_v_m)))
void vluxseg2ei32_v_u8m2_m(vuint8m2_t *, vuint8m2_t *, vbool4_t, vuint8m2_t, vuint8m2_t, const uint8_t *, vuint32m8_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vluxseg2ei32_v)))
void vluxseg2ei32_v_u8mf2(vuint8mf2_t *, vuint8mf2_t *, const uint8_t *, vuint32m2_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vluxseg2ei32_v_m)))
void vluxseg2ei32_v_u8mf2_m(vuint8mf2_t *, vuint8mf2_t *, vbool16_t, vuint8mf2_t, vuint8mf2_t, const uint8_t *, vuint32m2_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vluxseg2ei32_v)))
void vluxseg2ei32_v_u8mf4(vuint8mf4_t *, vuint8mf4_t *, const uint8_t *, vuint32m1_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vluxseg2ei32_v_m)))
void vluxseg2ei32_v_u8mf4_m(vuint8mf4_t *, vuint8mf4_t *, vbool32_t, vuint8mf4_t, vuint8mf4_t, const uint8_t *, vuint32m1_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vluxseg2ei32_v)))
void vluxseg2ei32_v_u8mf8(vuint8mf8_t *, vuint8mf8_t *, const uint8_t *, vuint32mf2_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vluxseg2ei32_v_m)))
void vluxseg2ei32_v_u8mf8_m(vuint8mf8_t *, vuint8mf8_t *, vbool64_t, vuint8mf8_t, vuint8mf8_t, const uint8_t *, vuint32mf2_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vluxseg3ei32_v)))
void vluxseg3ei32_v_i8m1(vint8m1_t *, vint8m1_t *, vint8m1_t *, const int8_t *, vuint32m4_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vluxseg3ei32_v_m)))
void vluxseg3ei32_v_i8m1_m(vint8m1_t *, vint8m1_t *, vint8m1_t *, vbool8_t, vint8m1_t, vint8m1_t, vint8m1_t, const int8_t *, vuint32m4_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vluxseg3ei32_v)))
void vluxseg3ei32_v_i8m2(vint8m2_t *, vint8m2_t *, vint8m2_t *, const int8_t *, vuint32m8_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vluxseg3ei32_v_m)))
void vluxseg3ei32_v_i8m2_m(vint8m2_t *, vint8m2_t *, vint8m2_t *, vbool4_t, vint8m2_t, vint8m2_t, vint8m2_t, const int8_t *, vuint32m8_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vluxseg3ei32_v)))
void vluxseg3ei32_v_i8mf2(vint8mf2_t *, vint8mf2_t *, vint8mf2_t *, const int8_t *, vuint32m2_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vluxseg3ei32_v_m)))
void vluxseg3ei32_v_i8mf2_m(vint8mf2_t *, vint8mf2_t *, vint8mf2_t *, vbool16_t, vint8mf2_t, vint8mf2_t, vint8mf2_t, const int8_t *, vuint32m2_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vluxseg3ei32_v)))
void vluxseg3ei32_v_i8mf4(vint8mf4_t *, vint8mf4_t *, vint8mf4_t *, const int8_t *, vuint32m1_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vluxseg3ei32_v_m)))
void vluxseg3ei32_v_i8mf4_m(vint8mf4_t *, vint8mf4_t *, vint8mf4_t *, vbool32_t, vint8mf4_t, vint8mf4_t, vint8mf4_t, const int8_t *, vuint32m1_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vluxseg3ei32_v)))
void vluxseg3ei32_v_i8mf8(vint8mf8_t *, vint8mf8_t *, vint8mf8_t *, const int8_t *, vuint32mf2_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vluxseg3ei32_v_m)))
void vluxseg3ei32_v_i8mf8_m(vint8mf8_t *, vint8mf8_t *, vint8mf8_t *, vbool64_t, vint8mf8_t, vint8mf8_t, vint8mf8_t, const int8_t *, vuint32mf2_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vluxseg3ei32_v)))
void vluxseg3ei32_v_u8m1(vuint8m1_t *, vuint8m1_t *, vuint8m1_t *, const uint8_t *, vuint32m4_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vluxseg3ei32_v_m)))
void vluxseg3ei32_v_u8m1_m(vuint8m1_t *, vuint8m1_t *, vuint8m1_t *, vbool8_t, vuint8m1_t, vuint8m1_t, vuint8m1_t, const uint8_t *, vuint32m4_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vluxseg3ei32_v)))
void vluxseg3ei32_v_u8m2(vuint8m2_t *, vuint8m2_t *, vuint8m2_t *, const uint8_t *, vuint32m8_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vluxseg3ei32_v_m)))
void vluxseg3ei32_v_u8m2_m(vuint8m2_t *, vuint8m2_t *, vuint8m2_t *, vbool4_t, vuint8m2_t, vuint8m2_t, vuint8m2_t, const uint8_t *, vuint32m8_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vluxseg3ei32_v)))
void vluxseg3ei32_v_u8mf2(vuint8mf2_t *, vuint8mf2_t *, vuint8mf2_t *, const uint8_t *, vuint32m2_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vluxseg3ei32_v_m)))
void vluxseg3ei32_v_u8mf2_m(vuint8mf2_t *, vuint8mf2_t *, vuint8mf2_t *, vbool16_t, vuint8mf2_t, vuint8mf2_t, vuint8mf2_t, const uint8_t *, vuint32m2_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vluxseg3ei32_v)))
void vluxseg3ei32_v_u8mf4(vuint8mf4_t *, vuint8mf4_t *, vuint8mf4_t *, const uint8_t *, vuint32m1_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vluxseg3ei32_v_m)))
void vluxseg3ei32_v_u8mf4_m(vuint8mf4_t *, vuint8mf4_t *, vuint8mf4_t *, vbool32_t, vuint8mf4_t, vuint8mf4_t, vuint8mf4_t, const uint8_t *, vuint32m1_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vluxseg3ei32_v)))
void vluxseg3ei32_v_u8mf8(vuint8mf8_t *, vuint8mf8_t *, vuint8mf8_t *, const uint8_t *, vuint32mf2_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vluxseg3ei32_v_m)))
void vluxseg3ei32_v_u8mf8_m(vuint8mf8_t *, vuint8mf8_t *, vuint8mf8_t *, vbool64_t, vuint8mf8_t, vuint8mf8_t, vuint8mf8_t, const uint8_t *, vuint32mf2_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vluxseg4ei32_v)))
void vluxseg4ei32_v_i8m1(vint8m1_t *, vint8m1_t *, vint8m1_t *, vint8m1_t *, const int8_t *, vuint32m4_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vluxseg4ei32_v_m)))
void vluxseg4ei32_v_i8m1_m(vint8m1_t *, vint8m1_t *, vint8m1_t *, vint8m1_t *, vbool8_t, vint8m1_t, vint8m1_t, vint8m1_t, vint8m1_t, const int8_t *, vuint32m4_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vluxseg4ei32_v)))
void vluxseg4ei32_v_i8m2(vint8m2_t *, vint8m2_t *, vint8m2_t *, vint8m2_t *, const int8_t *, vuint32m8_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vluxseg4ei32_v_m)))
void vluxseg4ei32_v_i8m2_m(vint8m2_t *, vint8m2_t *, vint8m2_t *, vint8m2_t *, vbool4_t, vint8m2_t, vint8m2_t, vint8m2_t, vint8m2_t, const int8_t *, vuint32m8_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vluxseg4ei32_v)))
void vluxseg4ei32_v_i8mf2(vint8mf2_t *, vint8mf2_t *, vint8mf2_t *, vint8mf2_t *, const int8_t *, vuint32m2_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vluxseg4ei32_v_m)))
void vluxseg4ei32_v_i8mf2_m(vint8mf2_t *, vint8mf2_t *, vint8mf2_t *, vint8mf2_t *, vbool16_t, vint8mf2_t, vint8mf2_t, vint8mf2_t, vint8mf2_t, const int8_t *, vuint32m2_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vluxseg4ei32_v)))
void vluxseg4ei32_v_i8mf4(vint8mf4_t *, vint8mf4_t *, vint8mf4_t *, vint8mf4_t *, const int8_t *, vuint32m1_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vluxseg4ei32_v_m)))
void vluxseg4ei32_v_i8mf4_m(vint8mf4_t *, vint8mf4_t *, vint8mf4_t *, vint8mf4_t *, vbool32_t, vint8mf4_t, vint8mf4_t, vint8mf4_t, vint8mf4_t, const int8_t *, vuint32m1_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vluxseg4ei32_v)))
void vluxseg4ei32_v_i8mf8(vint8mf8_t *, vint8mf8_t *, vint8mf8_t *, vint8mf8_t *, const int8_t *, vuint32mf2_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vluxseg4ei32_v_m)))
void vluxseg4ei32_v_i8mf8_m(vint8mf8_t *, vint8mf8_t *, vint8mf8_t *, vint8mf8_t *, vbool64_t, vint8mf8_t, vint8mf8_t, vint8mf8_t, vint8mf8_t, const int8_t *, vuint32mf2_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vluxseg4ei32_v)))
void vluxseg4ei32_v_u8m1(vuint8m1_t *, vuint8m1_t *, vuint8m1_t *, vuint8m1_t *, const uint8_t *, vuint32m4_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vluxseg4ei32_v_m)))
void vluxseg4ei32_v_u8m1_m(vuint8m1_t *, vuint8m1_t *, vuint8m1_t *, vuint8m1_t *, vbool8_t, vuint8m1_t, vuint8m1_t, vuint8m1_t, vuint8m1_t, const uint8_t *, vuint32m4_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vluxseg4ei32_v)))
void vluxseg4ei32_v_u8m2(vuint8m2_t *, vuint8m2_t *, vuint8m2_t *, vuint8m2_t *, const uint8_t *, vuint32m8_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vluxseg4ei32_v_m)))
void vluxseg4ei32_v_u8m2_m(vuint8m2_t *, vuint8m2_t *, vuint8m2_t *, vuint8m2_t *, vbool4_t, vuint8m2_t, vuint8m2_t, vuint8m2_t, vuint8m2_t, const uint8_t *, vuint32m8_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vluxseg4ei32_v)))
void vluxseg4ei32_v_u8mf2(vuint8mf2_t *, vuint8mf2_t *, vuint8mf2_t *, vuint8mf2_t *, const uint8_t *, vuint32m2_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vluxseg4ei32_v_m)))
void vluxseg4ei32_v_u8mf2_m(vuint8mf2_t *, vuint8mf2_t *, vuint8mf2_t *, vuint8mf2_t *, vbool16_t, vuint8mf2_t, vuint8mf2_t, vuint8mf2_t, vuint8mf2_t, const uint8_t *, vuint32m2_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vluxseg4ei32_v)))
void vluxseg4ei32_v_u8mf4(vuint8mf4_t *, vuint8mf4_t *, vuint8mf4_t *, vuint8mf4_t *, const uint8_t *, vuint32m1_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vluxseg4ei32_v_m)))
void vluxseg4ei32_v_u8mf4_m(vuint8mf4_t *, vuint8mf4_t *, vuint8mf4_t *, vuint8mf4_t *, vbool32_t, vuint8mf4_t, vuint8mf4_t, vuint8mf4_t, vuint8mf4_t, const uint8_t *, vuint32m1_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vluxseg4ei32_v)))
void vluxseg4ei32_v_u8mf8(vuint8mf8_t *, vuint8mf8_t *, vuint8mf8_t *, vuint8mf8_t *, const uint8_t *, vuint32mf2_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vluxseg4ei32_v_m)))
void vluxseg4ei32_v_u8mf8_m(vuint8mf8_t *, vuint8mf8_t *, vuint8mf8_t *, vuint8mf8_t *, vbool64_t, vuint8mf8_t, vuint8mf8_t, vuint8mf8_t, vuint8mf8_t, const uint8_t *, vuint32mf2_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vluxseg5ei32_v)))
void vluxseg5ei32_v_i8m1(vint8m1_t *, vint8m1_t *, vint8m1_t *, vint8m1_t *, vint8m1_t *, const int8_t *, vuint32m4_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vluxseg5ei32_v_m)))
void vluxseg5ei32_v_i8m1_m(vint8m1_t *, vint8m1_t *, vint8m1_t *, vint8m1_t *, vint8m1_t *, vbool8_t, vint8m1_t, vint8m1_t, vint8m1_t, vint8m1_t, vint8m1_t, const int8_t *, vuint32m4_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vluxseg5ei32_v)))
void vluxseg5ei32_v_i8mf2(vint8mf2_t *, vint8mf2_t *, vint8mf2_t *, vint8mf2_t *, vint8mf2_t *, const int8_t *, vuint32m2_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vluxseg5ei32_v_m)))
void vluxseg5ei32_v_i8mf2_m(vint8mf2_t *, vint8mf2_t *, vint8mf2_t *, vint8mf2_t *, vint8mf2_t *, vbool16_t, vint8mf2_t, vint8mf2_t, vint8mf2_t, vint8mf2_t, vint8mf2_t, const int8_t *, vuint32m2_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vluxseg5ei32_v)))
void vluxseg5ei32_v_i8mf4(vint8mf4_t *, vint8mf4_t *, vint8mf4_t *, vint8mf4_t *, vint8mf4_t *, const int8_t *, vuint32m1_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vluxseg5ei32_v_m)))
void vluxseg5ei32_v_i8mf4_m(vint8mf4_t *, vint8mf4_t *, vint8mf4_t *, vint8mf4_t *, vint8mf4_t *, vbool32_t, vint8mf4_t, vint8mf4_t, vint8mf4_t, vint8mf4_t, vint8mf4_t, const int8_t *, vuint32m1_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vluxseg5ei32_v)))
void vluxseg5ei32_v_i8mf8(vint8mf8_t *, vint8mf8_t *, vint8mf8_t *, vint8mf8_t *, vint8mf8_t *, const int8_t *, vuint32mf2_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vluxseg5ei32_v_m)))
void vluxseg5ei32_v_i8mf8_m(vint8mf8_t *, vint8mf8_t *, vint8mf8_t *, vint8mf8_t *, vint8mf8_t *, vbool64_t, vint8mf8_t, vint8mf8_t, vint8mf8_t, vint8mf8_t, vint8mf8_t, const int8_t *, vuint32mf2_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vluxseg5ei32_v)))
void vluxseg5ei32_v_u8m1(vuint8m1_t *, vuint8m1_t *, vuint8m1_t *, vuint8m1_t *, vuint8m1_t *, const uint8_t *, vuint32m4_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vluxseg5ei32_v_m)))
void vluxseg5ei32_v_u8m1_m(vuint8m1_t *, vuint8m1_t *, vuint8m1_t *, vuint8m1_t *, vuint8m1_t *, vbool8_t, vuint8m1_t, vuint8m1_t, vuint8m1_t, vuint8m1_t, vuint8m1_t, const uint8_t *, vuint32m4_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vluxseg5ei32_v)))
void vluxseg5ei32_v_u8mf2(vuint8mf2_t *, vuint8mf2_t *, vuint8mf2_t *, vuint8mf2_t *, vuint8mf2_t *, const uint8_t *, vuint32m2_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vluxseg5ei32_v_m)))
void vluxseg5ei32_v_u8mf2_m(vuint8mf2_t *, vuint8mf2_t *, vuint8mf2_t *, vuint8mf2_t *, vuint8mf2_t *, vbool16_t, vuint8mf2_t, vuint8mf2_t, vuint8mf2_t, vuint8mf2_t, vuint8mf2_t, const uint8_t *, vuint32m2_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vluxseg5ei32_v)))
void vluxseg5ei32_v_u8mf4(vuint8mf4_t *, vuint8mf4_t *, vuint8mf4_t *, vuint8mf4_t *, vuint8mf4_t *, const uint8_t *, vuint32m1_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vluxseg5ei32_v_m)))
void vluxseg5ei32_v_u8mf4_m(vuint8mf4_t *, vuint8mf4_t *, vuint8mf4_t *, vuint8mf4_t *, vuint8mf4_t *, vbool32_t, vuint8mf4_t, vuint8mf4_t, vuint8mf4_t, vuint8mf4_t, vuint8mf4_t, const uint8_t *, vuint32m1_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vluxseg5ei32_v)))
void vluxseg5ei32_v_u8mf8(vuint8mf8_t *, vuint8mf8_t *, vuint8mf8_t *, vuint8mf8_t *, vuint8mf8_t *, const uint8_t *, vuint32mf2_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vluxseg5ei32_v_m)))
void vluxseg5ei32_v_u8mf8_m(vuint8mf8_t *, vuint8mf8_t *, vuint8mf8_t *, vuint8mf8_t *, vuint8mf8_t *, vbool64_t, vuint8mf8_t, vuint8mf8_t, vuint8mf8_t, vuint8mf8_t, vuint8mf8_t, const uint8_t *, vuint32mf2_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vluxseg6ei32_v)))
void vluxseg6ei32_v_i8m1(vint8m1_t *, vint8m1_t *, vint8m1_t *, vint8m1_t *, vint8m1_t *, vint8m1_t *, const int8_t *, vuint32m4_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vluxseg6ei32_v_m)))
void vluxseg6ei32_v_i8m1_m(vint8m1_t *, vint8m1_t *, vint8m1_t *, vint8m1_t *, vint8m1_t *, vint8m1_t *, vbool8_t, vint8m1_t, vint8m1_t, vint8m1_t, vint8m1_t, vint8m1_t, vint8m1_t, const int8_t *, vuint32m4_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vluxseg6ei32_v)))
void vluxseg6ei32_v_i8mf2(vint8mf2_t *, vint8mf2_t *, vint8mf2_t *, vint8mf2_t *, vint8mf2_t *, vint8mf2_t *, const int8_t *, vuint32m2_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vluxseg6ei32_v_m)))
void vluxseg6ei32_v_i8mf2_m(vint8mf2_t *, vint8mf2_t *, vint8mf2_t *, vint8mf2_t *, vint8mf2_t *, vint8mf2_t *, vbool16_t, vint8mf2_t, vint8mf2_t, vint8mf2_t, vint8mf2_t, vint8mf2_t, vint8mf2_t, const int8_t *, vuint32m2_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vluxseg6ei32_v)))
void vluxseg6ei32_v_i8mf4(vint8mf4_t *, vint8mf4_t *, vint8mf4_t *, vint8mf4_t *, vint8mf4_t *, vint8mf4_t *, const int8_t *, vuint32m1_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vluxseg6ei32_v_m)))
void vluxseg6ei32_v_i8mf4_m(vint8mf4_t *, vint8mf4_t *, vint8mf4_t *, vint8mf4_t *, vint8mf4_t *, vint8mf4_t *, vbool32_t, vint8mf4_t, vint8mf4_t, vint8mf4_t, vint8mf4_t, vint8mf4_t, vint8mf4_t, const int8_t *, vuint32m1_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vluxseg6ei32_v)))
void vluxseg6ei32_v_i8mf8(vint8mf8_t *, vint8mf8_t *, vint8mf8_t *, vint8mf8_t *, vint8mf8_t *, vint8mf8_t *, const int8_t *, vuint32mf2_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vluxseg6ei32_v_m)))
void vluxseg6ei32_v_i8mf8_m(vint8mf8_t *, vint8mf8_t *, vint8mf8_t *, vint8mf8_t *, vint8mf8_t *, vint8mf8_t *, vbool64_t, vint8mf8_t, vint8mf8_t, vint8mf8_t, vint8mf8_t, vint8mf8_t, vint8mf8_t, const int8_t *, vuint32mf2_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vluxseg6ei32_v)))
void vluxseg6ei32_v_u8m1(vuint8m1_t *, vuint8m1_t *, vuint8m1_t *, vuint8m1_t *, vuint8m1_t *, vuint8m1_t *, const uint8_t *, vuint32m4_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vluxseg6ei32_v_m)))
void vluxseg6ei32_v_u8m1_m(vuint8m1_t *, vuint8m1_t *, vuint8m1_t *, vuint8m1_t *, vuint8m1_t *, vuint8m1_t *, vbool8_t, vuint8m1_t, vuint8m1_t, vuint8m1_t, vuint8m1_t, vuint8m1_t, vuint8m1_t, const uint8_t *, vuint32m4_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vluxseg6ei32_v)))
void vluxseg6ei32_v_u8mf2(vuint8mf2_t *, vuint8mf2_t *, vuint8mf2_t *, vuint8mf2_t *, vuint8mf2_t *, vuint8mf2_t *, const uint8_t *, vuint32m2_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vluxseg6ei32_v_m)))
void vluxseg6ei32_v_u8mf2_m(vuint8mf2_t *, vuint8mf2_t *, vuint8mf2_t *, vuint8mf2_t *, vuint8mf2_t *, vuint8mf2_t *, vbool16_t, vuint8mf2_t, vuint8mf2_t, vuint8mf2_t, vuint8mf2_t, vuint8mf2_t, vuint8mf2_t, const uint8_t *, vuint32m2_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vluxseg6ei32_v)))
void vluxseg6ei32_v_u8mf4(vuint8mf4_t *, vuint8mf4_t *, vuint8mf4_t *, vuint8mf4_t *, vuint8mf4_t *, vuint8mf4_t *, const uint8_t *, vuint32m1_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vluxseg6ei32_v_m)))
void vluxseg6ei32_v_u8mf4_m(vuint8mf4_t *, vuint8mf4_t *, vuint8mf4_t *, vuint8mf4_t *, vuint8mf4_t *, vuint8mf4_t *, vbool32_t, vuint8mf4_t, vuint8mf4_t, vuint8mf4_t, vuint8mf4_t, vuint8mf4_t, vuint8mf4_t, const uint8_t *, vuint32m1_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vluxseg6ei32_v)))
void vluxseg6ei32_v_u8mf8(vuint8mf8_t *, vuint8mf8_t *, vuint8mf8_t *, vuint8mf8_t *, vuint8mf8_t *, vuint8mf8_t *, const uint8_t *, vuint32mf2_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vluxseg6ei32_v_m)))
void vluxseg6ei32_v_u8mf8_m(vuint8mf8_t *, vuint8mf8_t *, vuint8mf8_t *, vuint8mf8_t *, vuint8mf8_t *, vuint8mf8_t *, vbool64_t, vuint8mf8_t, vuint8mf8_t, vuint8mf8_t, vuint8mf8_t, vuint8mf8_t, vuint8mf8_t, const uint8_t *, vuint32mf2_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vluxseg7ei32_v)))
void vluxseg7ei32_v_i8m1(vint8m1_t *, vint8m1_t *, vint8m1_t *, vint8m1_t *, vint8m1_t *, vint8m1_t *, vint8m1_t *, const int8_t *, vuint32m4_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vluxseg7ei32_v_m)))
void vluxseg7ei32_v_i8m1_m(vint8m1_t *, vint8m1_t *, vint8m1_t *, vint8m1_t *, vint8m1_t *, vint8m1_t *, vint8m1_t *, vbool8_t, vint8m1_t, vint8m1_t, vint8m1_t, vint8m1_t, vint8m1_t, vint8m1_t, vint8m1_t, const int8_t *, vuint32m4_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vluxseg7ei32_v)))
void vluxseg7ei32_v_i8mf2(vint8mf2_t *, vint8mf2_t *, vint8mf2_t *, vint8mf2_t *, vint8mf2_t *, vint8mf2_t *, vint8mf2_t *, const int8_t *, vuint32m2_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vluxseg7ei32_v_m)))
void vluxseg7ei32_v_i8mf2_m(vint8mf2_t *, vint8mf2_t *, vint8mf2_t *, vint8mf2_t *, vint8mf2_t *, vint8mf2_t *, vint8mf2_t *, vbool16_t, vint8mf2_t, vint8mf2_t, vint8mf2_t, vint8mf2_t, vint8mf2_t, vint8mf2_t, vint8mf2_t, const int8_t *, vuint32m2_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vluxseg7ei32_v)))
void vluxseg7ei32_v_i8mf4(vint8mf4_t *, vint8mf4_t *, vint8mf4_t *, vint8mf4_t *, vint8mf4_t *, vint8mf4_t *, vint8mf4_t *, const int8_t *, vuint32m1_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vluxseg7ei32_v_m)))
void vluxseg7ei32_v_i8mf4_m(vint8mf4_t *, vint8mf4_t *, vint8mf4_t *, vint8mf4_t *, vint8mf4_t *, vint8mf4_t *, vint8mf4_t *, vbool32_t, vint8mf4_t, vint8mf4_t, vint8mf4_t, vint8mf4_t, vint8mf4_t, vint8mf4_t, vint8mf4_t, const int8_t *, vuint32m1_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vluxseg7ei32_v)))
void vluxseg7ei32_v_i8mf8(vint8mf8_t *, vint8mf8_t *, vint8mf8_t *, vint8mf8_t *, vint8mf8_t *, vint8mf8_t *, vint8mf8_t *, const int8_t *, vuint32mf2_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vluxseg7ei32_v_m)))
void vluxseg7ei32_v_i8mf8_m(vint8mf8_t *, vint8mf8_t *, vint8mf8_t *, vint8mf8_t *, vint8mf8_t *, vint8mf8_t *, vint8mf8_t *, vbool64_t, vint8mf8_t, vint8mf8_t, vint8mf8_t, vint8mf8_t, vint8mf8_t, vint8mf8_t, vint8mf8_t, const int8_t *, vuint32mf2_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vluxseg7ei32_v)))
void vluxseg7ei32_v_u8m1(vuint8m1_t *, vuint8m1_t *, vuint8m1_t *, vuint8m1_t *, vuint8m1_t *, vuint8m1_t *, vuint8m1_t *, const uint8_t *, vuint32m4_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vluxseg7ei32_v_m)))
void vluxseg7ei32_v_u8m1_m(vuint8m1_t *, vuint8m1_t *, vuint8m1_t *, vuint8m1_t *, vuint8m1_t *, vuint8m1_t *, vuint8m1_t *, vbool8_t, vuint8m1_t, vuint8m1_t, vuint8m1_t, vuint8m1_t, vuint8m1_t, vuint8m1_t, vuint8m1_t, const uint8_t *, vuint32m4_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vluxseg7ei32_v)))
void vluxseg7ei32_v_u8mf2(vuint8mf2_t *, vuint8mf2_t *, vuint8mf2_t *, vuint8mf2_t *, vuint8mf2_t *, vuint8mf2_t *, vuint8mf2_t *, const uint8_t *, vuint32m2_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vluxseg7ei32_v_m)))
void vluxseg7ei32_v_u8mf2_m(vuint8mf2_t *, vuint8mf2_t *, vuint8mf2_t *, vuint8mf2_t *, vuint8mf2_t *, vuint8mf2_t *, vuint8mf2_t *, vbool16_t, vuint8mf2_t, vuint8mf2_t, vuint8mf2_t, vuint8mf2_t, vuint8mf2_t, vuint8mf2_t, vuint8mf2_t, const uint8_t *, vuint32m2_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vluxseg7ei32_v)))
void vluxseg7ei32_v_u8mf4(vuint8mf4_t *, vuint8mf4_t *, vuint8mf4_t *, vuint8mf4_t *, vuint8mf4_t *, vuint8mf4_t *, vuint8mf4_t *, const uint8_t *, vuint32m1_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vluxseg7ei32_v_m)))
void vluxseg7ei32_v_u8mf4_m(vuint8mf4_t *, vuint8mf4_t *, vuint8mf4_t *, vuint8mf4_t *, vuint8mf4_t *, vuint8mf4_t *, vuint8mf4_t *, vbool32_t, vuint8mf4_t, vuint8mf4_t, vuint8mf4_t, vuint8mf4_t, vuint8mf4_t, vuint8mf4_t, vuint8mf4_t, const uint8_t *, vuint32m1_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vluxseg7ei32_v)))
void vluxseg7ei32_v_u8mf8(vuint8mf8_t *, vuint8mf8_t *, vuint8mf8_t *, vuint8mf8_t *, vuint8mf8_t *, vuint8mf8_t *, vuint8mf8_t *, const uint8_t *, vuint32mf2_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vluxseg7ei32_v_m)))
void vluxseg7ei32_v_u8mf8_m(vuint8mf8_t *, vuint8mf8_t *, vuint8mf8_t *, vuint8mf8_t *, vuint8mf8_t *, vuint8mf8_t *, vuint8mf8_t *, vbool64_t, vuint8mf8_t, vuint8mf8_t, vuint8mf8_t, vuint8mf8_t, vuint8mf8_t, vuint8mf8_t, vuint8mf8_t, const uint8_t *, vuint32mf2_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vluxseg8ei32_v)))
void vluxseg8ei32_v_i8m1(vint8m1_t *, vint8m1_t *, vint8m1_t *, vint8m1_t *, vint8m1_t *, vint8m1_t *, vint8m1_t *, vint8m1_t *, const int8_t *, vuint32m4_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vluxseg8ei32_v_m)))
void vluxseg8ei32_v_i8m1_m(vint8m1_t *, vint8m1_t *, vint8m1_t *, vint8m1_t *, vint8m1_t *, vint8m1_t *, vint8m1_t *, vint8m1_t *, vbool8_t, vint8m1_t, vint8m1_t, vint8m1_t, vint8m1_t, vint8m1_t, vint8m1_t, vint8m1_t, vint8m1_t, const int8_t *, vuint32m4_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vluxseg8ei32_v)))
void vluxseg8ei32_v_i8mf2(vint8mf2_t *, vint8mf2_t *, vint8mf2_t *, vint8mf2_t *, vint8mf2_t *, vint8mf2_t *, vint8mf2_t *, vint8mf2_t *, const int8_t *, vuint32m2_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vluxseg8ei32_v_m)))
void vluxseg8ei32_v_i8mf2_m(vint8mf2_t *, vint8mf2_t *, vint8mf2_t *, vint8mf2_t *, vint8mf2_t *, vint8mf2_t *, vint8mf2_t *, vint8mf2_t *, vbool16_t, vint8mf2_t, vint8mf2_t, vint8mf2_t, vint8mf2_t, vint8mf2_t, vint8mf2_t, vint8mf2_t, vint8mf2_t, const int8_t *, vuint32m2_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vluxseg8ei32_v)))
void vluxseg8ei32_v_i8mf4(vint8mf4_t *, vint8mf4_t *, vint8mf4_t *, vint8mf4_t *, vint8mf4_t *, vint8mf4_t *, vint8mf4_t *, vint8mf4_t *, const int8_t *, vuint32m1_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vluxseg8ei32_v_m)))
void vluxseg8ei32_v_i8mf4_m(vint8mf4_t *, vint8mf4_t *, vint8mf4_t *, vint8mf4_t *, vint8mf4_t *, vint8mf4_t *, vint8mf4_t *, vint8mf4_t *, vbool32_t, vint8mf4_t, vint8mf4_t, vint8mf4_t, vint8mf4_t, vint8mf4_t, vint8mf4_t, vint8mf4_t, vint8mf4_t, const int8_t *, vuint32m1_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vluxseg8ei32_v)))
void vluxseg8ei32_v_i8mf8(vint8mf8_t *, vint8mf8_t *, vint8mf8_t *, vint8mf8_t *, vint8mf8_t *, vint8mf8_t *, vint8mf8_t *, vint8mf8_t *, const int8_t *, vuint32mf2_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vluxseg8ei32_v_m)))
void vluxseg8ei32_v_i8mf8_m(vint8mf8_t *, vint8mf8_t *, vint8mf8_t *, vint8mf8_t *, vint8mf8_t *, vint8mf8_t *, vint8mf8_t *, vint8mf8_t *, vbool64_t, vint8mf8_t, vint8mf8_t, vint8mf8_t, vint8mf8_t, vint8mf8_t, vint8mf8_t, vint8mf8_t, vint8mf8_t, const int8_t *, vuint32mf2_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vluxseg8ei32_v)))
void vluxseg8ei32_v_u8m1(vuint8m1_t *, vuint8m1_t *, vuint8m1_t *, vuint8m1_t *, vuint8m1_t *, vuint8m1_t *, vuint8m1_t *, vuint8m1_t *, const uint8_t *, vuint32m4_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vluxseg8ei32_v_m)))
void vluxseg8ei32_v_u8m1_m(vuint8m1_t *, vuint8m1_t *, vuint8m1_t *, vuint8m1_t *, vuint8m1_t *, vuint8m1_t *, vuint8m1_t *, vuint8m1_t *, vbool8_t, vuint8m1_t, vuint8m1_t, vuint8m1_t, vuint8m1_t, vuint8m1_t, vuint8m1_t, vuint8m1_t, vuint8m1_t, const uint8_t *, vuint32m4_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vluxseg8ei32_v)))
void vluxseg8ei32_v_u8mf2(vuint8mf2_t *, vuint8mf2_t *, vuint8mf2_t *, vuint8mf2_t *, vuint8mf2_t *, vuint8mf2_t *, vuint8mf2_t *, vuint8mf2_t *, const uint8_t *, vuint32m2_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vluxseg8ei32_v_m)))
void vluxseg8ei32_v_u8mf2_m(vuint8mf2_t *, vuint8mf2_t *, vuint8mf2_t *, vuint8mf2_t *, vuint8mf2_t *, vuint8mf2_t *, vuint8mf2_t *, vuint8mf2_t *, vbool16_t, vuint8mf2_t, vuint8mf2_t, vuint8mf2_t, vuint8mf2_t, vuint8mf2_t, vuint8mf2_t, vuint8mf2_t, vuint8mf2_t, const uint8_t *, vuint32m2_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vluxseg8ei32_v)))
void vluxseg8ei32_v_u8mf4(vuint8mf4_t *, vuint8mf4_t *, vuint8mf4_t *, vuint8mf4_t *, vuint8mf4_t *, vuint8mf4_t *, vuint8mf4_t *, vuint8mf4_t *, const uint8_t *, vuint32m1_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vluxseg8ei32_v_m)))
void vluxseg8ei32_v_u8mf4_m(vuint8mf4_t *, vuint8mf4_t *, vuint8mf4_t *, vuint8mf4_t *, vuint8mf4_t *, vuint8mf4_t *, vuint8mf4_t *, vuint8mf4_t *, vbool32_t, vuint8mf4_t, vuint8mf4_t, vuint8mf4_t, vuint8mf4_t, vuint8mf4_t, vuint8mf4_t, vuint8mf4_t, vuint8mf4_t, const uint8_t *, vuint32m1_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vluxseg8ei32_v)))
void vluxseg8ei32_v_u8mf8(vuint8mf8_t *, vuint8mf8_t *, vuint8mf8_t *, vuint8mf8_t *, vuint8mf8_t *, vuint8mf8_t *, vuint8mf8_t *, vuint8mf8_t *, const uint8_t *, vuint32mf2_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vluxseg8ei32_v_m)))
void vluxseg8ei32_v_u8mf8_m(vuint8mf8_t *, vuint8mf8_t *, vuint8mf8_t *, vuint8mf8_t *, vuint8mf8_t *, vuint8mf8_t *, vuint8mf8_t *, vuint8mf8_t *, vbool64_t, vuint8mf8_t, vuint8mf8_t, vuint8mf8_t, vuint8mf8_t, vuint8mf8_t, vuint8mf8_t, vuint8mf8_t, vuint8mf8_t, const uint8_t *, vuint32mf2_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vluxseg2ei8_v)))
void vluxseg2ei8_v_i16m1(vint16m1_t *, vint16m1_t *, const int16_t *, vuint8mf2_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vluxseg2ei8_v_m)))
void vluxseg2ei8_v_i16m1_m(vint16m1_t *, vint16m1_t *, vbool16_t, vint16m1_t, vint16m1_t, const int16_t *, vuint8mf2_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vluxseg2ei8_v)))
void vluxseg2ei8_v_i16m2(vint16m2_t *, vint16m2_t *, const int16_t *, vuint8m1_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vluxseg2ei8_v_m)))
void vluxseg2ei8_v_i16m2_m(vint16m2_t *, vint16m2_t *, vbool8_t, vint16m2_t, vint16m2_t, const int16_t *, vuint8m1_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vluxseg2ei8_v)))
void vluxseg2ei8_v_i16m4(vint16m4_t *, vint16m4_t *, const int16_t *, vuint8m2_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vluxseg2ei8_v_m)))
void vluxseg2ei8_v_i16m4_m(vint16m4_t *, vint16m4_t *, vbool4_t, vint16m4_t, vint16m4_t, const int16_t *, vuint8m2_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vluxseg2ei8_v)))
void vluxseg2ei8_v_i16mf2(vint16mf2_t *, vint16mf2_t *, const int16_t *, vuint8mf4_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vluxseg2ei8_v_m)))
void vluxseg2ei8_v_i16mf2_m(vint16mf2_t *, vint16mf2_t *, vbool32_t, vint16mf2_t, vint16mf2_t, const int16_t *, vuint8mf4_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vluxseg2ei8_v)))
void vluxseg2ei8_v_i16mf4(vint16mf4_t *, vint16mf4_t *, const int16_t *, vuint8mf8_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vluxseg2ei8_v_m)))
void vluxseg2ei8_v_i16mf4_m(vint16mf4_t *, vint16mf4_t *, vbool64_t, vint16mf4_t, vint16mf4_t, const int16_t *, vuint8mf8_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vluxseg2ei8_v)))
void vluxseg2ei8_v_u16m1(vuint16m1_t *, vuint16m1_t *, const uint16_t *, vuint8mf2_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vluxseg2ei8_v_m)))
void vluxseg2ei8_v_u16m1_m(vuint16m1_t *, vuint16m1_t *, vbool16_t, vuint16m1_t, vuint16m1_t, const uint16_t *, vuint8mf2_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vluxseg2ei8_v)))
void vluxseg2ei8_v_u16m2(vuint16m2_t *, vuint16m2_t *, const uint16_t *, vuint8m1_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vluxseg2ei8_v_m)))
void vluxseg2ei8_v_u16m2_m(vuint16m2_t *, vuint16m2_t *, vbool8_t, vuint16m2_t, vuint16m2_t, const uint16_t *, vuint8m1_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vluxseg2ei8_v)))
void vluxseg2ei8_v_u16m4(vuint16m4_t *, vuint16m4_t *, const uint16_t *, vuint8m2_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vluxseg2ei8_v_m)))
void vluxseg2ei8_v_u16m4_m(vuint16m4_t *, vuint16m4_t *, vbool4_t, vuint16m4_t, vuint16m4_t, const uint16_t *, vuint8m2_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vluxseg2ei8_v)))
void vluxseg2ei8_v_u16mf2(vuint16mf2_t *, vuint16mf2_t *, const uint16_t *, vuint8mf4_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vluxseg2ei8_v_m)))
void vluxseg2ei8_v_u16mf2_m(vuint16mf2_t *, vuint16mf2_t *, vbool32_t, vuint16mf2_t, vuint16mf2_t, const uint16_t *, vuint8mf4_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vluxseg2ei8_v)))
void vluxseg2ei8_v_u16mf4(vuint16mf4_t *, vuint16mf4_t *, const uint16_t *, vuint8mf8_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vluxseg2ei8_v_m)))
void vluxseg2ei8_v_u16mf4_m(vuint16mf4_t *, vuint16mf4_t *, vbool64_t, vuint16mf4_t, vuint16mf4_t, const uint16_t *, vuint8mf8_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vluxseg3ei8_v)))
void vluxseg3ei8_v_i16m1(vint16m1_t *, vint16m1_t *, vint16m1_t *, const int16_t *, vuint8mf2_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vluxseg3ei8_v_m)))
void vluxseg3ei8_v_i16m1_m(vint16m1_t *, vint16m1_t *, vint16m1_t *, vbool16_t, vint16m1_t, vint16m1_t, vint16m1_t, const int16_t *, vuint8mf2_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vluxseg3ei8_v)))
void vluxseg3ei8_v_i16m2(vint16m2_t *, vint16m2_t *, vint16m2_t *, const int16_t *, vuint8m1_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vluxseg3ei8_v_m)))
void vluxseg3ei8_v_i16m2_m(vint16m2_t *, vint16m2_t *, vint16m2_t *, vbool8_t, vint16m2_t, vint16m2_t, vint16m2_t, const int16_t *, vuint8m1_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vluxseg3ei8_v)))
void vluxseg3ei8_v_i16mf2(vint16mf2_t *, vint16mf2_t *, vint16mf2_t *, const int16_t *, vuint8mf4_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vluxseg3ei8_v_m)))
void vluxseg3ei8_v_i16mf2_m(vint16mf2_t *, vint16mf2_t *, vint16mf2_t *, vbool32_t, vint16mf2_t, vint16mf2_t, vint16mf2_t, const int16_t *, vuint8mf4_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vluxseg3ei8_v)))
void vluxseg3ei8_v_i16mf4(vint16mf4_t *, vint16mf4_t *, vint16mf4_t *, const int16_t *, vuint8mf8_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vluxseg3ei8_v_m)))
void vluxseg3ei8_v_i16mf4_m(vint16mf4_t *, vint16mf4_t *, vint16mf4_t *, vbool64_t, vint16mf4_t, vint16mf4_t, vint16mf4_t, const int16_t *, vuint8mf8_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vluxseg3ei8_v)))
void vluxseg3ei8_v_u16m1(vuint16m1_t *, vuint16m1_t *, vuint16m1_t *, const uint16_t *, vuint8mf2_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vluxseg3ei8_v_m)))
void vluxseg3ei8_v_u16m1_m(vuint16m1_t *, vuint16m1_t *, vuint16m1_t *, vbool16_t, vuint16m1_t, vuint16m1_t, vuint16m1_t, const uint16_t *, vuint8mf2_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vluxseg3ei8_v)))
void vluxseg3ei8_v_u16m2(vuint16m2_t *, vuint16m2_t *, vuint16m2_t *, const uint16_t *, vuint8m1_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vluxseg3ei8_v_m)))
void vluxseg3ei8_v_u16m2_m(vuint16m2_t *, vuint16m2_t *, vuint16m2_t *, vbool8_t, vuint16m2_t, vuint16m2_t, vuint16m2_t, const uint16_t *, vuint8m1_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vluxseg3ei8_v)))
void vluxseg3ei8_v_u16mf2(vuint16mf2_t *, vuint16mf2_t *, vuint16mf2_t *, const uint16_t *, vuint8mf4_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vluxseg3ei8_v_m)))
void vluxseg3ei8_v_u16mf2_m(vuint16mf2_t *, vuint16mf2_t *, vuint16mf2_t *, vbool32_t, vuint16mf2_t, vuint16mf2_t, vuint16mf2_t, const uint16_t *, vuint8mf4_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vluxseg3ei8_v)))
void vluxseg3ei8_v_u16mf4(vuint16mf4_t *, vuint16mf4_t *, vuint16mf4_t *, const uint16_t *, vuint8mf8_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vluxseg3ei8_v_m)))
void vluxseg3ei8_v_u16mf4_m(vuint16mf4_t *, vuint16mf4_t *, vuint16mf4_t *, vbool64_t, vuint16mf4_t, vuint16mf4_t, vuint16mf4_t, const uint16_t *, vuint8mf8_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vluxseg4ei8_v)))
void vluxseg4ei8_v_i16m1(vint16m1_t *, vint16m1_t *, vint16m1_t *, vint16m1_t *, const int16_t *, vuint8mf2_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vluxseg4ei8_v_m)))
void vluxseg4ei8_v_i16m1_m(vint16m1_t *, vint16m1_t *, vint16m1_t *, vint16m1_t *, vbool16_t, vint16m1_t, vint16m1_t, vint16m1_t, vint16m1_t, const int16_t *, vuint8mf2_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vluxseg4ei8_v)))
void vluxseg4ei8_v_i16m2(vint16m2_t *, vint16m2_t *, vint16m2_t *, vint16m2_t *, const int16_t *, vuint8m1_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vluxseg4ei8_v_m)))
void vluxseg4ei8_v_i16m2_m(vint16m2_t *, vint16m2_t *, vint16m2_t *, vint16m2_t *, vbool8_t, vint16m2_t, vint16m2_t, vint16m2_t, vint16m2_t, const int16_t *, vuint8m1_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vluxseg4ei8_v)))
void vluxseg4ei8_v_i16mf2(vint16mf2_t *, vint16mf2_t *, vint16mf2_t *, vint16mf2_t *, const int16_t *, vuint8mf4_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vluxseg4ei8_v_m)))
void vluxseg4ei8_v_i16mf2_m(vint16mf2_t *, vint16mf2_t *, vint16mf2_t *, vint16mf2_t *, vbool32_t, vint16mf2_t, vint16mf2_t, vint16mf2_t, vint16mf2_t, const int16_t *, vuint8mf4_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vluxseg4ei8_v)))
void vluxseg4ei8_v_i16mf4(vint16mf4_t *, vint16mf4_t *, vint16mf4_t *, vint16mf4_t *, const int16_t *, vuint8mf8_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vluxseg4ei8_v_m)))
void vluxseg4ei8_v_i16mf4_m(vint16mf4_t *, vint16mf4_t *, vint16mf4_t *, vint16mf4_t *, vbool64_t, vint16mf4_t, vint16mf4_t, vint16mf4_t, vint16mf4_t, const int16_t *, vuint8mf8_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vluxseg4ei8_v)))
void vluxseg4ei8_v_u16m1(vuint16m1_t *, vuint16m1_t *, vuint16m1_t *, vuint16m1_t *, const uint16_t *, vuint8mf2_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vluxseg4ei8_v_m)))
void vluxseg4ei8_v_u16m1_m(vuint16m1_t *, vuint16m1_t *, vuint16m1_t *, vuint16m1_t *, vbool16_t, vuint16m1_t, vuint16m1_t, vuint16m1_t, vuint16m1_t, const uint16_t *, vuint8mf2_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vluxseg4ei8_v)))
void vluxseg4ei8_v_u16m2(vuint16m2_t *, vuint16m2_t *, vuint16m2_t *, vuint16m2_t *, const uint16_t *, vuint8m1_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vluxseg4ei8_v_m)))
void vluxseg4ei8_v_u16m2_m(vuint16m2_t *, vuint16m2_t *, vuint16m2_t *, vuint16m2_t *, vbool8_t, vuint16m2_t, vuint16m2_t, vuint16m2_t, vuint16m2_t, const uint16_t *, vuint8m1_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vluxseg4ei8_v)))
void vluxseg4ei8_v_u16mf2(vuint16mf2_t *, vuint16mf2_t *, vuint16mf2_t *, vuint16mf2_t *, const uint16_t *, vuint8mf4_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vluxseg4ei8_v_m)))
void vluxseg4ei8_v_u16mf2_m(vuint16mf2_t *, vuint16mf2_t *, vuint16mf2_t *, vuint16mf2_t *, vbool32_t, vuint16mf2_t, vuint16mf2_t, vuint16mf2_t, vuint16mf2_t, const uint16_t *, vuint8mf4_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vluxseg4ei8_v)))
void vluxseg4ei8_v_u16mf4(vuint16mf4_t *, vuint16mf4_t *, vuint16mf4_t *, vuint16mf4_t *, const uint16_t *, vuint8mf8_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vluxseg4ei8_v_m)))
void vluxseg4ei8_v_u16mf4_m(vuint16mf4_t *, vuint16mf4_t *, vuint16mf4_t *, vuint16mf4_t *, vbool64_t, vuint16mf4_t, vuint16mf4_t, vuint16mf4_t, vuint16mf4_t, const uint16_t *, vuint8mf8_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vluxseg5ei8_v)))
void vluxseg5ei8_v_i16m1(vint16m1_t *, vint16m1_t *, vint16m1_t *, vint16m1_t *, vint16m1_t *, const int16_t *, vuint8mf2_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vluxseg5ei8_v_m)))
void vluxseg5ei8_v_i16m1_m(vint16m1_t *, vint16m1_t *, vint16m1_t *, vint16m1_t *, vint16m1_t *, vbool16_t, vint16m1_t, vint16m1_t, vint16m1_t, vint16m1_t, vint16m1_t, const int16_t *, vuint8mf2_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vluxseg5ei8_v)))
void vluxseg5ei8_v_i16mf2(vint16mf2_t *, vint16mf2_t *, vint16mf2_t *, vint16mf2_t *, vint16mf2_t *, const int16_t *, vuint8mf4_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vluxseg5ei8_v_m)))
void vluxseg5ei8_v_i16mf2_m(vint16mf2_t *, vint16mf2_t *, vint16mf2_t *, vint16mf2_t *, vint16mf2_t *, vbool32_t, vint16mf2_t, vint16mf2_t, vint16mf2_t, vint16mf2_t, vint16mf2_t, const int16_t *, vuint8mf4_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vluxseg5ei8_v)))
void vluxseg5ei8_v_i16mf4(vint16mf4_t *, vint16mf4_t *, vint16mf4_t *, vint16mf4_t *, vint16mf4_t *, const int16_t *, vuint8mf8_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vluxseg5ei8_v_m)))
void vluxseg5ei8_v_i16mf4_m(vint16mf4_t *, vint16mf4_t *, vint16mf4_t *, vint16mf4_t *, vint16mf4_t *, vbool64_t, vint16mf4_t, vint16mf4_t, vint16mf4_t, vint16mf4_t, vint16mf4_t, const int16_t *, vuint8mf8_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vluxseg5ei8_v)))
void vluxseg5ei8_v_u16m1(vuint16m1_t *, vuint16m1_t *, vuint16m1_t *, vuint16m1_t *, vuint16m1_t *, const uint16_t *, vuint8mf2_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vluxseg5ei8_v_m)))
void vluxseg5ei8_v_u16m1_m(vuint16m1_t *, vuint16m1_t *, vuint16m1_t *, vuint16m1_t *, vuint16m1_t *, vbool16_t, vuint16m1_t, vuint16m1_t, vuint16m1_t, vuint16m1_t, vuint16m1_t, const uint16_t *, vuint8mf2_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vluxseg5ei8_v)))
void vluxseg5ei8_v_u16mf2(vuint16mf2_t *, vuint16mf2_t *, vuint16mf2_t *, vuint16mf2_t *, vuint16mf2_t *, const uint16_t *, vuint8mf4_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vluxseg5ei8_v_m)))
void vluxseg5ei8_v_u16mf2_m(vuint16mf2_t *, vuint16mf2_t *, vuint16mf2_t *, vuint16mf2_t *, vuint16mf2_t *, vbool32_t, vuint16mf2_t, vuint16mf2_t, vuint16mf2_t, vuint16mf2_t, vuint16mf2_t, const uint16_t *, vuint8mf4_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vluxseg5ei8_v)))
void vluxseg5ei8_v_u16mf4(vuint16mf4_t *, vuint16mf4_t *, vuint16mf4_t *, vuint16mf4_t *, vuint16mf4_t *, const uint16_t *, vuint8mf8_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vluxseg5ei8_v_m)))
void vluxseg5ei8_v_u16mf4_m(vuint16mf4_t *, vuint16mf4_t *, vuint16mf4_t *, vuint16mf4_t *, vuint16mf4_t *, vbool64_t, vuint16mf4_t, vuint16mf4_t, vuint16mf4_t, vuint16mf4_t, vuint16mf4_t, const uint16_t *, vuint8mf8_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vluxseg6ei8_v)))
void vluxseg6ei8_v_i16m1(vint16m1_t *, vint16m1_t *, vint16m1_t *, vint16m1_t *, vint16m1_t *, vint16m1_t *, const int16_t *, vuint8mf2_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vluxseg6ei8_v_m)))
void vluxseg6ei8_v_i16m1_m(vint16m1_t *, vint16m1_t *, vint16m1_t *, vint16m1_t *, vint16m1_t *, vint16m1_t *, vbool16_t, vint16m1_t, vint16m1_t, vint16m1_t, vint16m1_t, vint16m1_t, vint16m1_t, const int16_t *, vuint8mf2_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vluxseg6ei8_v)))
void vluxseg6ei8_v_i16mf2(vint16mf2_t *, vint16mf2_t *, vint16mf2_t *, vint16mf2_t *, vint16mf2_t *, vint16mf2_t *, const int16_t *, vuint8mf4_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vluxseg6ei8_v_m)))
void vluxseg6ei8_v_i16mf2_m(vint16mf2_t *, vint16mf2_t *, vint16mf2_t *, vint16mf2_t *, vint16mf2_t *, vint16mf2_t *, vbool32_t, vint16mf2_t, vint16mf2_t, vint16mf2_t, vint16mf2_t, vint16mf2_t, vint16mf2_t, const int16_t *, vuint8mf4_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vluxseg6ei8_v)))
void vluxseg6ei8_v_i16mf4(vint16mf4_t *, vint16mf4_t *, vint16mf4_t *, vint16mf4_t *, vint16mf4_t *, vint16mf4_t *, const int16_t *, vuint8mf8_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vluxseg6ei8_v_m)))
void vluxseg6ei8_v_i16mf4_m(vint16mf4_t *, vint16mf4_t *, vint16mf4_t *, vint16mf4_t *, vint16mf4_t *, vint16mf4_t *, vbool64_t, vint16mf4_t, vint16mf4_t, vint16mf4_t, vint16mf4_t, vint16mf4_t, vint16mf4_t, const int16_t *, vuint8mf8_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vluxseg6ei8_v)))
void vluxseg6ei8_v_u16m1(vuint16m1_t *, vuint16m1_t *, vuint16m1_t *, vuint16m1_t *, vuint16m1_t *, vuint16m1_t *, const uint16_t *, vuint8mf2_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vluxseg6ei8_v_m)))
void vluxseg6ei8_v_u16m1_m(vuint16m1_t *, vuint16m1_t *, vuint16m1_t *, vuint16m1_t *, vuint16m1_t *, vuint16m1_t *, vbool16_t, vuint16m1_t, vuint16m1_t, vuint16m1_t, vuint16m1_t, vuint16m1_t, vuint16m1_t, const uint16_t *, vuint8mf2_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vluxseg6ei8_v)))
void vluxseg6ei8_v_u16mf2(vuint16mf2_t *, vuint16mf2_t *, vuint16mf2_t *, vuint16mf2_t *, vuint16mf2_t *, vuint16mf2_t *, const uint16_t *, vuint8mf4_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vluxseg6ei8_v_m)))
void vluxseg6ei8_v_u16mf2_m(vuint16mf2_t *, vuint16mf2_t *, vuint16mf2_t *, vuint16mf2_t *, vuint16mf2_t *, vuint16mf2_t *, vbool32_t, vuint16mf2_t, vuint16mf2_t, vuint16mf2_t, vuint16mf2_t, vuint16mf2_t, vuint16mf2_t, const uint16_t *, vuint8mf4_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vluxseg6ei8_v)))
void vluxseg6ei8_v_u16mf4(vuint16mf4_t *, vuint16mf4_t *, vuint16mf4_t *, vuint16mf4_t *, vuint16mf4_t *, vuint16mf4_t *, const uint16_t *, vuint8mf8_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vluxseg6ei8_v_m)))
void vluxseg6ei8_v_u16mf4_m(vuint16mf4_t *, vuint16mf4_t *, vuint16mf4_t *, vuint16mf4_t *, vuint16mf4_t *, vuint16mf4_t *, vbool64_t, vuint16mf4_t, vuint16mf4_t, vuint16mf4_t, vuint16mf4_t, vuint16mf4_t, vuint16mf4_t, const uint16_t *, vuint8mf8_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vluxseg7ei8_v)))
void vluxseg7ei8_v_i16m1(vint16m1_t *, vint16m1_t *, vint16m1_t *, vint16m1_t *, vint16m1_t *, vint16m1_t *, vint16m1_t *, const int16_t *, vuint8mf2_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vluxseg7ei8_v_m)))
void vluxseg7ei8_v_i16m1_m(vint16m1_t *, vint16m1_t *, vint16m1_t *, vint16m1_t *, vint16m1_t *, vint16m1_t *, vint16m1_t *, vbool16_t, vint16m1_t, vint16m1_t, vint16m1_t, vint16m1_t, vint16m1_t, vint16m1_t, vint16m1_t, const int16_t *, vuint8mf2_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vluxseg7ei8_v)))
void vluxseg7ei8_v_i16mf2(vint16mf2_t *, vint16mf2_t *, vint16mf2_t *, vint16mf2_t *, vint16mf2_t *, vint16mf2_t *, vint16mf2_t *, const int16_t *, vuint8mf4_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vluxseg7ei8_v_m)))
void vluxseg7ei8_v_i16mf2_m(vint16mf2_t *, vint16mf2_t *, vint16mf2_t *, vint16mf2_t *, vint16mf2_t *, vint16mf2_t *, vint16mf2_t *, vbool32_t, vint16mf2_t, vint16mf2_t, vint16mf2_t, vint16mf2_t, vint16mf2_t, vint16mf2_t, vint16mf2_t, const int16_t *, vuint8mf4_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vluxseg7ei8_v)))
void vluxseg7ei8_v_i16mf4(vint16mf4_t *, vint16mf4_t *, vint16mf4_t *, vint16mf4_t *, vint16mf4_t *, vint16mf4_t *, vint16mf4_t *, const int16_t *, vuint8mf8_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vluxseg7ei8_v_m)))
void vluxseg7ei8_v_i16mf4_m(vint16mf4_t *, vint16mf4_t *, vint16mf4_t *, vint16mf4_t *, vint16mf4_t *, vint16mf4_t *, vint16mf4_t *, vbool64_t, vint16mf4_t, vint16mf4_t, vint16mf4_t, vint16mf4_t, vint16mf4_t, vint16mf4_t, vint16mf4_t, const int16_t *, vuint8mf8_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vluxseg7ei8_v)))
void vluxseg7ei8_v_u16m1(vuint16m1_t *, vuint16m1_t *, vuint16m1_t *, vuint16m1_t *, vuint16m1_t *, vuint16m1_t *, vuint16m1_t *, const uint16_t *, vuint8mf2_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vluxseg7ei8_v_m)))
void vluxseg7ei8_v_u16m1_m(vuint16m1_t *, vuint16m1_t *, vuint16m1_t *, vuint16m1_t *, vuint16m1_t *, vuint16m1_t *, vuint16m1_t *, vbool16_t, vuint16m1_t, vuint16m1_t, vuint16m1_t, vuint16m1_t, vuint16m1_t, vuint16m1_t, vuint16m1_t, const uint16_t *, vuint8mf2_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vluxseg7ei8_v)))
void vluxseg7ei8_v_u16mf2(vuint16mf2_t *, vuint16mf2_t *, vuint16mf2_t *, vuint16mf2_t *, vuint16mf2_t *, vuint16mf2_t *, vuint16mf2_t *, const uint16_t *, vuint8mf4_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vluxseg7ei8_v_m)))
void vluxseg7ei8_v_u16mf2_m(vuint16mf2_t *, vuint16mf2_t *, vuint16mf2_t *, vuint16mf2_t *, vuint16mf2_t *, vuint16mf2_t *, vuint16mf2_t *, vbool32_t, vuint16mf2_t, vuint16mf2_t, vuint16mf2_t, vuint16mf2_t, vuint16mf2_t, vuint16mf2_t, vuint16mf2_t, const uint16_t *, vuint8mf4_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vluxseg7ei8_v)))
void vluxseg7ei8_v_u16mf4(vuint16mf4_t *, vuint16mf4_t *, vuint16mf4_t *, vuint16mf4_t *, vuint16mf4_t *, vuint16mf4_t *, vuint16mf4_t *, const uint16_t *, vuint8mf8_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vluxseg7ei8_v_m)))
void vluxseg7ei8_v_u16mf4_m(vuint16mf4_t *, vuint16mf4_t *, vuint16mf4_t *, vuint16mf4_t *, vuint16mf4_t *, vuint16mf4_t *, vuint16mf4_t *, vbool64_t, vuint16mf4_t, vuint16mf4_t, vuint16mf4_t, vuint16mf4_t, vuint16mf4_t, vuint16mf4_t, vuint16mf4_t, const uint16_t *, vuint8mf8_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vluxseg8ei8_v)))
void vluxseg8ei8_v_i16m1(vint16m1_t *, vint16m1_t *, vint16m1_t *, vint16m1_t *, vint16m1_t *, vint16m1_t *, vint16m1_t *, vint16m1_t *, const int16_t *, vuint8mf2_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vluxseg8ei8_v_m)))
void vluxseg8ei8_v_i16m1_m(vint16m1_t *, vint16m1_t *, vint16m1_t *, vint16m1_t *, vint16m1_t *, vint16m1_t *, vint16m1_t *, vint16m1_t *, vbool16_t, vint16m1_t, vint16m1_t, vint16m1_t, vint16m1_t, vint16m1_t, vint16m1_t, vint16m1_t, vint16m1_t, const int16_t *, vuint8mf2_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vluxseg8ei8_v)))
void vluxseg8ei8_v_i16mf2(vint16mf2_t *, vint16mf2_t *, vint16mf2_t *, vint16mf2_t *, vint16mf2_t *, vint16mf2_t *, vint16mf2_t *, vint16mf2_t *, const int16_t *, vuint8mf4_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vluxseg8ei8_v_m)))
void vluxseg8ei8_v_i16mf2_m(vint16mf2_t *, vint16mf2_t *, vint16mf2_t *, vint16mf2_t *, vint16mf2_t *, vint16mf2_t *, vint16mf2_t *, vint16mf2_t *, vbool32_t, vint16mf2_t, vint16mf2_t, vint16mf2_t, vint16mf2_t, vint16mf2_t, vint16mf2_t, vint16mf2_t, vint16mf2_t, const int16_t *, vuint8mf4_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vluxseg8ei8_v)))
void vluxseg8ei8_v_i16mf4(vint16mf4_t *, vint16mf4_t *, vint16mf4_t *, vint16mf4_t *, vint16mf4_t *, vint16mf4_t *, vint16mf4_t *, vint16mf4_t *, const int16_t *, vuint8mf8_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vluxseg8ei8_v_m)))
void vluxseg8ei8_v_i16mf4_m(vint16mf4_t *, vint16mf4_t *, vint16mf4_t *, vint16mf4_t *, vint16mf4_t *, vint16mf4_t *, vint16mf4_t *, vint16mf4_t *, vbool64_t, vint16mf4_t, vint16mf4_t, vint16mf4_t, vint16mf4_t, vint16mf4_t, vint16mf4_t, vint16mf4_t, vint16mf4_t, const int16_t *, vuint8mf8_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vluxseg8ei8_v)))
void vluxseg8ei8_v_u16m1(vuint16m1_t *, vuint16m1_t *, vuint16m1_t *, vuint16m1_t *, vuint16m1_t *, vuint16m1_t *, vuint16m1_t *, vuint16m1_t *, const uint16_t *, vuint8mf2_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vluxseg8ei8_v_m)))
void vluxseg8ei8_v_u16m1_m(vuint16m1_t *, vuint16m1_t *, vuint16m1_t *, vuint16m1_t *, vuint16m1_t *, vuint16m1_t *, vuint16m1_t *, vuint16m1_t *, vbool16_t, vuint16m1_t, vuint16m1_t, vuint16m1_t, vuint16m1_t, vuint16m1_t, vuint16m1_t, vuint16m1_t, vuint16m1_t, const uint16_t *, vuint8mf2_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vluxseg8ei8_v)))
void vluxseg8ei8_v_u16mf2(vuint16mf2_t *, vuint16mf2_t *, vuint16mf2_t *, vuint16mf2_t *, vuint16mf2_t *, vuint16mf2_t *, vuint16mf2_t *, vuint16mf2_t *, const uint16_t *, vuint8mf4_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vluxseg8ei8_v_m)))
void vluxseg8ei8_v_u16mf2_m(vuint16mf2_t *, vuint16mf2_t *, vuint16mf2_t *, vuint16mf2_t *, vuint16mf2_t *, vuint16mf2_t *, vuint16mf2_t *, vuint16mf2_t *, vbool32_t, vuint16mf2_t, vuint16mf2_t, vuint16mf2_t, vuint16mf2_t, vuint16mf2_t, vuint16mf2_t, vuint16mf2_t, vuint16mf2_t, const uint16_t *, vuint8mf4_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vluxseg8ei8_v)))
void vluxseg8ei8_v_u16mf4(vuint16mf4_t *, vuint16mf4_t *, vuint16mf4_t *, vuint16mf4_t *, vuint16mf4_t *, vuint16mf4_t *, vuint16mf4_t *, vuint16mf4_t *, const uint16_t *, vuint8mf8_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vluxseg8ei8_v_m)))
void vluxseg8ei8_v_u16mf4_m(vuint16mf4_t *, vuint16mf4_t *, vuint16mf4_t *, vuint16mf4_t *, vuint16mf4_t *, vuint16mf4_t *, vuint16mf4_t *, vuint16mf4_t *, vbool64_t, vuint16mf4_t, vuint16mf4_t, vuint16mf4_t, vuint16mf4_t, vuint16mf4_t, vuint16mf4_t, vuint16mf4_t, vuint16mf4_t, const uint16_t *, vuint8mf8_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vluxseg2ei16_v)))
void vluxseg2ei16_v_i16m1(vint16m1_t *, vint16m1_t *, const int16_t *, vuint16m1_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vluxseg2ei16_v_m)))
void vluxseg2ei16_v_i16m1_m(vint16m1_t *, vint16m1_t *, vbool16_t, vint16m1_t, vint16m1_t, const int16_t *, vuint16m1_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vluxseg2ei16_v)))
void vluxseg2ei16_v_i16m2(vint16m2_t *, vint16m2_t *, const int16_t *, vuint16m2_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vluxseg2ei16_v_m)))
void vluxseg2ei16_v_i16m2_m(vint16m2_t *, vint16m2_t *, vbool8_t, vint16m2_t, vint16m2_t, const int16_t *, vuint16m2_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vluxseg2ei16_v)))
void vluxseg2ei16_v_i16m4(vint16m4_t *, vint16m4_t *, const int16_t *, vuint16m4_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vluxseg2ei16_v_m)))
void vluxseg2ei16_v_i16m4_m(vint16m4_t *, vint16m4_t *, vbool4_t, vint16m4_t, vint16m4_t, const int16_t *, vuint16m4_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vluxseg2ei16_v)))
void vluxseg2ei16_v_i16mf2(vint16mf2_t *, vint16mf2_t *, const int16_t *, vuint16mf2_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vluxseg2ei16_v_m)))
void vluxseg2ei16_v_i16mf2_m(vint16mf2_t *, vint16mf2_t *, vbool32_t, vint16mf2_t, vint16mf2_t, const int16_t *, vuint16mf2_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vluxseg2ei16_v)))
void vluxseg2ei16_v_i16mf4(vint16mf4_t *, vint16mf4_t *, const int16_t *, vuint16mf4_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vluxseg2ei16_v_m)))
void vluxseg2ei16_v_i16mf4_m(vint16mf4_t *, vint16mf4_t *, vbool64_t, vint16mf4_t, vint16mf4_t, const int16_t *, vuint16mf4_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vluxseg2ei16_v)))
void vluxseg2ei16_v_u16m1(vuint16m1_t *, vuint16m1_t *, const uint16_t *, vuint16m1_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vluxseg2ei16_v_m)))
void vluxseg2ei16_v_u16m1_m(vuint16m1_t *, vuint16m1_t *, vbool16_t, vuint16m1_t, vuint16m1_t, const uint16_t *, vuint16m1_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vluxseg2ei16_v)))
void vluxseg2ei16_v_u16m2(vuint16m2_t *, vuint16m2_t *, const uint16_t *, vuint16m2_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vluxseg2ei16_v_m)))
void vluxseg2ei16_v_u16m2_m(vuint16m2_t *, vuint16m2_t *, vbool8_t, vuint16m2_t, vuint16m2_t, const uint16_t *, vuint16m2_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vluxseg2ei16_v)))
void vluxseg2ei16_v_u16m4(vuint16m4_t *, vuint16m4_t *, const uint16_t *, vuint16m4_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vluxseg2ei16_v_m)))
void vluxseg2ei16_v_u16m4_m(vuint16m4_t *, vuint16m4_t *, vbool4_t, vuint16m4_t, vuint16m4_t, const uint16_t *, vuint16m4_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vluxseg2ei16_v)))
void vluxseg2ei16_v_u16mf2(vuint16mf2_t *, vuint16mf2_t *, const uint16_t *, vuint16mf2_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vluxseg2ei16_v_m)))
void vluxseg2ei16_v_u16mf2_m(vuint16mf2_t *, vuint16mf2_t *, vbool32_t, vuint16mf2_t, vuint16mf2_t, const uint16_t *, vuint16mf2_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vluxseg2ei16_v)))
void vluxseg2ei16_v_u16mf4(vuint16mf4_t *, vuint16mf4_t *, const uint16_t *, vuint16mf4_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vluxseg2ei16_v_m)))
void vluxseg2ei16_v_u16mf4_m(vuint16mf4_t *, vuint16mf4_t *, vbool64_t, vuint16mf4_t, vuint16mf4_t, const uint16_t *, vuint16mf4_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vluxseg3ei16_v)))
void vluxseg3ei16_v_i16m1(vint16m1_t *, vint16m1_t *, vint16m1_t *, const int16_t *, vuint16m1_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vluxseg3ei16_v_m)))
void vluxseg3ei16_v_i16m1_m(vint16m1_t *, vint16m1_t *, vint16m1_t *, vbool16_t, vint16m1_t, vint16m1_t, vint16m1_t, const int16_t *, vuint16m1_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vluxseg3ei16_v)))
void vluxseg3ei16_v_i16m2(vint16m2_t *, vint16m2_t *, vint16m2_t *, const int16_t *, vuint16m2_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vluxseg3ei16_v_m)))
void vluxseg3ei16_v_i16m2_m(vint16m2_t *, vint16m2_t *, vint16m2_t *, vbool8_t, vint16m2_t, vint16m2_t, vint16m2_t, const int16_t *, vuint16m2_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vluxseg3ei16_v)))
void vluxseg3ei16_v_i16mf2(vint16mf2_t *, vint16mf2_t *, vint16mf2_t *, const int16_t *, vuint16mf2_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vluxseg3ei16_v_m)))
void vluxseg3ei16_v_i16mf2_m(vint16mf2_t *, vint16mf2_t *, vint16mf2_t *, vbool32_t, vint16mf2_t, vint16mf2_t, vint16mf2_t, const int16_t *, vuint16mf2_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vluxseg3ei16_v)))
void vluxseg3ei16_v_i16mf4(vint16mf4_t *, vint16mf4_t *, vint16mf4_t *, const int16_t *, vuint16mf4_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vluxseg3ei16_v_m)))
void vluxseg3ei16_v_i16mf4_m(vint16mf4_t *, vint16mf4_t *, vint16mf4_t *, vbool64_t, vint16mf4_t, vint16mf4_t, vint16mf4_t, const int16_t *, vuint16mf4_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vluxseg3ei16_v)))
void vluxseg3ei16_v_u16m1(vuint16m1_t *, vuint16m1_t *, vuint16m1_t *, const uint16_t *, vuint16m1_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vluxseg3ei16_v_m)))
void vluxseg3ei16_v_u16m1_m(vuint16m1_t *, vuint16m1_t *, vuint16m1_t *, vbool16_t, vuint16m1_t, vuint16m1_t, vuint16m1_t, const uint16_t *, vuint16m1_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vluxseg3ei16_v)))
void vluxseg3ei16_v_u16m2(vuint16m2_t *, vuint16m2_t *, vuint16m2_t *, const uint16_t *, vuint16m2_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vluxseg3ei16_v_m)))
void vluxseg3ei16_v_u16m2_m(vuint16m2_t *, vuint16m2_t *, vuint16m2_t *, vbool8_t, vuint16m2_t, vuint16m2_t, vuint16m2_t, const uint16_t *, vuint16m2_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vluxseg3ei16_v)))
void vluxseg3ei16_v_u16mf2(vuint16mf2_t *, vuint16mf2_t *, vuint16mf2_t *, const uint16_t *, vuint16mf2_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vluxseg3ei16_v_m)))
void vluxseg3ei16_v_u16mf2_m(vuint16mf2_t *, vuint16mf2_t *, vuint16mf2_t *, vbool32_t, vuint16mf2_t, vuint16mf2_t, vuint16mf2_t, const uint16_t *, vuint16mf2_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vluxseg3ei16_v)))
void vluxseg3ei16_v_u16mf4(vuint16mf4_t *, vuint16mf4_t *, vuint16mf4_t *, const uint16_t *, vuint16mf4_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vluxseg3ei16_v_m)))
void vluxseg3ei16_v_u16mf4_m(vuint16mf4_t *, vuint16mf4_t *, vuint16mf4_t *, vbool64_t, vuint16mf4_t, vuint16mf4_t, vuint16mf4_t, const uint16_t *, vuint16mf4_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vluxseg4ei16_v)))
void vluxseg4ei16_v_i16m1(vint16m1_t *, vint16m1_t *, vint16m1_t *, vint16m1_t *, const int16_t *, vuint16m1_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vluxseg4ei16_v_m)))
void vluxseg4ei16_v_i16m1_m(vint16m1_t *, vint16m1_t *, vint16m1_t *, vint16m1_t *, vbool16_t, vint16m1_t, vint16m1_t, vint16m1_t, vint16m1_t, const int16_t *, vuint16m1_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vluxseg4ei16_v)))
void vluxseg4ei16_v_i16m2(vint16m2_t *, vint16m2_t *, vint16m2_t *, vint16m2_t *, const int16_t *, vuint16m2_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vluxseg4ei16_v_m)))
void vluxseg4ei16_v_i16m2_m(vint16m2_t *, vint16m2_t *, vint16m2_t *, vint16m2_t *, vbool8_t, vint16m2_t, vint16m2_t, vint16m2_t, vint16m2_t, const int16_t *, vuint16m2_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vluxseg4ei16_v)))
void vluxseg4ei16_v_i16mf2(vint16mf2_t *, vint16mf2_t *, vint16mf2_t *, vint16mf2_t *, const int16_t *, vuint16mf2_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vluxseg4ei16_v_m)))
void vluxseg4ei16_v_i16mf2_m(vint16mf2_t *, vint16mf2_t *, vint16mf2_t *, vint16mf2_t *, vbool32_t, vint16mf2_t, vint16mf2_t, vint16mf2_t, vint16mf2_t, const int16_t *, vuint16mf2_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vluxseg4ei16_v)))
void vluxseg4ei16_v_i16mf4(vint16mf4_t *, vint16mf4_t *, vint16mf4_t *, vint16mf4_t *, const int16_t *, vuint16mf4_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vluxseg4ei16_v_m)))
void vluxseg4ei16_v_i16mf4_m(vint16mf4_t *, vint16mf4_t *, vint16mf4_t *, vint16mf4_t *, vbool64_t, vint16mf4_t, vint16mf4_t, vint16mf4_t, vint16mf4_t, const int16_t *, vuint16mf4_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vluxseg4ei16_v)))
void vluxseg4ei16_v_u16m1(vuint16m1_t *, vuint16m1_t *, vuint16m1_t *, vuint16m1_t *, const uint16_t *, vuint16m1_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vluxseg4ei16_v_m)))
void vluxseg4ei16_v_u16m1_m(vuint16m1_t *, vuint16m1_t *, vuint16m1_t *, vuint16m1_t *, vbool16_t, vuint16m1_t, vuint16m1_t, vuint16m1_t, vuint16m1_t, const uint16_t *, vuint16m1_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vluxseg4ei16_v)))
void vluxseg4ei16_v_u16m2(vuint16m2_t *, vuint16m2_t *, vuint16m2_t *, vuint16m2_t *, const uint16_t *, vuint16m2_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vluxseg4ei16_v_m)))
void vluxseg4ei16_v_u16m2_m(vuint16m2_t *, vuint16m2_t *, vuint16m2_t *, vuint16m2_t *, vbool8_t, vuint16m2_t, vuint16m2_t, vuint16m2_t, vuint16m2_t, const uint16_t *, vuint16m2_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vluxseg4ei16_v)))
void vluxseg4ei16_v_u16mf2(vuint16mf2_t *, vuint16mf2_t *, vuint16mf2_t *, vuint16mf2_t *, const uint16_t *, vuint16mf2_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vluxseg4ei16_v_m)))
void vluxseg4ei16_v_u16mf2_m(vuint16mf2_t *, vuint16mf2_t *, vuint16mf2_t *, vuint16mf2_t *, vbool32_t, vuint16mf2_t, vuint16mf2_t, vuint16mf2_t, vuint16mf2_t, const uint16_t *, vuint16mf2_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vluxseg4ei16_v)))
void vluxseg4ei16_v_u16mf4(vuint16mf4_t *, vuint16mf4_t *, vuint16mf4_t *, vuint16mf4_t *, const uint16_t *, vuint16mf4_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vluxseg4ei16_v_m)))
void vluxseg4ei16_v_u16mf4_m(vuint16mf4_t *, vuint16mf4_t *, vuint16mf4_t *, vuint16mf4_t *, vbool64_t, vuint16mf4_t, vuint16mf4_t, vuint16mf4_t, vuint16mf4_t, const uint16_t *, vuint16mf4_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vluxseg5ei16_v)))
void vluxseg5ei16_v_i16m1(vint16m1_t *, vint16m1_t *, vint16m1_t *, vint16m1_t *, vint16m1_t *, const int16_t *, vuint16m1_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vluxseg5ei16_v_m)))
void vluxseg5ei16_v_i16m1_m(vint16m1_t *, vint16m1_t *, vint16m1_t *, vint16m1_t *, vint16m1_t *, vbool16_t, vint16m1_t, vint16m1_t, vint16m1_t, vint16m1_t, vint16m1_t, const int16_t *, vuint16m1_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vluxseg5ei16_v)))
void vluxseg5ei16_v_i16mf2(vint16mf2_t *, vint16mf2_t *, vint16mf2_t *, vint16mf2_t *, vint16mf2_t *, const int16_t *, vuint16mf2_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vluxseg5ei16_v_m)))
void vluxseg5ei16_v_i16mf2_m(vint16mf2_t *, vint16mf2_t *, vint16mf2_t *, vint16mf2_t *, vint16mf2_t *, vbool32_t, vint16mf2_t, vint16mf2_t, vint16mf2_t, vint16mf2_t, vint16mf2_t, const int16_t *, vuint16mf2_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vluxseg5ei16_v)))
void vluxseg5ei16_v_i16mf4(vint16mf4_t *, vint16mf4_t *, vint16mf4_t *, vint16mf4_t *, vint16mf4_t *, const int16_t *, vuint16mf4_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vluxseg5ei16_v_m)))
void vluxseg5ei16_v_i16mf4_m(vint16mf4_t *, vint16mf4_t *, vint16mf4_t *, vint16mf4_t *, vint16mf4_t *, vbool64_t, vint16mf4_t, vint16mf4_t, vint16mf4_t, vint16mf4_t, vint16mf4_t, const int16_t *, vuint16mf4_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vluxseg5ei16_v)))
void vluxseg5ei16_v_u16m1(vuint16m1_t *, vuint16m1_t *, vuint16m1_t *, vuint16m1_t *, vuint16m1_t *, const uint16_t *, vuint16m1_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vluxseg5ei16_v_m)))
void vluxseg5ei16_v_u16m1_m(vuint16m1_t *, vuint16m1_t *, vuint16m1_t *, vuint16m1_t *, vuint16m1_t *, vbool16_t, vuint16m1_t, vuint16m1_t, vuint16m1_t, vuint16m1_t, vuint16m1_t, const uint16_t *, vuint16m1_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vluxseg5ei16_v)))
void vluxseg5ei16_v_u16mf2(vuint16mf2_t *, vuint16mf2_t *, vuint16mf2_t *, vuint16mf2_t *, vuint16mf2_t *, const uint16_t *, vuint16mf2_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vluxseg5ei16_v_m)))
void vluxseg5ei16_v_u16mf2_m(vuint16mf2_t *, vuint16mf2_t *, vuint16mf2_t *, vuint16mf2_t *, vuint16mf2_t *, vbool32_t, vuint16mf2_t, vuint16mf2_t, vuint16mf2_t, vuint16mf2_t, vuint16mf2_t, const uint16_t *, vuint16mf2_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vluxseg5ei16_v)))
void vluxseg5ei16_v_u16mf4(vuint16mf4_t *, vuint16mf4_t *, vuint16mf4_t *, vuint16mf4_t *, vuint16mf4_t *, const uint16_t *, vuint16mf4_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vluxseg5ei16_v_m)))
void vluxseg5ei16_v_u16mf4_m(vuint16mf4_t *, vuint16mf4_t *, vuint16mf4_t *, vuint16mf4_t *, vuint16mf4_t *, vbool64_t, vuint16mf4_t, vuint16mf4_t, vuint16mf4_t, vuint16mf4_t, vuint16mf4_t, const uint16_t *, vuint16mf4_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vluxseg6ei16_v)))
void vluxseg6ei16_v_i16m1(vint16m1_t *, vint16m1_t *, vint16m1_t *, vint16m1_t *, vint16m1_t *, vint16m1_t *, const int16_t *, vuint16m1_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vluxseg6ei16_v_m)))
void vluxseg6ei16_v_i16m1_m(vint16m1_t *, vint16m1_t *, vint16m1_t *, vint16m1_t *, vint16m1_t *, vint16m1_t *, vbool16_t, vint16m1_t, vint16m1_t, vint16m1_t, vint16m1_t, vint16m1_t, vint16m1_t, const int16_t *, vuint16m1_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vluxseg6ei16_v)))
void vluxseg6ei16_v_i16mf2(vint16mf2_t *, vint16mf2_t *, vint16mf2_t *, vint16mf2_t *, vint16mf2_t *, vint16mf2_t *, const int16_t *, vuint16mf2_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vluxseg6ei16_v_m)))
void vluxseg6ei16_v_i16mf2_m(vint16mf2_t *, vint16mf2_t *, vint16mf2_t *, vint16mf2_t *, vint16mf2_t *, vint16mf2_t *, vbool32_t, vint16mf2_t, vint16mf2_t, vint16mf2_t, vint16mf2_t, vint16mf2_t, vint16mf2_t, const int16_t *, vuint16mf2_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vluxseg6ei16_v)))
void vluxseg6ei16_v_i16mf4(vint16mf4_t *, vint16mf4_t *, vint16mf4_t *, vint16mf4_t *, vint16mf4_t *, vint16mf4_t *, const int16_t *, vuint16mf4_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vluxseg6ei16_v_m)))
void vluxseg6ei16_v_i16mf4_m(vint16mf4_t *, vint16mf4_t *, vint16mf4_t *, vint16mf4_t *, vint16mf4_t *, vint16mf4_t *, vbool64_t, vint16mf4_t, vint16mf4_t, vint16mf4_t, vint16mf4_t, vint16mf4_t, vint16mf4_t, const int16_t *, vuint16mf4_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vle8ff_v)))
vuint8m1_t vle8ff_v_u8m1(const uint8_t *, size_t *, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vle8ff_v_m)))
vuint8m1_t vle8ff_v_u8m1_m(vbool8_t, vuint8m1_t, const uint8_t *, size_t *, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vle8ff_v)))
vuint8m2_t vle8ff_v_u8m2(const uint8_t *, size_t *, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vle8ff_v_m)))
vuint8m2_t vle8ff_v_u8m2_m(vbool4_t, vuint8m2_t, const uint8_t *, size_t *, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vle8ff_v)))
vuint8m4_t vle8ff_v_u8m4(const uint8_t *, size_t *, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vle8ff_v_m)))
vuint8m4_t vle8ff_v_u8m4_m(vbool2_t, vuint8m4_t, const uint8_t *, size_t *, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vle8ff_v)))
vuint8m8_t vle8ff_v_u8m8(const uint8_t *, size_t *, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vle8ff_v_m)))
vuint8m8_t vle8ff_v_u8m8_m(vbool1_t, vuint8m8_t, const uint8_t *, size_t *, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vle8ff_v)))
vuint8mf2_t vle8ff_v_u8mf2(const uint8_t *, size_t *, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vle8ff_v_m)))
vuint8mf2_t vle8ff_v_u8mf2_m(vbool16_t, vuint8mf2_t, const uint8_t *, size_t *, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vle8ff_v)))
vuint8mf4_t vle8ff_v_u8mf4(const uint8_t *, size_t *, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vle8ff_v_m)))
vuint8mf4_t vle8ff_v_u8mf4_m(vbool32_t, vuint8mf4_t, const uint8_t *, size_t *, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vle8ff_v)))
vuint8mf8_t vle8ff_v_u8mf8(const uint8_t *, size_t *, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vle8ff_v_m)))
vuint8mf8_t vle8ff_v_u8mf8_m(vbool64_t, vuint8mf8_t, const uint8_t *, size_t *, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vluxseg6ei16_v)))
void vluxseg6ei16_v_u16m1(vuint16m1_t *, vuint16m1_t *, vuint16m1_t *, vuint16m1_t *, vuint16m1_t *, vuint16m1_t *, const uint16_t *, vuint16m1_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vluxseg6ei16_v_m)))
void vluxseg6ei16_v_u16m1_m(vuint16m1_t *, vuint16m1_t *, vuint16m1_t *, vuint16m1_t *, vuint16m1_t *, vuint16m1_t *, vbool16_t, vuint16m1_t, vuint16m1_t, vuint16m1_t, vuint16m1_t, vuint16m1_t, vuint16m1_t, const uint16_t *, vuint16m1_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vluxseg6ei16_v)))
void vluxseg6ei16_v_u16mf2(vuint16mf2_t *, vuint16mf2_t *, vuint16mf2_t *, vuint16mf2_t *, vuint16mf2_t *, vuint16mf2_t *, const uint16_t *, vuint16mf2_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vluxseg6ei16_v_m)))
void vluxseg6ei16_v_u16mf2_m(vuint16mf2_t *, vuint16mf2_t *, vuint16mf2_t *, vuint16mf2_t *, vuint16mf2_t *, vuint16mf2_t *, vbool32_t, vuint16mf2_t, vuint16mf2_t, vuint16mf2_t, vuint16mf2_t, vuint16mf2_t, vuint16mf2_t, const uint16_t *, vuint16mf2_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vluxseg6ei16_v)))
void vluxseg6ei16_v_u16mf4(vuint16mf4_t *, vuint16mf4_t *, vuint16mf4_t *, vuint16mf4_t *, vuint16mf4_t *, vuint16mf4_t *, const uint16_t *, vuint16mf4_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vluxseg6ei16_v_m)))
void vluxseg6ei16_v_u16mf4_m(vuint16mf4_t *, vuint16mf4_t *, vuint16mf4_t *, vuint16mf4_t *, vuint16mf4_t *, vuint16mf4_t *, vbool64_t, vuint16mf4_t, vuint16mf4_t, vuint16mf4_t, vuint16mf4_t, vuint16mf4_t, vuint16mf4_t, const uint16_t *, vuint16mf4_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vluxseg7ei16_v)))
void vluxseg7ei16_v_i16m1(vint16m1_t *, vint16m1_t *, vint16m1_t *, vint16m1_t *, vint16m1_t *, vint16m1_t *, vint16m1_t *, const int16_t *, vuint16m1_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vluxseg7ei16_v_m)))
void vluxseg7ei16_v_i16m1_m(vint16m1_t *, vint16m1_t *, vint16m1_t *, vint16m1_t *, vint16m1_t *, vint16m1_t *, vint16m1_t *, vbool16_t, vint16m1_t, vint16m1_t, vint16m1_t, vint16m1_t, vint16m1_t, vint16m1_t, vint16m1_t, const int16_t *, vuint16m1_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vluxseg7ei16_v)))
void vluxseg7ei16_v_i16mf2(vint16mf2_t *, vint16mf2_t *, vint16mf2_t *, vint16mf2_t *, vint16mf2_t *, vint16mf2_t *, vint16mf2_t *, const int16_t *, vuint16mf2_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vluxseg7ei16_v_m)))
void vluxseg7ei16_v_i16mf2_m(vint16mf2_t *, vint16mf2_t *, vint16mf2_t *, vint16mf2_t *, vint16mf2_t *, vint16mf2_t *, vint16mf2_t *, vbool32_t, vint16mf2_t, vint16mf2_t, vint16mf2_t, vint16mf2_t, vint16mf2_t, vint16mf2_t, vint16mf2_t, const int16_t *, vuint16mf2_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vluxseg7ei16_v)))
void vluxseg7ei16_v_i16mf4(vint16mf4_t *, vint16mf4_t *, vint16mf4_t *, vint16mf4_t *, vint16mf4_t *, vint16mf4_t *, vint16mf4_t *, const int16_t *, vuint16mf4_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vluxseg7ei16_v_m)))
void vluxseg7ei16_v_i16mf4_m(vint16mf4_t *, vint16mf4_t *, vint16mf4_t *, vint16mf4_t *, vint16mf4_t *, vint16mf4_t *, vint16mf4_t *, vbool64_t, vint16mf4_t, vint16mf4_t, vint16mf4_t, vint16mf4_t, vint16mf4_t, vint16mf4_t, vint16mf4_t, const int16_t *, vuint16mf4_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vluxseg7ei16_v)))
void vluxseg7ei16_v_u16m1(vuint16m1_t *, vuint16m1_t *, vuint16m1_t *, vuint16m1_t *, vuint16m1_t *, vuint16m1_t *, vuint16m1_t *, const uint16_t *, vuint16m1_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vluxseg7ei16_v_m)))
void vluxseg7ei16_v_u16m1_m(vuint16m1_t *, vuint16m1_t *, vuint16m1_t *, vuint16m1_t *, vuint16m1_t *, vuint16m1_t *, vuint16m1_t *, vbool16_t, vuint16m1_t, vuint16m1_t, vuint16m1_t, vuint16m1_t, vuint16m1_t, vuint16m1_t, vuint16m1_t, const uint16_t *, vuint16m1_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vluxseg7ei16_v)))
void vluxseg7ei16_v_u16mf2(vuint16mf2_t *, vuint16mf2_t *, vuint16mf2_t *, vuint16mf2_t *, vuint16mf2_t *, vuint16mf2_t *, vuint16mf2_t *, const uint16_t *, vuint16mf2_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vluxseg7ei16_v_m)))
void vluxseg7ei16_v_u16mf2_m(vuint16mf2_t *, vuint16mf2_t *, vuint16mf2_t *, vuint16mf2_t *, vuint16mf2_t *, vuint16mf2_t *, vuint16mf2_t *, vbool32_t, vuint16mf2_t, vuint16mf2_t, vuint16mf2_t, vuint16mf2_t, vuint16mf2_t, vuint16mf2_t, vuint16mf2_t, const uint16_t *, vuint16mf2_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vluxseg7ei16_v)))
void vluxseg7ei16_v_u16mf4(vuint16mf4_t *, vuint16mf4_t *, vuint16mf4_t *, vuint16mf4_t *, vuint16mf4_t *, vuint16mf4_t *, vuint16mf4_t *, const uint16_t *, vuint16mf4_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vluxseg7ei16_v_m)))
void vluxseg7ei16_v_u16mf4_m(vuint16mf4_t *, vuint16mf4_t *, vuint16mf4_t *, vuint16mf4_t *, vuint16mf4_t *, vuint16mf4_t *, vuint16mf4_t *, vbool64_t, vuint16mf4_t, vuint16mf4_t, vuint16mf4_t, vuint16mf4_t, vuint16mf4_t, vuint16mf4_t, vuint16mf4_t, const uint16_t *, vuint16mf4_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vluxseg8ei16_v)))
void vluxseg8ei16_v_i16m1(vint16m1_t *, vint16m1_t *, vint16m1_t *, vint16m1_t *, vint16m1_t *, vint16m1_t *, vint16m1_t *, vint16m1_t *, const int16_t *, vuint16m1_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vluxseg8ei16_v_m)))
void vluxseg8ei16_v_i16m1_m(vint16m1_t *, vint16m1_t *, vint16m1_t *, vint16m1_t *, vint16m1_t *, vint16m1_t *, vint16m1_t *, vint16m1_t *, vbool16_t, vint16m1_t, vint16m1_t, vint16m1_t, vint16m1_t, vint16m1_t, vint16m1_t, vint16m1_t, vint16m1_t, const int16_t *, vuint16m1_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vluxseg8ei16_v)))
void vluxseg8ei16_v_i16mf2(vint16mf2_t *, vint16mf2_t *, vint16mf2_t *, vint16mf2_t *, vint16mf2_t *, vint16mf2_t *, vint16mf2_t *, vint16mf2_t *, const int16_t *, vuint16mf2_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vluxseg8ei16_v_m)))
void vluxseg8ei16_v_i16mf2_m(vint16mf2_t *, vint16mf2_t *, vint16mf2_t *, vint16mf2_t *, vint16mf2_t *, vint16mf2_t *, vint16mf2_t *, vint16mf2_t *, vbool32_t, vint16mf2_t, vint16mf2_t, vint16mf2_t, vint16mf2_t, vint16mf2_t, vint16mf2_t, vint16mf2_t, vint16mf2_t, const int16_t *, vuint16mf2_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vluxseg8ei16_v)))
void vluxseg8ei16_v_i16mf4(vint16mf4_t *, vint16mf4_t *, vint16mf4_t *, vint16mf4_t *, vint16mf4_t *, vint16mf4_t *, vint16mf4_t *, vint16mf4_t *, const int16_t *, vuint16mf4_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vluxseg8ei16_v_m)))
void vluxseg8ei16_v_i16mf4_m(vint16mf4_t *, vint16mf4_t *, vint16mf4_t *, vint16mf4_t *, vint16mf4_t *, vint16mf4_t *, vint16mf4_t *, vint16mf4_t *, vbool64_t, vint16mf4_t, vint16mf4_t, vint16mf4_t, vint16mf4_t, vint16mf4_t, vint16mf4_t, vint16mf4_t, vint16mf4_t, const int16_t *, vuint16mf4_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vluxseg8ei16_v)))
void vluxseg8ei16_v_u16m1(vuint16m1_t *, vuint16m1_t *, vuint16m1_t *, vuint16m1_t *, vuint16m1_t *, vuint16m1_t *, vuint16m1_t *, vuint16m1_t *, const uint16_t *, vuint16m1_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vluxseg8ei16_v_m)))
void vluxseg8ei16_v_u16m1_m(vuint16m1_t *, vuint16m1_t *, vuint16m1_t *, vuint16m1_t *, vuint16m1_t *, vuint16m1_t *, vuint16m1_t *, vuint16m1_t *, vbool16_t, vuint16m1_t, vuint16m1_t, vuint16m1_t, vuint16m1_t, vuint16m1_t, vuint16m1_t, vuint16m1_t, vuint16m1_t, const uint16_t *, vuint16m1_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vluxseg8ei16_v)))
void vluxseg8ei16_v_u16mf2(vuint16mf2_t *, vuint16mf2_t *, vuint16mf2_t *, vuint16mf2_t *, vuint16mf2_t *, vuint16mf2_t *, vuint16mf2_t *, vuint16mf2_t *, const uint16_t *, vuint16mf2_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vluxseg8ei16_v_m)))
void vluxseg8ei16_v_u16mf2_m(vuint16mf2_t *, vuint16mf2_t *, vuint16mf2_t *, vuint16mf2_t *, vuint16mf2_t *, vuint16mf2_t *, vuint16mf2_t *, vuint16mf2_t *, vbool32_t, vuint16mf2_t, vuint16mf2_t, vuint16mf2_t, vuint16mf2_t, vuint16mf2_t, vuint16mf2_t, vuint16mf2_t, vuint16mf2_t, const uint16_t *, vuint16mf2_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vluxseg8ei16_v)))
void vluxseg8ei16_v_u16mf4(vuint16mf4_t *, vuint16mf4_t *, vuint16mf4_t *, vuint16mf4_t *, vuint16mf4_t *, vuint16mf4_t *, vuint16mf4_t *, vuint16mf4_t *, const uint16_t *, vuint16mf4_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vluxseg8ei16_v_m)))
void vluxseg8ei16_v_u16mf4_m(vuint16mf4_t *, vuint16mf4_t *, vuint16mf4_t *, vuint16mf4_t *, vuint16mf4_t *, vuint16mf4_t *, vuint16mf4_t *, vuint16mf4_t *, vbool64_t, vuint16mf4_t, vuint16mf4_t, vuint16mf4_t, vuint16mf4_t, vuint16mf4_t, vuint16mf4_t, vuint16mf4_t, vuint16mf4_t, const uint16_t *, vuint16mf4_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vluxseg2ei32_v)))
void vluxseg2ei32_v_i16m1(vint16m1_t *, vint16m1_t *, const int16_t *, vuint32m2_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vluxseg2ei32_v_m)))
void vluxseg2ei32_v_i16m1_m(vint16m1_t *, vint16m1_t *, vbool16_t, vint16m1_t, vint16m1_t, const int16_t *, vuint32m2_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vluxseg2ei32_v)))
void vluxseg2ei32_v_i16m2(vint16m2_t *, vint16m2_t *, const int16_t *, vuint32m4_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vluxseg2ei32_v_m)))
void vluxseg2ei32_v_i16m2_m(vint16m2_t *, vint16m2_t *, vbool8_t, vint16m2_t, vint16m2_t, const int16_t *, vuint32m4_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vluxseg2ei32_v)))
void vluxseg2ei32_v_i16m4(vint16m4_t *, vint16m4_t *, const int16_t *, vuint32m8_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vluxseg2ei32_v_m)))
void vluxseg2ei32_v_i16m4_m(vint16m4_t *, vint16m4_t *, vbool4_t, vint16m4_t, vint16m4_t, const int16_t *, vuint32m8_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vluxseg2ei32_v)))
void vluxseg2ei32_v_i16mf2(vint16mf2_t *, vint16mf2_t *, const int16_t *, vuint32m1_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vluxseg2ei32_v_m)))
void vluxseg2ei32_v_i16mf2_m(vint16mf2_t *, vint16mf2_t *, vbool32_t, vint16mf2_t, vint16mf2_t, const int16_t *, vuint32m1_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vluxseg2ei32_v)))
void vluxseg2ei32_v_i16mf4(vint16mf4_t *, vint16mf4_t *, const int16_t *, vuint32mf2_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vluxseg2ei32_v_m)))
void vluxseg2ei32_v_i16mf4_m(vint16mf4_t *, vint16mf4_t *, vbool64_t, vint16mf4_t, vint16mf4_t, const int16_t *, vuint32mf2_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vluxseg2ei32_v)))
void vluxseg2ei32_v_u16m1(vuint16m1_t *, vuint16m1_t *, const uint16_t *, vuint32m2_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vluxseg2ei32_v_m)))
void vluxseg2ei32_v_u16m1_m(vuint16m1_t *, vuint16m1_t *, vbool16_t, vuint16m1_t, vuint16m1_t, const uint16_t *, vuint32m2_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vluxseg2ei32_v)))
void vluxseg2ei32_v_u16m2(vuint16m2_t *, vuint16m2_t *, const uint16_t *, vuint32m4_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vluxseg2ei32_v_m)))
void vluxseg2ei32_v_u16m2_m(vuint16m2_t *, vuint16m2_t *, vbool8_t, vuint16m2_t, vuint16m2_t, const uint16_t *, vuint32m4_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vluxseg2ei32_v)))
void vluxseg2ei32_v_u16m4(vuint16m4_t *, vuint16m4_t *, const uint16_t *, vuint32m8_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vluxseg2ei32_v_m)))
void vluxseg2ei32_v_u16m4_m(vuint16m4_t *, vuint16m4_t *, vbool4_t, vuint16m4_t, vuint16m4_t, const uint16_t *, vuint32m8_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vluxseg2ei32_v)))
void vluxseg2ei32_v_u16mf2(vuint16mf2_t *, vuint16mf2_t *, const uint16_t *, vuint32m1_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vluxseg2ei32_v_m)))
void vluxseg2ei32_v_u16mf2_m(vuint16mf2_t *, vuint16mf2_t *, vbool32_t, vuint16mf2_t, vuint16mf2_t, const uint16_t *, vuint32m1_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vluxseg2ei32_v)))
void vluxseg2ei32_v_u16mf4(vuint16mf4_t *, vuint16mf4_t *, const uint16_t *, vuint32mf2_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vluxseg2ei32_v_m)))
void vluxseg2ei32_v_u16mf4_m(vuint16mf4_t *, vuint16mf4_t *, vbool64_t, vuint16mf4_t, vuint16mf4_t, const uint16_t *, vuint32mf2_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vluxseg3ei32_v)))
void vluxseg3ei32_v_i16m1(vint16m1_t *, vint16m1_t *, vint16m1_t *, const int16_t *, vuint32m2_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vluxseg3ei32_v_m)))
void vluxseg3ei32_v_i16m1_m(vint16m1_t *, vint16m1_t *, vint16m1_t *, vbool16_t, vint16m1_t, vint16m1_t, vint16m1_t, const int16_t *, vuint32m2_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vluxseg3ei32_v)))
void vluxseg3ei32_v_i16m2(vint16m2_t *, vint16m2_t *, vint16m2_t *, const int16_t *, vuint32m4_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vluxseg3ei32_v_m)))
void vluxseg3ei32_v_i16m2_m(vint16m2_t *, vint16m2_t *, vint16m2_t *, vbool8_t, vint16m2_t, vint16m2_t, vint16m2_t, const int16_t *, vuint32m4_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vluxseg3ei32_v)))
void vluxseg3ei32_v_i16mf2(vint16mf2_t *, vint16mf2_t *, vint16mf2_t *, const int16_t *, vuint32m1_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vluxseg3ei32_v_m)))
void vluxseg3ei32_v_i16mf2_m(vint16mf2_t *, vint16mf2_t *, vint16mf2_t *, vbool32_t, vint16mf2_t, vint16mf2_t, vint16mf2_t, const int16_t *, vuint32m1_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vluxseg3ei32_v)))
void vluxseg3ei32_v_i16mf4(vint16mf4_t *, vint16mf4_t *, vint16mf4_t *, const int16_t *, vuint32mf2_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vluxseg3ei32_v_m)))
void vluxseg3ei32_v_i16mf4_m(vint16mf4_t *, vint16mf4_t *, vint16mf4_t *, vbool64_t, vint16mf4_t, vint16mf4_t, vint16mf4_t, const int16_t *, vuint32mf2_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vluxseg3ei32_v)))
void vluxseg3ei32_v_u16m1(vuint16m1_t *, vuint16m1_t *, vuint16m1_t *, const uint16_t *, vuint32m2_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vluxseg3ei32_v_m)))
void vluxseg3ei32_v_u16m1_m(vuint16m1_t *, vuint16m1_t *, vuint16m1_t *, vbool16_t, vuint16m1_t, vuint16m1_t, vuint16m1_t, const uint16_t *, vuint32m2_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vluxseg3ei32_v)))
void vluxseg3ei32_v_u16m2(vuint16m2_t *, vuint16m2_t *, vuint16m2_t *, const uint16_t *, vuint32m4_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vluxseg3ei32_v_m)))
void vluxseg3ei32_v_u16m2_m(vuint16m2_t *, vuint16m2_t *, vuint16m2_t *, vbool8_t, vuint16m2_t, vuint16m2_t, vuint16m2_t, const uint16_t *, vuint32m4_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vluxseg3ei32_v)))
void vluxseg3ei32_v_u16mf2(vuint16mf2_t *, vuint16mf2_t *, vuint16mf2_t *, const uint16_t *, vuint32m1_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vluxseg3ei32_v_m)))
void vluxseg3ei32_v_u16mf2_m(vuint16mf2_t *, vuint16mf2_t *, vuint16mf2_t *, vbool32_t, vuint16mf2_t, vuint16mf2_t, vuint16mf2_t, const uint16_t *, vuint32m1_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vluxseg3ei32_v)))
void vluxseg3ei32_v_u16mf4(vuint16mf4_t *, vuint16mf4_t *, vuint16mf4_t *, const uint16_t *, vuint32mf2_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vluxseg3ei32_v_m)))
void vluxseg3ei32_v_u16mf4_m(vuint16mf4_t *, vuint16mf4_t *, vuint16mf4_t *, vbool64_t, vuint16mf4_t, vuint16mf4_t, vuint16mf4_t, const uint16_t *, vuint32mf2_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vluxseg4ei32_v)))
void vluxseg4ei32_v_i16m1(vint16m1_t *, vint16m1_t *, vint16m1_t *, vint16m1_t *, const int16_t *, vuint32m2_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vluxseg4ei32_v_m)))
void vluxseg4ei32_v_i16m1_m(vint16m1_t *, vint16m1_t *, vint16m1_t *, vint16m1_t *, vbool16_t, vint16m1_t, vint16m1_t, vint16m1_t, vint16m1_t, const int16_t *, vuint32m2_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vluxseg4ei32_v)))
void vluxseg4ei32_v_i16m2(vint16m2_t *, vint16m2_t *, vint16m2_t *, vint16m2_t *, const int16_t *, vuint32m4_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vluxseg4ei32_v_m)))
void vluxseg4ei32_v_i16m2_m(vint16m2_t *, vint16m2_t *, vint16m2_t *, vint16m2_t *, vbool8_t, vint16m2_t, vint16m2_t, vint16m2_t, vint16m2_t, const int16_t *, vuint32m4_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vluxseg4ei32_v)))
void vluxseg4ei32_v_i16mf2(vint16mf2_t *, vint16mf2_t *, vint16mf2_t *, vint16mf2_t *, const int16_t *, vuint32m1_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vluxseg4ei32_v_m)))
void vluxseg4ei32_v_i16mf2_m(vint16mf2_t *, vint16mf2_t *, vint16mf2_t *, vint16mf2_t *, vbool32_t, vint16mf2_t, vint16mf2_t, vint16mf2_t, vint16mf2_t, const int16_t *, vuint32m1_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vluxseg4ei32_v)))
void vluxseg4ei32_v_i16mf4(vint16mf4_t *, vint16mf4_t *, vint16mf4_t *, vint16mf4_t *, const int16_t *, vuint32mf2_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vluxseg4ei32_v_m)))
void vluxseg4ei32_v_i16mf4_m(vint16mf4_t *, vint16mf4_t *, vint16mf4_t *, vint16mf4_t *, vbool64_t, vint16mf4_t, vint16mf4_t, vint16mf4_t, vint16mf4_t, const int16_t *, vuint32mf2_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vluxseg4ei32_v)))
void vluxseg4ei32_v_u16m1(vuint16m1_t *, vuint16m1_t *, vuint16m1_t *, vuint16m1_t *, const uint16_t *, vuint32m2_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vluxseg4ei32_v_m)))
void vluxseg4ei32_v_u16m1_m(vuint16m1_t *, vuint16m1_t *, vuint16m1_t *, vuint16m1_t *, vbool16_t, vuint16m1_t, vuint16m1_t, vuint16m1_t, vuint16m1_t, const uint16_t *, vuint32m2_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vluxseg4ei32_v)))
void vluxseg4ei32_v_u16m2(vuint16m2_t *, vuint16m2_t *, vuint16m2_t *, vuint16m2_t *, const uint16_t *, vuint32m4_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vluxseg4ei32_v_m)))
void vluxseg4ei32_v_u16m2_m(vuint16m2_t *, vuint16m2_t *, vuint16m2_t *, vuint16m2_t *, vbool8_t, vuint16m2_t, vuint16m2_t, vuint16m2_t, vuint16m2_t, const uint16_t *, vuint32m4_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vluxseg4ei32_v)))
void vluxseg4ei32_v_u16mf2(vuint16mf2_t *, vuint16mf2_t *, vuint16mf2_t *, vuint16mf2_t *, const uint16_t *, vuint32m1_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vluxseg4ei32_v_m)))
void vluxseg4ei32_v_u16mf2_m(vuint16mf2_t *, vuint16mf2_t *, vuint16mf2_t *, vuint16mf2_t *, vbool32_t, vuint16mf2_t, vuint16mf2_t, vuint16mf2_t, vuint16mf2_t, const uint16_t *, vuint32m1_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vluxseg4ei32_v)))
void vluxseg4ei32_v_u16mf4(vuint16mf4_t *, vuint16mf4_t *, vuint16mf4_t *, vuint16mf4_t *, const uint16_t *, vuint32mf2_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vluxseg4ei32_v_m)))
void vluxseg4ei32_v_u16mf4_m(vuint16mf4_t *, vuint16mf4_t *, vuint16mf4_t *, vuint16mf4_t *, vbool64_t, vuint16mf4_t, vuint16mf4_t, vuint16mf4_t, vuint16mf4_t, const uint16_t *, vuint32mf2_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vluxseg5ei32_v)))
void vluxseg5ei32_v_i16m1(vint16m1_t *, vint16m1_t *, vint16m1_t *, vint16m1_t *, vint16m1_t *, const int16_t *, vuint32m2_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vluxseg5ei32_v_m)))
void vluxseg5ei32_v_i16m1_m(vint16m1_t *, vint16m1_t *, vint16m1_t *, vint16m1_t *, vint16m1_t *, vbool16_t, vint16m1_t, vint16m1_t, vint16m1_t, vint16m1_t, vint16m1_t, const int16_t *, vuint32m2_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vluxseg5ei32_v)))
void vluxseg5ei32_v_i16mf2(vint16mf2_t *, vint16mf2_t *, vint16mf2_t *, vint16mf2_t *, vint16mf2_t *, const int16_t *, vuint32m1_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vluxseg5ei32_v_m)))
void vluxseg5ei32_v_i16mf2_m(vint16mf2_t *, vint16mf2_t *, vint16mf2_t *, vint16mf2_t *, vint16mf2_t *, vbool32_t, vint16mf2_t, vint16mf2_t, vint16mf2_t, vint16mf2_t, vint16mf2_t, const int16_t *, vuint32m1_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vluxseg5ei32_v)))
void vluxseg5ei32_v_i16mf4(vint16mf4_t *, vint16mf4_t *, vint16mf4_t *, vint16mf4_t *, vint16mf4_t *, const int16_t *, vuint32mf2_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vluxseg5ei32_v_m)))
void vluxseg5ei32_v_i16mf4_m(vint16mf4_t *, vint16mf4_t *, vint16mf4_t *, vint16mf4_t *, vint16mf4_t *, vbool64_t, vint16mf4_t, vint16mf4_t, vint16mf4_t, vint16mf4_t, vint16mf4_t, const int16_t *, vuint32mf2_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vluxseg5ei32_v)))
void vluxseg5ei32_v_u16m1(vuint16m1_t *, vuint16m1_t *, vuint16m1_t *, vuint16m1_t *, vuint16m1_t *, const uint16_t *, vuint32m2_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vluxseg5ei32_v_m)))
void vluxseg5ei32_v_u16m1_m(vuint16m1_t *, vuint16m1_t *, vuint16m1_t *, vuint16m1_t *, vuint16m1_t *, vbool16_t, vuint16m1_t, vuint16m1_t, vuint16m1_t, vuint16m1_t, vuint16m1_t, const uint16_t *, vuint32m2_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vluxseg5ei32_v)))
void vluxseg5ei32_v_u16mf2(vuint16mf2_t *, vuint16mf2_t *, vuint16mf2_t *, vuint16mf2_t *, vuint16mf2_t *, const uint16_t *, vuint32m1_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vluxseg5ei32_v_m)))
void vluxseg5ei32_v_u16mf2_m(vuint16mf2_t *, vuint16mf2_t *, vuint16mf2_t *, vuint16mf2_t *, vuint16mf2_t *, vbool32_t, vuint16mf2_t, vuint16mf2_t, vuint16mf2_t, vuint16mf2_t, vuint16mf2_t, const uint16_t *, vuint32m1_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vluxseg5ei32_v)))
void vluxseg5ei32_v_u16mf4(vuint16mf4_t *, vuint16mf4_t *, vuint16mf4_t *, vuint16mf4_t *, vuint16mf4_t *, const uint16_t *, vuint32mf2_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vluxseg5ei32_v_m)))
void vluxseg5ei32_v_u16mf4_m(vuint16mf4_t *, vuint16mf4_t *, vuint16mf4_t *, vuint16mf4_t *, vuint16mf4_t *, vbool64_t, vuint16mf4_t, vuint16mf4_t, vuint16mf4_t, vuint16mf4_t, vuint16mf4_t, const uint16_t *, vuint32mf2_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vluxseg6ei32_v)))
void vluxseg6ei32_v_i16m1(vint16m1_t *, vint16m1_t *, vint16m1_t *, vint16m1_t *, vint16m1_t *, vint16m1_t *, const int16_t *, vuint32m2_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vluxseg6ei32_v_m)))
void vluxseg6ei32_v_i16m1_m(vint16m1_t *, vint16m1_t *, vint16m1_t *, vint16m1_t *, vint16m1_t *, vint16m1_t *, vbool16_t, vint16m1_t, vint16m1_t, vint16m1_t, vint16m1_t, vint16m1_t, vint16m1_t, const int16_t *, vuint32m2_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vluxseg6ei32_v)))
void vluxseg6ei32_v_i16mf2(vint16mf2_t *, vint16mf2_t *, vint16mf2_t *, vint16mf2_t *, vint16mf2_t *, vint16mf2_t *, const int16_t *, vuint32m1_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vluxseg6ei32_v_m)))
void vluxseg6ei32_v_i16mf2_m(vint16mf2_t *, vint16mf2_t *, vint16mf2_t *, vint16mf2_t *, vint16mf2_t *, vint16mf2_t *, vbool32_t, vint16mf2_t, vint16mf2_t, vint16mf2_t, vint16mf2_t, vint16mf2_t, vint16mf2_t, const int16_t *, vuint32m1_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vluxseg6ei32_v)))
void vluxseg6ei32_v_i16mf4(vint16mf4_t *, vint16mf4_t *, vint16mf4_t *, vint16mf4_t *, vint16mf4_t *, vint16mf4_t *, const int16_t *, vuint32mf2_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vluxseg6ei32_v_m)))
void vluxseg6ei32_v_i16mf4_m(vint16mf4_t *, vint16mf4_t *, vint16mf4_t *, vint16mf4_t *, vint16mf4_t *, vint16mf4_t *, vbool64_t, vint16mf4_t, vint16mf4_t, vint16mf4_t, vint16mf4_t, vint16mf4_t, vint16mf4_t, const int16_t *, vuint32mf2_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vluxseg6ei32_v)))
void vluxseg6ei32_v_u16m1(vuint16m1_t *, vuint16m1_t *, vuint16m1_t *, vuint16m1_t *, vuint16m1_t *, vuint16m1_t *, const uint16_t *, vuint32m2_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vluxseg6ei32_v_m)))
void vluxseg6ei32_v_u16m1_m(vuint16m1_t *, vuint16m1_t *, vuint16m1_t *, vuint16m1_t *, vuint16m1_t *, vuint16m1_t *, vbool16_t, vuint16m1_t, vuint16m1_t, vuint16m1_t, vuint16m1_t, vuint16m1_t, vuint16m1_t, const uint16_t *, vuint32m2_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vluxseg6ei32_v)))
void vluxseg6ei32_v_u16mf2(vuint16mf2_t *, vuint16mf2_t *, vuint16mf2_t *, vuint16mf2_t *, vuint16mf2_t *, vuint16mf2_t *, const uint16_t *, vuint32m1_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vluxseg6ei32_v_m)))
void vluxseg6ei32_v_u16mf2_m(vuint16mf2_t *, vuint16mf2_t *, vuint16mf2_t *, vuint16mf2_t *, vuint16mf2_t *, vuint16mf2_t *, vbool32_t, vuint16mf2_t, vuint16mf2_t, vuint16mf2_t, vuint16mf2_t, vuint16mf2_t, vuint16mf2_t, const uint16_t *, vuint32m1_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vluxseg6ei32_v)))
void vluxseg6ei32_v_u16mf4(vuint16mf4_t *, vuint16mf4_t *, vuint16mf4_t *, vuint16mf4_t *, vuint16mf4_t *, vuint16mf4_t *, const uint16_t *, vuint32mf2_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vluxseg6ei32_v_m)))
void vluxseg6ei32_v_u16mf4_m(vuint16mf4_t *, vuint16mf4_t *, vuint16mf4_t *, vuint16mf4_t *, vuint16mf4_t *, vuint16mf4_t *, vbool64_t, vuint16mf4_t, vuint16mf4_t, vuint16mf4_t, vuint16mf4_t, vuint16mf4_t, vuint16mf4_t, const uint16_t *, vuint32mf2_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vluxseg7ei32_v)))
void vluxseg7ei32_v_i16m1(vint16m1_t *, vint16m1_t *, vint16m1_t *, vint16m1_t *, vint16m1_t *, vint16m1_t *, vint16m1_t *, const int16_t *, vuint32m2_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vluxseg7ei32_v_m)))
void vluxseg7ei32_v_i16m1_m(vint16m1_t *, vint16m1_t *, vint16m1_t *, vint16m1_t *, vint16m1_t *, vint16m1_t *, vint16m1_t *, vbool16_t, vint16m1_t, vint16m1_t, vint16m1_t, vint16m1_t, vint16m1_t, vint16m1_t, vint16m1_t, const int16_t *, vuint32m2_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vluxseg7ei32_v)))
void vluxseg7ei32_v_i16mf2(vint16mf2_t *, vint16mf2_t *, vint16mf2_t *, vint16mf2_t *, vint16mf2_t *, vint16mf2_t *, vint16mf2_t *, const int16_t *, vuint32m1_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vluxseg7ei32_v_m)))
void vluxseg7ei32_v_i16mf2_m(vint16mf2_t *, vint16mf2_t *, vint16mf2_t *, vint16mf2_t *, vint16mf2_t *, vint16mf2_t *, vint16mf2_t *, vbool32_t, vint16mf2_t, vint16mf2_t, vint16mf2_t, vint16mf2_t, vint16mf2_t, vint16mf2_t, vint16mf2_t, const int16_t *, vuint32m1_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vluxseg7ei32_v)))
void vluxseg7ei32_v_i16mf4(vint16mf4_t *, vint16mf4_t *, vint16mf4_t *, vint16mf4_t *, vint16mf4_t *, vint16mf4_t *, vint16mf4_t *, const int16_t *, vuint32mf2_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vluxseg7ei32_v_m)))
void vluxseg7ei32_v_i16mf4_m(vint16mf4_t *, vint16mf4_t *, vint16mf4_t *, vint16mf4_t *, vint16mf4_t *, vint16mf4_t *, vint16mf4_t *, vbool64_t, vint16mf4_t, vint16mf4_t, vint16mf4_t, vint16mf4_t, vint16mf4_t, vint16mf4_t, vint16mf4_t, const int16_t *, vuint32mf2_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vluxseg7ei32_v)))
void vluxseg7ei32_v_u16m1(vuint16m1_t *, vuint16m1_t *, vuint16m1_t *, vuint16m1_t *, vuint16m1_t *, vuint16m1_t *, vuint16m1_t *, const uint16_t *, vuint32m2_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vluxseg7ei32_v_m)))
void vluxseg7ei32_v_u16m1_m(vuint16m1_t *, vuint16m1_t *, vuint16m1_t *, vuint16m1_t *, vuint16m1_t *, vuint16m1_t *, vuint16m1_t *, vbool16_t, vuint16m1_t, vuint16m1_t, vuint16m1_t, vuint16m1_t, vuint16m1_t, vuint16m1_t, vuint16m1_t, const uint16_t *, vuint32m2_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vluxseg7ei32_v)))
void vluxseg7ei32_v_u16mf2(vuint16mf2_t *, vuint16mf2_t *, vuint16mf2_t *, vuint16mf2_t *, vuint16mf2_t *, vuint16mf2_t *, vuint16mf2_t *, const uint16_t *, vuint32m1_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vluxseg7ei32_v_m)))
void vluxseg7ei32_v_u16mf2_m(vuint16mf2_t *, vuint16mf2_t *, vuint16mf2_t *, vuint16mf2_t *, vuint16mf2_t *, vuint16mf2_t *, vuint16mf2_t *, vbool32_t, vuint16mf2_t, vuint16mf2_t, vuint16mf2_t, vuint16mf2_t, vuint16mf2_t, vuint16mf2_t, vuint16mf2_t, const uint16_t *, vuint32m1_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vluxseg7ei32_v)))
void vluxseg7ei32_v_u16mf4(vuint16mf4_t *, vuint16mf4_t *, vuint16mf4_t *, vuint16mf4_t *, vuint16mf4_t *, vuint16mf4_t *, vuint16mf4_t *, const uint16_t *, vuint32mf2_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vluxseg7ei32_v_m)))
void vluxseg7ei32_v_u16mf4_m(vuint16mf4_t *, vuint16mf4_t *, vuint16mf4_t *, vuint16mf4_t *, vuint16mf4_t *, vuint16mf4_t *, vuint16mf4_t *, vbool64_t, vuint16mf4_t, vuint16mf4_t, vuint16mf4_t, vuint16mf4_t, vuint16mf4_t, vuint16mf4_t, vuint16mf4_t, const uint16_t *, vuint32mf2_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vluxseg8ei32_v)))
void vluxseg8ei32_v_i16m1(vint16m1_t *, vint16m1_t *, vint16m1_t *, vint16m1_t *, vint16m1_t *, vint16m1_t *, vint16m1_t *, vint16m1_t *, const int16_t *, vuint32m2_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vluxseg8ei32_v_m)))
void vluxseg8ei32_v_i16m1_m(vint16m1_t *, vint16m1_t *, vint16m1_t *, vint16m1_t *, vint16m1_t *, vint16m1_t *, vint16m1_t *, vint16m1_t *, vbool16_t, vint16m1_t, vint16m1_t, vint16m1_t, vint16m1_t, vint16m1_t, vint16m1_t, vint16m1_t, vint16m1_t, const int16_t *, vuint32m2_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vluxseg8ei32_v)))
void vluxseg8ei32_v_i16mf2(vint16mf2_t *, vint16mf2_t *, vint16mf2_t *, vint16mf2_t *, vint16mf2_t *, vint16mf2_t *, vint16mf2_t *, vint16mf2_t *, const int16_t *, vuint32m1_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vluxseg8ei32_v_m)))
void vluxseg8ei32_v_i16mf2_m(vint16mf2_t *, vint16mf2_t *, vint16mf2_t *, vint16mf2_t *, vint16mf2_t *, vint16mf2_t *, vint16mf2_t *, vint16mf2_t *, vbool32_t, vint16mf2_t, vint16mf2_t, vint16mf2_t, vint16mf2_t, vint16mf2_t, vint16mf2_t, vint16mf2_t, vint16mf2_t, const int16_t *, vuint32m1_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vluxseg8ei32_v)))
void vluxseg8ei32_v_i16mf4(vint16mf4_t *, vint16mf4_t *, vint16mf4_t *, vint16mf4_t *, vint16mf4_t *, vint16mf4_t *, vint16mf4_t *, vint16mf4_t *, const int16_t *, vuint32mf2_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vluxseg8ei32_v_m)))
void vluxseg8ei32_v_i16mf4_m(vint16mf4_t *, vint16mf4_t *, vint16mf4_t *, vint16mf4_t *, vint16mf4_t *, vint16mf4_t *, vint16mf4_t *, vint16mf4_t *, vbool64_t, vint16mf4_t, vint16mf4_t, vint16mf4_t, vint16mf4_t, vint16mf4_t, vint16mf4_t, vint16mf4_t, vint16mf4_t, const int16_t *, vuint32mf2_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vluxseg8ei32_v)))
void vluxseg8ei32_v_u16m1(vuint16m1_t *, vuint16m1_t *, vuint16m1_t *, vuint16m1_t *, vuint16m1_t *, vuint16m1_t *, vuint16m1_t *, vuint16m1_t *, const uint16_t *, vuint32m2_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vluxseg8ei32_v_m)))
void vluxseg8ei32_v_u16m1_m(vuint16m1_t *, vuint16m1_t *, vuint16m1_t *, vuint16m1_t *, vuint16m1_t *, vuint16m1_t *, vuint16m1_t *, vuint16m1_t *, vbool16_t, vuint16m1_t, vuint16m1_t, vuint16m1_t, vuint16m1_t, vuint16m1_t, vuint16m1_t, vuint16m1_t, vuint16m1_t, const uint16_t *, vuint32m2_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vluxseg8ei32_v)))
void vluxseg8ei32_v_u16mf2(vuint16mf2_t *, vuint16mf2_t *, vuint16mf2_t *, vuint16mf2_t *, vuint16mf2_t *, vuint16mf2_t *, vuint16mf2_t *, vuint16mf2_t *, const uint16_t *, vuint32m1_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vluxseg8ei32_v_m)))
void vluxseg8ei32_v_u16mf2_m(vuint16mf2_t *, vuint16mf2_t *, vuint16mf2_t *, vuint16mf2_t *, vuint16mf2_t *, vuint16mf2_t *, vuint16mf2_t *, vuint16mf2_t *, vbool32_t, vuint16mf2_t, vuint16mf2_t, vuint16mf2_t, vuint16mf2_t, vuint16mf2_t, vuint16mf2_t, vuint16mf2_t, vuint16mf2_t, const uint16_t *, vuint32m1_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vluxseg8ei32_v)))
void vluxseg8ei32_v_u16mf4(vuint16mf4_t *, vuint16mf4_t *, vuint16mf4_t *, vuint16mf4_t *, vuint16mf4_t *, vuint16mf4_t *, vuint16mf4_t *, vuint16mf4_t *, const uint16_t *, vuint32mf2_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vluxseg8ei32_v_m)))
void vluxseg8ei32_v_u16mf4_m(vuint16mf4_t *, vuint16mf4_t *, vuint16mf4_t *, vuint16mf4_t *, vuint16mf4_t *, vuint16mf4_t *, vuint16mf4_t *, vuint16mf4_t *, vbool64_t, vuint16mf4_t, vuint16mf4_t, vuint16mf4_t, vuint16mf4_t, vuint16mf4_t, vuint16mf4_t, vuint16mf4_t, vuint16mf4_t, const uint16_t *, vuint32mf2_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vluxseg2ei8_v)))
void vluxseg2ei8_v_i32m1(vint32m1_t *, vint32m1_t *, const int32_t *, vuint8mf4_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vluxseg2ei8_v_m)))
void vluxseg2ei8_v_i32m1_m(vint32m1_t *, vint32m1_t *, vbool32_t, vint32m1_t, vint32m1_t, const int32_t *, vuint8mf4_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vluxseg2ei8_v)))
void vluxseg2ei8_v_i32m2(vint32m2_t *, vint32m2_t *, const int32_t *, vuint8mf2_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vluxseg2ei8_v_m)))
void vluxseg2ei8_v_i32m2_m(vint32m2_t *, vint32m2_t *, vbool16_t, vint32m2_t, vint32m2_t, const int32_t *, vuint8mf2_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vluxseg2ei8_v)))
void vluxseg2ei8_v_i32m4(vint32m4_t *, vint32m4_t *, const int32_t *, vuint8m1_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vluxseg2ei8_v_m)))
void vluxseg2ei8_v_i32m4_m(vint32m4_t *, vint32m4_t *, vbool8_t, vint32m4_t, vint32m4_t, const int32_t *, vuint8m1_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vluxseg2ei8_v)))
void vluxseg2ei8_v_i32mf2(vint32mf2_t *, vint32mf2_t *, const int32_t *, vuint8mf8_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vluxseg2ei8_v_m)))
void vluxseg2ei8_v_i32mf2_m(vint32mf2_t *, vint32mf2_t *, vbool64_t, vint32mf2_t, vint32mf2_t, const int32_t *, vuint8mf8_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vluxseg2ei8_v)))
void vluxseg2ei8_v_u32m1(vuint32m1_t *, vuint32m1_t *, const uint32_t *, vuint8mf4_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vluxseg2ei8_v_m)))
void vluxseg2ei8_v_u32m1_m(vuint32m1_t *, vuint32m1_t *, vbool32_t, vuint32m1_t, vuint32m1_t, const uint32_t *, vuint8mf4_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vluxseg2ei8_v)))
void vluxseg2ei8_v_u32m2(vuint32m2_t *, vuint32m2_t *, const uint32_t *, vuint8mf2_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vluxseg2ei8_v_m)))
void vluxseg2ei8_v_u32m2_m(vuint32m2_t *, vuint32m2_t *, vbool16_t, vuint32m2_t, vuint32m2_t, const uint32_t *, vuint8mf2_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vluxseg2ei8_v)))
void vluxseg2ei8_v_u32m4(vuint32m4_t *, vuint32m4_t *, const uint32_t *, vuint8m1_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vluxseg2ei8_v_m)))
void vluxseg2ei8_v_u32m4_m(vuint32m4_t *, vuint32m4_t *, vbool8_t, vuint32m4_t, vuint32m4_t, const uint32_t *, vuint8m1_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vluxseg2ei8_v)))
void vluxseg2ei8_v_u32mf2(vuint32mf2_t *, vuint32mf2_t *, const uint32_t *, vuint8mf8_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vluxseg2ei8_v_m)))
void vluxseg2ei8_v_u32mf2_m(vuint32mf2_t *, vuint32mf2_t *, vbool64_t, vuint32mf2_t, vuint32mf2_t, const uint32_t *, vuint8mf8_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vluxseg3ei8_v)))
void vluxseg3ei8_v_i32m1(vint32m1_t *, vint32m1_t *, vint32m1_t *, const int32_t *, vuint8mf4_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vluxseg3ei8_v_m)))
void vluxseg3ei8_v_i32m1_m(vint32m1_t *, vint32m1_t *, vint32m1_t *, vbool32_t, vint32m1_t, vint32m1_t, vint32m1_t, const int32_t *, vuint8mf4_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vluxseg3ei8_v)))
void vluxseg3ei8_v_i32m2(vint32m2_t *, vint32m2_t *, vint32m2_t *, const int32_t *, vuint8mf2_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vluxseg3ei8_v_m)))
void vluxseg3ei8_v_i32m2_m(vint32m2_t *, vint32m2_t *, vint32m2_t *, vbool16_t, vint32m2_t, vint32m2_t, vint32m2_t, const int32_t *, vuint8mf2_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vluxseg3ei8_v)))
void vluxseg3ei8_v_i32mf2(vint32mf2_t *, vint32mf2_t *, vint32mf2_t *, const int32_t *, vuint8mf8_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vluxseg3ei8_v_m)))
void vluxseg3ei8_v_i32mf2_m(vint32mf2_t *, vint32mf2_t *, vint32mf2_t *, vbool64_t, vint32mf2_t, vint32mf2_t, vint32mf2_t, const int32_t *, vuint8mf8_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vluxseg3ei8_v)))
void vluxseg3ei8_v_u32m1(vuint32m1_t *, vuint32m1_t *, vuint32m1_t *, const uint32_t *, vuint8mf4_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vluxseg3ei8_v_m)))
void vluxseg3ei8_v_u32m1_m(vuint32m1_t *, vuint32m1_t *, vuint32m1_t *, vbool32_t, vuint32m1_t, vuint32m1_t, vuint32m1_t, const uint32_t *, vuint8mf4_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vluxseg3ei8_v)))
void vluxseg3ei8_v_u32m2(vuint32m2_t *, vuint32m2_t *, vuint32m2_t *, const uint32_t *, vuint8mf2_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vluxseg3ei8_v_m)))
void vluxseg3ei8_v_u32m2_m(vuint32m2_t *, vuint32m2_t *, vuint32m2_t *, vbool16_t, vuint32m2_t, vuint32m2_t, vuint32m2_t, const uint32_t *, vuint8mf2_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vluxseg3ei8_v)))
void vluxseg3ei8_v_u32mf2(vuint32mf2_t *, vuint32mf2_t *, vuint32mf2_t *, const uint32_t *, vuint8mf8_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vluxseg3ei8_v_m)))
void vluxseg3ei8_v_u32mf2_m(vuint32mf2_t *, vuint32mf2_t *, vuint32mf2_t *, vbool64_t, vuint32mf2_t, vuint32mf2_t, vuint32mf2_t, const uint32_t *, vuint8mf8_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vluxseg4ei8_v)))
void vluxseg4ei8_v_i32m1(vint32m1_t *, vint32m1_t *, vint32m1_t *, vint32m1_t *, const int32_t *, vuint8mf4_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vluxseg4ei8_v_m)))
void vluxseg4ei8_v_i32m1_m(vint32m1_t *, vint32m1_t *, vint32m1_t *, vint32m1_t *, vbool32_t, vint32m1_t, vint32m1_t, vint32m1_t, vint32m1_t, const int32_t *, vuint8mf4_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vluxseg4ei8_v)))
void vluxseg4ei8_v_i32m2(vint32m2_t *, vint32m2_t *, vint32m2_t *, vint32m2_t *, const int32_t *, vuint8mf2_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vluxseg4ei8_v_m)))
void vluxseg4ei8_v_i32m2_m(vint32m2_t *, vint32m2_t *, vint32m2_t *, vint32m2_t *, vbool16_t, vint32m2_t, vint32m2_t, vint32m2_t, vint32m2_t, const int32_t *, vuint8mf2_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vluxseg4ei8_v)))
void vluxseg4ei8_v_i32mf2(vint32mf2_t *, vint32mf2_t *, vint32mf2_t *, vint32mf2_t *, const int32_t *, vuint8mf8_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vluxseg4ei8_v_m)))
void vluxseg4ei8_v_i32mf2_m(vint32mf2_t *, vint32mf2_t *, vint32mf2_t *, vint32mf2_t *, vbool64_t, vint32mf2_t, vint32mf2_t, vint32mf2_t, vint32mf2_t, const int32_t *, vuint8mf8_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vluxseg4ei8_v)))
void vluxseg4ei8_v_u32m1(vuint32m1_t *, vuint32m1_t *, vuint32m1_t *, vuint32m1_t *, const uint32_t *, vuint8mf4_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vluxseg4ei8_v_m)))
void vluxseg4ei8_v_u32m1_m(vuint32m1_t *, vuint32m1_t *, vuint32m1_t *, vuint32m1_t *, vbool32_t, vuint32m1_t, vuint32m1_t, vuint32m1_t, vuint32m1_t, const uint32_t *, vuint8mf4_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vluxseg4ei8_v)))
void vluxseg4ei8_v_u32m2(vuint32m2_t *, vuint32m2_t *, vuint32m2_t *, vuint32m2_t *, const uint32_t *, vuint8mf2_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vluxseg4ei8_v_m)))
void vluxseg4ei8_v_u32m2_m(vuint32m2_t *, vuint32m2_t *, vuint32m2_t *, vuint32m2_t *, vbool16_t, vuint32m2_t, vuint32m2_t, vuint32m2_t, vuint32m2_t, const uint32_t *, vuint8mf2_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vluxseg4ei8_v)))
void vluxseg4ei8_v_u32mf2(vuint32mf2_t *, vuint32mf2_t *, vuint32mf2_t *, vuint32mf2_t *, const uint32_t *, vuint8mf8_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vluxseg4ei8_v_m)))
void vluxseg4ei8_v_u32mf2_m(vuint32mf2_t *, vuint32mf2_t *, vuint32mf2_t *, vuint32mf2_t *, vbool64_t, vuint32mf2_t, vuint32mf2_t, vuint32mf2_t, vuint32mf2_t, const uint32_t *, vuint8mf8_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vluxseg5ei8_v)))
void vluxseg5ei8_v_i32m1(vint32m1_t *, vint32m1_t *, vint32m1_t *, vint32m1_t *, vint32m1_t *, const int32_t *, vuint8mf4_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vluxseg5ei8_v_m)))
void vluxseg5ei8_v_i32m1_m(vint32m1_t *, vint32m1_t *, vint32m1_t *, vint32m1_t *, vint32m1_t *, vbool32_t, vint32m1_t, vint32m1_t, vint32m1_t, vint32m1_t, vint32m1_t, const int32_t *, vuint8mf4_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vluxseg5ei8_v)))
void vluxseg5ei8_v_i32mf2(vint32mf2_t *, vint32mf2_t *, vint32mf2_t *, vint32mf2_t *, vint32mf2_t *, const int32_t *, vuint8mf8_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vluxseg5ei8_v_m)))
void vluxseg5ei8_v_i32mf2_m(vint32mf2_t *, vint32mf2_t *, vint32mf2_t *, vint32mf2_t *, vint32mf2_t *, vbool64_t, vint32mf2_t, vint32mf2_t, vint32mf2_t, vint32mf2_t, vint32mf2_t, const int32_t *, vuint8mf8_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vluxseg5ei8_v)))
void vluxseg5ei8_v_u32m1(vuint32m1_t *, vuint32m1_t *, vuint32m1_t *, vuint32m1_t *, vuint32m1_t *, const uint32_t *, vuint8mf4_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vluxseg5ei8_v_m)))
void vluxseg5ei8_v_u32m1_m(vuint32m1_t *, vuint32m1_t *, vuint32m1_t *, vuint32m1_t *, vuint32m1_t *, vbool32_t, vuint32m1_t, vuint32m1_t, vuint32m1_t, vuint32m1_t, vuint32m1_t, const uint32_t *, vuint8mf4_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vluxseg5ei8_v)))
void vluxseg5ei8_v_u32mf2(vuint32mf2_t *, vuint32mf2_t *, vuint32mf2_t *, vuint32mf2_t *, vuint32mf2_t *, const uint32_t *, vuint8mf8_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vluxseg5ei8_v_m)))
void vluxseg5ei8_v_u32mf2_m(vuint32mf2_t *, vuint32mf2_t *, vuint32mf2_t *, vuint32mf2_t *, vuint32mf2_t *, vbool64_t, vuint32mf2_t, vuint32mf2_t, vuint32mf2_t, vuint32mf2_t, vuint32mf2_t, const uint32_t *, vuint8mf8_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vluxseg6ei8_v)))
void vluxseg6ei8_v_i32m1(vint32m1_t *, vint32m1_t *, vint32m1_t *, vint32m1_t *, vint32m1_t *, vint32m1_t *, const int32_t *, vuint8mf4_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vluxseg6ei8_v_m)))
void vluxseg6ei8_v_i32m1_m(vint32m1_t *, vint32m1_t *, vint32m1_t *, vint32m1_t *, vint32m1_t *, vint32m1_t *, vbool32_t, vint32m1_t, vint32m1_t, vint32m1_t, vint32m1_t, vint32m1_t, vint32m1_t, const int32_t *, vuint8mf4_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vluxseg6ei8_v)))
void vluxseg6ei8_v_i32mf2(vint32mf2_t *, vint32mf2_t *, vint32mf2_t *, vint32mf2_t *, vint32mf2_t *, vint32mf2_t *, const int32_t *, vuint8mf8_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vluxseg6ei8_v_m)))
void vluxseg6ei8_v_i32mf2_m(vint32mf2_t *, vint32mf2_t *, vint32mf2_t *, vint32mf2_t *, vint32mf2_t *, vint32mf2_t *, vbool64_t, vint32mf2_t, vint32mf2_t, vint32mf2_t, vint32mf2_t, vint32mf2_t, vint32mf2_t, const int32_t *, vuint8mf8_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vluxseg6ei8_v)))
void vluxseg6ei8_v_u32m1(vuint32m1_t *, vuint32m1_t *, vuint32m1_t *, vuint32m1_t *, vuint32m1_t *, vuint32m1_t *, const uint32_t *, vuint8mf4_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vluxseg6ei8_v_m)))
void vluxseg6ei8_v_u32m1_m(vuint32m1_t *, vuint32m1_t *, vuint32m1_t *, vuint32m1_t *, vuint32m1_t *, vuint32m1_t *, vbool32_t, vuint32m1_t, vuint32m1_t, vuint32m1_t, vuint32m1_t, vuint32m1_t, vuint32m1_t, const uint32_t *, vuint8mf4_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vluxseg6ei8_v)))
void vluxseg6ei8_v_u32mf2(vuint32mf2_t *, vuint32mf2_t *, vuint32mf2_t *, vuint32mf2_t *, vuint32mf2_t *, vuint32mf2_t *, const uint32_t *, vuint8mf8_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vluxseg6ei8_v_m)))
void vluxseg6ei8_v_u32mf2_m(vuint32mf2_t *, vuint32mf2_t *, vuint32mf2_t *, vuint32mf2_t *, vuint32mf2_t *, vuint32mf2_t *, vbool64_t, vuint32mf2_t, vuint32mf2_t, vuint32mf2_t, vuint32mf2_t, vuint32mf2_t, vuint32mf2_t, const uint32_t *, vuint8mf8_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vluxseg7ei8_v)))
void vluxseg7ei8_v_i32m1(vint32m1_t *, vint32m1_t *, vint32m1_t *, vint32m1_t *, vint32m1_t *, vint32m1_t *, vint32m1_t *, const int32_t *, vuint8mf4_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vluxseg7ei8_v_m)))
void vluxseg7ei8_v_i32m1_m(vint32m1_t *, vint32m1_t *, vint32m1_t *, vint32m1_t *, vint32m1_t *, vint32m1_t *, vint32m1_t *, vbool32_t, vint32m1_t, vint32m1_t, vint32m1_t, vint32m1_t, vint32m1_t, vint32m1_t, vint32m1_t, const int32_t *, vuint8mf4_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vluxseg7ei8_v)))
void vluxseg7ei8_v_i32mf2(vint32mf2_t *, vint32mf2_t *, vint32mf2_t *, vint32mf2_t *, vint32mf2_t *, vint32mf2_t *, vint32mf2_t *, const int32_t *, vuint8mf8_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vluxseg7ei8_v_m)))
void vluxseg7ei8_v_i32mf2_m(vint32mf2_t *, vint32mf2_t *, vint32mf2_t *, vint32mf2_t *, vint32mf2_t *, vint32mf2_t *, vint32mf2_t *, vbool64_t, vint32mf2_t, vint32mf2_t, vint32mf2_t, vint32mf2_t, vint32mf2_t, vint32mf2_t, vint32mf2_t, const int32_t *, vuint8mf8_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vluxseg7ei8_v)))
void vluxseg7ei8_v_u32m1(vuint32m1_t *, vuint32m1_t *, vuint32m1_t *, vuint32m1_t *, vuint32m1_t *, vuint32m1_t *, vuint32m1_t *, const uint32_t *, vuint8mf4_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vluxseg7ei8_v_m)))
void vluxseg7ei8_v_u32m1_m(vuint32m1_t *, vuint32m1_t *, vuint32m1_t *, vuint32m1_t *, vuint32m1_t *, vuint32m1_t *, vuint32m1_t *, vbool32_t, vuint32m1_t, vuint32m1_t, vuint32m1_t, vuint32m1_t, vuint32m1_t, vuint32m1_t, vuint32m1_t, const uint32_t *, vuint8mf4_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vluxseg7ei8_v)))
void vluxseg7ei8_v_u32mf2(vuint32mf2_t *, vuint32mf2_t *, vuint32mf2_t *, vuint32mf2_t *, vuint32mf2_t *, vuint32mf2_t *, vuint32mf2_t *, const uint32_t *, vuint8mf8_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vluxseg7ei8_v_m)))
void vluxseg7ei8_v_u32mf2_m(vuint32mf2_t *, vuint32mf2_t *, vuint32mf2_t *, vuint32mf2_t *, vuint32mf2_t *, vuint32mf2_t *, vuint32mf2_t *, vbool64_t, vuint32mf2_t, vuint32mf2_t, vuint32mf2_t, vuint32mf2_t, vuint32mf2_t, vuint32mf2_t, vuint32mf2_t, const uint32_t *, vuint8mf8_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vluxseg8ei8_v)))
void vluxseg8ei8_v_i32m1(vint32m1_t *, vint32m1_t *, vint32m1_t *, vint32m1_t *, vint32m1_t *, vint32m1_t *, vint32m1_t *, vint32m1_t *, const int32_t *, vuint8mf4_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vluxseg8ei8_v_m)))
void vluxseg8ei8_v_i32m1_m(vint32m1_t *, vint32m1_t *, vint32m1_t *, vint32m1_t *, vint32m1_t *, vint32m1_t *, vint32m1_t *, vint32m1_t *, vbool32_t, vint32m1_t, vint32m1_t, vint32m1_t, vint32m1_t, vint32m1_t, vint32m1_t, vint32m1_t, vint32m1_t, const int32_t *, vuint8mf4_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vluxseg8ei8_v)))
void vluxseg8ei8_v_i32mf2(vint32mf2_t *, vint32mf2_t *, vint32mf2_t *, vint32mf2_t *, vint32mf2_t *, vint32mf2_t *, vint32mf2_t *, vint32mf2_t *, const int32_t *, vuint8mf8_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vluxseg8ei8_v_m)))
void vluxseg8ei8_v_i32mf2_m(vint32mf2_t *, vint32mf2_t *, vint32mf2_t *, vint32mf2_t *, vint32mf2_t *, vint32mf2_t *, vint32mf2_t *, vint32mf2_t *, vbool64_t, vint32mf2_t, vint32mf2_t, vint32mf2_t, vint32mf2_t, vint32mf2_t, vint32mf2_t, vint32mf2_t, vint32mf2_t, const int32_t *, vuint8mf8_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vluxseg8ei8_v)))
void vluxseg8ei8_v_u32m1(vuint32m1_t *, vuint32m1_t *, vuint32m1_t *, vuint32m1_t *, vuint32m1_t *, vuint32m1_t *, vuint32m1_t *, vuint32m1_t *, const uint32_t *, vuint8mf4_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vluxseg8ei8_v_m)))
void vluxseg8ei8_v_u32m1_m(vuint32m1_t *, vuint32m1_t *, vuint32m1_t *, vuint32m1_t *, vuint32m1_t *, vuint32m1_t *, vuint32m1_t *, vuint32m1_t *, vbool32_t, vuint32m1_t, vuint32m1_t, vuint32m1_t, vuint32m1_t, vuint32m1_t, vuint32m1_t, vuint32m1_t, vuint32m1_t, const uint32_t *, vuint8mf4_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vluxseg8ei8_v)))
void vluxseg8ei8_v_u32mf2(vuint32mf2_t *, vuint32mf2_t *, vuint32mf2_t *, vuint32mf2_t *, vuint32mf2_t *, vuint32mf2_t *, vuint32mf2_t *, vuint32mf2_t *, const uint32_t *, vuint8mf8_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vluxseg8ei8_v_m)))
void vluxseg8ei8_v_u32mf2_m(vuint32mf2_t *, vuint32mf2_t *, vuint32mf2_t *, vuint32mf2_t *, vuint32mf2_t *, vuint32mf2_t *, vuint32mf2_t *, vuint32mf2_t *, vbool64_t, vuint32mf2_t, vuint32mf2_t, vuint32mf2_t, vuint32mf2_t, vuint32mf2_t, vuint32mf2_t, vuint32mf2_t, vuint32mf2_t, const uint32_t *, vuint8mf8_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vluxseg2ei16_v)))
void vluxseg2ei16_v_i32m1(vint32m1_t *, vint32m1_t *, const int32_t *, vuint16mf2_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vluxseg2ei16_v_m)))
void vluxseg2ei16_v_i32m1_m(vint32m1_t *, vint32m1_t *, vbool32_t, vint32m1_t, vint32m1_t, const int32_t *, vuint16mf2_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vluxseg2ei16_v)))
void vluxseg2ei16_v_i32m2(vint32m2_t *, vint32m2_t *, const int32_t *, vuint16m1_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vluxseg2ei16_v_m)))
void vluxseg2ei16_v_i32m2_m(vint32m2_t *, vint32m2_t *, vbool16_t, vint32m2_t, vint32m2_t, const int32_t *, vuint16m1_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vluxseg2ei16_v)))
void vluxseg2ei16_v_i32m4(vint32m4_t *, vint32m4_t *, const int32_t *, vuint16m2_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vluxseg2ei16_v_m)))
void vluxseg2ei16_v_i32m4_m(vint32m4_t *, vint32m4_t *, vbool8_t, vint32m4_t, vint32m4_t, const int32_t *, vuint16m2_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vluxseg2ei16_v)))
void vluxseg2ei16_v_i32mf2(vint32mf2_t *, vint32mf2_t *, const int32_t *, vuint16mf4_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vluxseg2ei16_v_m)))
void vluxseg2ei16_v_i32mf2_m(vint32mf2_t *, vint32mf2_t *, vbool64_t, vint32mf2_t, vint32mf2_t, const int32_t *, vuint16mf4_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vluxseg2ei16_v)))
void vluxseg2ei16_v_u32m1(vuint32m1_t *, vuint32m1_t *, const uint32_t *, vuint16mf2_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vluxseg2ei16_v_m)))
void vluxseg2ei16_v_u32m1_m(vuint32m1_t *, vuint32m1_t *, vbool32_t, vuint32m1_t, vuint32m1_t, const uint32_t *, vuint16mf2_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vluxseg2ei16_v)))
void vluxseg2ei16_v_u32m2(vuint32m2_t *, vuint32m2_t *, const uint32_t *, vuint16m1_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vluxseg2ei16_v_m)))
void vluxseg2ei16_v_u32m2_m(vuint32m2_t *, vuint32m2_t *, vbool16_t, vuint32m2_t, vuint32m2_t, const uint32_t *, vuint16m1_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vluxseg2ei16_v)))
void vluxseg2ei16_v_u32m4(vuint32m4_t *, vuint32m4_t *, const uint32_t *, vuint16m2_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vluxseg2ei16_v_m)))
void vluxseg2ei16_v_u32m4_m(vuint32m4_t *, vuint32m4_t *, vbool8_t, vuint32m4_t, vuint32m4_t, const uint32_t *, vuint16m2_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vluxseg2ei16_v)))
void vluxseg2ei16_v_u32mf2(vuint32mf2_t *, vuint32mf2_t *, const uint32_t *, vuint16mf4_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vluxseg2ei16_v_m)))
void vluxseg2ei16_v_u32mf2_m(vuint32mf2_t *, vuint32mf2_t *, vbool64_t, vuint32mf2_t, vuint32mf2_t, const uint32_t *, vuint16mf4_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vluxseg3ei16_v)))
void vluxseg3ei16_v_i32m1(vint32m1_t *, vint32m1_t *, vint32m1_t *, const int32_t *, vuint16mf2_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vluxseg3ei16_v_m)))
void vluxseg3ei16_v_i32m1_m(vint32m1_t *, vint32m1_t *, vint32m1_t *, vbool32_t, vint32m1_t, vint32m1_t, vint32m1_t, const int32_t *, vuint16mf2_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vluxseg3ei16_v)))
void vluxseg3ei16_v_i32m2(vint32m2_t *, vint32m2_t *, vint32m2_t *, const int32_t *, vuint16m1_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vluxseg3ei16_v_m)))
void vluxseg3ei16_v_i32m2_m(vint32m2_t *, vint32m2_t *, vint32m2_t *, vbool16_t, vint32m2_t, vint32m2_t, vint32m2_t, const int32_t *, vuint16m1_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vluxseg3ei16_v)))
void vluxseg3ei16_v_i32mf2(vint32mf2_t *, vint32mf2_t *, vint32mf2_t *, const int32_t *, vuint16mf4_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vluxseg3ei16_v_m)))
void vluxseg3ei16_v_i32mf2_m(vint32mf2_t *, vint32mf2_t *, vint32mf2_t *, vbool64_t, vint32mf2_t, vint32mf2_t, vint32mf2_t, const int32_t *, vuint16mf4_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vluxseg3ei16_v)))
void vluxseg3ei16_v_u32m1(vuint32m1_t *, vuint32m1_t *, vuint32m1_t *, const uint32_t *, vuint16mf2_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vluxseg3ei16_v_m)))
void vluxseg3ei16_v_u32m1_m(vuint32m1_t *, vuint32m1_t *, vuint32m1_t *, vbool32_t, vuint32m1_t, vuint32m1_t, vuint32m1_t, const uint32_t *, vuint16mf2_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vluxseg3ei16_v)))
void vluxseg3ei16_v_u32m2(vuint32m2_t *, vuint32m2_t *, vuint32m2_t *, const uint32_t *, vuint16m1_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vluxseg3ei16_v_m)))
void vluxseg3ei16_v_u32m2_m(vuint32m2_t *, vuint32m2_t *, vuint32m2_t *, vbool16_t, vuint32m2_t, vuint32m2_t, vuint32m2_t, const uint32_t *, vuint16m1_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vluxseg3ei16_v)))
void vluxseg3ei16_v_u32mf2(vuint32mf2_t *, vuint32mf2_t *, vuint32mf2_t *, const uint32_t *, vuint16mf4_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vluxseg3ei16_v_m)))
void vluxseg3ei16_v_u32mf2_m(vuint32mf2_t *, vuint32mf2_t *, vuint32mf2_t *, vbool64_t, vuint32mf2_t, vuint32mf2_t, vuint32mf2_t, const uint32_t *, vuint16mf4_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vluxseg4ei16_v)))
void vluxseg4ei16_v_i32m1(vint32m1_t *, vint32m1_t *, vint32m1_t *, vint32m1_t *, const int32_t *, vuint16mf2_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vluxseg4ei16_v_m)))
void vluxseg4ei16_v_i32m1_m(vint32m1_t *, vint32m1_t *, vint32m1_t *, vint32m1_t *, vbool32_t, vint32m1_t, vint32m1_t, vint32m1_t, vint32m1_t, const int32_t *, vuint16mf2_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vluxseg4ei16_v)))
void vluxseg4ei16_v_i32m2(vint32m2_t *, vint32m2_t *, vint32m2_t *, vint32m2_t *, const int32_t *, vuint16m1_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vluxseg4ei16_v_m)))
void vluxseg4ei16_v_i32m2_m(vint32m2_t *, vint32m2_t *, vint32m2_t *, vint32m2_t *, vbool16_t, vint32m2_t, vint32m2_t, vint32m2_t, vint32m2_t, const int32_t *, vuint16m1_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vluxseg4ei16_v)))
void vluxseg4ei16_v_i32mf2(vint32mf2_t *, vint32mf2_t *, vint32mf2_t *, vint32mf2_t *, const int32_t *, vuint16mf4_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vluxseg4ei16_v_m)))
void vluxseg4ei16_v_i32mf2_m(vint32mf2_t *, vint32mf2_t *, vint32mf2_t *, vint32mf2_t *, vbool64_t, vint32mf2_t, vint32mf2_t, vint32mf2_t, vint32mf2_t, const int32_t *, vuint16mf4_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vluxseg4ei16_v)))
void vluxseg4ei16_v_u32m1(vuint32m1_t *, vuint32m1_t *, vuint32m1_t *, vuint32m1_t *, const uint32_t *, vuint16mf2_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vluxseg4ei16_v_m)))
void vluxseg4ei16_v_u32m1_m(vuint32m1_t *, vuint32m1_t *, vuint32m1_t *, vuint32m1_t *, vbool32_t, vuint32m1_t, vuint32m1_t, vuint32m1_t, vuint32m1_t, const uint32_t *, vuint16mf2_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vluxseg4ei16_v)))
void vluxseg4ei16_v_u32m2(vuint32m2_t *, vuint32m2_t *, vuint32m2_t *, vuint32m2_t *, const uint32_t *, vuint16m1_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vluxseg4ei16_v_m)))
void vluxseg4ei16_v_u32m2_m(vuint32m2_t *, vuint32m2_t *, vuint32m2_t *, vuint32m2_t *, vbool16_t, vuint32m2_t, vuint32m2_t, vuint32m2_t, vuint32m2_t, const uint32_t *, vuint16m1_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vluxseg4ei16_v)))
void vluxseg4ei16_v_u32mf2(vuint32mf2_t *, vuint32mf2_t *, vuint32mf2_t *, vuint32mf2_t *, const uint32_t *, vuint16mf4_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vluxseg4ei16_v_m)))
void vluxseg4ei16_v_u32mf2_m(vuint32mf2_t *, vuint32mf2_t *, vuint32mf2_t *, vuint32mf2_t *, vbool64_t, vuint32mf2_t, vuint32mf2_t, vuint32mf2_t, vuint32mf2_t, const uint32_t *, vuint16mf4_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vluxseg5ei16_v)))
void vluxseg5ei16_v_i32m1(vint32m1_t *, vint32m1_t *, vint32m1_t *, vint32m1_t *, vint32m1_t *, const int32_t *, vuint16mf2_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vluxseg5ei16_v_m)))
void vluxseg5ei16_v_i32m1_m(vint32m1_t *, vint32m1_t *, vint32m1_t *, vint32m1_t *, vint32m1_t *, vbool32_t, vint32m1_t, vint32m1_t, vint32m1_t, vint32m1_t, vint32m1_t, const int32_t *, vuint16mf2_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vluxseg5ei16_v)))
void vluxseg5ei16_v_i32mf2(vint32mf2_t *, vint32mf2_t *, vint32mf2_t *, vint32mf2_t *, vint32mf2_t *, const int32_t *, vuint16mf4_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vluxseg5ei16_v_m)))
void vluxseg5ei16_v_i32mf2_m(vint32mf2_t *, vint32mf2_t *, vint32mf2_t *, vint32mf2_t *, vint32mf2_t *, vbool64_t, vint32mf2_t, vint32mf2_t, vint32mf2_t, vint32mf2_t, vint32mf2_t, const int32_t *, vuint16mf4_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vluxseg5ei16_v)))
void vluxseg5ei16_v_u32m1(vuint32m1_t *, vuint32m1_t *, vuint32m1_t *, vuint32m1_t *, vuint32m1_t *, const uint32_t *, vuint16mf2_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vluxseg5ei16_v_m)))
void vluxseg5ei16_v_u32m1_m(vuint32m1_t *, vuint32m1_t *, vuint32m1_t *, vuint32m1_t *, vuint32m1_t *, vbool32_t, vuint32m1_t, vuint32m1_t, vuint32m1_t, vuint32m1_t, vuint32m1_t, const uint32_t *, vuint16mf2_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vluxseg5ei16_v)))
void vluxseg5ei16_v_u32mf2(vuint32mf2_t *, vuint32mf2_t *, vuint32mf2_t *, vuint32mf2_t *, vuint32mf2_t *, const uint32_t *, vuint16mf4_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vluxseg5ei16_v_m)))
void vluxseg5ei16_v_u32mf2_m(vuint32mf2_t *, vuint32mf2_t *, vuint32mf2_t *, vuint32mf2_t *, vuint32mf2_t *, vbool64_t, vuint32mf2_t, vuint32mf2_t, vuint32mf2_t, vuint32mf2_t, vuint32mf2_t, const uint32_t *, vuint16mf4_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vluxseg6ei16_v)))
void vluxseg6ei16_v_i32m1(vint32m1_t *, vint32m1_t *, vint32m1_t *, vint32m1_t *, vint32m1_t *, vint32m1_t *, const int32_t *, vuint16mf2_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vluxseg6ei16_v_m)))
void vluxseg6ei16_v_i32m1_m(vint32m1_t *, vint32m1_t *, vint32m1_t *, vint32m1_t *, vint32m1_t *, vint32m1_t *, vbool32_t, vint32m1_t, vint32m1_t, vint32m1_t, vint32m1_t, vint32m1_t, vint32m1_t, const int32_t *, vuint16mf2_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vluxseg6ei16_v)))
void vluxseg6ei16_v_i32mf2(vint32mf2_t *, vint32mf2_t *, vint32mf2_t *, vint32mf2_t *, vint32mf2_t *, vint32mf2_t *, const int32_t *, vuint16mf4_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vluxseg6ei16_v_m)))
void vluxseg6ei16_v_i32mf2_m(vint32mf2_t *, vint32mf2_t *, vint32mf2_t *, vint32mf2_t *, vint32mf2_t *, vint32mf2_t *, vbool64_t, vint32mf2_t, vint32mf2_t, vint32mf2_t, vint32mf2_t, vint32mf2_t, vint32mf2_t, const int32_t *, vuint16mf4_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vluxseg6ei16_v)))
void vluxseg6ei16_v_u32m1(vuint32m1_t *, vuint32m1_t *, vuint32m1_t *, vuint32m1_t *, vuint32m1_t *, vuint32m1_t *, const uint32_t *, vuint16mf2_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vluxseg6ei16_v_m)))
void vluxseg6ei16_v_u32m1_m(vuint32m1_t *, vuint32m1_t *, vuint32m1_t *, vuint32m1_t *, vuint32m1_t *, vuint32m1_t *, vbool32_t, vuint32m1_t, vuint32m1_t, vuint32m1_t, vuint32m1_t, vuint32m1_t, vuint32m1_t, const uint32_t *, vuint16mf2_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vluxseg6ei16_v)))
void vluxseg6ei16_v_u32mf2(vuint32mf2_t *, vuint32mf2_t *, vuint32mf2_t *, vuint32mf2_t *, vuint32mf2_t *, vuint32mf2_t *, const uint32_t *, vuint16mf4_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vluxseg6ei16_v_m)))
void vluxseg6ei16_v_u32mf2_m(vuint32mf2_t *, vuint32mf2_t *, vuint32mf2_t *, vuint32mf2_t *, vuint32mf2_t *, vuint32mf2_t *, vbool64_t, vuint32mf2_t, vuint32mf2_t, vuint32mf2_t, vuint32mf2_t, vuint32mf2_t, vuint32mf2_t, const uint32_t *, vuint16mf4_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vluxseg7ei16_v)))
void vluxseg7ei16_v_i32m1(vint32m1_t *, vint32m1_t *, vint32m1_t *, vint32m1_t *, vint32m1_t *, vint32m1_t *, vint32m1_t *, const int32_t *, vuint16mf2_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vluxseg7ei16_v_m)))
void vluxseg7ei16_v_i32m1_m(vint32m1_t *, vint32m1_t *, vint32m1_t *, vint32m1_t *, vint32m1_t *, vint32m1_t *, vint32m1_t *, vbool32_t, vint32m1_t, vint32m1_t, vint32m1_t, vint32m1_t, vint32m1_t, vint32m1_t, vint32m1_t, const int32_t *, vuint16mf2_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vluxseg7ei16_v)))
void vluxseg7ei16_v_i32mf2(vint32mf2_t *, vint32mf2_t *, vint32mf2_t *, vint32mf2_t *, vint32mf2_t *, vint32mf2_t *, vint32mf2_t *, const int32_t *, vuint16mf4_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vluxseg7ei16_v_m)))
void vluxseg7ei16_v_i32mf2_m(vint32mf2_t *, vint32mf2_t *, vint32mf2_t *, vint32mf2_t *, vint32mf2_t *, vint32mf2_t *, vint32mf2_t *, vbool64_t, vint32mf2_t, vint32mf2_t, vint32mf2_t, vint32mf2_t, vint32mf2_t, vint32mf2_t, vint32mf2_t, const int32_t *, vuint16mf4_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vluxseg7ei16_v)))
void vluxseg7ei16_v_u32m1(vuint32m1_t *, vuint32m1_t *, vuint32m1_t *, vuint32m1_t *, vuint32m1_t *, vuint32m1_t *, vuint32m1_t *, const uint32_t *, vuint16mf2_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vluxseg7ei16_v_m)))
void vluxseg7ei16_v_u32m1_m(vuint32m1_t *, vuint32m1_t *, vuint32m1_t *, vuint32m1_t *, vuint32m1_t *, vuint32m1_t *, vuint32m1_t *, vbool32_t, vuint32m1_t, vuint32m1_t, vuint32m1_t, vuint32m1_t, vuint32m1_t, vuint32m1_t, vuint32m1_t, const uint32_t *, vuint16mf2_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vluxseg7ei16_v)))
void vluxseg7ei16_v_u32mf2(vuint32mf2_t *, vuint32mf2_t *, vuint32mf2_t *, vuint32mf2_t *, vuint32mf2_t *, vuint32mf2_t *, vuint32mf2_t *, const uint32_t *, vuint16mf4_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vluxseg7ei16_v_m)))
void vluxseg7ei16_v_u32mf2_m(vuint32mf2_t *, vuint32mf2_t *, vuint32mf2_t *, vuint32mf2_t *, vuint32mf2_t *, vuint32mf2_t *, vuint32mf2_t *, vbool64_t, vuint32mf2_t, vuint32mf2_t, vuint32mf2_t, vuint32mf2_t, vuint32mf2_t, vuint32mf2_t, vuint32mf2_t, const uint32_t *, vuint16mf4_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vluxseg8ei16_v)))
void vluxseg8ei16_v_i32m1(vint32m1_t *, vint32m1_t *, vint32m1_t *, vint32m1_t *, vint32m1_t *, vint32m1_t *, vint32m1_t *, vint32m1_t *, const int32_t *, vuint16mf2_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vluxseg8ei16_v_m)))
void vluxseg8ei16_v_i32m1_m(vint32m1_t *, vint32m1_t *, vint32m1_t *, vint32m1_t *, vint32m1_t *, vint32m1_t *, vint32m1_t *, vint32m1_t *, vbool32_t, vint32m1_t, vint32m1_t, vint32m1_t, vint32m1_t, vint32m1_t, vint32m1_t, vint32m1_t, vint32m1_t, const int32_t *, vuint16mf2_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vluxseg8ei16_v)))
void vluxseg8ei16_v_i32mf2(vint32mf2_t *, vint32mf2_t *, vint32mf2_t *, vint32mf2_t *, vint32mf2_t *, vint32mf2_t *, vint32mf2_t *, vint32mf2_t *, const int32_t *, vuint16mf4_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vluxseg8ei16_v_m)))
void vluxseg8ei16_v_i32mf2_m(vint32mf2_t *, vint32mf2_t *, vint32mf2_t *, vint32mf2_t *, vint32mf2_t *, vint32mf2_t *, vint32mf2_t *, vint32mf2_t *, vbool64_t, vint32mf2_t, vint32mf2_t, vint32mf2_t, vint32mf2_t, vint32mf2_t, vint32mf2_t, vint32mf2_t, vint32mf2_t, const int32_t *, vuint16mf4_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vssseg2e8_v)))
void vssseg2e8_v_i8m1(int8_t *, ptrdiff_t, vint8m1_t, vint8m1_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vssseg2e8_v_m)))
void vssseg2e8_v_i8m1_m(vbool8_t, int8_t *, ptrdiff_t, vint8m1_t, vint8m1_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vssseg2e8_v)))
void vssseg2e8_v_i8m2(int8_t *, ptrdiff_t, vint8m2_t, vint8m2_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vssseg2e8_v_m)))
void vssseg2e8_v_i8m2_m(vbool4_t, int8_t *, ptrdiff_t, vint8m2_t, vint8m2_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vssseg2e8_v)))
void vssseg2e8_v_i8m4(int8_t *, ptrdiff_t, vint8m4_t, vint8m4_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vssseg2e8_v_m)))
void vssseg2e8_v_i8m4_m(vbool2_t, int8_t *, ptrdiff_t, vint8m4_t, vint8m4_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vssseg2e8_v)))
void vssseg2e8_v_i8mf2(int8_t *, ptrdiff_t, vint8mf2_t, vint8mf2_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vssseg2e8_v_m)))
void vssseg2e8_v_i8mf2_m(vbool16_t, int8_t *, ptrdiff_t, vint8mf2_t, vint8mf2_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vssseg2e8_v)))
void vssseg2e8_v_i8mf4(int8_t *, ptrdiff_t, vint8mf4_t, vint8mf4_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vssseg2e8_v_m)))
void vssseg2e8_v_i8mf4_m(vbool32_t, int8_t *, ptrdiff_t, vint8mf4_t, vint8mf4_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vssseg2e8_v)))
void vssseg2e8_v_i8mf8(int8_t *, ptrdiff_t, vint8mf8_t, vint8mf8_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vssseg2e8_v_m)))
void vssseg2e8_v_i8mf8_m(vbool64_t, int8_t *, ptrdiff_t, vint8mf8_t, vint8mf8_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vluxseg8ei16_v)))
void vluxseg8ei16_v_u32m1(vuint32m1_t *, vuint32m1_t *, vuint32m1_t *, vuint32m1_t *, vuint32m1_t *, vuint32m1_t *, vuint32m1_t *, vuint32m1_t *, const uint32_t *, vuint16mf2_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vluxseg8ei16_v_m)))
void vluxseg8ei16_v_u32m1_m(vuint32m1_t *, vuint32m1_t *, vuint32m1_t *, vuint32m1_t *, vuint32m1_t *, vuint32m1_t *, vuint32m1_t *, vuint32m1_t *, vbool32_t, vuint32m1_t, vuint32m1_t, vuint32m1_t, vuint32m1_t, vuint32m1_t, vuint32m1_t, vuint32m1_t, vuint32m1_t, const uint32_t *, vuint16mf2_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vluxseg8ei16_v)))
void vluxseg8ei16_v_u32mf2(vuint32mf2_t *, vuint32mf2_t *, vuint32mf2_t *, vuint32mf2_t *, vuint32mf2_t *, vuint32mf2_t *, vuint32mf2_t *, vuint32mf2_t *, const uint32_t *, vuint16mf4_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vluxseg8ei16_v_m)))
void vluxseg8ei16_v_u32mf2_m(vuint32mf2_t *, vuint32mf2_t *, vuint32mf2_t *, vuint32mf2_t *, vuint32mf2_t *, vuint32mf2_t *, vuint32mf2_t *, vuint32mf2_t *, vbool64_t, vuint32mf2_t, vuint32mf2_t, vuint32mf2_t, vuint32mf2_t, vuint32mf2_t, vuint32mf2_t, vuint32mf2_t, vuint32mf2_t, const uint32_t *, vuint16mf4_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vluxseg2ei32_v)))
void vluxseg2ei32_v_i32m1(vint32m1_t *, vint32m1_t *, const int32_t *, vuint32m1_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vluxseg2ei32_v_m)))
void vluxseg2ei32_v_i32m1_m(vint32m1_t *, vint32m1_t *, vbool32_t, vint32m1_t, vint32m1_t, const int32_t *, vuint32m1_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vluxseg2ei32_v)))
void vluxseg2ei32_v_i32m2(vint32m2_t *, vint32m2_t *, const int32_t *, vuint32m2_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vluxseg2ei32_v_m)))
void vluxseg2ei32_v_i32m2_m(vint32m2_t *, vint32m2_t *, vbool16_t, vint32m2_t, vint32m2_t, const int32_t *, vuint32m2_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vluxseg2ei32_v)))
void vluxseg2ei32_v_i32m4(vint32m4_t *, vint32m4_t *, const int32_t *, vuint32m4_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vluxseg2ei32_v_m)))
void vluxseg2ei32_v_i32m4_m(vint32m4_t *, vint32m4_t *, vbool8_t, vint32m4_t, vint32m4_t, const int32_t *, vuint32m4_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vluxseg2ei32_v)))
void vluxseg2ei32_v_i32mf2(vint32mf2_t *, vint32mf2_t *, const int32_t *, vuint32mf2_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vluxseg2ei32_v_m)))
void vluxseg2ei32_v_i32mf2_m(vint32mf2_t *, vint32mf2_t *, vbool64_t, vint32mf2_t, vint32mf2_t, const int32_t *, vuint32mf2_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vluxseg2ei32_v)))
void vluxseg2ei32_v_u32m1(vuint32m1_t *, vuint32m1_t *, const uint32_t *, vuint32m1_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vluxseg2ei32_v_m)))
void vluxseg2ei32_v_u32m1_m(vuint32m1_t *, vuint32m1_t *, vbool32_t, vuint32m1_t, vuint32m1_t, const uint32_t *, vuint32m1_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vluxseg2ei32_v)))
void vluxseg2ei32_v_u32m2(vuint32m2_t *, vuint32m2_t *, const uint32_t *, vuint32m2_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vluxseg2ei32_v_m)))
void vluxseg2ei32_v_u32m2_m(vuint32m2_t *, vuint32m2_t *, vbool16_t, vuint32m2_t, vuint32m2_t, const uint32_t *, vuint32m2_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vluxseg2ei32_v)))
void vluxseg2ei32_v_u32m4(vuint32m4_t *, vuint32m4_t *, const uint32_t *, vuint32m4_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vluxseg2ei32_v_m)))
void vluxseg2ei32_v_u32m4_m(vuint32m4_t *, vuint32m4_t *, vbool8_t, vuint32m4_t, vuint32m4_t, const uint32_t *, vuint32m4_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vluxseg2ei32_v)))
void vluxseg2ei32_v_u32mf2(vuint32mf2_t *, vuint32mf2_t *, const uint32_t *, vuint32mf2_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vluxseg2ei32_v_m)))
void vluxseg2ei32_v_u32mf2_m(vuint32mf2_t *, vuint32mf2_t *, vbool64_t, vuint32mf2_t, vuint32mf2_t, const uint32_t *, vuint32mf2_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vluxseg3ei32_v)))
void vluxseg3ei32_v_i32m1(vint32m1_t *, vint32m1_t *, vint32m1_t *, const int32_t *, vuint32m1_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vluxseg3ei32_v_m)))
void vluxseg3ei32_v_i32m1_m(vint32m1_t *, vint32m1_t *, vint32m1_t *, vbool32_t, vint32m1_t, vint32m1_t, vint32m1_t, const int32_t *, vuint32m1_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vluxseg3ei32_v)))
void vluxseg3ei32_v_i32m2(vint32m2_t *, vint32m2_t *, vint32m2_t *, const int32_t *, vuint32m2_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vluxseg3ei32_v_m)))
void vluxseg3ei32_v_i32m2_m(vint32m2_t *, vint32m2_t *, vint32m2_t *, vbool16_t, vint32m2_t, vint32m2_t, vint32m2_t, const int32_t *, vuint32m2_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vluxseg3ei32_v)))
void vluxseg3ei32_v_i32mf2(vint32mf2_t *, vint32mf2_t *, vint32mf2_t *, const int32_t *, vuint32mf2_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vluxseg3ei32_v_m)))
void vluxseg3ei32_v_i32mf2_m(vint32mf2_t *, vint32mf2_t *, vint32mf2_t *, vbool64_t, vint32mf2_t, vint32mf2_t, vint32mf2_t, const int32_t *, vuint32mf2_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vluxseg3ei32_v)))
void vluxseg3ei32_v_u32m1(vuint32m1_t *, vuint32m1_t *, vuint32m1_t *, const uint32_t *, vuint32m1_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vluxseg3ei32_v_m)))
void vluxseg3ei32_v_u32m1_m(vuint32m1_t *, vuint32m1_t *, vuint32m1_t *, vbool32_t, vuint32m1_t, vuint32m1_t, vuint32m1_t, const uint32_t *, vuint32m1_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vluxseg3ei32_v)))
void vluxseg3ei32_v_u32m2(vuint32m2_t *, vuint32m2_t *, vuint32m2_t *, const uint32_t *, vuint32m2_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vluxseg3ei32_v_m)))
void vluxseg3ei32_v_u32m2_m(vuint32m2_t *, vuint32m2_t *, vuint32m2_t *, vbool16_t, vuint32m2_t, vuint32m2_t, vuint32m2_t, const uint32_t *, vuint32m2_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vluxseg3ei32_v)))
void vluxseg3ei32_v_u32mf2(vuint32mf2_t *, vuint32mf2_t *, vuint32mf2_t *, const uint32_t *, vuint32mf2_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vluxseg3ei32_v_m)))
void vluxseg3ei32_v_u32mf2_m(vuint32mf2_t *, vuint32mf2_t *, vuint32mf2_t *, vbool64_t, vuint32mf2_t, vuint32mf2_t, vuint32mf2_t, const uint32_t *, vuint32mf2_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vluxseg4ei32_v)))
void vluxseg4ei32_v_i32m1(vint32m1_t *, vint32m1_t *, vint32m1_t *, vint32m1_t *, const int32_t *, vuint32m1_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vluxseg4ei32_v_m)))
void vluxseg4ei32_v_i32m1_m(vint32m1_t *, vint32m1_t *, vint32m1_t *, vint32m1_t *, vbool32_t, vint32m1_t, vint32m1_t, vint32m1_t, vint32m1_t, const int32_t *, vuint32m1_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vluxseg4ei32_v)))
void vluxseg4ei32_v_i32m2(vint32m2_t *, vint32m2_t *, vint32m2_t *, vint32m2_t *, const int32_t *, vuint32m2_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vluxseg4ei32_v_m)))
void vluxseg4ei32_v_i32m2_m(vint32m2_t *, vint32m2_t *, vint32m2_t *, vint32m2_t *, vbool16_t, vint32m2_t, vint32m2_t, vint32m2_t, vint32m2_t, const int32_t *, vuint32m2_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vluxseg4ei32_v)))
void vluxseg4ei32_v_i32mf2(vint32mf2_t *, vint32mf2_t *, vint32mf2_t *, vint32mf2_t *, const int32_t *, vuint32mf2_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vluxseg4ei32_v_m)))
void vluxseg4ei32_v_i32mf2_m(vint32mf2_t *, vint32mf2_t *, vint32mf2_t *, vint32mf2_t *, vbool64_t, vint32mf2_t, vint32mf2_t, vint32mf2_t, vint32mf2_t, const int32_t *, vuint32mf2_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vluxseg4ei32_v)))
void vluxseg4ei32_v_u32m1(vuint32m1_t *, vuint32m1_t *, vuint32m1_t *, vuint32m1_t *, const uint32_t *, vuint32m1_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vluxseg4ei32_v_m)))
void vluxseg4ei32_v_u32m1_m(vuint32m1_t *, vuint32m1_t *, vuint32m1_t *, vuint32m1_t *, vbool32_t, vuint32m1_t, vuint32m1_t, vuint32m1_t, vuint32m1_t, const uint32_t *, vuint32m1_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vluxseg4ei32_v)))
void vluxseg4ei32_v_u32m2(vuint32m2_t *, vuint32m2_t *, vuint32m2_t *, vuint32m2_t *, const uint32_t *, vuint32m2_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vluxseg4ei32_v_m)))
void vluxseg4ei32_v_u32m2_m(vuint32m2_t *, vuint32m2_t *, vuint32m2_t *, vuint32m2_t *, vbool16_t, vuint32m2_t, vuint32m2_t, vuint32m2_t, vuint32m2_t, const uint32_t *, vuint32m2_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vluxseg4ei32_v)))
void vluxseg4ei32_v_u32mf2(vuint32mf2_t *, vuint32mf2_t *, vuint32mf2_t *, vuint32mf2_t *, const uint32_t *, vuint32mf2_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vluxseg4ei32_v_m)))
void vluxseg4ei32_v_u32mf2_m(vuint32mf2_t *, vuint32mf2_t *, vuint32mf2_t *, vuint32mf2_t *, vbool64_t, vuint32mf2_t, vuint32mf2_t, vuint32mf2_t, vuint32mf2_t, const uint32_t *, vuint32mf2_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vluxseg5ei32_v)))
void vluxseg5ei32_v_i32m1(vint32m1_t *, vint32m1_t *, vint32m1_t *, vint32m1_t *, vint32m1_t *, const int32_t *, vuint32m1_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vluxseg5ei32_v_m)))
void vluxseg5ei32_v_i32m1_m(vint32m1_t *, vint32m1_t *, vint32m1_t *, vint32m1_t *, vint32m1_t *, vbool32_t, vint32m1_t, vint32m1_t, vint32m1_t, vint32m1_t, vint32m1_t, const int32_t *, vuint32m1_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vluxseg5ei32_v)))
void vluxseg5ei32_v_i32mf2(vint32mf2_t *, vint32mf2_t *, vint32mf2_t *, vint32mf2_t *, vint32mf2_t *, const int32_t *, vuint32mf2_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vluxseg5ei32_v_m)))
void vluxseg5ei32_v_i32mf2_m(vint32mf2_t *, vint32mf2_t *, vint32mf2_t *, vint32mf2_t *, vint32mf2_t *, vbool64_t, vint32mf2_t, vint32mf2_t, vint32mf2_t, vint32mf2_t, vint32mf2_t, const int32_t *, vuint32mf2_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vluxseg5ei32_v)))
void vluxseg5ei32_v_u32m1(vuint32m1_t *, vuint32m1_t *, vuint32m1_t *, vuint32m1_t *, vuint32m1_t *, const uint32_t *, vuint32m1_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vluxseg5ei32_v_m)))
void vluxseg5ei32_v_u32m1_m(vuint32m1_t *, vuint32m1_t *, vuint32m1_t *, vuint32m1_t *, vuint32m1_t *, vbool32_t, vuint32m1_t, vuint32m1_t, vuint32m1_t, vuint32m1_t, vuint32m1_t, const uint32_t *, vuint32m1_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vluxseg5ei32_v)))
void vluxseg5ei32_v_u32mf2(vuint32mf2_t *, vuint32mf2_t *, vuint32mf2_t *, vuint32mf2_t *, vuint32mf2_t *, const uint32_t *, vuint32mf2_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vluxseg5ei32_v_m)))
void vluxseg5ei32_v_u32mf2_m(vuint32mf2_t *, vuint32mf2_t *, vuint32mf2_t *, vuint32mf2_t *, vuint32mf2_t *, vbool64_t, vuint32mf2_t, vuint32mf2_t, vuint32mf2_t, vuint32mf2_t, vuint32mf2_t, const uint32_t *, vuint32mf2_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vluxseg6ei32_v)))
void vluxseg6ei32_v_i32m1(vint32m1_t *, vint32m1_t *, vint32m1_t *, vint32m1_t *, vint32m1_t *, vint32m1_t *, const int32_t *, vuint32m1_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vluxseg6ei32_v_m)))
void vluxseg6ei32_v_i32m1_m(vint32m1_t *, vint32m1_t *, vint32m1_t *, vint32m1_t *, vint32m1_t *, vint32m1_t *, vbool32_t, vint32m1_t, vint32m1_t, vint32m1_t, vint32m1_t, vint32m1_t, vint32m1_t, const int32_t *, vuint32m1_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vluxseg6ei32_v)))
void vluxseg6ei32_v_i32mf2(vint32mf2_t *, vint32mf2_t *, vint32mf2_t *, vint32mf2_t *, vint32mf2_t *, vint32mf2_t *, const int32_t *, vuint32mf2_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vluxseg6ei32_v_m)))
void vluxseg6ei32_v_i32mf2_m(vint32mf2_t *, vint32mf2_t *, vint32mf2_t *, vint32mf2_t *, vint32mf2_t *, vint32mf2_t *, vbool64_t, vint32mf2_t, vint32mf2_t, vint32mf2_t, vint32mf2_t, vint32mf2_t, vint32mf2_t, const int32_t *, vuint32mf2_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vssseg2e8_v)))
void vssseg2e8_v_u8m1(uint8_t *, ptrdiff_t, vuint8m1_t, vuint8m1_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vssseg2e8_v_m)))
void vssseg2e8_v_u8m1_m(vbool8_t, uint8_t *, ptrdiff_t, vuint8m1_t, vuint8m1_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vssseg2e8_v)))
void vssseg2e8_v_u8m2(uint8_t *, ptrdiff_t, vuint8m2_t, vuint8m2_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vssseg2e8_v_m)))
void vssseg2e8_v_u8m2_m(vbool4_t, uint8_t *, ptrdiff_t, vuint8m2_t, vuint8m2_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vssseg2e8_v)))
void vssseg2e8_v_u8m4(uint8_t *, ptrdiff_t, vuint8m4_t, vuint8m4_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vssseg2e8_v_m)))
void vssseg2e8_v_u8m4_m(vbool2_t, uint8_t *, ptrdiff_t, vuint8m4_t, vuint8m4_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vssseg2e8_v)))
void vssseg2e8_v_u8mf2(uint8_t *, ptrdiff_t, vuint8mf2_t, vuint8mf2_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vssseg2e8_v_m)))
void vssseg2e8_v_u8mf2_m(vbool16_t, uint8_t *, ptrdiff_t, vuint8mf2_t, vuint8mf2_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vssseg2e8_v)))
void vssseg2e8_v_u8mf4(uint8_t *, ptrdiff_t, vuint8mf4_t, vuint8mf4_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vssseg2e8_v_m)))
void vssseg2e8_v_u8mf4_m(vbool32_t, uint8_t *, ptrdiff_t, vuint8mf4_t, vuint8mf4_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vssseg2e8_v)))
void vssseg2e8_v_u8mf8(uint8_t *, ptrdiff_t, vuint8mf8_t, vuint8mf8_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vssseg2e8_v_m)))
void vssseg2e8_v_u8mf8_m(vbool64_t, uint8_t *, ptrdiff_t, vuint8mf8_t, vuint8mf8_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vluxseg6ei32_v)))
void vluxseg6ei32_v_u32m1(vuint32m1_t *, vuint32m1_t *, vuint32m1_t *, vuint32m1_t *, vuint32m1_t *, vuint32m1_t *, const uint32_t *, vuint32m1_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vluxseg6ei32_v_m)))
void vluxseg6ei32_v_u32m1_m(vuint32m1_t *, vuint32m1_t *, vuint32m1_t *, vuint32m1_t *, vuint32m1_t *, vuint32m1_t *, vbool32_t, vuint32m1_t, vuint32m1_t, vuint32m1_t, vuint32m1_t, vuint32m1_t, vuint32m1_t, const uint32_t *, vuint32m1_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vluxseg6ei32_v)))
void vluxseg6ei32_v_u32mf2(vuint32mf2_t *, vuint32mf2_t *, vuint32mf2_t *, vuint32mf2_t *, vuint32mf2_t *, vuint32mf2_t *, const uint32_t *, vuint32mf2_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vluxseg6ei32_v_m)))
void vluxseg6ei32_v_u32mf2_m(vuint32mf2_t *, vuint32mf2_t *, vuint32mf2_t *, vuint32mf2_t *, vuint32mf2_t *, vuint32mf2_t *, vbool64_t, vuint32mf2_t, vuint32mf2_t, vuint32mf2_t, vuint32mf2_t, vuint32mf2_t, vuint32mf2_t, const uint32_t *, vuint32mf2_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vluxseg7ei32_v)))
void vluxseg7ei32_v_i32m1(vint32m1_t *, vint32m1_t *, vint32m1_t *, vint32m1_t *, vint32m1_t *, vint32m1_t *, vint32m1_t *, const int32_t *, vuint32m1_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vluxseg7ei32_v_m)))
void vluxseg7ei32_v_i32m1_m(vint32m1_t *, vint32m1_t *, vint32m1_t *, vint32m1_t *, vint32m1_t *, vint32m1_t *, vint32m1_t *, vbool32_t, vint32m1_t, vint32m1_t, vint32m1_t, vint32m1_t, vint32m1_t, vint32m1_t, vint32m1_t, const int32_t *, vuint32m1_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vluxseg7ei32_v)))
void vluxseg7ei32_v_i32mf2(vint32mf2_t *, vint32mf2_t *, vint32mf2_t *, vint32mf2_t *, vint32mf2_t *, vint32mf2_t *, vint32mf2_t *, const int32_t *, vuint32mf2_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vluxseg7ei32_v_m)))
void vluxseg7ei32_v_i32mf2_m(vint32mf2_t *, vint32mf2_t *, vint32mf2_t *, vint32mf2_t *, vint32mf2_t *, vint32mf2_t *, vint32mf2_t *, vbool64_t, vint32mf2_t, vint32mf2_t, vint32mf2_t, vint32mf2_t, vint32mf2_t, vint32mf2_t, vint32mf2_t, const int32_t *, vuint32mf2_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vluxseg7ei32_v)))
void vluxseg7ei32_v_u32m1(vuint32m1_t *, vuint32m1_t *, vuint32m1_t *, vuint32m1_t *, vuint32m1_t *, vuint32m1_t *, vuint32m1_t *, const uint32_t *, vuint32m1_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vluxseg7ei32_v_m)))
void vluxseg7ei32_v_u32m1_m(vuint32m1_t *, vuint32m1_t *, vuint32m1_t *, vuint32m1_t *, vuint32m1_t *, vuint32m1_t *, vuint32m1_t *, vbool32_t, vuint32m1_t, vuint32m1_t, vuint32m1_t, vuint32m1_t, vuint32m1_t, vuint32m1_t, vuint32m1_t, const uint32_t *, vuint32m1_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vluxseg7ei32_v)))
void vluxseg7ei32_v_u32mf2(vuint32mf2_t *, vuint32mf2_t *, vuint32mf2_t *, vuint32mf2_t *, vuint32mf2_t *, vuint32mf2_t *, vuint32mf2_t *, const uint32_t *, vuint32mf2_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vluxseg7ei32_v_m)))
void vluxseg7ei32_v_u32mf2_m(vuint32mf2_t *, vuint32mf2_t *, vuint32mf2_t *, vuint32mf2_t *, vuint32mf2_t *, vuint32mf2_t *, vuint32mf2_t *, vbool64_t, vuint32mf2_t, vuint32mf2_t, vuint32mf2_t, vuint32mf2_t, vuint32mf2_t, vuint32mf2_t, vuint32mf2_t, const uint32_t *, vuint32mf2_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vluxseg8ei32_v)))
void vluxseg8ei32_v_i32m1(vint32m1_t *, vint32m1_t *, vint32m1_t *, vint32m1_t *, vint32m1_t *, vint32m1_t *, vint32m1_t *, vint32m1_t *, const int32_t *, vuint32m1_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vluxseg8ei32_v_m)))
void vluxseg8ei32_v_i32m1_m(vint32m1_t *, vint32m1_t *, vint32m1_t *, vint32m1_t *, vint32m1_t *, vint32m1_t *, vint32m1_t *, vint32m1_t *, vbool32_t, vint32m1_t, vint32m1_t, vint32m1_t, vint32m1_t, vint32m1_t, vint32m1_t, vint32m1_t, vint32m1_t, const int32_t *, vuint32m1_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vluxseg8ei32_v)))
void vluxseg8ei32_v_i32mf2(vint32mf2_t *, vint32mf2_t *, vint32mf2_t *, vint32mf2_t *, vint32mf2_t *, vint32mf2_t *, vint32mf2_t *, vint32mf2_t *, const int32_t *, vuint32mf2_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vluxseg8ei32_v_m)))
void vluxseg8ei32_v_i32mf2_m(vint32mf2_t *, vint32mf2_t *, vint32mf2_t *, vint32mf2_t *, vint32mf2_t *, vint32mf2_t *, vint32mf2_t *, vint32mf2_t *, vbool64_t, vint32mf2_t, vint32mf2_t, vint32mf2_t, vint32mf2_t, vint32mf2_t, vint32mf2_t, vint32mf2_t, vint32mf2_t, const int32_t *, vuint32mf2_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vluxseg8ei32_v)))
void vluxseg8ei32_v_u32m1(vuint32m1_t *, vuint32m1_t *, vuint32m1_t *, vuint32m1_t *, vuint32m1_t *, vuint32m1_t *, vuint32m1_t *, vuint32m1_t *, const uint32_t *, vuint32m1_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vluxseg8ei32_v_m)))
void vluxseg8ei32_v_u32m1_m(vuint32m1_t *, vuint32m1_t *, vuint32m1_t *, vuint32m1_t *, vuint32m1_t *, vuint32m1_t *, vuint32m1_t *, vuint32m1_t *, vbool32_t, vuint32m1_t, vuint32m1_t, vuint32m1_t, vuint32m1_t, vuint32m1_t, vuint32m1_t, vuint32m1_t, vuint32m1_t, const uint32_t *, vuint32m1_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vluxseg8ei32_v)))
void vluxseg8ei32_v_u32mf2(vuint32mf2_t *, vuint32mf2_t *, vuint32mf2_t *, vuint32mf2_t *, vuint32mf2_t *, vuint32mf2_t *, vuint32mf2_t *, vuint32mf2_t *, const uint32_t *, vuint32mf2_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vluxseg8ei32_v_m)))
void vluxseg8ei32_v_u32mf2_m(vuint32mf2_t *, vuint32mf2_t *, vuint32mf2_t *, vuint32mf2_t *, vuint32mf2_t *, vuint32mf2_t *, vuint32mf2_t *, vuint32mf2_t *, vbool64_t, vuint32mf2_t, vuint32mf2_t, vuint32mf2_t, vuint32mf2_t, vuint32mf2_t, vuint32mf2_t, vuint32mf2_t, vuint32mf2_t, const uint32_t *, vuint32mf2_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vsuxseg2ei8_v)))
void vsuxseg2ei8_v_i8m1(int8_t *, vuint8m1_t, vint8m1_t, vint8m1_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vsuxseg2ei8_v_m)))
void vsuxseg2ei8_v_i8m1_m(vbool8_t, int8_t *, vuint8m1_t, vint8m1_t, vint8m1_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vsuxseg2ei8_v)))
void vsuxseg2ei8_v_i8m2(int8_t *, vuint8m2_t, vint8m2_t, vint8m2_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vsuxseg2ei8_v_m)))
void vsuxseg2ei8_v_i8m2_m(vbool4_t, int8_t *, vuint8m2_t, vint8m2_t, vint8m2_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vsuxseg2ei8_v)))
void vsuxseg2ei8_v_i8m4(int8_t *, vuint8m4_t, vint8m4_t, vint8m4_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vsuxseg2ei8_v_m)))
void vsuxseg2ei8_v_i8m4_m(vbool2_t, int8_t *, vuint8m4_t, vint8m4_t, vint8m4_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vsuxseg2ei8_v)))
void vsuxseg2ei8_v_i8mf2(int8_t *, vuint8mf2_t, vint8mf2_t, vint8mf2_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vsuxseg2ei8_v_m)))
void vsuxseg2ei8_v_i8mf2_m(vbool16_t, int8_t *, vuint8mf2_t, vint8mf2_t, vint8mf2_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vsuxseg2ei8_v)))
void vsuxseg2ei8_v_i8mf4(int8_t *, vuint8mf4_t, vint8mf4_t, vint8mf4_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vsuxseg2ei8_v_m)))
void vsuxseg2ei8_v_i8mf4_m(vbool32_t, int8_t *, vuint8mf4_t, vint8mf4_t, vint8mf4_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vsuxseg2ei8_v)))
void vsuxseg2ei8_v_i8mf8(int8_t *, vuint8mf8_t, vint8mf8_t, vint8mf8_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vsuxseg2ei8_v_m)))
void vsuxseg2ei8_v_i8mf8_m(vbool64_t, int8_t *, vuint8mf8_t, vint8mf8_t, vint8mf8_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vsuxseg2ei8_v)))
void vsuxseg2ei8_v_u8m1(uint8_t *, vuint8m1_t, vuint8m1_t, vuint8m1_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vsuxseg2ei8_v_m)))
void vsuxseg2ei8_v_u8m1_m(vbool8_t, uint8_t *, vuint8m1_t, vuint8m1_t, vuint8m1_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vsuxseg2ei8_v)))
void vsuxseg2ei8_v_u8m2(uint8_t *, vuint8m2_t, vuint8m2_t, vuint8m2_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vsuxseg2ei8_v_m)))
void vsuxseg2ei8_v_u8m2_m(vbool4_t, uint8_t *, vuint8m2_t, vuint8m2_t, vuint8m2_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vsuxseg2ei8_v)))
void vsuxseg2ei8_v_u8m4(uint8_t *, vuint8m4_t, vuint8m4_t, vuint8m4_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vsuxseg2ei8_v_m)))
void vsuxseg2ei8_v_u8m4_m(vbool2_t, uint8_t *, vuint8m4_t, vuint8m4_t, vuint8m4_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vsuxseg2ei8_v)))
void vsuxseg2ei8_v_u8mf2(uint8_t *, vuint8mf2_t, vuint8mf2_t, vuint8mf2_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vsuxseg2ei8_v_m)))
void vsuxseg2ei8_v_u8mf2_m(vbool16_t, uint8_t *, vuint8mf2_t, vuint8mf2_t, vuint8mf2_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vsuxseg2ei8_v)))
void vsuxseg2ei8_v_u8mf4(uint8_t *, vuint8mf4_t, vuint8mf4_t, vuint8mf4_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vsuxseg2ei8_v_m)))
void vsuxseg2ei8_v_u8mf4_m(vbool32_t, uint8_t *, vuint8mf4_t, vuint8mf4_t, vuint8mf4_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vsuxseg2ei8_v)))
void vsuxseg2ei8_v_u8mf8(uint8_t *, vuint8mf8_t, vuint8mf8_t, vuint8mf8_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vsuxseg2ei8_v_m)))
void vsuxseg2ei8_v_u8mf8_m(vbool64_t, uint8_t *, vuint8mf8_t, vuint8mf8_t, vuint8mf8_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vlse8_v)))
vint8m1_t vlse8_v_i8m1(const int8_t *, ptrdiff_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vlse8_v_m)))
vint8m1_t vlse8_v_i8m1_m(vbool8_t, vint8m1_t, const int8_t *, ptrdiff_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vlse8_v)))
vint8m2_t vlse8_v_i8m2(const int8_t *, ptrdiff_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vlse8_v_m)))
vint8m2_t vlse8_v_i8m2_m(vbool4_t, vint8m2_t, const int8_t *, ptrdiff_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vlse8_v)))
vint8m4_t vlse8_v_i8m4(const int8_t *, ptrdiff_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vlse8_v_m)))
vint8m4_t vlse8_v_i8m4_m(vbool2_t, vint8m4_t, const int8_t *, ptrdiff_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vlse8_v)))
vint8m8_t vlse8_v_i8m8(const int8_t *, ptrdiff_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vlse8_v_m)))
vint8m8_t vlse8_v_i8m8_m(vbool1_t, vint8m8_t, const int8_t *, ptrdiff_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vlse8_v)))
vint8mf2_t vlse8_v_i8mf2(const int8_t *, ptrdiff_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vlse8_v_m)))
vint8mf2_t vlse8_v_i8mf2_m(vbool16_t, vint8mf2_t, const int8_t *, ptrdiff_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vlse8_v)))
vint8mf4_t vlse8_v_i8mf4(const int8_t *, ptrdiff_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vlse8_v_m)))
vint8mf4_t vlse8_v_i8mf4_m(vbool32_t, vint8mf4_t, const int8_t *, ptrdiff_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vlse8_v)))
vint8mf8_t vlse8_v_i8mf8(const int8_t *, ptrdiff_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vlse8_v_m)))
vint8mf8_t vlse8_v_i8mf8_m(vbool64_t, vint8mf8_t, const int8_t *, ptrdiff_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vneg_v)))
vint8m1_t vneg_v_i8m1(vint8m1_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vneg_v_m)))
vint8m1_t vneg_v_i8m1_m(vbool8_t, vint8m1_t, vint8m1_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vneg_v)))
vint8m2_t vneg_v_i8m2(vint8m2_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vneg_v_m)))
vint8m2_t vneg_v_i8m2_m(vbool4_t, vint8m2_t, vint8m2_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vneg_v)))
vint8m4_t vneg_v_i8m4(vint8m4_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vneg_v_m)))
vint8m4_t vneg_v_i8m4_m(vbool2_t, vint8m4_t, vint8m4_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vneg_v)))
vint8m8_t vneg_v_i8m8(vint8m8_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vneg_v_m)))
vint8m8_t vneg_v_i8m8_m(vbool1_t, vint8m8_t, vint8m8_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vneg_v)))
vint8mf2_t vneg_v_i8mf2(vint8mf2_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vneg_v_m)))
vint8mf2_t vneg_v_i8mf2_m(vbool16_t, vint8mf2_t, vint8mf2_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vneg_v)))
vint8mf4_t vneg_v_i8mf4(vint8mf4_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vneg_v_m)))
vint8mf4_t vneg_v_i8mf4_m(vbool32_t, vint8mf4_t, vint8mf4_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vneg_v)))
vint8mf8_t vneg_v_i8mf8(vint8mf8_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vneg_v_m)))
vint8mf8_t vneg_v_i8mf8_m(vbool64_t, vint8mf8_t, vint8mf8_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vneg_v)))
vint16m1_t vneg_v_i16m1(vint16m1_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vneg_v_m)))
vint16m1_t vneg_v_i16m1_m(vbool16_t, vint16m1_t, vint16m1_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vneg_v)))
vint16m2_t vneg_v_i16m2(vint16m2_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vneg_v_m)))
vint16m2_t vneg_v_i16m2_m(vbool8_t, vint16m2_t, vint16m2_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vneg_v)))
vint16m4_t vneg_v_i16m4(vint16m4_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vneg_v_m)))
vint16m4_t vneg_v_i16m4_m(vbool4_t, vint16m4_t, vint16m4_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vneg_v)))
vint16m8_t vneg_v_i16m8(vint16m8_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vneg_v_m)))
vint16m8_t vneg_v_i16m8_m(vbool2_t, vint16m8_t, vint16m8_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vneg_v)))
vint16mf2_t vneg_v_i16mf2(vint16mf2_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vneg_v_m)))
vint16mf2_t vneg_v_i16mf2_m(vbool32_t, vint16mf2_t, vint16mf2_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vneg_v)))
vint16mf4_t vneg_v_i16mf4(vint16mf4_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vneg_v_m)))
vint16mf4_t vneg_v_i16mf4_m(vbool64_t, vint16mf4_t, vint16mf4_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vneg_v)))
vint32m1_t vneg_v_i32m1(vint32m1_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vneg_v_m)))
vint32m1_t vneg_v_i32m1_m(vbool32_t, vint32m1_t, vint32m1_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vneg_v)))
vint32m2_t vneg_v_i32m2(vint32m2_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vneg_v_m)))
vint32m2_t vneg_v_i32m2_m(vbool16_t, vint32m2_t, vint32m2_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vneg_v)))
vint32m4_t vneg_v_i32m4(vint32m4_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vneg_v_m)))
vint32m4_t vneg_v_i32m4_m(vbool8_t, vint32m4_t, vint32m4_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vneg_v)))
vint32m8_t vneg_v_i32m8(vint32m8_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vneg_v_m)))
vint32m8_t vneg_v_i32m8_m(vbool4_t, vint32m8_t, vint32m8_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vneg_v)))
vint32mf2_t vneg_v_i32mf2(vint32mf2_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vneg_v_m)))
vint32mf2_t vneg_v_i32mf2_m(vbool64_t, vint32mf2_t, vint32mf2_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vnot_v)))
vint8m1_t vnot_v_i8m1(vint8m1_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vnot_v_m)))
vint8m1_t vnot_v_i8m1_m(vbool8_t, vint8m1_t, vint8m1_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vnot_v)))
vint8m2_t vnot_v_i8m2(vint8m2_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vnot_v_m)))
vint8m2_t vnot_v_i8m2_m(vbool4_t, vint8m2_t, vint8m2_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vnot_v)))
vint8m4_t vnot_v_i8m4(vint8m4_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vnot_v_m)))
vint8m4_t vnot_v_i8m4_m(vbool2_t, vint8m4_t, vint8m4_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vnot_v)))
vint8m8_t vnot_v_i8m8(vint8m8_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vnot_v_m)))
vint8m8_t vnot_v_i8m8_m(vbool1_t, vint8m8_t, vint8m8_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vnot_v)))
vint8mf2_t vnot_v_i8mf2(vint8mf2_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vnot_v_m)))
vint8mf2_t vnot_v_i8mf2_m(vbool16_t, vint8mf2_t, vint8mf2_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vnot_v)))
vint8mf4_t vnot_v_i8mf4(vint8mf4_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vnot_v_m)))
vint8mf4_t vnot_v_i8mf4_m(vbool32_t, vint8mf4_t, vint8mf4_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vnot_v)))
vint8mf8_t vnot_v_i8mf8(vint8mf8_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vnot_v_m)))
vint8mf8_t vnot_v_i8mf8_m(vbool64_t, vint8mf8_t, vint8mf8_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vnot_v)))
vint16m1_t vnot_v_i16m1(vint16m1_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vnot_v_m)))
vint16m1_t vnot_v_i16m1_m(vbool16_t, vint16m1_t, vint16m1_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vnot_v)))
vint16m2_t vnot_v_i16m2(vint16m2_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vnot_v_m)))
vint16m2_t vnot_v_i16m2_m(vbool8_t, vint16m2_t, vint16m2_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vnot_v)))
vint16m4_t vnot_v_i16m4(vint16m4_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vnot_v_m)))
vint16m4_t vnot_v_i16m4_m(vbool4_t, vint16m4_t, vint16m4_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vnot_v)))
vint16m8_t vnot_v_i16m8(vint16m8_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vnot_v_m)))
vint16m8_t vnot_v_i16m8_m(vbool2_t, vint16m8_t, vint16m8_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vnot_v)))
vint16mf2_t vnot_v_i16mf2(vint16mf2_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vnot_v_m)))
vint16mf2_t vnot_v_i16mf2_m(vbool32_t, vint16mf2_t, vint16mf2_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vnot_v)))
vint16mf4_t vnot_v_i16mf4(vint16mf4_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vnot_v_m)))
vint16mf4_t vnot_v_i16mf4_m(vbool64_t, vint16mf4_t, vint16mf4_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vnot_v)))
vint32m1_t vnot_v_i32m1(vint32m1_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vnot_v_m)))
vint32m1_t vnot_v_i32m1_m(vbool32_t, vint32m1_t, vint32m1_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vnot_v)))
vint32m2_t vnot_v_i32m2(vint32m2_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vnot_v_m)))
vint32m2_t vnot_v_i32m2_m(vbool16_t, vint32m2_t, vint32m2_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vnot_v)))
vint32m4_t vnot_v_i32m4(vint32m4_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vnot_v_m)))
vint32m4_t vnot_v_i32m4_m(vbool8_t, vint32m4_t, vint32m4_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vnot_v)))
vint32m8_t vnot_v_i32m8(vint32m8_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vnot_v_m)))
vint32m8_t vnot_v_i32m8_m(vbool4_t, vint32m8_t, vint32m8_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vnot_v)))
vint32mf2_t vnot_v_i32mf2(vint32mf2_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vnot_v_m)))
vint32mf2_t vnot_v_i32mf2_m(vbool64_t, vint32mf2_t, vint32mf2_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vnot_v)))
vuint8m1_t vnot_v_u8m1(vuint8m1_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vnot_v_m)))
vuint8m1_t vnot_v_u8m1_m(vbool8_t, vuint8m1_t, vuint8m1_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vnot_v)))
vuint8m2_t vnot_v_u8m2(vuint8m2_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vnot_v_m)))
vuint8m2_t vnot_v_u8m2_m(vbool4_t, vuint8m2_t, vuint8m2_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vnot_v)))
vuint8m4_t vnot_v_u8m4(vuint8m4_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vnot_v_m)))
vuint8m4_t vnot_v_u8m4_m(vbool2_t, vuint8m4_t, vuint8m4_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vnot_v)))
vuint8m8_t vnot_v_u8m8(vuint8m8_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vnot_v_m)))
vuint8m8_t vnot_v_u8m8_m(vbool1_t, vuint8m8_t, vuint8m8_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vnot_v)))
vuint8mf2_t vnot_v_u8mf2(vuint8mf2_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vnot_v_m)))
vuint8mf2_t vnot_v_u8mf2_m(vbool16_t, vuint8mf2_t, vuint8mf2_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vnot_v)))
vuint8mf4_t vnot_v_u8mf4(vuint8mf4_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vnot_v_m)))
vuint8mf4_t vnot_v_u8mf4_m(vbool32_t, vuint8mf4_t, vuint8mf4_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vnot_v)))
vuint8mf8_t vnot_v_u8mf8(vuint8mf8_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vnot_v_m)))
vuint8mf8_t vnot_v_u8mf8_m(vbool64_t, vuint8mf8_t, vuint8mf8_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vnot_v)))
vuint16m1_t vnot_v_u16m1(vuint16m1_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vnot_v_m)))
vuint16m1_t vnot_v_u16m1_m(vbool16_t, vuint16m1_t, vuint16m1_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vnot_v)))
vuint16m2_t vnot_v_u16m2(vuint16m2_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vnot_v_m)))
vuint16m2_t vnot_v_u16m2_m(vbool8_t, vuint16m2_t, vuint16m2_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vnot_v)))
vuint16m4_t vnot_v_u16m4(vuint16m4_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vnot_v_m)))
vuint16m4_t vnot_v_u16m4_m(vbool4_t, vuint16m4_t, vuint16m4_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vnot_v)))
vuint16m8_t vnot_v_u16m8(vuint16m8_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vnot_v_m)))
vuint16m8_t vnot_v_u16m8_m(vbool2_t, vuint16m8_t, vuint16m8_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vnot_v)))
vuint16mf2_t vnot_v_u16mf2(vuint16mf2_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vnot_v_m)))
vuint16mf2_t vnot_v_u16mf2_m(vbool32_t, vuint16mf2_t, vuint16mf2_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vnot_v)))
vuint16mf4_t vnot_v_u16mf4(vuint16mf4_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vnot_v_m)))
vuint16mf4_t vnot_v_u16mf4_m(vbool64_t, vuint16mf4_t, vuint16mf4_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vnot_v)))
vuint32m1_t vnot_v_u32m1(vuint32m1_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vnot_v_m)))
vuint32m1_t vnot_v_u32m1_m(vbool32_t, vuint32m1_t, vuint32m1_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vnot_v)))
vuint32m2_t vnot_v_u32m2(vuint32m2_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vnot_v_m)))
vuint32m2_t vnot_v_u32m2_m(vbool16_t, vuint32m2_t, vuint32m2_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vnot_v)))
vuint32m4_t vnot_v_u32m4(vuint32m4_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vnot_v_m)))
vuint32m4_t vnot_v_u32m4_m(vbool8_t, vuint32m4_t, vuint32m4_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vnot_v)))
vuint32m8_t vnot_v_u32m8(vuint32m8_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vnot_v_m)))
vuint32m8_t vnot_v_u32m8_m(vbool4_t, vuint32m8_t, vuint32m8_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vnot_v)))
vuint32mf2_t vnot_v_u32mf2(vuint32mf2_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vnot_v_m)))
vuint32mf2_t vnot_v_u32mf2_m(vbool64_t, vuint32mf2_t, vuint32mf2_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vmmv_m)))
vbool8_t vmmv_m_b8(vbool8_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vmmv_m)))
vbool4_t vmmv_m_b4(vbool4_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vmmv_m)))
vbool2_t vmmv_m_b2(vbool2_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vmmv_m)))
vbool1_t vmmv_m_b1(vbool1_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vmmv_m)))
vbool16_t vmmv_m_b16(vbool16_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vmmv_m)))
vbool32_t vmmv_m_b32(vbool32_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vmmv_m)))
vbool64_t vmmv_m_b64(vbool64_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vwcvtu_x_x_v)))
vuint16m2_t vwcvtu_x_x_v_u16m2(vuint8m1_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vwcvtu_x_x_v_m)))
vuint16m2_t vwcvtu_x_x_v_u16m2_m(vbool8_t, vuint16m2_t, vuint8m1_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vwcvtu_x_x_v)))
vuint16m4_t vwcvtu_x_x_v_u16m4(vuint8m2_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vwcvtu_x_x_v_m)))
vuint16m4_t vwcvtu_x_x_v_u16m4_m(vbool4_t, vuint16m4_t, vuint8m2_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vwcvtu_x_x_v)))
vuint16m8_t vwcvtu_x_x_v_u16m8(vuint8m4_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vwcvtu_x_x_v_m)))
vuint16m8_t vwcvtu_x_x_v_u16m8_m(vbool2_t, vuint16m8_t, vuint8m4_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vwcvtu_x_x_v)))
vuint16m1_t vwcvtu_x_x_v_u16m1(vuint8mf2_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vwcvtu_x_x_v_m)))
vuint16m1_t vwcvtu_x_x_v_u16m1_m(vbool16_t, vuint16m1_t, vuint8mf2_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vwcvtu_x_x_v)))
vuint16mf2_t vwcvtu_x_x_v_u16mf2(vuint8mf4_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vwcvtu_x_x_v_m)))
vuint16mf2_t vwcvtu_x_x_v_u16mf2_m(vbool32_t, vuint16mf2_t, vuint8mf4_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vwcvtu_x_x_v)))
vuint16mf4_t vwcvtu_x_x_v_u16mf4(vuint8mf8_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vwcvtu_x_x_v_m)))
vuint16mf4_t vwcvtu_x_x_v_u16mf4_m(vbool64_t, vuint16mf4_t, vuint8mf8_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vwcvtu_x_x_v)))
vuint32m2_t vwcvtu_x_x_v_u32m2(vuint16m1_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vwcvtu_x_x_v_m)))
vuint32m2_t vwcvtu_x_x_v_u32m2_m(vbool16_t, vuint32m2_t, vuint16m1_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vwcvtu_x_x_v)))
vuint32m4_t vwcvtu_x_x_v_u32m4(vuint16m2_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vwcvtu_x_x_v_m)))
vuint32m4_t vwcvtu_x_x_v_u32m4_m(vbool8_t, vuint32m4_t, vuint16m2_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vwcvtu_x_x_v)))
vuint32m8_t vwcvtu_x_x_v_u32m8(vuint16m4_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vwcvtu_x_x_v_m)))
vuint32m8_t vwcvtu_x_x_v_u32m8_m(vbool4_t, vuint32m8_t, vuint16m4_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vwcvtu_x_x_v)))
vuint32m1_t vwcvtu_x_x_v_u32m1(vuint16mf2_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vwcvtu_x_x_v_m)))
vuint32m1_t vwcvtu_x_x_v_u32m1_m(vbool32_t, vuint32m1_t, vuint16mf2_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vwcvtu_x_x_v)))
vuint32mf2_t vwcvtu_x_x_v_u32mf2(vuint16mf4_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vwcvtu_x_x_v_m)))
vuint32mf2_t vwcvtu_x_x_v_u32mf2_m(vbool64_t, vuint32mf2_t, vuint16mf4_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vncvt_x_x_w)))
vint8m1_t vncvt_x_x_w_i8m1(vint16m2_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vncvt_x_x_w_m)))
vint8m1_t vncvt_x_x_w_i8m1_m(vbool8_t, vint8m1_t, vint16m2_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vncvt_x_x_w)))
vint8m2_t vncvt_x_x_w_i8m2(vint16m4_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vncvt_x_x_w_m)))
vint8m2_t vncvt_x_x_w_i8m2_m(vbool4_t, vint8m2_t, vint16m4_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vncvt_x_x_w)))
vint8m4_t vncvt_x_x_w_i8m4(vint16m8_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vncvt_x_x_w_m)))
vint8m4_t vncvt_x_x_w_i8m4_m(vbool2_t, vint8m4_t, vint16m8_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vncvt_x_x_w)))
vint8mf2_t vncvt_x_x_w_i8mf2(vint16m1_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vncvt_x_x_w_m)))
vint8mf2_t vncvt_x_x_w_i8mf2_m(vbool16_t, vint8mf2_t, vint16m1_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vncvt_x_x_w)))
vint8mf4_t vncvt_x_x_w_i8mf4(vint16mf2_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vncvt_x_x_w_m)))
vint8mf4_t vncvt_x_x_w_i8mf4_m(vbool32_t, vint8mf4_t, vint16mf2_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vncvt_x_x_w)))
vint8mf8_t vncvt_x_x_w_i8mf8(vint16mf4_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vncvt_x_x_w_m)))
vint8mf8_t vncvt_x_x_w_i8mf8_m(vbool64_t, vint8mf8_t, vint16mf4_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vncvt_x_x_w)))
vint16m1_t vncvt_x_x_w_i16m1(vint32m2_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vncvt_x_x_w_m)))
vint16m1_t vncvt_x_x_w_i16m1_m(vbool16_t, vint16m1_t, vint32m2_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vncvt_x_x_w)))
vint16m2_t vncvt_x_x_w_i16m2(vint32m4_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vncvt_x_x_w_m)))
vint16m2_t vncvt_x_x_w_i16m2_m(vbool8_t, vint16m2_t, vint32m4_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vncvt_x_x_w)))
vint16m4_t vncvt_x_x_w_i16m4(vint32m8_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vncvt_x_x_w_m)))
vint16m4_t vncvt_x_x_w_i16m4_m(vbool4_t, vint16m4_t, vint32m8_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vncvt_x_x_w)))
vint16mf2_t vncvt_x_x_w_i16mf2(vint32m1_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vncvt_x_x_w_m)))
vint16mf2_t vncvt_x_x_w_i16mf2_m(vbool32_t, vint16mf2_t, vint32m1_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vncvt_x_x_w)))
vint16mf4_t vncvt_x_x_w_i16mf4(vint32mf2_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vncvt_x_x_w_m)))
vint16mf4_t vncvt_x_x_w_i16mf4_m(vbool64_t, vint16mf4_t, vint32mf2_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vle16_v)))
vint16m1_t vle16_v_i16m1(const int16_t *, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vle16_v_m)))
vint16m1_t vle16_v_i16m1_m(vbool16_t, vint16m1_t, const int16_t *, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vle16_v)))
vint16m2_t vle16_v_i16m2(const int16_t *, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vle16_v_m)))
vint16m2_t vle16_v_i16m2_m(vbool8_t, vint16m2_t, const int16_t *, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vle16_v)))
vint16m4_t vle16_v_i16m4(const int16_t *, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vle16_v_m)))
vint16m4_t vle16_v_i16m4_m(vbool4_t, vint16m4_t, const int16_t *, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vle16_v)))
vint16m8_t vle16_v_i16m8(const int16_t *, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vle16_v_m)))
vint16m8_t vle16_v_i16m8_m(vbool2_t, vint16m8_t, const int16_t *, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vle16_v)))
vint16mf2_t vle16_v_i16mf2(const int16_t *, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vle16_v_m)))
vint16mf2_t vle16_v_i16mf2_m(vbool32_t, vint16mf2_t, const int16_t *, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vle16_v)))
vint16mf4_t vle16_v_i16mf4(const int16_t *, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vle16_v_m)))
vint16mf4_t vle16_v_i16mf4_m(vbool64_t, vint16mf4_t, const int16_t *, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vle16_v)))
vuint16m1_t vle16_v_u16m1(const uint16_t *, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vle16_v_m)))
vuint16m1_t vle16_v_u16m1_m(vbool16_t, vuint16m1_t, const uint16_t *, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vle16_v)))
vuint16m2_t vle16_v_u16m2(const uint16_t *, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vle16_v_m)))
vuint16m2_t vle16_v_u16m2_m(vbool8_t, vuint16m2_t, const uint16_t *, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vle16_v)))
vuint16m4_t vle16_v_u16m4(const uint16_t *, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vle16_v_m)))
vuint16m4_t vle16_v_u16m4_m(vbool4_t, vuint16m4_t, const uint16_t *, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vle16_v)))
vuint16m8_t vle16_v_u16m8(const uint16_t *, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vle16_v_m)))
vuint16m8_t vle16_v_u16m8_m(vbool2_t, vuint16m8_t, const uint16_t *, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vle16_v)))
vuint16mf2_t vle16_v_u16mf2(const uint16_t *, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vle16_v_m)))
vuint16mf2_t vle16_v_u16mf2_m(vbool32_t, vuint16mf2_t, const uint16_t *, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vle16_v)))
vuint16mf4_t vle16_v_u16mf4(const uint16_t *, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vle16_v_m)))
vuint16mf4_t vle16_v_u16mf4_m(vbool64_t, vuint16mf4_t, const uint16_t *, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vlse8_v)))
vuint8m1_t vlse8_v_u8m1(const uint8_t *, ptrdiff_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vlse8_v_m)))
vuint8m1_t vlse8_v_u8m1_m(vbool8_t, vuint8m1_t, const uint8_t *, ptrdiff_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vlse8_v)))
vuint8m2_t vlse8_v_u8m2(const uint8_t *, ptrdiff_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vlse8_v_m)))
vuint8m2_t vlse8_v_u8m2_m(vbool4_t, vuint8m2_t, const uint8_t *, ptrdiff_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vlse8_v)))
vuint8m4_t vlse8_v_u8m4(const uint8_t *, ptrdiff_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vlse8_v_m)))
vuint8m4_t vlse8_v_u8m4_m(vbool2_t, vuint8m4_t, const uint8_t *, ptrdiff_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vlse8_v)))
vuint8m8_t vlse8_v_u8m8(const uint8_t *, ptrdiff_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vlse8_v_m)))
vuint8m8_t vlse8_v_u8m8_m(vbool1_t, vuint8m8_t, const uint8_t *, ptrdiff_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vlse8_v)))
vuint8mf2_t vlse8_v_u8mf2(const uint8_t *, ptrdiff_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vlse8_v_m)))
vuint8mf2_t vlse8_v_u8mf2_m(vbool16_t, vuint8mf2_t, const uint8_t *, ptrdiff_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vlse8_v)))
vuint8mf4_t vlse8_v_u8mf4(const uint8_t *, ptrdiff_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vlse8_v_m)))
vuint8mf4_t vlse8_v_u8mf4_m(vbool32_t, vuint8mf4_t, const uint8_t *, ptrdiff_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vlse8_v)))
vuint8mf8_t vlse8_v_u8mf8(const uint8_t *, ptrdiff_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vlse8_v_m)))
vuint8mf8_t vlse8_v_u8mf8_m(vbool64_t, vuint8mf8_t, const uint8_t *, ptrdiff_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vle32_v)))
vint32m1_t vle32_v_i32m1(const int32_t *, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vle32_v_m)))
vint32m1_t vle32_v_i32m1_m(vbool32_t, vint32m1_t, const int32_t *, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vle32_v)))
vint32m2_t vle32_v_i32m2(const int32_t *, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vle32_v_m)))
vint32m2_t vle32_v_i32m2_m(vbool16_t, vint32m2_t, const int32_t *, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vle32_v)))
vint32m4_t vle32_v_i32m4(const int32_t *, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vle32_v_m)))
vint32m4_t vle32_v_i32m4_m(vbool8_t, vint32m4_t, const int32_t *, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vle32_v)))
vint32m8_t vle32_v_i32m8(const int32_t *, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vle32_v_m)))
vint32m8_t vle32_v_i32m8_m(vbool4_t, vint32m8_t, const int32_t *, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vle32_v)))
vint32mf2_t vle32_v_i32mf2(const int32_t *, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vle32_v_m)))
vint32mf2_t vle32_v_i32mf2_m(vbool64_t, vint32mf2_t, const int32_t *, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vle32_v)))
vuint32m1_t vle32_v_u32m1(const uint32_t *, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vle32_v_m)))
vuint32m1_t vle32_v_u32m1_m(vbool32_t, vuint32m1_t, const uint32_t *, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vle32_v)))
vuint32m2_t vle32_v_u32m2(const uint32_t *, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vle32_v_m)))
vuint32m2_t vle32_v_u32m2_m(vbool16_t, vuint32m2_t, const uint32_t *, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vle32_v)))
vuint32m4_t vle32_v_u32m4(const uint32_t *, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vle32_v_m)))
vuint32m4_t vle32_v_u32m4_m(vbool8_t, vuint32m4_t, const uint32_t *, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vle32_v)))
vuint32m8_t vle32_v_u32m8(const uint32_t *, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vle32_v_m)))
vuint32m8_t vle32_v_u32m8_m(vbool4_t, vuint32m8_t, const uint32_t *, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vle32_v)))
vuint32mf2_t vle32_v_u32mf2(const uint32_t *, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vle32_v_m)))
vuint32mf2_t vle32_v_u32mf2_m(vbool64_t, vuint32mf2_t, const uint32_t *, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vloxseg2ei8_v)))
void vloxseg2ei8_v_i8m1(vint8m1_t *, vint8m1_t *, const int8_t *, vuint8m1_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vloxseg2ei8_v_m)))
void vloxseg2ei8_v_i8m1_m(vint8m1_t *, vint8m1_t *, vbool8_t, vint8m1_t, vint8m1_t, const int8_t *, vuint8m1_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vloxseg2ei8_v)))
void vloxseg2ei8_v_i8m2(vint8m2_t *, vint8m2_t *, const int8_t *, vuint8m2_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vloxseg2ei8_v_m)))
void vloxseg2ei8_v_i8m2_m(vint8m2_t *, vint8m2_t *, vbool4_t, vint8m2_t, vint8m2_t, const int8_t *, vuint8m2_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vloxseg2ei8_v)))
void vloxseg2ei8_v_i8m4(vint8m4_t *, vint8m4_t *, const int8_t *, vuint8m4_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vloxseg2ei8_v_m)))
void vloxseg2ei8_v_i8m4_m(vint8m4_t *, vint8m4_t *, vbool2_t, vint8m4_t, vint8m4_t, const int8_t *, vuint8m4_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vloxseg2ei8_v)))
void vloxseg2ei8_v_i8mf2(vint8mf2_t *, vint8mf2_t *, const int8_t *, vuint8mf2_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vloxseg2ei8_v_m)))
void vloxseg2ei8_v_i8mf2_m(vint8mf2_t *, vint8mf2_t *, vbool16_t, vint8mf2_t, vint8mf2_t, const int8_t *, vuint8mf2_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vloxseg2ei8_v)))
void vloxseg2ei8_v_i8mf4(vint8mf4_t *, vint8mf4_t *, const int8_t *, vuint8mf4_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vloxseg2ei8_v_m)))
void vloxseg2ei8_v_i8mf4_m(vint8mf4_t *, vint8mf4_t *, vbool32_t, vint8mf4_t, vint8mf4_t, const int8_t *, vuint8mf4_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vloxseg2ei8_v)))
void vloxseg2ei8_v_i8mf8(vint8mf8_t *, vint8mf8_t *, const int8_t *, vuint8mf8_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vloxseg2ei8_v_m)))
void vloxseg2ei8_v_i8mf8_m(vint8mf8_t *, vint8mf8_t *, vbool64_t, vint8mf8_t, vint8mf8_t, const int8_t *, vuint8mf8_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vloxseg2ei8_v)))
void vloxseg2ei8_v_u8m1(vuint8m1_t *, vuint8m1_t *, const uint8_t *, vuint8m1_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vloxseg2ei8_v_m)))
void vloxseg2ei8_v_u8m1_m(vuint8m1_t *, vuint8m1_t *, vbool8_t, vuint8m1_t, vuint8m1_t, const uint8_t *, vuint8m1_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vloxseg2ei8_v)))
void vloxseg2ei8_v_u8m2(vuint8m2_t *, vuint8m2_t *, const uint8_t *, vuint8m2_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vloxseg2ei8_v_m)))
void vloxseg2ei8_v_u8m2_m(vuint8m2_t *, vuint8m2_t *, vbool4_t, vuint8m2_t, vuint8m2_t, const uint8_t *, vuint8m2_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vloxseg2ei8_v)))
void vloxseg2ei8_v_u8m4(vuint8m4_t *, vuint8m4_t *, const uint8_t *, vuint8m4_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vloxseg2ei8_v_m)))
void vloxseg2ei8_v_u8m4_m(vuint8m4_t *, vuint8m4_t *, vbool2_t, vuint8m4_t, vuint8m4_t, const uint8_t *, vuint8m4_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vloxseg2ei8_v)))
void vloxseg2ei8_v_u8mf2(vuint8mf2_t *, vuint8mf2_t *, const uint8_t *, vuint8mf2_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vloxseg2ei8_v_m)))
void vloxseg2ei8_v_u8mf2_m(vuint8mf2_t *, vuint8mf2_t *, vbool16_t, vuint8mf2_t, vuint8mf2_t, const uint8_t *, vuint8mf2_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vloxseg2ei8_v)))
void vloxseg2ei8_v_u8mf4(vuint8mf4_t *, vuint8mf4_t *, const uint8_t *, vuint8mf4_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vloxseg2ei8_v_m)))
void vloxseg2ei8_v_u8mf4_m(vuint8mf4_t *, vuint8mf4_t *, vbool32_t, vuint8mf4_t, vuint8mf4_t, const uint8_t *, vuint8mf4_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vloxseg2ei8_v)))
void vloxseg2ei8_v_u8mf8(vuint8mf8_t *, vuint8mf8_t *, const uint8_t *, vuint8mf8_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vloxseg2ei8_v_m)))
void vloxseg2ei8_v_u8mf8_m(vuint8mf8_t *, vuint8mf8_t *, vbool64_t, vuint8mf8_t, vuint8mf8_t, const uint8_t *, vuint8mf8_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vloxseg3ei8_v)))
void vloxseg3ei8_v_i8m1(vint8m1_t *, vint8m1_t *, vint8m1_t *, const int8_t *, vuint8m1_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vloxseg3ei8_v_m)))
void vloxseg3ei8_v_i8m1_m(vint8m1_t *, vint8m1_t *, vint8m1_t *, vbool8_t, vint8m1_t, vint8m1_t, vint8m1_t, const int8_t *, vuint8m1_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vloxseg3ei8_v)))
void vloxseg3ei8_v_i8m2(vint8m2_t *, vint8m2_t *, vint8m2_t *, const int8_t *, vuint8m2_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vloxseg3ei8_v_m)))
void vloxseg3ei8_v_i8m2_m(vint8m2_t *, vint8m2_t *, vint8m2_t *, vbool4_t, vint8m2_t, vint8m2_t, vint8m2_t, const int8_t *, vuint8m2_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vloxseg3ei8_v)))
void vloxseg3ei8_v_i8mf2(vint8mf2_t *, vint8mf2_t *, vint8mf2_t *, const int8_t *, vuint8mf2_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vloxseg3ei8_v_m)))
void vloxseg3ei8_v_i8mf2_m(vint8mf2_t *, vint8mf2_t *, vint8mf2_t *, vbool16_t, vint8mf2_t, vint8mf2_t, vint8mf2_t, const int8_t *, vuint8mf2_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vloxseg3ei8_v)))
void vloxseg3ei8_v_i8mf4(vint8mf4_t *, vint8mf4_t *, vint8mf4_t *, const int8_t *, vuint8mf4_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vloxseg3ei8_v_m)))
void vloxseg3ei8_v_i8mf4_m(vint8mf4_t *, vint8mf4_t *, vint8mf4_t *, vbool32_t, vint8mf4_t, vint8mf4_t, vint8mf4_t, const int8_t *, vuint8mf4_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vloxseg3ei8_v)))
void vloxseg3ei8_v_i8mf8(vint8mf8_t *, vint8mf8_t *, vint8mf8_t *, const int8_t *, vuint8mf8_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vloxseg3ei8_v_m)))
void vloxseg3ei8_v_i8mf8_m(vint8mf8_t *, vint8mf8_t *, vint8mf8_t *, vbool64_t, vint8mf8_t, vint8mf8_t, vint8mf8_t, const int8_t *, vuint8mf8_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vloxseg3ei8_v)))
void vloxseg3ei8_v_u8m1(vuint8m1_t *, vuint8m1_t *, vuint8m1_t *, const uint8_t *, vuint8m1_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vloxseg3ei8_v_m)))
void vloxseg3ei8_v_u8m1_m(vuint8m1_t *, vuint8m1_t *, vuint8m1_t *, vbool8_t, vuint8m1_t, vuint8m1_t, vuint8m1_t, const uint8_t *, vuint8m1_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vloxseg3ei8_v)))
void vloxseg3ei8_v_u8m2(vuint8m2_t *, vuint8m2_t *, vuint8m2_t *, const uint8_t *, vuint8m2_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vloxseg3ei8_v_m)))
void vloxseg3ei8_v_u8m2_m(vuint8m2_t *, vuint8m2_t *, vuint8m2_t *, vbool4_t, vuint8m2_t, vuint8m2_t, vuint8m2_t, const uint8_t *, vuint8m2_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vloxseg3ei8_v)))
void vloxseg3ei8_v_u8mf2(vuint8mf2_t *, vuint8mf2_t *, vuint8mf2_t *, const uint8_t *, vuint8mf2_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vloxseg3ei8_v_m)))
void vloxseg3ei8_v_u8mf2_m(vuint8mf2_t *, vuint8mf2_t *, vuint8mf2_t *, vbool16_t, vuint8mf2_t, vuint8mf2_t, vuint8mf2_t, const uint8_t *, vuint8mf2_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vloxseg3ei8_v)))
void vloxseg3ei8_v_u8mf4(vuint8mf4_t *, vuint8mf4_t *, vuint8mf4_t *, const uint8_t *, vuint8mf4_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vloxseg3ei8_v_m)))
void vloxseg3ei8_v_u8mf4_m(vuint8mf4_t *, vuint8mf4_t *, vuint8mf4_t *, vbool32_t, vuint8mf4_t, vuint8mf4_t, vuint8mf4_t, const uint8_t *, vuint8mf4_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vloxseg3ei8_v)))
void vloxseg3ei8_v_u8mf8(vuint8mf8_t *, vuint8mf8_t *, vuint8mf8_t *, const uint8_t *, vuint8mf8_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vloxseg3ei8_v_m)))
void vloxseg3ei8_v_u8mf8_m(vuint8mf8_t *, vuint8mf8_t *, vuint8mf8_t *, vbool64_t, vuint8mf8_t, vuint8mf8_t, vuint8mf8_t, const uint8_t *, vuint8mf8_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vloxseg4ei8_v)))
void vloxseg4ei8_v_i8m1(vint8m1_t *, vint8m1_t *, vint8m1_t *, vint8m1_t *, const int8_t *, vuint8m1_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vloxseg4ei8_v_m)))
void vloxseg4ei8_v_i8m1_m(vint8m1_t *, vint8m1_t *, vint8m1_t *, vint8m1_t *, vbool8_t, vint8m1_t, vint8m1_t, vint8m1_t, vint8m1_t, const int8_t *, vuint8m1_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vloxseg4ei8_v)))
void vloxseg4ei8_v_i8m2(vint8m2_t *, vint8m2_t *, vint8m2_t *, vint8m2_t *, const int8_t *, vuint8m2_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vloxseg4ei8_v_m)))
void vloxseg4ei8_v_i8m2_m(vint8m2_t *, vint8m2_t *, vint8m2_t *, vint8m2_t *, vbool4_t, vint8m2_t, vint8m2_t, vint8m2_t, vint8m2_t, const int8_t *, vuint8m2_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vloxseg4ei8_v)))
void vloxseg4ei8_v_i8mf2(vint8mf2_t *, vint8mf2_t *, vint8mf2_t *, vint8mf2_t *, const int8_t *, vuint8mf2_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vloxseg4ei8_v_m)))
void vloxseg4ei8_v_i8mf2_m(vint8mf2_t *, vint8mf2_t *, vint8mf2_t *, vint8mf2_t *, vbool16_t, vint8mf2_t, vint8mf2_t, vint8mf2_t, vint8mf2_t, const int8_t *, vuint8mf2_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vloxseg4ei8_v)))
void vloxseg4ei8_v_i8mf4(vint8mf4_t *, vint8mf4_t *, vint8mf4_t *, vint8mf4_t *, const int8_t *, vuint8mf4_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vloxseg4ei8_v_m)))
void vloxseg4ei8_v_i8mf4_m(vint8mf4_t *, vint8mf4_t *, vint8mf4_t *, vint8mf4_t *, vbool32_t, vint8mf4_t, vint8mf4_t, vint8mf4_t, vint8mf4_t, const int8_t *, vuint8mf4_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vloxseg4ei8_v)))
void vloxseg4ei8_v_i8mf8(vint8mf8_t *, vint8mf8_t *, vint8mf8_t *, vint8mf8_t *, const int8_t *, vuint8mf8_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vloxseg4ei8_v_m)))
void vloxseg4ei8_v_i8mf8_m(vint8mf8_t *, vint8mf8_t *, vint8mf8_t *, vint8mf8_t *, vbool64_t, vint8mf8_t, vint8mf8_t, vint8mf8_t, vint8mf8_t, const int8_t *, vuint8mf8_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vloxseg4ei8_v)))
void vloxseg4ei8_v_u8m1(vuint8m1_t *, vuint8m1_t *, vuint8m1_t *, vuint8m1_t *, const uint8_t *, vuint8m1_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vloxseg4ei8_v_m)))
void vloxseg4ei8_v_u8m1_m(vuint8m1_t *, vuint8m1_t *, vuint8m1_t *, vuint8m1_t *, vbool8_t, vuint8m1_t, vuint8m1_t, vuint8m1_t, vuint8m1_t, const uint8_t *, vuint8m1_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vloxseg4ei8_v)))
void vloxseg4ei8_v_u8m2(vuint8m2_t *, vuint8m2_t *, vuint8m2_t *, vuint8m2_t *, const uint8_t *, vuint8m2_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vloxseg4ei8_v_m)))
void vloxseg4ei8_v_u8m2_m(vuint8m2_t *, vuint8m2_t *, vuint8m2_t *, vuint8m2_t *, vbool4_t, vuint8m2_t, vuint8m2_t, vuint8m2_t, vuint8m2_t, const uint8_t *, vuint8m2_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vloxseg4ei8_v)))
void vloxseg4ei8_v_u8mf2(vuint8mf2_t *, vuint8mf2_t *, vuint8mf2_t *, vuint8mf2_t *, const uint8_t *, vuint8mf2_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vloxseg4ei8_v_m)))
void vloxseg4ei8_v_u8mf2_m(vuint8mf2_t *, vuint8mf2_t *, vuint8mf2_t *, vuint8mf2_t *, vbool16_t, vuint8mf2_t, vuint8mf2_t, vuint8mf2_t, vuint8mf2_t, const uint8_t *, vuint8mf2_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vloxseg4ei8_v)))
void vloxseg4ei8_v_u8mf4(vuint8mf4_t *, vuint8mf4_t *, vuint8mf4_t *, vuint8mf4_t *, const uint8_t *, vuint8mf4_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vloxseg4ei8_v_m)))
void vloxseg4ei8_v_u8mf4_m(vuint8mf4_t *, vuint8mf4_t *, vuint8mf4_t *, vuint8mf4_t *, vbool32_t, vuint8mf4_t, vuint8mf4_t, vuint8mf4_t, vuint8mf4_t, const uint8_t *, vuint8mf4_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vloxseg4ei8_v)))
void vloxseg4ei8_v_u8mf8(vuint8mf8_t *, vuint8mf8_t *, vuint8mf8_t *, vuint8mf8_t *, const uint8_t *, vuint8mf8_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vloxseg4ei8_v_m)))
void vloxseg4ei8_v_u8mf8_m(vuint8mf8_t *, vuint8mf8_t *, vuint8mf8_t *, vuint8mf8_t *, vbool64_t, vuint8mf8_t, vuint8mf8_t, vuint8mf8_t, vuint8mf8_t, const uint8_t *, vuint8mf8_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vloxseg5ei8_v)))
void vloxseg5ei8_v_i8m1(vint8m1_t *, vint8m1_t *, vint8m1_t *, vint8m1_t *, vint8m1_t *, const int8_t *, vuint8m1_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vloxseg5ei8_v_m)))
void vloxseg5ei8_v_i8m1_m(vint8m1_t *, vint8m1_t *, vint8m1_t *, vint8m1_t *, vint8m1_t *, vbool8_t, vint8m1_t, vint8m1_t, vint8m1_t, vint8m1_t, vint8m1_t, const int8_t *, vuint8m1_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vloxseg5ei8_v)))
void vloxseg5ei8_v_i8mf2(vint8mf2_t *, vint8mf2_t *, vint8mf2_t *, vint8mf2_t *, vint8mf2_t *, const int8_t *, vuint8mf2_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vloxseg5ei8_v_m)))
void vloxseg5ei8_v_i8mf2_m(vint8mf2_t *, vint8mf2_t *, vint8mf2_t *, vint8mf2_t *, vint8mf2_t *, vbool16_t, vint8mf2_t, vint8mf2_t, vint8mf2_t, vint8mf2_t, vint8mf2_t, const int8_t *, vuint8mf2_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vloxseg5ei8_v)))
void vloxseg5ei8_v_i8mf4(vint8mf4_t *, vint8mf4_t *, vint8mf4_t *, vint8mf4_t *, vint8mf4_t *, const int8_t *, vuint8mf4_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vloxseg5ei8_v_m)))
void vloxseg5ei8_v_i8mf4_m(vint8mf4_t *, vint8mf4_t *, vint8mf4_t *, vint8mf4_t *, vint8mf4_t *, vbool32_t, vint8mf4_t, vint8mf4_t, vint8mf4_t, vint8mf4_t, vint8mf4_t, const int8_t *, vuint8mf4_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vloxseg5ei8_v)))
void vloxseg5ei8_v_i8mf8(vint8mf8_t *, vint8mf8_t *, vint8mf8_t *, vint8mf8_t *, vint8mf8_t *, const int8_t *, vuint8mf8_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vloxseg5ei8_v_m)))
void vloxseg5ei8_v_i8mf8_m(vint8mf8_t *, vint8mf8_t *, vint8mf8_t *, vint8mf8_t *, vint8mf8_t *, vbool64_t, vint8mf8_t, vint8mf8_t, vint8mf8_t, vint8mf8_t, vint8mf8_t, const int8_t *, vuint8mf8_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vloxseg5ei8_v)))
void vloxseg5ei8_v_u8m1(vuint8m1_t *, vuint8m1_t *, vuint8m1_t *, vuint8m1_t *, vuint8m1_t *, const uint8_t *, vuint8m1_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vloxseg5ei8_v_m)))
void vloxseg5ei8_v_u8m1_m(vuint8m1_t *, vuint8m1_t *, vuint8m1_t *, vuint8m1_t *, vuint8m1_t *, vbool8_t, vuint8m1_t, vuint8m1_t, vuint8m1_t, vuint8m1_t, vuint8m1_t, const uint8_t *, vuint8m1_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vloxseg5ei8_v)))
void vloxseg5ei8_v_u8mf2(vuint8mf2_t *, vuint8mf2_t *, vuint8mf2_t *, vuint8mf2_t *, vuint8mf2_t *, const uint8_t *, vuint8mf2_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vloxseg5ei8_v_m)))
void vloxseg5ei8_v_u8mf2_m(vuint8mf2_t *, vuint8mf2_t *, vuint8mf2_t *, vuint8mf2_t *, vuint8mf2_t *, vbool16_t, vuint8mf2_t, vuint8mf2_t, vuint8mf2_t, vuint8mf2_t, vuint8mf2_t, const uint8_t *, vuint8mf2_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vloxseg5ei8_v)))
void vloxseg5ei8_v_u8mf4(vuint8mf4_t *, vuint8mf4_t *, vuint8mf4_t *, vuint8mf4_t *, vuint8mf4_t *, const uint8_t *, vuint8mf4_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vloxseg5ei8_v_m)))
void vloxseg5ei8_v_u8mf4_m(vuint8mf4_t *, vuint8mf4_t *, vuint8mf4_t *, vuint8mf4_t *, vuint8mf4_t *, vbool32_t, vuint8mf4_t, vuint8mf4_t, vuint8mf4_t, vuint8mf4_t, vuint8mf4_t, const uint8_t *, vuint8mf4_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vloxseg5ei8_v)))
void vloxseg5ei8_v_u8mf8(vuint8mf8_t *, vuint8mf8_t *, vuint8mf8_t *, vuint8mf8_t *, vuint8mf8_t *, const uint8_t *, vuint8mf8_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vloxseg5ei8_v_m)))
void vloxseg5ei8_v_u8mf8_m(vuint8mf8_t *, vuint8mf8_t *, vuint8mf8_t *, vuint8mf8_t *, vuint8mf8_t *, vbool64_t, vuint8mf8_t, vuint8mf8_t, vuint8mf8_t, vuint8mf8_t, vuint8mf8_t, const uint8_t *, vuint8mf8_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vloxseg6ei8_v)))
void vloxseg6ei8_v_i8m1(vint8m1_t *, vint8m1_t *, vint8m1_t *, vint8m1_t *, vint8m1_t *, vint8m1_t *, const int8_t *, vuint8m1_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vloxseg6ei8_v_m)))
void vloxseg6ei8_v_i8m1_m(vint8m1_t *, vint8m1_t *, vint8m1_t *, vint8m1_t *, vint8m1_t *, vint8m1_t *, vbool8_t, vint8m1_t, vint8m1_t, vint8m1_t, vint8m1_t, vint8m1_t, vint8m1_t, const int8_t *, vuint8m1_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vloxseg6ei8_v)))
void vloxseg6ei8_v_i8mf2(vint8mf2_t *, vint8mf2_t *, vint8mf2_t *, vint8mf2_t *, vint8mf2_t *, vint8mf2_t *, const int8_t *, vuint8mf2_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vloxseg6ei8_v_m)))
void vloxseg6ei8_v_i8mf2_m(vint8mf2_t *, vint8mf2_t *, vint8mf2_t *, vint8mf2_t *, vint8mf2_t *, vint8mf2_t *, vbool16_t, vint8mf2_t, vint8mf2_t, vint8mf2_t, vint8mf2_t, vint8mf2_t, vint8mf2_t, const int8_t *, vuint8mf2_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vloxseg6ei8_v)))
void vloxseg6ei8_v_i8mf4(vint8mf4_t *, vint8mf4_t *, vint8mf4_t *, vint8mf4_t *, vint8mf4_t *, vint8mf4_t *, const int8_t *, vuint8mf4_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vloxseg6ei8_v_m)))
void vloxseg6ei8_v_i8mf4_m(vint8mf4_t *, vint8mf4_t *, vint8mf4_t *, vint8mf4_t *, vint8mf4_t *, vint8mf4_t *, vbool32_t, vint8mf4_t, vint8mf4_t, vint8mf4_t, vint8mf4_t, vint8mf4_t, vint8mf4_t, const int8_t *, vuint8mf4_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vloxseg6ei8_v)))
void vloxseg6ei8_v_i8mf8(vint8mf8_t *, vint8mf8_t *, vint8mf8_t *, vint8mf8_t *, vint8mf8_t *, vint8mf8_t *, const int8_t *, vuint8mf8_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vloxseg6ei8_v_m)))
void vloxseg6ei8_v_i8mf8_m(vint8mf8_t *, vint8mf8_t *, vint8mf8_t *, vint8mf8_t *, vint8mf8_t *, vint8mf8_t *, vbool64_t, vint8mf8_t, vint8mf8_t, vint8mf8_t, vint8mf8_t, vint8mf8_t, vint8mf8_t, const int8_t *, vuint8mf8_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vloxseg6ei8_v)))
void vloxseg6ei8_v_u8m1(vuint8m1_t *, vuint8m1_t *, vuint8m1_t *, vuint8m1_t *, vuint8m1_t *, vuint8m1_t *, const uint8_t *, vuint8m1_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vloxseg6ei8_v_m)))
void vloxseg6ei8_v_u8m1_m(vuint8m1_t *, vuint8m1_t *, vuint8m1_t *, vuint8m1_t *, vuint8m1_t *, vuint8m1_t *, vbool8_t, vuint8m1_t, vuint8m1_t, vuint8m1_t, vuint8m1_t, vuint8m1_t, vuint8m1_t, const uint8_t *, vuint8m1_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vloxseg6ei8_v)))
void vloxseg6ei8_v_u8mf2(vuint8mf2_t *, vuint8mf2_t *, vuint8mf2_t *, vuint8mf2_t *, vuint8mf2_t *, vuint8mf2_t *, const uint8_t *, vuint8mf2_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vloxseg6ei8_v_m)))
void vloxseg6ei8_v_u8mf2_m(vuint8mf2_t *, vuint8mf2_t *, vuint8mf2_t *, vuint8mf2_t *, vuint8mf2_t *, vuint8mf2_t *, vbool16_t, vuint8mf2_t, vuint8mf2_t, vuint8mf2_t, vuint8mf2_t, vuint8mf2_t, vuint8mf2_t, const uint8_t *, vuint8mf2_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vloxseg6ei8_v)))
void vloxseg6ei8_v_u8mf4(vuint8mf4_t *, vuint8mf4_t *, vuint8mf4_t *, vuint8mf4_t *, vuint8mf4_t *, vuint8mf4_t *, const uint8_t *, vuint8mf4_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vloxseg6ei8_v_m)))
void vloxseg6ei8_v_u8mf4_m(vuint8mf4_t *, vuint8mf4_t *, vuint8mf4_t *, vuint8mf4_t *, vuint8mf4_t *, vuint8mf4_t *, vbool32_t, vuint8mf4_t, vuint8mf4_t, vuint8mf4_t, vuint8mf4_t, vuint8mf4_t, vuint8mf4_t, const uint8_t *, vuint8mf4_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vloxseg6ei8_v)))
void vloxseg6ei8_v_u8mf8(vuint8mf8_t *, vuint8mf8_t *, vuint8mf8_t *, vuint8mf8_t *, vuint8mf8_t *, vuint8mf8_t *, const uint8_t *, vuint8mf8_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vloxseg6ei8_v_m)))
void vloxseg6ei8_v_u8mf8_m(vuint8mf8_t *, vuint8mf8_t *, vuint8mf8_t *, vuint8mf8_t *, vuint8mf8_t *, vuint8mf8_t *, vbool64_t, vuint8mf8_t, vuint8mf8_t, vuint8mf8_t, vuint8mf8_t, vuint8mf8_t, vuint8mf8_t, const uint8_t *, vuint8mf8_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vloxseg7ei8_v)))
void vloxseg7ei8_v_i8m1(vint8m1_t *, vint8m1_t *, vint8m1_t *, vint8m1_t *, vint8m1_t *, vint8m1_t *, vint8m1_t *, const int8_t *, vuint8m1_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vloxseg7ei8_v_m)))
void vloxseg7ei8_v_i8m1_m(vint8m1_t *, vint8m1_t *, vint8m1_t *, vint8m1_t *, vint8m1_t *, vint8m1_t *, vint8m1_t *, vbool8_t, vint8m1_t, vint8m1_t, vint8m1_t, vint8m1_t, vint8m1_t, vint8m1_t, vint8m1_t, const int8_t *, vuint8m1_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vloxseg7ei8_v)))
void vloxseg7ei8_v_i8mf2(vint8mf2_t *, vint8mf2_t *, vint8mf2_t *, vint8mf2_t *, vint8mf2_t *, vint8mf2_t *, vint8mf2_t *, const int8_t *, vuint8mf2_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vloxseg7ei8_v_m)))
void vloxseg7ei8_v_i8mf2_m(vint8mf2_t *, vint8mf2_t *, vint8mf2_t *, vint8mf2_t *, vint8mf2_t *, vint8mf2_t *, vint8mf2_t *, vbool16_t, vint8mf2_t, vint8mf2_t, vint8mf2_t, vint8mf2_t, vint8mf2_t, vint8mf2_t, vint8mf2_t, const int8_t *, vuint8mf2_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vloxseg7ei8_v)))
void vloxseg7ei8_v_i8mf4(vint8mf4_t *, vint8mf4_t *, vint8mf4_t *, vint8mf4_t *, vint8mf4_t *, vint8mf4_t *, vint8mf4_t *, const int8_t *, vuint8mf4_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vloxseg7ei8_v_m)))
void vloxseg7ei8_v_i8mf4_m(vint8mf4_t *, vint8mf4_t *, vint8mf4_t *, vint8mf4_t *, vint8mf4_t *, vint8mf4_t *, vint8mf4_t *, vbool32_t, vint8mf4_t, vint8mf4_t, vint8mf4_t, vint8mf4_t, vint8mf4_t, vint8mf4_t, vint8mf4_t, const int8_t *, vuint8mf4_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vloxseg7ei8_v)))
void vloxseg7ei8_v_i8mf8(vint8mf8_t *, vint8mf8_t *, vint8mf8_t *, vint8mf8_t *, vint8mf8_t *, vint8mf8_t *, vint8mf8_t *, const int8_t *, vuint8mf8_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vloxseg7ei8_v_m)))
void vloxseg7ei8_v_i8mf8_m(vint8mf8_t *, vint8mf8_t *, vint8mf8_t *, vint8mf8_t *, vint8mf8_t *, vint8mf8_t *, vint8mf8_t *, vbool64_t, vint8mf8_t, vint8mf8_t, vint8mf8_t, vint8mf8_t, vint8mf8_t, vint8mf8_t, vint8mf8_t, const int8_t *, vuint8mf8_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vloxseg7ei8_v)))
void vloxseg7ei8_v_u8m1(vuint8m1_t *, vuint8m1_t *, vuint8m1_t *, vuint8m1_t *, vuint8m1_t *, vuint8m1_t *, vuint8m1_t *, const uint8_t *, vuint8m1_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vloxseg7ei8_v_m)))
void vloxseg7ei8_v_u8m1_m(vuint8m1_t *, vuint8m1_t *, vuint8m1_t *, vuint8m1_t *, vuint8m1_t *, vuint8m1_t *, vuint8m1_t *, vbool8_t, vuint8m1_t, vuint8m1_t, vuint8m1_t, vuint8m1_t, vuint8m1_t, vuint8m1_t, vuint8m1_t, const uint8_t *, vuint8m1_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vloxseg7ei8_v)))
void vloxseg7ei8_v_u8mf2(vuint8mf2_t *, vuint8mf2_t *, vuint8mf2_t *, vuint8mf2_t *, vuint8mf2_t *, vuint8mf2_t *, vuint8mf2_t *, const uint8_t *, vuint8mf2_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vloxseg7ei8_v_m)))
void vloxseg7ei8_v_u8mf2_m(vuint8mf2_t *, vuint8mf2_t *, vuint8mf2_t *, vuint8mf2_t *, vuint8mf2_t *, vuint8mf2_t *, vuint8mf2_t *, vbool16_t, vuint8mf2_t, vuint8mf2_t, vuint8mf2_t, vuint8mf2_t, vuint8mf2_t, vuint8mf2_t, vuint8mf2_t, const uint8_t *, vuint8mf2_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vloxseg7ei8_v)))
void vloxseg7ei8_v_u8mf4(vuint8mf4_t *, vuint8mf4_t *, vuint8mf4_t *, vuint8mf4_t *, vuint8mf4_t *, vuint8mf4_t *, vuint8mf4_t *, const uint8_t *, vuint8mf4_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vloxseg7ei8_v_m)))
void vloxseg7ei8_v_u8mf4_m(vuint8mf4_t *, vuint8mf4_t *, vuint8mf4_t *, vuint8mf4_t *, vuint8mf4_t *, vuint8mf4_t *, vuint8mf4_t *, vbool32_t, vuint8mf4_t, vuint8mf4_t, vuint8mf4_t, vuint8mf4_t, vuint8mf4_t, vuint8mf4_t, vuint8mf4_t, const uint8_t *, vuint8mf4_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vloxseg7ei8_v)))
void vloxseg7ei8_v_u8mf8(vuint8mf8_t *, vuint8mf8_t *, vuint8mf8_t *, vuint8mf8_t *, vuint8mf8_t *, vuint8mf8_t *, vuint8mf8_t *, const uint8_t *, vuint8mf8_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vloxseg7ei8_v_m)))
void vloxseg7ei8_v_u8mf8_m(vuint8mf8_t *, vuint8mf8_t *, vuint8mf8_t *, vuint8mf8_t *, vuint8mf8_t *, vuint8mf8_t *, vuint8mf8_t *, vbool64_t, vuint8mf8_t, vuint8mf8_t, vuint8mf8_t, vuint8mf8_t, vuint8mf8_t, vuint8mf8_t, vuint8mf8_t, const uint8_t *, vuint8mf8_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vloxseg8ei8_v)))
void vloxseg8ei8_v_i8m1(vint8m1_t *, vint8m1_t *, vint8m1_t *, vint8m1_t *, vint8m1_t *, vint8m1_t *, vint8m1_t *, vint8m1_t *, const int8_t *, vuint8m1_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vloxseg8ei8_v_m)))
void vloxseg8ei8_v_i8m1_m(vint8m1_t *, vint8m1_t *, vint8m1_t *, vint8m1_t *, vint8m1_t *, vint8m1_t *, vint8m1_t *, vint8m1_t *, vbool8_t, vint8m1_t, vint8m1_t, vint8m1_t, vint8m1_t, vint8m1_t, vint8m1_t, vint8m1_t, vint8m1_t, const int8_t *, vuint8m1_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vloxseg8ei8_v)))
void vloxseg8ei8_v_i8mf2(vint8mf2_t *, vint8mf2_t *, vint8mf2_t *, vint8mf2_t *, vint8mf2_t *, vint8mf2_t *, vint8mf2_t *, vint8mf2_t *, const int8_t *, vuint8mf2_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vloxseg8ei8_v_m)))
void vloxseg8ei8_v_i8mf2_m(vint8mf2_t *, vint8mf2_t *, vint8mf2_t *, vint8mf2_t *, vint8mf2_t *, vint8mf2_t *, vint8mf2_t *, vint8mf2_t *, vbool16_t, vint8mf2_t, vint8mf2_t, vint8mf2_t, vint8mf2_t, vint8mf2_t, vint8mf2_t, vint8mf2_t, vint8mf2_t, const int8_t *, vuint8mf2_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vloxseg8ei8_v)))
void vloxseg8ei8_v_i8mf4(vint8mf4_t *, vint8mf4_t *, vint8mf4_t *, vint8mf4_t *, vint8mf4_t *, vint8mf4_t *, vint8mf4_t *, vint8mf4_t *, const int8_t *, vuint8mf4_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vloxseg8ei8_v_m)))
void vloxseg8ei8_v_i8mf4_m(vint8mf4_t *, vint8mf4_t *, vint8mf4_t *, vint8mf4_t *, vint8mf4_t *, vint8mf4_t *, vint8mf4_t *, vint8mf4_t *, vbool32_t, vint8mf4_t, vint8mf4_t, vint8mf4_t, vint8mf4_t, vint8mf4_t, vint8mf4_t, vint8mf4_t, vint8mf4_t, const int8_t *, vuint8mf4_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vloxseg8ei8_v)))
void vloxseg8ei8_v_i8mf8(vint8mf8_t *, vint8mf8_t *, vint8mf8_t *, vint8mf8_t *, vint8mf8_t *, vint8mf8_t *, vint8mf8_t *, vint8mf8_t *, const int8_t *, vuint8mf8_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vloxseg8ei8_v_m)))
void vloxseg8ei8_v_i8mf8_m(vint8mf8_t *, vint8mf8_t *, vint8mf8_t *, vint8mf8_t *, vint8mf8_t *, vint8mf8_t *, vint8mf8_t *, vint8mf8_t *, vbool64_t, vint8mf8_t, vint8mf8_t, vint8mf8_t, vint8mf8_t, vint8mf8_t, vint8mf8_t, vint8mf8_t, vint8mf8_t, const int8_t *, vuint8mf8_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vloxseg8ei8_v)))
void vloxseg8ei8_v_u8m1(vuint8m1_t *, vuint8m1_t *, vuint8m1_t *, vuint8m1_t *, vuint8m1_t *, vuint8m1_t *, vuint8m1_t *, vuint8m1_t *, const uint8_t *, vuint8m1_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vloxseg8ei8_v_m)))
void vloxseg8ei8_v_u8m1_m(vuint8m1_t *, vuint8m1_t *, vuint8m1_t *, vuint8m1_t *, vuint8m1_t *, vuint8m1_t *, vuint8m1_t *, vuint8m1_t *, vbool8_t, vuint8m1_t, vuint8m1_t, vuint8m1_t, vuint8m1_t, vuint8m1_t, vuint8m1_t, vuint8m1_t, vuint8m1_t, const uint8_t *, vuint8m1_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vloxseg8ei8_v)))
void vloxseg8ei8_v_u8mf2(vuint8mf2_t *, vuint8mf2_t *, vuint8mf2_t *, vuint8mf2_t *, vuint8mf2_t *, vuint8mf2_t *, vuint8mf2_t *, vuint8mf2_t *, const uint8_t *, vuint8mf2_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vloxseg8ei8_v_m)))
void vloxseg8ei8_v_u8mf2_m(vuint8mf2_t *, vuint8mf2_t *, vuint8mf2_t *, vuint8mf2_t *, vuint8mf2_t *, vuint8mf2_t *, vuint8mf2_t *, vuint8mf2_t *, vbool16_t, vuint8mf2_t, vuint8mf2_t, vuint8mf2_t, vuint8mf2_t, vuint8mf2_t, vuint8mf2_t, vuint8mf2_t, vuint8mf2_t, const uint8_t *, vuint8mf2_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vloxseg8ei8_v)))
void vloxseg8ei8_v_u8mf4(vuint8mf4_t *, vuint8mf4_t *, vuint8mf4_t *, vuint8mf4_t *, vuint8mf4_t *, vuint8mf4_t *, vuint8mf4_t *, vuint8mf4_t *, const uint8_t *, vuint8mf4_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vloxseg8ei8_v_m)))
void vloxseg8ei8_v_u8mf4_m(vuint8mf4_t *, vuint8mf4_t *, vuint8mf4_t *, vuint8mf4_t *, vuint8mf4_t *, vuint8mf4_t *, vuint8mf4_t *, vuint8mf4_t *, vbool32_t, vuint8mf4_t, vuint8mf4_t, vuint8mf4_t, vuint8mf4_t, vuint8mf4_t, vuint8mf4_t, vuint8mf4_t, vuint8mf4_t, const uint8_t *, vuint8mf4_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vloxseg8ei8_v)))
void vloxseg8ei8_v_u8mf8(vuint8mf8_t *, vuint8mf8_t *, vuint8mf8_t *, vuint8mf8_t *, vuint8mf8_t *, vuint8mf8_t *, vuint8mf8_t *, vuint8mf8_t *, const uint8_t *, vuint8mf8_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vloxseg8ei8_v_m)))
void vloxseg8ei8_v_u8mf8_m(vuint8mf8_t *, vuint8mf8_t *, vuint8mf8_t *, vuint8mf8_t *, vuint8mf8_t *, vuint8mf8_t *, vuint8mf8_t *, vuint8mf8_t *, vbool64_t, vuint8mf8_t, vuint8mf8_t, vuint8mf8_t, vuint8mf8_t, vuint8mf8_t, vuint8mf8_t, vuint8mf8_t, vuint8mf8_t, const uint8_t *, vuint8mf8_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vloxseg2ei16_v)))
void vloxseg2ei16_v_i8m1(vint8m1_t *, vint8m1_t *, const int8_t *, vuint16m2_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vloxseg2ei16_v_m)))
void vloxseg2ei16_v_i8m1_m(vint8m1_t *, vint8m1_t *, vbool8_t, vint8m1_t, vint8m1_t, const int8_t *, vuint16m2_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vloxseg2ei16_v)))
void vloxseg2ei16_v_i8m2(vint8m2_t *, vint8m2_t *, const int8_t *, vuint16m4_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vloxseg2ei16_v_m)))
void vloxseg2ei16_v_i8m2_m(vint8m2_t *, vint8m2_t *, vbool4_t, vint8m2_t, vint8m2_t, const int8_t *, vuint16m4_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vloxseg2ei16_v)))
void vloxseg2ei16_v_i8m4(vint8m4_t *, vint8m4_t *, const int8_t *, vuint16m8_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vloxseg2ei16_v_m)))
void vloxseg2ei16_v_i8m4_m(vint8m4_t *, vint8m4_t *, vbool2_t, vint8m4_t, vint8m4_t, const int8_t *, vuint16m8_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vloxseg2ei16_v)))
void vloxseg2ei16_v_i8mf2(vint8mf2_t *, vint8mf2_t *, const int8_t *, vuint16m1_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vloxseg2ei16_v_m)))
void vloxseg2ei16_v_i8mf2_m(vint8mf2_t *, vint8mf2_t *, vbool16_t, vint8mf2_t, vint8mf2_t, const int8_t *, vuint16m1_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vloxseg2ei16_v)))
void vloxseg2ei16_v_i8mf4(vint8mf4_t *, vint8mf4_t *, const int8_t *, vuint16mf2_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vloxseg2ei16_v_m)))
void vloxseg2ei16_v_i8mf4_m(vint8mf4_t *, vint8mf4_t *, vbool32_t, vint8mf4_t, vint8mf4_t, const int8_t *, vuint16mf2_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vloxseg2ei16_v)))
void vloxseg2ei16_v_i8mf8(vint8mf8_t *, vint8mf8_t *, const int8_t *, vuint16mf4_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vloxseg2ei16_v_m)))
void vloxseg2ei16_v_i8mf8_m(vint8mf8_t *, vint8mf8_t *, vbool64_t, vint8mf8_t, vint8mf8_t, const int8_t *, vuint16mf4_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vloxseg2ei16_v)))
void vloxseg2ei16_v_u8m1(vuint8m1_t *, vuint8m1_t *, const uint8_t *, vuint16m2_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vloxseg2ei16_v_m)))
void vloxseg2ei16_v_u8m1_m(vuint8m1_t *, vuint8m1_t *, vbool8_t, vuint8m1_t, vuint8m1_t, const uint8_t *, vuint16m2_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vloxseg2ei16_v)))
void vloxseg2ei16_v_u8m2(vuint8m2_t *, vuint8m2_t *, const uint8_t *, vuint16m4_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vloxseg2ei16_v_m)))
void vloxseg2ei16_v_u8m2_m(vuint8m2_t *, vuint8m2_t *, vbool4_t, vuint8m2_t, vuint8m2_t, const uint8_t *, vuint16m4_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vloxseg2ei16_v)))
void vloxseg2ei16_v_u8m4(vuint8m4_t *, vuint8m4_t *, const uint8_t *, vuint16m8_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vloxseg2ei16_v_m)))
void vloxseg2ei16_v_u8m4_m(vuint8m4_t *, vuint8m4_t *, vbool2_t, vuint8m4_t, vuint8m4_t, const uint8_t *, vuint16m8_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vloxseg2ei16_v)))
void vloxseg2ei16_v_u8mf2(vuint8mf2_t *, vuint8mf2_t *, const uint8_t *, vuint16m1_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vloxseg2ei16_v_m)))
void vloxseg2ei16_v_u8mf2_m(vuint8mf2_t *, vuint8mf2_t *, vbool16_t, vuint8mf2_t, vuint8mf2_t, const uint8_t *, vuint16m1_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vloxseg2ei16_v)))
void vloxseg2ei16_v_u8mf4(vuint8mf4_t *, vuint8mf4_t *, const uint8_t *, vuint16mf2_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vloxseg2ei16_v_m)))
void vloxseg2ei16_v_u8mf4_m(vuint8mf4_t *, vuint8mf4_t *, vbool32_t, vuint8mf4_t, vuint8mf4_t, const uint8_t *, vuint16mf2_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vloxseg2ei16_v)))
void vloxseg2ei16_v_u8mf8(vuint8mf8_t *, vuint8mf8_t *, const uint8_t *, vuint16mf4_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vloxseg2ei16_v_m)))
void vloxseg2ei16_v_u8mf8_m(vuint8mf8_t *, vuint8mf8_t *, vbool64_t, vuint8mf8_t, vuint8mf8_t, const uint8_t *, vuint16mf4_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vloxseg3ei16_v)))
void vloxseg3ei16_v_i8m1(vint8m1_t *, vint8m1_t *, vint8m1_t *, const int8_t *, vuint16m2_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vloxseg3ei16_v_m)))
void vloxseg3ei16_v_i8m1_m(vint8m1_t *, vint8m1_t *, vint8m1_t *, vbool8_t, vint8m1_t, vint8m1_t, vint8m1_t, const int8_t *, vuint16m2_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vloxseg3ei16_v)))
void vloxseg3ei16_v_i8m2(vint8m2_t *, vint8m2_t *, vint8m2_t *, const int8_t *, vuint16m4_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vloxseg3ei16_v_m)))
void vloxseg3ei16_v_i8m2_m(vint8m2_t *, vint8m2_t *, vint8m2_t *, vbool4_t, vint8m2_t, vint8m2_t, vint8m2_t, const int8_t *, vuint16m4_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vloxseg3ei16_v)))
void vloxseg3ei16_v_i8mf2(vint8mf2_t *, vint8mf2_t *, vint8mf2_t *, const int8_t *, vuint16m1_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vloxseg3ei16_v_m)))
void vloxseg3ei16_v_i8mf2_m(vint8mf2_t *, vint8mf2_t *, vint8mf2_t *, vbool16_t, vint8mf2_t, vint8mf2_t, vint8mf2_t, const int8_t *, vuint16m1_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vloxseg3ei16_v)))
void vloxseg3ei16_v_i8mf4(vint8mf4_t *, vint8mf4_t *, vint8mf4_t *, const int8_t *, vuint16mf2_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vloxseg3ei16_v_m)))
void vloxseg3ei16_v_i8mf4_m(vint8mf4_t *, vint8mf4_t *, vint8mf4_t *, vbool32_t, vint8mf4_t, vint8mf4_t, vint8mf4_t, const int8_t *, vuint16mf2_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vloxseg3ei16_v)))
void vloxseg3ei16_v_i8mf8(vint8mf8_t *, vint8mf8_t *, vint8mf8_t *, const int8_t *, vuint16mf4_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vloxseg3ei16_v_m)))
void vloxseg3ei16_v_i8mf8_m(vint8mf8_t *, vint8mf8_t *, vint8mf8_t *, vbool64_t, vint8mf8_t, vint8mf8_t, vint8mf8_t, const int8_t *, vuint16mf4_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vloxseg3ei16_v)))
void vloxseg3ei16_v_u8m1(vuint8m1_t *, vuint8m1_t *, vuint8m1_t *, const uint8_t *, vuint16m2_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vloxseg3ei16_v_m)))
void vloxseg3ei16_v_u8m1_m(vuint8m1_t *, vuint8m1_t *, vuint8m1_t *, vbool8_t, vuint8m1_t, vuint8m1_t, vuint8m1_t, const uint8_t *, vuint16m2_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vloxseg3ei16_v)))
void vloxseg3ei16_v_u8m2(vuint8m2_t *, vuint8m2_t *, vuint8m2_t *, const uint8_t *, vuint16m4_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vloxseg3ei16_v_m)))
void vloxseg3ei16_v_u8m2_m(vuint8m2_t *, vuint8m2_t *, vuint8m2_t *, vbool4_t, vuint8m2_t, vuint8m2_t, vuint8m2_t, const uint8_t *, vuint16m4_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vloxseg3ei16_v)))
void vloxseg3ei16_v_u8mf2(vuint8mf2_t *, vuint8mf2_t *, vuint8mf2_t *, const uint8_t *, vuint16m1_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vloxseg3ei16_v_m)))
void vloxseg3ei16_v_u8mf2_m(vuint8mf2_t *, vuint8mf2_t *, vuint8mf2_t *, vbool16_t, vuint8mf2_t, vuint8mf2_t, vuint8mf2_t, const uint8_t *, vuint16m1_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vloxseg3ei16_v)))
void vloxseg3ei16_v_u8mf4(vuint8mf4_t *, vuint8mf4_t *, vuint8mf4_t *, const uint8_t *, vuint16mf2_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vloxseg3ei16_v_m)))
void vloxseg3ei16_v_u8mf4_m(vuint8mf4_t *, vuint8mf4_t *, vuint8mf4_t *, vbool32_t, vuint8mf4_t, vuint8mf4_t, vuint8mf4_t, const uint8_t *, vuint16mf2_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vloxseg3ei16_v)))
void vloxseg3ei16_v_u8mf8(vuint8mf8_t *, vuint8mf8_t *, vuint8mf8_t *, const uint8_t *, vuint16mf4_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vloxseg3ei16_v_m)))
void vloxseg3ei16_v_u8mf8_m(vuint8mf8_t *, vuint8mf8_t *, vuint8mf8_t *, vbool64_t, vuint8mf8_t, vuint8mf8_t, vuint8mf8_t, const uint8_t *, vuint16mf4_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vloxseg4ei16_v)))
void vloxseg4ei16_v_i8m1(vint8m1_t *, vint8m1_t *, vint8m1_t *, vint8m1_t *, const int8_t *, vuint16m2_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vloxseg4ei16_v_m)))
void vloxseg4ei16_v_i8m1_m(vint8m1_t *, vint8m1_t *, vint8m1_t *, vint8m1_t *, vbool8_t, vint8m1_t, vint8m1_t, vint8m1_t, vint8m1_t, const int8_t *, vuint16m2_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vloxseg4ei16_v)))
void vloxseg4ei16_v_i8m2(vint8m2_t *, vint8m2_t *, vint8m2_t *, vint8m2_t *, const int8_t *, vuint16m4_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vloxseg4ei16_v_m)))
void vloxseg4ei16_v_i8m2_m(vint8m2_t *, vint8m2_t *, vint8m2_t *, vint8m2_t *, vbool4_t, vint8m2_t, vint8m2_t, vint8m2_t, vint8m2_t, const int8_t *, vuint16m4_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vloxseg4ei16_v)))
void vloxseg4ei16_v_i8mf2(vint8mf2_t *, vint8mf2_t *, vint8mf2_t *, vint8mf2_t *, const int8_t *, vuint16m1_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vloxseg4ei16_v_m)))
void vloxseg4ei16_v_i8mf2_m(vint8mf2_t *, vint8mf2_t *, vint8mf2_t *, vint8mf2_t *, vbool16_t, vint8mf2_t, vint8mf2_t, vint8mf2_t, vint8mf2_t, const int8_t *, vuint16m1_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vloxseg4ei16_v)))
void vloxseg4ei16_v_i8mf4(vint8mf4_t *, vint8mf4_t *, vint8mf4_t *, vint8mf4_t *, const int8_t *, vuint16mf2_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vloxseg4ei16_v_m)))
void vloxseg4ei16_v_i8mf4_m(vint8mf4_t *, vint8mf4_t *, vint8mf4_t *, vint8mf4_t *, vbool32_t, vint8mf4_t, vint8mf4_t, vint8mf4_t, vint8mf4_t, const int8_t *, vuint16mf2_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vloxseg4ei16_v)))
void vloxseg4ei16_v_i8mf8(vint8mf8_t *, vint8mf8_t *, vint8mf8_t *, vint8mf8_t *, const int8_t *, vuint16mf4_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vloxseg4ei16_v_m)))
void vloxseg4ei16_v_i8mf8_m(vint8mf8_t *, vint8mf8_t *, vint8mf8_t *, vint8mf8_t *, vbool64_t, vint8mf8_t, vint8mf8_t, vint8mf8_t, vint8mf8_t, const int8_t *, vuint16mf4_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vloxseg4ei16_v)))
void vloxseg4ei16_v_u8m1(vuint8m1_t *, vuint8m1_t *, vuint8m1_t *, vuint8m1_t *, const uint8_t *, vuint16m2_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vloxseg4ei16_v_m)))
void vloxseg4ei16_v_u8m1_m(vuint8m1_t *, vuint8m1_t *, vuint8m1_t *, vuint8m1_t *, vbool8_t, vuint8m1_t, vuint8m1_t, vuint8m1_t, vuint8m1_t, const uint8_t *, vuint16m2_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vloxseg4ei16_v)))
void vloxseg4ei16_v_u8m2(vuint8m2_t *, vuint8m2_t *, vuint8m2_t *, vuint8m2_t *, const uint8_t *, vuint16m4_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vloxseg4ei16_v_m)))
void vloxseg4ei16_v_u8m2_m(vuint8m2_t *, vuint8m2_t *, vuint8m2_t *, vuint8m2_t *, vbool4_t, vuint8m2_t, vuint8m2_t, vuint8m2_t, vuint8m2_t, const uint8_t *, vuint16m4_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vloxseg4ei16_v)))
void vloxseg4ei16_v_u8mf2(vuint8mf2_t *, vuint8mf2_t *, vuint8mf2_t *, vuint8mf2_t *, const uint8_t *, vuint16m1_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vloxseg4ei16_v_m)))
void vloxseg4ei16_v_u8mf2_m(vuint8mf2_t *, vuint8mf2_t *, vuint8mf2_t *, vuint8mf2_t *, vbool16_t, vuint8mf2_t, vuint8mf2_t, vuint8mf2_t, vuint8mf2_t, const uint8_t *, vuint16m1_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vloxseg4ei16_v)))
void vloxseg4ei16_v_u8mf4(vuint8mf4_t *, vuint8mf4_t *, vuint8mf4_t *, vuint8mf4_t *, const uint8_t *, vuint16mf2_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vloxseg4ei16_v_m)))
void vloxseg4ei16_v_u8mf4_m(vuint8mf4_t *, vuint8mf4_t *, vuint8mf4_t *, vuint8mf4_t *, vbool32_t, vuint8mf4_t, vuint8mf4_t, vuint8mf4_t, vuint8mf4_t, const uint8_t *, vuint16mf2_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vloxseg4ei16_v)))
void vloxseg4ei16_v_u8mf8(vuint8mf8_t *, vuint8mf8_t *, vuint8mf8_t *, vuint8mf8_t *, const uint8_t *, vuint16mf4_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vloxseg4ei16_v_m)))
void vloxseg4ei16_v_u8mf8_m(vuint8mf8_t *, vuint8mf8_t *, vuint8mf8_t *, vuint8mf8_t *, vbool64_t, vuint8mf8_t, vuint8mf8_t, vuint8mf8_t, vuint8mf8_t, const uint8_t *, vuint16mf4_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vloxseg5ei16_v)))
void vloxseg5ei16_v_i8m1(vint8m1_t *, vint8m1_t *, vint8m1_t *, vint8m1_t *, vint8m1_t *, const int8_t *, vuint16m2_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vloxseg5ei16_v_m)))
void vloxseg5ei16_v_i8m1_m(vint8m1_t *, vint8m1_t *, vint8m1_t *, vint8m1_t *, vint8m1_t *, vbool8_t, vint8m1_t, vint8m1_t, vint8m1_t, vint8m1_t, vint8m1_t, const int8_t *, vuint16m2_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vloxseg5ei16_v)))
void vloxseg5ei16_v_i8mf2(vint8mf2_t *, vint8mf2_t *, vint8mf2_t *, vint8mf2_t *, vint8mf2_t *, const int8_t *, vuint16m1_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vloxseg5ei16_v_m)))
void vloxseg5ei16_v_i8mf2_m(vint8mf2_t *, vint8mf2_t *, vint8mf2_t *, vint8mf2_t *, vint8mf2_t *, vbool16_t, vint8mf2_t, vint8mf2_t, vint8mf2_t, vint8mf2_t, vint8mf2_t, const int8_t *, vuint16m1_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vloxseg5ei16_v)))
void vloxseg5ei16_v_i8mf4(vint8mf4_t *, vint8mf4_t *, vint8mf4_t *, vint8mf4_t *, vint8mf4_t *, const int8_t *, vuint16mf2_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vloxseg5ei16_v_m)))
void vloxseg5ei16_v_i8mf4_m(vint8mf4_t *, vint8mf4_t *, vint8mf4_t *, vint8mf4_t *, vint8mf4_t *, vbool32_t, vint8mf4_t, vint8mf4_t, vint8mf4_t, vint8mf4_t, vint8mf4_t, const int8_t *, vuint16mf2_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vloxseg5ei16_v)))
void vloxseg5ei16_v_i8mf8(vint8mf8_t *, vint8mf8_t *, vint8mf8_t *, vint8mf8_t *, vint8mf8_t *, const int8_t *, vuint16mf4_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vloxseg5ei16_v_m)))
void vloxseg5ei16_v_i8mf8_m(vint8mf8_t *, vint8mf8_t *, vint8mf8_t *, vint8mf8_t *, vint8mf8_t *, vbool64_t, vint8mf8_t, vint8mf8_t, vint8mf8_t, vint8mf8_t, vint8mf8_t, const int8_t *, vuint16mf4_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vloxseg5ei16_v)))
void vloxseg5ei16_v_u8m1(vuint8m1_t *, vuint8m1_t *, vuint8m1_t *, vuint8m1_t *, vuint8m1_t *, const uint8_t *, vuint16m2_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vloxseg5ei16_v_m)))
void vloxseg5ei16_v_u8m1_m(vuint8m1_t *, vuint8m1_t *, vuint8m1_t *, vuint8m1_t *, vuint8m1_t *, vbool8_t, vuint8m1_t, vuint8m1_t, vuint8m1_t, vuint8m1_t, vuint8m1_t, const uint8_t *, vuint16m2_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vloxseg5ei16_v)))
void vloxseg5ei16_v_u8mf2(vuint8mf2_t *, vuint8mf2_t *, vuint8mf2_t *, vuint8mf2_t *, vuint8mf2_t *, const uint8_t *, vuint16m1_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vloxseg5ei16_v_m)))
void vloxseg5ei16_v_u8mf2_m(vuint8mf2_t *, vuint8mf2_t *, vuint8mf2_t *, vuint8mf2_t *, vuint8mf2_t *, vbool16_t, vuint8mf2_t, vuint8mf2_t, vuint8mf2_t, vuint8mf2_t, vuint8mf2_t, const uint8_t *, vuint16m1_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vloxseg5ei16_v)))
void vloxseg5ei16_v_u8mf4(vuint8mf4_t *, vuint8mf4_t *, vuint8mf4_t *, vuint8mf4_t *, vuint8mf4_t *, const uint8_t *, vuint16mf2_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vloxseg5ei16_v_m)))
void vloxseg5ei16_v_u8mf4_m(vuint8mf4_t *, vuint8mf4_t *, vuint8mf4_t *, vuint8mf4_t *, vuint8mf4_t *, vbool32_t, vuint8mf4_t, vuint8mf4_t, vuint8mf4_t, vuint8mf4_t, vuint8mf4_t, const uint8_t *, vuint16mf2_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vloxseg5ei16_v)))
void vloxseg5ei16_v_u8mf8(vuint8mf8_t *, vuint8mf8_t *, vuint8mf8_t *, vuint8mf8_t *, vuint8mf8_t *, const uint8_t *, vuint16mf4_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vloxseg5ei16_v_m)))
void vloxseg5ei16_v_u8mf8_m(vuint8mf8_t *, vuint8mf8_t *, vuint8mf8_t *, vuint8mf8_t *, vuint8mf8_t *, vbool64_t, vuint8mf8_t, vuint8mf8_t, vuint8mf8_t, vuint8mf8_t, vuint8mf8_t, const uint8_t *, vuint16mf4_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vloxseg6ei16_v)))
void vloxseg6ei16_v_i8m1(vint8m1_t *, vint8m1_t *, vint8m1_t *, vint8m1_t *, vint8m1_t *, vint8m1_t *, const int8_t *, vuint16m2_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vloxseg6ei16_v_m)))
void vloxseg6ei16_v_i8m1_m(vint8m1_t *, vint8m1_t *, vint8m1_t *, vint8m1_t *, vint8m1_t *, vint8m1_t *, vbool8_t, vint8m1_t, vint8m1_t, vint8m1_t, vint8m1_t, vint8m1_t, vint8m1_t, const int8_t *, vuint16m2_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vloxseg6ei16_v)))
void vloxseg6ei16_v_i8mf2(vint8mf2_t *, vint8mf2_t *, vint8mf2_t *, vint8mf2_t *, vint8mf2_t *, vint8mf2_t *, const int8_t *, vuint16m1_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vloxseg6ei16_v_m)))
void vloxseg6ei16_v_i8mf2_m(vint8mf2_t *, vint8mf2_t *, vint8mf2_t *, vint8mf2_t *, vint8mf2_t *, vint8mf2_t *, vbool16_t, vint8mf2_t, vint8mf2_t, vint8mf2_t, vint8mf2_t, vint8mf2_t, vint8mf2_t, const int8_t *, vuint16m1_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vloxseg6ei16_v)))
void vloxseg6ei16_v_i8mf4(vint8mf4_t *, vint8mf4_t *, vint8mf4_t *, vint8mf4_t *, vint8mf4_t *, vint8mf4_t *, const int8_t *, vuint16mf2_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vloxseg6ei16_v_m)))
void vloxseg6ei16_v_i8mf4_m(vint8mf4_t *, vint8mf4_t *, vint8mf4_t *, vint8mf4_t *, vint8mf4_t *, vint8mf4_t *, vbool32_t, vint8mf4_t, vint8mf4_t, vint8mf4_t, vint8mf4_t, vint8mf4_t, vint8mf4_t, const int8_t *, vuint16mf2_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vloxseg6ei16_v)))
void vloxseg6ei16_v_i8mf8(vint8mf8_t *, vint8mf8_t *, vint8mf8_t *, vint8mf8_t *, vint8mf8_t *, vint8mf8_t *, const int8_t *, vuint16mf4_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vloxseg6ei16_v_m)))
void vloxseg6ei16_v_i8mf8_m(vint8mf8_t *, vint8mf8_t *, vint8mf8_t *, vint8mf8_t *, vint8mf8_t *, vint8mf8_t *, vbool64_t, vint8mf8_t, vint8mf8_t, vint8mf8_t, vint8mf8_t, vint8mf8_t, vint8mf8_t, const int8_t *, vuint16mf4_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vloxseg6ei16_v)))
void vloxseg6ei16_v_u8m1(vuint8m1_t *, vuint8m1_t *, vuint8m1_t *, vuint8m1_t *, vuint8m1_t *, vuint8m1_t *, const uint8_t *, vuint16m2_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vloxseg6ei16_v_m)))
void vloxseg6ei16_v_u8m1_m(vuint8m1_t *, vuint8m1_t *, vuint8m1_t *, vuint8m1_t *, vuint8m1_t *, vuint8m1_t *, vbool8_t, vuint8m1_t, vuint8m1_t, vuint8m1_t, vuint8m1_t, vuint8m1_t, vuint8m1_t, const uint8_t *, vuint16m2_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vloxseg6ei16_v)))
void vloxseg6ei16_v_u8mf2(vuint8mf2_t *, vuint8mf2_t *, vuint8mf2_t *, vuint8mf2_t *, vuint8mf2_t *, vuint8mf2_t *, const uint8_t *, vuint16m1_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vloxseg6ei16_v_m)))
void vloxseg6ei16_v_u8mf2_m(vuint8mf2_t *, vuint8mf2_t *, vuint8mf2_t *, vuint8mf2_t *, vuint8mf2_t *, vuint8mf2_t *, vbool16_t, vuint8mf2_t, vuint8mf2_t, vuint8mf2_t, vuint8mf2_t, vuint8mf2_t, vuint8mf2_t, const uint8_t *, vuint16m1_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vloxseg6ei16_v)))
void vloxseg6ei16_v_u8mf4(vuint8mf4_t *, vuint8mf4_t *, vuint8mf4_t *, vuint8mf4_t *, vuint8mf4_t *, vuint8mf4_t *, const uint8_t *, vuint16mf2_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vloxseg6ei16_v_m)))
void vloxseg6ei16_v_u8mf4_m(vuint8mf4_t *, vuint8mf4_t *, vuint8mf4_t *, vuint8mf4_t *, vuint8mf4_t *, vuint8mf4_t *, vbool32_t, vuint8mf4_t, vuint8mf4_t, vuint8mf4_t, vuint8mf4_t, vuint8mf4_t, vuint8mf4_t, const uint8_t *, vuint16mf2_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vloxseg6ei16_v)))
void vloxseg6ei16_v_u8mf8(vuint8mf8_t *, vuint8mf8_t *, vuint8mf8_t *, vuint8mf8_t *, vuint8mf8_t *, vuint8mf8_t *, const uint8_t *, vuint16mf4_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vloxseg6ei16_v_m)))
void vloxseg6ei16_v_u8mf8_m(vuint8mf8_t *, vuint8mf8_t *, vuint8mf8_t *, vuint8mf8_t *, vuint8mf8_t *, vuint8mf8_t *, vbool64_t, vuint8mf8_t, vuint8mf8_t, vuint8mf8_t, vuint8mf8_t, vuint8mf8_t, vuint8mf8_t, const uint8_t *, vuint16mf4_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vloxseg7ei16_v)))
void vloxseg7ei16_v_i8m1(vint8m1_t *, vint8m1_t *, vint8m1_t *, vint8m1_t *, vint8m1_t *, vint8m1_t *, vint8m1_t *, const int8_t *, vuint16m2_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vloxseg7ei16_v_m)))
void vloxseg7ei16_v_i8m1_m(vint8m1_t *, vint8m1_t *, vint8m1_t *, vint8m1_t *, vint8m1_t *, vint8m1_t *, vint8m1_t *, vbool8_t, vint8m1_t, vint8m1_t, vint8m1_t, vint8m1_t, vint8m1_t, vint8m1_t, vint8m1_t, const int8_t *, vuint16m2_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vloxseg7ei16_v)))
void vloxseg7ei16_v_i8mf2(vint8mf2_t *, vint8mf2_t *, vint8mf2_t *, vint8mf2_t *, vint8mf2_t *, vint8mf2_t *, vint8mf2_t *, const int8_t *, vuint16m1_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vloxseg7ei16_v_m)))
void vloxseg7ei16_v_i8mf2_m(vint8mf2_t *, vint8mf2_t *, vint8mf2_t *, vint8mf2_t *, vint8mf2_t *, vint8mf2_t *, vint8mf2_t *, vbool16_t, vint8mf2_t, vint8mf2_t, vint8mf2_t, vint8mf2_t, vint8mf2_t, vint8mf2_t, vint8mf2_t, const int8_t *, vuint16m1_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vloxseg7ei16_v)))
void vloxseg7ei16_v_i8mf4(vint8mf4_t *, vint8mf4_t *, vint8mf4_t *, vint8mf4_t *, vint8mf4_t *, vint8mf4_t *, vint8mf4_t *, const int8_t *, vuint16mf2_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vloxseg7ei16_v_m)))
void vloxseg7ei16_v_i8mf4_m(vint8mf4_t *, vint8mf4_t *, vint8mf4_t *, vint8mf4_t *, vint8mf4_t *, vint8mf4_t *, vint8mf4_t *, vbool32_t, vint8mf4_t, vint8mf4_t, vint8mf4_t, vint8mf4_t, vint8mf4_t, vint8mf4_t, vint8mf4_t, const int8_t *, vuint16mf2_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vloxseg7ei16_v)))
void vloxseg7ei16_v_i8mf8(vint8mf8_t *, vint8mf8_t *, vint8mf8_t *, vint8mf8_t *, vint8mf8_t *, vint8mf8_t *, vint8mf8_t *, const int8_t *, vuint16mf4_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vloxseg7ei16_v_m)))
void vloxseg7ei16_v_i8mf8_m(vint8mf8_t *, vint8mf8_t *, vint8mf8_t *, vint8mf8_t *, vint8mf8_t *, vint8mf8_t *, vint8mf8_t *, vbool64_t, vint8mf8_t, vint8mf8_t, vint8mf8_t, vint8mf8_t, vint8mf8_t, vint8mf8_t, vint8mf8_t, const int8_t *, vuint16mf4_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vloxseg7ei16_v)))
void vloxseg7ei16_v_u8m1(vuint8m1_t *, vuint8m1_t *, vuint8m1_t *, vuint8m1_t *, vuint8m1_t *, vuint8m1_t *, vuint8m1_t *, const uint8_t *, vuint16m2_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vloxseg7ei16_v_m)))
void vloxseg7ei16_v_u8m1_m(vuint8m1_t *, vuint8m1_t *, vuint8m1_t *, vuint8m1_t *, vuint8m1_t *, vuint8m1_t *, vuint8m1_t *, vbool8_t, vuint8m1_t, vuint8m1_t, vuint8m1_t, vuint8m1_t, vuint8m1_t, vuint8m1_t, vuint8m1_t, const uint8_t *, vuint16m2_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vloxseg7ei16_v)))
void vloxseg7ei16_v_u8mf2(vuint8mf2_t *, vuint8mf2_t *, vuint8mf2_t *, vuint8mf2_t *, vuint8mf2_t *, vuint8mf2_t *, vuint8mf2_t *, const uint8_t *, vuint16m1_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vloxseg7ei16_v_m)))
void vloxseg7ei16_v_u8mf2_m(vuint8mf2_t *, vuint8mf2_t *, vuint8mf2_t *, vuint8mf2_t *, vuint8mf2_t *, vuint8mf2_t *, vuint8mf2_t *, vbool16_t, vuint8mf2_t, vuint8mf2_t, vuint8mf2_t, vuint8mf2_t, vuint8mf2_t, vuint8mf2_t, vuint8mf2_t, const uint8_t *, vuint16m1_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vloxseg7ei16_v)))
void vloxseg7ei16_v_u8mf4(vuint8mf4_t *, vuint8mf4_t *, vuint8mf4_t *, vuint8mf4_t *, vuint8mf4_t *, vuint8mf4_t *, vuint8mf4_t *, const uint8_t *, vuint16mf2_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vloxseg7ei16_v_m)))
void vloxseg7ei16_v_u8mf4_m(vuint8mf4_t *, vuint8mf4_t *, vuint8mf4_t *, vuint8mf4_t *, vuint8mf4_t *, vuint8mf4_t *, vuint8mf4_t *, vbool32_t, vuint8mf4_t, vuint8mf4_t, vuint8mf4_t, vuint8mf4_t, vuint8mf4_t, vuint8mf4_t, vuint8mf4_t, const uint8_t *, vuint16mf2_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vloxseg7ei16_v)))
void vloxseg7ei16_v_u8mf8(vuint8mf8_t *, vuint8mf8_t *, vuint8mf8_t *, vuint8mf8_t *, vuint8mf8_t *, vuint8mf8_t *, vuint8mf8_t *, const uint8_t *, vuint16mf4_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vloxseg7ei16_v_m)))
void vloxseg7ei16_v_u8mf8_m(vuint8mf8_t *, vuint8mf8_t *, vuint8mf8_t *, vuint8mf8_t *, vuint8mf8_t *, vuint8mf8_t *, vuint8mf8_t *, vbool64_t, vuint8mf8_t, vuint8mf8_t, vuint8mf8_t, vuint8mf8_t, vuint8mf8_t, vuint8mf8_t, vuint8mf8_t, const uint8_t *, vuint16mf4_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vloxseg8ei16_v)))
void vloxseg8ei16_v_i8m1(vint8m1_t *, vint8m1_t *, vint8m1_t *, vint8m1_t *, vint8m1_t *, vint8m1_t *, vint8m1_t *, vint8m1_t *, const int8_t *, vuint16m2_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vloxseg8ei16_v_m)))
void vloxseg8ei16_v_i8m1_m(vint8m1_t *, vint8m1_t *, vint8m1_t *, vint8m1_t *, vint8m1_t *, vint8m1_t *, vint8m1_t *, vint8m1_t *, vbool8_t, vint8m1_t, vint8m1_t, vint8m1_t, vint8m1_t, vint8m1_t, vint8m1_t, vint8m1_t, vint8m1_t, const int8_t *, vuint16m2_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vloxseg8ei16_v)))
void vloxseg8ei16_v_i8mf2(vint8mf2_t *, vint8mf2_t *, vint8mf2_t *, vint8mf2_t *, vint8mf2_t *, vint8mf2_t *, vint8mf2_t *, vint8mf2_t *, const int8_t *, vuint16m1_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vloxseg8ei16_v_m)))
void vloxseg8ei16_v_i8mf2_m(vint8mf2_t *, vint8mf2_t *, vint8mf2_t *, vint8mf2_t *, vint8mf2_t *, vint8mf2_t *, vint8mf2_t *, vint8mf2_t *, vbool16_t, vint8mf2_t, vint8mf2_t, vint8mf2_t, vint8mf2_t, vint8mf2_t, vint8mf2_t, vint8mf2_t, vint8mf2_t, const int8_t *, vuint16m1_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vloxseg8ei16_v)))
void vloxseg8ei16_v_i8mf4(vint8mf4_t *, vint8mf4_t *, vint8mf4_t *, vint8mf4_t *, vint8mf4_t *, vint8mf4_t *, vint8mf4_t *, vint8mf4_t *, const int8_t *, vuint16mf2_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vloxseg8ei16_v_m)))
void vloxseg8ei16_v_i8mf4_m(vint8mf4_t *, vint8mf4_t *, vint8mf4_t *, vint8mf4_t *, vint8mf4_t *, vint8mf4_t *, vint8mf4_t *, vint8mf4_t *, vbool32_t, vint8mf4_t, vint8mf4_t, vint8mf4_t, vint8mf4_t, vint8mf4_t, vint8mf4_t, vint8mf4_t, vint8mf4_t, const int8_t *, vuint16mf2_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vloxseg8ei16_v)))
void vloxseg8ei16_v_i8mf8(vint8mf8_t *, vint8mf8_t *, vint8mf8_t *, vint8mf8_t *, vint8mf8_t *, vint8mf8_t *, vint8mf8_t *, vint8mf8_t *, const int8_t *, vuint16mf4_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vloxseg8ei16_v_m)))
void vloxseg8ei16_v_i8mf8_m(vint8mf8_t *, vint8mf8_t *, vint8mf8_t *, vint8mf8_t *, vint8mf8_t *, vint8mf8_t *, vint8mf8_t *, vint8mf8_t *, vbool64_t, vint8mf8_t, vint8mf8_t, vint8mf8_t, vint8mf8_t, vint8mf8_t, vint8mf8_t, vint8mf8_t, vint8mf8_t, const int8_t *, vuint16mf4_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vloxseg8ei16_v)))
void vloxseg8ei16_v_u8m1(vuint8m1_t *, vuint8m1_t *, vuint8m1_t *, vuint8m1_t *, vuint8m1_t *, vuint8m1_t *, vuint8m1_t *, vuint8m1_t *, const uint8_t *, vuint16m2_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vloxseg8ei16_v_m)))
void vloxseg8ei16_v_u8m1_m(vuint8m1_t *, vuint8m1_t *, vuint8m1_t *, vuint8m1_t *, vuint8m1_t *, vuint8m1_t *, vuint8m1_t *, vuint8m1_t *, vbool8_t, vuint8m1_t, vuint8m1_t, vuint8m1_t, vuint8m1_t, vuint8m1_t, vuint8m1_t, vuint8m1_t, vuint8m1_t, const uint8_t *, vuint16m2_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vloxseg8ei16_v)))
void vloxseg8ei16_v_u8mf2(vuint8mf2_t *, vuint8mf2_t *, vuint8mf2_t *, vuint8mf2_t *, vuint8mf2_t *, vuint8mf2_t *, vuint8mf2_t *, vuint8mf2_t *, const uint8_t *, vuint16m1_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vloxseg8ei16_v_m)))
void vloxseg8ei16_v_u8mf2_m(vuint8mf2_t *, vuint8mf2_t *, vuint8mf2_t *, vuint8mf2_t *, vuint8mf2_t *, vuint8mf2_t *, vuint8mf2_t *, vuint8mf2_t *, vbool16_t, vuint8mf2_t, vuint8mf2_t, vuint8mf2_t, vuint8mf2_t, vuint8mf2_t, vuint8mf2_t, vuint8mf2_t, vuint8mf2_t, const uint8_t *, vuint16m1_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vloxseg8ei16_v)))
void vloxseg8ei16_v_u8mf4(vuint8mf4_t *, vuint8mf4_t *, vuint8mf4_t *, vuint8mf4_t *, vuint8mf4_t *, vuint8mf4_t *, vuint8mf4_t *, vuint8mf4_t *, const uint8_t *, vuint16mf2_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vloxseg8ei16_v_m)))
void vloxseg8ei16_v_u8mf4_m(vuint8mf4_t *, vuint8mf4_t *, vuint8mf4_t *, vuint8mf4_t *, vuint8mf4_t *, vuint8mf4_t *, vuint8mf4_t *, vuint8mf4_t *, vbool32_t, vuint8mf4_t, vuint8mf4_t, vuint8mf4_t, vuint8mf4_t, vuint8mf4_t, vuint8mf4_t, vuint8mf4_t, vuint8mf4_t, const uint8_t *, vuint16mf2_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vloxseg8ei16_v)))
void vloxseg8ei16_v_u8mf8(vuint8mf8_t *, vuint8mf8_t *, vuint8mf8_t *, vuint8mf8_t *, vuint8mf8_t *, vuint8mf8_t *, vuint8mf8_t *, vuint8mf8_t *, const uint8_t *, vuint16mf4_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vloxseg8ei16_v_m)))
void vloxseg8ei16_v_u8mf8_m(vuint8mf8_t *, vuint8mf8_t *, vuint8mf8_t *, vuint8mf8_t *, vuint8mf8_t *, vuint8mf8_t *, vuint8mf8_t *, vuint8mf8_t *, vbool64_t, vuint8mf8_t, vuint8mf8_t, vuint8mf8_t, vuint8mf8_t, vuint8mf8_t, vuint8mf8_t, vuint8mf8_t, vuint8mf8_t, const uint8_t *, vuint16mf4_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vloxseg2ei32_v)))
void vloxseg2ei32_v_i8m1(vint8m1_t *, vint8m1_t *, const int8_t *, vuint32m4_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vloxseg2ei32_v_m)))
void vloxseg2ei32_v_i8m1_m(vint8m1_t *, vint8m1_t *, vbool8_t, vint8m1_t, vint8m1_t, const int8_t *, vuint32m4_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vloxseg2ei32_v)))
void vloxseg2ei32_v_i8m2(vint8m2_t *, vint8m2_t *, const int8_t *, vuint32m8_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vloxseg2ei32_v_m)))
void vloxseg2ei32_v_i8m2_m(vint8m2_t *, vint8m2_t *, vbool4_t, vint8m2_t, vint8m2_t, const int8_t *, vuint32m8_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vloxseg2ei32_v)))
void vloxseg2ei32_v_i8mf2(vint8mf2_t *, vint8mf2_t *, const int8_t *, vuint32m2_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vloxseg2ei32_v_m)))
void vloxseg2ei32_v_i8mf2_m(vint8mf2_t *, vint8mf2_t *, vbool16_t, vint8mf2_t, vint8mf2_t, const int8_t *, vuint32m2_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vloxseg2ei32_v)))
void vloxseg2ei32_v_i8mf4(vint8mf4_t *, vint8mf4_t *, const int8_t *, vuint32m1_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vloxseg2ei32_v_m)))
void vloxseg2ei32_v_i8mf4_m(vint8mf4_t *, vint8mf4_t *, vbool32_t, vint8mf4_t, vint8mf4_t, const int8_t *, vuint32m1_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vloxseg2ei32_v)))
void vloxseg2ei32_v_i8mf8(vint8mf8_t *, vint8mf8_t *, const int8_t *, vuint32mf2_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vloxseg2ei32_v_m)))
void vloxseg2ei32_v_i8mf8_m(vint8mf8_t *, vint8mf8_t *, vbool64_t, vint8mf8_t, vint8mf8_t, const int8_t *, vuint32mf2_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vloxseg2ei32_v)))
void vloxseg2ei32_v_u8m1(vuint8m1_t *, vuint8m1_t *, const uint8_t *, vuint32m4_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vloxseg2ei32_v_m)))
void vloxseg2ei32_v_u8m1_m(vuint8m1_t *, vuint8m1_t *, vbool8_t, vuint8m1_t, vuint8m1_t, const uint8_t *, vuint32m4_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vloxseg2ei32_v)))
void vloxseg2ei32_v_u8m2(vuint8m2_t *, vuint8m2_t *, const uint8_t *, vuint32m8_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vloxseg2ei32_v_m)))
void vloxseg2ei32_v_u8m2_m(vuint8m2_t *, vuint8m2_t *, vbool4_t, vuint8m2_t, vuint8m2_t, const uint8_t *, vuint32m8_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vloxseg2ei32_v)))
void vloxseg2ei32_v_u8mf2(vuint8mf2_t *, vuint8mf2_t *, const uint8_t *, vuint32m2_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vloxseg2ei32_v_m)))
void vloxseg2ei32_v_u8mf2_m(vuint8mf2_t *, vuint8mf2_t *, vbool16_t, vuint8mf2_t, vuint8mf2_t, const uint8_t *, vuint32m2_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vloxseg2ei32_v)))
void vloxseg2ei32_v_u8mf4(vuint8mf4_t *, vuint8mf4_t *, const uint8_t *, vuint32m1_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vloxseg2ei32_v_m)))
void vloxseg2ei32_v_u8mf4_m(vuint8mf4_t *, vuint8mf4_t *, vbool32_t, vuint8mf4_t, vuint8mf4_t, const uint8_t *, vuint32m1_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vloxseg2ei32_v)))
void vloxseg2ei32_v_u8mf8(vuint8mf8_t *, vuint8mf8_t *, const uint8_t *, vuint32mf2_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vloxseg2ei32_v_m)))
void vloxseg2ei32_v_u8mf8_m(vuint8mf8_t *, vuint8mf8_t *, vbool64_t, vuint8mf8_t, vuint8mf8_t, const uint8_t *, vuint32mf2_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vse16_v)))
void vse16_v_i16m1(int16_t *, vint16m1_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vse16_v_m)))
void vse16_v_i16m1_m(vbool16_t, int16_t *, vint16m1_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vse16_v)))
void vse16_v_i16m2(int16_t *, vint16m2_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vse16_v_m)))
void vse16_v_i16m2_m(vbool8_t, int16_t *, vint16m2_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vse16_v)))
void vse16_v_i16m4(int16_t *, vint16m4_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vse16_v_m)))
void vse16_v_i16m4_m(vbool4_t, int16_t *, vint16m4_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vse16_v)))
void vse16_v_i16m8(int16_t *, vint16m8_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vse16_v_m)))
void vse16_v_i16m8_m(vbool2_t, int16_t *, vint16m8_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vse16_v)))
void vse16_v_i16mf2(int16_t *, vint16mf2_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vse16_v_m)))
void vse16_v_i16mf2_m(vbool32_t, int16_t *, vint16mf2_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vse16_v)))
void vse16_v_i16mf4(int16_t *, vint16mf4_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vse16_v_m)))
void vse16_v_i16mf4_m(vbool64_t, int16_t *, vint16mf4_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vloxseg3ei32_v)))
void vloxseg3ei32_v_i8m1(vint8m1_t *, vint8m1_t *, vint8m1_t *, const int8_t *, vuint32m4_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vloxseg3ei32_v_m)))
void vloxseg3ei32_v_i8m1_m(vint8m1_t *, vint8m1_t *, vint8m1_t *, vbool8_t, vint8m1_t, vint8m1_t, vint8m1_t, const int8_t *, vuint32m4_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vloxseg3ei32_v)))
void vloxseg3ei32_v_i8m2(vint8m2_t *, vint8m2_t *, vint8m2_t *, const int8_t *, vuint32m8_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vloxseg3ei32_v_m)))
void vloxseg3ei32_v_i8m2_m(vint8m2_t *, vint8m2_t *, vint8m2_t *, vbool4_t, vint8m2_t, vint8m2_t, vint8m2_t, const int8_t *, vuint32m8_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vloxseg3ei32_v)))
void vloxseg3ei32_v_i8mf2(vint8mf2_t *, vint8mf2_t *, vint8mf2_t *, const int8_t *, vuint32m2_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vloxseg3ei32_v_m)))
void vloxseg3ei32_v_i8mf2_m(vint8mf2_t *, vint8mf2_t *, vint8mf2_t *, vbool16_t, vint8mf2_t, vint8mf2_t, vint8mf2_t, const int8_t *, vuint32m2_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vloxseg3ei32_v)))
void vloxseg3ei32_v_i8mf4(vint8mf4_t *, vint8mf4_t *, vint8mf4_t *, const int8_t *, vuint32m1_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vloxseg3ei32_v_m)))
void vloxseg3ei32_v_i8mf4_m(vint8mf4_t *, vint8mf4_t *, vint8mf4_t *, vbool32_t, vint8mf4_t, vint8mf4_t, vint8mf4_t, const int8_t *, vuint32m1_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vloxseg3ei32_v)))
void vloxseg3ei32_v_i8mf8(vint8mf8_t *, vint8mf8_t *, vint8mf8_t *, const int8_t *, vuint32mf2_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vloxseg3ei32_v_m)))
void vloxseg3ei32_v_i8mf8_m(vint8mf8_t *, vint8mf8_t *, vint8mf8_t *, vbool64_t, vint8mf8_t, vint8mf8_t, vint8mf8_t, const int8_t *, vuint32mf2_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vloxseg3ei32_v)))
void vloxseg3ei32_v_u8m1(vuint8m1_t *, vuint8m1_t *, vuint8m1_t *, const uint8_t *, vuint32m4_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vloxseg3ei32_v_m)))
void vloxseg3ei32_v_u8m1_m(vuint8m1_t *, vuint8m1_t *, vuint8m1_t *, vbool8_t, vuint8m1_t, vuint8m1_t, vuint8m1_t, const uint8_t *, vuint32m4_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vloxseg3ei32_v)))
void vloxseg3ei32_v_u8m2(vuint8m2_t *, vuint8m2_t *, vuint8m2_t *, const uint8_t *, vuint32m8_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vloxseg3ei32_v_m)))
void vloxseg3ei32_v_u8m2_m(vuint8m2_t *, vuint8m2_t *, vuint8m2_t *, vbool4_t, vuint8m2_t, vuint8m2_t, vuint8m2_t, const uint8_t *, vuint32m8_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vloxseg3ei32_v)))
void vloxseg3ei32_v_u8mf2(vuint8mf2_t *, vuint8mf2_t *, vuint8mf2_t *, const uint8_t *, vuint32m2_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vloxseg3ei32_v_m)))
void vloxseg3ei32_v_u8mf2_m(vuint8mf2_t *, vuint8mf2_t *, vuint8mf2_t *, vbool16_t, vuint8mf2_t, vuint8mf2_t, vuint8mf2_t, const uint8_t *, vuint32m2_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vloxseg3ei32_v)))
void vloxseg3ei32_v_u8mf4(vuint8mf4_t *, vuint8mf4_t *, vuint8mf4_t *, const uint8_t *, vuint32m1_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vloxseg3ei32_v_m)))
void vloxseg3ei32_v_u8mf4_m(vuint8mf4_t *, vuint8mf4_t *, vuint8mf4_t *, vbool32_t, vuint8mf4_t, vuint8mf4_t, vuint8mf4_t, const uint8_t *, vuint32m1_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vloxseg3ei32_v)))
void vloxseg3ei32_v_u8mf8(vuint8mf8_t *, vuint8mf8_t *, vuint8mf8_t *, const uint8_t *, vuint32mf2_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vloxseg3ei32_v_m)))
void vloxseg3ei32_v_u8mf8_m(vuint8mf8_t *, vuint8mf8_t *, vuint8mf8_t *, vbool64_t, vuint8mf8_t, vuint8mf8_t, vuint8mf8_t, const uint8_t *, vuint32mf2_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vloxseg4ei32_v)))
void vloxseg4ei32_v_i8m1(vint8m1_t *, vint8m1_t *, vint8m1_t *, vint8m1_t *, const int8_t *, vuint32m4_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vloxseg4ei32_v_m)))
void vloxseg4ei32_v_i8m1_m(vint8m1_t *, vint8m1_t *, vint8m1_t *, vint8m1_t *, vbool8_t, vint8m1_t, vint8m1_t, vint8m1_t, vint8m1_t, const int8_t *, vuint32m4_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vloxseg4ei32_v)))
void vloxseg4ei32_v_i8m2(vint8m2_t *, vint8m2_t *, vint8m2_t *, vint8m2_t *, const int8_t *, vuint32m8_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vloxseg4ei32_v_m)))
void vloxseg4ei32_v_i8m2_m(vint8m2_t *, vint8m2_t *, vint8m2_t *, vint8m2_t *, vbool4_t, vint8m2_t, vint8m2_t, vint8m2_t, vint8m2_t, const int8_t *, vuint32m8_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vloxseg4ei32_v)))
void vloxseg4ei32_v_i8mf2(vint8mf2_t *, vint8mf2_t *, vint8mf2_t *, vint8mf2_t *, const int8_t *, vuint32m2_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vloxseg4ei32_v_m)))
void vloxseg4ei32_v_i8mf2_m(vint8mf2_t *, vint8mf2_t *, vint8mf2_t *, vint8mf2_t *, vbool16_t, vint8mf2_t, vint8mf2_t, vint8mf2_t, vint8mf2_t, const int8_t *, vuint32m2_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vloxseg4ei32_v)))
void vloxseg4ei32_v_i8mf4(vint8mf4_t *, vint8mf4_t *, vint8mf4_t *, vint8mf4_t *, const int8_t *, vuint32m1_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vloxseg4ei32_v_m)))
void vloxseg4ei32_v_i8mf4_m(vint8mf4_t *, vint8mf4_t *, vint8mf4_t *, vint8mf4_t *, vbool32_t, vint8mf4_t, vint8mf4_t, vint8mf4_t, vint8mf4_t, const int8_t *, vuint32m1_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vloxseg4ei32_v)))
void vloxseg4ei32_v_i8mf8(vint8mf8_t *, vint8mf8_t *, vint8mf8_t *, vint8mf8_t *, const int8_t *, vuint32mf2_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vloxseg4ei32_v_m)))
void vloxseg4ei32_v_i8mf8_m(vint8mf8_t *, vint8mf8_t *, vint8mf8_t *, vint8mf8_t *, vbool64_t, vint8mf8_t, vint8mf8_t, vint8mf8_t, vint8mf8_t, const int8_t *, vuint32mf2_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vloxseg4ei32_v)))
void vloxseg4ei32_v_u8m1(vuint8m1_t *, vuint8m1_t *, vuint8m1_t *, vuint8m1_t *, const uint8_t *, vuint32m4_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vloxseg4ei32_v_m)))
void vloxseg4ei32_v_u8m1_m(vuint8m1_t *, vuint8m1_t *, vuint8m1_t *, vuint8m1_t *, vbool8_t, vuint8m1_t, vuint8m1_t, vuint8m1_t, vuint8m1_t, const uint8_t *, vuint32m4_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vloxseg4ei32_v)))
void vloxseg4ei32_v_u8m2(vuint8m2_t *, vuint8m2_t *, vuint8m2_t *, vuint8m2_t *, const uint8_t *, vuint32m8_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vloxseg4ei32_v_m)))
void vloxseg4ei32_v_u8m2_m(vuint8m2_t *, vuint8m2_t *, vuint8m2_t *, vuint8m2_t *, vbool4_t, vuint8m2_t, vuint8m2_t, vuint8m2_t, vuint8m2_t, const uint8_t *, vuint32m8_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vloxseg4ei32_v)))
void vloxseg4ei32_v_u8mf2(vuint8mf2_t *, vuint8mf2_t *, vuint8mf2_t *, vuint8mf2_t *, const uint8_t *, vuint32m2_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vloxseg4ei32_v_m)))
void vloxseg4ei32_v_u8mf2_m(vuint8mf2_t *, vuint8mf2_t *, vuint8mf2_t *, vuint8mf2_t *, vbool16_t, vuint8mf2_t, vuint8mf2_t, vuint8mf2_t, vuint8mf2_t, const uint8_t *, vuint32m2_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vloxseg4ei32_v)))
void vloxseg4ei32_v_u8mf4(vuint8mf4_t *, vuint8mf4_t *, vuint8mf4_t *, vuint8mf4_t *, const uint8_t *, vuint32m1_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vloxseg4ei32_v_m)))
void vloxseg4ei32_v_u8mf4_m(vuint8mf4_t *, vuint8mf4_t *, vuint8mf4_t *, vuint8mf4_t *, vbool32_t, vuint8mf4_t, vuint8mf4_t, vuint8mf4_t, vuint8mf4_t, const uint8_t *, vuint32m1_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vloxseg4ei32_v)))
void vloxseg4ei32_v_u8mf8(vuint8mf8_t *, vuint8mf8_t *, vuint8mf8_t *, vuint8mf8_t *, const uint8_t *, vuint32mf2_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vloxseg4ei32_v_m)))
void vloxseg4ei32_v_u8mf8_m(vuint8mf8_t *, vuint8mf8_t *, vuint8mf8_t *, vuint8mf8_t *, vbool64_t, vuint8mf8_t, vuint8mf8_t, vuint8mf8_t, vuint8mf8_t, const uint8_t *, vuint32mf2_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vloxseg5ei32_v)))
void vloxseg5ei32_v_i8m1(vint8m1_t *, vint8m1_t *, vint8m1_t *, vint8m1_t *, vint8m1_t *, const int8_t *, vuint32m4_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vloxseg5ei32_v_m)))
void vloxseg5ei32_v_i8m1_m(vint8m1_t *, vint8m1_t *, vint8m1_t *, vint8m1_t *, vint8m1_t *, vbool8_t, vint8m1_t, vint8m1_t, vint8m1_t, vint8m1_t, vint8m1_t, const int8_t *, vuint32m4_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vloxseg5ei32_v)))
void vloxseg5ei32_v_i8mf2(vint8mf2_t *, vint8mf2_t *, vint8mf2_t *, vint8mf2_t *, vint8mf2_t *, const int8_t *, vuint32m2_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vloxseg5ei32_v_m)))
void vloxseg5ei32_v_i8mf2_m(vint8mf2_t *, vint8mf2_t *, vint8mf2_t *, vint8mf2_t *, vint8mf2_t *, vbool16_t, vint8mf2_t, vint8mf2_t, vint8mf2_t, vint8mf2_t, vint8mf2_t, const int8_t *, vuint32m2_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vloxseg5ei32_v)))
void vloxseg5ei32_v_i8mf4(vint8mf4_t *, vint8mf4_t *, vint8mf4_t *, vint8mf4_t *, vint8mf4_t *, const int8_t *, vuint32m1_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vloxseg5ei32_v_m)))
void vloxseg5ei32_v_i8mf4_m(vint8mf4_t *, vint8mf4_t *, vint8mf4_t *, vint8mf4_t *, vint8mf4_t *, vbool32_t, vint8mf4_t, vint8mf4_t, vint8mf4_t, vint8mf4_t, vint8mf4_t, const int8_t *, vuint32m1_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vloxseg5ei32_v)))
void vloxseg5ei32_v_i8mf8(vint8mf8_t *, vint8mf8_t *, vint8mf8_t *, vint8mf8_t *, vint8mf8_t *, const int8_t *, vuint32mf2_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vloxseg5ei32_v_m)))
void vloxseg5ei32_v_i8mf8_m(vint8mf8_t *, vint8mf8_t *, vint8mf8_t *, vint8mf8_t *, vint8mf8_t *, vbool64_t, vint8mf8_t, vint8mf8_t, vint8mf8_t, vint8mf8_t, vint8mf8_t, const int8_t *, vuint32mf2_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vloxseg5ei32_v)))
void vloxseg5ei32_v_u8m1(vuint8m1_t *, vuint8m1_t *, vuint8m1_t *, vuint8m1_t *, vuint8m1_t *, const uint8_t *, vuint32m4_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vloxseg5ei32_v_m)))
void vloxseg5ei32_v_u8m1_m(vuint8m1_t *, vuint8m1_t *, vuint8m1_t *, vuint8m1_t *, vuint8m1_t *, vbool8_t, vuint8m1_t, vuint8m1_t, vuint8m1_t, vuint8m1_t, vuint8m1_t, const uint8_t *, vuint32m4_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vloxseg5ei32_v)))
void vloxseg5ei32_v_u8mf2(vuint8mf2_t *, vuint8mf2_t *, vuint8mf2_t *, vuint8mf2_t *, vuint8mf2_t *, const uint8_t *, vuint32m2_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vloxseg5ei32_v_m)))
void vloxseg5ei32_v_u8mf2_m(vuint8mf2_t *, vuint8mf2_t *, vuint8mf2_t *, vuint8mf2_t *, vuint8mf2_t *, vbool16_t, vuint8mf2_t, vuint8mf2_t, vuint8mf2_t, vuint8mf2_t, vuint8mf2_t, const uint8_t *, vuint32m2_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vloxseg5ei32_v)))
void vloxseg5ei32_v_u8mf4(vuint8mf4_t *, vuint8mf4_t *, vuint8mf4_t *, vuint8mf4_t *, vuint8mf4_t *, const uint8_t *, vuint32m1_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vloxseg5ei32_v_m)))
void vloxseg5ei32_v_u8mf4_m(vuint8mf4_t *, vuint8mf4_t *, vuint8mf4_t *, vuint8mf4_t *, vuint8mf4_t *, vbool32_t, vuint8mf4_t, vuint8mf4_t, vuint8mf4_t, vuint8mf4_t, vuint8mf4_t, const uint8_t *, vuint32m1_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vloxseg5ei32_v)))
void vloxseg5ei32_v_u8mf8(vuint8mf8_t *, vuint8mf8_t *, vuint8mf8_t *, vuint8mf8_t *, vuint8mf8_t *, const uint8_t *, vuint32mf2_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vloxseg5ei32_v_m)))
void vloxseg5ei32_v_u8mf8_m(vuint8mf8_t *, vuint8mf8_t *, vuint8mf8_t *, vuint8mf8_t *, vuint8mf8_t *, vbool64_t, vuint8mf8_t, vuint8mf8_t, vuint8mf8_t, vuint8mf8_t, vuint8mf8_t, const uint8_t *, vuint32mf2_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vloxseg6ei32_v)))
void vloxseg6ei32_v_i8m1(vint8m1_t *, vint8m1_t *, vint8m1_t *, vint8m1_t *, vint8m1_t *, vint8m1_t *, const int8_t *, vuint32m4_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vloxseg6ei32_v_m)))
void vloxseg6ei32_v_i8m1_m(vint8m1_t *, vint8m1_t *, vint8m1_t *, vint8m1_t *, vint8m1_t *, vint8m1_t *, vbool8_t, vint8m1_t, vint8m1_t, vint8m1_t, vint8m1_t, vint8m1_t, vint8m1_t, const int8_t *, vuint32m4_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vloxseg6ei32_v)))
void vloxseg6ei32_v_i8mf2(vint8mf2_t *, vint8mf2_t *, vint8mf2_t *, vint8mf2_t *, vint8mf2_t *, vint8mf2_t *, const int8_t *, vuint32m2_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vloxseg6ei32_v_m)))
void vloxseg6ei32_v_i8mf2_m(vint8mf2_t *, vint8mf2_t *, vint8mf2_t *, vint8mf2_t *, vint8mf2_t *, vint8mf2_t *, vbool16_t, vint8mf2_t, vint8mf2_t, vint8mf2_t, vint8mf2_t, vint8mf2_t, vint8mf2_t, const int8_t *, vuint32m2_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vloxseg6ei32_v)))
void vloxseg6ei32_v_i8mf4(vint8mf4_t *, vint8mf4_t *, vint8mf4_t *, vint8mf4_t *, vint8mf4_t *, vint8mf4_t *, const int8_t *, vuint32m1_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vloxseg6ei32_v_m)))
void vloxseg6ei32_v_i8mf4_m(vint8mf4_t *, vint8mf4_t *, vint8mf4_t *, vint8mf4_t *, vint8mf4_t *, vint8mf4_t *, vbool32_t, vint8mf4_t, vint8mf4_t, vint8mf4_t, vint8mf4_t, vint8mf4_t, vint8mf4_t, const int8_t *, vuint32m1_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vloxseg6ei32_v)))
void vloxseg6ei32_v_i8mf8(vint8mf8_t *, vint8mf8_t *, vint8mf8_t *, vint8mf8_t *, vint8mf8_t *, vint8mf8_t *, const int8_t *, vuint32mf2_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vloxseg6ei32_v_m)))
void vloxseg6ei32_v_i8mf8_m(vint8mf8_t *, vint8mf8_t *, vint8mf8_t *, vint8mf8_t *, vint8mf8_t *, vint8mf8_t *, vbool64_t, vint8mf8_t, vint8mf8_t, vint8mf8_t, vint8mf8_t, vint8mf8_t, vint8mf8_t, const int8_t *, vuint32mf2_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vloxseg6ei32_v)))
void vloxseg6ei32_v_u8m1(vuint8m1_t *, vuint8m1_t *, vuint8m1_t *, vuint8m1_t *, vuint8m1_t *, vuint8m1_t *, const uint8_t *, vuint32m4_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vloxseg6ei32_v_m)))
void vloxseg6ei32_v_u8m1_m(vuint8m1_t *, vuint8m1_t *, vuint8m1_t *, vuint8m1_t *, vuint8m1_t *, vuint8m1_t *, vbool8_t, vuint8m1_t, vuint8m1_t, vuint8m1_t, vuint8m1_t, vuint8m1_t, vuint8m1_t, const uint8_t *, vuint32m4_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vloxseg6ei32_v)))
void vloxseg6ei32_v_u8mf2(vuint8mf2_t *, vuint8mf2_t *, vuint8mf2_t *, vuint8mf2_t *, vuint8mf2_t *, vuint8mf2_t *, const uint8_t *, vuint32m2_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vloxseg6ei32_v_m)))
void vloxseg6ei32_v_u8mf2_m(vuint8mf2_t *, vuint8mf2_t *, vuint8mf2_t *, vuint8mf2_t *, vuint8mf2_t *, vuint8mf2_t *, vbool16_t, vuint8mf2_t, vuint8mf2_t, vuint8mf2_t, vuint8mf2_t, vuint8mf2_t, vuint8mf2_t, const uint8_t *, vuint32m2_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vloxseg6ei32_v)))
void vloxseg6ei32_v_u8mf4(vuint8mf4_t *, vuint8mf4_t *, vuint8mf4_t *, vuint8mf4_t *, vuint8mf4_t *, vuint8mf4_t *, const uint8_t *, vuint32m1_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vloxseg6ei32_v_m)))
void vloxseg6ei32_v_u8mf4_m(vuint8mf4_t *, vuint8mf4_t *, vuint8mf4_t *, vuint8mf4_t *, vuint8mf4_t *, vuint8mf4_t *, vbool32_t, vuint8mf4_t, vuint8mf4_t, vuint8mf4_t, vuint8mf4_t, vuint8mf4_t, vuint8mf4_t, const uint8_t *, vuint32m1_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vloxseg6ei32_v)))
void vloxseg6ei32_v_u8mf8(vuint8mf8_t *, vuint8mf8_t *, vuint8mf8_t *, vuint8mf8_t *, vuint8mf8_t *, vuint8mf8_t *, const uint8_t *, vuint32mf2_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vloxseg6ei32_v_m)))
void vloxseg6ei32_v_u8mf8_m(vuint8mf8_t *, vuint8mf8_t *, vuint8mf8_t *, vuint8mf8_t *, vuint8mf8_t *, vuint8mf8_t *, vbool64_t, vuint8mf8_t, vuint8mf8_t, vuint8mf8_t, vuint8mf8_t, vuint8mf8_t, vuint8mf8_t, const uint8_t *, vuint32mf2_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vloxseg7ei32_v)))
void vloxseg7ei32_v_i8m1(vint8m1_t *, vint8m1_t *, vint8m1_t *, vint8m1_t *, vint8m1_t *, vint8m1_t *, vint8m1_t *, const int8_t *, vuint32m4_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vloxseg7ei32_v_m)))
void vloxseg7ei32_v_i8m1_m(vint8m1_t *, vint8m1_t *, vint8m1_t *, vint8m1_t *, vint8m1_t *, vint8m1_t *, vint8m1_t *, vbool8_t, vint8m1_t, vint8m1_t, vint8m1_t, vint8m1_t, vint8m1_t, vint8m1_t, vint8m1_t, const int8_t *, vuint32m4_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vloxseg7ei32_v)))
void vloxseg7ei32_v_i8mf2(vint8mf2_t *, vint8mf2_t *, vint8mf2_t *, vint8mf2_t *, vint8mf2_t *, vint8mf2_t *, vint8mf2_t *, const int8_t *, vuint32m2_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vloxseg7ei32_v_m)))
void vloxseg7ei32_v_i8mf2_m(vint8mf2_t *, vint8mf2_t *, vint8mf2_t *, vint8mf2_t *, vint8mf2_t *, vint8mf2_t *, vint8mf2_t *, vbool16_t, vint8mf2_t, vint8mf2_t, vint8mf2_t, vint8mf2_t, vint8mf2_t, vint8mf2_t, vint8mf2_t, const int8_t *, vuint32m2_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vloxseg7ei32_v)))
void vloxseg7ei32_v_i8mf4(vint8mf4_t *, vint8mf4_t *, vint8mf4_t *, vint8mf4_t *, vint8mf4_t *, vint8mf4_t *, vint8mf4_t *, const int8_t *, vuint32m1_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vloxseg7ei32_v_m)))
void vloxseg7ei32_v_i8mf4_m(vint8mf4_t *, vint8mf4_t *, vint8mf4_t *, vint8mf4_t *, vint8mf4_t *, vint8mf4_t *, vint8mf4_t *, vbool32_t, vint8mf4_t, vint8mf4_t, vint8mf4_t, vint8mf4_t, vint8mf4_t, vint8mf4_t, vint8mf4_t, const int8_t *, vuint32m1_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vloxseg7ei32_v)))
void vloxseg7ei32_v_i8mf8(vint8mf8_t *, vint8mf8_t *, vint8mf8_t *, vint8mf8_t *, vint8mf8_t *, vint8mf8_t *, vint8mf8_t *, const int8_t *, vuint32mf2_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vloxseg7ei32_v_m)))
void vloxseg7ei32_v_i8mf8_m(vint8mf8_t *, vint8mf8_t *, vint8mf8_t *, vint8mf8_t *, vint8mf8_t *, vint8mf8_t *, vint8mf8_t *, vbool64_t, vint8mf8_t, vint8mf8_t, vint8mf8_t, vint8mf8_t, vint8mf8_t, vint8mf8_t, vint8mf8_t, const int8_t *, vuint32mf2_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vloxseg7ei32_v)))
void vloxseg7ei32_v_u8m1(vuint8m1_t *, vuint8m1_t *, vuint8m1_t *, vuint8m1_t *, vuint8m1_t *, vuint8m1_t *, vuint8m1_t *, const uint8_t *, vuint32m4_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vloxseg7ei32_v_m)))
void vloxseg7ei32_v_u8m1_m(vuint8m1_t *, vuint8m1_t *, vuint8m1_t *, vuint8m1_t *, vuint8m1_t *, vuint8m1_t *, vuint8m1_t *, vbool8_t, vuint8m1_t, vuint8m1_t, vuint8m1_t, vuint8m1_t, vuint8m1_t, vuint8m1_t, vuint8m1_t, const uint8_t *, vuint32m4_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vloxseg7ei32_v)))
void vloxseg7ei32_v_u8mf2(vuint8mf2_t *, vuint8mf2_t *, vuint8mf2_t *, vuint8mf2_t *, vuint8mf2_t *, vuint8mf2_t *, vuint8mf2_t *, const uint8_t *, vuint32m2_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vloxseg7ei32_v_m)))
void vloxseg7ei32_v_u8mf2_m(vuint8mf2_t *, vuint8mf2_t *, vuint8mf2_t *, vuint8mf2_t *, vuint8mf2_t *, vuint8mf2_t *, vuint8mf2_t *, vbool16_t, vuint8mf2_t, vuint8mf2_t, vuint8mf2_t, vuint8mf2_t, vuint8mf2_t, vuint8mf2_t, vuint8mf2_t, const uint8_t *, vuint32m2_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vloxseg7ei32_v)))
void vloxseg7ei32_v_u8mf4(vuint8mf4_t *, vuint8mf4_t *, vuint8mf4_t *, vuint8mf4_t *, vuint8mf4_t *, vuint8mf4_t *, vuint8mf4_t *, const uint8_t *, vuint32m1_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vloxseg7ei32_v_m)))
void vloxseg7ei32_v_u8mf4_m(vuint8mf4_t *, vuint8mf4_t *, vuint8mf4_t *, vuint8mf4_t *, vuint8mf4_t *, vuint8mf4_t *, vuint8mf4_t *, vbool32_t, vuint8mf4_t, vuint8mf4_t, vuint8mf4_t, vuint8mf4_t, vuint8mf4_t, vuint8mf4_t, vuint8mf4_t, const uint8_t *, vuint32m1_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vloxseg7ei32_v)))
void vloxseg7ei32_v_u8mf8(vuint8mf8_t *, vuint8mf8_t *, vuint8mf8_t *, vuint8mf8_t *, vuint8mf8_t *, vuint8mf8_t *, vuint8mf8_t *, const uint8_t *, vuint32mf2_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vloxseg7ei32_v_m)))
void vloxseg7ei32_v_u8mf8_m(vuint8mf8_t *, vuint8mf8_t *, vuint8mf8_t *, vuint8mf8_t *, vuint8mf8_t *, vuint8mf8_t *, vuint8mf8_t *, vbool64_t, vuint8mf8_t, vuint8mf8_t, vuint8mf8_t, vuint8mf8_t, vuint8mf8_t, vuint8mf8_t, vuint8mf8_t, const uint8_t *, vuint32mf2_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vse16_v)))
void vse16_v_u16m1(uint16_t *, vuint16m1_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vse16_v_m)))
void vse16_v_u16m1_m(vbool16_t, uint16_t *, vuint16m1_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vse16_v)))
void vse16_v_u16m2(uint16_t *, vuint16m2_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vse16_v_m)))
void vse16_v_u16m2_m(vbool8_t, uint16_t *, vuint16m2_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vse16_v)))
void vse16_v_u16m4(uint16_t *, vuint16m4_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vse16_v_m)))
void vse16_v_u16m4_m(vbool4_t, uint16_t *, vuint16m4_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vse16_v)))
void vse16_v_u16m8(uint16_t *, vuint16m8_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vse16_v_m)))
void vse16_v_u16m8_m(vbool2_t, uint16_t *, vuint16m8_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vse16_v)))
void vse16_v_u16mf2(uint16_t *, vuint16mf2_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vse16_v_m)))
void vse16_v_u16mf2_m(vbool32_t, uint16_t *, vuint16mf2_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vse16_v)))
void vse16_v_u16mf4(uint16_t *, vuint16mf4_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vse16_v_m)))
void vse16_v_u16mf4_m(vbool64_t, uint16_t *, vuint16mf4_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vloxseg8ei32_v)))
void vloxseg8ei32_v_i8m1(vint8m1_t *, vint8m1_t *, vint8m1_t *, vint8m1_t *, vint8m1_t *, vint8m1_t *, vint8m1_t *, vint8m1_t *, const int8_t *, vuint32m4_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vloxseg8ei32_v_m)))
void vloxseg8ei32_v_i8m1_m(vint8m1_t *, vint8m1_t *, vint8m1_t *, vint8m1_t *, vint8m1_t *, vint8m1_t *, vint8m1_t *, vint8m1_t *, vbool8_t, vint8m1_t, vint8m1_t, vint8m1_t, vint8m1_t, vint8m1_t, vint8m1_t, vint8m1_t, vint8m1_t, const int8_t *, vuint32m4_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vloxseg8ei32_v)))
void vloxseg8ei32_v_i8mf2(vint8mf2_t *, vint8mf2_t *, vint8mf2_t *, vint8mf2_t *, vint8mf2_t *, vint8mf2_t *, vint8mf2_t *, vint8mf2_t *, const int8_t *, vuint32m2_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vloxseg8ei32_v_m)))
void vloxseg8ei32_v_i8mf2_m(vint8mf2_t *, vint8mf2_t *, vint8mf2_t *, vint8mf2_t *, vint8mf2_t *, vint8mf2_t *, vint8mf2_t *, vint8mf2_t *, vbool16_t, vint8mf2_t, vint8mf2_t, vint8mf2_t, vint8mf2_t, vint8mf2_t, vint8mf2_t, vint8mf2_t, vint8mf2_t, const int8_t *, vuint32m2_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vloxseg8ei32_v)))
void vloxseg8ei32_v_i8mf4(vint8mf4_t *, vint8mf4_t *, vint8mf4_t *, vint8mf4_t *, vint8mf4_t *, vint8mf4_t *, vint8mf4_t *, vint8mf4_t *, const int8_t *, vuint32m1_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vloxseg8ei32_v_m)))
void vloxseg8ei32_v_i8mf4_m(vint8mf4_t *, vint8mf4_t *, vint8mf4_t *, vint8mf4_t *, vint8mf4_t *, vint8mf4_t *, vint8mf4_t *, vint8mf4_t *, vbool32_t, vint8mf4_t, vint8mf4_t, vint8mf4_t, vint8mf4_t, vint8mf4_t, vint8mf4_t, vint8mf4_t, vint8mf4_t, const int8_t *, vuint32m1_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vloxseg8ei32_v)))
void vloxseg8ei32_v_i8mf8(vint8mf8_t *, vint8mf8_t *, vint8mf8_t *, vint8mf8_t *, vint8mf8_t *, vint8mf8_t *, vint8mf8_t *, vint8mf8_t *, const int8_t *, vuint32mf2_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vloxseg8ei32_v_m)))
void vloxseg8ei32_v_i8mf8_m(vint8mf8_t *, vint8mf8_t *, vint8mf8_t *, vint8mf8_t *, vint8mf8_t *, vint8mf8_t *, vint8mf8_t *, vint8mf8_t *, vbool64_t, vint8mf8_t, vint8mf8_t, vint8mf8_t, vint8mf8_t, vint8mf8_t, vint8mf8_t, vint8mf8_t, vint8mf8_t, const int8_t *, vuint32mf2_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vloxseg8ei32_v)))
void vloxseg8ei32_v_u8m1(vuint8m1_t *, vuint8m1_t *, vuint8m1_t *, vuint8m1_t *, vuint8m1_t *, vuint8m1_t *, vuint8m1_t *, vuint8m1_t *, const uint8_t *, vuint32m4_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vloxseg8ei32_v_m)))
void vloxseg8ei32_v_u8m1_m(vuint8m1_t *, vuint8m1_t *, vuint8m1_t *, vuint8m1_t *, vuint8m1_t *, vuint8m1_t *, vuint8m1_t *, vuint8m1_t *, vbool8_t, vuint8m1_t, vuint8m1_t, vuint8m1_t, vuint8m1_t, vuint8m1_t, vuint8m1_t, vuint8m1_t, vuint8m1_t, const uint8_t *, vuint32m4_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vloxseg8ei32_v)))
void vloxseg8ei32_v_u8mf2(vuint8mf2_t *, vuint8mf2_t *, vuint8mf2_t *, vuint8mf2_t *, vuint8mf2_t *, vuint8mf2_t *, vuint8mf2_t *, vuint8mf2_t *, const uint8_t *, vuint32m2_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vloxseg8ei32_v_m)))
void vloxseg8ei32_v_u8mf2_m(vuint8mf2_t *, vuint8mf2_t *, vuint8mf2_t *, vuint8mf2_t *, vuint8mf2_t *, vuint8mf2_t *, vuint8mf2_t *, vuint8mf2_t *, vbool16_t, vuint8mf2_t, vuint8mf2_t, vuint8mf2_t, vuint8mf2_t, vuint8mf2_t, vuint8mf2_t, vuint8mf2_t, vuint8mf2_t, const uint8_t *, vuint32m2_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vloxseg8ei32_v)))
void vloxseg8ei32_v_u8mf4(vuint8mf4_t *, vuint8mf4_t *, vuint8mf4_t *, vuint8mf4_t *, vuint8mf4_t *, vuint8mf4_t *, vuint8mf4_t *, vuint8mf4_t *, const uint8_t *, vuint32m1_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vloxseg8ei32_v_m)))
void vloxseg8ei32_v_u8mf4_m(vuint8mf4_t *, vuint8mf4_t *, vuint8mf4_t *, vuint8mf4_t *, vuint8mf4_t *, vuint8mf4_t *, vuint8mf4_t *, vuint8mf4_t *, vbool32_t, vuint8mf4_t, vuint8mf4_t, vuint8mf4_t, vuint8mf4_t, vuint8mf4_t, vuint8mf4_t, vuint8mf4_t, vuint8mf4_t, const uint8_t *, vuint32m1_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vloxseg8ei32_v)))
void vloxseg8ei32_v_u8mf8(vuint8mf8_t *, vuint8mf8_t *, vuint8mf8_t *, vuint8mf8_t *, vuint8mf8_t *, vuint8mf8_t *, vuint8mf8_t *, vuint8mf8_t *, const uint8_t *, vuint32mf2_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vloxseg8ei32_v_m)))
void vloxseg8ei32_v_u8mf8_m(vuint8mf8_t *, vuint8mf8_t *, vuint8mf8_t *, vuint8mf8_t *, vuint8mf8_t *, vuint8mf8_t *, vuint8mf8_t *, vuint8mf8_t *, vbool64_t, vuint8mf8_t, vuint8mf8_t, vuint8mf8_t, vuint8mf8_t, vuint8mf8_t, vuint8mf8_t, vuint8mf8_t, vuint8mf8_t, const uint8_t *, vuint32mf2_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vloxseg2ei8_v)))
void vloxseg2ei8_v_i16m1(vint16m1_t *, vint16m1_t *, const int16_t *, vuint8mf2_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vloxseg2ei8_v_m)))
void vloxseg2ei8_v_i16m1_m(vint16m1_t *, vint16m1_t *, vbool16_t, vint16m1_t, vint16m1_t, const int16_t *, vuint8mf2_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vloxseg2ei8_v)))
void vloxseg2ei8_v_i16m2(vint16m2_t *, vint16m2_t *, const int16_t *, vuint8m1_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vloxseg2ei8_v_m)))
void vloxseg2ei8_v_i16m2_m(vint16m2_t *, vint16m2_t *, vbool8_t, vint16m2_t, vint16m2_t, const int16_t *, vuint8m1_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vloxseg2ei8_v)))
void vloxseg2ei8_v_i16m4(vint16m4_t *, vint16m4_t *, const int16_t *, vuint8m2_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vloxseg2ei8_v_m)))
void vloxseg2ei8_v_i16m4_m(vint16m4_t *, vint16m4_t *, vbool4_t, vint16m4_t, vint16m4_t, const int16_t *, vuint8m2_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vloxseg2ei8_v)))
void vloxseg2ei8_v_i16mf2(vint16mf2_t *, vint16mf2_t *, const int16_t *, vuint8mf4_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vloxseg2ei8_v_m)))
void vloxseg2ei8_v_i16mf2_m(vint16mf2_t *, vint16mf2_t *, vbool32_t, vint16mf2_t, vint16mf2_t, const int16_t *, vuint8mf4_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vloxseg2ei8_v)))
void vloxseg2ei8_v_i16mf4(vint16mf4_t *, vint16mf4_t *, const int16_t *, vuint8mf8_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vloxseg2ei8_v_m)))
void vloxseg2ei8_v_i16mf4_m(vint16mf4_t *, vint16mf4_t *, vbool64_t, vint16mf4_t, vint16mf4_t, const int16_t *, vuint8mf8_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vloxseg2ei8_v)))
void vloxseg2ei8_v_u16m1(vuint16m1_t *, vuint16m1_t *, const uint16_t *, vuint8mf2_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vloxseg2ei8_v_m)))
void vloxseg2ei8_v_u16m1_m(vuint16m1_t *, vuint16m1_t *, vbool16_t, vuint16m1_t, vuint16m1_t, const uint16_t *, vuint8mf2_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vloxseg2ei8_v)))
void vloxseg2ei8_v_u16m2(vuint16m2_t *, vuint16m2_t *, const uint16_t *, vuint8m1_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vloxseg2ei8_v_m)))
void vloxseg2ei8_v_u16m2_m(vuint16m2_t *, vuint16m2_t *, vbool8_t, vuint16m2_t, vuint16m2_t, const uint16_t *, vuint8m1_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vloxseg2ei8_v)))
void vloxseg2ei8_v_u16m4(vuint16m4_t *, vuint16m4_t *, const uint16_t *, vuint8m2_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vloxseg2ei8_v_m)))
void vloxseg2ei8_v_u16m4_m(vuint16m4_t *, vuint16m4_t *, vbool4_t, vuint16m4_t, vuint16m4_t, const uint16_t *, vuint8m2_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vloxseg2ei8_v)))
void vloxseg2ei8_v_u16mf2(vuint16mf2_t *, vuint16mf2_t *, const uint16_t *, vuint8mf4_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vloxseg2ei8_v_m)))
void vloxseg2ei8_v_u16mf2_m(vuint16mf2_t *, vuint16mf2_t *, vbool32_t, vuint16mf2_t, vuint16mf2_t, const uint16_t *, vuint8mf4_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vloxseg2ei8_v)))
void vloxseg2ei8_v_u16mf4(vuint16mf4_t *, vuint16mf4_t *, const uint16_t *, vuint8mf8_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vloxseg2ei8_v_m)))
void vloxseg2ei8_v_u16mf4_m(vuint16mf4_t *, vuint16mf4_t *, vbool64_t, vuint16mf4_t, vuint16mf4_t, const uint16_t *, vuint8mf8_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vloxseg3ei8_v)))
void vloxseg3ei8_v_i16m1(vint16m1_t *, vint16m1_t *, vint16m1_t *, const int16_t *, vuint8mf2_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vloxseg3ei8_v_m)))
void vloxseg3ei8_v_i16m1_m(vint16m1_t *, vint16m1_t *, vint16m1_t *, vbool16_t, vint16m1_t, vint16m1_t, vint16m1_t, const int16_t *, vuint8mf2_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vloxseg3ei8_v)))
void vloxseg3ei8_v_i16m2(vint16m2_t *, vint16m2_t *, vint16m2_t *, const int16_t *, vuint8m1_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vloxseg3ei8_v_m)))
void vloxseg3ei8_v_i16m2_m(vint16m2_t *, vint16m2_t *, vint16m2_t *, vbool8_t, vint16m2_t, vint16m2_t, vint16m2_t, const int16_t *, vuint8m1_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vloxseg3ei8_v)))
void vloxseg3ei8_v_i16mf2(vint16mf2_t *, vint16mf2_t *, vint16mf2_t *, const int16_t *, vuint8mf4_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vloxseg3ei8_v_m)))
void vloxseg3ei8_v_i16mf2_m(vint16mf2_t *, vint16mf2_t *, vint16mf2_t *, vbool32_t, vint16mf2_t, vint16mf2_t, vint16mf2_t, const int16_t *, vuint8mf4_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vloxseg3ei8_v)))
void vloxseg3ei8_v_i16mf4(vint16mf4_t *, vint16mf4_t *, vint16mf4_t *, const int16_t *, vuint8mf8_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vloxseg3ei8_v_m)))
void vloxseg3ei8_v_i16mf4_m(vint16mf4_t *, vint16mf4_t *, vint16mf4_t *, vbool64_t, vint16mf4_t, vint16mf4_t, vint16mf4_t, const int16_t *, vuint8mf8_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vloxseg3ei8_v)))
void vloxseg3ei8_v_u16m1(vuint16m1_t *, vuint16m1_t *, vuint16m1_t *, const uint16_t *, vuint8mf2_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vloxseg3ei8_v_m)))
void vloxseg3ei8_v_u16m1_m(vuint16m1_t *, vuint16m1_t *, vuint16m1_t *, vbool16_t, vuint16m1_t, vuint16m1_t, vuint16m1_t, const uint16_t *, vuint8mf2_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vloxseg3ei8_v)))
void vloxseg3ei8_v_u16m2(vuint16m2_t *, vuint16m2_t *, vuint16m2_t *, const uint16_t *, vuint8m1_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vloxseg3ei8_v_m)))
void vloxseg3ei8_v_u16m2_m(vuint16m2_t *, vuint16m2_t *, vuint16m2_t *, vbool8_t, vuint16m2_t, vuint16m2_t, vuint16m2_t, const uint16_t *, vuint8m1_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vloxseg3ei8_v)))
void vloxseg3ei8_v_u16mf2(vuint16mf2_t *, vuint16mf2_t *, vuint16mf2_t *, const uint16_t *, vuint8mf4_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vloxseg3ei8_v_m)))
void vloxseg3ei8_v_u16mf2_m(vuint16mf2_t *, vuint16mf2_t *, vuint16mf2_t *, vbool32_t, vuint16mf2_t, vuint16mf2_t, vuint16mf2_t, const uint16_t *, vuint8mf4_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vloxseg3ei8_v)))
void vloxseg3ei8_v_u16mf4(vuint16mf4_t *, vuint16mf4_t *, vuint16mf4_t *, const uint16_t *, vuint8mf8_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vloxseg3ei8_v_m)))
void vloxseg3ei8_v_u16mf4_m(vuint16mf4_t *, vuint16mf4_t *, vuint16mf4_t *, vbool64_t, vuint16mf4_t, vuint16mf4_t, vuint16mf4_t, const uint16_t *, vuint8mf8_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vse32_v)))
void vse32_v_i32m1(int32_t *, vint32m1_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vse32_v_m)))
void vse32_v_i32m1_m(vbool32_t, int32_t *, vint32m1_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vse32_v)))
void vse32_v_i32m2(int32_t *, vint32m2_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vse32_v_m)))
void vse32_v_i32m2_m(vbool16_t, int32_t *, vint32m2_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vse32_v)))
void vse32_v_i32m4(int32_t *, vint32m4_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vse32_v_m)))
void vse32_v_i32m4_m(vbool8_t, int32_t *, vint32m4_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vse32_v)))
void vse32_v_i32m8(int32_t *, vint32m8_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vse32_v_m)))
void vse32_v_i32m8_m(vbool4_t, int32_t *, vint32m8_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vse32_v)))
void vse32_v_i32mf2(int32_t *, vint32mf2_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vse32_v_m)))
void vse32_v_i32mf2_m(vbool64_t, int32_t *, vint32mf2_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vloxseg4ei8_v)))
void vloxseg4ei8_v_i16m1(vint16m1_t *, vint16m1_t *, vint16m1_t *, vint16m1_t *, const int16_t *, vuint8mf2_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vloxseg4ei8_v_m)))
void vloxseg4ei8_v_i16m1_m(vint16m1_t *, vint16m1_t *, vint16m1_t *, vint16m1_t *, vbool16_t, vint16m1_t, vint16m1_t, vint16m1_t, vint16m1_t, const int16_t *, vuint8mf2_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vloxseg4ei8_v)))
void vloxseg4ei8_v_i16m2(vint16m2_t *, vint16m2_t *, vint16m2_t *, vint16m2_t *, const int16_t *, vuint8m1_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vloxseg4ei8_v_m)))
void vloxseg4ei8_v_i16m2_m(vint16m2_t *, vint16m2_t *, vint16m2_t *, vint16m2_t *, vbool8_t, vint16m2_t, vint16m2_t, vint16m2_t, vint16m2_t, const int16_t *, vuint8m1_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vloxseg4ei8_v)))
void vloxseg4ei8_v_i16mf2(vint16mf2_t *, vint16mf2_t *, vint16mf2_t *, vint16mf2_t *, const int16_t *, vuint8mf4_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vloxseg4ei8_v_m)))
void vloxseg4ei8_v_i16mf2_m(vint16mf2_t *, vint16mf2_t *, vint16mf2_t *, vint16mf2_t *, vbool32_t, vint16mf2_t, vint16mf2_t, vint16mf2_t, vint16mf2_t, const int16_t *, vuint8mf4_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vloxseg4ei8_v)))
void vloxseg4ei8_v_i16mf4(vint16mf4_t *, vint16mf4_t *, vint16mf4_t *, vint16mf4_t *, const int16_t *, vuint8mf8_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vloxseg4ei8_v_m)))
void vloxseg4ei8_v_i16mf4_m(vint16mf4_t *, vint16mf4_t *, vint16mf4_t *, vint16mf4_t *, vbool64_t, vint16mf4_t, vint16mf4_t, vint16mf4_t, vint16mf4_t, const int16_t *, vuint8mf8_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vloxseg4ei8_v)))
void vloxseg4ei8_v_u16m1(vuint16m1_t *, vuint16m1_t *, vuint16m1_t *, vuint16m1_t *, const uint16_t *, vuint8mf2_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vloxseg4ei8_v_m)))
void vloxseg4ei8_v_u16m1_m(vuint16m1_t *, vuint16m1_t *, vuint16m1_t *, vuint16m1_t *, vbool16_t, vuint16m1_t, vuint16m1_t, vuint16m1_t, vuint16m1_t, const uint16_t *, vuint8mf2_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vloxseg4ei8_v)))
void vloxseg4ei8_v_u16m2(vuint16m2_t *, vuint16m2_t *, vuint16m2_t *, vuint16m2_t *, const uint16_t *, vuint8m1_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vloxseg4ei8_v_m)))
void vloxseg4ei8_v_u16m2_m(vuint16m2_t *, vuint16m2_t *, vuint16m2_t *, vuint16m2_t *, vbool8_t, vuint16m2_t, vuint16m2_t, vuint16m2_t, vuint16m2_t, const uint16_t *, vuint8m1_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vloxseg4ei8_v)))
void vloxseg4ei8_v_u16mf2(vuint16mf2_t *, vuint16mf2_t *, vuint16mf2_t *, vuint16mf2_t *, const uint16_t *, vuint8mf4_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vloxseg4ei8_v_m)))
void vloxseg4ei8_v_u16mf2_m(vuint16mf2_t *, vuint16mf2_t *, vuint16mf2_t *, vuint16mf2_t *, vbool32_t, vuint16mf2_t, vuint16mf2_t, vuint16mf2_t, vuint16mf2_t, const uint16_t *, vuint8mf4_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vloxseg4ei8_v)))
void vloxseg4ei8_v_u16mf4(vuint16mf4_t *, vuint16mf4_t *, vuint16mf4_t *, vuint16mf4_t *, const uint16_t *, vuint8mf8_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vloxseg4ei8_v_m)))
void vloxseg4ei8_v_u16mf4_m(vuint16mf4_t *, vuint16mf4_t *, vuint16mf4_t *, vuint16mf4_t *, vbool64_t, vuint16mf4_t, vuint16mf4_t, vuint16mf4_t, vuint16mf4_t, const uint16_t *, vuint8mf8_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vloxseg5ei8_v)))
void vloxseg5ei8_v_i16m1(vint16m1_t *, vint16m1_t *, vint16m1_t *, vint16m1_t *, vint16m1_t *, const int16_t *, vuint8mf2_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vloxseg5ei8_v_m)))
void vloxseg5ei8_v_i16m1_m(vint16m1_t *, vint16m1_t *, vint16m1_t *, vint16m1_t *, vint16m1_t *, vbool16_t, vint16m1_t, vint16m1_t, vint16m1_t, vint16m1_t, vint16m1_t, const int16_t *, vuint8mf2_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vloxseg5ei8_v)))
void vloxseg5ei8_v_i16mf2(vint16mf2_t *, vint16mf2_t *, vint16mf2_t *, vint16mf2_t *, vint16mf2_t *, const int16_t *, vuint8mf4_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vloxseg5ei8_v_m)))
void vloxseg5ei8_v_i16mf2_m(vint16mf2_t *, vint16mf2_t *, vint16mf2_t *, vint16mf2_t *, vint16mf2_t *, vbool32_t, vint16mf2_t, vint16mf2_t, vint16mf2_t, vint16mf2_t, vint16mf2_t, const int16_t *, vuint8mf4_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vloxseg5ei8_v)))
void vloxseg5ei8_v_i16mf4(vint16mf4_t *, vint16mf4_t *, vint16mf4_t *, vint16mf4_t *, vint16mf4_t *, const int16_t *, vuint8mf8_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vloxseg5ei8_v_m)))
void vloxseg5ei8_v_i16mf4_m(vint16mf4_t *, vint16mf4_t *, vint16mf4_t *, vint16mf4_t *, vint16mf4_t *, vbool64_t, vint16mf4_t, vint16mf4_t, vint16mf4_t, vint16mf4_t, vint16mf4_t, const int16_t *, vuint8mf8_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vloxseg5ei8_v)))
void vloxseg5ei8_v_u16m1(vuint16m1_t *, vuint16m1_t *, vuint16m1_t *, vuint16m1_t *, vuint16m1_t *, const uint16_t *, vuint8mf2_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vloxseg5ei8_v_m)))
void vloxseg5ei8_v_u16m1_m(vuint16m1_t *, vuint16m1_t *, vuint16m1_t *, vuint16m1_t *, vuint16m1_t *, vbool16_t, vuint16m1_t, vuint16m1_t, vuint16m1_t, vuint16m1_t, vuint16m1_t, const uint16_t *, vuint8mf2_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vloxseg5ei8_v)))
void vloxseg5ei8_v_u16mf2(vuint16mf2_t *, vuint16mf2_t *, vuint16mf2_t *, vuint16mf2_t *, vuint16mf2_t *, const uint16_t *, vuint8mf4_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vloxseg5ei8_v_m)))
void vloxseg5ei8_v_u16mf2_m(vuint16mf2_t *, vuint16mf2_t *, vuint16mf2_t *, vuint16mf2_t *, vuint16mf2_t *, vbool32_t, vuint16mf2_t, vuint16mf2_t, vuint16mf2_t, vuint16mf2_t, vuint16mf2_t, const uint16_t *, vuint8mf4_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vloxseg5ei8_v)))
void vloxseg5ei8_v_u16mf4(vuint16mf4_t *, vuint16mf4_t *, vuint16mf4_t *, vuint16mf4_t *, vuint16mf4_t *, const uint16_t *, vuint8mf8_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vloxseg5ei8_v_m)))
void vloxseg5ei8_v_u16mf4_m(vuint16mf4_t *, vuint16mf4_t *, vuint16mf4_t *, vuint16mf4_t *, vuint16mf4_t *, vbool64_t, vuint16mf4_t, vuint16mf4_t, vuint16mf4_t, vuint16mf4_t, vuint16mf4_t, const uint16_t *, vuint8mf8_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vloxseg6ei8_v)))
void vloxseg6ei8_v_i16m1(vint16m1_t *, vint16m1_t *, vint16m1_t *, vint16m1_t *, vint16m1_t *, vint16m1_t *, const int16_t *, vuint8mf2_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vloxseg6ei8_v_m)))
void vloxseg6ei8_v_i16m1_m(vint16m1_t *, vint16m1_t *, vint16m1_t *, vint16m1_t *, vint16m1_t *, vint16m1_t *, vbool16_t, vint16m1_t, vint16m1_t, vint16m1_t, vint16m1_t, vint16m1_t, vint16m1_t, const int16_t *, vuint8mf2_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vloxseg6ei8_v)))
void vloxseg6ei8_v_i16mf2(vint16mf2_t *, vint16mf2_t *, vint16mf2_t *, vint16mf2_t *, vint16mf2_t *, vint16mf2_t *, const int16_t *, vuint8mf4_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vloxseg6ei8_v_m)))
void vloxseg6ei8_v_i16mf2_m(vint16mf2_t *, vint16mf2_t *, vint16mf2_t *, vint16mf2_t *, vint16mf2_t *, vint16mf2_t *, vbool32_t, vint16mf2_t, vint16mf2_t, vint16mf2_t, vint16mf2_t, vint16mf2_t, vint16mf2_t, const int16_t *, vuint8mf4_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vloxseg6ei8_v)))
void vloxseg6ei8_v_i16mf4(vint16mf4_t *, vint16mf4_t *, vint16mf4_t *, vint16mf4_t *, vint16mf4_t *, vint16mf4_t *, const int16_t *, vuint8mf8_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vloxseg6ei8_v_m)))
void vloxseg6ei8_v_i16mf4_m(vint16mf4_t *, vint16mf4_t *, vint16mf4_t *, vint16mf4_t *, vint16mf4_t *, vint16mf4_t *, vbool64_t, vint16mf4_t, vint16mf4_t, vint16mf4_t, vint16mf4_t, vint16mf4_t, vint16mf4_t, const int16_t *, vuint8mf8_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vloxseg6ei8_v)))
void vloxseg6ei8_v_u16m1(vuint16m1_t *, vuint16m1_t *, vuint16m1_t *, vuint16m1_t *, vuint16m1_t *, vuint16m1_t *, const uint16_t *, vuint8mf2_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vloxseg6ei8_v_m)))
void vloxseg6ei8_v_u16m1_m(vuint16m1_t *, vuint16m1_t *, vuint16m1_t *, vuint16m1_t *, vuint16m1_t *, vuint16m1_t *, vbool16_t, vuint16m1_t, vuint16m1_t, vuint16m1_t, vuint16m1_t, vuint16m1_t, vuint16m1_t, const uint16_t *, vuint8mf2_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vloxseg6ei8_v)))
void vloxseg6ei8_v_u16mf2(vuint16mf2_t *, vuint16mf2_t *, vuint16mf2_t *, vuint16mf2_t *, vuint16mf2_t *, vuint16mf2_t *, const uint16_t *, vuint8mf4_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vloxseg6ei8_v_m)))
void vloxseg6ei8_v_u16mf2_m(vuint16mf2_t *, vuint16mf2_t *, vuint16mf2_t *, vuint16mf2_t *, vuint16mf2_t *, vuint16mf2_t *, vbool32_t, vuint16mf2_t, vuint16mf2_t, vuint16mf2_t, vuint16mf2_t, vuint16mf2_t, vuint16mf2_t, const uint16_t *, vuint8mf4_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vloxseg6ei8_v)))
void vloxseg6ei8_v_u16mf4(vuint16mf4_t *, vuint16mf4_t *, vuint16mf4_t *, vuint16mf4_t *, vuint16mf4_t *, vuint16mf4_t *, const uint16_t *, vuint8mf8_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vloxseg6ei8_v_m)))
void vloxseg6ei8_v_u16mf4_m(vuint16mf4_t *, vuint16mf4_t *, vuint16mf4_t *, vuint16mf4_t *, vuint16mf4_t *, vuint16mf4_t *, vbool64_t, vuint16mf4_t, vuint16mf4_t, vuint16mf4_t, vuint16mf4_t, vuint16mf4_t, vuint16mf4_t, const uint16_t *, vuint8mf8_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vloxseg7ei8_v)))
void vloxseg7ei8_v_i16m1(vint16m1_t *, vint16m1_t *, vint16m1_t *, vint16m1_t *, vint16m1_t *, vint16m1_t *, vint16m1_t *, const int16_t *, vuint8mf2_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vloxseg7ei8_v_m)))
void vloxseg7ei8_v_i16m1_m(vint16m1_t *, vint16m1_t *, vint16m1_t *, vint16m1_t *, vint16m1_t *, vint16m1_t *, vint16m1_t *, vbool16_t, vint16m1_t, vint16m1_t, vint16m1_t, vint16m1_t, vint16m1_t, vint16m1_t, vint16m1_t, const int16_t *, vuint8mf2_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vloxseg7ei8_v)))
void vloxseg7ei8_v_i16mf2(vint16mf2_t *, vint16mf2_t *, vint16mf2_t *, vint16mf2_t *, vint16mf2_t *, vint16mf2_t *, vint16mf2_t *, const int16_t *, vuint8mf4_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vloxseg7ei8_v_m)))
void vloxseg7ei8_v_i16mf2_m(vint16mf2_t *, vint16mf2_t *, vint16mf2_t *, vint16mf2_t *, vint16mf2_t *, vint16mf2_t *, vint16mf2_t *, vbool32_t, vint16mf2_t, vint16mf2_t, vint16mf2_t, vint16mf2_t, vint16mf2_t, vint16mf2_t, vint16mf2_t, const int16_t *, vuint8mf4_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vloxseg7ei8_v)))
void vloxseg7ei8_v_i16mf4(vint16mf4_t *, vint16mf4_t *, vint16mf4_t *, vint16mf4_t *, vint16mf4_t *, vint16mf4_t *, vint16mf4_t *, const int16_t *, vuint8mf8_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vloxseg7ei8_v_m)))
void vloxseg7ei8_v_i16mf4_m(vint16mf4_t *, vint16mf4_t *, vint16mf4_t *, vint16mf4_t *, vint16mf4_t *, vint16mf4_t *, vint16mf4_t *, vbool64_t, vint16mf4_t, vint16mf4_t, vint16mf4_t, vint16mf4_t, vint16mf4_t, vint16mf4_t, vint16mf4_t, const int16_t *, vuint8mf8_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vloxseg7ei8_v)))
void vloxseg7ei8_v_u16m1(vuint16m1_t *, vuint16m1_t *, vuint16m1_t *, vuint16m1_t *, vuint16m1_t *, vuint16m1_t *, vuint16m1_t *, const uint16_t *, vuint8mf2_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vloxseg7ei8_v_m)))
void vloxseg7ei8_v_u16m1_m(vuint16m1_t *, vuint16m1_t *, vuint16m1_t *, vuint16m1_t *, vuint16m1_t *, vuint16m1_t *, vuint16m1_t *, vbool16_t, vuint16m1_t, vuint16m1_t, vuint16m1_t, vuint16m1_t, vuint16m1_t, vuint16m1_t, vuint16m1_t, const uint16_t *, vuint8mf2_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vloxseg7ei8_v)))
void vloxseg7ei8_v_u16mf2(vuint16mf2_t *, vuint16mf2_t *, vuint16mf2_t *, vuint16mf2_t *, vuint16mf2_t *, vuint16mf2_t *, vuint16mf2_t *, const uint16_t *, vuint8mf4_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vloxseg7ei8_v_m)))
void vloxseg7ei8_v_u16mf2_m(vuint16mf2_t *, vuint16mf2_t *, vuint16mf2_t *, vuint16mf2_t *, vuint16mf2_t *, vuint16mf2_t *, vuint16mf2_t *, vbool32_t, vuint16mf2_t, vuint16mf2_t, vuint16mf2_t, vuint16mf2_t, vuint16mf2_t, vuint16mf2_t, vuint16mf2_t, const uint16_t *, vuint8mf4_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vloxseg7ei8_v)))
void vloxseg7ei8_v_u16mf4(vuint16mf4_t *, vuint16mf4_t *, vuint16mf4_t *, vuint16mf4_t *, vuint16mf4_t *, vuint16mf4_t *, vuint16mf4_t *, const uint16_t *, vuint8mf8_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vloxseg7ei8_v_m)))
void vloxseg7ei8_v_u16mf4_m(vuint16mf4_t *, vuint16mf4_t *, vuint16mf4_t *, vuint16mf4_t *, vuint16mf4_t *, vuint16mf4_t *, vuint16mf4_t *, vbool64_t, vuint16mf4_t, vuint16mf4_t, vuint16mf4_t, vuint16mf4_t, vuint16mf4_t, vuint16mf4_t, vuint16mf4_t, const uint16_t *, vuint8mf8_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vloxseg8ei8_v)))
void vloxseg8ei8_v_i16m1(vint16m1_t *, vint16m1_t *, vint16m1_t *, vint16m1_t *, vint16m1_t *, vint16m1_t *, vint16m1_t *, vint16m1_t *, const int16_t *, vuint8mf2_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vloxseg8ei8_v_m)))
void vloxseg8ei8_v_i16m1_m(vint16m1_t *, vint16m1_t *, vint16m1_t *, vint16m1_t *, vint16m1_t *, vint16m1_t *, vint16m1_t *, vint16m1_t *, vbool16_t, vint16m1_t, vint16m1_t, vint16m1_t, vint16m1_t, vint16m1_t, vint16m1_t, vint16m1_t, vint16m1_t, const int16_t *, vuint8mf2_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vloxseg8ei8_v)))
void vloxseg8ei8_v_i16mf2(vint16mf2_t *, vint16mf2_t *, vint16mf2_t *, vint16mf2_t *, vint16mf2_t *, vint16mf2_t *, vint16mf2_t *, vint16mf2_t *, const int16_t *, vuint8mf4_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vloxseg8ei8_v_m)))
void vloxseg8ei8_v_i16mf2_m(vint16mf2_t *, vint16mf2_t *, vint16mf2_t *, vint16mf2_t *, vint16mf2_t *, vint16mf2_t *, vint16mf2_t *, vint16mf2_t *, vbool32_t, vint16mf2_t, vint16mf2_t, vint16mf2_t, vint16mf2_t, vint16mf2_t, vint16mf2_t, vint16mf2_t, vint16mf2_t, const int16_t *, vuint8mf4_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vloxseg8ei8_v)))
void vloxseg8ei8_v_i16mf4(vint16mf4_t *, vint16mf4_t *, vint16mf4_t *, vint16mf4_t *, vint16mf4_t *, vint16mf4_t *, vint16mf4_t *, vint16mf4_t *, const int16_t *, vuint8mf8_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vloxseg8ei8_v_m)))
void vloxseg8ei8_v_i16mf4_m(vint16mf4_t *, vint16mf4_t *, vint16mf4_t *, vint16mf4_t *, vint16mf4_t *, vint16mf4_t *, vint16mf4_t *, vint16mf4_t *, vbool64_t, vint16mf4_t, vint16mf4_t, vint16mf4_t, vint16mf4_t, vint16mf4_t, vint16mf4_t, vint16mf4_t, vint16mf4_t, const int16_t *, vuint8mf8_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vloxseg8ei8_v)))
void vloxseg8ei8_v_u16m1(vuint16m1_t *, vuint16m1_t *, vuint16m1_t *, vuint16m1_t *, vuint16m1_t *, vuint16m1_t *, vuint16m1_t *, vuint16m1_t *, const uint16_t *, vuint8mf2_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vloxseg8ei8_v_m)))
void vloxseg8ei8_v_u16m1_m(vuint16m1_t *, vuint16m1_t *, vuint16m1_t *, vuint16m1_t *, vuint16m1_t *, vuint16m1_t *, vuint16m1_t *, vuint16m1_t *, vbool16_t, vuint16m1_t, vuint16m1_t, vuint16m1_t, vuint16m1_t, vuint16m1_t, vuint16m1_t, vuint16m1_t, vuint16m1_t, const uint16_t *, vuint8mf2_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vloxseg8ei8_v)))
void vloxseg8ei8_v_u16mf2(vuint16mf2_t *, vuint16mf2_t *, vuint16mf2_t *, vuint16mf2_t *, vuint16mf2_t *, vuint16mf2_t *, vuint16mf2_t *, vuint16mf2_t *, const uint16_t *, vuint8mf4_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vloxseg8ei8_v_m)))
void vloxseg8ei8_v_u16mf2_m(vuint16mf2_t *, vuint16mf2_t *, vuint16mf2_t *, vuint16mf2_t *, vuint16mf2_t *, vuint16mf2_t *, vuint16mf2_t *, vuint16mf2_t *, vbool32_t, vuint16mf2_t, vuint16mf2_t, vuint16mf2_t, vuint16mf2_t, vuint16mf2_t, vuint16mf2_t, vuint16mf2_t, vuint16mf2_t, const uint16_t *, vuint8mf4_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vloxseg8ei8_v)))
void vloxseg8ei8_v_u16mf4(vuint16mf4_t *, vuint16mf4_t *, vuint16mf4_t *, vuint16mf4_t *, vuint16mf4_t *, vuint16mf4_t *, vuint16mf4_t *, vuint16mf4_t *, const uint16_t *, vuint8mf8_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vloxseg8ei8_v_m)))
void vloxseg8ei8_v_u16mf4_m(vuint16mf4_t *, vuint16mf4_t *, vuint16mf4_t *, vuint16mf4_t *, vuint16mf4_t *, vuint16mf4_t *, vuint16mf4_t *, vuint16mf4_t *, vbool64_t, vuint16mf4_t, vuint16mf4_t, vuint16mf4_t, vuint16mf4_t, vuint16mf4_t, vuint16mf4_t, vuint16mf4_t, vuint16mf4_t, const uint16_t *, vuint8mf8_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vluxei8_v)))
vint8m1_t vluxei8_v_i8m1(const int8_t *, vuint8m1_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vluxei8_v_m)))
vint8m1_t vluxei8_v_i8m1_m(vbool8_t, vint8m1_t, const int8_t *, vuint8m1_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vluxei8_v)))
vint8m2_t vluxei8_v_i8m2(const int8_t *, vuint8m2_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vluxei8_v_m)))
vint8m2_t vluxei8_v_i8m2_m(vbool4_t, vint8m2_t, const int8_t *, vuint8m2_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vluxei8_v)))
vint8m4_t vluxei8_v_i8m4(const int8_t *, vuint8m4_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vluxei8_v_m)))
vint8m4_t vluxei8_v_i8m4_m(vbool2_t, vint8m4_t, const int8_t *, vuint8m4_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vluxei8_v)))
vint8m8_t vluxei8_v_i8m8(const int8_t *, vuint8m8_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vluxei8_v_m)))
vint8m8_t vluxei8_v_i8m8_m(vbool1_t, vint8m8_t, const int8_t *, vuint8m8_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vluxei8_v)))
vint8mf2_t vluxei8_v_i8mf2(const int8_t *, vuint8mf2_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vluxei8_v_m)))
vint8mf2_t vluxei8_v_i8mf2_m(vbool16_t, vint8mf2_t, const int8_t *, vuint8mf2_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vluxei8_v)))
vint8mf4_t vluxei8_v_i8mf4(const int8_t *, vuint8mf4_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vluxei8_v_m)))
vint8mf4_t vluxei8_v_i8mf4_m(vbool32_t, vint8mf4_t, const int8_t *, vuint8mf4_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vluxei8_v)))
vint8mf8_t vluxei8_v_i8mf8(const int8_t *, vuint8mf8_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vluxei8_v_m)))
vint8mf8_t vluxei8_v_i8mf8_m(vbool64_t, vint8mf8_t, const int8_t *, vuint8mf8_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vse32_v)))
void vse32_v_u32m1(uint32_t *, vuint32m1_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vse32_v_m)))
void vse32_v_u32m1_m(vbool32_t, uint32_t *, vuint32m1_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vse32_v)))
void vse32_v_u32m2(uint32_t *, vuint32m2_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vse32_v_m)))
void vse32_v_u32m2_m(vbool16_t, uint32_t *, vuint32m2_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vse32_v)))
void vse32_v_u32m4(uint32_t *, vuint32m4_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vse32_v_m)))
void vse32_v_u32m4_m(vbool8_t, uint32_t *, vuint32m4_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vse32_v)))
void vse32_v_u32m8(uint32_t *, vuint32m8_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vse32_v_m)))
void vse32_v_u32m8_m(vbool4_t, uint32_t *, vuint32m8_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vse32_v)))
void vse32_v_u32mf2(uint32_t *, vuint32mf2_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vse32_v_m)))
void vse32_v_u32mf2_m(vbool64_t, uint32_t *, vuint32mf2_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vloxseg2ei16_v)))
void vloxseg2ei16_v_i16m1(vint16m1_t *, vint16m1_t *, const int16_t *, vuint16m1_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vloxseg2ei16_v_m)))
void vloxseg2ei16_v_i16m1_m(vint16m1_t *, vint16m1_t *, vbool16_t, vint16m1_t, vint16m1_t, const int16_t *, vuint16m1_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vloxseg2ei16_v)))
void vloxseg2ei16_v_i16m2(vint16m2_t *, vint16m2_t *, const int16_t *, vuint16m2_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vloxseg2ei16_v_m)))
void vloxseg2ei16_v_i16m2_m(vint16m2_t *, vint16m2_t *, vbool8_t, vint16m2_t, vint16m2_t, const int16_t *, vuint16m2_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vloxseg2ei16_v)))
void vloxseg2ei16_v_i16m4(vint16m4_t *, vint16m4_t *, const int16_t *, vuint16m4_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vloxseg2ei16_v_m)))
void vloxseg2ei16_v_i16m4_m(vint16m4_t *, vint16m4_t *, vbool4_t, vint16m4_t, vint16m4_t, const int16_t *, vuint16m4_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vloxseg2ei16_v)))
void vloxseg2ei16_v_i16mf2(vint16mf2_t *, vint16mf2_t *, const int16_t *, vuint16mf2_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vloxseg2ei16_v_m)))
void vloxseg2ei16_v_i16mf2_m(vint16mf2_t *, vint16mf2_t *, vbool32_t, vint16mf2_t, vint16mf2_t, const int16_t *, vuint16mf2_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vloxseg2ei16_v)))
void vloxseg2ei16_v_i16mf4(vint16mf4_t *, vint16mf4_t *, const int16_t *, vuint16mf4_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vloxseg2ei16_v_m)))
void vloxseg2ei16_v_i16mf4_m(vint16mf4_t *, vint16mf4_t *, vbool64_t, vint16mf4_t, vint16mf4_t, const int16_t *, vuint16mf4_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vloxseg2ei16_v)))
void vloxseg2ei16_v_u16m1(vuint16m1_t *, vuint16m1_t *, const uint16_t *, vuint16m1_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vloxseg2ei16_v_m)))
void vloxseg2ei16_v_u16m1_m(vuint16m1_t *, vuint16m1_t *, vbool16_t, vuint16m1_t, vuint16m1_t, const uint16_t *, vuint16m1_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vloxseg2ei16_v)))
void vloxseg2ei16_v_u16m2(vuint16m2_t *, vuint16m2_t *, const uint16_t *, vuint16m2_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vloxseg2ei16_v_m)))
void vloxseg2ei16_v_u16m2_m(vuint16m2_t *, vuint16m2_t *, vbool8_t, vuint16m2_t, vuint16m2_t, const uint16_t *, vuint16m2_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vloxseg2ei16_v)))
void vloxseg2ei16_v_u16m4(vuint16m4_t *, vuint16m4_t *, const uint16_t *, vuint16m4_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vloxseg2ei16_v_m)))
void vloxseg2ei16_v_u16m4_m(vuint16m4_t *, vuint16m4_t *, vbool4_t, vuint16m4_t, vuint16m4_t, const uint16_t *, vuint16m4_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vloxseg2ei16_v)))
void vloxseg2ei16_v_u16mf2(vuint16mf2_t *, vuint16mf2_t *, const uint16_t *, vuint16mf2_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vloxseg2ei16_v_m)))
void vloxseg2ei16_v_u16mf2_m(vuint16mf2_t *, vuint16mf2_t *, vbool32_t, vuint16mf2_t, vuint16mf2_t, const uint16_t *, vuint16mf2_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vloxseg2ei16_v)))
void vloxseg2ei16_v_u16mf4(vuint16mf4_t *, vuint16mf4_t *, const uint16_t *, vuint16mf4_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vloxseg2ei16_v_m)))
void vloxseg2ei16_v_u16mf4_m(vuint16mf4_t *, vuint16mf4_t *, vbool64_t, vuint16mf4_t, vuint16mf4_t, const uint16_t *, vuint16mf4_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vloxseg3ei16_v)))
void vloxseg3ei16_v_i16m1(vint16m1_t *, vint16m1_t *, vint16m1_t *, const int16_t *, vuint16m1_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vloxseg3ei16_v_m)))
void vloxseg3ei16_v_i16m1_m(vint16m1_t *, vint16m1_t *, vint16m1_t *, vbool16_t, vint16m1_t, vint16m1_t, vint16m1_t, const int16_t *, vuint16m1_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vloxseg3ei16_v)))
void vloxseg3ei16_v_i16m2(vint16m2_t *, vint16m2_t *, vint16m2_t *, const int16_t *, vuint16m2_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vloxseg3ei16_v_m)))
void vloxseg3ei16_v_i16m2_m(vint16m2_t *, vint16m2_t *, vint16m2_t *, vbool8_t, vint16m2_t, vint16m2_t, vint16m2_t, const int16_t *, vuint16m2_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vloxseg3ei16_v)))
void vloxseg3ei16_v_i16mf2(vint16mf2_t *, vint16mf2_t *, vint16mf2_t *, const int16_t *, vuint16mf2_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vloxseg3ei16_v_m)))
void vloxseg3ei16_v_i16mf2_m(vint16mf2_t *, vint16mf2_t *, vint16mf2_t *, vbool32_t, vint16mf2_t, vint16mf2_t, vint16mf2_t, const int16_t *, vuint16mf2_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vloxseg3ei16_v)))
void vloxseg3ei16_v_i16mf4(vint16mf4_t *, vint16mf4_t *, vint16mf4_t *, const int16_t *, vuint16mf4_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vloxseg3ei16_v_m)))
void vloxseg3ei16_v_i16mf4_m(vint16mf4_t *, vint16mf4_t *, vint16mf4_t *, vbool64_t, vint16mf4_t, vint16mf4_t, vint16mf4_t, const int16_t *, vuint16mf4_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vloxseg3ei16_v)))
void vloxseg3ei16_v_u16m1(vuint16m1_t *, vuint16m1_t *, vuint16m1_t *, const uint16_t *, vuint16m1_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vloxseg3ei16_v_m)))
void vloxseg3ei16_v_u16m1_m(vuint16m1_t *, vuint16m1_t *, vuint16m1_t *, vbool16_t, vuint16m1_t, vuint16m1_t, vuint16m1_t, const uint16_t *, vuint16m1_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vloxseg3ei16_v)))
void vloxseg3ei16_v_u16m2(vuint16m2_t *, vuint16m2_t *, vuint16m2_t *, const uint16_t *, vuint16m2_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vloxseg3ei16_v_m)))
void vloxseg3ei16_v_u16m2_m(vuint16m2_t *, vuint16m2_t *, vuint16m2_t *, vbool8_t, vuint16m2_t, vuint16m2_t, vuint16m2_t, const uint16_t *, vuint16m2_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vloxseg3ei16_v)))
void vloxseg3ei16_v_u16mf2(vuint16mf2_t *, vuint16mf2_t *, vuint16mf2_t *, const uint16_t *, vuint16mf2_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vloxseg3ei16_v_m)))
void vloxseg3ei16_v_u16mf2_m(vuint16mf2_t *, vuint16mf2_t *, vuint16mf2_t *, vbool32_t, vuint16mf2_t, vuint16mf2_t, vuint16mf2_t, const uint16_t *, vuint16mf2_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vloxseg3ei16_v)))
void vloxseg3ei16_v_u16mf4(vuint16mf4_t *, vuint16mf4_t *, vuint16mf4_t *, const uint16_t *, vuint16mf4_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vloxseg3ei16_v_m)))
void vloxseg3ei16_v_u16mf4_m(vuint16mf4_t *, vuint16mf4_t *, vuint16mf4_t *, vbool64_t, vuint16mf4_t, vuint16mf4_t, vuint16mf4_t, const uint16_t *, vuint16mf4_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vloxseg4ei16_v)))
void vloxseg4ei16_v_i16m1(vint16m1_t *, vint16m1_t *, vint16m1_t *, vint16m1_t *, const int16_t *, vuint16m1_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vloxseg4ei16_v_m)))
void vloxseg4ei16_v_i16m1_m(vint16m1_t *, vint16m1_t *, vint16m1_t *, vint16m1_t *, vbool16_t, vint16m1_t, vint16m1_t, vint16m1_t, vint16m1_t, const int16_t *, vuint16m1_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vloxseg4ei16_v)))
void vloxseg4ei16_v_i16m2(vint16m2_t *, vint16m2_t *, vint16m2_t *, vint16m2_t *, const int16_t *, vuint16m2_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vloxseg4ei16_v_m)))
void vloxseg4ei16_v_i16m2_m(vint16m2_t *, vint16m2_t *, vint16m2_t *, vint16m2_t *, vbool8_t, vint16m2_t, vint16m2_t, vint16m2_t, vint16m2_t, const int16_t *, vuint16m2_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vloxseg4ei16_v)))
void vloxseg4ei16_v_i16mf2(vint16mf2_t *, vint16mf2_t *, vint16mf2_t *, vint16mf2_t *, const int16_t *, vuint16mf2_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vloxseg4ei16_v_m)))
void vloxseg4ei16_v_i16mf2_m(vint16mf2_t *, vint16mf2_t *, vint16mf2_t *, vint16mf2_t *, vbool32_t, vint16mf2_t, vint16mf2_t, vint16mf2_t, vint16mf2_t, const int16_t *, vuint16mf2_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vloxseg4ei16_v)))
void vloxseg4ei16_v_i16mf4(vint16mf4_t *, vint16mf4_t *, vint16mf4_t *, vint16mf4_t *, const int16_t *, vuint16mf4_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vloxseg4ei16_v_m)))
void vloxseg4ei16_v_i16mf4_m(vint16mf4_t *, vint16mf4_t *, vint16mf4_t *, vint16mf4_t *, vbool64_t, vint16mf4_t, vint16mf4_t, vint16mf4_t, vint16mf4_t, const int16_t *, vuint16mf4_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vloxseg4ei16_v)))
void vloxseg4ei16_v_u16m1(vuint16m1_t *, vuint16m1_t *, vuint16m1_t *, vuint16m1_t *, const uint16_t *, vuint16m1_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vloxseg4ei16_v_m)))
void vloxseg4ei16_v_u16m1_m(vuint16m1_t *, vuint16m1_t *, vuint16m1_t *, vuint16m1_t *, vbool16_t, vuint16m1_t, vuint16m1_t, vuint16m1_t, vuint16m1_t, const uint16_t *, vuint16m1_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vloxseg4ei16_v)))
void vloxseg4ei16_v_u16m2(vuint16m2_t *, vuint16m2_t *, vuint16m2_t *, vuint16m2_t *, const uint16_t *, vuint16m2_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vloxseg4ei16_v_m)))
void vloxseg4ei16_v_u16m2_m(vuint16m2_t *, vuint16m2_t *, vuint16m2_t *, vuint16m2_t *, vbool8_t, vuint16m2_t, vuint16m2_t, vuint16m2_t, vuint16m2_t, const uint16_t *, vuint16m2_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vloxseg4ei16_v)))
void vloxseg4ei16_v_u16mf2(vuint16mf2_t *, vuint16mf2_t *, vuint16mf2_t *, vuint16mf2_t *, const uint16_t *, vuint16mf2_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vloxseg4ei16_v_m)))
void vloxseg4ei16_v_u16mf2_m(vuint16mf2_t *, vuint16mf2_t *, vuint16mf2_t *, vuint16mf2_t *, vbool32_t, vuint16mf2_t, vuint16mf2_t, vuint16mf2_t, vuint16mf2_t, const uint16_t *, vuint16mf2_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vloxseg4ei16_v)))
void vloxseg4ei16_v_u16mf4(vuint16mf4_t *, vuint16mf4_t *, vuint16mf4_t *, vuint16mf4_t *, const uint16_t *, vuint16mf4_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vloxseg4ei16_v_m)))
void vloxseg4ei16_v_u16mf4_m(vuint16mf4_t *, vuint16mf4_t *, vuint16mf4_t *, vuint16mf4_t *, vbool64_t, vuint16mf4_t, vuint16mf4_t, vuint16mf4_t, vuint16mf4_t, const uint16_t *, vuint16mf4_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vloxseg5ei16_v)))
void vloxseg5ei16_v_i16m1(vint16m1_t *, vint16m1_t *, vint16m1_t *, vint16m1_t *, vint16m1_t *, const int16_t *, vuint16m1_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vloxseg5ei16_v_m)))
void vloxseg5ei16_v_i16m1_m(vint16m1_t *, vint16m1_t *, vint16m1_t *, vint16m1_t *, vint16m1_t *, vbool16_t, vint16m1_t, vint16m1_t, vint16m1_t, vint16m1_t, vint16m1_t, const int16_t *, vuint16m1_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vloxseg5ei16_v)))
void vloxseg5ei16_v_i16mf2(vint16mf2_t *, vint16mf2_t *, vint16mf2_t *, vint16mf2_t *, vint16mf2_t *, const int16_t *, vuint16mf2_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vloxseg5ei16_v_m)))
void vloxseg5ei16_v_i16mf2_m(vint16mf2_t *, vint16mf2_t *, vint16mf2_t *, vint16mf2_t *, vint16mf2_t *, vbool32_t, vint16mf2_t, vint16mf2_t, vint16mf2_t, vint16mf2_t, vint16mf2_t, const int16_t *, vuint16mf2_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vloxseg5ei16_v)))
void vloxseg5ei16_v_i16mf4(vint16mf4_t *, vint16mf4_t *, vint16mf4_t *, vint16mf4_t *, vint16mf4_t *, const int16_t *, vuint16mf4_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vloxseg5ei16_v_m)))
void vloxseg5ei16_v_i16mf4_m(vint16mf4_t *, vint16mf4_t *, vint16mf4_t *, vint16mf4_t *, vint16mf4_t *, vbool64_t, vint16mf4_t, vint16mf4_t, vint16mf4_t, vint16mf4_t, vint16mf4_t, const int16_t *, vuint16mf4_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vloxseg5ei16_v)))
void vloxseg5ei16_v_u16m1(vuint16m1_t *, vuint16m1_t *, vuint16m1_t *, vuint16m1_t *, vuint16m1_t *, const uint16_t *, vuint16m1_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vloxseg5ei16_v_m)))
void vloxseg5ei16_v_u16m1_m(vuint16m1_t *, vuint16m1_t *, vuint16m1_t *, vuint16m1_t *, vuint16m1_t *, vbool16_t, vuint16m1_t, vuint16m1_t, vuint16m1_t, vuint16m1_t, vuint16m1_t, const uint16_t *, vuint16m1_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vloxseg5ei16_v)))
void vloxseg5ei16_v_u16mf2(vuint16mf2_t *, vuint16mf2_t *, vuint16mf2_t *, vuint16mf2_t *, vuint16mf2_t *, const uint16_t *, vuint16mf2_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vloxseg5ei16_v_m)))
void vloxseg5ei16_v_u16mf2_m(vuint16mf2_t *, vuint16mf2_t *, vuint16mf2_t *, vuint16mf2_t *, vuint16mf2_t *, vbool32_t, vuint16mf2_t, vuint16mf2_t, vuint16mf2_t, vuint16mf2_t, vuint16mf2_t, const uint16_t *, vuint16mf2_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vloxseg5ei16_v)))
void vloxseg5ei16_v_u16mf4(vuint16mf4_t *, vuint16mf4_t *, vuint16mf4_t *, vuint16mf4_t *, vuint16mf4_t *, const uint16_t *, vuint16mf4_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vloxseg5ei16_v_m)))
void vloxseg5ei16_v_u16mf4_m(vuint16mf4_t *, vuint16mf4_t *, vuint16mf4_t *, vuint16mf4_t *, vuint16mf4_t *, vbool64_t, vuint16mf4_t, vuint16mf4_t, vuint16mf4_t, vuint16mf4_t, vuint16mf4_t, const uint16_t *, vuint16mf4_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vloxseg6ei16_v)))
void vloxseg6ei16_v_i16m1(vint16m1_t *, vint16m1_t *, vint16m1_t *, vint16m1_t *, vint16m1_t *, vint16m1_t *, const int16_t *, vuint16m1_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vloxseg6ei16_v_m)))
void vloxseg6ei16_v_i16m1_m(vint16m1_t *, vint16m1_t *, vint16m1_t *, vint16m1_t *, vint16m1_t *, vint16m1_t *, vbool16_t, vint16m1_t, vint16m1_t, vint16m1_t, vint16m1_t, vint16m1_t, vint16m1_t, const int16_t *, vuint16m1_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vloxseg6ei16_v)))
void vloxseg6ei16_v_i16mf2(vint16mf2_t *, vint16mf2_t *, vint16mf2_t *, vint16mf2_t *, vint16mf2_t *, vint16mf2_t *, const int16_t *, vuint16mf2_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vloxseg6ei16_v_m)))
void vloxseg6ei16_v_i16mf2_m(vint16mf2_t *, vint16mf2_t *, vint16mf2_t *, vint16mf2_t *, vint16mf2_t *, vint16mf2_t *, vbool32_t, vint16mf2_t, vint16mf2_t, vint16mf2_t, vint16mf2_t, vint16mf2_t, vint16mf2_t, const int16_t *, vuint16mf2_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vloxseg6ei16_v)))
void vloxseg6ei16_v_i16mf4(vint16mf4_t *, vint16mf4_t *, vint16mf4_t *, vint16mf4_t *, vint16mf4_t *, vint16mf4_t *, const int16_t *, vuint16mf4_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vloxseg6ei16_v_m)))
void vloxseg6ei16_v_i16mf4_m(vint16mf4_t *, vint16mf4_t *, vint16mf4_t *, vint16mf4_t *, vint16mf4_t *, vint16mf4_t *, vbool64_t, vint16mf4_t, vint16mf4_t, vint16mf4_t, vint16mf4_t, vint16mf4_t, vint16mf4_t, const int16_t *, vuint16mf4_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vloxseg6ei16_v)))
void vloxseg6ei16_v_u16m1(vuint16m1_t *, vuint16m1_t *, vuint16m1_t *, vuint16m1_t *, vuint16m1_t *, vuint16m1_t *, const uint16_t *, vuint16m1_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vloxseg6ei16_v_m)))
void vloxseg6ei16_v_u16m1_m(vuint16m1_t *, vuint16m1_t *, vuint16m1_t *, vuint16m1_t *, vuint16m1_t *, vuint16m1_t *, vbool16_t, vuint16m1_t, vuint16m1_t, vuint16m1_t, vuint16m1_t, vuint16m1_t, vuint16m1_t, const uint16_t *, vuint16m1_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vloxseg6ei16_v)))
void vloxseg6ei16_v_u16mf2(vuint16mf2_t *, vuint16mf2_t *, vuint16mf2_t *, vuint16mf2_t *, vuint16mf2_t *, vuint16mf2_t *, const uint16_t *, vuint16mf2_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vloxseg6ei16_v_m)))
void vloxseg6ei16_v_u16mf2_m(vuint16mf2_t *, vuint16mf2_t *, vuint16mf2_t *, vuint16mf2_t *, vuint16mf2_t *, vuint16mf2_t *, vbool32_t, vuint16mf2_t, vuint16mf2_t, vuint16mf2_t, vuint16mf2_t, vuint16mf2_t, vuint16mf2_t, const uint16_t *, vuint16mf2_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vloxseg6ei16_v)))
void vloxseg6ei16_v_u16mf4(vuint16mf4_t *, vuint16mf4_t *, vuint16mf4_t *, vuint16mf4_t *, vuint16mf4_t *, vuint16mf4_t *, const uint16_t *, vuint16mf4_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vloxseg6ei16_v_m)))
void vloxseg6ei16_v_u16mf4_m(vuint16mf4_t *, vuint16mf4_t *, vuint16mf4_t *, vuint16mf4_t *, vuint16mf4_t *, vuint16mf4_t *, vbool64_t, vuint16mf4_t, vuint16mf4_t, vuint16mf4_t, vuint16mf4_t, vuint16mf4_t, vuint16mf4_t, const uint16_t *, vuint16mf4_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vloxseg7ei16_v)))
void vloxseg7ei16_v_i16m1(vint16m1_t *, vint16m1_t *, vint16m1_t *, vint16m1_t *, vint16m1_t *, vint16m1_t *, vint16m1_t *, const int16_t *, vuint16m1_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vloxseg7ei16_v_m)))
void vloxseg7ei16_v_i16m1_m(vint16m1_t *, vint16m1_t *, vint16m1_t *, vint16m1_t *, vint16m1_t *, vint16m1_t *, vint16m1_t *, vbool16_t, vint16m1_t, vint16m1_t, vint16m1_t, vint16m1_t, vint16m1_t, vint16m1_t, vint16m1_t, const int16_t *, vuint16m1_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vloxseg7ei16_v)))
void vloxseg7ei16_v_i16mf2(vint16mf2_t *, vint16mf2_t *, vint16mf2_t *, vint16mf2_t *, vint16mf2_t *, vint16mf2_t *, vint16mf2_t *, const int16_t *, vuint16mf2_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vloxseg7ei16_v_m)))
void vloxseg7ei16_v_i16mf2_m(vint16mf2_t *, vint16mf2_t *, vint16mf2_t *, vint16mf2_t *, vint16mf2_t *, vint16mf2_t *, vint16mf2_t *, vbool32_t, vint16mf2_t, vint16mf2_t, vint16mf2_t, vint16mf2_t, vint16mf2_t, vint16mf2_t, vint16mf2_t, const int16_t *, vuint16mf2_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vloxseg7ei16_v)))
void vloxseg7ei16_v_i16mf4(vint16mf4_t *, vint16mf4_t *, vint16mf4_t *, vint16mf4_t *, vint16mf4_t *, vint16mf4_t *, vint16mf4_t *, const int16_t *, vuint16mf4_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vloxseg7ei16_v_m)))
void vloxseg7ei16_v_i16mf4_m(vint16mf4_t *, vint16mf4_t *, vint16mf4_t *, vint16mf4_t *, vint16mf4_t *, vint16mf4_t *, vint16mf4_t *, vbool64_t, vint16mf4_t, vint16mf4_t, vint16mf4_t, vint16mf4_t, vint16mf4_t, vint16mf4_t, vint16mf4_t, const int16_t *, vuint16mf4_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vloxseg7ei16_v)))
void vloxseg7ei16_v_u16m1(vuint16m1_t *, vuint16m1_t *, vuint16m1_t *, vuint16m1_t *, vuint16m1_t *, vuint16m1_t *, vuint16m1_t *, const uint16_t *, vuint16m1_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vloxseg7ei16_v_m)))
void vloxseg7ei16_v_u16m1_m(vuint16m1_t *, vuint16m1_t *, vuint16m1_t *, vuint16m1_t *, vuint16m1_t *, vuint16m1_t *, vuint16m1_t *, vbool16_t, vuint16m1_t, vuint16m1_t, vuint16m1_t, vuint16m1_t, vuint16m1_t, vuint16m1_t, vuint16m1_t, const uint16_t *, vuint16m1_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vloxseg7ei16_v)))
void vloxseg7ei16_v_u16mf2(vuint16mf2_t *, vuint16mf2_t *, vuint16mf2_t *, vuint16mf2_t *, vuint16mf2_t *, vuint16mf2_t *, vuint16mf2_t *, const uint16_t *, vuint16mf2_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vloxseg7ei16_v_m)))
void vloxseg7ei16_v_u16mf2_m(vuint16mf2_t *, vuint16mf2_t *, vuint16mf2_t *, vuint16mf2_t *, vuint16mf2_t *, vuint16mf2_t *, vuint16mf2_t *, vbool32_t, vuint16mf2_t, vuint16mf2_t, vuint16mf2_t, vuint16mf2_t, vuint16mf2_t, vuint16mf2_t, vuint16mf2_t, const uint16_t *, vuint16mf2_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vloxseg7ei16_v)))
void vloxseg7ei16_v_u16mf4(vuint16mf4_t *, vuint16mf4_t *, vuint16mf4_t *, vuint16mf4_t *, vuint16mf4_t *, vuint16mf4_t *, vuint16mf4_t *, const uint16_t *, vuint16mf4_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vloxseg7ei16_v_m)))
void vloxseg7ei16_v_u16mf4_m(vuint16mf4_t *, vuint16mf4_t *, vuint16mf4_t *, vuint16mf4_t *, vuint16mf4_t *, vuint16mf4_t *, vuint16mf4_t *, vbool64_t, vuint16mf4_t, vuint16mf4_t, vuint16mf4_t, vuint16mf4_t, vuint16mf4_t, vuint16mf4_t, vuint16mf4_t, const uint16_t *, vuint16mf4_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vloxseg8ei16_v)))
void vloxseg8ei16_v_i16m1(vint16m1_t *, vint16m1_t *, vint16m1_t *, vint16m1_t *, vint16m1_t *, vint16m1_t *, vint16m1_t *, vint16m1_t *, const int16_t *, vuint16m1_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vloxseg8ei16_v_m)))
void vloxseg8ei16_v_i16m1_m(vint16m1_t *, vint16m1_t *, vint16m1_t *, vint16m1_t *, vint16m1_t *, vint16m1_t *, vint16m1_t *, vint16m1_t *, vbool16_t, vint16m1_t, vint16m1_t, vint16m1_t, vint16m1_t, vint16m1_t, vint16m1_t, vint16m1_t, vint16m1_t, const int16_t *, vuint16m1_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vloxseg8ei16_v)))
void vloxseg8ei16_v_i16mf2(vint16mf2_t *, vint16mf2_t *, vint16mf2_t *, vint16mf2_t *, vint16mf2_t *, vint16mf2_t *, vint16mf2_t *, vint16mf2_t *, const int16_t *, vuint16mf2_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vloxseg8ei16_v_m)))
void vloxseg8ei16_v_i16mf2_m(vint16mf2_t *, vint16mf2_t *, vint16mf2_t *, vint16mf2_t *, vint16mf2_t *, vint16mf2_t *, vint16mf2_t *, vint16mf2_t *, vbool32_t, vint16mf2_t, vint16mf2_t, vint16mf2_t, vint16mf2_t, vint16mf2_t, vint16mf2_t, vint16mf2_t, vint16mf2_t, const int16_t *, vuint16mf2_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vloxseg8ei16_v)))
void vloxseg8ei16_v_i16mf4(vint16mf4_t *, vint16mf4_t *, vint16mf4_t *, vint16mf4_t *, vint16mf4_t *, vint16mf4_t *, vint16mf4_t *, vint16mf4_t *, const int16_t *, vuint16mf4_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vloxseg8ei16_v_m)))
void vloxseg8ei16_v_i16mf4_m(vint16mf4_t *, vint16mf4_t *, vint16mf4_t *, vint16mf4_t *, vint16mf4_t *, vint16mf4_t *, vint16mf4_t *, vint16mf4_t *, vbool64_t, vint16mf4_t, vint16mf4_t, vint16mf4_t, vint16mf4_t, vint16mf4_t, vint16mf4_t, vint16mf4_t, vint16mf4_t, const int16_t *, vuint16mf4_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vloxseg8ei16_v)))
void vloxseg8ei16_v_u16m1(vuint16m1_t *, vuint16m1_t *, vuint16m1_t *, vuint16m1_t *, vuint16m1_t *, vuint16m1_t *, vuint16m1_t *, vuint16m1_t *, const uint16_t *, vuint16m1_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vloxseg8ei16_v_m)))
void vloxseg8ei16_v_u16m1_m(vuint16m1_t *, vuint16m1_t *, vuint16m1_t *, vuint16m1_t *, vuint16m1_t *, vuint16m1_t *, vuint16m1_t *, vuint16m1_t *, vbool16_t, vuint16m1_t, vuint16m1_t, vuint16m1_t, vuint16m1_t, vuint16m1_t, vuint16m1_t, vuint16m1_t, vuint16m1_t, const uint16_t *, vuint16m1_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vloxseg8ei16_v)))
void vloxseg8ei16_v_u16mf2(vuint16mf2_t *, vuint16mf2_t *, vuint16mf2_t *, vuint16mf2_t *, vuint16mf2_t *, vuint16mf2_t *, vuint16mf2_t *, vuint16mf2_t *, const uint16_t *, vuint16mf2_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vloxseg8ei16_v_m)))
void vloxseg8ei16_v_u16mf2_m(vuint16mf2_t *, vuint16mf2_t *, vuint16mf2_t *, vuint16mf2_t *, vuint16mf2_t *, vuint16mf2_t *, vuint16mf2_t *, vuint16mf2_t *, vbool32_t, vuint16mf2_t, vuint16mf2_t, vuint16mf2_t, vuint16mf2_t, vuint16mf2_t, vuint16mf2_t, vuint16mf2_t, vuint16mf2_t, const uint16_t *, vuint16mf2_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vloxseg8ei16_v)))
void vloxseg8ei16_v_u16mf4(vuint16mf4_t *, vuint16mf4_t *, vuint16mf4_t *, vuint16mf4_t *, vuint16mf4_t *, vuint16mf4_t *, vuint16mf4_t *, vuint16mf4_t *, const uint16_t *, vuint16mf4_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vloxseg8ei16_v_m)))
void vloxseg8ei16_v_u16mf4_m(vuint16mf4_t *, vuint16mf4_t *, vuint16mf4_t *, vuint16mf4_t *, vuint16mf4_t *, vuint16mf4_t *, vuint16mf4_t *, vuint16mf4_t *, vbool64_t, vuint16mf4_t, vuint16mf4_t, vuint16mf4_t, vuint16mf4_t, vuint16mf4_t, vuint16mf4_t, vuint16mf4_t, vuint16mf4_t, const uint16_t *, vuint16mf4_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vloxseg2ei32_v)))
void vloxseg2ei32_v_i16m1(vint16m1_t *, vint16m1_t *, const int16_t *, vuint32m2_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vloxseg2ei32_v_m)))
void vloxseg2ei32_v_i16m1_m(vint16m1_t *, vint16m1_t *, vbool16_t, vint16m1_t, vint16m1_t, const int16_t *, vuint32m2_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vloxseg2ei32_v)))
void vloxseg2ei32_v_i16m2(vint16m2_t *, vint16m2_t *, const int16_t *, vuint32m4_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vloxseg2ei32_v_m)))
void vloxseg2ei32_v_i16m2_m(vint16m2_t *, vint16m2_t *, vbool8_t, vint16m2_t, vint16m2_t, const int16_t *, vuint32m4_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vloxseg2ei32_v)))
void vloxseg2ei32_v_i16m4(vint16m4_t *, vint16m4_t *, const int16_t *, vuint32m8_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vloxseg2ei32_v_m)))
void vloxseg2ei32_v_i16m4_m(vint16m4_t *, vint16m4_t *, vbool4_t, vint16m4_t, vint16m4_t, const int16_t *, vuint32m8_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vloxseg2ei32_v)))
void vloxseg2ei32_v_i16mf2(vint16mf2_t *, vint16mf2_t *, const int16_t *, vuint32m1_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vloxseg2ei32_v_m)))
void vloxseg2ei32_v_i16mf2_m(vint16mf2_t *, vint16mf2_t *, vbool32_t, vint16mf2_t, vint16mf2_t, const int16_t *, vuint32m1_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vloxseg2ei32_v)))
void vloxseg2ei32_v_i16mf4(vint16mf4_t *, vint16mf4_t *, const int16_t *, vuint32mf2_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vloxseg2ei32_v_m)))
void vloxseg2ei32_v_i16mf4_m(vint16mf4_t *, vint16mf4_t *, vbool64_t, vint16mf4_t, vint16mf4_t, const int16_t *, vuint32mf2_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vloxseg2ei32_v)))
void vloxseg2ei32_v_u16m1(vuint16m1_t *, vuint16m1_t *, const uint16_t *, vuint32m2_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vloxseg2ei32_v_m)))
void vloxseg2ei32_v_u16m1_m(vuint16m1_t *, vuint16m1_t *, vbool16_t, vuint16m1_t, vuint16m1_t, const uint16_t *, vuint32m2_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vloxseg2ei32_v)))
void vloxseg2ei32_v_u16m2(vuint16m2_t *, vuint16m2_t *, const uint16_t *, vuint32m4_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vloxseg2ei32_v_m)))
void vloxseg2ei32_v_u16m2_m(vuint16m2_t *, vuint16m2_t *, vbool8_t, vuint16m2_t, vuint16m2_t, const uint16_t *, vuint32m4_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vloxseg2ei32_v)))
void vloxseg2ei32_v_u16m4(vuint16m4_t *, vuint16m4_t *, const uint16_t *, vuint32m8_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vloxseg2ei32_v_m)))
void vloxseg2ei32_v_u16m4_m(vuint16m4_t *, vuint16m4_t *, vbool4_t, vuint16m4_t, vuint16m4_t, const uint16_t *, vuint32m8_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vloxseg2ei32_v)))
void vloxseg2ei32_v_u16mf2(vuint16mf2_t *, vuint16mf2_t *, const uint16_t *, vuint32m1_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vloxseg2ei32_v_m)))
void vloxseg2ei32_v_u16mf2_m(vuint16mf2_t *, vuint16mf2_t *, vbool32_t, vuint16mf2_t, vuint16mf2_t, const uint16_t *, vuint32m1_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vloxseg2ei32_v)))
void vloxseg2ei32_v_u16mf4(vuint16mf4_t *, vuint16mf4_t *, const uint16_t *, vuint32mf2_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vloxseg2ei32_v_m)))
void vloxseg2ei32_v_u16mf4_m(vuint16mf4_t *, vuint16mf4_t *, vbool64_t, vuint16mf4_t, vuint16mf4_t, const uint16_t *, vuint32mf2_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vloxseg3ei32_v)))
void vloxseg3ei32_v_i16m1(vint16m1_t *, vint16m1_t *, vint16m1_t *, const int16_t *, vuint32m2_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vloxseg3ei32_v_m)))
void vloxseg3ei32_v_i16m1_m(vint16m1_t *, vint16m1_t *, vint16m1_t *, vbool16_t, vint16m1_t, vint16m1_t, vint16m1_t, const int16_t *, vuint32m2_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vloxseg3ei32_v)))
void vloxseg3ei32_v_i16m2(vint16m2_t *, vint16m2_t *, vint16m2_t *, const int16_t *, vuint32m4_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vloxseg3ei32_v_m)))
void vloxseg3ei32_v_i16m2_m(vint16m2_t *, vint16m2_t *, vint16m2_t *, vbool8_t, vint16m2_t, vint16m2_t, vint16m2_t, const int16_t *, vuint32m4_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vloxseg3ei32_v)))
void vloxseg3ei32_v_i16mf2(vint16mf2_t *, vint16mf2_t *, vint16mf2_t *, const int16_t *, vuint32m1_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vloxseg3ei32_v_m)))
void vloxseg3ei32_v_i16mf2_m(vint16mf2_t *, vint16mf2_t *, vint16mf2_t *, vbool32_t, vint16mf2_t, vint16mf2_t, vint16mf2_t, const int16_t *, vuint32m1_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vloxseg3ei32_v)))
void vloxseg3ei32_v_i16mf4(vint16mf4_t *, vint16mf4_t *, vint16mf4_t *, const int16_t *, vuint32mf2_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vloxseg3ei32_v_m)))
void vloxseg3ei32_v_i16mf4_m(vint16mf4_t *, vint16mf4_t *, vint16mf4_t *, vbool64_t, vint16mf4_t, vint16mf4_t, vint16mf4_t, const int16_t *, vuint32mf2_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vloxseg3ei32_v)))
void vloxseg3ei32_v_u16m1(vuint16m1_t *, vuint16m1_t *, vuint16m1_t *, const uint16_t *, vuint32m2_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vloxseg3ei32_v_m)))
void vloxseg3ei32_v_u16m1_m(vuint16m1_t *, vuint16m1_t *, vuint16m1_t *, vbool16_t, vuint16m1_t, vuint16m1_t, vuint16m1_t, const uint16_t *, vuint32m2_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vloxseg3ei32_v)))
void vloxseg3ei32_v_u16m2(vuint16m2_t *, vuint16m2_t *, vuint16m2_t *, const uint16_t *, vuint32m4_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vloxseg3ei32_v_m)))
void vloxseg3ei32_v_u16m2_m(vuint16m2_t *, vuint16m2_t *, vuint16m2_t *, vbool8_t, vuint16m2_t, vuint16m2_t, vuint16m2_t, const uint16_t *, vuint32m4_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vloxseg3ei32_v)))
void vloxseg3ei32_v_u16mf2(vuint16mf2_t *, vuint16mf2_t *, vuint16mf2_t *, const uint16_t *, vuint32m1_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vloxseg3ei32_v_m)))
void vloxseg3ei32_v_u16mf2_m(vuint16mf2_t *, vuint16mf2_t *, vuint16mf2_t *, vbool32_t, vuint16mf2_t, vuint16mf2_t, vuint16mf2_t, const uint16_t *, vuint32m1_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vloxseg3ei32_v)))
void vloxseg3ei32_v_u16mf4(vuint16mf4_t *, vuint16mf4_t *, vuint16mf4_t *, const uint16_t *, vuint32mf2_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vloxseg3ei32_v_m)))
void vloxseg3ei32_v_u16mf4_m(vuint16mf4_t *, vuint16mf4_t *, vuint16mf4_t *, vbool64_t, vuint16mf4_t, vuint16mf4_t, vuint16mf4_t, const uint16_t *, vuint32mf2_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vloxseg4ei32_v)))
void vloxseg4ei32_v_i16m1(vint16m1_t *, vint16m1_t *, vint16m1_t *, vint16m1_t *, const int16_t *, vuint32m2_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vloxseg4ei32_v_m)))
void vloxseg4ei32_v_i16m1_m(vint16m1_t *, vint16m1_t *, vint16m1_t *, vint16m1_t *, vbool16_t, vint16m1_t, vint16m1_t, vint16m1_t, vint16m1_t, const int16_t *, vuint32m2_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vloxseg4ei32_v)))
void vloxseg4ei32_v_i16m2(vint16m2_t *, vint16m2_t *, vint16m2_t *, vint16m2_t *, const int16_t *, vuint32m4_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vloxseg4ei32_v_m)))
void vloxseg4ei32_v_i16m2_m(vint16m2_t *, vint16m2_t *, vint16m2_t *, vint16m2_t *, vbool8_t, vint16m2_t, vint16m2_t, vint16m2_t, vint16m2_t, const int16_t *, vuint32m4_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vloxseg4ei32_v)))
void vloxseg4ei32_v_i16mf2(vint16mf2_t *, vint16mf2_t *, vint16mf2_t *, vint16mf2_t *, const int16_t *, vuint32m1_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vloxseg4ei32_v_m)))
void vloxseg4ei32_v_i16mf2_m(vint16mf2_t *, vint16mf2_t *, vint16mf2_t *, vint16mf2_t *, vbool32_t, vint16mf2_t, vint16mf2_t, vint16mf2_t, vint16mf2_t, const int16_t *, vuint32m1_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vloxseg4ei32_v)))
void vloxseg4ei32_v_i16mf4(vint16mf4_t *, vint16mf4_t *, vint16mf4_t *, vint16mf4_t *, const int16_t *, vuint32mf2_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vloxseg4ei32_v_m)))
void vloxseg4ei32_v_i16mf4_m(vint16mf4_t *, vint16mf4_t *, vint16mf4_t *, vint16mf4_t *, vbool64_t, vint16mf4_t, vint16mf4_t, vint16mf4_t, vint16mf4_t, const int16_t *, vuint32mf2_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vloxseg4ei32_v)))
void vloxseg4ei32_v_u16m1(vuint16m1_t *, vuint16m1_t *, vuint16m1_t *, vuint16m1_t *, const uint16_t *, vuint32m2_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vloxseg4ei32_v_m)))
void vloxseg4ei32_v_u16m1_m(vuint16m1_t *, vuint16m1_t *, vuint16m1_t *, vuint16m1_t *, vbool16_t, vuint16m1_t, vuint16m1_t, vuint16m1_t, vuint16m1_t, const uint16_t *, vuint32m2_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vloxseg4ei32_v)))
void vloxseg4ei32_v_u16m2(vuint16m2_t *, vuint16m2_t *, vuint16m2_t *, vuint16m2_t *, const uint16_t *, vuint32m4_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vloxseg4ei32_v_m)))
void vloxseg4ei32_v_u16m2_m(vuint16m2_t *, vuint16m2_t *, vuint16m2_t *, vuint16m2_t *, vbool8_t, vuint16m2_t, vuint16m2_t, vuint16m2_t, vuint16m2_t, const uint16_t *, vuint32m4_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vloxseg4ei32_v)))
void vloxseg4ei32_v_u16mf2(vuint16mf2_t *, vuint16mf2_t *, vuint16mf2_t *, vuint16mf2_t *, const uint16_t *, vuint32m1_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vloxseg4ei32_v_m)))
void vloxseg4ei32_v_u16mf2_m(vuint16mf2_t *, vuint16mf2_t *, vuint16mf2_t *, vuint16mf2_t *, vbool32_t, vuint16mf2_t, vuint16mf2_t, vuint16mf2_t, vuint16mf2_t, const uint16_t *, vuint32m1_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vloxseg4ei32_v)))
void vloxseg4ei32_v_u16mf4(vuint16mf4_t *, vuint16mf4_t *, vuint16mf4_t *, vuint16mf4_t *, const uint16_t *, vuint32mf2_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vloxseg4ei32_v_m)))
void vloxseg4ei32_v_u16mf4_m(vuint16mf4_t *, vuint16mf4_t *, vuint16mf4_t *, vuint16mf4_t *, vbool64_t, vuint16mf4_t, vuint16mf4_t, vuint16mf4_t, vuint16mf4_t, const uint16_t *, vuint32mf2_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vloxseg5ei32_v)))
void vloxseg5ei32_v_i16m1(vint16m1_t *, vint16m1_t *, vint16m1_t *, vint16m1_t *, vint16m1_t *, const int16_t *, vuint32m2_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vloxseg5ei32_v_m)))
void vloxseg5ei32_v_i16m1_m(vint16m1_t *, vint16m1_t *, vint16m1_t *, vint16m1_t *, vint16m1_t *, vbool16_t, vint16m1_t, vint16m1_t, vint16m1_t, vint16m1_t, vint16m1_t, const int16_t *, vuint32m2_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vloxseg5ei32_v)))
void vloxseg5ei32_v_i16mf2(vint16mf2_t *, vint16mf2_t *, vint16mf2_t *, vint16mf2_t *, vint16mf2_t *, const int16_t *, vuint32m1_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vloxseg5ei32_v_m)))
void vloxseg5ei32_v_i16mf2_m(vint16mf2_t *, vint16mf2_t *, vint16mf2_t *, vint16mf2_t *, vint16mf2_t *, vbool32_t, vint16mf2_t, vint16mf2_t, vint16mf2_t, vint16mf2_t, vint16mf2_t, const int16_t *, vuint32m1_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vloxseg5ei32_v)))
void vloxseg5ei32_v_i16mf4(vint16mf4_t *, vint16mf4_t *, vint16mf4_t *, vint16mf4_t *, vint16mf4_t *, const int16_t *, vuint32mf2_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vloxseg5ei32_v_m)))
void vloxseg5ei32_v_i16mf4_m(vint16mf4_t *, vint16mf4_t *, vint16mf4_t *, vint16mf4_t *, vint16mf4_t *, vbool64_t, vint16mf4_t, vint16mf4_t, vint16mf4_t, vint16mf4_t, vint16mf4_t, const int16_t *, vuint32mf2_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vloxseg5ei32_v)))
void vloxseg5ei32_v_u16m1(vuint16m1_t *, vuint16m1_t *, vuint16m1_t *, vuint16m1_t *, vuint16m1_t *, const uint16_t *, vuint32m2_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vloxseg5ei32_v_m)))
void vloxseg5ei32_v_u16m1_m(vuint16m1_t *, vuint16m1_t *, vuint16m1_t *, vuint16m1_t *, vuint16m1_t *, vbool16_t, vuint16m1_t, vuint16m1_t, vuint16m1_t, vuint16m1_t, vuint16m1_t, const uint16_t *, vuint32m2_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vloxseg5ei32_v)))
void vloxseg5ei32_v_u16mf2(vuint16mf2_t *, vuint16mf2_t *, vuint16mf2_t *, vuint16mf2_t *, vuint16mf2_t *, const uint16_t *, vuint32m1_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vloxseg5ei32_v_m)))
void vloxseg5ei32_v_u16mf2_m(vuint16mf2_t *, vuint16mf2_t *, vuint16mf2_t *, vuint16mf2_t *, vuint16mf2_t *, vbool32_t, vuint16mf2_t, vuint16mf2_t, vuint16mf2_t, vuint16mf2_t, vuint16mf2_t, const uint16_t *, vuint32m1_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vloxseg5ei32_v)))
void vloxseg5ei32_v_u16mf4(vuint16mf4_t *, vuint16mf4_t *, vuint16mf4_t *, vuint16mf4_t *, vuint16mf4_t *, const uint16_t *, vuint32mf2_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vloxseg5ei32_v_m)))
void vloxseg5ei32_v_u16mf4_m(vuint16mf4_t *, vuint16mf4_t *, vuint16mf4_t *, vuint16mf4_t *, vuint16mf4_t *, vbool64_t, vuint16mf4_t, vuint16mf4_t, vuint16mf4_t, vuint16mf4_t, vuint16mf4_t, const uint16_t *, vuint32mf2_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vloxseg6ei32_v)))
void vloxseg6ei32_v_i16m1(vint16m1_t *, vint16m1_t *, vint16m1_t *, vint16m1_t *, vint16m1_t *, vint16m1_t *, const int16_t *, vuint32m2_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vloxseg6ei32_v_m)))
void vloxseg6ei32_v_i16m1_m(vint16m1_t *, vint16m1_t *, vint16m1_t *, vint16m1_t *, vint16m1_t *, vint16m1_t *, vbool16_t, vint16m1_t, vint16m1_t, vint16m1_t, vint16m1_t, vint16m1_t, vint16m1_t, const int16_t *, vuint32m2_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vloxseg6ei32_v)))
void vloxseg6ei32_v_i16mf2(vint16mf2_t *, vint16mf2_t *, vint16mf2_t *, vint16mf2_t *, vint16mf2_t *, vint16mf2_t *, const int16_t *, vuint32m1_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vloxseg6ei32_v_m)))
void vloxseg6ei32_v_i16mf2_m(vint16mf2_t *, vint16mf2_t *, vint16mf2_t *, vint16mf2_t *, vint16mf2_t *, vint16mf2_t *, vbool32_t, vint16mf2_t, vint16mf2_t, vint16mf2_t, vint16mf2_t, vint16mf2_t, vint16mf2_t, const int16_t *, vuint32m1_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vloxseg6ei32_v)))
void vloxseg6ei32_v_i16mf4(vint16mf4_t *, vint16mf4_t *, vint16mf4_t *, vint16mf4_t *, vint16mf4_t *, vint16mf4_t *, const int16_t *, vuint32mf2_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vloxseg6ei32_v_m)))
void vloxseg6ei32_v_i16mf4_m(vint16mf4_t *, vint16mf4_t *, vint16mf4_t *, vint16mf4_t *, vint16mf4_t *, vint16mf4_t *, vbool64_t, vint16mf4_t, vint16mf4_t, vint16mf4_t, vint16mf4_t, vint16mf4_t, vint16mf4_t, const int16_t *, vuint32mf2_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vloxseg6ei32_v)))
void vloxseg6ei32_v_u16m1(vuint16m1_t *, vuint16m1_t *, vuint16m1_t *, vuint16m1_t *, vuint16m1_t *, vuint16m1_t *, const uint16_t *, vuint32m2_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vloxseg6ei32_v_m)))
void vloxseg6ei32_v_u16m1_m(vuint16m1_t *, vuint16m1_t *, vuint16m1_t *, vuint16m1_t *, vuint16m1_t *, vuint16m1_t *, vbool16_t, vuint16m1_t, vuint16m1_t, vuint16m1_t, vuint16m1_t, vuint16m1_t, vuint16m1_t, const uint16_t *, vuint32m2_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vloxseg6ei32_v)))
void vloxseg6ei32_v_u16mf2(vuint16mf2_t *, vuint16mf2_t *, vuint16mf2_t *, vuint16mf2_t *, vuint16mf2_t *, vuint16mf2_t *, const uint16_t *, vuint32m1_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vloxseg6ei32_v_m)))
void vloxseg6ei32_v_u16mf2_m(vuint16mf2_t *, vuint16mf2_t *, vuint16mf2_t *, vuint16mf2_t *, vuint16mf2_t *, vuint16mf2_t *, vbool32_t, vuint16mf2_t, vuint16mf2_t, vuint16mf2_t, vuint16mf2_t, vuint16mf2_t, vuint16mf2_t, const uint16_t *, vuint32m1_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vloxseg6ei32_v)))
void vloxseg6ei32_v_u16mf4(vuint16mf4_t *, vuint16mf4_t *, vuint16mf4_t *, vuint16mf4_t *, vuint16mf4_t *, vuint16mf4_t *, const uint16_t *, vuint32mf2_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vloxseg6ei32_v_m)))
void vloxseg6ei32_v_u16mf4_m(vuint16mf4_t *, vuint16mf4_t *, vuint16mf4_t *, vuint16mf4_t *, vuint16mf4_t *, vuint16mf4_t *, vbool64_t, vuint16mf4_t, vuint16mf4_t, vuint16mf4_t, vuint16mf4_t, vuint16mf4_t, vuint16mf4_t, const uint16_t *, vuint32mf2_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vloxseg7ei32_v)))
void vloxseg7ei32_v_i16m1(vint16m1_t *, vint16m1_t *, vint16m1_t *, vint16m1_t *, vint16m1_t *, vint16m1_t *, vint16m1_t *, const int16_t *, vuint32m2_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vloxseg7ei32_v_m)))
void vloxseg7ei32_v_i16m1_m(vint16m1_t *, vint16m1_t *, vint16m1_t *, vint16m1_t *, vint16m1_t *, vint16m1_t *, vint16m1_t *, vbool16_t, vint16m1_t, vint16m1_t, vint16m1_t, vint16m1_t, vint16m1_t, vint16m1_t, vint16m1_t, const int16_t *, vuint32m2_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vloxseg7ei32_v)))
void vloxseg7ei32_v_i16mf2(vint16mf2_t *, vint16mf2_t *, vint16mf2_t *, vint16mf2_t *, vint16mf2_t *, vint16mf2_t *, vint16mf2_t *, const int16_t *, vuint32m1_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vloxseg7ei32_v_m)))
void vloxseg7ei32_v_i16mf2_m(vint16mf2_t *, vint16mf2_t *, vint16mf2_t *, vint16mf2_t *, vint16mf2_t *, vint16mf2_t *, vint16mf2_t *, vbool32_t, vint16mf2_t, vint16mf2_t, vint16mf2_t, vint16mf2_t, vint16mf2_t, vint16mf2_t, vint16mf2_t, const int16_t *, vuint32m1_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vloxseg7ei32_v)))
void vloxseg7ei32_v_i16mf4(vint16mf4_t *, vint16mf4_t *, vint16mf4_t *, vint16mf4_t *, vint16mf4_t *, vint16mf4_t *, vint16mf4_t *, const int16_t *, vuint32mf2_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vloxseg7ei32_v_m)))
void vloxseg7ei32_v_i16mf4_m(vint16mf4_t *, vint16mf4_t *, vint16mf4_t *, vint16mf4_t *, vint16mf4_t *, vint16mf4_t *, vint16mf4_t *, vbool64_t, vint16mf4_t, vint16mf4_t, vint16mf4_t, vint16mf4_t, vint16mf4_t, vint16mf4_t, vint16mf4_t, const int16_t *, vuint32mf2_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vloxseg7ei32_v)))
void vloxseg7ei32_v_u16m1(vuint16m1_t *, vuint16m1_t *, vuint16m1_t *, vuint16m1_t *, vuint16m1_t *, vuint16m1_t *, vuint16m1_t *, const uint16_t *, vuint32m2_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vloxseg7ei32_v_m)))
void vloxseg7ei32_v_u16m1_m(vuint16m1_t *, vuint16m1_t *, vuint16m1_t *, vuint16m1_t *, vuint16m1_t *, vuint16m1_t *, vuint16m1_t *, vbool16_t, vuint16m1_t, vuint16m1_t, vuint16m1_t, vuint16m1_t, vuint16m1_t, vuint16m1_t, vuint16m1_t, const uint16_t *, vuint32m2_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vloxseg7ei32_v)))
void vloxseg7ei32_v_u16mf2(vuint16mf2_t *, vuint16mf2_t *, vuint16mf2_t *, vuint16mf2_t *, vuint16mf2_t *, vuint16mf2_t *, vuint16mf2_t *, const uint16_t *, vuint32m1_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vloxseg7ei32_v_m)))
void vloxseg7ei32_v_u16mf2_m(vuint16mf2_t *, vuint16mf2_t *, vuint16mf2_t *, vuint16mf2_t *, vuint16mf2_t *, vuint16mf2_t *, vuint16mf2_t *, vbool32_t, vuint16mf2_t, vuint16mf2_t, vuint16mf2_t, vuint16mf2_t, vuint16mf2_t, vuint16mf2_t, vuint16mf2_t, const uint16_t *, vuint32m1_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vloxseg7ei32_v)))
void vloxseg7ei32_v_u16mf4(vuint16mf4_t *, vuint16mf4_t *, vuint16mf4_t *, vuint16mf4_t *, vuint16mf4_t *, vuint16mf4_t *, vuint16mf4_t *, const uint16_t *, vuint32mf2_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vloxseg7ei32_v_m)))
void vloxseg7ei32_v_u16mf4_m(vuint16mf4_t *, vuint16mf4_t *, vuint16mf4_t *, vuint16mf4_t *, vuint16mf4_t *, vuint16mf4_t *, vuint16mf4_t *, vbool64_t, vuint16mf4_t, vuint16mf4_t, vuint16mf4_t, vuint16mf4_t, vuint16mf4_t, vuint16mf4_t, vuint16mf4_t, const uint16_t *, vuint32mf2_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vloxseg8ei32_v)))
void vloxseg8ei32_v_i16m1(vint16m1_t *, vint16m1_t *, vint16m1_t *, vint16m1_t *, vint16m1_t *, vint16m1_t *, vint16m1_t *, vint16m1_t *, const int16_t *, vuint32m2_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vloxseg8ei32_v_m)))
void vloxseg8ei32_v_i16m1_m(vint16m1_t *, vint16m1_t *, vint16m1_t *, vint16m1_t *, vint16m1_t *, vint16m1_t *, vint16m1_t *, vint16m1_t *, vbool16_t, vint16m1_t, vint16m1_t, vint16m1_t, vint16m1_t, vint16m1_t, vint16m1_t, vint16m1_t, vint16m1_t, const int16_t *, vuint32m2_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vloxseg8ei32_v)))
void vloxseg8ei32_v_i16mf2(vint16mf2_t *, vint16mf2_t *, vint16mf2_t *, vint16mf2_t *, vint16mf2_t *, vint16mf2_t *, vint16mf2_t *, vint16mf2_t *, const int16_t *, vuint32m1_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vloxseg8ei32_v_m)))
void vloxseg8ei32_v_i16mf2_m(vint16mf2_t *, vint16mf2_t *, vint16mf2_t *, vint16mf2_t *, vint16mf2_t *, vint16mf2_t *, vint16mf2_t *, vint16mf2_t *, vbool32_t, vint16mf2_t, vint16mf2_t, vint16mf2_t, vint16mf2_t, vint16mf2_t, vint16mf2_t, vint16mf2_t, vint16mf2_t, const int16_t *, vuint32m1_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vloxseg8ei32_v)))
void vloxseg8ei32_v_i16mf4(vint16mf4_t *, vint16mf4_t *, vint16mf4_t *, vint16mf4_t *, vint16mf4_t *, vint16mf4_t *, vint16mf4_t *, vint16mf4_t *, const int16_t *, vuint32mf2_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vloxseg8ei32_v_m)))
void vloxseg8ei32_v_i16mf4_m(vint16mf4_t *, vint16mf4_t *, vint16mf4_t *, vint16mf4_t *, vint16mf4_t *, vint16mf4_t *, vint16mf4_t *, vint16mf4_t *, vbool64_t, vint16mf4_t, vint16mf4_t, vint16mf4_t, vint16mf4_t, vint16mf4_t, vint16mf4_t, vint16mf4_t, vint16mf4_t, const int16_t *, vuint32mf2_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vloxseg8ei32_v)))
void vloxseg8ei32_v_u16m1(vuint16m1_t *, vuint16m1_t *, vuint16m1_t *, vuint16m1_t *, vuint16m1_t *, vuint16m1_t *, vuint16m1_t *, vuint16m1_t *, const uint16_t *, vuint32m2_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vloxseg8ei32_v_m)))
void vloxseg8ei32_v_u16m1_m(vuint16m1_t *, vuint16m1_t *, vuint16m1_t *, vuint16m1_t *, vuint16m1_t *, vuint16m1_t *, vuint16m1_t *, vuint16m1_t *, vbool16_t, vuint16m1_t, vuint16m1_t, vuint16m1_t, vuint16m1_t, vuint16m1_t, vuint16m1_t, vuint16m1_t, vuint16m1_t, const uint16_t *, vuint32m2_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vloxseg8ei32_v)))
void vloxseg8ei32_v_u16mf2(vuint16mf2_t *, vuint16mf2_t *, vuint16mf2_t *, vuint16mf2_t *, vuint16mf2_t *, vuint16mf2_t *, vuint16mf2_t *, vuint16mf2_t *, const uint16_t *, vuint32m1_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vloxseg8ei32_v_m)))
void vloxseg8ei32_v_u16mf2_m(vuint16mf2_t *, vuint16mf2_t *, vuint16mf2_t *, vuint16mf2_t *, vuint16mf2_t *, vuint16mf2_t *, vuint16mf2_t *, vuint16mf2_t *, vbool32_t, vuint16mf2_t, vuint16mf2_t, vuint16mf2_t, vuint16mf2_t, vuint16mf2_t, vuint16mf2_t, vuint16mf2_t, vuint16mf2_t, const uint16_t *, vuint32m1_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vloxseg8ei32_v)))
void vloxseg8ei32_v_u16mf4(vuint16mf4_t *, vuint16mf4_t *, vuint16mf4_t *, vuint16mf4_t *, vuint16mf4_t *, vuint16mf4_t *, vuint16mf4_t *, vuint16mf4_t *, const uint16_t *, vuint32mf2_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vloxseg8ei32_v_m)))
void vloxseg8ei32_v_u16mf4_m(vuint16mf4_t *, vuint16mf4_t *, vuint16mf4_t *, vuint16mf4_t *, vuint16mf4_t *, vuint16mf4_t *, vuint16mf4_t *, vuint16mf4_t *, vbool64_t, vuint16mf4_t, vuint16mf4_t, vuint16mf4_t, vuint16mf4_t, vuint16mf4_t, vuint16mf4_t, vuint16mf4_t, vuint16mf4_t, const uint16_t *, vuint32mf2_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vloxseg2ei8_v)))
void vloxseg2ei8_v_i32m1(vint32m1_t *, vint32m1_t *, const int32_t *, vuint8mf4_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vloxseg2ei8_v_m)))
void vloxseg2ei8_v_i32m1_m(vint32m1_t *, vint32m1_t *, vbool32_t, vint32m1_t, vint32m1_t, const int32_t *, vuint8mf4_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vloxseg2ei8_v)))
void vloxseg2ei8_v_i32m2(vint32m2_t *, vint32m2_t *, const int32_t *, vuint8mf2_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vloxseg2ei8_v_m)))
void vloxseg2ei8_v_i32m2_m(vint32m2_t *, vint32m2_t *, vbool16_t, vint32m2_t, vint32m2_t, const int32_t *, vuint8mf2_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vloxseg2ei8_v)))
void vloxseg2ei8_v_i32m4(vint32m4_t *, vint32m4_t *, const int32_t *, vuint8m1_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vloxseg2ei8_v_m)))
void vloxseg2ei8_v_i32m4_m(vint32m4_t *, vint32m4_t *, vbool8_t, vint32m4_t, vint32m4_t, const int32_t *, vuint8m1_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vloxseg2ei8_v)))
void vloxseg2ei8_v_i32mf2(vint32mf2_t *, vint32mf2_t *, const int32_t *, vuint8mf8_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vloxseg2ei8_v_m)))
void vloxseg2ei8_v_i32mf2_m(vint32mf2_t *, vint32mf2_t *, vbool64_t, vint32mf2_t, vint32mf2_t, const int32_t *, vuint8mf8_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vloxseg2ei8_v)))
void vloxseg2ei8_v_u32m1(vuint32m1_t *, vuint32m1_t *, const uint32_t *, vuint8mf4_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vloxseg2ei8_v_m)))
void vloxseg2ei8_v_u32m1_m(vuint32m1_t *, vuint32m1_t *, vbool32_t, vuint32m1_t, vuint32m1_t, const uint32_t *, vuint8mf4_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vloxseg2ei8_v)))
void vloxseg2ei8_v_u32m2(vuint32m2_t *, vuint32m2_t *, const uint32_t *, vuint8mf2_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vloxseg2ei8_v_m)))
void vloxseg2ei8_v_u32m2_m(vuint32m2_t *, vuint32m2_t *, vbool16_t, vuint32m2_t, vuint32m2_t, const uint32_t *, vuint8mf2_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vloxseg2ei8_v)))
void vloxseg2ei8_v_u32m4(vuint32m4_t *, vuint32m4_t *, const uint32_t *, vuint8m1_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vloxseg2ei8_v_m)))
void vloxseg2ei8_v_u32m4_m(vuint32m4_t *, vuint32m4_t *, vbool8_t, vuint32m4_t, vuint32m4_t, const uint32_t *, vuint8m1_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vloxseg2ei8_v)))
void vloxseg2ei8_v_u32mf2(vuint32mf2_t *, vuint32mf2_t *, const uint32_t *, vuint8mf8_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vloxseg2ei8_v_m)))
void vloxseg2ei8_v_u32mf2_m(vuint32mf2_t *, vuint32mf2_t *, vbool64_t, vuint32mf2_t, vuint32mf2_t, const uint32_t *, vuint8mf8_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vloxseg3ei8_v)))
void vloxseg3ei8_v_i32m1(vint32m1_t *, vint32m1_t *, vint32m1_t *, const int32_t *, vuint8mf4_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vloxseg3ei8_v_m)))
void vloxseg3ei8_v_i32m1_m(vint32m1_t *, vint32m1_t *, vint32m1_t *, vbool32_t, vint32m1_t, vint32m1_t, vint32m1_t, const int32_t *, vuint8mf4_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vloxseg3ei8_v)))
void vloxseg3ei8_v_i32m2(vint32m2_t *, vint32m2_t *, vint32m2_t *, const int32_t *, vuint8mf2_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vloxseg3ei8_v_m)))
void vloxseg3ei8_v_i32m2_m(vint32m2_t *, vint32m2_t *, vint32m2_t *, vbool16_t, vint32m2_t, vint32m2_t, vint32m2_t, const int32_t *, vuint8mf2_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vloxseg3ei8_v)))
void vloxseg3ei8_v_i32mf2(vint32mf2_t *, vint32mf2_t *, vint32mf2_t *, const int32_t *, vuint8mf8_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vloxseg3ei8_v_m)))
void vloxseg3ei8_v_i32mf2_m(vint32mf2_t *, vint32mf2_t *, vint32mf2_t *, vbool64_t, vint32mf2_t, vint32mf2_t, vint32mf2_t, const int32_t *, vuint8mf8_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vloxseg3ei8_v)))
void vloxseg3ei8_v_u32m1(vuint32m1_t *, vuint32m1_t *, vuint32m1_t *, const uint32_t *, vuint8mf4_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vloxseg3ei8_v_m)))
void vloxseg3ei8_v_u32m1_m(vuint32m1_t *, vuint32m1_t *, vuint32m1_t *, vbool32_t, vuint32m1_t, vuint32m1_t, vuint32m1_t, const uint32_t *, vuint8mf4_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vloxseg3ei8_v)))
void vloxseg3ei8_v_u32m2(vuint32m2_t *, vuint32m2_t *, vuint32m2_t *, const uint32_t *, vuint8mf2_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vloxseg3ei8_v_m)))
void vloxseg3ei8_v_u32m2_m(vuint32m2_t *, vuint32m2_t *, vuint32m2_t *, vbool16_t, vuint32m2_t, vuint32m2_t, vuint32m2_t, const uint32_t *, vuint8mf2_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vloxseg3ei8_v)))
void vloxseg3ei8_v_u32mf2(vuint32mf2_t *, vuint32mf2_t *, vuint32mf2_t *, const uint32_t *, vuint8mf8_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vloxseg3ei8_v_m)))
void vloxseg3ei8_v_u32mf2_m(vuint32mf2_t *, vuint32mf2_t *, vuint32mf2_t *, vbool64_t, vuint32mf2_t, vuint32mf2_t, vuint32mf2_t, const uint32_t *, vuint8mf8_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vloxseg4ei8_v)))
void vloxseg4ei8_v_i32m1(vint32m1_t *, vint32m1_t *, vint32m1_t *, vint32m1_t *, const int32_t *, vuint8mf4_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vloxseg4ei8_v_m)))
void vloxseg4ei8_v_i32m1_m(vint32m1_t *, vint32m1_t *, vint32m1_t *, vint32m1_t *, vbool32_t, vint32m1_t, vint32m1_t, vint32m1_t, vint32m1_t, const int32_t *, vuint8mf4_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vloxseg4ei8_v)))
void vloxseg4ei8_v_i32m2(vint32m2_t *, vint32m2_t *, vint32m2_t *, vint32m2_t *, const int32_t *, vuint8mf2_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vloxseg4ei8_v_m)))
void vloxseg4ei8_v_i32m2_m(vint32m2_t *, vint32m2_t *, vint32m2_t *, vint32m2_t *, vbool16_t, vint32m2_t, vint32m2_t, vint32m2_t, vint32m2_t, const int32_t *, vuint8mf2_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vloxseg4ei8_v)))
void vloxseg4ei8_v_i32mf2(vint32mf2_t *, vint32mf2_t *, vint32mf2_t *, vint32mf2_t *, const int32_t *, vuint8mf8_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vloxseg4ei8_v_m)))
void vloxseg4ei8_v_i32mf2_m(vint32mf2_t *, vint32mf2_t *, vint32mf2_t *, vint32mf2_t *, vbool64_t, vint32mf2_t, vint32mf2_t, vint32mf2_t, vint32mf2_t, const int32_t *, vuint8mf8_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vloxseg4ei8_v)))
void vloxseg4ei8_v_u32m1(vuint32m1_t *, vuint32m1_t *, vuint32m1_t *, vuint32m1_t *, const uint32_t *, vuint8mf4_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vloxseg4ei8_v_m)))
void vloxseg4ei8_v_u32m1_m(vuint32m1_t *, vuint32m1_t *, vuint32m1_t *, vuint32m1_t *, vbool32_t, vuint32m1_t, vuint32m1_t, vuint32m1_t, vuint32m1_t, const uint32_t *, vuint8mf4_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vloxseg4ei8_v)))
void vloxseg4ei8_v_u32m2(vuint32m2_t *, vuint32m2_t *, vuint32m2_t *, vuint32m2_t *, const uint32_t *, vuint8mf2_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vloxseg4ei8_v_m)))
void vloxseg4ei8_v_u32m2_m(vuint32m2_t *, vuint32m2_t *, vuint32m2_t *, vuint32m2_t *, vbool16_t, vuint32m2_t, vuint32m2_t, vuint32m2_t, vuint32m2_t, const uint32_t *, vuint8mf2_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vloxseg4ei8_v)))
void vloxseg4ei8_v_u32mf2(vuint32mf2_t *, vuint32mf2_t *, vuint32mf2_t *, vuint32mf2_t *, const uint32_t *, vuint8mf8_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vloxseg4ei8_v_m)))
void vloxseg4ei8_v_u32mf2_m(vuint32mf2_t *, vuint32mf2_t *, vuint32mf2_t *, vuint32mf2_t *, vbool64_t, vuint32mf2_t, vuint32mf2_t, vuint32mf2_t, vuint32mf2_t, const uint32_t *, vuint8mf8_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vloxseg5ei8_v)))
void vloxseg5ei8_v_i32m1(vint32m1_t *, vint32m1_t *, vint32m1_t *, vint32m1_t *, vint32m1_t *, const int32_t *, vuint8mf4_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vloxseg5ei8_v_m)))
void vloxseg5ei8_v_i32m1_m(vint32m1_t *, vint32m1_t *, vint32m1_t *, vint32m1_t *, vint32m1_t *, vbool32_t, vint32m1_t, vint32m1_t, vint32m1_t, vint32m1_t, vint32m1_t, const int32_t *, vuint8mf4_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vloxseg5ei8_v)))
void vloxseg5ei8_v_i32mf2(vint32mf2_t *, vint32mf2_t *, vint32mf2_t *, vint32mf2_t *, vint32mf2_t *, const int32_t *, vuint8mf8_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vloxseg5ei8_v_m)))
void vloxseg5ei8_v_i32mf2_m(vint32mf2_t *, vint32mf2_t *, vint32mf2_t *, vint32mf2_t *, vint32mf2_t *, vbool64_t, vint32mf2_t, vint32mf2_t, vint32mf2_t, vint32mf2_t, vint32mf2_t, const int32_t *, vuint8mf8_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vloxseg5ei8_v)))
void vloxseg5ei8_v_u32m1(vuint32m1_t *, vuint32m1_t *, vuint32m1_t *, vuint32m1_t *, vuint32m1_t *, const uint32_t *, vuint8mf4_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vloxseg5ei8_v_m)))
void vloxseg5ei8_v_u32m1_m(vuint32m1_t *, vuint32m1_t *, vuint32m1_t *, vuint32m1_t *, vuint32m1_t *, vbool32_t, vuint32m1_t, vuint32m1_t, vuint32m1_t, vuint32m1_t, vuint32m1_t, const uint32_t *, vuint8mf4_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vloxseg5ei8_v)))
void vloxseg5ei8_v_u32mf2(vuint32mf2_t *, vuint32mf2_t *, vuint32mf2_t *, vuint32mf2_t *, vuint32mf2_t *, const uint32_t *, vuint8mf8_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vloxseg5ei8_v_m)))
void vloxseg5ei8_v_u32mf2_m(vuint32mf2_t *, vuint32mf2_t *, vuint32mf2_t *, vuint32mf2_t *, vuint32mf2_t *, vbool64_t, vuint32mf2_t, vuint32mf2_t, vuint32mf2_t, vuint32mf2_t, vuint32mf2_t, const uint32_t *, vuint8mf8_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vlse16_v)))
vint16m1_t vlse16_v_i16m1(const int16_t *, ptrdiff_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vlse16_v_m)))
vint16m1_t vlse16_v_i16m1_m(vbool16_t, vint16m1_t, const int16_t *, ptrdiff_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vlse16_v)))
vint16m2_t vlse16_v_i16m2(const int16_t *, ptrdiff_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vlse16_v_m)))
vint16m2_t vlse16_v_i16m2_m(vbool8_t, vint16m2_t, const int16_t *, ptrdiff_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vlse16_v)))
vint16m4_t vlse16_v_i16m4(const int16_t *, ptrdiff_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vlse16_v_m)))
vint16m4_t vlse16_v_i16m4_m(vbool4_t, vint16m4_t, const int16_t *, ptrdiff_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vlse16_v)))
vint16m8_t vlse16_v_i16m8(const int16_t *, ptrdiff_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vlse16_v_m)))
vint16m8_t vlse16_v_i16m8_m(vbool2_t, vint16m8_t, const int16_t *, ptrdiff_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vlse16_v)))
vint16mf2_t vlse16_v_i16mf2(const int16_t *, ptrdiff_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vlse16_v_m)))
vint16mf2_t vlse16_v_i16mf2_m(vbool32_t, vint16mf2_t, const int16_t *, ptrdiff_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vlse16_v)))
vint16mf4_t vlse16_v_i16mf4(const int16_t *, ptrdiff_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vlse16_v_m)))
vint16mf4_t vlse16_v_i16mf4_m(vbool64_t, vint16mf4_t, const int16_t *, ptrdiff_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vloxseg6ei8_v)))
void vloxseg6ei8_v_i32m1(vint32m1_t *, vint32m1_t *, vint32m1_t *, vint32m1_t *, vint32m1_t *, vint32m1_t *, const int32_t *, vuint8mf4_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vloxseg6ei8_v_m)))
void vloxseg6ei8_v_i32m1_m(vint32m1_t *, vint32m1_t *, vint32m1_t *, vint32m1_t *, vint32m1_t *, vint32m1_t *, vbool32_t, vint32m1_t, vint32m1_t, vint32m1_t, vint32m1_t, vint32m1_t, vint32m1_t, const int32_t *, vuint8mf4_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vloxseg6ei8_v)))
void vloxseg6ei8_v_i32mf2(vint32mf2_t *, vint32mf2_t *, vint32mf2_t *, vint32mf2_t *, vint32mf2_t *, vint32mf2_t *, const int32_t *, vuint8mf8_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vloxseg6ei8_v_m)))
void vloxseg6ei8_v_i32mf2_m(vint32mf2_t *, vint32mf2_t *, vint32mf2_t *, vint32mf2_t *, vint32mf2_t *, vint32mf2_t *, vbool64_t, vint32mf2_t, vint32mf2_t, vint32mf2_t, vint32mf2_t, vint32mf2_t, vint32mf2_t, const int32_t *, vuint8mf8_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vloxseg6ei8_v)))
void vloxseg6ei8_v_u32m1(vuint32m1_t *, vuint32m1_t *, vuint32m1_t *, vuint32m1_t *, vuint32m1_t *, vuint32m1_t *, const uint32_t *, vuint8mf4_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vloxseg6ei8_v_m)))
void vloxseg6ei8_v_u32m1_m(vuint32m1_t *, vuint32m1_t *, vuint32m1_t *, vuint32m1_t *, vuint32m1_t *, vuint32m1_t *, vbool32_t, vuint32m1_t, vuint32m1_t, vuint32m1_t, vuint32m1_t, vuint32m1_t, vuint32m1_t, const uint32_t *, vuint8mf4_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vloxseg6ei8_v)))
void vloxseg6ei8_v_u32mf2(vuint32mf2_t *, vuint32mf2_t *, vuint32mf2_t *, vuint32mf2_t *, vuint32mf2_t *, vuint32mf2_t *, const uint32_t *, vuint8mf8_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vloxseg6ei8_v_m)))
void vloxseg6ei8_v_u32mf2_m(vuint32mf2_t *, vuint32mf2_t *, vuint32mf2_t *, vuint32mf2_t *, vuint32mf2_t *, vuint32mf2_t *, vbool64_t, vuint32mf2_t, vuint32mf2_t, vuint32mf2_t, vuint32mf2_t, vuint32mf2_t, vuint32mf2_t, const uint32_t *, vuint8mf8_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vloxseg7ei8_v)))
void vloxseg7ei8_v_i32m1(vint32m1_t *, vint32m1_t *, vint32m1_t *, vint32m1_t *, vint32m1_t *, vint32m1_t *, vint32m1_t *, const int32_t *, vuint8mf4_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vloxseg7ei8_v_m)))
void vloxseg7ei8_v_i32m1_m(vint32m1_t *, vint32m1_t *, vint32m1_t *, vint32m1_t *, vint32m1_t *, vint32m1_t *, vint32m1_t *, vbool32_t, vint32m1_t, vint32m1_t, vint32m1_t, vint32m1_t, vint32m1_t, vint32m1_t, vint32m1_t, const int32_t *, vuint8mf4_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vloxseg7ei8_v)))
void vloxseg7ei8_v_i32mf2(vint32mf2_t *, vint32mf2_t *, vint32mf2_t *, vint32mf2_t *, vint32mf2_t *, vint32mf2_t *, vint32mf2_t *, const int32_t *, vuint8mf8_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vloxseg7ei8_v_m)))
void vloxseg7ei8_v_i32mf2_m(vint32mf2_t *, vint32mf2_t *, vint32mf2_t *, vint32mf2_t *, vint32mf2_t *, vint32mf2_t *, vint32mf2_t *, vbool64_t, vint32mf2_t, vint32mf2_t, vint32mf2_t, vint32mf2_t, vint32mf2_t, vint32mf2_t, vint32mf2_t, const int32_t *, vuint8mf8_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vloxseg7ei8_v)))
void vloxseg7ei8_v_u32m1(vuint32m1_t *, vuint32m1_t *, vuint32m1_t *, vuint32m1_t *, vuint32m1_t *, vuint32m1_t *, vuint32m1_t *, const uint32_t *, vuint8mf4_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vloxseg7ei8_v_m)))
void vloxseg7ei8_v_u32m1_m(vuint32m1_t *, vuint32m1_t *, vuint32m1_t *, vuint32m1_t *, vuint32m1_t *, vuint32m1_t *, vuint32m1_t *, vbool32_t, vuint32m1_t, vuint32m1_t, vuint32m1_t, vuint32m1_t, vuint32m1_t, vuint32m1_t, vuint32m1_t, const uint32_t *, vuint8mf4_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vloxseg7ei8_v)))
void vloxseg7ei8_v_u32mf2(vuint32mf2_t *, vuint32mf2_t *, vuint32mf2_t *, vuint32mf2_t *, vuint32mf2_t *, vuint32mf2_t *, vuint32mf2_t *, const uint32_t *, vuint8mf8_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vloxseg7ei8_v_m)))
void vloxseg7ei8_v_u32mf2_m(vuint32mf2_t *, vuint32mf2_t *, vuint32mf2_t *, vuint32mf2_t *, vuint32mf2_t *, vuint32mf2_t *, vuint32mf2_t *, vbool64_t, vuint32mf2_t, vuint32mf2_t, vuint32mf2_t, vuint32mf2_t, vuint32mf2_t, vuint32mf2_t, vuint32mf2_t, const uint32_t *, vuint8mf8_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vloxseg8ei8_v)))
void vloxseg8ei8_v_i32m1(vint32m1_t *, vint32m1_t *, vint32m1_t *, vint32m1_t *, vint32m1_t *, vint32m1_t *, vint32m1_t *, vint32m1_t *, const int32_t *, vuint8mf4_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vloxseg8ei8_v_m)))
void vloxseg8ei8_v_i32m1_m(vint32m1_t *, vint32m1_t *, vint32m1_t *, vint32m1_t *, vint32m1_t *, vint32m1_t *, vint32m1_t *, vint32m1_t *, vbool32_t, vint32m1_t, vint32m1_t, vint32m1_t, vint32m1_t, vint32m1_t, vint32m1_t, vint32m1_t, vint32m1_t, const int32_t *, vuint8mf4_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vloxseg8ei8_v)))
void vloxseg8ei8_v_i32mf2(vint32mf2_t *, vint32mf2_t *, vint32mf2_t *, vint32mf2_t *, vint32mf2_t *, vint32mf2_t *, vint32mf2_t *, vint32mf2_t *, const int32_t *, vuint8mf8_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vloxseg8ei8_v_m)))
void vloxseg8ei8_v_i32mf2_m(vint32mf2_t *, vint32mf2_t *, vint32mf2_t *, vint32mf2_t *, vint32mf2_t *, vint32mf2_t *, vint32mf2_t *, vint32mf2_t *, vbool64_t, vint32mf2_t, vint32mf2_t, vint32mf2_t, vint32mf2_t, vint32mf2_t, vint32mf2_t, vint32mf2_t, vint32mf2_t, const int32_t *, vuint8mf8_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vloxseg8ei8_v)))
void vloxseg8ei8_v_u32m1(vuint32m1_t *, vuint32m1_t *, vuint32m1_t *, vuint32m1_t *, vuint32m1_t *, vuint32m1_t *, vuint32m1_t *, vuint32m1_t *, const uint32_t *, vuint8mf4_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vloxseg8ei8_v_m)))
void vloxseg8ei8_v_u32m1_m(vuint32m1_t *, vuint32m1_t *, vuint32m1_t *, vuint32m1_t *, vuint32m1_t *, vuint32m1_t *, vuint32m1_t *, vuint32m1_t *, vbool32_t, vuint32m1_t, vuint32m1_t, vuint32m1_t, vuint32m1_t, vuint32m1_t, vuint32m1_t, vuint32m1_t, vuint32m1_t, const uint32_t *, vuint8mf4_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vloxseg8ei8_v)))
void vloxseg8ei8_v_u32mf2(vuint32mf2_t *, vuint32mf2_t *, vuint32mf2_t *, vuint32mf2_t *, vuint32mf2_t *, vuint32mf2_t *, vuint32mf2_t *, vuint32mf2_t *, const uint32_t *, vuint8mf8_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vloxseg8ei8_v_m)))
void vloxseg8ei8_v_u32mf2_m(vuint32mf2_t *, vuint32mf2_t *, vuint32mf2_t *, vuint32mf2_t *, vuint32mf2_t *, vuint32mf2_t *, vuint32mf2_t *, vuint32mf2_t *, vbool64_t, vuint32mf2_t, vuint32mf2_t, vuint32mf2_t, vuint32mf2_t, vuint32mf2_t, vuint32mf2_t, vuint32mf2_t, vuint32mf2_t, const uint32_t *, vuint8mf8_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vloxseg2ei16_v)))
void vloxseg2ei16_v_i32m1(vint32m1_t *, vint32m1_t *, const int32_t *, vuint16mf2_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vloxseg2ei16_v_m)))
void vloxseg2ei16_v_i32m1_m(vint32m1_t *, vint32m1_t *, vbool32_t, vint32m1_t, vint32m1_t, const int32_t *, vuint16mf2_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vloxseg2ei16_v)))
void vloxseg2ei16_v_i32m2(vint32m2_t *, vint32m2_t *, const int32_t *, vuint16m1_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vloxseg2ei16_v_m)))
void vloxseg2ei16_v_i32m2_m(vint32m2_t *, vint32m2_t *, vbool16_t, vint32m2_t, vint32m2_t, const int32_t *, vuint16m1_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vloxseg2ei16_v)))
void vloxseg2ei16_v_i32m4(vint32m4_t *, vint32m4_t *, const int32_t *, vuint16m2_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vloxseg2ei16_v_m)))
void vloxseg2ei16_v_i32m4_m(vint32m4_t *, vint32m4_t *, vbool8_t, vint32m4_t, vint32m4_t, const int32_t *, vuint16m2_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vloxseg2ei16_v)))
void vloxseg2ei16_v_i32mf2(vint32mf2_t *, vint32mf2_t *, const int32_t *, vuint16mf4_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vloxseg2ei16_v_m)))
void vloxseg2ei16_v_i32mf2_m(vint32mf2_t *, vint32mf2_t *, vbool64_t, vint32mf2_t, vint32mf2_t, const int32_t *, vuint16mf4_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vloxseg2ei16_v)))
void vloxseg2ei16_v_u32m1(vuint32m1_t *, vuint32m1_t *, const uint32_t *, vuint16mf2_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vloxseg2ei16_v_m)))
void vloxseg2ei16_v_u32m1_m(vuint32m1_t *, vuint32m1_t *, vbool32_t, vuint32m1_t, vuint32m1_t, const uint32_t *, vuint16mf2_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vloxseg2ei16_v)))
void vloxseg2ei16_v_u32m2(vuint32m2_t *, vuint32m2_t *, const uint32_t *, vuint16m1_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vloxseg2ei16_v_m)))
void vloxseg2ei16_v_u32m2_m(vuint32m2_t *, vuint32m2_t *, vbool16_t, vuint32m2_t, vuint32m2_t, const uint32_t *, vuint16m1_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vloxseg2ei16_v)))
void vloxseg2ei16_v_u32m4(vuint32m4_t *, vuint32m4_t *, const uint32_t *, vuint16m2_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vloxseg2ei16_v_m)))
void vloxseg2ei16_v_u32m4_m(vuint32m4_t *, vuint32m4_t *, vbool8_t, vuint32m4_t, vuint32m4_t, const uint32_t *, vuint16m2_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vloxseg2ei16_v)))
void vloxseg2ei16_v_u32mf2(vuint32mf2_t *, vuint32mf2_t *, const uint32_t *, vuint16mf4_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vloxseg2ei16_v_m)))
void vloxseg2ei16_v_u32mf2_m(vuint32mf2_t *, vuint32mf2_t *, vbool64_t, vuint32mf2_t, vuint32mf2_t, const uint32_t *, vuint16mf4_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vloxseg3ei16_v)))
void vloxseg3ei16_v_i32m1(vint32m1_t *, vint32m1_t *, vint32m1_t *, const int32_t *, vuint16mf2_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vloxseg3ei16_v_m)))
void vloxseg3ei16_v_i32m1_m(vint32m1_t *, vint32m1_t *, vint32m1_t *, vbool32_t, vint32m1_t, vint32m1_t, vint32m1_t, const int32_t *, vuint16mf2_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vloxseg3ei16_v)))
void vloxseg3ei16_v_i32m2(vint32m2_t *, vint32m2_t *, vint32m2_t *, const int32_t *, vuint16m1_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vloxseg3ei16_v_m)))
void vloxseg3ei16_v_i32m2_m(vint32m2_t *, vint32m2_t *, vint32m2_t *, vbool16_t, vint32m2_t, vint32m2_t, vint32m2_t, const int32_t *, vuint16m1_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vloxseg3ei16_v)))
void vloxseg3ei16_v_i32mf2(vint32mf2_t *, vint32mf2_t *, vint32mf2_t *, const int32_t *, vuint16mf4_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vloxseg3ei16_v_m)))
void vloxseg3ei16_v_i32mf2_m(vint32mf2_t *, vint32mf2_t *, vint32mf2_t *, vbool64_t, vint32mf2_t, vint32mf2_t, vint32mf2_t, const int32_t *, vuint16mf4_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vloxseg3ei16_v)))
void vloxseg3ei16_v_u32m1(vuint32m1_t *, vuint32m1_t *, vuint32m1_t *, const uint32_t *, vuint16mf2_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vloxseg3ei16_v_m)))
void vloxseg3ei16_v_u32m1_m(vuint32m1_t *, vuint32m1_t *, vuint32m1_t *, vbool32_t, vuint32m1_t, vuint32m1_t, vuint32m1_t, const uint32_t *, vuint16mf2_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vloxseg3ei16_v)))
void vloxseg3ei16_v_u32m2(vuint32m2_t *, vuint32m2_t *, vuint32m2_t *, const uint32_t *, vuint16m1_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vloxseg3ei16_v_m)))
void vloxseg3ei16_v_u32m2_m(vuint32m2_t *, vuint32m2_t *, vuint32m2_t *, vbool16_t, vuint32m2_t, vuint32m2_t, vuint32m2_t, const uint32_t *, vuint16m1_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vloxseg3ei16_v)))
void vloxseg3ei16_v_u32mf2(vuint32mf2_t *, vuint32mf2_t *, vuint32mf2_t *, const uint32_t *, vuint16mf4_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vloxseg3ei16_v_m)))
void vloxseg3ei16_v_u32mf2_m(vuint32mf2_t *, vuint32mf2_t *, vuint32mf2_t *, vbool64_t, vuint32mf2_t, vuint32mf2_t, vuint32mf2_t, const uint32_t *, vuint16mf4_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vlse16_v)))
vuint16m1_t vlse16_v_u16m1(const uint16_t *, ptrdiff_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vlse16_v_m)))
vuint16m1_t vlse16_v_u16m1_m(vbool16_t, vuint16m1_t, const uint16_t *, ptrdiff_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vlse16_v)))
vuint16m2_t vlse16_v_u16m2(const uint16_t *, ptrdiff_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vlse16_v_m)))
vuint16m2_t vlse16_v_u16m2_m(vbool8_t, vuint16m2_t, const uint16_t *, ptrdiff_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vlse16_v)))
vuint16m4_t vlse16_v_u16m4(const uint16_t *, ptrdiff_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vlse16_v_m)))
vuint16m4_t vlse16_v_u16m4_m(vbool4_t, vuint16m4_t, const uint16_t *, ptrdiff_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vlse16_v)))
vuint16m8_t vlse16_v_u16m8(const uint16_t *, ptrdiff_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vlse16_v_m)))
vuint16m8_t vlse16_v_u16m8_m(vbool2_t, vuint16m8_t, const uint16_t *, ptrdiff_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vlse16_v)))
vuint16mf2_t vlse16_v_u16mf2(const uint16_t *, ptrdiff_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vlse16_v_m)))
vuint16mf2_t vlse16_v_u16mf2_m(vbool32_t, vuint16mf2_t, const uint16_t *, ptrdiff_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vlse16_v)))
vuint16mf4_t vlse16_v_u16mf4(const uint16_t *, ptrdiff_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vlse16_v_m)))
vuint16mf4_t vlse16_v_u16mf4_m(vbool64_t, vuint16mf4_t, const uint16_t *, ptrdiff_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vloxseg4ei16_v)))
void vloxseg4ei16_v_i32m1(vint32m1_t *, vint32m1_t *, vint32m1_t *, vint32m1_t *, const int32_t *, vuint16mf2_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vloxseg4ei16_v_m)))
void vloxseg4ei16_v_i32m1_m(vint32m1_t *, vint32m1_t *, vint32m1_t *, vint32m1_t *, vbool32_t, vint32m1_t, vint32m1_t, vint32m1_t, vint32m1_t, const int32_t *, vuint16mf2_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vloxseg4ei16_v)))
void vloxseg4ei16_v_i32m2(vint32m2_t *, vint32m2_t *, vint32m2_t *, vint32m2_t *, const int32_t *, vuint16m1_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vloxseg4ei16_v_m)))
void vloxseg4ei16_v_i32m2_m(vint32m2_t *, vint32m2_t *, vint32m2_t *, vint32m2_t *, vbool16_t, vint32m2_t, vint32m2_t, vint32m2_t, vint32m2_t, const int32_t *, vuint16m1_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vloxseg4ei16_v)))
void vloxseg4ei16_v_i32mf2(vint32mf2_t *, vint32mf2_t *, vint32mf2_t *, vint32mf2_t *, const int32_t *, vuint16mf4_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vloxseg4ei16_v_m)))
void vloxseg4ei16_v_i32mf2_m(vint32mf2_t *, vint32mf2_t *, vint32mf2_t *, vint32mf2_t *, vbool64_t, vint32mf2_t, vint32mf2_t, vint32mf2_t, vint32mf2_t, const int32_t *, vuint16mf4_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vloxseg4ei16_v)))
void vloxseg4ei16_v_u32m1(vuint32m1_t *, vuint32m1_t *, vuint32m1_t *, vuint32m1_t *, const uint32_t *, vuint16mf2_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vloxseg4ei16_v_m)))
void vloxseg4ei16_v_u32m1_m(vuint32m1_t *, vuint32m1_t *, vuint32m1_t *, vuint32m1_t *, vbool32_t, vuint32m1_t, vuint32m1_t, vuint32m1_t, vuint32m1_t, const uint32_t *, vuint16mf2_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vloxseg4ei16_v)))
void vloxseg4ei16_v_u32m2(vuint32m2_t *, vuint32m2_t *, vuint32m2_t *, vuint32m2_t *, const uint32_t *, vuint16m1_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vloxseg4ei16_v_m)))
void vloxseg4ei16_v_u32m2_m(vuint32m2_t *, vuint32m2_t *, vuint32m2_t *, vuint32m2_t *, vbool16_t, vuint32m2_t, vuint32m2_t, vuint32m2_t, vuint32m2_t, const uint32_t *, vuint16m1_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vloxseg4ei16_v)))
void vloxseg4ei16_v_u32mf2(vuint32mf2_t *, vuint32mf2_t *, vuint32mf2_t *, vuint32mf2_t *, const uint32_t *, vuint16mf4_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vloxseg4ei16_v_m)))
void vloxseg4ei16_v_u32mf2_m(vuint32mf2_t *, vuint32mf2_t *, vuint32mf2_t *, vuint32mf2_t *, vbool64_t, vuint32mf2_t, vuint32mf2_t, vuint32mf2_t, vuint32mf2_t, const uint32_t *, vuint16mf4_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vloxseg5ei16_v)))
void vloxseg5ei16_v_i32m1(vint32m1_t *, vint32m1_t *, vint32m1_t *, vint32m1_t *, vint32m1_t *, const int32_t *, vuint16mf2_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vloxseg5ei16_v_m)))
void vloxseg5ei16_v_i32m1_m(vint32m1_t *, vint32m1_t *, vint32m1_t *, vint32m1_t *, vint32m1_t *, vbool32_t, vint32m1_t, vint32m1_t, vint32m1_t, vint32m1_t, vint32m1_t, const int32_t *, vuint16mf2_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vloxseg5ei16_v)))
void vloxseg5ei16_v_i32mf2(vint32mf2_t *, vint32mf2_t *, vint32mf2_t *, vint32mf2_t *, vint32mf2_t *, const int32_t *, vuint16mf4_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vloxseg5ei16_v_m)))
void vloxseg5ei16_v_i32mf2_m(vint32mf2_t *, vint32mf2_t *, vint32mf2_t *, vint32mf2_t *, vint32mf2_t *, vbool64_t, vint32mf2_t, vint32mf2_t, vint32mf2_t, vint32mf2_t, vint32mf2_t, const int32_t *, vuint16mf4_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vloxseg5ei16_v)))
void vloxseg5ei16_v_u32m1(vuint32m1_t *, vuint32m1_t *, vuint32m1_t *, vuint32m1_t *, vuint32m1_t *, const uint32_t *, vuint16mf2_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vloxseg5ei16_v_m)))
void vloxseg5ei16_v_u32m1_m(vuint32m1_t *, vuint32m1_t *, vuint32m1_t *, vuint32m1_t *, vuint32m1_t *, vbool32_t, vuint32m1_t, vuint32m1_t, vuint32m1_t, vuint32m1_t, vuint32m1_t, const uint32_t *, vuint16mf2_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vloxseg5ei16_v)))
void vloxseg5ei16_v_u32mf2(vuint32mf2_t *, vuint32mf2_t *, vuint32mf2_t *, vuint32mf2_t *, vuint32mf2_t *, const uint32_t *, vuint16mf4_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vloxseg5ei16_v_m)))
void vloxseg5ei16_v_u32mf2_m(vuint32mf2_t *, vuint32mf2_t *, vuint32mf2_t *, vuint32mf2_t *, vuint32mf2_t *, vbool64_t, vuint32mf2_t, vuint32mf2_t, vuint32mf2_t, vuint32mf2_t, vuint32mf2_t, const uint32_t *, vuint16mf4_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vloxseg6ei16_v)))
void vloxseg6ei16_v_i32m1(vint32m1_t *, vint32m1_t *, vint32m1_t *, vint32m1_t *, vint32m1_t *, vint32m1_t *, const int32_t *, vuint16mf2_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vloxseg6ei16_v_m)))
void vloxseg6ei16_v_i32m1_m(vint32m1_t *, vint32m1_t *, vint32m1_t *, vint32m1_t *, vint32m1_t *, vint32m1_t *, vbool32_t, vint32m1_t, vint32m1_t, vint32m1_t, vint32m1_t, vint32m1_t, vint32m1_t, const int32_t *, vuint16mf2_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vloxseg6ei16_v)))
void vloxseg6ei16_v_i32mf2(vint32mf2_t *, vint32mf2_t *, vint32mf2_t *, vint32mf2_t *, vint32mf2_t *, vint32mf2_t *, const int32_t *, vuint16mf4_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vloxseg6ei16_v_m)))
void vloxseg6ei16_v_i32mf2_m(vint32mf2_t *, vint32mf2_t *, vint32mf2_t *, vint32mf2_t *, vint32mf2_t *, vint32mf2_t *, vbool64_t, vint32mf2_t, vint32mf2_t, vint32mf2_t, vint32mf2_t, vint32mf2_t, vint32mf2_t, const int32_t *, vuint16mf4_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vloxseg6ei16_v)))
void vloxseg6ei16_v_u32m1(vuint32m1_t *, vuint32m1_t *, vuint32m1_t *, vuint32m1_t *, vuint32m1_t *, vuint32m1_t *, const uint32_t *, vuint16mf2_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vloxseg6ei16_v_m)))
void vloxseg6ei16_v_u32m1_m(vuint32m1_t *, vuint32m1_t *, vuint32m1_t *, vuint32m1_t *, vuint32m1_t *, vuint32m1_t *, vbool32_t, vuint32m1_t, vuint32m1_t, vuint32m1_t, vuint32m1_t, vuint32m1_t, vuint32m1_t, const uint32_t *, vuint16mf2_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vloxseg6ei16_v)))
void vloxseg6ei16_v_u32mf2(vuint32mf2_t *, vuint32mf2_t *, vuint32mf2_t *, vuint32mf2_t *, vuint32mf2_t *, vuint32mf2_t *, const uint32_t *, vuint16mf4_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vloxseg6ei16_v_m)))
void vloxseg6ei16_v_u32mf2_m(vuint32mf2_t *, vuint32mf2_t *, vuint32mf2_t *, vuint32mf2_t *, vuint32mf2_t *, vuint32mf2_t *, vbool64_t, vuint32mf2_t, vuint32mf2_t, vuint32mf2_t, vuint32mf2_t, vuint32mf2_t, vuint32mf2_t, const uint32_t *, vuint16mf4_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vloxseg7ei16_v)))
void vloxseg7ei16_v_i32m1(vint32m1_t *, vint32m1_t *, vint32m1_t *, vint32m1_t *, vint32m1_t *, vint32m1_t *, vint32m1_t *, const int32_t *, vuint16mf2_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vloxseg7ei16_v_m)))
void vloxseg7ei16_v_i32m1_m(vint32m1_t *, vint32m1_t *, vint32m1_t *, vint32m1_t *, vint32m1_t *, vint32m1_t *, vint32m1_t *, vbool32_t, vint32m1_t, vint32m1_t, vint32m1_t, vint32m1_t, vint32m1_t, vint32m1_t, vint32m1_t, const int32_t *, vuint16mf2_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vloxseg7ei16_v)))
void vloxseg7ei16_v_i32mf2(vint32mf2_t *, vint32mf2_t *, vint32mf2_t *, vint32mf2_t *, vint32mf2_t *, vint32mf2_t *, vint32mf2_t *, const int32_t *, vuint16mf4_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vloxseg7ei16_v_m)))
void vloxseg7ei16_v_i32mf2_m(vint32mf2_t *, vint32mf2_t *, vint32mf2_t *, vint32mf2_t *, vint32mf2_t *, vint32mf2_t *, vint32mf2_t *, vbool64_t, vint32mf2_t, vint32mf2_t, vint32mf2_t, vint32mf2_t, vint32mf2_t, vint32mf2_t, vint32mf2_t, const int32_t *, vuint16mf4_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vloxseg7ei16_v)))
void vloxseg7ei16_v_u32m1(vuint32m1_t *, vuint32m1_t *, vuint32m1_t *, vuint32m1_t *, vuint32m1_t *, vuint32m1_t *, vuint32m1_t *, const uint32_t *, vuint16mf2_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vloxseg7ei16_v_m)))
void vloxseg7ei16_v_u32m1_m(vuint32m1_t *, vuint32m1_t *, vuint32m1_t *, vuint32m1_t *, vuint32m1_t *, vuint32m1_t *, vuint32m1_t *, vbool32_t, vuint32m1_t, vuint32m1_t, vuint32m1_t, vuint32m1_t, vuint32m1_t, vuint32m1_t, vuint32m1_t, const uint32_t *, vuint16mf2_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vloxseg7ei16_v)))
void vloxseg7ei16_v_u32mf2(vuint32mf2_t *, vuint32mf2_t *, vuint32mf2_t *, vuint32mf2_t *, vuint32mf2_t *, vuint32mf2_t *, vuint32mf2_t *, const uint32_t *, vuint16mf4_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vloxseg7ei16_v_m)))
void vloxseg7ei16_v_u32mf2_m(vuint32mf2_t *, vuint32mf2_t *, vuint32mf2_t *, vuint32mf2_t *, vuint32mf2_t *, vuint32mf2_t *, vuint32mf2_t *, vbool64_t, vuint32mf2_t, vuint32mf2_t, vuint32mf2_t, vuint32mf2_t, vuint32mf2_t, vuint32mf2_t, vuint32mf2_t, const uint32_t *, vuint16mf4_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vloxseg8ei16_v)))
void vloxseg8ei16_v_i32m1(vint32m1_t *, vint32m1_t *, vint32m1_t *, vint32m1_t *, vint32m1_t *, vint32m1_t *, vint32m1_t *, vint32m1_t *, const int32_t *, vuint16mf2_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vloxseg8ei16_v_m)))
void vloxseg8ei16_v_i32m1_m(vint32m1_t *, vint32m1_t *, vint32m1_t *, vint32m1_t *, vint32m1_t *, vint32m1_t *, vint32m1_t *, vint32m1_t *, vbool32_t, vint32m1_t, vint32m1_t, vint32m1_t, vint32m1_t, vint32m1_t, vint32m1_t, vint32m1_t, vint32m1_t, const int32_t *, vuint16mf2_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vloxseg8ei16_v)))
void vloxseg8ei16_v_i32mf2(vint32mf2_t *, vint32mf2_t *, vint32mf2_t *, vint32mf2_t *, vint32mf2_t *, vint32mf2_t *, vint32mf2_t *, vint32mf2_t *, const int32_t *, vuint16mf4_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vloxseg8ei16_v_m)))
void vloxseg8ei16_v_i32mf2_m(vint32mf2_t *, vint32mf2_t *, vint32mf2_t *, vint32mf2_t *, vint32mf2_t *, vint32mf2_t *, vint32mf2_t *, vint32mf2_t *, vbool64_t, vint32mf2_t, vint32mf2_t, vint32mf2_t, vint32mf2_t, vint32mf2_t, vint32mf2_t, vint32mf2_t, vint32mf2_t, const int32_t *, vuint16mf4_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vloxseg8ei16_v)))
void vloxseg8ei16_v_u32m1(vuint32m1_t *, vuint32m1_t *, vuint32m1_t *, vuint32m1_t *, vuint32m1_t *, vuint32m1_t *, vuint32m1_t *, vuint32m1_t *, const uint32_t *, vuint16mf2_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vloxseg8ei16_v_m)))
void vloxseg8ei16_v_u32m1_m(vuint32m1_t *, vuint32m1_t *, vuint32m1_t *, vuint32m1_t *, vuint32m1_t *, vuint32m1_t *, vuint32m1_t *, vuint32m1_t *, vbool32_t, vuint32m1_t, vuint32m1_t, vuint32m1_t, vuint32m1_t, vuint32m1_t, vuint32m1_t, vuint32m1_t, vuint32m1_t, const uint32_t *, vuint16mf2_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vloxseg8ei16_v)))
void vloxseg8ei16_v_u32mf2(vuint32mf2_t *, vuint32mf2_t *, vuint32mf2_t *, vuint32mf2_t *, vuint32mf2_t *, vuint32mf2_t *, vuint32mf2_t *, vuint32mf2_t *, const uint32_t *, vuint16mf4_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vloxseg8ei16_v_m)))
void vloxseg8ei16_v_u32mf2_m(vuint32mf2_t *, vuint32mf2_t *, vuint32mf2_t *, vuint32mf2_t *, vuint32mf2_t *, vuint32mf2_t *, vuint32mf2_t *, vuint32mf2_t *, vbool64_t, vuint32mf2_t, vuint32mf2_t, vuint32mf2_t, vuint32mf2_t, vuint32mf2_t, vuint32mf2_t, vuint32mf2_t, vuint32mf2_t, const uint32_t *, vuint16mf4_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vloxseg2ei32_v)))
void vloxseg2ei32_v_i32m1(vint32m1_t *, vint32m1_t *, const int32_t *, vuint32m1_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vloxseg2ei32_v_m)))
void vloxseg2ei32_v_i32m1_m(vint32m1_t *, vint32m1_t *, vbool32_t, vint32m1_t, vint32m1_t, const int32_t *, vuint32m1_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vloxseg2ei32_v)))
void vloxseg2ei32_v_i32m2(vint32m2_t *, vint32m2_t *, const int32_t *, vuint32m2_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vloxseg2ei32_v_m)))
void vloxseg2ei32_v_i32m2_m(vint32m2_t *, vint32m2_t *, vbool16_t, vint32m2_t, vint32m2_t, const int32_t *, vuint32m2_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vloxseg2ei32_v)))
void vloxseg2ei32_v_i32m4(vint32m4_t *, vint32m4_t *, const int32_t *, vuint32m4_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vloxseg2ei32_v_m)))
void vloxseg2ei32_v_i32m4_m(vint32m4_t *, vint32m4_t *, vbool8_t, vint32m4_t, vint32m4_t, const int32_t *, vuint32m4_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vloxseg2ei32_v)))
void vloxseg2ei32_v_i32mf2(vint32mf2_t *, vint32mf2_t *, const int32_t *, vuint32mf2_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vloxseg2ei32_v_m)))
void vloxseg2ei32_v_i32mf2_m(vint32mf2_t *, vint32mf2_t *, vbool64_t, vint32mf2_t, vint32mf2_t, const int32_t *, vuint32mf2_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vloxseg2ei32_v)))
void vloxseg2ei32_v_u32m1(vuint32m1_t *, vuint32m1_t *, const uint32_t *, vuint32m1_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vloxseg2ei32_v_m)))
void vloxseg2ei32_v_u32m1_m(vuint32m1_t *, vuint32m1_t *, vbool32_t, vuint32m1_t, vuint32m1_t, const uint32_t *, vuint32m1_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vloxseg2ei32_v)))
void vloxseg2ei32_v_u32m2(vuint32m2_t *, vuint32m2_t *, const uint32_t *, vuint32m2_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vloxseg2ei32_v_m)))
void vloxseg2ei32_v_u32m2_m(vuint32m2_t *, vuint32m2_t *, vbool16_t, vuint32m2_t, vuint32m2_t, const uint32_t *, vuint32m2_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vloxseg2ei32_v)))
void vloxseg2ei32_v_u32m4(vuint32m4_t *, vuint32m4_t *, const uint32_t *, vuint32m4_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vloxseg2ei32_v_m)))
void vloxseg2ei32_v_u32m4_m(vuint32m4_t *, vuint32m4_t *, vbool8_t, vuint32m4_t, vuint32m4_t, const uint32_t *, vuint32m4_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vloxseg2ei32_v)))
void vloxseg2ei32_v_u32mf2(vuint32mf2_t *, vuint32mf2_t *, const uint32_t *, vuint32mf2_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vloxseg2ei32_v_m)))
void vloxseg2ei32_v_u32mf2_m(vuint32mf2_t *, vuint32mf2_t *, vbool64_t, vuint32mf2_t, vuint32mf2_t, const uint32_t *, vuint32mf2_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vloxseg3ei32_v)))
void vloxseg3ei32_v_i32m1(vint32m1_t *, vint32m1_t *, vint32m1_t *, const int32_t *, vuint32m1_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vloxseg3ei32_v_m)))
void vloxseg3ei32_v_i32m1_m(vint32m1_t *, vint32m1_t *, vint32m1_t *, vbool32_t, vint32m1_t, vint32m1_t, vint32m1_t, const int32_t *, vuint32m1_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vloxseg3ei32_v)))
void vloxseg3ei32_v_i32m2(vint32m2_t *, vint32m2_t *, vint32m2_t *, const int32_t *, vuint32m2_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vloxseg3ei32_v_m)))
void vloxseg3ei32_v_i32m2_m(vint32m2_t *, vint32m2_t *, vint32m2_t *, vbool16_t, vint32m2_t, vint32m2_t, vint32m2_t, const int32_t *, vuint32m2_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vloxseg3ei32_v)))
void vloxseg3ei32_v_i32mf2(vint32mf2_t *, vint32mf2_t *, vint32mf2_t *, const int32_t *, vuint32mf2_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vloxseg3ei32_v_m)))
void vloxseg3ei32_v_i32mf2_m(vint32mf2_t *, vint32mf2_t *, vint32mf2_t *, vbool64_t, vint32mf2_t, vint32mf2_t, vint32mf2_t, const int32_t *, vuint32mf2_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vloxseg3ei32_v)))
void vloxseg3ei32_v_u32m1(vuint32m1_t *, vuint32m1_t *, vuint32m1_t *, const uint32_t *, vuint32m1_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vloxseg3ei32_v_m)))
void vloxseg3ei32_v_u32m1_m(vuint32m1_t *, vuint32m1_t *, vuint32m1_t *, vbool32_t, vuint32m1_t, vuint32m1_t, vuint32m1_t, const uint32_t *, vuint32m1_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vloxseg3ei32_v)))
void vloxseg3ei32_v_u32m2(vuint32m2_t *, vuint32m2_t *, vuint32m2_t *, const uint32_t *, vuint32m2_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vloxseg3ei32_v_m)))
void vloxseg3ei32_v_u32m2_m(vuint32m2_t *, vuint32m2_t *, vuint32m2_t *, vbool16_t, vuint32m2_t, vuint32m2_t, vuint32m2_t, const uint32_t *, vuint32m2_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vloxseg3ei32_v)))
void vloxseg3ei32_v_u32mf2(vuint32mf2_t *, vuint32mf2_t *, vuint32mf2_t *, const uint32_t *, vuint32mf2_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vloxseg3ei32_v_m)))
void vloxseg3ei32_v_u32mf2_m(vuint32mf2_t *, vuint32mf2_t *, vuint32mf2_t *, vbool64_t, vuint32mf2_t, vuint32mf2_t, vuint32mf2_t, const uint32_t *, vuint32mf2_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vloxseg4ei32_v)))
void vloxseg4ei32_v_i32m1(vint32m1_t *, vint32m1_t *, vint32m1_t *, vint32m1_t *, const int32_t *, vuint32m1_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vloxseg4ei32_v_m)))
void vloxseg4ei32_v_i32m1_m(vint32m1_t *, vint32m1_t *, vint32m1_t *, vint32m1_t *, vbool32_t, vint32m1_t, vint32m1_t, vint32m1_t, vint32m1_t, const int32_t *, vuint32m1_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vloxseg4ei32_v)))
void vloxseg4ei32_v_i32m2(vint32m2_t *, vint32m2_t *, vint32m2_t *, vint32m2_t *, const int32_t *, vuint32m2_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vloxseg4ei32_v_m)))
void vloxseg4ei32_v_i32m2_m(vint32m2_t *, vint32m2_t *, vint32m2_t *, vint32m2_t *, vbool16_t, vint32m2_t, vint32m2_t, vint32m2_t, vint32m2_t, const int32_t *, vuint32m2_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vloxseg4ei32_v)))
void vloxseg4ei32_v_i32mf2(vint32mf2_t *, vint32mf2_t *, vint32mf2_t *, vint32mf2_t *, const int32_t *, vuint32mf2_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vloxseg4ei32_v_m)))
void vloxseg4ei32_v_i32mf2_m(vint32mf2_t *, vint32mf2_t *, vint32mf2_t *, vint32mf2_t *, vbool64_t, vint32mf2_t, vint32mf2_t, vint32mf2_t, vint32mf2_t, const int32_t *, vuint32mf2_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vloxseg4ei32_v)))
void vloxseg4ei32_v_u32m1(vuint32m1_t *, vuint32m1_t *, vuint32m1_t *, vuint32m1_t *, const uint32_t *, vuint32m1_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vloxseg4ei32_v_m)))
void vloxseg4ei32_v_u32m1_m(vuint32m1_t *, vuint32m1_t *, vuint32m1_t *, vuint32m1_t *, vbool32_t, vuint32m1_t, vuint32m1_t, vuint32m1_t, vuint32m1_t, const uint32_t *, vuint32m1_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vloxseg4ei32_v)))
void vloxseg4ei32_v_u32m2(vuint32m2_t *, vuint32m2_t *, vuint32m2_t *, vuint32m2_t *, const uint32_t *, vuint32m2_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vloxseg4ei32_v_m)))
void vloxseg4ei32_v_u32m2_m(vuint32m2_t *, vuint32m2_t *, vuint32m2_t *, vuint32m2_t *, vbool16_t, vuint32m2_t, vuint32m2_t, vuint32m2_t, vuint32m2_t, const uint32_t *, vuint32m2_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vloxseg4ei32_v)))
void vloxseg4ei32_v_u32mf2(vuint32mf2_t *, vuint32mf2_t *, vuint32mf2_t *, vuint32mf2_t *, const uint32_t *, vuint32mf2_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vloxseg4ei32_v_m)))
void vloxseg4ei32_v_u32mf2_m(vuint32mf2_t *, vuint32mf2_t *, vuint32mf2_t *, vuint32mf2_t *, vbool64_t, vuint32mf2_t, vuint32mf2_t, vuint32mf2_t, vuint32mf2_t, const uint32_t *, vuint32mf2_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vloxseg5ei32_v)))
void vloxseg5ei32_v_i32m1(vint32m1_t *, vint32m1_t *, vint32m1_t *, vint32m1_t *, vint32m1_t *, const int32_t *, vuint32m1_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vloxseg5ei32_v_m)))
void vloxseg5ei32_v_i32m1_m(vint32m1_t *, vint32m1_t *, vint32m1_t *, vint32m1_t *, vint32m1_t *, vbool32_t, vint32m1_t, vint32m1_t, vint32m1_t, vint32m1_t, vint32m1_t, const int32_t *, vuint32m1_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vloxseg5ei32_v)))
void vloxseg5ei32_v_i32mf2(vint32mf2_t *, vint32mf2_t *, vint32mf2_t *, vint32mf2_t *, vint32mf2_t *, const int32_t *, vuint32mf2_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vloxseg5ei32_v_m)))
void vloxseg5ei32_v_i32mf2_m(vint32mf2_t *, vint32mf2_t *, vint32mf2_t *, vint32mf2_t *, vint32mf2_t *, vbool64_t, vint32mf2_t, vint32mf2_t, vint32mf2_t, vint32mf2_t, vint32mf2_t, const int32_t *, vuint32mf2_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vloxseg5ei32_v)))
void vloxseg5ei32_v_u32m1(vuint32m1_t *, vuint32m1_t *, vuint32m1_t *, vuint32m1_t *, vuint32m1_t *, const uint32_t *, vuint32m1_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vloxseg5ei32_v_m)))
void vloxseg5ei32_v_u32m1_m(vuint32m1_t *, vuint32m1_t *, vuint32m1_t *, vuint32m1_t *, vuint32m1_t *, vbool32_t, vuint32m1_t, vuint32m1_t, vuint32m1_t, vuint32m1_t, vuint32m1_t, const uint32_t *, vuint32m1_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vloxseg5ei32_v)))
void vloxseg5ei32_v_u32mf2(vuint32mf2_t *, vuint32mf2_t *, vuint32mf2_t *, vuint32mf2_t *, vuint32mf2_t *, const uint32_t *, vuint32mf2_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vloxseg5ei32_v_m)))
void vloxseg5ei32_v_u32mf2_m(vuint32mf2_t *, vuint32mf2_t *, vuint32mf2_t *, vuint32mf2_t *, vuint32mf2_t *, vbool64_t, vuint32mf2_t, vuint32mf2_t, vuint32mf2_t, vuint32mf2_t, vuint32mf2_t, const uint32_t *, vuint32mf2_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vloxseg6ei32_v)))
void vloxseg6ei32_v_i32m1(vint32m1_t *, vint32m1_t *, vint32m1_t *, vint32m1_t *, vint32m1_t *, vint32m1_t *, const int32_t *, vuint32m1_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vloxseg6ei32_v_m)))
void vloxseg6ei32_v_i32m1_m(vint32m1_t *, vint32m1_t *, vint32m1_t *, vint32m1_t *, vint32m1_t *, vint32m1_t *, vbool32_t, vint32m1_t, vint32m1_t, vint32m1_t, vint32m1_t, vint32m1_t, vint32m1_t, const int32_t *, vuint32m1_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vloxseg6ei32_v)))
void vloxseg6ei32_v_i32mf2(vint32mf2_t *, vint32mf2_t *, vint32mf2_t *, vint32mf2_t *, vint32mf2_t *, vint32mf2_t *, const int32_t *, vuint32mf2_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vloxseg6ei32_v_m)))
void vloxseg6ei32_v_i32mf2_m(vint32mf2_t *, vint32mf2_t *, vint32mf2_t *, vint32mf2_t *, vint32mf2_t *, vint32mf2_t *, vbool64_t, vint32mf2_t, vint32mf2_t, vint32mf2_t, vint32mf2_t, vint32mf2_t, vint32mf2_t, const int32_t *, vuint32mf2_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vloxseg6ei32_v)))
void vloxseg6ei32_v_u32m1(vuint32m1_t *, vuint32m1_t *, vuint32m1_t *, vuint32m1_t *, vuint32m1_t *, vuint32m1_t *, const uint32_t *, vuint32m1_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vloxseg6ei32_v_m)))
void vloxseg6ei32_v_u32m1_m(vuint32m1_t *, vuint32m1_t *, vuint32m1_t *, vuint32m1_t *, vuint32m1_t *, vuint32m1_t *, vbool32_t, vuint32m1_t, vuint32m1_t, vuint32m1_t, vuint32m1_t, vuint32m1_t, vuint32m1_t, const uint32_t *, vuint32m1_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vloxseg6ei32_v)))
void vloxseg6ei32_v_u32mf2(vuint32mf2_t *, vuint32mf2_t *, vuint32mf2_t *, vuint32mf2_t *, vuint32mf2_t *, vuint32mf2_t *, const uint32_t *, vuint32mf2_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vloxseg6ei32_v_m)))
void vloxseg6ei32_v_u32mf2_m(vuint32mf2_t *, vuint32mf2_t *, vuint32mf2_t *, vuint32mf2_t *, vuint32mf2_t *, vuint32mf2_t *, vbool64_t, vuint32mf2_t, vuint32mf2_t, vuint32mf2_t, vuint32mf2_t, vuint32mf2_t, vuint32mf2_t, const uint32_t *, vuint32mf2_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vlse32_v)))
vint32m1_t vlse32_v_i32m1(const int32_t *, ptrdiff_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vlse32_v_m)))
vint32m1_t vlse32_v_i32m1_m(vbool32_t, vint32m1_t, const int32_t *, ptrdiff_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vlse32_v)))
vint32m2_t vlse32_v_i32m2(const int32_t *, ptrdiff_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vlse32_v_m)))
vint32m2_t vlse32_v_i32m2_m(vbool16_t, vint32m2_t, const int32_t *, ptrdiff_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vlse32_v)))
vint32m4_t vlse32_v_i32m4(const int32_t *, ptrdiff_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vlse32_v_m)))
vint32m4_t vlse32_v_i32m4_m(vbool8_t, vint32m4_t, const int32_t *, ptrdiff_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vlse32_v)))
vint32m8_t vlse32_v_i32m8(const int32_t *, ptrdiff_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vlse32_v_m)))
vint32m8_t vlse32_v_i32m8_m(vbool4_t, vint32m8_t, const int32_t *, ptrdiff_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vlse32_v)))
vint32mf2_t vlse32_v_i32mf2(const int32_t *, ptrdiff_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vlse32_v_m)))
vint32mf2_t vlse32_v_i32mf2_m(vbool64_t, vint32mf2_t, const int32_t *, ptrdiff_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vloxseg7ei32_v)))
void vloxseg7ei32_v_i32m1(vint32m1_t *, vint32m1_t *, vint32m1_t *, vint32m1_t *, vint32m1_t *, vint32m1_t *, vint32m1_t *, const int32_t *, vuint32m1_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vloxseg7ei32_v_m)))
void vloxseg7ei32_v_i32m1_m(vint32m1_t *, vint32m1_t *, vint32m1_t *, vint32m1_t *, vint32m1_t *, vint32m1_t *, vint32m1_t *, vbool32_t, vint32m1_t, vint32m1_t, vint32m1_t, vint32m1_t, vint32m1_t, vint32m1_t, vint32m1_t, const int32_t *, vuint32m1_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vloxseg7ei32_v)))
void vloxseg7ei32_v_i32mf2(vint32mf2_t *, vint32mf2_t *, vint32mf2_t *, vint32mf2_t *, vint32mf2_t *, vint32mf2_t *, vint32mf2_t *, const int32_t *, vuint32mf2_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vloxseg7ei32_v_m)))
void vloxseg7ei32_v_i32mf2_m(vint32mf2_t *, vint32mf2_t *, vint32mf2_t *, vint32mf2_t *, vint32mf2_t *, vint32mf2_t *, vint32mf2_t *, vbool64_t, vint32mf2_t, vint32mf2_t, vint32mf2_t, vint32mf2_t, vint32mf2_t, vint32mf2_t, vint32mf2_t, const int32_t *, vuint32mf2_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vloxseg7ei32_v)))
void vloxseg7ei32_v_u32m1(vuint32m1_t *, vuint32m1_t *, vuint32m1_t *, vuint32m1_t *, vuint32m1_t *, vuint32m1_t *, vuint32m1_t *, const uint32_t *, vuint32m1_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vloxseg7ei32_v_m)))
void vloxseg7ei32_v_u32m1_m(vuint32m1_t *, vuint32m1_t *, vuint32m1_t *, vuint32m1_t *, vuint32m1_t *, vuint32m1_t *, vuint32m1_t *, vbool32_t, vuint32m1_t, vuint32m1_t, vuint32m1_t, vuint32m1_t, vuint32m1_t, vuint32m1_t, vuint32m1_t, const uint32_t *, vuint32m1_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vloxseg7ei32_v)))
void vloxseg7ei32_v_u32mf2(vuint32mf2_t *, vuint32mf2_t *, vuint32mf2_t *, vuint32mf2_t *, vuint32mf2_t *, vuint32mf2_t *, vuint32mf2_t *, const uint32_t *, vuint32mf2_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vloxseg7ei32_v_m)))
void vloxseg7ei32_v_u32mf2_m(vuint32mf2_t *, vuint32mf2_t *, vuint32mf2_t *, vuint32mf2_t *, vuint32mf2_t *, vuint32mf2_t *, vuint32mf2_t *, vbool64_t, vuint32mf2_t, vuint32mf2_t, vuint32mf2_t, vuint32mf2_t, vuint32mf2_t, vuint32mf2_t, vuint32mf2_t, const uint32_t *, vuint32mf2_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vloxseg8ei32_v)))
void vloxseg8ei32_v_i32m1(vint32m1_t *, vint32m1_t *, vint32m1_t *, vint32m1_t *, vint32m1_t *, vint32m1_t *, vint32m1_t *, vint32m1_t *, const int32_t *, vuint32m1_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vloxseg8ei32_v_m)))
void vloxseg8ei32_v_i32m1_m(vint32m1_t *, vint32m1_t *, vint32m1_t *, vint32m1_t *, vint32m1_t *, vint32m1_t *, vint32m1_t *, vint32m1_t *, vbool32_t, vint32m1_t, vint32m1_t, vint32m1_t, vint32m1_t, vint32m1_t, vint32m1_t, vint32m1_t, vint32m1_t, const int32_t *, vuint32m1_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vloxseg8ei32_v)))
void vloxseg8ei32_v_i32mf2(vint32mf2_t *, vint32mf2_t *, vint32mf2_t *, vint32mf2_t *, vint32mf2_t *, vint32mf2_t *, vint32mf2_t *, vint32mf2_t *, const int32_t *, vuint32mf2_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vloxseg8ei32_v_m)))
void vloxseg8ei32_v_i32mf2_m(vint32mf2_t *, vint32mf2_t *, vint32mf2_t *, vint32mf2_t *, vint32mf2_t *, vint32mf2_t *, vint32mf2_t *, vint32mf2_t *, vbool64_t, vint32mf2_t, vint32mf2_t, vint32mf2_t, vint32mf2_t, vint32mf2_t, vint32mf2_t, vint32mf2_t, vint32mf2_t, const int32_t *, vuint32mf2_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vloxseg8ei32_v)))
void vloxseg8ei32_v_u32m1(vuint32m1_t *, vuint32m1_t *, vuint32m1_t *, vuint32m1_t *, vuint32m1_t *, vuint32m1_t *, vuint32m1_t *, vuint32m1_t *, const uint32_t *, vuint32m1_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vloxseg8ei32_v_m)))
void vloxseg8ei32_v_u32m1_m(vuint32m1_t *, vuint32m1_t *, vuint32m1_t *, vuint32m1_t *, vuint32m1_t *, vuint32m1_t *, vuint32m1_t *, vuint32m1_t *, vbool32_t, vuint32m1_t, vuint32m1_t, vuint32m1_t, vuint32m1_t, vuint32m1_t, vuint32m1_t, vuint32m1_t, vuint32m1_t, const uint32_t *, vuint32m1_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vloxseg8ei32_v)))
void vloxseg8ei32_v_u32mf2(vuint32mf2_t *, vuint32mf2_t *, vuint32mf2_t *, vuint32mf2_t *, vuint32mf2_t *, vuint32mf2_t *, vuint32mf2_t *, vuint32mf2_t *, const uint32_t *, vuint32mf2_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vloxseg8ei32_v_m)))
void vloxseg8ei32_v_u32mf2_m(vuint32mf2_t *, vuint32mf2_t *, vuint32mf2_t *, vuint32mf2_t *, vuint32mf2_t *, vuint32mf2_t *, vuint32mf2_t *, vuint32mf2_t *, vbool64_t, vuint32mf2_t, vuint32mf2_t, vuint32mf2_t, vuint32mf2_t, vuint32mf2_t, vuint32mf2_t, vuint32mf2_t, vuint32mf2_t, const uint32_t *, vuint32mf2_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vlse32_v)))
vuint32m1_t vlse32_v_u32m1(const uint32_t *, ptrdiff_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vlse32_v_m)))
vuint32m1_t vlse32_v_u32m1_m(vbool32_t, vuint32m1_t, const uint32_t *, ptrdiff_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vlse32_v)))
vuint32m2_t vlse32_v_u32m2(const uint32_t *, ptrdiff_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vlse32_v_m)))
vuint32m2_t vlse32_v_u32m2_m(vbool16_t, vuint32m2_t, const uint32_t *, ptrdiff_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vlse32_v)))
vuint32m4_t vlse32_v_u32m4(const uint32_t *, ptrdiff_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vlse32_v_m)))
vuint32m4_t vlse32_v_u32m4_m(vbool8_t, vuint32m4_t, const uint32_t *, ptrdiff_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vlse32_v)))
vuint32m8_t vlse32_v_u32m8(const uint32_t *, ptrdiff_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vlse32_v_m)))
vuint32m8_t vlse32_v_u32m8_m(vbool4_t, vuint32m8_t, const uint32_t *, ptrdiff_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vlse32_v)))
vuint32mf2_t vlse32_v_u32mf2(const uint32_t *, ptrdiff_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vlse32_v_m)))
vuint32mf2_t vlse32_v_u32mf2_m(vbool64_t, vuint32mf2_t, const uint32_t *, ptrdiff_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vcpop_m)))
unsigned long vcpop_m_b8(vbool8_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vcpop_m_m)))
unsigned long vcpop_m_b8_m(vbool8_t, vbool8_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vcpop_m)))
unsigned long vcpop_m_b4(vbool4_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vcpop_m_m)))
unsigned long vcpop_m_b4_m(vbool4_t, vbool4_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vcpop_m)))
unsigned long vcpop_m_b2(vbool2_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vcpop_m_m)))
unsigned long vcpop_m_b2_m(vbool2_t, vbool2_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vcpop_m)))
unsigned long vcpop_m_b1(vbool1_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vcpop_m_m)))
unsigned long vcpop_m_b1_m(vbool1_t, vbool1_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vcpop_m)))
unsigned long vcpop_m_b16(vbool16_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vcpop_m_m)))
unsigned long vcpop_m_b16_m(vbool16_t, vbool16_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vcpop_m)))
unsigned long vcpop_m_b32(vbool32_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vcpop_m_m)))
unsigned long vcpop_m_b32_m(vbool32_t, vbool32_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vcpop_m)))
unsigned long vcpop_m_b64(vbool64_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vcpop_m_m)))
unsigned long vcpop_m_b64_m(vbool64_t, vbool64_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vfirst_m)))
long vfirst_m_b8(vbool8_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vfirst_m_m)))
long vfirst_m_b8_m(vbool8_t, vbool8_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vfirst_m)))
long vfirst_m_b4(vbool4_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vfirst_m_m)))
long vfirst_m_b4_m(vbool4_t, vbool4_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vfirst_m)))
long vfirst_m_b2(vbool2_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vfirst_m_m)))
long vfirst_m_b2_m(vbool2_t, vbool2_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vfirst_m)))
long vfirst_m_b1(vbool1_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vfirst_m_m)))
long vfirst_m_b1_m(vbool1_t, vbool1_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vfirst_m)))
long vfirst_m_b16(vbool16_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vfirst_m_m)))
long vfirst_m_b16_m(vbool16_t, vbool16_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vfirst_m)))
long vfirst_m_b32(vbool32_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vfirst_m_m)))
long vfirst_m_b32_m(vbool32_t, vbool32_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vfirst_m)))
long vfirst_m_b64(vbool64_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vfirst_m_m)))
long vfirst_m_b64_m(vbool64_t, vbool64_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vlm_v)))
vbool8_t vlm_v_b8(const uint8_t *, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vlm_v)))
vbool4_t vlm_v_b4(const uint8_t *, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vlm_v)))
vbool2_t vlm_v_b2(const uint8_t *, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vlm_v)))
vbool1_t vlm_v_b1(const uint8_t *, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vlm_v)))
vbool16_t vlm_v_b16(const uint8_t *, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vlm_v)))
vbool32_t vlm_v_b32(const uint8_t *, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vlm_v)))
vbool64_t vlm_v_b64(const uint8_t *, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vlmul_ext_v)))
vint8m1_t vlmul_ext_v_i8mf2_i8m1(vint8mf2_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vlmul_ext_v)))
vint8m1_t vlmul_ext_v_i8mf4_i8m1(vint8mf4_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vlmul_ext_v)))
vint8m1_t vlmul_ext_v_i8mf8_i8m1(vint8mf8_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vlmul_ext_v)))
vint16m1_t vlmul_ext_v_i16mf2_i16m1(vint16mf2_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vlmul_ext_v)))
vint16m1_t vlmul_ext_v_i16mf4_i16m1(vint16mf4_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vlmul_ext_v)))
vint32m1_t vlmul_ext_v_i32mf2_i32m1(vint32mf2_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vlmul_ext_v)))
vint8mf2_t vlmul_ext_v_i8mf4_i8mf2(vint8mf4_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vlmul_ext_v)))
vint8mf2_t vlmul_ext_v_i8mf8_i8mf2(vint8mf8_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vlmul_ext_v)))
vint16mf2_t vlmul_ext_v_i16mf4_i16mf2(vint16mf4_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vlmul_ext_v)))
vint8mf4_t vlmul_ext_v_i8mf8_i8mf4(vint8mf8_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vlmul_ext_v)))
vint8m2_t vlmul_ext_v_i8m1_i8m2(vint8m1_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vlmul_ext_v)))
vint8m2_t vlmul_ext_v_i8mf2_i8m2(vint8mf2_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vlmul_ext_v)))
vint8m2_t vlmul_ext_v_i8mf4_i8m2(vint8mf4_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vlmul_ext_v)))
vint8m2_t vlmul_ext_v_i8mf8_i8m2(vint8mf8_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vlmul_ext_v)))
vint16m2_t vlmul_ext_v_i16m1_i16m2(vint16m1_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vlmul_ext_v)))
vint16m2_t vlmul_ext_v_i16mf2_i16m2(vint16mf2_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vlmul_ext_v)))
vint16m2_t vlmul_ext_v_i16mf4_i16m2(vint16mf4_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vlmul_ext_v)))
vint32m2_t vlmul_ext_v_i32m1_i32m2(vint32m1_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vlmul_ext_v)))
vint32m2_t vlmul_ext_v_i32mf2_i32m2(vint32mf2_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vlmul_ext_v)))
vint8m4_t vlmul_ext_v_i8m1_i8m4(vint8m1_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vlmul_ext_v)))
vint8m4_t vlmul_ext_v_i8m2_i8m4(vint8m2_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vlmul_ext_v)))
vint8m4_t vlmul_ext_v_i8mf2_i8m4(vint8mf2_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vlmul_ext_v)))
vint8m4_t vlmul_ext_v_i8mf4_i8m4(vint8mf4_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vlmul_ext_v)))
vint8m4_t vlmul_ext_v_i8mf8_i8m4(vint8mf8_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vlmul_ext_v)))
vint16m4_t vlmul_ext_v_i16m1_i16m4(vint16m1_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vlmul_ext_v)))
vint16m4_t vlmul_ext_v_i16m2_i16m4(vint16m2_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vlmul_ext_v)))
vint16m4_t vlmul_ext_v_i16mf2_i16m4(vint16mf2_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vlmul_ext_v)))
vint16m4_t vlmul_ext_v_i16mf4_i16m4(vint16mf4_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vlmul_ext_v)))
vint32m4_t vlmul_ext_v_i32m1_i32m4(vint32m1_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vlmul_ext_v)))
vint32m4_t vlmul_ext_v_i32m2_i32m4(vint32m2_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vlmul_ext_v)))
vint32m4_t vlmul_ext_v_i32mf2_i32m4(vint32mf2_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vlmul_ext_v)))
vint8m8_t vlmul_ext_v_i8m1_i8m8(vint8m1_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vlmul_ext_v)))
vint8m8_t vlmul_ext_v_i8m2_i8m8(vint8m2_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vlmul_ext_v)))
vint8m8_t vlmul_ext_v_i8m4_i8m8(vint8m4_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vlmul_ext_v)))
vint8m8_t vlmul_ext_v_i8mf2_i8m8(vint8mf2_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vlmul_ext_v)))
vint8m8_t vlmul_ext_v_i8mf4_i8m8(vint8mf4_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vlmul_ext_v)))
vint8m8_t vlmul_ext_v_i8mf8_i8m8(vint8mf8_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vlmul_ext_v)))
vint16m8_t vlmul_ext_v_i16m1_i16m8(vint16m1_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vlmul_ext_v)))
vint16m8_t vlmul_ext_v_i16m2_i16m8(vint16m2_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vlmul_ext_v)))
vint16m8_t vlmul_ext_v_i16m4_i16m8(vint16m4_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vlmul_ext_v)))
vint16m8_t vlmul_ext_v_i16mf2_i16m8(vint16mf2_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vlmul_ext_v)))
vint16m8_t vlmul_ext_v_i16mf4_i16m8(vint16mf4_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vlmul_ext_v)))
vint32m8_t vlmul_ext_v_i32m1_i32m8(vint32m1_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vlmul_ext_v)))
vint32m8_t vlmul_ext_v_i32m2_i32m8(vint32m2_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vlmul_ext_v)))
vint32m8_t vlmul_ext_v_i32m4_i32m8(vint32m4_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vlmul_ext_v)))
vint32m8_t vlmul_ext_v_i32mf2_i32m8(vint32mf2_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vlmul_ext_v)))
vuint8m1_t vlmul_ext_v_u8mf2_u8m1(vuint8mf2_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vlmul_ext_v)))
vuint8m1_t vlmul_ext_v_u8mf4_u8m1(vuint8mf4_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vlmul_ext_v)))
vuint8m1_t vlmul_ext_v_u8mf8_u8m1(vuint8mf8_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vlmul_ext_v)))
vuint16m1_t vlmul_ext_v_u16mf2_u16m1(vuint16mf2_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vlmul_ext_v)))
vuint16m1_t vlmul_ext_v_u16mf4_u16m1(vuint16mf4_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vlmul_ext_v)))
vuint32m1_t vlmul_ext_v_u32mf2_u32m1(vuint32mf2_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vlmul_ext_v)))
vuint8mf2_t vlmul_ext_v_u8mf4_u8mf2(vuint8mf4_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vlmul_ext_v)))
vuint8mf2_t vlmul_ext_v_u8mf8_u8mf2(vuint8mf8_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vlmul_ext_v)))
vuint16mf2_t vlmul_ext_v_u16mf4_u16mf2(vuint16mf4_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vlmul_ext_v)))
vuint8mf4_t vlmul_ext_v_u8mf8_u8mf4(vuint8mf8_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vlmul_ext_v)))
vuint8m2_t vlmul_ext_v_u8m1_u8m2(vuint8m1_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vlmul_ext_v)))
vuint8m2_t vlmul_ext_v_u8mf2_u8m2(vuint8mf2_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vlmul_ext_v)))
vuint8m2_t vlmul_ext_v_u8mf4_u8m2(vuint8mf4_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vlmul_ext_v)))
vuint8m2_t vlmul_ext_v_u8mf8_u8m2(vuint8mf8_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vlmul_ext_v)))
vuint16m2_t vlmul_ext_v_u16m1_u16m2(vuint16m1_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vlmul_ext_v)))
vuint16m2_t vlmul_ext_v_u16mf2_u16m2(vuint16mf2_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vlmul_ext_v)))
vuint16m2_t vlmul_ext_v_u16mf4_u16m2(vuint16mf4_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vlmul_ext_v)))
vuint32m2_t vlmul_ext_v_u32m1_u32m2(vuint32m1_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vlmul_ext_v)))
vuint32m2_t vlmul_ext_v_u32mf2_u32m2(vuint32mf2_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vlmul_ext_v)))
vuint8m4_t vlmul_ext_v_u8m1_u8m4(vuint8m1_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vlmul_ext_v)))
vuint8m4_t vlmul_ext_v_u8m2_u8m4(vuint8m2_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vlmul_ext_v)))
vuint8m4_t vlmul_ext_v_u8mf2_u8m4(vuint8mf2_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vlmul_ext_v)))
vuint8m4_t vlmul_ext_v_u8mf4_u8m4(vuint8mf4_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vlmul_ext_v)))
vuint8m4_t vlmul_ext_v_u8mf8_u8m4(vuint8mf8_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vlmul_ext_v)))
vuint16m4_t vlmul_ext_v_u16m1_u16m4(vuint16m1_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vlmul_ext_v)))
vuint16m4_t vlmul_ext_v_u16m2_u16m4(vuint16m2_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vlmul_ext_v)))
vuint16m4_t vlmul_ext_v_u16mf2_u16m4(vuint16mf2_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vlmul_ext_v)))
vuint16m4_t vlmul_ext_v_u16mf4_u16m4(vuint16mf4_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vlmul_ext_v)))
vuint32m4_t vlmul_ext_v_u32m1_u32m4(vuint32m1_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vlmul_ext_v)))
vuint32m4_t vlmul_ext_v_u32m2_u32m4(vuint32m2_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vlmul_ext_v)))
vuint32m4_t vlmul_ext_v_u32mf2_u32m4(vuint32mf2_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vlmul_ext_v)))
vuint8m8_t vlmul_ext_v_u8m1_u8m8(vuint8m1_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vlmul_ext_v)))
vuint8m8_t vlmul_ext_v_u8m2_u8m8(vuint8m2_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vlmul_ext_v)))
vuint8m8_t vlmul_ext_v_u8m4_u8m8(vuint8m4_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vlmul_ext_v)))
vuint8m8_t vlmul_ext_v_u8mf2_u8m8(vuint8mf2_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vlmul_ext_v)))
vuint8m8_t vlmul_ext_v_u8mf4_u8m8(vuint8mf4_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vlmul_ext_v)))
vuint8m8_t vlmul_ext_v_u8mf8_u8m8(vuint8mf8_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vlmul_ext_v)))
vuint16m8_t vlmul_ext_v_u16m1_u16m8(vuint16m1_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vlmul_ext_v)))
vuint16m8_t vlmul_ext_v_u16m2_u16m8(vuint16m2_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vlmul_ext_v)))
vuint16m8_t vlmul_ext_v_u16m4_u16m8(vuint16m4_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vlmul_ext_v)))
vuint16m8_t vlmul_ext_v_u16mf2_u16m8(vuint16mf2_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vlmul_ext_v)))
vuint16m8_t vlmul_ext_v_u16mf4_u16m8(vuint16mf4_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vlmul_ext_v)))
vuint32m8_t vlmul_ext_v_u32m1_u32m8(vuint32m1_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vlmul_ext_v)))
vuint32m8_t vlmul_ext_v_u32m2_u32m8(vuint32m2_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vlmul_ext_v)))
vuint32m8_t vlmul_ext_v_u32m4_u32m8(vuint32m4_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vlmul_ext_v)))
vuint32m8_t vlmul_ext_v_u32mf2_u32m8(vuint32mf2_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vlmul_trunc_v)))
vint8mf2_t vlmul_trunc_v_i8m1_i8mf2(vint8m1_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vlmul_trunc_v)))
vint8mf2_t vlmul_trunc_v_i8m2_i8mf2(vint8m2_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vlmul_trunc_v)))
vint8mf2_t vlmul_trunc_v_i8m4_i8mf2(vint8m4_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vlmul_trunc_v)))
vint8mf2_t vlmul_trunc_v_i8m8_i8mf2(vint8m8_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vlmul_trunc_v)))
vint16mf2_t vlmul_trunc_v_i16m1_i16mf2(vint16m1_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vlmul_trunc_v)))
vint16mf2_t vlmul_trunc_v_i16m2_i16mf2(vint16m2_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vlmul_trunc_v)))
vint16mf2_t vlmul_trunc_v_i16m4_i16mf2(vint16m4_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vlmul_trunc_v)))
vint16mf2_t vlmul_trunc_v_i16m8_i16mf2(vint16m8_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vlmul_trunc_v)))
vint32mf2_t vlmul_trunc_v_i32m1_i32mf2(vint32m1_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vlmul_trunc_v)))
vint32mf2_t vlmul_trunc_v_i32m2_i32mf2(vint32m2_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vlmul_trunc_v)))
vint32mf2_t vlmul_trunc_v_i32m4_i32mf2(vint32m4_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vlmul_trunc_v)))
vint32mf2_t vlmul_trunc_v_i32m8_i32mf2(vint32m8_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vlmul_trunc_v)))
vint8mf4_t vlmul_trunc_v_i8m1_i8mf4(vint8m1_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vlmul_trunc_v)))
vint8mf4_t vlmul_trunc_v_i8m2_i8mf4(vint8m2_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vlmul_trunc_v)))
vint8mf4_t vlmul_trunc_v_i8m4_i8mf4(vint8m4_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vlmul_trunc_v)))
vint8mf4_t vlmul_trunc_v_i8m8_i8mf4(vint8m8_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vlmul_trunc_v)))
vint8mf4_t vlmul_trunc_v_i8mf2_i8mf4(vint8mf2_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vlmul_trunc_v)))
vint16mf4_t vlmul_trunc_v_i16m1_i16mf4(vint16m1_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vlmul_trunc_v)))
vint16mf4_t vlmul_trunc_v_i16m2_i16mf4(vint16m2_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vlmul_trunc_v)))
vint16mf4_t vlmul_trunc_v_i16m4_i16mf4(vint16m4_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vlmul_trunc_v)))
vint16mf4_t vlmul_trunc_v_i16m8_i16mf4(vint16m8_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vlmul_trunc_v)))
vint16mf4_t vlmul_trunc_v_i16mf2_i16mf4(vint16mf2_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vlmul_trunc_v)))
vint8mf8_t vlmul_trunc_v_i8m1_i8mf8(vint8m1_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vlmul_trunc_v)))
vint8mf8_t vlmul_trunc_v_i8m2_i8mf8(vint8m2_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vlmul_trunc_v)))
vint8mf8_t vlmul_trunc_v_i8m4_i8mf8(vint8m4_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vlmul_trunc_v)))
vint8mf8_t vlmul_trunc_v_i8m8_i8mf8(vint8m8_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vlmul_trunc_v)))
vint8mf8_t vlmul_trunc_v_i8mf2_i8mf8(vint8mf2_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vlmul_trunc_v)))
vint8mf8_t vlmul_trunc_v_i8mf4_i8mf8(vint8mf4_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vlmul_trunc_v)))
vint8m1_t vlmul_trunc_v_i8m2_i8m1(vint8m2_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vlmul_trunc_v)))
vint8m1_t vlmul_trunc_v_i8m4_i8m1(vint8m4_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vlmul_trunc_v)))
vint8m1_t vlmul_trunc_v_i8m8_i8m1(vint8m8_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vlmul_trunc_v)))
vint16m1_t vlmul_trunc_v_i16m2_i16m1(vint16m2_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vlmul_trunc_v)))
vint16m1_t vlmul_trunc_v_i16m4_i16m1(vint16m4_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vlmul_trunc_v)))
vint16m1_t vlmul_trunc_v_i16m8_i16m1(vint16m8_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vlmul_trunc_v)))
vint32m1_t vlmul_trunc_v_i32m2_i32m1(vint32m2_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vlmul_trunc_v)))
vint32m1_t vlmul_trunc_v_i32m4_i32m1(vint32m4_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vlmul_trunc_v)))
vint32m1_t vlmul_trunc_v_i32m8_i32m1(vint32m8_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vlmul_trunc_v)))
vint8m2_t vlmul_trunc_v_i8m4_i8m2(vint8m4_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vlmul_trunc_v)))
vint8m2_t vlmul_trunc_v_i8m8_i8m2(vint8m8_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vlmul_trunc_v)))
vint16m2_t vlmul_trunc_v_i16m4_i16m2(vint16m4_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vlmul_trunc_v)))
vint16m2_t vlmul_trunc_v_i16m8_i16m2(vint16m8_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vlmul_trunc_v)))
vint32m2_t vlmul_trunc_v_i32m4_i32m2(vint32m4_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vlmul_trunc_v)))
vint32m2_t vlmul_trunc_v_i32m8_i32m2(vint32m8_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vlmul_trunc_v)))
vint8m4_t vlmul_trunc_v_i8m8_i8m4(vint8m8_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vlmul_trunc_v)))
vint16m4_t vlmul_trunc_v_i16m8_i16m4(vint16m8_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vlmul_trunc_v)))
vint32m4_t vlmul_trunc_v_i32m8_i32m4(vint32m8_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vlmul_trunc_v)))
vuint8mf2_t vlmul_trunc_v_u8m1_u8mf2(vuint8m1_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vlmul_trunc_v)))
vuint8mf2_t vlmul_trunc_v_u8m2_u8mf2(vuint8m2_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vlmul_trunc_v)))
vuint8mf2_t vlmul_trunc_v_u8m4_u8mf2(vuint8m4_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vlmul_trunc_v)))
vuint8mf2_t vlmul_trunc_v_u8m8_u8mf2(vuint8m8_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vlmul_trunc_v)))
vuint16mf2_t vlmul_trunc_v_u16m1_u16mf2(vuint16m1_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vlmul_trunc_v)))
vuint16mf2_t vlmul_trunc_v_u16m2_u16mf2(vuint16m2_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vlmul_trunc_v)))
vuint16mf2_t vlmul_trunc_v_u16m4_u16mf2(vuint16m4_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vlmul_trunc_v)))
vuint16mf2_t vlmul_trunc_v_u16m8_u16mf2(vuint16m8_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vlmul_trunc_v)))
vuint32mf2_t vlmul_trunc_v_u32m1_u32mf2(vuint32m1_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vlmul_trunc_v)))
vuint32mf2_t vlmul_trunc_v_u32m2_u32mf2(vuint32m2_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vlmul_trunc_v)))
vuint32mf2_t vlmul_trunc_v_u32m4_u32mf2(vuint32m4_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vlmul_trunc_v)))
vuint32mf2_t vlmul_trunc_v_u32m8_u32mf2(vuint32m8_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vlmul_trunc_v)))
vuint8mf4_t vlmul_trunc_v_u8m1_u8mf4(vuint8m1_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vlmul_trunc_v)))
vuint8mf4_t vlmul_trunc_v_u8m2_u8mf4(vuint8m2_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vlmul_trunc_v)))
vuint8mf4_t vlmul_trunc_v_u8m4_u8mf4(vuint8m4_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vlmul_trunc_v)))
vuint8mf4_t vlmul_trunc_v_u8m8_u8mf4(vuint8m8_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vlmul_trunc_v)))
vuint8mf4_t vlmul_trunc_v_u8mf2_u8mf4(vuint8mf2_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vlmul_trunc_v)))
vuint16mf4_t vlmul_trunc_v_u16m1_u16mf4(vuint16m1_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vlmul_trunc_v)))
vuint16mf4_t vlmul_trunc_v_u16m2_u16mf4(vuint16m2_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vlmul_trunc_v)))
vuint16mf4_t vlmul_trunc_v_u16m4_u16mf4(vuint16m4_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vlmul_trunc_v)))
vuint16mf4_t vlmul_trunc_v_u16m8_u16mf4(vuint16m8_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vlmul_trunc_v)))
vuint16mf4_t vlmul_trunc_v_u16mf2_u16mf4(vuint16mf2_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vlmul_trunc_v)))
vuint8mf8_t vlmul_trunc_v_u8m1_u8mf8(vuint8m1_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vlmul_trunc_v)))
vuint8mf8_t vlmul_trunc_v_u8m2_u8mf8(vuint8m2_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vlmul_trunc_v)))
vuint8mf8_t vlmul_trunc_v_u8m4_u8mf8(vuint8m4_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vlmul_trunc_v)))
vuint8mf8_t vlmul_trunc_v_u8m8_u8mf8(vuint8m8_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vlmul_trunc_v)))
vuint8mf8_t vlmul_trunc_v_u8mf2_u8mf8(vuint8mf2_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vlmul_trunc_v)))
vuint8mf8_t vlmul_trunc_v_u8mf4_u8mf8(vuint8mf4_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vlmul_trunc_v)))
vuint8m1_t vlmul_trunc_v_u8m2_u8m1(vuint8m2_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vlmul_trunc_v)))
vuint8m1_t vlmul_trunc_v_u8m4_u8m1(vuint8m4_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vlmul_trunc_v)))
vuint8m1_t vlmul_trunc_v_u8m8_u8m1(vuint8m8_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vlmul_trunc_v)))
vuint16m1_t vlmul_trunc_v_u16m2_u16m1(vuint16m2_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vlmul_trunc_v)))
vuint16m1_t vlmul_trunc_v_u16m4_u16m1(vuint16m4_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vlmul_trunc_v)))
vuint16m1_t vlmul_trunc_v_u16m8_u16m1(vuint16m8_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vlmul_trunc_v)))
vuint32m1_t vlmul_trunc_v_u32m2_u32m1(vuint32m2_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vlmul_trunc_v)))
vuint32m1_t vlmul_trunc_v_u32m4_u32m1(vuint32m4_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vlmul_trunc_v)))
vuint32m1_t vlmul_trunc_v_u32m8_u32m1(vuint32m8_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vlmul_trunc_v)))
vuint8m2_t vlmul_trunc_v_u8m4_u8m2(vuint8m4_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vlmul_trunc_v)))
vuint8m2_t vlmul_trunc_v_u8m8_u8m2(vuint8m8_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vlmul_trunc_v)))
vuint16m2_t vlmul_trunc_v_u16m4_u16m2(vuint16m4_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vlmul_trunc_v)))
vuint16m2_t vlmul_trunc_v_u16m8_u16m2(vuint16m8_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vlmul_trunc_v)))
vuint32m2_t vlmul_trunc_v_u32m4_u32m2(vuint32m4_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vlmul_trunc_v)))
vuint32m2_t vlmul_trunc_v_u32m8_u32m2(vuint32m8_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vlmul_trunc_v)))
vuint8m4_t vlmul_trunc_v_u8m8_u8m4(vuint8m8_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vlmul_trunc_v)))
vuint16m4_t vlmul_trunc_v_u16m8_u16m4(vuint16m8_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vlmul_trunc_v)))
vuint32m4_t vlmul_trunc_v_u32m8_u32m4(vuint32m8_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vmand_mm)))
vbool8_t vmand_mm_b8(vbool8_t, vbool8_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vmand_mm)))
vbool4_t vmand_mm_b4(vbool4_t, vbool4_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vmand_mm)))
vbool2_t vmand_mm_b2(vbool2_t, vbool2_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vmand_mm)))
vbool1_t vmand_mm_b1(vbool1_t, vbool1_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vmand_mm)))
vbool16_t vmand_mm_b16(vbool16_t, vbool16_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vmand_mm)))
vbool32_t vmand_mm_b32(vbool32_t, vbool32_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vmand_mm)))
vbool64_t vmand_mm_b64(vbool64_t, vbool64_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vmandn_mm)))
vbool8_t vmandn_mm_b8(vbool8_t, vbool8_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vmandn_mm)))
vbool4_t vmandn_mm_b4(vbool4_t, vbool4_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vmandn_mm)))
vbool2_t vmandn_mm_b2(vbool2_t, vbool2_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vmandn_mm)))
vbool1_t vmandn_mm_b1(vbool1_t, vbool1_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vmandn_mm)))
vbool16_t vmandn_mm_b16(vbool16_t, vbool16_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vmandn_mm)))
vbool32_t vmandn_mm_b32(vbool32_t, vbool32_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vmandn_mm)))
vbool64_t vmandn_mm_b64(vbool64_t, vbool64_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vmclr_m)))
vbool8_t vmclr_m_b8(size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vmclr_m)))
vbool4_t vmclr_m_b4(size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vmclr_m)))
vbool2_t vmclr_m_b2(size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vmclr_m)))
vbool1_t vmclr_m_b1(size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vmclr_m)))
vbool16_t vmclr_m_b16(size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vmclr_m)))
vbool32_t vmclr_m_b32(size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vmclr_m)))
vbool64_t vmclr_m_b64(size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vmnand_mm)))
vbool8_t vmnand_mm_b8(vbool8_t, vbool8_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vmnand_mm)))
vbool4_t vmnand_mm_b4(vbool4_t, vbool4_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vmnand_mm)))
vbool2_t vmnand_mm_b2(vbool2_t, vbool2_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vmnand_mm)))
vbool1_t vmnand_mm_b1(vbool1_t, vbool1_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vmnand_mm)))
vbool16_t vmnand_mm_b16(vbool16_t, vbool16_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vmnand_mm)))
vbool32_t vmnand_mm_b32(vbool32_t, vbool32_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vmnand_mm)))
vbool64_t vmnand_mm_b64(vbool64_t, vbool64_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vmnor_mm)))
vbool8_t vmnor_mm_b8(vbool8_t, vbool8_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vmnor_mm)))
vbool4_t vmnor_mm_b4(vbool4_t, vbool4_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vmnor_mm)))
vbool2_t vmnor_mm_b2(vbool2_t, vbool2_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vmnor_mm)))
vbool1_t vmnor_mm_b1(vbool1_t, vbool1_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vmnor_mm)))
vbool16_t vmnor_mm_b16(vbool16_t, vbool16_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vmnor_mm)))
vbool32_t vmnor_mm_b32(vbool32_t, vbool32_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vmnor_mm)))
vbool64_t vmnor_mm_b64(vbool64_t, vbool64_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vmor_mm)))
vbool8_t vmor_mm_b8(vbool8_t, vbool8_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vmor_mm)))
vbool4_t vmor_mm_b4(vbool4_t, vbool4_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vmor_mm)))
vbool2_t vmor_mm_b2(vbool2_t, vbool2_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vmor_mm)))
vbool1_t vmor_mm_b1(vbool1_t, vbool1_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vmor_mm)))
vbool16_t vmor_mm_b16(vbool16_t, vbool16_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vmor_mm)))
vbool32_t vmor_mm_b32(vbool32_t, vbool32_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vmor_mm)))
vbool64_t vmor_mm_b64(vbool64_t, vbool64_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vmorn_mm)))
vbool8_t vmorn_mm_b8(vbool8_t, vbool8_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vmorn_mm)))
vbool4_t vmorn_mm_b4(vbool4_t, vbool4_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vmorn_mm)))
vbool2_t vmorn_mm_b2(vbool2_t, vbool2_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vmorn_mm)))
vbool1_t vmorn_mm_b1(vbool1_t, vbool1_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vmorn_mm)))
vbool16_t vmorn_mm_b16(vbool16_t, vbool16_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vmorn_mm)))
vbool32_t vmorn_mm_b32(vbool32_t, vbool32_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vmorn_mm)))
vbool64_t vmorn_mm_b64(vbool64_t, vbool64_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vmsbf_m)))
vbool8_t vmsbf_m_b8(vbool8_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vmsbf_m_m)))
vbool8_t vmsbf_m_b8_m(vbool8_t, vbool8_t, vbool8_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vmsbf_m)))
vbool4_t vmsbf_m_b4(vbool4_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vmsbf_m_m)))
vbool4_t vmsbf_m_b4_m(vbool4_t, vbool4_t, vbool4_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vmsbf_m)))
vbool2_t vmsbf_m_b2(vbool2_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vmsbf_m_m)))
vbool2_t vmsbf_m_b2_m(vbool2_t, vbool2_t, vbool2_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vmsbf_m)))
vbool1_t vmsbf_m_b1(vbool1_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vmsbf_m_m)))
vbool1_t vmsbf_m_b1_m(vbool1_t, vbool1_t, vbool1_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vmsbf_m)))
vbool16_t vmsbf_m_b16(vbool16_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vmsbf_m_m)))
vbool16_t vmsbf_m_b16_m(vbool16_t, vbool16_t, vbool16_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vmsbf_m)))
vbool32_t vmsbf_m_b32(vbool32_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vmsbf_m_m)))
vbool32_t vmsbf_m_b32_m(vbool32_t, vbool32_t, vbool32_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vmsbf_m)))
vbool64_t vmsbf_m_b64(vbool64_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vmsbf_m_m)))
vbool64_t vmsbf_m_b64_m(vbool64_t, vbool64_t, vbool64_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vmset_m)))
vbool8_t vmset_m_b8(size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vmset_m)))
vbool4_t vmset_m_b4(size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vmset_m)))
vbool2_t vmset_m_b2(size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vmset_m)))
vbool1_t vmset_m_b1(size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vmset_m)))
vbool16_t vmset_m_b16(size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vmset_m)))
vbool32_t vmset_m_b32(size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vmset_m)))
vbool64_t vmset_m_b64(size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vmsif_m)))
vbool8_t vmsif_m_b8(vbool8_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vmsif_m_m)))
vbool8_t vmsif_m_b8_m(vbool8_t, vbool8_t, vbool8_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vmsif_m)))
vbool4_t vmsif_m_b4(vbool4_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vmsif_m_m)))
vbool4_t vmsif_m_b4_m(vbool4_t, vbool4_t, vbool4_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vmsif_m)))
vbool2_t vmsif_m_b2(vbool2_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vmsif_m_m)))
vbool2_t vmsif_m_b2_m(vbool2_t, vbool2_t, vbool2_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vmsif_m)))
vbool1_t vmsif_m_b1(vbool1_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vmsif_m_m)))
vbool1_t vmsif_m_b1_m(vbool1_t, vbool1_t, vbool1_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vmsif_m)))
vbool16_t vmsif_m_b16(vbool16_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vmsif_m_m)))
vbool16_t vmsif_m_b16_m(vbool16_t, vbool16_t, vbool16_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vmsif_m)))
vbool32_t vmsif_m_b32(vbool32_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vmsif_m_m)))
vbool32_t vmsif_m_b32_m(vbool32_t, vbool32_t, vbool32_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vmsif_m)))
vbool64_t vmsif_m_b64(vbool64_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vmsif_m_m)))
vbool64_t vmsif_m_b64_m(vbool64_t, vbool64_t, vbool64_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vmsof_m)))
vbool8_t vmsof_m_b8(vbool8_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vmsof_m_m)))
vbool8_t vmsof_m_b8_m(vbool8_t, vbool8_t, vbool8_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vmsof_m)))
vbool4_t vmsof_m_b4(vbool4_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vmsof_m_m)))
vbool4_t vmsof_m_b4_m(vbool4_t, vbool4_t, vbool4_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vmsof_m)))
vbool2_t vmsof_m_b2(vbool2_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vmsof_m_m)))
vbool2_t vmsof_m_b2_m(vbool2_t, vbool2_t, vbool2_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vmsof_m)))
vbool1_t vmsof_m_b1(vbool1_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vmsof_m_m)))
vbool1_t vmsof_m_b1_m(vbool1_t, vbool1_t, vbool1_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vmsof_m)))
vbool16_t vmsof_m_b16(vbool16_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vmsof_m_m)))
vbool16_t vmsof_m_b16_m(vbool16_t, vbool16_t, vbool16_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vmsof_m)))
vbool32_t vmsof_m_b32(vbool32_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vmsof_m_m)))
vbool32_t vmsof_m_b32_m(vbool32_t, vbool32_t, vbool32_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vmsof_m)))
vbool64_t vmsof_m_b64(vbool64_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vmsof_m_m)))
vbool64_t vmsof_m_b64_m(vbool64_t, vbool64_t, vbool64_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vmxnor_mm)))
vbool8_t vmxnor_mm_b8(vbool8_t, vbool8_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vmxnor_mm)))
vbool4_t vmxnor_mm_b4(vbool4_t, vbool4_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vmxnor_mm)))
vbool2_t vmxnor_mm_b2(vbool2_t, vbool2_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vmxnor_mm)))
vbool1_t vmxnor_mm_b1(vbool1_t, vbool1_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vmxnor_mm)))
vbool16_t vmxnor_mm_b16(vbool16_t, vbool16_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vmxnor_mm)))
vbool32_t vmxnor_mm_b32(vbool32_t, vbool32_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vmxnor_mm)))
vbool64_t vmxnor_mm_b64(vbool64_t, vbool64_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vmxor_mm)))
vbool8_t vmxor_mm_b8(vbool8_t, vbool8_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vmxor_mm)))
vbool4_t vmxor_mm_b4(vbool4_t, vbool4_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vmxor_mm)))
vbool2_t vmxor_mm_b2(vbool2_t, vbool2_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vmxor_mm)))
vbool1_t vmxor_mm_b1(vbool1_t, vbool1_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vmxor_mm)))
vbool16_t vmxor_mm_b16(vbool16_t, vbool16_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vmxor_mm)))
vbool32_t vmxor_mm_b32(vbool32_t, vbool32_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vmxor_mm)))
vbool64_t vmxor_mm_b64(vbool64_t, vbool64_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vreinterpret_v)))
vint16m1_t vreinterpret_v_i8m1_i16m1(vint8m1_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vreinterpret_v)))
vint16m2_t vreinterpret_v_i8m2_i16m2(vint8m2_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vreinterpret_v)))
vint16m4_t vreinterpret_v_i8m4_i16m4(vint8m4_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vreinterpret_v)))
vint16m8_t vreinterpret_v_i8m8_i16m8(vint8m8_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vreinterpret_v)))
vint16mf2_t vreinterpret_v_i8mf2_i16mf2(vint8mf2_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vreinterpret_v)))
vint16mf4_t vreinterpret_v_i8mf4_i16mf4(vint8mf4_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vreinterpret_v)))
vint16m1_t vreinterpret_v_i32m1_i16m1(vint32m1_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vreinterpret_v)))
vint16m2_t vreinterpret_v_i32m2_i16m2(vint32m2_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vreinterpret_v)))
vint16m4_t vreinterpret_v_i32m4_i16m4(vint32m4_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vreinterpret_v)))
vint16m8_t vreinterpret_v_i32m8_i16m8(vint32m8_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vreinterpret_v)))
vint16mf2_t vreinterpret_v_i32mf2_i16mf2(vint32mf2_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vreinterpret_v)))
vint32m1_t vreinterpret_v_i8m1_i32m1(vint8m1_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vreinterpret_v)))
vint32m2_t vreinterpret_v_i8m2_i32m2(vint8m2_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vreinterpret_v)))
vint32m4_t vreinterpret_v_i8m4_i32m4(vint8m4_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vreinterpret_v)))
vint32m8_t vreinterpret_v_i8m8_i32m8(vint8m8_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vreinterpret_v)))
vint32mf2_t vreinterpret_v_i8mf2_i32mf2(vint8mf2_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vreinterpret_v)))
vint32m1_t vreinterpret_v_i16m1_i32m1(vint16m1_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vreinterpret_v)))
vint32m2_t vreinterpret_v_i16m2_i32m2(vint16m2_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vreinterpret_v)))
vint32m4_t vreinterpret_v_i16m4_i32m4(vint16m4_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vreinterpret_v)))
vint32m8_t vreinterpret_v_i16m8_i32m8(vint16m8_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vreinterpret_v)))
vint32mf2_t vreinterpret_v_i16mf2_i32mf2(vint16mf2_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vreinterpret_v)))
vint8m1_t vreinterpret_v_i16m1_i8m1(vint16m1_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vreinterpret_v)))
vint8m2_t vreinterpret_v_i16m2_i8m2(vint16m2_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vreinterpret_v)))
vint8m4_t vreinterpret_v_i16m4_i8m4(vint16m4_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vreinterpret_v)))
vint8m8_t vreinterpret_v_i16m8_i8m8(vint16m8_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vreinterpret_v)))
vint8mf2_t vreinterpret_v_i16mf2_i8mf2(vint16mf2_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vreinterpret_v)))
vint8mf4_t vreinterpret_v_i16mf4_i8mf4(vint16mf4_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vreinterpret_v)))
vint8m1_t vreinterpret_v_i32m1_i8m1(vint32m1_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vreinterpret_v)))
vint8m2_t vreinterpret_v_i32m2_i8m2(vint32m2_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vreinterpret_v)))
vint8m4_t vreinterpret_v_i32m4_i8m4(vint32m4_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vreinterpret_v)))
vint8m8_t vreinterpret_v_i32m8_i8m8(vint32m8_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vreinterpret_v)))
vint8mf2_t vreinterpret_v_i32mf2_i8mf2(vint32mf2_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vreinterpret_v)))
vint8m1_t vreinterpret_v_u8m1_i8m1(vuint8m1_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vreinterpret_v)))
vint8m2_t vreinterpret_v_u8m2_i8m2(vuint8m2_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vreinterpret_v)))
vint8m4_t vreinterpret_v_u8m4_i8m4(vuint8m4_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vreinterpret_v)))
vint8m8_t vreinterpret_v_u8m8_i8m8(vuint8m8_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vreinterpret_v)))
vint8mf2_t vreinterpret_v_u8mf2_i8mf2(vuint8mf2_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vreinterpret_v)))
vint8mf4_t vreinterpret_v_u8mf4_i8mf4(vuint8mf4_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vreinterpret_v)))
vint8mf8_t vreinterpret_v_u8mf8_i8mf8(vuint8mf8_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vreinterpret_v)))
vint16m1_t vreinterpret_v_u16m1_i16m1(vuint16m1_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vreinterpret_v)))
vint16m2_t vreinterpret_v_u16m2_i16m2(vuint16m2_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vreinterpret_v)))
vint16m4_t vreinterpret_v_u16m4_i16m4(vuint16m4_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vreinterpret_v)))
vint16m8_t vreinterpret_v_u16m8_i16m8(vuint16m8_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vreinterpret_v)))
vint16mf2_t vreinterpret_v_u16mf2_i16mf2(vuint16mf2_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vreinterpret_v)))
vint16mf4_t vreinterpret_v_u16mf4_i16mf4(vuint16mf4_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vreinterpret_v)))
vint32m1_t vreinterpret_v_u32m1_i32m1(vuint32m1_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vreinterpret_v)))
vint32m2_t vreinterpret_v_u32m2_i32m2(vuint32m2_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vreinterpret_v)))
vint32m4_t vreinterpret_v_u32m4_i32m4(vuint32m4_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vreinterpret_v)))
vint32m8_t vreinterpret_v_u32m8_i32m8(vuint32m8_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vreinterpret_v)))
vint32mf2_t vreinterpret_v_u32mf2_i32mf2(vuint32mf2_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vreinterpret_v)))
vuint16m1_t vreinterpret_v_u8m1_u16m1(vuint8m1_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vreinterpret_v)))
vuint16m2_t vreinterpret_v_u8m2_u16m2(vuint8m2_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vreinterpret_v)))
vuint16m4_t vreinterpret_v_u8m4_u16m4(vuint8m4_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vreinterpret_v)))
vuint16m8_t vreinterpret_v_u8m8_u16m8(vuint8m8_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vreinterpret_v)))
vuint16mf2_t vreinterpret_v_u8mf2_u16mf2(vuint8mf2_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vreinterpret_v)))
vuint16mf4_t vreinterpret_v_u8mf4_u16mf4(vuint8mf4_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vreinterpret_v)))
vuint16m1_t vreinterpret_v_u32m1_u16m1(vuint32m1_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vreinterpret_v)))
vuint16m2_t vreinterpret_v_u32m2_u16m2(vuint32m2_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vreinterpret_v)))
vuint16m4_t vreinterpret_v_u32m4_u16m4(vuint32m4_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vreinterpret_v)))
vuint16m8_t vreinterpret_v_u32m8_u16m8(vuint32m8_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vreinterpret_v)))
vuint16mf2_t vreinterpret_v_u32mf2_u16mf2(vuint32mf2_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vreinterpret_v)))
vuint32m1_t vreinterpret_v_u8m1_u32m1(vuint8m1_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vreinterpret_v)))
vuint32m2_t vreinterpret_v_u8m2_u32m2(vuint8m2_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vreinterpret_v)))
vuint32m4_t vreinterpret_v_u8m4_u32m4(vuint8m4_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vreinterpret_v)))
vuint32m8_t vreinterpret_v_u8m8_u32m8(vuint8m8_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vreinterpret_v)))
vuint32mf2_t vreinterpret_v_u8mf2_u32mf2(vuint8mf2_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vreinterpret_v)))
vuint32m1_t vreinterpret_v_u16m1_u32m1(vuint16m1_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vreinterpret_v)))
vuint32m2_t vreinterpret_v_u16m2_u32m2(vuint16m2_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vreinterpret_v)))
vuint32m4_t vreinterpret_v_u16m4_u32m4(vuint16m4_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vreinterpret_v)))
vuint32m8_t vreinterpret_v_u16m8_u32m8(vuint16m8_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vreinterpret_v)))
vuint32mf2_t vreinterpret_v_u16mf2_u32mf2(vuint16mf2_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vreinterpret_v)))
vuint8m1_t vreinterpret_v_u16m1_u8m1(vuint16m1_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vreinterpret_v)))
vuint8m2_t vreinterpret_v_u16m2_u8m2(vuint16m2_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vreinterpret_v)))
vuint8m4_t vreinterpret_v_u16m4_u8m4(vuint16m4_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vreinterpret_v)))
vuint8m8_t vreinterpret_v_u16m8_u8m8(vuint16m8_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vreinterpret_v)))
vuint8mf2_t vreinterpret_v_u16mf2_u8mf2(vuint16mf2_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vreinterpret_v)))
vuint8mf4_t vreinterpret_v_u16mf4_u8mf4(vuint16mf4_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vreinterpret_v)))
vuint8m1_t vreinterpret_v_u32m1_u8m1(vuint32m1_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vreinterpret_v)))
vuint8m2_t vreinterpret_v_u32m2_u8m2(vuint32m2_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vreinterpret_v)))
vuint8m4_t vreinterpret_v_u32m4_u8m4(vuint32m4_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vreinterpret_v)))
vuint8m8_t vreinterpret_v_u32m8_u8m8(vuint32m8_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vreinterpret_v)))
vuint8mf2_t vreinterpret_v_u32mf2_u8mf2(vuint32mf2_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vreinterpret_v)))
vuint8m1_t vreinterpret_v_i8m1_u8m1(vint8m1_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vreinterpret_v)))
vuint8m2_t vreinterpret_v_i8m2_u8m2(vint8m2_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vreinterpret_v)))
vuint8m4_t vreinterpret_v_i8m4_u8m4(vint8m4_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vreinterpret_v)))
vuint8m8_t vreinterpret_v_i8m8_u8m8(vint8m8_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vreinterpret_v)))
vuint8mf2_t vreinterpret_v_i8mf2_u8mf2(vint8mf2_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vreinterpret_v)))
vuint8mf4_t vreinterpret_v_i8mf4_u8mf4(vint8mf4_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vreinterpret_v)))
vuint8mf8_t vreinterpret_v_i8mf8_u8mf8(vint8mf8_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vreinterpret_v)))
vuint16m1_t vreinterpret_v_i16m1_u16m1(vint16m1_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vreinterpret_v)))
vuint16m2_t vreinterpret_v_i16m2_u16m2(vint16m2_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vreinterpret_v)))
vuint16m4_t vreinterpret_v_i16m4_u16m4(vint16m4_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vreinterpret_v)))
vuint16m8_t vreinterpret_v_i16m8_u16m8(vint16m8_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vreinterpret_v)))
vuint16mf2_t vreinterpret_v_i16mf2_u16mf2(vint16mf2_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vreinterpret_v)))
vuint16mf4_t vreinterpret_v_i16mf4_u16mf4(vint16mf4_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vreinterpret_v)))
vuint32m1_t vreinterpret_v_i32m1_u32m1(vint32m1_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vreinterpret_v)))
vuint32m2_t vreinterpret_v_i32m2_u32m2(vint32m2_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vreinterpret_v)))
vuint32m4_t vreinterpret_v_i32m4_u32m4(vint32m4_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vreinterpret_v)))
vuint32m8_t vreinterpret_v_i32m8_u32m8(vint32m8_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vreinterpret_v)))
vuint32mf2_t vreinterpret_v_i32mf2_u32mf2(vint32mf2_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vsext_vf2)))
vint16mf4_t vsext_vf2_i16mf4(vint8mf8_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vsext_vf2_m)))
vint16mf4_t vsext_vf2_i16mf4_m(vbool64_t, vint16mf4_t, vint8mf8_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vsext_vf2)))
vint16mf2_t vsext_vf2_i16mf2(vint8mf4_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vsext_vf2_m)))
vint16mf2_t vsext_vf2_i16mf2_m(vbool32_t, vint16mf2_t, vint8mf4_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vsext_vf2)))
vint16m1_t vsext_vf2_i16m1(vint8mf2_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vsext_vf2_m)))
vint16m1_t vsext_vf2_i16m1_m(vbool16_t, vint16m1_t, vint8mf2_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vsext_vf2)))
vint16m2_t vsext_vf2_i16m2(vint8m1_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vsext_vf2_m)))
vint16m2_t vsext_vf2_i16m2_m(vbool8_t, vint16m2_t, vint8m1_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vsext_vf2)))
vint16m4_t vsext_vf2_i16m4(vint8m2_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vsext_vf2_m)))
vint16m4_t vsext_vf2_i16m4_m(vbool4_t, vint16m4_t, vint8m2_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vsext_vf2)))
vint16m8_t vsext_vf2_i16m8(vint8m4_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vsext_vf2_m)))
vint16m8_t vsext_vf2_i16m8_m(vbool2_t, vint16m8_t, vint8m4_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vsext_vf2)))
vint32mf2_t vsext_vf2_i32mf2(vint16mf4_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vsext_vf2_m)))
vint32mf2_t vsext_vf2_i32mf2_m(vbool64_t, vint32mf2_t, vint16mf4_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vsext_vf2)))
vint32m1_t vsext_vf2_i32m1(vint16mf2_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vsext_vf2_m)))
vint32m1_t vsext_vf2_i32m1_m(vbool32_t, vint32m1_t, vint16mf2_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vsext_vf2)))
vint32m2_t vsext_vf2_i32m2(vint16m1_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vsext_vf2_m)))
vint32m2_t vsext_vf2_i32m2_m(vbool16_t, vint32m2_t, vint16m1_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vsext_vf2)))
vint32m4_t vsext_vf2_i32m4(vint16m2_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vsext_vf2_m)))
vint32m4_t vsext_vf2_i32m4_m(vbool8_t, vint32m4_t, vint16m2_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vsext_vf2)))
vint32m8_t vsext_vf2_i32m8(vint16m4_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vsext_vf2_m)))
vint32m8_t vsext_vf2_i32m8_m(vbool4_t, vint32m8_t, vint16m4_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vsext_vf4)))
vint32mf2_t vsext_vf4_i32mf2(vint8mf8_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vsext_vf4_m)))
vint32mf2_t vsext_vf4_i32mf2_m(vbool64_t, vint32mf2_t, vint8mf8_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vsext_vf4)))
vint32m1_t vsext_vf4_i32m1(vint8mf4_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vsext_vf4_m)))
vint32m1_t vsext_vf4_i32m1_m(vbool32_t, vint32m1_t, vint8mf4_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vsext_vf4)))
vint32m2_t vsext_vf4_i32m2(vint8mf2_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vsext_vf4_m)))
vint32m2_t vsext_vf4_i32m2_m(vbool16_t, vint32m2_t, vint8mf2_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vsext_vf4)))
vint32m4_t vsext_vf4_i32m4(vint8m1_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vsext_vf4_m)))
vint32m4_t vsext_vf4_i32m4_m(vbool8_t, vint32m4_t, vint8m1_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vsext_vf4)))
vint32m8_t vsext_vf4_i32m8(vint8m2_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vsext_vf4_m)))
vint32m8_t vsext_vf4_i32m8_m(vbool4_t, vint32m8_t, vint8m2_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vsm_v)))
void vsm_v_b8(uint8_t *, vbool8_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vsm_v)))
void vsm_v_b4(uint8_t *, vbool4_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vsm_v)))
void vsm_v_b2(uint8_t *, vbool2_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vsm_v)))
void vsm_v_b1(uint8_t *, vbool1_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vsm_v)))
void vsm_v_b16(uint8_t *, vbool16_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vsm_v)))
void vsm_v_b32(uint8_t *, vbool32_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vsm_v)))
void vsm_v_b64(uint8_t *, vbool64_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vundefined)))
vint8m1_t vundefined_i8m1();
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vundefined)))
vint8m2_t vundefined_i8m2();
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vundefined)))
vint8m4_t vundefined_i8m4();
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vundefined)))
vint8m8_t vundefined_i8m8();
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vundefined)))
vint8mf2_t vundefined_i8mf2();
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vundefined)))
vint8mf4_t vundefined_i8mf4();
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vundefined)))
vint8mf8_t vundefined_i8mf8();
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vundefined)))
vint16m1_t vundefined_i16m1();
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vundefined)))
vint16m2_t vundefined_i16m2();
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vundefined)))
vint16m4_t vundefined_i16m4();
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vundefined)))
vint16m8_t vundefined_i16m8();
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vundefined)))
vint16mf2_t vundefined_i16mf2();
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vundefined)))
vint16mf4_t vundefined_i16mf4();
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vundefined)))
vint32m1_t vundefined_i32m1();
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vundefined)))
vint32m2_t vundefined_i32m2();
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vundefined)))
vint32m4_t vundefined_i32m4();
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vundefined)))
vint32m8_t vundefined_i32m8();
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vundefined)))
vint32mf2_t vundefined_i32mf2();
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vundefined)))
vuint8m1_t vundefined_u8m1();
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vundefined)))
vuint8m2_t vundefined_u8m2();
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vundefined)))
vuint8m4_t vundefined_u8m4();
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vundefined)))
vuint8m8_t vundefined_u8m8();
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vundefined)))
vuint8mf2_t vundefined_u8mf2();
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vundefined)))
vuint8mf4_t vundefined_u8mf4();
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vundefined)))
vuint8mf8_t vundefined_u8mf8();
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vundefined)))
vuint16m1_t vundefined_u16m1();
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vundefined)))
vuint16m2_t vundefined_u16m2();
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vundefined)))
vuint16m4_t vundefined_u16m4();
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vundefined)))
vuint16m8_t vundefined_u16m8();
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vundefined)))
vuint16mf2_t vundefined_u16mf2();
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vundefined)))
vuint16mf4_t vundefined_u16mf4();
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vundefined)))
vuint32m1_t vundefined_u32m1();
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vundefined)))
vuint32m2_t vundefined_u32m2();
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vundefined)))
vuint32m4_t vundefined_u32m4();
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vundefined)))
vuint32m8_t vundefined_u32m8();
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vundefined)))
vuint32mf2_t vundefined_u32mf2();
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vzext_vf2)))
vuint16mf4_t vzext_vf2_u16mf4(vuint8mf8_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vzext_vf2_m)))
vuint16mf4_t vzext_vf2_u16mf4_m(vbool64_t, vuint16mf4_t, vuint8mf8_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vzext_vf2)))
vuint16mf2_t vzext_vf2_u16mf2(vuint8mf4_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vzext_vf2_m)))
vuint16mf2_t vzext_vf2_u16mf2_m(vbool32_t, vuint16mf2_t, vuint8mf4_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vzext_vf2)))
vuint16m1_t vzext_vf2_u16m1(vuint8mf2_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vzext_vf2_m)))
vuint16m1_t vzext_vf2_u16m1_m(vbool16_t, vuint16m1_t, vuint8mf2_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vzext_vf2)))
vuint16m2_t vzext_vf2_u16m2(vuint8m1_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vzext_vf2_m)))
vuint16m2_t vzext_vf2_u16m2_m(vbool8_t, vuint16m2_t, vuint8m1_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vzext_vf2)))
vuint16m4_t vzext_vf2_u16m4(vuint8m2_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vzext_vf2_m)))
vuint16m4_t vzext_vf2_u16m4_m(vbool4_t, vuint16m4_t, vuint8m2_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vzext_vf2)))
vuint16m8_t vzext_vf2_u16m8(vuint8m4_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vzext_vf2_m)))
vuint16m8_t vzext_vf2_u16m8_m(vbool2_t, vuint16m8_t, vuint8m4_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vzext_vf2)))
vuint32mf2_t vzext_vf2_u32mf2(vuint16mf4_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vzext_vf2_m)))
vuint32mf2_t vzext_vf2_u32mf2_m(vbool64_t, vuint32mf2_t, vuint16mf4_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vzext_vf2)))
vuint32m1_t vzext_vf2_u32m1(vuint16mf2_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vzext_vf2_m)))
vuint32m1_t vzext_vf2_u32m1_m(vbool32_t, vuint32m1_t, vuint16mf2_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vzext_vf2)))
vuint32m2_t vzext_vf2_u32m2(vuint16m1_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vzext_vf2_m)))
vuint32m2_t vzext_vf2_u32m2_m(vbool16_t, vuint32m2_t, vuint16m1_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vzext_vf2)))
vuint32m4_t vzext_vf2_u32m4(vuint16m2_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vzext_vf2_m)))
vuint32m4_t vzext_vf2_u32m4_m(vbool8_t, vuint32m4_t, vuint16m2_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vzext_vf2)))
vuint32m8_t vzext_vf2_u32m8(vuint16m4_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vzext_vf2_m)))
vuint32m8_t vzext_vf2_u32m8_m(vbool4_t, vuint32m8_t, vuint16m4_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vzext_vf4)))
vuint32mf2_t vzext_vf4_u32mf2(vuint8mf8_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vzext_vf4_m)))
vuint32mf2_t vzext_vf4_u32mf2_m(vbool64_t, vuint32mf2_t, vuint8mf8_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vzext_vf4)))
vuint32m1_t vzext_vf4_u32m1(vuint8mf4_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vzext_vf4_m)))
vuint32m1_t vzext_vf4_u32m1_m(vbool32_t, vuint32m1_t, vuint8mf4_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vzext_vf4)))
vuint32m2_t vzext_vf4_u32m2(vuint8mf2_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vzext_vf4_m)))
vuint32m2_t vzext_vf4_u32m2_m(vbool16_t, vuint32m2_t, vuint8mf2_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vzext_vf4)))
vuint32m4_t vzext_vf4_u32m4(vuint8m1_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vzext_vf4_m)))
vuint32m4_t vzext_vf4_u32m4_m(vbool8_t, vuint32m4_t, vuint8m1_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vzext_vf4)))
vuint32m8_t vzext_vf4_u32m8(vuint8m2_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vzext_vf4_m)))
vuint32m8_t vzext_vf4_u32m8_m(vbool4_t, vuint32m8_t, vuint8m2_t, size_t);
#if defined(__riscv_zfh)
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vloxseg2ei8_v)))
void vloxseg2ei8_v_f16m1(vfloat16m1_t *, vfloat16m1_t *, const _Float16 *, vuint8mf2_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vloxseg2ei8_v_m)))
void vloxseg2ei8_v_f16m1_m(vfloat16m1_t *, vfloat16m1_t *, vbool16_t, vfloat16m1_t, vfloat16m1_t, const _Float16 *, vuint8mf2_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vloxseg2ei8_v)))
void vloxseg2ei8_v_f16m2(vfloat16m2_t *, vfloat16m2_t *, const _Float16 *, vuint8m1_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vloxseg2ei8_v_m)))
void vloxseg2ei8_v_f16m2_m(vfloat16m2_t *, vfloat16m2_t *, vbool8_t, vfloat16m2_t, vfloat16m2_t, const _Float16 *, vuint8m1_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vloxseg2ei8_v)))
void vloxseg2ei8_v_f16m4(vfloat16m4_t *, vfloat16m4_t *, const _Float16 *, vuint8m2_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vloxseg2ei8_v_m)))
void vloxseg2ei8_v_f16m4_m(vfloat16m4_t *, vfloat16m4_t *, vbool4_t, vfloat16m4_t, vfloat16m4_t, const _Float16 *, vuint8m2_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vloxseg2ei8_v)))
void vloxseg2ei8_v_f16mf2(vfloat16mf2_t *, vfloat16mf2_t *, const _Float16 *, vuint8mf4_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vloxseg2ei8_v_m)))
void vloxseg2ei8_v_f16mf2_m(vfloat16mf2_t *, vfloat16mf2_t *, vbool32_t, vfloat16mf2_t, vfloat16mf2_t, const _Float16 *, vuint8mf4_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vloxseg2ei8_v)))
void vloxseg2ei8_v_f16mf4(vfloat16mf4_t *, vfloat16mf4_t *, const _Float16 *, vuint8mf8_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vloxseg2ei8_v_m)))
void vloxseg2ei8_v_f16mf4_m(vfloat16mf4_t *, vfloat16mf4_t *, vbool64_t, vfloat16mf4_t, vfloat16mf4_t, const _Float16 *, vuint8mf8_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vloxseg3ei8_v)))
void vloxseg3ei8_v_f16m1(vfloat16m1_t *, vfloat16m1_t *, vfloat16m1_t *, const _Float16 *, vuint8mf2_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vloxseg3ei8_v_m)))
void vloxseg3ei8_v_f16m1_m(vfloat16m1_t *, vfloat16m1_t *, vfloat16m1_t *, vbool16_t, vfloat16m1_t, vfloat16m1_t, vfloat16m1_t, const _Float16 *, vuint8mf2_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vloxseg3ei8_v)))
void vloxseg3ei8_v_f16m2(vfloat16m2_t *, vfloat16m2_t *, vfloat16m2_t *, const _Float16 *, vuint8m1_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vloxseg3ei8_v_m)))
void vloxseg3ei8_v_f16m2_m(vfloat16m2_t *, vfloat16m2_t *, vfloat16m2_t *, vbool8_t, vfloat16m2_t, vfloat16m2_t, vfloat16m2_t, const _Float16 *, vuint8m1_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vloxseg3ei8_v)))
void vloxseg3ei8_v_f16mf2(vfloat16mf2_t *, vfloat16mf2_t *, vfloat16mf2_t *, const _Float16 *, vuint8mf4_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vloxseg3ei8_v_m)))
void vloxseg3ei8_v_f16mf2_m(vfloat16mf2_t *, vfloat16mf2_t *, vfloat16mf2_t *, vbool32_t, vfloat16mf2_t, vfloat16mf2_t, vfloat16mf2_t, const _Float16 *, vuint8mf4_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vloxseg3ei8_v)))
void vloxseg3ei8_v_f16mf4(vfloat16mf4_t *, vfloat16mf4_t *, vfloat16mf4_t *, const _Float16 *, vuint8mf8_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vloxseg3ei8_v_m)))
void vloxseg3ei8_v_f16mf4_m(vfloat16mf4_t *, vfloat16mf4_t *, vfloat16mf4_t *, vbool64_t, vfloat16mf4_t, vfloat16mf4_t, vfloat16mf4_t, const _Float16 *, vuint8mf8_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vloxseg4ei8_v)))
void vloxseg4ei8_v_f16m1(vfloat16m1_t *, vfloat16m1_t *, vfloat16m1_t *, vfloat16m1_t *, const _Float16 *, vuint8mf2_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vloxseg4ei8_v_m)))
void vloxseg4ei8_v_f16m1_m(vfloat16m1_t *, vfloat16m1_t *, vfloat16m1_t *, vfloat16m1_t *, vbool16_t, vfloat16m1_t, vfloat16m1_t, vfloat16m1_t, vfloat16m1_t, const _Float16 *, vuint8mf2_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vloxseg4ei8_v)))
void vloxseg4ei8_v_f16m2(vfloat16m2_t *, vfloat16m2_t *, vfloat16m2_t *, vfloat16m2_t *, const _Float16 *, vuint8m1_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vloxseg4ei8_v_m)))
void vloxseg4ei8_v_f16m2_m(vfloat16m2_t *, vfloat16m2_t *, vfloat16m2_t *, vfloat16m2_t *, vbool8_t, vfloat16m2_t, vfloat16m2_t, vfloat16m2_t, vfloat16m2_t, const _Float16 *, vuint8m1_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vloxseg4ei8_v)))
void vloxseg4ei8_v_f16mf2(vfloat16mf2_t *, vfloat16mf2_t *, vfloat16mf2_t *, vfloat16mf2_t *, const _Float16 *, vuint8mf4_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vloxseg4ei8_v_m)))
void vloxseg4ei8_v_f16mf2_m(vfloat16mf2_t *, vfloat16mf2_t *, vfloat16mf2_t *, vfloat16mf2_t *, vbool32_t, vfloat16mf2_t, vfloat16mf2_t, vfloat16mf2_t, vfloat16mf2_t, const _Float16 *, vuint8mf4_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vloxseg4ei8_v)))
void vloxseg4ei8_v_f16mf4(vfloat16mf4_t *, vfloat16mf4_t *, vfloat16mf4_t *, vfloat16mf4_t *, const _Float16 *, vuint8mf8_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vloxseg4ei8_v_m)))
void vloxseg4ei8_v_f16mf4_m(vfloat16mf4_t *, vfloat16mf4_t *, vfloat16mf4_t *, vfloat16mf4_t *, vbool64_t, vfloat16mf4_t, vfloat16mf4_t, vfloat16mf4_t, vfloat16mf4_t, const _Float16 *, vuint8mf8_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vloxseg5ei8_v)))
void vloxseg5ei8_v_f16m1(vfloat16m1_t *, vfloat16m1_t *, vfloat16m1_t *, vfloat16m1_t *, vfloat16m1_t *, const _Float16 *, vuint8mf2_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vloxseg5ei8_v_m)))
void vloxseg5ei8_v_f16m1_m(vfloat16m1_t *, vfloat16m1_t *, vfloat16m1_t *, vfloat16m1_t *, vfloat16m1_t *, vbool16_t, vfloat16m1_t, vfloat16m1_t, vfloat16m1_t, vfloat16m1_t, vfloat16m1_t, const _Float16 *, vuint8mf2_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vloxseg5ei8_v)))
void vloxseg5ei8_v_f16mf2(vfloat16mf2_t *, vfloat16mf2_t *, vfloat16mf2_t *, vfloat16mf2_t *, vfloat16mf2_t *, const _Float16 *, vuint8mf4_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vloxseg5ei8_v_m)))
void vloxseg5ei8_v_f16mf2_m(vfloat16mf2_t *, vfloat16mf2_t *, vfloat16mf2_t *, vfloat16mf2_t *, vfloat16mf2_t *, vbool32_t, vfloat16mf2_t, vfloat16mf2_t, vfloat16mf2_t, vfloat16mf2_t, vfloat16mf2_t, const _Float16 *, vuint8mf4_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vloxseg5ei8_v)))
void vloxseg5ei8_v_f16mf4(vfloat16mf4_t *, vfloat16mf4_t *, vfloat16mf4_t *, vfloat16mf4_t *, vfloat16mf4_t *, const _Float16 *, vuint8mf8_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vloxseg5ei8_v_m)))
void vloxseg5ei8_v_f16mf4_m(vfloat16mf4_t *, vfloat16mf4_t *, vfloat16mf4_t *, vfloat16mf4_t *, vfloat16mf4_t *, vbool64_t, vfloat16mf4_t, vfloat16mf4_t, vfloat16mf4_t, vfloat16mf4_t, vfloat16mf4_t, const _Float16 *, vuint8mf8_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vloxseg6ei8_v)))
void vloxseg6ei8_v_f16m1(vfloat16m1_t *, vfloat16m1_t *, vfloat16m1_t *, vfloat16m1_t *, vfloat16m1_t *, vfloat16m1_t *, const _Float16 *, vuint8mf2_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vloxseg6ei8_v_m)))
void vloxseg6ei8_v_f16m1_m(vfloat16m1_t *, vfloat16m1_t *, vfloat16m1_t *, vfloat16m1_t *, vfloat16m1_t *, vfloat16m1_t *, vbool16_t, vfloat16m1_t, vfloat16m1_t, vfloat16m1_t, vfloat16m1_t, vfloat16m1_t, vfloat16m1_t, const _Float16 *, vuint8mf2_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vloxseg6ei8_v)))
void vloxseg6ei8_v_f16mf2(vfloat16mf2_t *, vfloat16mf2_t *, vfloat16mf2_t *, vfloat16mf2_t *, vfloat16mf2_t *, vfloat16mf2_t *, const _Float16 *, vuint8mf4_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vloxseg6ei8_v_m)))
void vloxseg6ei8_v_f16mf2_m(vfloat16mf2_t *, vfloat16mf2_t *, vfloat16mf2_t *, vfloat16mf2_t *, vfloat16mf2_t *, vfloat16mf2_t *, vbool32_t, vfloat16mf2_t, vfloat16mf2_t, vfloat16mf2_t, vfloat16mf2_t, vfloat16mf2_t, vfloat16mf2_t, const _Float16 *, vuint8mf4_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vloxseg6ei8_v)))
void vloxseg6ei8_v_f16mf4(vfloat16mf4_t *, vfloat16mf4_t *, vfloat16mf4_t *, vfloat16mf4_t *, vfloat16mf4_t *, vfloat16mf4_t *, const _Float16 *, vuint8mf8_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vloxseg6ei8_v_m)))
void vloxseg6ei8_v_f16mf4_m(vfloat16mf4_t *, vfloat16mf4_t *, vfloat16mf4_t *, vfloat16mf4_t *, vfloat16mf4_t *, vfloat16mf4_t *, vbool64_t, vfloat16mf4_t, vfloat16mf4_t, vfloat16mf4_t, vfloat16mf4_t, vfloat16mf4_t, vfloat16mf4_t, const _Float16 *, vuint8mf8_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vloxseg7ei8_v)))
void vloxseg7ei8_v_f16m1(vfloat16m1_t *, vfloat16m1_t *, vfloat16m1_t *, vfloat16m1_t *, vfloat16m1_t *, vfloat16m1_t *, vfloat16m1_t *, const _Float16 *, vuint8mf2_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vloxseg7ei8_v_m)))
void vloxseg7ei8_v_f16m1_m(vfloat16m1_t *, vfloat16m1_t *, vfloat16m1_t *, vfloat16m1_t *, vfloat16m1_t *, vfloat16m1_t *, vfloat16m1_t *, vbool16_t, vfloat16m1_t, vfloat16m1_t, vfloat16m1_t, vfloat16m1_t, vfloat16m1_t, vfloat16m1_t, vfloat16m1_t, const _Float16 *, vuint8mf2_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vloxseg7ei8_v)))
void vloxseg7ei8_v_f16mf2(vfloat16mf2_t *, vfloat16mf2_t *, vfloat16mf2_t *, vfloat16mf2_t *, vfloat16mf2_t *, vfloat16mf2_t *, vfloat16mf2_t *, const _Float16 *, vuint8mf4_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vloxseg7ei8_v_m)))
void vloxseg7ei8_v_f16mf2_m(vfloat16mf2_t *, vfloat16mf2_t *, vfloat16mf2_t *, vfloat16mf2_t *, vfloat16mf2_t *, vfloat16mf2_t *, vfloat16mf2_t *, vbool32_t, vfloat16mf2_t, vfloat16mf2_t, vfloat16mf2_t, vfloat16mf2_t, vfloat16mf2_t, vfloat16mf2_t, vfloat16mf2_t, const _Float16 *, vuint8mf4_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vloxseg7ei8_v)))
void vloxseg7ei8_v_f16mf4(vfloat16mf4_t *, vfloat16mf4_t *, vfloat16mf4_t *, vfloat16mf4_t *, vfloat16mf4_t *, vfloat16mf4_t *, vfloat16mf4_t *, const _Float16 *, vuint8mf8_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vloxseg7ei8_v_m)))
void vloxseg7ei8_v_f16mf4_m(vfloat16mf4_t *, vfloat16mf4_t *, vfloat16mf4_t *, vfloat16mf4_t *, vfloat16mf4_t *, vfloat16mf4_t *, vfloat16mf4_t *, vbool64_t, vfloat16mf4_t, vfloat16mf4_t, vfloat16mf4_t, vfloat16mf4_t, vfloat16mf4_t, vfloat16mf4_t, vfloat16mf4_t, const _Float16 *, vuint8mf8_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vsse16_v)))
void vsse16_v_f16m1(_Float16 *, ptrdiff_t, vfloat16m1_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vsse16_v_m)))
void vsse16_v_f16m1_m(vbool16_t, _Float16 *, ptrdiff_t, vfloat16m1_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vsse16_v)))
void vsse16_v_f16m2(_Float16 *, ptrdiff_t, vfloat16m2_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vsse16_v_m)))
void vsse16_v_f16m2_m(vbool8_t, _Float16 *, ptrdiff_t, vfloat16m2_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vsse16_v)))
void vsse16_v_f16m4(_Float16 *, ptrdiff_t, vfloat16m4_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vsse16_v_m)))
void vsse16_v_f16m4_m(vbool4_t, _Float16 *, ptrdiff_t, vfloat16m4_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vsse16_v)))
void vsse16_v_f16m8(_Float16 *, ptrdiff_t, vfloat16m8_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vsse16_v_m)))
void vsse16_v_f16m8_m(vbool2_t, _Float16 *, ptrdiff_t, vfloat16m8_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vsse16_v)))
void vsse16_v_f16mf2(_Float16 *, ptrdiff_t, vfloat16mf2_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vsse16_v_m)))
void vsse16_v_f16mf2_m(vbool32_t, _Float16 *, ptrdiff_t, vfloat16mf2_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vsse16_v)))
void vsse16_v_f16mf4(_Float16 *, ptrdiff_t, vfloat16mf4_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vsse16_v_m)))
void vsse16_v_f16mf4_m(vbool64_t, _Float16 *, ptrdiff_t, vfloat16mf4_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vloxseg8ei8_v)))
void vloxseg8ei8_v_f16m1(vfloat16m1_t *, vfloat16m1_t *, vfloat16m1_t *, vfloat16m1_t *, vfloat16m1_t *, vfloat16m1_t *, vfloat16m1_t *, vfloat16m1_t *, const _Float16 *, vuint8mf2_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vloxseg8ei8_v_m)))
void vloxseg8ei8_v_f16m1_m(vfloat16m1_t *, vfloat16m1_t *, vfloat16m1_t *, vfloat16m1_t *, vfloat16m1_t *, vfloat16m1_t *, vfloat16m1_t *, vfloat16m1_t *, vbool16_t, vfloat16m1_t, vfloat16m1_t, vfloat16m1_t, vfloat16m1_t, vfloat16m1_t, vfloat16m1_t, vfloat16m1_t, vfloat16m1_t, const _Float16 *, vuint8mf2_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vloxseg8ei8_v)))
void vloxseg8ei8_v_f16mf2(vfloat16mf2_t *, vfloat16mf2_t *, vfloat16mf2_t *, vfloat16mf2_t *, vfloat16mf2_t *, vfloat16mf2_t *, vfloat16mf2_t *, vfloat16mf2_t *, const _Float16 *, vuint8mf4_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vloxseg8ei8_v_m)))
void vloxseg8ei8_v_f16mf2_m(vfloat16mf2_t *, vfloat16mf2_t *, vfloat16mf2_t *, vfloat16mf2_t *, vfloat16mf2_t *, vfloat16mf2_t *, vfloat16mf2_t *, vfloat16mf2_t *, vbool32_t, vfloat16mf2_t, vfloat16mf2_t, vfloat16mf2_t, vfloat16mf2_t, vfloat16mf2_t, vfloat16mf2_t, vfloat16mf2_t, vfloat16mf2_t, const _Float16 *, vuint8mf4_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vloxseg8ei8_v)))
void vloxseg8ei8_v_f16mf4(vfloat16mf4_t *, vfloat16mf4_t *, vfloat16mf4_t *, vfloat16mf4_t *, vfloat16mf4_t *, vfloat16mf4_t *, vfloat16mf4_t *, vfloat16mf4_t *, const _Float16 *, vuint8mf8_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vloxseg8ei8_v_m)))
void vloxseg8ei8_v_f16mf4_m(vfloat16mf4_t *, vfloat16mf4_t *, vfloat16mf4_t *, vfloat16mf4_t *, vfloat16mf4_t *, vfloat16mf4_t *, vfloat16mf4_t *, vfloat16mf4_t *, vbool64_t, vfloat16mf4_t, vfloat16mf4_t, vfloat16mf4_t, vfloat16mf4_t, vfloat16mf4_t, vfloat16mf4_t, vfloat16mf4_t, vfloat16mf4_t, const _Float16 *, vuint8mf8_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vloxseg2ei16_v)))
void vloxseg2ei16_v_f16m1(vfloat16m1_t *, vfloat16m1_t *, const _Float16 *, vuint16m1_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vloxseg2ei16_v_m)))
void vloxseg2ei16_v_f16m1_m(vfloat16m1_t *, vfloat16m1_t *, vbool16_t, vfloat16m1_t, vfloat16m1_t, const _Float16 *, vuint16m1_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vloxseg2ei16_v)))
void vloxseg2ei16_v_f16m2(vfloat16m2_t *, vfloat16m2_t *, const _Float16 *, vuint16m2_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vloxseg2ei16_v_m)))
void vloxseg2ei16_v_f16m2_m(vfloat16m2_t *, vfloat16m2_t *, vbool8_t, vfloat16m2_t, vfloat16m2_t, const _Float16 *, vuint16m2_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vloxseg2ei16_v)))
void vloxseg2ei16_v_f16m4(vfloat16m4_t *, vfloat16m4_t *, const _Float16 *, vuint16m4_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vloxseg2ei16_v_m)))
void vloxseg2ei16_v_f16m4_m(vfloat16m4_t *, vfloat16m4_t *, vbool4_t, vfloat16m4_t, vfloat16m4_t, const _Float16 *, vuint16m4_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vloxseg2ei16_v)))
void vloxseg2ei16_v_f16mf2(vfloat16mf2_t *, vfloat16mf2_t *, const _Float16 *, vuint16mf2_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vloxseg2ei16_v_m)))
void vloxseg2ei16_v_f16mf2_m(vfloat16mf2_t *, vfloat16mf2_t *, vbool32_t, vfloat16mf2_t, vfloat16mf2_t, const _Float16 *, vuint16mf2_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vloxseg2ei16_v)))
void vloxseg2ei16_v_f16mf4(vfloat16mf4_t *, vfloat16mf4_t *, const _Float16 *, vuint16mf4_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vloxseg2ei16_v_m)))
void vloxseg2ei16_v_f16mf4_m(vfloat16mf4_t *, vfloat16mf4_t *, vbool64_t, vfloat16mf4_t, vfloat16mf4_t, const _Float16 *, vuint16mf4_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vloxseg3ei16_v)))
void vloxseg3ei16_v_f16m1(vfloat16m1_t *, vfloat16m1_t *, vfloat16m1_t *, const _Float16 *, vuint16m1_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vloxseg3ei16_v_m)))
void vloxseg3ei16_v_f16m1_m(vfloat16m1_t *, vfloat16m1_t *, vfloat16m1_t *, vbool16_t, vfloat16m1_t, vfloat16m1_t, vfloat16m1_t, const _Float16 *, vuint16m1_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vloxseg3ei16_v)))
void vloxseg3ei16_v_f16m2(vfloat16m2_t *, vfloat16m2_t *, vfloat16m2_t *, const _Float16 *, vuint16m2_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vloxseg3ei16_v_m)))
void vloxseg3ei16_v_f16m2_m(vfloat16m2_t *, vfloat16m2_t *, vfloat16m2_t *, vbool8_t, vfloat16m2_t, vfloat16m2_t, vfloat16m2_t, const _Float16 *, vuint16m2_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vloxseg3ei16_v)))
void vloxseg3ei16_v_f16mf2(vfloat16mf2_t *, vfloat16mf2_t *, vfloat16mf2_t *, const _Float16 *, vuint16mf2_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vloxseg3ei16_v_m)))
void vloxseg3ei16_v_f16mf2_m(vfloat16mf2_t *, vfloat16mf2_t *, vfloat16mf2_t *, vbool32_t, vfloat16mf2_t, vfloat16mf2_t, vfloat16mf2_t, const _Float16 *, vuint16mf2_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vloxseg3ei16_v)))
void vloxseg3ei16_v_f16mf4(vfloat16mf4_t *, vfloat16mf4_t *, vfloat16mf4_t *, const _Float16 *, vuint16mf4_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vloxseg3ei16_v_m)))
void vloxseg3ei16_v_f16mf4_m(vfloat16mf4_t *, vfloat16mf4_t *, vfloat16mf4_t *, vbool64_t, vfloat16mf4_t, vfloat16mf4_t, vfloat16mf4_t, const _Float16 *, vuint16mf4_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vloxseg4ei16_v)))
void vloxseg4ei16_v_f16m1(vfloat16m1_t *, vfloat16m1_t *, vfloat16m1_t *, vfloat16m1_t *, const _Float16 *, vuint16m1_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vloxseg4ei16_v_m)))
void vloxseg4ei16_v_f16m1_m(vfloat16m1_t *, vfloat16m1_t *, vfloat16m1_t *, vfloat16m1_t *, vbool16_t, vfloat16m1_t, vfloat16m1_t, vfloat16m1_t, vfloat16m1_t, const _Float16 *, vuint16m1_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vloxseg4ei16_v)))
void vloxseg4ei16_v_f16m2(vfloat16m2_t *, vfloat16m2_t *, vfloat16m2_t *, vfloat16m2_t *, const _Float16 *, vuint16m2_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vloxseg4ei16_v_m)))
void vloxseg4ei16_v_f16m2_m(vfloat16m2_t *, vfloat16m2_t *, vfloat16m2_t *, vfloat16m2_t *, vbool8_t, vfloat16m2_t, vfloat16m2_t, vfloat16m2_t, vfloat16m2_t, const _Float16 *, vuint16m2_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vloxseg4ei16_v)))
void vloxseg4ei16_v_f16mf2(vfloat16mf2_t *, vfloat16mf2_t *, vfloat16mf2_t *, vfloat16mf2_t *, const _Float16 *, vuint16mf2_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vloxseg4ei16_v_m)))
void vloxseg4ei16_v_f16mf2_m(vfloat16mf2_t *, vfloat16mf2_t *, vfloat16mf2_t *, vfloat16mf2_t *, vbool32_t, vfloat16mf2_t, vfloat16mf2_t, vfloat16mf2_t, vfloat16mf2_t, const _Float16 *, vuint16mf2_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vloxseg4ei16_v)))
void vloxseg4ei16_v_f16mf4(vfloat16mf4_t *, vfloat16mf4_t *, vfloat16mf4_t *, vfloat16mf4_t *, const _Float16 *, vuint16mf4_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vloxseg4ei16_v_m)))
void vloxseg4ei16_v_f16mf4_m(vfloat16mf4_t *, vfloat16mf4_t *, vfloat16mf4_t *, vfloat16mf4_t *, vbool64_t, vfloat16mf4_t, vfloat16mf4_t, vfloat16mf4_t, vfloat16mf4_t, const _Float16 *, vuint16mf4_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vloxseg5ei16_v)))
void vloxseg5ei16_v_f16m1(vfloat16m1_t *, vfloat16m1_t *, vfloat16m1_t *, vfloat16m1_t *, vfloat16m1_t *, const _Float16 *, vuint16m1_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vloxseg5ei16_v_m)))
void vloxseg5ei16_v_f16m1_m(vfloat16m1_t *, vfloat16m1_t *, vfloat16m1_t *, vfloat16m1_t *, vfloat16m1_t *, vbool16_t, vfloat16m1_t, vfloat16m1_t, vfloat16m1_t, vfloat16m1_t, vfloat16m1_t, const _Float16 *, vuint16m1_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vloxseg5ei16_v)))
void vloxseg5ei16_v_f16mf2(vfloat16mf2_t *, vfloat16mf2_t *, vfloat16mf2_t *, vfloat16mf2_t *, vfloat16mf2_t *, const _Float16 *, vuint16mf2_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vloxseg5ei16_v_m)))
void vloxseg5ei16_v_f16mf2_m(vfloat16mf2_t *, vfloat16mf2_t *, vfloat16mf2_t *, vfloat16mf2_t *, vfloat16mf2_t *, vbool32_t, vfloat16mf2_t, vfloat16mf2_t, vfloat16mf2_t, vfloat16mf2_t, vfloat16mf2_t, const _Float16 *, vuint16mf2_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vloxseg5ei16_v)))
void vloxseg5ei16_v_f16mf4(vfloat16mf4_t *, vfloat16mf4_t *, vfloat16mf4_t *, vfloat16mf4_t *, vfloat16mf4_t *, const _Float16 *, vuint16mf4_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vloxseg5ei16_v_m)))
void vloxseg5ei16_v_f16mf4_m(vfloat16mf4_t *, vfloat16mf4_t *, vfloat16mf4_t *, vfloat16mf4_t *, vfloat16mf4_t *, vbool64_t, vfloat16mf4_t, vfloat16mf4_t, vfloat16mf4_t, vfloat16mf4_t, vfloat16mf4_t, const _Float16 *, vuint16mf4_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vloxseg6ei16_v)))
void vloxseg6ei16_v_f16m1(vfloat16m1_t *, vfloat16m1_t *, vfloat16m1_t *, vfloat16m1_t *, vfloat16m1_t *, vfloat16m1_t *, const _Float16 *, vuint16m1_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vloxseg6ei16_v_m)))
void vloxseg6ei16_v_f16m1_m(vfloat16m1_t *, vfloat16m1_t *, vfloat16m1_t *, vfloat16m1_t *, vfloat16m1_t *, vfloat16m1_t *, vbool16_t, vfloat16m1_t, vfloat16m1_t, vfloat16m1_t, vfloat16m1_t, vfloat16m1_t, vfloat16m1_t, const _Float16 *, vuint16m1_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vloxseg6ei16_v)))
void vloxseg6ei16_v_f16mf2(vfloat16mf2_t *, vfloat16mf2_t *, vfloat16mf2_t *, vfloat16mf2_t *, vfloat16mf2_t *, vfloat16mf2_t *, const _Float16 *, vuint16mf2_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vloxseg6ei16_v_m)))
void vloxseg6ei16_v_f16mf2_m(vfloat16mf2_t *, vfloat16mf2_t *, vfloat16mf2_t *, vfloat16mf2_t *, vfloat16mf2_t *, vfloat16mf2_t *, vbool32_t, vfloat16mf2_t, vfloat16mf2_t, vfloat16mf2_t, vfloat16mf2_t, vfloat16mf2_t, vfloat16mf2_t, const _Float16 *, vuint16mf2_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vloxseg6ei16_v)))
void vloxseg6ei16_v_f16mf4(vfloat16mf4_t *, vfloat16mf4_t *, vfloat16mf4_t *, vfloat16mf4_t *, vfloat16mf4_t *, vfloat16mf4_t *, const _Float16 *, vuint16mf4_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vloxseg6ei16_v_m)))
void vloxseg6ei16_v_f16mf4_m(vfloat16mf4_t *, vfloat16mf4_t *, vfloat16mf4_t *, vfloat16mf4_t *, vfloat16mf4_t *, vfloat16mf4_t *, vbool64_t, vfloat16mf4_t, vfloat16mf4_t, vfloat16mf4_t, vfloat16mf4_t, vfloat16mf4_t, vfloat16mf4_t, const _Float16 *, vuint16mf4_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vloxseg7ei16_v)))
void vloxseg7ei16_v_f16m1(vfloat16m1_t *, vfloat16m1_t *, vfloat16m1_t *, vfloat16m1_t *, vfloat16m1_t *, vfloat16m1_t *, vfloat16m1_t *, const _Float16 *, vuint16m1_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vloxseg7ei16_v_m)))
void vloxseg7ei16_v_f16m1_m(vfloat16m1_t *, vfloat16m1_t *, vfloat16m1_t *, vfloat16m1_t *, vfloat16m1_t *, vfloat16m1_t *, vfloat16m1_t *, vbool16_t, vfloat16m1_t, vfloat16m1_t, vfloat16m1_t, vfloat16m1_t, vfloat16m1_t, vfloat16m1_t, vfloat16m1_t, const _Float16 *, vuint16m1_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vloxseg7ei16_v)))
void vloxseg7ei16_v_f16mf2(vfloat16mf2_t *, vfloat16mf2_t *, vfloat16mf2_t *, vfloat16mf2_t *, vfloat16mf2_t *, vfloat16mf2_t *, vfloat16mf2_t *, const _Float16 *, vuint16mf2_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vloxseg7ei16_v_m)))
void vloxseg7ei16_v_f16mf2_m(vfloat16mf2_t *, vfloat16mf2_t *, vfloat16mf2_t *, vfloat16mf2_t *, vfloat16mf2_t *, vfloat16mf2_t *, vfloat16mf2_t *, vbool32_t, vfloat16mf2_t, vfloat16mf2_t, vfloat16mf2_t, vfloat16mf2_t, vfloat16mf2_t, vfloat16mf2_t, vfloat16mf2_t, const _Float16 *, vuint16mf2_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vloxseg7ei16_v)))
void vloxseg7ei16_v_f16mf4(vfloat16mf4_t *, vfloat16mf4_t *, vfloat16mf4_t *, vfloat16mf4_t *, vfloat16mf4_t *, vfloat16mf4_t *, vfloat16mf4_t *, const _Float16 *, vuint16mf4_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vloxseg7ei16_v_m)))
void vloxseg7ei16_v_f16mf4_m(vfloat16mf4_t *, vfloat16mf4_t *, vfloat16mf4_t *, vfloat16mf4_t *, vfloat16mf4_t *, vfloat16mf4_t *, vfloat16mf4_t *, vbool64_t, vfloat16mf4_t, vfloat16mf4_t, vfloat16mf4_t, vfloat16mf4_t, vfloat16mf4_t, vfloat16mf4_t, vfloat16mf4_t, const _Float16 *, vuint16mf4_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vloxseg8ei16_v)))
void vloxseg8ei16_v_f16m1(vfloat16m1_t *, vfloat16m1_t *, vfloat16m1_t *, vfloat16m1_t *, vfloat16m1_t *, vfloat16m1_t *, vfloat16m1_t *, vfloat16m1_t *, const _Float16 *, vuint16m1_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vloxseg8ei16_v_m)))
void vloxseg8ei16_v_f16m1_m(vfloat16m1_t *, vfloat16m1_t *, vfloat16m1_t *, vfloat16m1_t *, vfloat16m1_t *, vfloat16m1_t *, vfloat16m1_t *, vfloat16m1_t *, vbool16_t, vfloat16m1_t, vfloat16m1_t, vfloat16m1_t, vfloat16m1_t, vfloat16m1_t, vfloat16m1_t, vfloat16m1_t, vfloat16m1_t, const _Float16 *, vuint16m1_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vloxseg8ei16_v)))
void vloxseg8ei16_v_f16mf2(vfloat16mf2_t *, vfloat16mf2_t *, vfloat16mf2_t *, vfloat16mf2_t *, vfloat16mf2_t *, vfloat16mf2_t *, vfloat16mf2_t *, vfloat16mf2_t *, const _Float16 *, vuint16mf2_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vloxseg8ei16_v_m)))
void vloxseg8ei16_v_f16mf2_m(vfloat16mf2_t *, vfloat16mf2_t *, vfloat16mf2_t *, vfloat16mf2_t *, vfloat16mf2_t *, vfloat16mf2_t *, vfloat16mf2_t *, vfloat16mf2_t *, vbool32_t, vfloat16mf2_t, vfloat16mf2_t, vfloat16mf2_t, vfloat16mf2_t, vfloat16mf2_t, vfloat16mf2_t, vfloat16mf2_t, vfloat16mf2_t, const _Float16 *, vuint16mf2_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vloxseg8ei16_v)))
void vloxseg8ei16_v_f16mf4(vfloat16mf4_t *, vfloat16mf4_t *, vfloat16mf4_t *, vfloat16mf4_t *, vfloat16mf4_t *, vfloat16mf4_t *, vfloat16mf4_t *, vfloat16mf4_t *, const _Float16 *, vuint16mf4_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vloxseg8ei16_v_m)))
void vloxseg8ei16_v_f16mf4_m(vfloat16mf4_t *, vfloat16mf4_t *, vfloat16mf4_t *, vfloat16mf4_t *, vfloat16mf4_t *, vfloat16mf4_t *, vfloat16mf4_t *, vfloat16mf4_t *, vbool64_t, vfloat16mf4_t, vfloat16mf4_t, vfloat16mf4_t, vfloat16mf4_t, vfloat16mf4_t, vfloat16mf4_t, vfloat16mf4_t, vfloat16mf4_t, const _Float16 *, vuint16mf4_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vloxseg2ei32_v)))
void vloxseg2ei32_v_f16m1(vfloat16m1_t *, vfloat16m1_t *, const _Float16 *, vuint32m2_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vloxseg2ei32_v_m)))
void vloxseg2ei32_v_f16m1_m(vfloat16m1_t *, vfloat16m1_t *, vbool16_t, vfloat16m1_t, vfloat16m1_t, const _Float16 *, vuint32m2_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vloxseg2ei32_v)))
void vloxseg2ei32_v_f16m2(vfloat16m2_t *, vfloat16m2_t *, const _Float16 *, vuint32m4_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vloxseg2ei32_v_m)))
void vloxseg2ei32_v_f16m2_m(vfloat16m2_t *, vfloat16m2_t *, vbool8_t, vfloat16m2_t, vfloat16m2_t, const _Float16 *, vuint32m4_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vloxseg2ei32_v)))
void vloxseg2ei32_v_f16m4(vfloat16m4_t *, vfloat16m4_t *, const _Float16 *, vuint32m8_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vloxseg2ei32_v_m)))
void vloxseg2ei32_v_f16m4_m(vfloat16m4_t *, vfloat16m4_t *, vbool4_t, vfloat16m4_t, vfloat16m4_t, const _Float16 *, vuint32m8_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vloxseg2ei32_v)))
void vloxseg2ei32_v_f16mf2(vfloat16mf2_t *, vfloat16mf2_t *, const _Float16 *, vuint32m1_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vloxseg2ei32_v_m)))
void vloxseg2ei32_v_f16mf2_m(vfloat16mf2_t *, vfloat16mf2_t *, vbool32_t, vfloat16mf2_t, vfloat16mf2_t, const _Float16 *, vuint32m1_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vloxseg2ei32_v)))
void vloxseg2ei32_v_f16mf4(vfloat16mf4_t *, vfloat16mf4_t *, const _Float16 *, vuint32mf2_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vloxseg2ei32_v_m)))
void vloxseg2ei32_v_f16mf4_m(vfloat16mf4_t *, vfloat16mf4_t *, vbool64_t, vfloat16mf4_t, vfloat16mf4_t, const _Float16 *, vuint32mf2_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vloxseg3ei32_v)))
void vloxseg3ei32_v_f16m1(vfloat16m1_t *, vfloat16m1_t *, vfloat16m1_t *, const _Float16 *, vuint32m2_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vloxseg3ei32_v_m)))
void vloxseg3ei32_v_f16m1_m(vfloat16m1_t *, vfloat16m1_t *, vfloat16m1_t *, vbool16_t, vfloat16m1_t, vfloat16m1_t, vfloat16m1_t, const _Float16 *, vuint32m2_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vloxseg3ei32_v)))
void vloxseg3ei32_v_f16m2(vfloat16m2_t *, vfloat16m2_t *, vfloat16m2_t *, const _Float16 *, vuint32m4_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vloxseg3ei32_v_m)))
void vloxseg3ei32_v_f16m2_m(vfloat16m2_t *, vfloat16m2_t *, vfloat16m2_t *, vbool8_t, vfloat16m2_t, vfloat16m2_t, vfloat16m2_t, const _Float16 *, vuint32m4_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vloxseg3ei32_v)))
void vloxseg3ei32_v_f16mf2(vfloat16mf2_t *, vfloat16mf2_t *, vfloat16mf2_t *, const _Float16 *, vuint32m1_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vloxseg3ei32_v_m)))
void vloxseg3ei32_v_f16mf2_m(vfloat16mf2_t *, vfloat16mf2_t *, vfloat16mf2_t *, vbool32_t, vfloat16mf2_t, vfloat16mf2_t, vfloat16mf2_t, const _Float16 *, vuint32m1_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vloxseg3ei32_v)))
void vloxseg3ei32_v_f16mf4(vfloat16mf4_t *, vfloat16mf4_t *, vfloat16mf4_t *, const _Float16 *, vuint32mf2_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vloxseg3ei32_v_m)))
void vloxseg3ei32_v_f16mf4_m(vfloat16mf4_t *, vfloat16mf4_t *, vfloat16mf4_t *, vbool64_t, vfloat16mf4_t, vfloat16mf4_t, vfloat16mf4_t, const _Float16 *, vuint32mf2_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vloxseg4ei32_v)))
void vloxseg4ei32_v_f16m1(vfloat16m1_t *, vfloat16m1_t *, vfloat16m1_t *, vfloat16m1_t *, const _Float16 *, vuint32m2_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vloxseg4ei32_v_m)))
void vloxseg4ei32_v_f16m1_m(vfloat16m1_t *, vfloat16m1_t *, vfloat16m1_t *, vfloat16m1_t *, vbool16_t, vfloat16m1_t, vfloat16m1_t, vfloat16m1_t, vfloat16m1_t, const _Float16 *, vuint32m2_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vloxseg4ei32_v)))
void vloxseg4ei32_v_f16m2(vfloat16m2_t *, vfloat16m2_t *, vfloat16m2_t *, vfloat16m2_t *, const _Float16 *, vuint32m4_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vloxseg4ei32_v_m)))
void vloxseg4ei32_v_f16m2_m(vfloat16m2_t *, vfloat16m2_t *, vfloat16m2_t *, vfloat16m2_t *, vbool8_t, vfloat16m2_t, vfloat16m2_t, vfloat16m2_t, vfloat16m2_t, const _Float16 *, vuint32m4_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vloxseg4ei32_v)))
void vloxseg4ei32_v_f16mf2(vfloat16mf2_t *, vfloat16mf2_t *, vfloat16mf2_t *, vfloat16mf2_t *, const _Float16 *, vuint32m1_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vloxseg4ei32_v_m)))
void vloxseg4ei32_v_f16mf2_m(vfloat16mf2_t *, vfloat16mf2_t *, vfloat16mf2_t *, vfloat16mf2_t *, vbool32_t, vfloat16mf2_t, vfloat16mf2_t, vfloat16mf2_t, vfloat16mf2_t, const _Float16 *, vuint32m1_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vloxseg4ei32_v)))
void vloxseg4ei32_v_f16mf4(vfloat16mf4_t *, vfloat16mf4_t *, vfloat16mf4_t *, vfloat16mf4_t *, const _Float16 *, vuint32mf2_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vloxseg4ei32_v_m)))
void vloxseg4ei32_v_f16mf4_m(vfloat16mf4_t *, vfloat16mf4_t *, vfloat16mf4_t *, vfloat16mf4_t *, vbool64_t, vfloat16mf4_t, vfloat16mf4_t, vfloat16mf4_t, vfloat16mf4_t, const _Float16 *, vuint32mf2_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vloxseg5ei32_v)))
void vloxseg5ei32_v_f16m1(vfloat16m1_t *, vfloat16m1_t *, vfloat16m1_t *, vfloat16m1_t *, vfloat16m1_t *, const _Float16 *, vuint32m2_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vloxseg5ei32_v_m)))
void vloxseg5ei32_v_f16m1_m(vfloat16m1_t *, vfloat16m1_t *, vfloat16m1_t *, vfloat16m1_t *, vfloat16m1_t *, vbool16_t, vfloat16m1_t, vfloat16m1_t, vfloat16m1_t, vfloat16m1_t, vfloat16m1_t, const _Float16 *, vuint32m2_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vloxseg5ei32_v)))
void vloxseg5ei32_v_f16mf2(vfloat16mf2_t *, vfloat16mf2_t *, vfloat16mf2_t *, vfloat16mf2_t *, vfloat16mf2_t *, const _Float16 *, vuint32m1_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vloxseg5ei32_v_m)))
void vloxseg5ei32_v_f16mf2_m(vfloat16mf2_t *, vfloat16mf2_t *, vfloat16mf2_t *, vfloat16mf2_t *, vfloat16mf2_t *, vbool32_t, vfloat16mf2_t, vfloat16mf2_t, vfloat16mf2_t, vfloat16mf2_t, vfloat16mf2_t, const _Float16 *, vuint32m1_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vloxseg5ei32_v)))
void vloxseg5ei32_v_f16mf4(vfloat16mf4_t *, vfloat16mf4_t *, vfloat16mf4_t *, vfloat16mf4_t *, vfloat16mf4_t *, const _Float16 *, vuint32mf2_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vloxseg5ei32_v_m)))
void vloxseg5ei32_v_f16mf4_m(vfloat16mf4_t *, vfloat16mf4_t *, vfloat16mf4_t *, vfloat16mf4_t *, vfloat16mf4_t *, vbool64_t, vfloat16mf4_t, vfloat16mf4_t, vfloat16mf4_t, vfloat16mf4_t, vfloat16mf4_t, const _Float16 *, vuint32mf2_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vloxseg6ei32_v)))
void vloxseg6ei32_v_f16m1(vfloat16m1_t *, vfloat16m1_t *, vfloat16m1_t *, vfloat16m1_t *, vfloat16m1_t *, vfloat16m1_t *, const _Float16 *, vuint32m2_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vloxseg6ei32_v_m)))
void vloxseg6ei32_v_f16m1_m(vfloat16m1_t *, vfloat16m1_t *, vfloat16m1_t *, vfloat16m1_t *, vfloat16m1_t *, vfloat16m1_t *, vbool16_t, vfloat16m1_t, vfloat16m1_t, vfloat16m1_t, vfloat16m1_t, vfloat16m1_t, vfloat16m1_t, const _Float16 *, vuint32m2_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vloxseg6ei32_v)))
void vloxseg6ei32_v_f16mf2(vfloat16mf2_t *, vfloat16mf2_t *, vfloat16mf2_t *, vfloat16mf2_t *, vfloat16mf2_t *, vfloat16mf2_t *, const _Float16 *, vuint32m1_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vloxseg6ei32_v_m)))
void vloxseg6ei32_v_f16mf2_m(vfloat16mf2_t *, vfloat16mf2_t *, vfloat16mf2_t *, vfloat16mf2_t *, vfloat16mf2_t *, vfloat16mf2_t *, vbool32_t, vfloat16mf2_t, vfloat16mf2_t, vfloat16mf2_t, vfloat16mf2_t, vfloat16mf2_t, vfloat16mf2_t, const _Float16 *, vuint32m1_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vloxseg6ei32_v)))
void vloxseg6ei32_v_f16mf4(vfloat16mf4_t *, vfloat16mf4_t *, vfloat16mf4_t *, vfloat16mf4_t *, vfloat16mf4_t *, vfloat16mf4_t *, const _Float16 *, vuint32mf2_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vloxseg6ei32_v_m)))
void vloxseg6ei32_v_f16mf4_m(vfloat16mf4_t *, vfloat16mf4_t *, vfloat16mf4_t *, vfloat16mf4_t *, vfloat16mf4_t *, vfloat16mf4_t *, vbool64_t, vfloat16mf4_t, vfloat16mf4_t, vfloat16mf4_t, vfloat16mf4_t, vfloat16mf4_t, vfloat16mf4_t, const _Float16 *, vuint32mf2_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vloxseg7ei32_v)))
void vloxseg7ei32_v_f16m1(vfloat16m1_t *, vfloat16m1_t *, vfloat16m1_t *, vfloat16m1_t *, vfloat16m1_t *, vfloat16m1_t *, vfloat16m1_t *, const _Float16 *, vuint32m2_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vloxseg7ei32_v_m)))
void vloxseg7ei32_v_f16m1_m(vfloat16m1_t *, vfloat16m1_t *, vfloat16m1_t *, vfloat16m1_t *, vfloat16m1_t *, vfloat16m1_t *, vfloat16m1_t *, vbool16_t, vfloat16m1_t, vfloat16m1_t, vfloat16m1_t, vfloat16m1_t, vfloat16m1_t, vfloat16m1_t, vfloat16m1_t, const _Float16 *, vuint32m2_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vloxseg7ei32_v)))
void vloxseg7ei32_v_f16mf2(vfloat16mf2_t *, vfloat16mf2_t *, vfloat16mf2_t *, vfloat16mf2_t *, vfloat16mf2_t *, vfloat16mf2_t *, vfloat16mf2_t *, const _Float16 *, vuint32m1_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vloxseg7ei32_v_m)))
void vloxseg7ei32_v_f16mf2_m(vfloat16mf2_t *, vfloat16mf2_t *, vfloat16mf2_t *, vfloat16mf2_t *, vfloat16mf2_t *, vfloat16mf2_t *, vfloat16mf2_t *, vbool32_t, vfloat16mf2_t, vfloat16mf2_t, vfloat16mf2_t, vfloat16mf2_t, vfloat16mf2_t, vfloat16mf2_t, vfloat16mf2_t, const _Float16 *, vuint32m1_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vloxseg7ei32_v)))
void vloxseg7ei32_v_f16mf4(vfloat16mf4_t *, vfloat16mf4_t *, vfloat16mf4_t *, vfloat16mf4_t *, vfloat16mf4_t *, vfloat16mf4_t *, vfloat16mf4_t *, const _Float16 *, vuint32mf2_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vloxseg7ei32_v_m)))
void vloxseg7ei32_v_f16mf4_m(vfloat16mf4_t *, vfloat16mf4_t *, vfloat16mf4_t *, vfloat16mf4_t *, vfloat16mf4_t *, vfloat16mf4_t *, vfloat16mf4_t *, vbool64_t, vfloat16mf4_t, vfloat16mf4_t, vfloat16mf4_t, vfloat16mf4_t, vfloat16mf4_t, vfloat16mf4_t, vfloat16mf4_t, const _Float16 *, vuint32mf2_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vloxseg8ei32_v)))
void vloxseg8ei32_v_f16m1(vfloat16m1_t *, vfloat16m1_t *, vfloat16m1_t *, vfloat16m1_t *, vfloat16m1_t *, vfloat16m1_t *, vfloat16m1_t *, vfloat16m1_t *, const _Float16 *, vuint32m2_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vloxseg8ei32_v_m)))
void vloxseg8ei32_v_f16m1_m(vfloat16m1_t *, vfloat16m1_t *, vfloat16m1_t *, vfloat16m1_t *, vfloat16m1_t *, vfloat16m1_t *, vfloat16m1_t *, vfloat16m1_t *, vbool16_t, vfloat16m1_t, vfloat16m1_t, vfloat16m1_t, vfloat16m1_t, vfloat16m1_t, vfloat16m1_t, vfloat16m1_t, vfloat16m1_t, const _Float16 *, vuint32m2_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vloxseg8ei32_v)))
void vloxseg8ei32_v_f16mf2(vfloat16mf2_t *, vfloat16mf2_t *, vfloat16mf2_t *, vfloat16mf2_t *, vfloat16mf2_t *, vfloat16mf2_t *, vfloat16mf2_t *, vfloat16mf2_t *, const _Float16 *, vuint32m1_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vloxseg8ei32_v_m)))
void vloxseg8ei32_v_f16mf2_m(vfloat16mf2_t *, vfloat16mf2_t *, vfloat16mf2_t *, vfloat16mf2_t *, vfloat16mf2_t *, vfloat16mf2_t *, vfloat16mf2_t *, vfloat16mf2_t *, vbool32_t, vfloat16mf2_t, vfloat16mf2_t, vfloat16mf2_t, vfloat16mf2_t, vfloat16mf2_t, vfloat16mf2_t, vfloat16mf2_t, vfloat16mf2_t, const _Float16 *, vuint32m1_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vloxseg8ei32_v)))
void vloxseg8ei32_v_f16mf4(vfloat16mf4_t *, vfloat16mf4_t *, vfloat16mf4_t *, vfloat16mf4_t *, vfloat16mf4_t *, vfloat16mf4_t *, vfloat16mf4_t *, vfloat16mf4_t *, const _Float16 *, vuint32mf2_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vloxseg8ei32_v_m)))
void vloxseg8ei32_v_f16mf4_m(vfloat16mf4_t *, vfloat16mf4_t *, vfloat16mf4_t *, vfloat16mf4_t *, vfloat16mf4_t *, vfloat16mf4_t *, vfloat16mf4_t *, vfloat16mf4_t *, vbool64_t, vfloat16mf4_t, vfloat16mf4_t, vfloat16mf4_t, vfloat16mf4_t, vfloat16mf4_t, vfloat16mf4_t, vfloat16mf4_t, vfloat16mf4_t, const _Float16 *, vuint32mf2_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vsseg2e16_v)))
void vsseg2e16_v_f16m1(_Float16 *, vfloat16m1_t, vfloat16m1_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vsseg2e16_v_m)))
void vsseg2e16_v_f16m1_m(vbool16_t, _Float16 *, vfloat16m1_t, vfloat16m1_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vsseg2e16_v)))
void vsseg2e16_v_f16m2(_Float16 *, vfloat16m2_t, vfloat16m2_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vsseg2e16_v_m)))
void vsseg2e16_v_f16m2_m(vbool8_t, _Float16 *, vfloat16m2_t, vfloat16m2_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vsseg2e16_v)))
void vsseg2e16_v_f16m4(_Float16 *, vfloat16m4_t, vfloat16m4_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vsseg2e16_v_m)))
void vsseg2e16_v_f16m4_m(vbool4_t, _Float16 *, vfloat16m4_t, vfloat16m4_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vsseg2e16_v)))
void vsseg2e16_v_f16mf2(_Float16 *, vfloat16mf2_t, vfloat16mf2_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vsseg2e16_v_m)))
void vsseg2e16_v_f16mf2_m(vbool32_t, _Float16 *, vfloat16mf2_t, vfloat16mf2_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vsseg2e16_v)))
void vsseg2e16_v_f16mf4(_Float16 *, vfloat16mf4_t, vfloat16mf4_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vsseg2e16_v_m)))
void vsseg2e16_v_f16mf4_m(vbool64_t, _Float16 *, vfloat16mf4_t, vfloat16mf4_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vsseg3e16_v)))
void vsseg3e16_v_f16m1(_Float16 *, vfloat16m1_t, vfloat16m1_t, vfloat16m1_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vsseg3e16_v_m)))
void vsseg3e16_v_f16m1_m(vbool16_t, _Float16 *, vfloat16m1_t, vfloat16m1_t, vfloat16m1_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vsseg3e16_v)))
void vsseg3e16_v_f16m2(_Float16 *, vfloat16m2_t, vfloat16m2_t, vfloat16m2_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vsseg3e16_v_m)))
void vsseg3e16_v_f16m2_m(vbool8_t, _Float16 *, vfloat16m2_t, vfloat16m2_t, vfloat16m2_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vsseg3e16_v)))
void vsseg3e16_v_f16mf2(_Float16 *, vfloat16mf2_t, vfloat16mf2_t, vfloat16mf2_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vsseg3e16_v_m)))
void vsseg3e16_v_f16mf2_m(vbool32_t, _Float16 *, vfloat16mf2_t, vfloat16mf2_t, vfloat16mf2_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vsseg3e16_v)))
void vsseg3e16_v_f16mf4(_Float16 *, vfloat16mf4_t, vfloat16mf4_t, vfloat16mf4_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vsseg3e16_v_m)))
void vsseg3e16_v_f16mf4_m(vbool64_t, _Float16 *, vfloat16mf4_t, vfloat16mf4_t, vfloat16mf4_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vsseg4e16_v)))
void vsseg4e16_v_f16m1(_Float16 *, vfloat16m1_t, vfloat16m1_t, vfloat16m1_t, vfloat16m1_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vsseg4e16_v_m)))
void vsseg4e16_v_f16m1_m(vbool16_t, _Float16 *, vfloat16m1_t, vfloat16m1_t, vfloat16m1_t, vfloat16m1_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vsseg4e16_v)))
void vsseg4e16_v_f16m2(_Float16 *, vfloat16m2_t, vfloat16m2_t, vfloat16m2_t, vfloat16m2_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vsseg4e16_v_m)))
void vsseg4e16_v_f16m2_m(vbool8_t, _Float16 *, vfloat16m2_t, vfloat16m2_t, vfloat16m2_t, vfloat16m2_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vsseg4e16_v)))
void vsseg4e16_v_f16mf2(_Float16 *, vfloat16mf2_t, vfloat16mf2_t, vfloat16mf2_t, vfloat16mf2_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vsseg4e16_v_m)))
void vsseg4e16_v_f16mf2_m(vbool32_t, _Float16 *, vfloat16mf2_t, vfloat16mf2_t, vfloat16mf2_t, vfloat16mf2_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vsseg4e16_v)))
void vsseg4e16_v_f16mf4(_Float16 *, vfloat16mf4_t, vfloat16mf4_t, vfloat16mf4_t, vfloat16mf4_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vsseg4e16_v_m)))
void vsseg4e16_v_f16mf4_m(vbool64_t, _Float16 *, vfloat16mf4_t, vfloat16mf4_t, vfloat16mf4_t, vfloat16mf4_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vsseg5e16_v)))
void vsseg5e16_v_f16m1(_Float16 *, vfloat16m1_t, vfloat16m1_t, vfloat16m1_t, vfloat16m1_t, vfloat16m1_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vsseg5e16_v_m)))
void vsseg5e16_v_f16m1_m(vbool16_t, _Float16 *, vfloat16m1_t, vfloat16m1_t, vfloat16m1_t, vfloat16m1_t, vfloat16m1_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vsseg5e16_v)))
void vsseg5e16_v_f16mf2(_Float16 *, vfloat16mf2_t, vfloat16mf2_t, vfloat16mf2_t, vfloat16mf2_t, vfloat16mf2_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vsseg5e16_v_m)))
void vsseg5e16_v_f16mf2_m(vbool32_t, _Float16 *, vfloat16mf2_t, vfloat16mf2_t, vfloat16mf2_t, vfloat16mf2_t, vfloat16mf2_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vsseg5e16_v)))
void vsseg5e16_v_f16mf4(_Float16 *, vfloat16mf4_t, vfloat16mf4_t, vfloat16mf4_t, vfloat16mf4_t, vfloat16mf4_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vsseg5e16_v_m)))
void vsseg5e16_v_f16mf4_m(vbool64_t, _Float16 *, vfloat16mf4_t, vfloat16mf4_t, vfloat16mf4_t, vfloat16mf4_t, vfloat16mf4_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vsseg6e16_v)))
void vsseg6e16_v_f16m1(_Float16 *, vfloat16m1_t, vfloat16m1_t, vfloat16m1_t, vfloat16m1_t, vfloat16m1_t, vfloat16m1_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vsseg6e16_v_m)))
void vsseg6e16_v_f16m1_m(vbool16_t, _Float16 *, vfloat16m1_t, vfloat16m1_t, vfloat16m1_t, vfloat16m1_t, vfloat16m1_t, vfloat16m1_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vsseg6e16_v)))
void vsseg6e16_v_f16mf2(_Float16 *, vfloat16mf2_t, vfloat16mf2_t, vfloat16mf2_t, vfloat16mf2_t, vfloat16mf2_t, vfloat16mf2_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vsseg6e16_v_m)))
void vsseg6e16_v_f16mf2_m(vbool32_t, _Float16 *, vfloat16mf2_t, vfloat16mf2_t, vfloat16mf2_t, vfloat16mf2_t, vfloat16mf2_t, vfloat16mf2_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vsseg6e16_v)))
void vsseg6e16_v_f16mf4(_Float16 *, vfloat16mf4_t, vfloat16mf4_t, vfloat16mf4_t, vfloat16mf4_t, vfloat16mf4_t, vfloat16mf4_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vsseg6e16_v_m)))
void vsseg6e16_v_f16mf4_m(vbool64_t, _Float16 *, vfloat16mf4_t, vfloat16mf4_t, vfloat16mf4_t, vfloat16mf4_t, vfloat16mf4_t, vfloat16mf4_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vsseg7e16_v)))
void vsseg7e16_v_f16m1(_Float16 *, vfloat16m1_t, vfloat16m1_t, vfloat16m1_t, vfloat16m1_t, vfloat16m1_t, vfloat16m1_t, vfloat16m1_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vsseg7e16_v_m)))
void vsseg7e16_v_f16m1_m(vbool16_t, _Float16 *, vfloat16m1_t, vfloat16m1_t, vfloat16m1_t, vfloat16m1_t, vfloat16m1_t, vfloat16m1_t, vfloat16m1_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vsseg7e16_v)))
void vsseg7e16_v_f16mf2(_Float16 *, vfloat16mf2_t, vfloat16mf2_t, vfloat16mf2_t, vfloat16mf2_t, vfloat16mf2_t, vfloat16mf2_t, vfloat16mf2_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vsseg7e16_v_m)))
void vsseg7e16_v_f16mf2_m(vbool32_t, _Float16 *, vfloat16mf2_t, vfloat16mf2_t, vfloat16mf2_t, vfloat16mf2_t, vfloat16mf2_t, vfloat16mf2_t, vfloat16mf2_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vsseg7e16_v)))
void vsseg7e16_v_f16mf4(_Float16 *, vfloat16mf4_t, vfloat16mf4_t, vfloat16mf4_t, vfloat16mf4_t, vfloat16mf4_t, vfloat16mf4_t, vfloat16mf4_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vsseg7e16_v_m)))
void vsseg7e16_v_f16mf4_m(vbool64_t, _Float16 *, vfloat16mf4_t, vfloat16mf4_t, vfloat16mf4_t, vfloat16mf4_t, vfloat16mf4_t, vfloat16mf4_t, vfloat16mf4_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vsseg8e16_v)))
void vsseg8e16_v_f16m1(_Float16 *, vfloat16m1_t, vfloat16m1_t, vfloat16m1_t, vfloat16m1_t, vfloat16m1_t, vfloat16m1_t, vfloat16m1_t, vfloat16m1_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vsseg8e16_v_m)))
void vsseg8e16_v_f16m1_m(vbool16_t, _Float16 *, vfloat16m1_t, vfloat16m1_t, vfloat16m1_t, vfloat16m1_t, vfloat16m1_t, vfloat16m1_t, vfloat16m1_t, vfloat16m1_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vsseg8e16_v)))
void vsseg8e16_v_f16mf2(_Float16 *, vfloat16mf2_t, vfloat16mf2_t, vfloat16mf2_t, vfloat16mf2_t, vfloat16mf2_t, vfloat16mf2_t, vfloat16mf2_t, vfloat16mf2_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vsseg8e16_v_m)))
void vsseg8e16_v_f16mf2_m(vbool32_t, _Float16 *, vfloat16mf2_t, vfloat16mf2_t, vfloat16mf2_t, vfloat16mf2_t, vfloat16mf2_t, vfloat16mf2_t, vfloat16mf2_t, vfloat16mf2_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vsseg8e16_v)))
void vsseg8e16_v_f16mf4(_Float16 *, vfloat16mf4_t, vfloat16mf4_t, vfloat16mf4_t, vfloat16mf4_t, vfloat16mf4_t, vfloat16mf4_t, vfloat16mf4_t, vfloat16mf4_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vsseg8e16_v_m)))
void vsseg8e16_v_f16mf4_m(vbool64_t, _Float16 *, vfloat16mf4_t, vfloat16mf4_t, vfloat16mf4_t, vfloat16mf4_t, vfloat16mf4_t, vfloat16mf4_t, vfloat16mf4_t, vfloat16mf4_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vssseg2e16_v)))
void vssseg2e16_v_f16m1(_Float16 *, ptrdiff_t, vfloat16m1_t, vfloat16m1_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vssseg2e16_v_m)))
void vssseg2e16_v_f16m1_m(vbool16_t, _Float16 *, ptrdiff_t, vfloat16m1_t, vfloat16m1_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vssseg2e16_v)))
void vssseg2e16_v_f16m2(_Float16 *, ptrdiff_t, vfloat16m2_t, vfloat16m2_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vssseg2e16_v_m)))
void vssseg2e16_v_f16m2_m(vbool8_t, _Float16 *, ptrdiff_t, vfloat16m2_t, vfloat16m2_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vssseg2e16_v)))
void vssseg2e16_v_f16m4(_Float16 *, ptrdiff_t, vfloat16m4_t, vfloat16m4_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vssseg2e16_v_m)))
void vssseg2e16_v_f16m4_m(vbool4_t, _Float16 *, ptrdiff_t, vfloat16m4_t, vfloat16m4_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vssseg2e16_v)))
void vssseg2e16_v_f16mf2(_Float16 *, ptrdiff_t, vfloat16mf2_t, vfloat16mf2_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vssseg2e16_v_m)))
void vssseg2e16_v_f16mf2_m(vbool32_t, _Float16 *, ptrdiff_t, vfloat16mf2_t, vfloat16mf2_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vssseg2e16_v)))
void vssseg2e16_v_f16mf4(_Float16 *, ptrdiff_t, vfloat16mf4_t, vfloat16mf4_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vssseg2e16_v_m)))
void vssseg2e16_v_f16mf4_m(vbool64_t, _Float16 *, ptrdiff_t, vfloat16mf4_t, vfloat16mf4_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vssseg3e16_v)))
void vssseg3e16_v_f16m1(_Float16 *, ptrdiff_t, vfloat16m1_t, vfloat16m1_t, vfloat16m1_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vssseg3e16_v_m)))
void vssseg3e16_v_f16m1_m(vbool16_t, _Float16 *, ptrdiff_t, vfloat16m1_t, vfloat16m1_t, vfloat16m1_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vssseg3e16_v)))
void vssseg3e16_v_f16m2(_Float16 *, ptrdiff_t, vfloat16m2_t, vfloat16m2_t, vfloat16m2_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vssseg3e16_v_m)))
void vssseg3e16_v_f16m2_m(vbool8_t, _Float16 *, ptrdiff_t, vfloat16m2_t, vfloat16m2_t, vfloat16m2_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vssseg3e16_v)))
void vssseg3e16_v_f16mf2(_Float16 *, ptrdiff_t, vfloat16mf2_t, vfloat16mf2_t, vfloat16mf2_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vssseg3e16_v_m)))
void vssseg3e16_v_f16mf2_m(vbool32_t, _Float16 *, ptrdiff_t, vfloat16mf2_t, vfloat16mf2_t, vfloat16mf2_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vssseg3e16_v)))
void vssseg3e16_v_f16mf4(_Float16 *, ptrdiff_t, vfloat16mf4_t, vfloat16mf4_t, vfloat16mf4_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vssseg3e16_v_m)))
void vssseg3e16_v_f16mf4_m(vbool64_t, _Float16 *, ptrdiff_t, vfloat16mf4_t, vfloat16mf4_t, vfloat16mf4_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vssseg4e16_v)))
void vssseg4e16_v_f16m1(_Float16 *, ptrdiff_t, vfloat16m1_t, vfloat16m1_t, vfloat16m1_t, vfloat16m1_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vssseg4e16_v_m)))
void vssseg4e16_v_f16m1_m(vbool16_t, _Float16 *, ptrdiff_t, vfloat16m1_t, vfloat16m1_t, vfloat16m1_t, vfloat16m1_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vssseg4e16_v)))
void vssseg4e16_v_f16m2(_Float16 *, ptrdiff_t, vfloat16m2_t, vfloat16m2_t, vfloat16m2_t, vfloat16m2_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vssseg4e16_v_m)))
void vssseg4e16_v_f16m2_m(vbool8_t, _Float16 *, ptrdiff_t, vfloat16m2_t, vfloat16m2_t, vfloat16m2_t, vfloat16m2_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vssseg4e16_v)))
void vssseg4e16_v_f16mf2(_Float16 *, ptrdiff_t, vfloat16mf2_t, vfloat16mf2_t, vfloat16mf2_t, vfloat16mf2_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vssseg4e16_v_m)))
void vssseg4e16_v_f16mf2_m(vbool32_t, _Float16 *, ptrdiff_t, vfloat16mf2_t, vfloat16mf2_t, vfloat16mf2_t, vfloat16mf2_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vssseg4e16_v)))
void vssseg4e16_v_f16mf4(_Float16 *, ptrdiff_t, vfloat16mf4_t, vfloat16mf4_t, vfloat16mf4_t, vfloat16mf4_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vssseg4e16_v_m)))
void vssseg4e16_v_f16mf4_m(vbool64_t, _Float16 *, ptrdiff_t, vfloat16mf4_t, vfloat16mf4_t, vfloat16mf4_t, vfloat16mf4_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vssseg5e16_v)))
void vssseg5e16_v_f16m1(_Float16 *, ptrdiff_t, vfloat16m1_t, vfloat16m1_t, vfloat16m1_t, vfloat16m1_t, vfloat16m1_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vssseg5e16_v_m)))
void vssseg5e16_v_f16m1_m(vbool16_t, _Float16 *, ptrdiff_t, vfloat16m1_t, vfloat16m1_t, vfloat16m1_t, vfloat16m1_t, vfloat16m1_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vssseg5e16_v)))
void vssseg5e16_v_f16mf2(_Float16 *, ptrdiff_t, vfloat16mf2_t, vfloat16mf2_t, vfloat16mf2_t, vfloat16mf2_t, vfloat16mf2_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vssseg5e16_v_m)))
void vssseg5e16_v_f16mf2_m(vbool32_t, _Float16 *, ptrdiff_t, vfloat16mf2_t, vfloat16mf2_t, vfloat16mf2_t, vfloat16mf2_t, vfloat16mf2_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vssseg5e16_v)))
void vssseg5e16_v_f16mf4(_Float16 *, ptrdiff_t, vfloat16mf4_t, vfloat16mf4_t, vfloat16mf4_t, vfloat16mf4_t, vfloat16mf4_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vssseg5e16_v_m)))
void vssseg5e16_v_f16mf4_m(vbool64_t, _Float16 *, ptrdiff_t, vfloat16mf4_t, vfloat16mf4_t, vfloat16mf4_t, vfloat16mf4_t, vfloat16mf4_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vssseg6e16_v)))
void vssseg6e16_v_f16m1(_Float16 *, ptrdiff_t, vfloat16m1_t, vfloat16m1_t, vfloat16m1_t, vfloat16m1_t, vfloat16m1_t, vfloat16m1_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vssseg6e16_v_m)))
void vssseg6e16_v_f16m1_m(vbool16_t, _Float16 *, ptrdiff_t, vfloat16m1_t, vfloat16m1_t, vfloat16m1_t, vfloat16m1_t, vfloat16m1_t, vfloat16m1_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vssseg6e16_v)))
void vssseg6e16_v_f16mf2(_Float16 *, ptrdiff_t, vfloat16mf2_t, vfloat16mf2_t, vfloat16mf2_t, vfloat16mf2_t, vfloat16mf2_t, vfloat16mf2_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vssseg6e16_v_m)))
void vssseg6e16_v_f16mf2_m(vbool32_t, _Float16 *, ptrdiff_t, vfloat16mf2_t, vfloat16mf2_t, vfloat16mf2_t, vfloat16mf2_t, vfloat16mf2_t, vfloat16mf2_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vssseg6e16_v)))
void vssseg6e16_v_f16mf4(_Float16 *, ptrdiff_t, vfloat16mf4_t, vfloat16mf4_t, vfloat16mf4_t, vfloat16mf4_t, vfloat16mf4_t, vfloat16mf4_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vssseg6e16_v_m)))
void vssseg6e16_v_f16mf4_m(vbool64_t, _Float16 *, ptrdiff_t, vfloat16mf4_t, vfloat16mf4_t, vfloat16mf4_t, vfloat16mf4_t, vfloat16mf4_t, vfloat16mf4_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vssseg7e16_v)))
void vssseg7e16_v_f16m1(_Float16 *, ptrdiff_t, vfloat16m1_t, vfloat16m1_t, vfloat16m1_t, vfloat16m1_t, vfloat16m1_t, vfloat16m1_t, vfloat16m1_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vssseg7e16_v_m)))
void vssseg7e16_v_f16m1_m(vbool16_t, _Float16 *, ptrdiff_t, vfloat16m1_t, vfloat16m1_t, vfloat16m1_t, vfloat16m1_t, vfloat16m1_t, vfloat16m1_t, vfloat16m1_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vssseg7e16_v)))
void vssseg7e16_v_f16mf2(_Float16 *, ptrdiff_t, vfloat16mf2_t, vfloat16mf2_t, vfloat16mf2_t, vfloat16mf2_t, vfloat16mf2_t, vfloat16mf2_t, vfloat16mf2_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vssseg7e16_v_m)))
void vssseg7e16_v_f16mf2_m(vbool32_t, _Float16 *, ptrdiff_t, vfloat16mf2_t, vfloat16mf2_t, vfloat16mf2_t, vfloat16mf2_t, vfloat16mf2_t, vfloat16mf2_t, vfloat16mf2_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vssseg7e16_v)))
void vssseg7e16_v_f16mf4(_Float16 *, ptrdiff_t, vfloat16mf4_t, vfloat16mf4_t, vfloat16mf4_t, vfloat16mf4_t, vfloat16mf4_t, vfloat16mf4_t, vfloat16mf4_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vssseg7e16_v_m)))
void vssseg7e16_v_f16mf4_m(vbool64_t, _Float16 *, ptrdiff_t, vfloat16mf4_t, vfloat16mf4_t, vfloat16mf4_t, vfloat16mf4_t, vfloat16mf4_t, vfloat16mf4_t, vfloat16mf4_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vssseg8e16_v)))
void vssseg8e16_v_f16m1(_Float16 *, ptrdiff_t, vfloat16m1_t, vfloat16m1_t, vfloat16m1_t, vfloat16m1_t, vfloat16m1_t, vfloat16m1_t, vfloat16m1_t, vfloat16m1_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vssseg8e16_v_m)))
void vssseg8e16_v_f16m1_m(vbool16_t, _Float16 *, ptrdiff_t, vfloat16m1_t, vfloat16m1_t, vfloat16m1_t, vfloat16m1_t, vfloat16m1_t, vfloat16m1_t, vfloat16m1_t, vfloat16m1_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vssseg8e16_v)))
void vssseg8e16_v_f16mf2(_Float16 *, ptrdiff_t, vfloat16mf2_t, vfloat16mf2_t, vfloat16mf2_t, vfloat16mf2_t, vfloat16mf2_t, vfloat16mf2_t, vfloat16mf2_t, vfloat16mf2_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vssseg8e16_v_m)))
void vssseg8e16_v_f16mf2_m(vbool32_t, _Float16 *, ptrdiff_t, vfloat16mf2_t, vfloat16mf2_t, vfloat16mf2_t, vfloat16mf2_t, vfloat16mf2_t, vfloat16mf2_t, vfloat16mf2_t, vfloat16mf2_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vssseg8e16_v)))
void vssseg8e16_v_f16mf4(_Float16 *, ptrdiff_t, vfloat16mf4_t, vfloat16mf4_t, vfloat16mf4_t, vfloat16mf4_t, vfloat16mf4_t, vfloat16mf4_t, vfloat16mf4_t, vfloat16mf4_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vssseg8e16_v_m)))
void vssseg8e16_v_f16mf4_m(vbool64_t, _Float16 *, ptrdiff_t, vfloat16mf4_t, vfloat16mf4_t, vfloat16mf4_t, vfloat16mf4_t, vfloat16mf4_t, vfloat16mf4_t, vfloat16mf4_t, vfloat16mf4_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vluxei8_v)))
vfloat16m1_t vluxei8_v_f16m1(const _Float16 *, vuint8mf2_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vluxei8_v_m)))
vfloat16m1_t vluxei8_v_f16m1_m(vbool16_t, vfloat16m1_t, const _Float16 *, vuint8mf2_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vluxei8_v)))
vfloat16m2_t vluxei8_v_f16m2(const _Float16 *, vuint8m1_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vluxei8_v_m)))
vfloat16m2_t vluxei8_v_f16m2_m(vbool8_t, vfloat16m2_t, const _Float16 *, vuint8m1_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vluxei8_v)))
vfloat16m4_t vluxei8_v_f16m4(const _Float16 *, vuint8m2_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vluxei8_v_m)))
vfloat16m4_t vluxei8_v_f16m4_m(vbool4_t, vfloat16m4_t, const _Float16 *, vuint8m2_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vluxei8_v)))
vfloat16m8_t vluxei8_v_f16m8(const _Float16 *, vuint8m4_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vluxei8_v_m)))
vfloat16m8_t vluxei8_v_f16m8_m(vbool2_t, vfloat16m8_t, const _Float16 *, vuint8m4_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vluxei8_v)))
vfloat16mf2_t vluxei8_v_f16mf2(const _Float16 *, vuint8mf4_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vluxei8_v_m)))
vfloat16mf2_t vluxei8_v_f16mf2_m(vbool32_t, vfloat16mf2_t, const _Float16 *, vuint8mf4_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vluxei8_v)))
vfloat16mf4_t vluxei8_v_f16mf4(const _Float16 *, vuint8mf8_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vluxei8_v_m)))
vfloat16mf4_t vluxei8_v_f16mf4_m(vbool64_t, vfloat16mf4_t, const _Float16 *, vuint8mf8_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vluxei16_v)))
vfloat16m1_t vluxei16_v_f16m1(const _Float16 *, vuint16m1_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vluxei16_v_m)))
vfloat16m1_t vluxei16_v_f16m1_m(vbool16_t, vfloat16m1_t, const _Float16 *, vuint16m1_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vluxei16_v)))
vfloat16m2_t vluxei16_v_f16m2(const _Float16 *, vuint16m2_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vluxei16_v_m)))
vfloat16m2_t vluxei16_v_f16m2_m(vbool8_t, vfloat16m2_t, const _Float16 *, vuint16m2_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vluxei16_v)))
vfloat16m4_t vluxei16_v_f16m4(const _Float16 *, vuint16m4_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vluxei16_v_m)))
vfloat16m4_t vluxei16_v_f16m4_m(vbool4_t, vfloat16m4_t, const _Float16 *, vuint16m4_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vluxei16_v)))
vfloat16m8_t vluxei16_v_f16m8(const _Float16 *, vuint16m8_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vluxei16_v_m)))
vfloat16m8_t vluxei16_v_f16m8_m(vbool2_t, vfloat16m8_t, const _Float16 *, vuint16m8_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vluxei16_v)))
vfloat16mf2_t vluxei16_v_f16mf2(const _Float16 *, vuint16mf2_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vluxei16_v_m)))
vfloat16mf2_t vluxei16_v_f16mf2_m(vbool32_t, vfloat16mf2_t, const _Float16 *, vuint16mf2_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vluxei16_v)))
vfloat16mf4_t vluxei16_v_f16mf4(const _Float16 *, vuint16mf4_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vluxei16_v_m)))
vfloat16mf4_t vluxei16_v_f16mf4_m(vbool64_t, vfloat16mf4_t, const _Float16 *, vuint16mf4_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vluxei32_v)))
vfloat16m1_t vluxei32_v_f16m1(const _Float16 *, vuint32m2_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vluxei32_v_m)))
vfloat16m1_t vluxei32_v_f16m1_m(vbool16_t, vfloat16m1_t, const _Float16 *, vuint32m2_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vluxei32_v)))
vfloat16m2_t vluxei32_v_f16m2(const _Float16 *, vuint32m4_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vluxei32_v_m)))
vfloat16m2_t vluxei32_v_f16m2_m(vbool8_t, vfloat16m2_t, const _Float16 *, vuint32m4_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vluxei32_v)))
vfloat16m4_t vluxei32_v_f16m4(const _Float16 *, vuint32m8_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vluxei32_v_m)))
vfloat16m4_t vluxei32_v_f16m4_m(vbool4_t, vfloat16m4_t, const _Float16 *, vuint32m8_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vluxei32_v)))
vfloat16mf2_t vluxei32_v_f16mf2(const _Float16 *, vuint32m1_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vluxei32_v_m)))
vfloat16mf2_t vluxei32_v_f16mf2_m(vbool32_t, vfloat16mf2_t, const _Float16 *, vuint32m1_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vluxei32_v)))
vfloat16mf4_t vluxei32_v_f16mf4(const _Float16 *, vuint32mf2_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vluxei32_v_m)))
vfloat16mf4_t vluxei32_v_f16mf4_m(vbool64_t, vfloat16mf4_t, const _Float16 *, vuint32mf2_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vsuxseg2ei8_v)))
void vsuxseg2ei8_v_f16m1(_Float16 *, vuint8mf2_t, vfloat16m1_t, vfloat16m1_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vsuxseg2ei8_v_m)))
void vsuxseg2ei8_v_f16m1_m(vbool16_t, _Float16 *, vuint8mf2_t, vfloat16m1_t, vfloat16m1_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vsuxseg2ei8_v)))
void vsuxseg2ei8_v_f16m2(_Float16 *, vuint8m1_t, vfloat16m2_t, vfloat16m2_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vsuxseg2ei8_v_m)))
void vsuxseg2ei8_v_f16m2_m(vbool8_t, _Float16 *, vuint8m1_t, vfloat16m2_t, vfloat16m2_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vsuxseg2ei8_v)))
void vsuxseg2ei8_v_f16m4(_Float16 *, vuint8m2_t, vfloat16m4_t, vfloat16m4_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vsuxseg2ei8_v_m)))
void vsuxseg2ei8_v_f16m4_m(vbool4_t, _Float16 *, vuint8m2_t, vfloat16m4_t, vfloat16m4_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vsuxseg2ei8_v)))
void vsuxseg2ei8_v_f16mf2(_Float16 *, vuint8mf4_t, vfloat16mf2_t, vfloat16mf2_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vsuxseg2ei8_v_m)))
void vsuxseg2ei8_v_f16mf2_m(vbool32_t, _Float16 *, vuint8mf4_t, vfloat16mf2_t, vfloat16mf2_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vsuxseg2ei8_v)))
void vsuxseg2ei8_v_f16mf4(_Float16 *, vuint8mf8_t, vfloat16mf4_t, vfloat16mf4_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vsuxseg2ei8_v_m)))
void vsuxseg2ei8_v_f16mf4_m(vbool64_t, _Float16 *, vuint8mf8_t, vfloat16mf4_t, vfloat16mf4_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vsuxseg3ei8_v)))
void vsuxseg3ei8_v_f16m1(_Float16 *, vuint8mf2_t, vfloat16m1_t, vfloat16m1_t, vfloat16m1_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vsuxseg3ei8_v_m)))
void vsuxseg3ei8_v_f16m1_m(vbool16_t, _Float16 *, vuint8mf2_t, vfloat16m1_t, vfloat16m1_t, vfloat16m1_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vsuxseg3ei8_v)))
void vsuxseg3ei8_v_f16m2(_Float16 *, vuint8m1_t, vfloat16m2_t, vfloat16m2_t, vfloat16m2_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vsuxseg3ei8_v_m)))
void vsuxseg3ei8_v_f16m2_m(vbool8_t, _Float16 *, vuint8m1_t, vfloat16m2_t, vfloat16m2_t, vfloat16m2_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vsuxseg3ei8_v)))
void vsuxseg3ei8_v_f16mf2(_Float16 *, vuint8mf4_t, vfloat16mf2_t, vfloat16mf2_t, vfloat16mf2_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vsuxseg3ei8_v_m)))
void vsuxseg3ei8_v_f16mf2_m(vbool32_t, _Float16 *, vuint8mf4_t, vfloat16mf2_t, vfloat16mf2_t, vfloat16mf2_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vsuxseg3ei8_v)))
void vsuxseg3ei8_v_f16mf4(_Float16 *, vuint8mf8_t, vfloat16mf4_t, vfloat16mf4_t, vfloat16mf4_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vsuxseg3ei8_v_m)))
void vsuxseg3ei8_v_f16mf4_m(vbool64_t, _Float16 *, vuint8mf8_t, vfloat16mf4_t, vfloat16mf4_t, vfloat16mf4_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vsuxseg4ei8_v)))
void vsuxseg4ei8_v_f16m1(_Float16 *, vuint8mf2_t, vfloat16m1_t, vfloat16m1_t, vfloat16m1_t, vfloat16m1_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vsuxseg4ei8_v_m)))
void vsuxseg4ei8_v_f16m1_m(vbool16_t, _Float16 *, vuint8mf2_t, vfloat16m1_t, vfloat16m1_t, vfloat16m1_t, vfloat16m1_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vsuxseg4ei8_v)))
void vsuxseg4ei8_v_f16m2(_Float16 *, vuint8m1_t, vfloat16m2_t, vfloat16m2_t, vfloat16m2_t, vfloat16m2_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vsuxseg4ei8_v_m)))
void vsuxseg4ei8_v_f16m2_m(vbool8_t, _Float16 *, vuint8m1_t, vfloat16m2_t, vfloat16m2_t, vfloat16m2_t, vfloat16m2_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vsuxseg4ei8_v)))
void vsuxseg4ei8_v_f16mf2(_Float16 *, vuint8mf4_t, vfloat16mf2_t, vfloat16mf2_t, vfloat16mf2_t, vfloat16mf2_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vsuxseg4ei8_v_m)))
void vsuxseg4ei8_v_f16mf2_m(vbool32_t, _Float16 *, vuint8mf4_t, vfloat16mf2_t, vfloat16mf2_t, vfloat16mf2_t, vfloat16mf2_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vsuxseg4ei8_v)))
void vsuxseg4ei8_v_f16mf4(_Float16 *, vuint8mf8_t, vfloat16mf4_t, vfloat16mf4_t, vfloat16mf4_t, vfloat16mf4_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vsuxseg4ei8_v_m)))
void vsuxseg4ei8_v_f16mf4_m(vbool64_t, _Float16 *, vuint8mf8_t, vfloat16mf4_t, vfloat16mf4_t, vfloat16mf4_t, vfloat16mf4_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vsuxseg5ei8_v)))
void vsuxseg5ei8_v_f16m1(_Float16 *, vuint8mf2_t, vfloat16m1_t, vfloat16m1_t, vfloat16m1_t, vfloat16m1_t, vfloat16m1_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vsuxseg5ei8_v_m)))
void vsuxseg5ei8_v_f16m1_m(vbool16_t, _Float16 *, vuint8mf2_t, vfloat16m1_t, vfloat16m1_t, vfloat16m1_t, vfloat16m1_t, vfloat16m1_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vsuxseg5ei8_v)))
void vsuxseg5ei8_v_f16mf2(_Float16 *, vuint8mf4_t, vfloat16mf2_t, vfloat16mf2_t, vfloat16mf2_t, vfloat16mf2_t, vfloat16mf2_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vsuxseg5ei8_v_m)))
void vsuxseg5ei8_v_f16mf2_m(vbool32_t, _Float16 *, vuint8mf4_t, vfloat16mf2_t, vfloat16mf2_t, vfloat16mf2_t, vfloat16mf2_t, vfloat16mf2_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vsuxseg5ei8_v)))
void vsuxseg5ei8_v_f16mf4(_Float16 *, vuint8mf8_t, vfloat16mf4_t, vfloat16mf4_t, vfloat16mf4_t, vfloat16mf4_t, vfloat16mf4_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vsuxseg5ei8_v_m)))
void vsuxseg5ei8_v_f16mf4_m(vbool64_t, _Float16 *, vuint8mf8_t, vfloat16mf4_t, vfloat16mf4_t, vfloat16mf4_t, vfloat16mf4_t, vfloat16mf4_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vsuxseg6ei8_v)))
void vsuxseg6ei8_v_f16m1(_Float16 *, vuint8mf2_t, vfloat16m1_t, vfloat16m1_t, vfloat16m1_t, vfloat16m1_t, vfloat16m1_t, vfloat16m1_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vsuxseg6ei8_v_m)))
void vsuxseg6ei8_v_f16m1_m(vbool16_t, _Float16 *, vuint8mf2_t, vfloat16m1_t, vfloat16m1_t, vfloat16m1_t, vfloat16m1_t, vfloat16m1_t, vfloat16m1_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vsuxseg6ei8_v)))
void vsuxseg6ei8_v_f16mf2(_Float16 *, vuint8mf4_t, vfloat16mf2_t, vfloat16mf2_t, vfloat16mf2_t, vfloat16mf2_t, vfloat16mf2_t, vfloat16mf2_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vsuxseg6ei8_v_m)))
void vsuxseg6ei8_v_f16mf2_m(vbool32_t, _Float16 *, vuint8mf4_t, vfloat16mf2_t, vfloat16mf2_t, vfloat16mf2_t, vfloat16mf2_t, vfloat16mf2_t, vfloat16mf2_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vsuxseg6ei8_v)))
void vsuxseg6ei8_v_f16mf4(_Float16 *, vuint8mf8_t, vfloat16mf4_t, vfloat16mf4_t, vfloat16mf4_t, vfloat16mf4_t, vfloat16mf4_t, vfloat16mf4_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vsuxseg6ei8_v_m)))
void vsuxseg6ei8_v_f16mf4_m(vbool64_t, _Float16 *, vuint8mf8_t, vfloat16mf4_t, vfloat16mf4_t, vfloat16mf4_t, vfloat16mf4_t, vfloat16mf4_t, vfloat16mf4_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vsuxseg7ei8_v)))
void vsuxseg7ei8_v_f16m1(_Float16 *, vuint8mf2_t, vfloat16m1_t, vfloat16m1_t, vfloat16m1_t, vfloat16m1_t, vfloat16m1_t, vfloat16m1_t, vfloat16m1_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vsuxseg7ei8_v_m)))
void vsuxseg7ei8_v_f16m1_m(vbool16_t, _Float16 *, vuint8mf2_t, vfloat16m1_t, vfloat16m1_t, vfloat16m1_t, vfloat16m1_t, vfloat16m1_t, vfloat16m1_t, vfloat16m1_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vsuxseg7ei8_v)))
void vsuxseg7ei8_v_f16mf2(_Float16 *, vuint8mf4_t, vfloat16mf2_t, vfloat16mf2_t, vfloat16mf2_t, vfloat16mf2_t, vfloat16mf2_t, vfloat16mf2_t, vfloat16mf2_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vsuxseg7ei8_v_m)))
void vsuxseg7ei8_v_f16mf2_m(vbool32_t, _Float16 *, vuint8mf4_t, vfloat16mf2_t, vfloat16mf2_t, vfloat16mf2_t, vfloat16mf2_t, vfloat16mf2_t, vfloat16mf2_t, vfloat16mf2_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vsuxseg7ei8_v)))
void vsuxseg7ei8_v_f16mf4(_Float16 *, vuint8mf8_t, vfloat16mf4_t, vfloat16mf4_t, vfloat16mf4_t, vfloat16mf4_t, vfloat16mf4_t, vfloat16mf4_t, vfloat16mf4_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vsuxseg7ei8_v_m)))
void vsuxseg7ei8_v_f16mf4_m(vbool64_t, _Float16 *, vuint8mf8_t, vfloat16mf4_t, vfloat16mf4_t, vfloat16mf4_t, vfloat16mf4_t, vfloat16mf4_t, vfloat16mf4_t, vfloat16mf4_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vsuxseg8ei8_v)))
void vsuxseg8ei8_v_f16m1(_Float16 *, vuint8mf2_t, vfloat16m1_t, vfloat16m1_t, vfloat16m1_t, vfloat16m1_t, vfloat16m1_t, vfloat16m1_t, vfloat16m1_t, vfloat16m1_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vsuxseg8ei8_v_m)))
void vsuxseg8ei8_v_f16m1_m(vbool16_t, _Float16 *, vuint8mf2_t, vfloat16m1_t, vfloat16m1_t, vfloat16m1_t, vfloat16m1_t, vfloat16m1_t, vfloat16m1_t, vfloat16m1_t, vfloat16m1_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vsuxseg8ei8_v)))
void vsuxseg8ei8_v_f16mf2(_Float16 *, vuint8mf4_t, vfloat16mf2_t, vfloat16mf2_t, vfloat16mf2_t, vfloat16mf2_t, vfloat16mf2_t, vfloat16mf2_t, vfloat16mf2_t, vfloat16mf2_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vsuxseg8ei8_v_m)))
void vsuxseg8ei8_v_f16mf2_m(vbool32_t, _Float16 *, vuint8mf4_t, vfloat16mf2_t, vfloat16mf2_t, vfloat16mf2_t, vfloat16mf2_t, vfloat16mf2_t, vfloat16mf2_t, vfloat16mf2_t, vfloat16mf2_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vsuxseg8ei8_v)))
void vsuxseg8ei8_v_f16mf4(_Float16 *, vuint8mf8_t, vfloat16mf4_t, vfloat16mf4_t, vfloat16mf4_t, vfloat16mf4_t, vfloat16mf4_t, vfloat16mf4_t, vfloat16mf4_t, vfloat16mf4_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vsuxseg8ei8_v_m)))
void vsuxseg8ei8_v_f16mf4_m(vbool64_t, _Float16 *, vuint8mf8_t, vfloat16mf4_t, vfloat16mf4_t, vfloat16mf4_t, vfloat16mf4_t, vfloat16mf4_t, vfloat16mf4_t, vfloat16mf4_t, vfloat16mf4_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vsuxseg2ei16_v)))
void vsuxseg2ei16_v_f16m1(_Float16 *, vuint16m1_t, vfloat16m1_t, vfloat16m1_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vsuxseg2ei16_v_m)))
void vsuxseg2ei16_v_f16m1_m(vbool16_t, _Float16 *, vuint16m1_t, vfloat16m1_t, vfloat16m1_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vsuxseg2ei16_v)))
void vsuxseg2ei16_v_f16m2(_Float16 *, vuint16m2_t, vfloat16m2_t, vfloat16m2_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vsuxseg2ei16_v_m)))
void vsuxseg2ei16_v_f16m2_m(vbool8_t, _Float16 *, vuint16m2_t, vfloat16m2_t, vfloat16m2_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vsuxseg2ei16_v)))
void vsuxseg2ei16_v_f16m4(_Float16 *, vuint16m4_t, vfloat16m4_t, vfloat16m4_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vsuxseg2ei16_v_m)))
void vsuxseg2ei16_v_f16m4_m(vbool4_t, _Float16 *, vuint16m4_t, vfloat16m4_t, vfloat16m4_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vsuxseg2ei16_v)))
void vsuxseg2ei16_v_f16mf2(_Float16 *, vuint16mf2_t, vfloat16mf2_t, vfloat16mf2_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vsuxseg2ei16_v_m)))
void vsuxseg2ei16_v_f16mf2_m(vbool32_t, _Float16 *, vuint16mf2_t, vfloat16mf2_t, vfloat16mf2_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vsuxseg2ei16_v)))
void vsuxseg2ei16_v_f16mf4(_Float16 *, vuint16mf4_t, vfloat16mf4_t, vfloat16mf4_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vsuxseg2ei16_v_m)))
void vsuxseg2ei16_v_f16mf4_m(vbool64_t, _Float16 *, vuint16mf4_t, vfloat16mf4_t, vfloat16mf4_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vsuxseg3ei16_v)))
void vsuxseg3ei16_v_f16m1(_Float16 *, vuint16m1_t, vfloat16m1_t, vfloat16m1_t, vfloat16m1_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vsuxseg3ei16_v_m)))
void vsuxseg3ei16_v_f16m1_m(vbool16_t, _Float16 *, vuint16m1_t, vfloat16m1_t, vfloat16m1_t, vfloat16m1_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vsuxseg3ei16_v)))
void vsuxseg3ei16_v_f16m2(_Float16 *, vuint16m2_t, vfloat16m2_t, vfloat16m2_t, vfloat16m2_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vsuxseg3ei16_v_m)))
void vsuxseg3ei16_v_f16m2_m(vbool8_t, _Float16 *, vuint16m2_t, vfloat16m2_t, vfloat16m2_t, vfloat16m2_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vsuxseg3ei16_v)))
void vsuxseg3ei16_v_f16mf2(_Float16 *, vuint16mf2_t, vfloat16mf2_t, vfloat16mf2_t, vfloat16mf2_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vsuxseg3ei16_v_m)))
void vsuxseg3ei16_v_f16mf2_m(vbool32_t, _Float16 *, vuint16mf2_t, vfloat16mf2_t, vfloat16mf2_t, vfloat16mf2_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vsuxseg3ei16_v)))
void vsuxseg3ei16_v_f16mf4(_Float16 *, vuint16mf4_t, vfloat16mf4_t, vfloat16mf4_t, vfloat16mf4_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vsuxseg3ei16_v_m)))
void vsuxseg3ei16_v_f16mf4_m(vbool64_t, _Float16 *, vuint16mf4_t, vfloat16mf4_t, vfloat16mf4_t, vfloat16mf4_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vsuxseg4ei16_v)))
void vsuxseg4ei16_v_f16m1(_Float16 *, vuint16m1_t, vfloat16m1_t, vfloat16m1_t, vfloat16m1_t, vfloat16m1_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vsuxseg4ei16_v_m)))
void vsuxseg4ei16_v_f16m1_m(vbool16_t, _Float16 *, vuint16m1_t, vfloat16m1_t, vfloat16m1_t, vfloat16m1_t, vfloat16m1_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vsuxseg4ei16_v)))
void vsuxseg4ei16_v_f16m2(_Float16 *, vuint16m2_t, vfloat16m2_t, vfloat16m2_t, vfloat16m2_t, vfloat16m2_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vsuxseg4ei16_v_m)))
void vsuxseg4ei16_v_f16m2_m(vbool8_t, _Float16 *, vuint16m2_t, vfloat16m2_t, vfloat16m2_t, vfloat16m2_t, vfloat16m2_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vsuxseg4ei16_v)))
void vsuxseg4ei16_v_f16mf2(_Float16 *, vuint16mf2_t, vfloat16mf2_t, vfloat16mf2_t, vfloat16mf2_t, vfloat16mf2_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vsuxseg4ei16_v_m)))
void vsuxseg4ei16_v_f16mf2_m(vbool32_t, _Float16 *, vuint16mf2_t, vfloat16mf2_t, vfloat16mf2_t, vfloat16mf2_t, vfloat16mf2_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vsuxseg4ei16_v)))
void vsuxseg4ei16_v_f16mf4(_Float16 *, vuint16mf4_t, vfloat16mf4_t, vfloat16mf4_t, vfloat16mf4_t, vfloat16mf4_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vsuxseg4ei16_v_m)))
void vsuxseg4ei16_v_f16mf4_m(vbool64_t, _Float16 *, vuint16mf4_t, vfloat16mf4_t, vfloat16mf4_t, vfloat16mf4_t, vfloat16mf4_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vsuxseg5ei16_v)))
void vsuxseg5ei16_v_f16m1(_Float16 *, vuint16m1_t, vfloat16m1_t, vfloat16m1_t, vfloat16m1_t, vfloat16m1_t, vfloat16m1_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vsuxseg5ei16_v_m)))
void vsuxseg5ei16_v_f16m1_m(vbool16_t, _Float16 *, vuint16m1_t, vfloat16m1_t, vfloat16m1_t, vfloat16m1_t, vfloat16m1_t, vfloat16m1_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vsuxseg5ei16_v)))
void vsuxseg5ei16_v_f16mf2(_Float16 *, vuint16mf2_t, vfloat16mf2_t, vfloat16mf2_t, vfloat16mf2_t, vfloat16mf2_t, vfloat16mf2_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vsuxseg5ei16_v_m)))
void vsuxseg5ei16_v_f16mf2_m(vbool32_t, _Float16 *, vuint16mf2_t, vfloat16mf2_t, vfloat16mf2_t, vfloat16mf2_t, vfloat16mf2_t, vfloat16mf2_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vsuxseg5ei16_v)))
void vsuxseg5ei16_v_f16mf4(_Float16 *, vuint16mf4_t, vfloat16mf4_t, vfloat16mf4_t, vfloat16mf4_t, vfloat16mf4_t, vfloat16mf4_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vsuxseg5ei16_v_m)))
void vsuxseg5ei16_v_f16mf4_m(vbool64_t, _Float16 *, vuint16mf4_t, vfloat16mf4_t, vfloat16mf4_t, vfloat16mf4_t, vfloat16mf4_t, vfloat16mf4_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vsuxseg6ei16_v)))
void vsuxseg6ei16_v_f16m1(_Float16 *, vuint16m1_t, vfloat16m1_t, vfloat16m1_t, vfloat16m1_t, vfloat16m1_t, vfloat16m1_t, vfloat16m1_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vsuxseg6ei16_v_m)))
void vsuxseg6ei16_v_f16m1_m(vbool16_t, _Float16 *, vuint16m1_t, vfloat16m1_t, vfloat16m1_t, vfloat16m1_t, vfloat16m1_t, vfloat16m1_t, vfloat16m1_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vsuxseg6ei16_v)))
void vsuxseg6ei16_v_f16mf2(_Float16 *, vuint16mf2_t, vfloat16mf2_t, vfloat16mf2_t, vfloat16mf2_t, vfloat16mf2_t, vfloat16mf2_t, vfloat16mf2_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vsuxseg6ei16_v_m)))
void vsuxseg6ei16_v_f16mf2_m(vbool32_t, _Float16 *, vuint16mf2_t, vfloat16mf2_t, vfloat16mf2_t, vfloat16mf2_t, vfloat16mf2_t, vfloat16mf2_t, vfloat16mf2_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vsuxseg6ei16_v)))
void vsuxseg6ei16_v_f16mf4(_Float16 *, vuint16mf4_t, vfloat16mf4_t, vfloat16mf4_t, vfloat16mf4_t, vfloat16mf4_t, vfloat16mf4_t, vfloat16mf4_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vsuxseg6ei16_v_m)))
void vsuxseg6ei16_v_f16mf4_m(vbool64_t, _Float16 *, vuint16mf4_t, vfloat16mf4_t, vfloat16mf4_t, vfloat16mf4_t, vfloat16mf4_t, vfloat16mf4_t, vfloat16mf4_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vsuxseg7ei16_v)))
void vsuxseg7ei16_v_f16m1(_Float16 *, vuint16m1_t, vfloat16m1_t, vfloat16m1_t, vfloat16m1_t, vfloat16m1_t, vfloat16m1_t, vfloat16m1_t, vfloat16m1_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vsuxseg7ei16_v_m)))
void vsuxseg7ei16_v_f16m1_m(vbool16_t, _Float16 *, vuint16m1_t, vfloat16m1_t, vfloat16m1_t, vfloat16m1_t, vfloat16m1_t, vfloat16m1_t, vfloat16m1_t, vfloat16m1_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vsuxseg7ei16_v)))
void vsuxseg7ei16_v_f16mf2(_Float16 *, vuint16mf2_t, vfloat16mf2_t, vfloat16mf2_t, vfloat16mf2_t, vfloat16mf2_t, vfloat16mf2_t, vfloat16mf2_t, vfloat16mf2_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vsuxseg7ei16_v_m)))
void vsuxseg7ei16_v_f16mf2_m(vbool32_t, _Float16 *, vuint16mf2_t, vfloat16mf2_t, vfloat16mf2_t, vfloat16mf2_t, vfloat16mf2_t, vfloat16mf2_t, vfloat16mf2_t, vfloat16mf2_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vsuxseg7ei16_v)))
void vsuxseg7ei16_v_f16mf4(_Float16 *, vuint16mf4_t, vfloat16mf4_t, vfloat16mf4_t, vfloat16mf4_t, vfloat16mf4_t, vfloat16mf4_t, vfloat16mf4_t, vfloat16mf4_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vsuxseg7ei16_v_m)))
void vsuxseg7ei16_v_f16mf4_m(vbool64_t, _Float16 *, vuint16mf4_t, vfloat16mf4_t, vfloat16mf4_t, vfloat16mf4_t, vfloat16mf4_t, vfloat16mf4_t, vfloat16mf4_t, vfloat16mf4_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vsuxseg8ei16_v)))
void vsuxseg8ei16_v_f16m1(_Float16 *, vuint16m1_t, vfloat16m1_t, vfloat16m1_t, vfloat16m1_t, vfloat16m1_t, vfloat16m1_t, vfloat16m1_t, vfloat16m1_t, vfloat16m1_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vsuxseg8ei16_v_m)))
void vsuxseg8ei16_v_f16m1_m(vbool16_t, _Float16 *, vuint16m1_t, vfloat16m1_t, vfloat16m1_t, vfloat16m1_t, vfloat16m1_t, vfloat16m1_t, vfloat16m1_t, vfloat16m1_t, vfloat16m1_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vsuxseg8ei16_v)))
void vsuxseg8ei16_v_f16mf2(_Float16 *, vuint16mf2_t, vfloat16mf2_t, vfloat16mf2_t, vfloat16mf2_t, vfloat16mf2_t, vfloat16mf2_t, vfloat16mf2_t, vfloat16mf2_t, vfloat16mf2_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vsuxseg8ei16_v_m)))
void vsuxseg8ei16_v_f16mf2_m(vbool32_t, _Float16 *, vuint16mf2_t, vfloat16mf2_t, vfloat16mf2_t, vfloat16mf2_t, vfloat16mf2_t, vfloat16mf2_t, vfloat16mf2_t, vfloat16mf2_t, vfloat16mf2_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vsuxseg8ei16_v)))
void vsuxseg8ei16_v_f16mf4(_Float16 *, vuint16mf4_t, vfloat16mf4_t, vfloat16mf4_t, vfloat16mf4_t, vfloat16mf4_t, vfloat16mf4_t, vfloat16mf4_t, vfloat16mf4_t, vfloat16mf4_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vsuxseg8ei16_v_m)))
void vsuxseg8ei16_v_f16mf4_m(vbool64_t, _Float16 *, vuint16mf4_t, vfloat16mf4_t, vfloat16mf4_t, vfloat16mf4_t, vfloat16mf4_t, vfloat16mf4_t, vfloat16mf4_t, vfloat16mf4_t, vfloat16mf4_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vsuxseg2ei32_v)))
void vsuxseg2ei32_v_f16m1(_Float16 *, vuint32m2_t, vfloat16m1_t, vfloat16m1_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vsuxseg2ei32_v_m)))
void vsuxseg2ei32_v_f16m1_m(vbool16_t, _Float16 *, vuint32m2_t, vfloat16m1_t, vfloat16m1_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vsuxseg2ei32_v)))
void vsuxseg2ei32_v_f16m2(_Float16 *, vuint32m4_t, vfloat16m2_t, vfloat16m2_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vsuxseg2ei32_v_m)))
void vsuxseg2ei32_v_f16m2_m(vbool8_t, _Float16 *, vuint32m4_t, vfloat16m2_t, vfloat16m2_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vsuxseg2ei32_v)))
void vsuxseg2ei32_v_f16m4(_Float16 *, vuint32m8_t, vfloat16m4_t, vfloat16m4_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vsuxseg2ei32_v_m)))
void vsuxseg2ei32_v_f16m4_m(vbool4_t, _Float16 *, vuint32m8_t, vfloat16m4_t, vfloat16m4_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vsuxseg2ei32_v)))
void vsuxseg2ei32_v_f16mf2(_Float16 *, vuint32m1_t, vfloat16mf2_t, vfloat16mf2_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vsuxseg2ei32_v_m)))
void vsuxseg2ei32_v_f16mf2_m(vbool32_t, _Float16 *, vuint32m1_t, vfloat16mf2_t, vfloat16mf2_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vsuxseg2ei32_v)))
void vsuxseg2ei32_v_f16mf4(_Float16 *, vuint32mf2_t, vfloat16mf4_t, vfloat16mf4_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vsuxseg2ei32_v_m)))
void vsuxseg2ei32_v_f16mf4_m(vbool64_t, _Float16 *, vuint32mf2_t, vfloat16mf4_t, vfloat16mf4_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vsuxseg3ei32_v)))
void vsuxseg3ei32_v_f16m1(_Float16 *, vuint32m2_t, vfloat16m1_t, vfloat16m1_t, vfloat16m1_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vsuxseg3ei32_v_m)))
void vsuxseg3ei32_v_f16m1_m(vbool16_t, _Float16 *, vuint32m2_t, vfloat16m1_t, vfloat16m1_t, vfloat16m1_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vsuxseg3ei32_v)))
void vsuxseg3ei32_v_f16m2(_Float16 *, vuint32m4_t, vfloat16m2_t, vfloat16m2_t, vfloat16m2_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vsuxseg3ei32_v_m)))
void vsuxseg3ei32_v_f16m2_m(vbool8_t, _Float16 *, vuint32m4_t, vfloat16m2_t, vfloat16m2_t, vfloat16m2_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vsuxseg3ei32_v)))
void vsuxseg3ei32_v_f16mf2(_Float16 *, vuint32m1_t, vfloat16mf2_t, vfloat16mf2_t, vfloat16mf2_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vsuxseg3ei32_v_m)))
void vsuxseg3ei32_v_f16mf2_m(vbool32_t, _Float16 *, vuint32m1_t, vfloat16mf2_t, vfloat16mf2_t, vfloat16mf2_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vsuxseg3ei32_v)))
void vsuxseg3ei32_v_f16mf4(_Float16 *, vuint32mf2_t, vfloat16mf4_t, vfloat16mf4_t, vfloat16mf4_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vsuxseg3ei32_v_m)))
void vsuxseg3ei32_v_f16mf4_m(vbool64_t, _Float16 *, vuint32mf2_t, vfloat16mf4_t, vfloat16mf4_t, vfloat16mf4_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vsuxseg4ei32_v)))
void vsuxseg4ei32_v_f16m1(_Float16 *, vuint32m2_t, vfloat16m1_t, vfloat16m1_t, vfloat16m1_t, vfloat16m1_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vsuxseg4ei32_v_m)))
void vsuxseg4ei32_v_f16m1_m(vbool16_t, _Float16 *, vuint32m2_t, vfloat16m1_t, vfloat16m1_t, vfloat16m1_t, vfloat16m1_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vsuxseg4ei32_v)))
void vsuxseg4ei32_v_f16m2(_Float16 *, vuint32m4_t, vfloat16m2_t, vfloat16m2_t, vfloat16m2_t, vfloat16m2_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vsuxseg4ei32_v_m)))
void vsuxseg4ei32_v_f16m2_m(vbool8_t, _Float16 *, vuint32m4_t, vfloat16m2_t, vfloat16m2_t, vfloat16m2_t, vfloat16m2_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vsuxseg4ei32_v)))
void vsuxseg4ei32_v_f16mf2(_Float16 *, vuint32m1_t, vfloat16mf2_t, vfloat16mf2_t, vfloat16mf2_t, vfloat16mf2_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vsuxseg4ei32_v_m)))
void vsuxseg4ei32_v_f16mf2_m(vbool32_t, _Float16 *, vuint32m1_t, vfloat16mf2_t, vfloat16mf2_t, vfloat16mf2_t, vfloat16mf2_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vsuxseg4ei32_v)))
void vsuxseg4ei32_v_f16mf4(_Float16 *, vuint32mf2_t, vfloat16mf4_t, vfloat16mf4_t, vfloat16mf4_t, vfloat16mf4_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vsuxseg4ei32_v_m)))
void vsuxseg4ei32_v_f16mf4_m(vbool64_t, _Float16 *, vuint32mf2_t, vfloat16mf4_t, vfloat16mf4_t, vfloat16mf4_t, vfloat16mf4_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vsuxseg5ei32_v)))
void vsuxseg5ei32_v_f16m1(_Float16 *, vuint32m2_t, vfloat16m1_t, vfloat16m1_t, vfloat16m1_t, vfloat16m1_t, vfloat16m1_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vsuxseg5ei32_v_m)))
void vsuxseg5ei32_v_f16m1_m(vbool16_t, _Float16 *, vuint32m2_t, vfloat16m1_t, vfloat16m1_t, vfloat16m1_t, vfloat16m1_t, vfloat16m1_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vsuxseg5ei32_v)))
void vsuxseg5ei32_v_f16mf2(_Float16 *, vuint32m1_t, vfloat16mf2_t, vfloat16mf2_t, vfloat16mf2_t, vfloat16mf2_t, vfloat16mf2_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vsuxseg5ei32_v_m)))
void vsuxseg5ei32_v_f16mf2_m(vbool32_t, _Float16 *, vuint32m1_t, vfloat16mf2_t, vfloat16mf2_t, vfloat16mf2_t, vfloat16mf2_t, vfloat16mf2_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vsuxseg5ei32_v)))
void vsuxseg5ei32_v_f16mf4(_Float16 *, vuint32mf2_t, vfloat16mf4_t, vfloat16mf4_t, vfloat16mf4_t, vfloat16mf4_t, vfloat16mf4_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vsuxseg5ei32_v_m)))
void vsuxseg5ei32_v_f16mf4_m(vbool64_t, _Float16 *, vuint32mf2_t, vfloat16mf4_t, vfloat16mf4_t, vfloat16mf4_t, vfloat16mf4_t, vfloat16mf4_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vsuxseg6ei32_v)))
void vsuxseg6ei32_v_f16m1(_Float16 *, vuint32m2_t, vfloat16m1_t, vfloat16m1_t, vfloat16m1_t, vfloat16m1_t, vfloat16m1_t, vfloat16m1_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vsuxseg6ei32_v_m)))
void vsuxseg6ei32_v_f16m1_m(vbool16_t, _Float16 *, vuint32m2_t, vfloat16m1_t, vfloat16m1_t, vfloat16m1_t, vfloat16m1_t, vfloat16m1_t, vfloat16m1_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vsuxseg6ei32_v)))
void vsuxseg6ei32_v_f16mf2(_Float16 *, vuint32m1_t, vfloat16mf2_t, vfloat16mf2_t, vfloat16mf2_t, vfloat16mf2_t, vfloat16mf2_t, vfloat16mf2_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vsuxseg6ei32_v_m)))
void vsuxseg6ei32_v_f16mf2_m(vbool32_t, _Float16 *, vuint32m1_t, vfloat16mf2_t, vfloat16mf2_t, vfloat16mf2_t, vfloat16mf2_t, vfloat16mf2_t, vfloat16mf2_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vsuxseg6ei32_v)))
void vsuxseg6ei32_v_f16mf4(_Float16 *, vuint32mf2_t, vfloat16mf4_t, vfloat16mf4_t, vfloat16mf4_t, vfloat16mf4_t, vfloat16mf4_t, vfloat16mf4_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vsuxseg6ei32_v_m)))
void vsuxseg6ei32_v_f16mf4_m(vbool64_t, _Float16 *, vuint32mf2_t, vfloat16mf4_t, vfloat16mf4_t, vfloat16mf4_t, vfloat16mf4_t, vfloat16mf4_t, vfloat16mf4_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vsuxseg7ei32_v)))
void vsuxseg7ei32_v_f16m1(_Float16 *, vuint32m2_t, vfloat16m1_t, vfloat16m1_t, vfloat16m1_t, vfloat16m1_t, vfloat16m1_t, vfloat16m1_t, vfloat16m1_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vsuxseg7ei32_v_m)))
void vsuxseg7ei32_v_f16m1_m(vbool16_t, _Float16 *, vuint32m2_t, vfloat16m1_t, vfloat16m1_t, vfloat16m1_t, vfloat16m1_t, vfloat16m1_t, vfloat16m1_t, vfloat16m1_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vsuxseg7ei32_v)))
void vsuxseg7ei32_v_f16mf2(_Float16 *, vuint32m1_t, vfloat16mf2_t, vfloat16mf2_t, vfloat16mf2_t, vfloat16mf2_t, vfloat16mf2_t, vfloat16mf2_t, vfloat16mf2_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vsuxseg7ei32_v_m)))
void vsuxseg7ei32_v_f16mf2_m(vbool32_t, _Float16 *, vuint32m1_t, vfloat16mf2_t, vfloat16mf2_t, vfloat16mf2_t, vfloat16mf2_t, vfloat16mf2_t, vfloat16mf2_t, vfloat16mf2_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vsuxseg7ei32_v)))
void vsuxseg7ei32_v_f16mf4(_Float16 *, vuint32mf2_t, vfloat16mf4_t, vfloat16mf4_t, vfloat16mf4_t, vfloat16mf4_t, vfloat16mf4_t, vfloat16mf4_t, vfloat16mf4_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vsuxseg7ei32_v_m)))
void vsuxseg7ei32_v_f16mf4_m(vbool64_t, _Float16 *, vuint32mf2_t, vfloat16mf4_t, vfloat16mf4_t, vfloat16mf4_t, vfloat16mf4_t, vfloat16mf4_t, vfloat16mf4_t, vfloat16mf4_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vsuxseg8ei32_v)))
void vsuxseg8ei32_v_f16m1(_Float16 *, vuint32m2_t, vfloat16m1_t, vfloat16m1_t, vfloat16m1_t, vfloat16m1_t, vfloat16m1_t, vfloat16m1_t, vfloat16m1_t, vfloat16m1_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vsuxseg8ei32_v_m)))
void vsuxseg8ei32_v_f16m1_m(vbool16_t, _Float16 *, vuint32m2_t, vfloat16m1_t, vfloat16m1_t, vfloat16m1_t, vfloat16m1_t, vfloat16m1_t, vfloat16m1_t, vfloat16m1_t, vfloat16m1_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vsuxseg8ei32_v)))
void vsuxseg8ei32_v_f16mf2(_Float16 *, vuint32m1_t, vfloat16mf2_t, vfloat16mf2_t, vfloat16mf2_t, vfloat16mf2_t, vfloat16mf2_t, vfloat16mf2_t, vfloat16mf2_t, vfloat16mf2_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vsuxseg8ei32_v_m)))
void vsuxseg8ei32_v_f16mf2_m(vbool32_t, _Float16 *, vuint32m1_t, vfloat16mf2_t, vfloat16mf2_t, vfloat16mf2_t, vfloat16mf2_t, vfloat16mf2_t, vfloat16mf2_t, vfloat16mf2_t, vfloat16mf2_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vsuxseg8ei32_v)))
void vsuxseg8ei32_v_f16mf4(_Float16 *, vuint32mf2_t, vfloat16mf4_t, vfloat16mf4_t, vfloat16mf4_t, vfloat16mf4_t, vfloat16mf4_t, vfloat16mf4_t, vfloat16mf4_t, vfloat16mf4_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vsuxseg8ei32_v_m)))
void vsuxseg8ei32_v_f16mf4_m(vbool64_t, _Float16 *, vuint32mf2_t, vfloat16mf4_t, vfloat16mf4_t, vfloat16mf4_t, vfloat16mf4_t, vfloat16mf4_t, vfloat16mf4_t, vfloat16mf4_t, vfloat16mf4_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vsoxseg2ei8_v)))
void vsoxseg2ei8_v_f16m1(_Float16 *, vuint8mf2_t, vfloat16m1_t, vfloat16m1_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vsoxseg2ei8_v_m)))
void vsoxseg2ei8_v_f16m1_m(vbool16_t, _Float16 *, vuint8mf2_t, vfloat16m1_t, vfloat16m1_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vsoxseg2ei8_v)))
void vsoxseg2ei8_v_f16m2(_Float16 *, vuint8m1_t, vfloat16m2_t, vfloat16m2_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vsoxseg2ei8_v_m)))
void vsoxseg2ei8_v_f16m2_m(vbool8_t, _Float16 *, vuint8m1_t, vfloat16m2_t, vfloat16m2_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vsoxseg2ei8_v)))
void vsoxseg2ei8_v_f16m4(_Float16 *, vuint8m2_t, vfloat16m4_t, vfloat16m4_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vsoxseg2ei8_v_m)))
void vsoxseg2ei8_v_f16m4_m(vbool4_t, _Float16 *, vuint8m2_t, vfloat16m4_t, vfloat16m4_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vsoxseg2ei8_v)))
void vsoxseg2ei8_v_f16mf2(_Float16 *, vuint8mf4_t, vfloat16mf2_t, vfloat16mf2_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vsoxseg2ei8_v_m)))
void vsoxseg2ei8_v_f16mf2_m(vbool32_t, _Float16 *, vuint8mf4_t, vfloat16mf2_t, vfloat16mf2_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vsoxseg2ei8_v)))
void vsoxseg2ei8_v_f16mf4(_Float16 *, vuint8mf8_t, vfloat16mf4_t, vfloat16mf4_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vsoxseg2ei8_v_m)))
void vsoxseg2ei8_v_f16mf4_m(vbool64_t, _Float16 *, vuint8mf8_t, vfloat16mf4_t, vfloat16mf4_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vsoxseg3ei8_v)))
void vsoxseg3ei8_v_f16m1(_Float16 *, vuint8mf2_t, vfloat16m1_t, vfloat16m1_t, vfloat16m1_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vsoxseg3ei8_v_m)))
void vsoxseg3ei8_v_f16m1_m(vbool16_t, _Float16 *, vuint8mf2_t, vfloat16m1_t, vfloat16m1_t, vfloat16m1_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vsoxseg3ei8_v)))
void vsoxseg3ei8_v_f16m2(_Float16 *, vuint8m1_t, vfloat16m2_t, vfloat16m2_t, vfloat16m2_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vsoxseg3ei8_v_m)))
void vsoxseg3ei8_v_f16m2_m(vbool8_t, _Float16 *, vuint8m1_t, vfloat16m2_t, vfloat16m2_t, vfloat16m2_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vsoxseg3ei8_v)))
void vsoxseg3ei8_v_f16mf2(_Float16 *, vuint8mf4_t, vfloat16mf2_t, vfloat16mf2_t, vfloat16mf2_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vsoxseg3ei8_v_m)))
void vsoxseg3ei8_v_f16mf2_m(vbool32_t, _Float16 *, vuint8mf4_t, vfloat16mf2_t, vfloat16mf2_t, vfloat16mf2_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vsoxseg3ei8_v)))
void vsoxseg3ei8_v_f16mf4(_Float16 *, vuint8mf8_t, vfloat16mf4_t, vfloat16mf4_t, vfloat16mf4_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vsoxseg3ei8_v_m)))
void vsoxseg3ei8_v_f16mf4_m(vbool64_t, _Float16 *, vuint8mf8_t, vfloat16mf4_t, vfloat16mf4_t, vfloat16mf4_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vsoxseg4ei8_v)))
void vsoxseg4ei8_v_f16m1(_Float16 *, vuint8mf2_t, vfloat16m1_t, vfloat16m1_t, vfloat16m1_t, vfloat16m1_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vsoxseg4ei8_v_m)))
void vsoxseg4ei8_v_f16m1_m(vbool16_t, _Float16 *, vuint8mf2_t, vfloat16m1_t, vfloat16m1_t, vfloat16m1_t, vfloat16m1_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vsoxseg4ei8_v)))
void vsoxseg4ei8_v_f16m2(_Float16 *, vuint8m1_t, vfloat16m2_t, vfloat16m2_t, vfloat16m2_t, vfloat16m2_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vsoxseg4ei8_v_m)))
void vsoxseg4ei8_v_f16m2_m(vbool8_t, _Float16 *, vuint8m1_t, vfloat16m2_t, vfloat16m2_t, vfloat16m2_t, vfloat16m2_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vsoxseg4ei8_v)))
void vsoxseg4ei8_v_f16mf2(_Float16 *, vuint8mf4_t, vfloat16mf2_t, vfloat16mf2_t, vfloat16mf2_t, vfloat16mf2_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vsoxseg4ei8_v_m)))
void vsoxseg4ei8_v_f16mf2_m(vbool32_t, _Float16 *, vuint8mf4_t, vfloat16mf2_t, vfloat16mf2_t, vfloat16mf2_t, vfloat16mf2_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vsoxseg4ei8_v)))
void vsoxseg4ei8_v_f16mf4(_Float16 *, vuint8mf8_t, vfloat16mf4_t, vfloat16mf4_t, vfloat16mf4_t, vfloat16mf4_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vsoxseg4ei8_v_m)))
void vsoxseg4ei8_v_f16mf4_m(vbool64_t, _Float16 *, vuint8mf8_t, vfloat16mf4_t, vfloat16mf4_t, vfloat16mf4_t, vfloat16mf4_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vsoxseg5ei8_v)))
void vsoxseg5ei8_v_f16m1(_Float16 *, vuint8mf2_t, vfloat16m1_t, vfloat16m1_t, vfloat16m1_t, vfloat16m1_t, vfloat16m1_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vsoxseg5ei8_v_m)))
void vsoxseg5ei8_v_f16m1_m(vbool16_t, _Float16 *, vuint8mf2_t, vfloat16m1_t, vfloat16m1_t, vfloat16m1_t, vfloat16m1_t, vfloat16m1_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vsoxseg5ei8_v)))
void vsoxseg5ei8_v_f16mf2(_Float16 *, vuint8mf4_t, vfloat16mf2_t, vfloat16mf2_t, vfloat16mf2_t, vfloat16mf2_t, vfloat16mf2_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vsoxseg5ei8_v_m)))
void vsoxseg5ei8_v_f16mf2_m(vbool32_t, _Float16 *, vuint8mf4_t, vfloat16mf2_t, vfloat16mf2_t, vfloat16mf2_t, vfloat16mf2_t, vfloat16mf2_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vsoxseg5ei8_v)))
void vsoxseg5ei8_v_f16mf4(_Float16 *, vuint8mf8_t, vfloat16mf4_t, vfloat16mf4_t, vfloat16mf4_t, vfloat16mf4_t, vfloat16mf4_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vsoxseg5ei8_v_m)))
void vsoxseg5ei8_v_f16mf4_m(vbool64_t, _Float16 *, vuint8mf8_t, vfloat16mf4_t, vfloat16mf4_t, vfloat16mf4_t, vfloat16mf4_t, vfloat16mf4_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vsoxseg6ei8_v)))
void vsoxseg6ei8_v_f16m1(_Float16 *, vuint8mf2_t, vfloat16m1_t, vfloat16m1_t, vfloat16m1_t, vfloat16m1_t, vfloat16m1_t, vfloat16m1_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vsoxseg6ei8_v_m)))
void vsoxseg6ei8_v_f16m1_m(vbool16_t, _Float16 *, vuint8mf2_t, vfloat16m1_t, vfloat16m1_t, vfloat16m1_t, vfloat16m1_t, vfloat16m1_t, vfloat16m1_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vsoxseg6ei8_v)))
void vsoxseg6ei8_v_f16mf2(_Float16 *, vuint8mf4_t, vfloat16mf2_t, vfloat16mf2_t, vfloat16mf2_t, vfloat16mf2_t, vfloat16mf2_t, vfloat16mf2_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vsoxseg6ei8_v_m)))
void vsoxseg6ei8_v_f16mf2_m(vbool32_t, _Float16 *, vuint8mf4_t, vfloat16mf2_t, vfloat16mf2_t, vfloat16mf2_t, vfloat16mf2_t, vfloat16mf2_t, vfloat16mf2_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vsoxseg6ei8_v)))
void vsoxseg6ei8_v_f16mf4(_Float16 *, vuint8mf8_t, vfloat16mf4_t, vfloat16mf4_t, vfloat16mf4_t, vfloat16mf4_t, vfloat16mf4_t, vfloat16mf4_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vsoxseg6ei8_v_m)))
void vsoxseg6ei8_v_f16mf4_m(vbool64_t, _Float16 *, vuint8mf8_t, vfloat16mf4_t, vfloat16mf4_t, vfloat16mf4_t, vfloat16mf4_t, vfloat16mf4_t, vfloat16mf4_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vsoxseg7ei8_v)))
void vsoxseg7ei8_v_f16m1(_Float16 *, vuint8mf2_t, vfloat16m1_t, vfloat16m1_t, vfloat16m1_t, vfloat16m1_t, vfloat16m1_t, vfloat16m1_t, vfloat16m1_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vsoxseg7ei8_v_m)))
void vsoxseg7ei8_v_f16m1_m(vbool16_t, _Float16 *, vuint8mf2_t, vfloat16m1_t, vfloat16m1_t, vfloat16m1_t, vfloat16m1_t, vfloat16m1_t, vfloat16m1_t, vfloat16m1_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vsoxseg7ei8_v)))
void vsoxseg7ei8_v_f16mf2(_Float16 *, vuint8mf4_t, vfloat16mf2_t, vfloat16mf2_t, vfloat16mf2_t, vfloat16mf2_t, vfloat16mf2_t, vfloat16mf2_t, vfloat16mf2_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vsoxseg7ei8_v_m)))
void vsoxseg7ei8_v_f16mf2_m(vbool32_t, _Float16 *, vuint8mf4_t, vfloat16mf2_t, vfloat16mf2_t, vfloat16mf2_t, vfloat16mf2_t, vfloat16mf2_t, vfloat16mf2_t, vfloat16mf2_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vsoxseg7ei8_v)))
void vsoxseg7ei8_v_f16mf4(_Float16 *, vuint8mf8_t, vfloat16mf4_t, vfloat16mf4_t, vfloat16mf4_t, vfloat16mf4_t, vfloat16mf4_t, vfloat16mf4_t, vfloat16mf4_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vsoxseg7ei8_v_m)))
void vsoxseg7ei8_v_f16mf4_m(vbool64_t, _Float16 *, vuint8mf8_t, vfloat16mf4_t, vfloat16mf4_t, vfloat16mf4_t, vfloat16mf4_t, vfloat16mf4_t, vfloat16mf4_t, vfloat16mf4_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vsoxseg8ei8_v)))
void vsoxseg8ei8_v_f16m1(_Float16 *, vuint8mf2_t, vfloat16m1_t, vfloat16m1_t, vfloat16m1_t, vfloat16m1_t, vfloat16m1_t, vfloat16m1_t, vfloat16m1_t, vfloat16m1_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vsoxseg8ei8_v_m)))
void vsoxseg8ei8_v_f16m1_m(vbool16_t, _Float16 *, vuint8mf2_t, vfloat16m1_t, vfloat16m1_t, vfloat16m1_t, vfloat16m1_t, vfloat16m1_t, vfloat16m1_t, vfloat16m1_t, vfloat16m1_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vsoxseg8ei8_v)))
void vsoxseg8ei8_v_f16mf2(_Float16 *, vuint8mf4_t, vfloat16mf2_t, vfloat16mf2_t, vfloat16mf2_t, vfloat16mf2_t, vfloat16mf2_t, vfloat16mf2_t, vfloat16mf2_t, vfloat16mf2_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vsoxseg8ei8_v_m)))
void vsoxseg8ei8_v_f16mf2_m(vbool32_t, _Float16 *, vuint8mf4_t, vfloat16mf2_t, vfloat16mf2_t, vfloat16mf2_t, vfloat16mf2_t, vfloat16mf2_t, vfloat16mf2_t, vfloat16mf2_t, vfloat16mf2_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vsoxseg8ei8_v)))
void vsoxseg8ei8_v_f16mf4(_Float16 *, vuint8mf8_t, vfloat16mf4_t, vfloat16mf4_t, vfloat16mf4_t, vfloat16mf4_t, vfloat16mf4_t, vfloat16mf4_t, vfloat16mf4_t, vfloat16mf4_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vsoxseg8ei8_v_m)))
void vsoxseg8ei8_v_f16mf4_m(vbool64_t, _Float16 *, vuint8mf8_t, vfloat16mf4_t, vfloat16mf4_t, vfloat16mf4_t, vfloat16mf4_t, vfloat16mf4_t, vfloat16mf4_t, vfloat16mf4_t, vfloat16mf4_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vsoxseg2ei16_v)))
void vsoxseg2ei16_v_f16m1(_Float16 *, vuint16m1_t, vfloat16m1_t, vfloat16m1_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vsoxseg2ei16_v_m)))
void vsoxseg2ei16_v_f16m1_m(vbool16_t, _Float16 *, vuint16m1_t, vfloat16m1_t, vfloat16m1_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vsoxseg2ei16_v)))
void vsoxseg2ei16_v_f16m2(_Float16 *, vuint16m2_t, vfloat16m2_t, vfloat16m2_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vsoxseg2ei16_v_m)))
void vsoxseg2ei16_v_f16m2_m(vbool8_t, _Float16 *, vuint16m2_t, vfloat16m2_t, vfloat16m2_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vsoxseg2ei16_v)))
void vsoxseg2ei16_v_f16m4(_Float16 *, vuint16m4_t, vfloat16m4_t, vfloat16m4_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vsoxseg2ei16_v_m)))
void vsoxseg2ei16_v_f16m4_m(vbool4_t, _Float16 *, vuint16m4_t, vfloat16m4_t, vfloat16m4_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vsoxseg2ei16_v)))
void vsoxseg2ei16_v_f16mf2(_Float16 *, vuint16mf2_t, vfloat16mf2_t, vfloat16mf2_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vsoxseg2ei16_v_m)))
void vsoxseg2ei16_v_f16mf2_m(vbool32_t, _Float16 *, vuint16mf2_t, vfloat16mf2_t, vfloat16mf2_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vsoxseg2ei16_v)))
void vsoxseg2ei16_v_f16mf4(_Float16 *, vuint16mf4_t, vfloat16mf4_t, vfloat16mf4_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vsoxseg2ei16_v_m)))
void vsoxseg2ei16_v_f16mf4_m(vbool64_t, _Float16 *, vuint16mf4_t, vfloat16mf4_t, vfloat16mf4_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vsoxseg3ei16_v)))
void vsoxseg3ei16_v_f16m1(_Float16 *, vuint16m1_t, vfloat16m1_t, vfloat16m1_t, vfloat16m1_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vsoxseg3ei16_v_m)))
void vsoxseg3ei16_v_f16m1_m(vbool16_t, _Float16 *, vuint16m1_t, vfloat16m1_t, vfloat16m1_t, vfloat16m1_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vsoxseg3ei16_v)))
void vsoxseg3ei16_v_f16m2(_Float16 *, vuint16m2_t, vfloat16m2_t, vfloat16m2_t, vfloat16m2_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vsoxseg3ei16_v_m)))
void vsoxseg3ei16_v_f16m2_m(vbool8_t, _Float16 *, vuint16m2_t, vfloat16m2_t, vfloat16m2_t, vfloat16m2_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vsoxseg3ei16_v)))
void vsoxseg3ei16_v_f16mf2(_Float16 *, vuint16mf2_t, vfloat16mf2_t, vfloat16mf2_t, vfloat16mf2_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vsoxseg3ei16_v_m)))
void vsoxseg3ei16_v_f16mf2_m(vbool32_t, _Float16 *, vuint16mf2_t, vfloat16mf2_t, vfloat16mf2_t, vfloat16mf2_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vsoxseg3ei16_v)))
void vsoxseg3ei16_v_f16mf4(_Float16 *, vuint16mf4_t, vfloat16mf4_t, vfloat16mf4_t, vfloat16mf4_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vsoxseg3ei16_v_m)))
void vsoxseg3ei16_v_f16mf4_m(vbool64_t, _Float16 *, vuint16mf4_t, vfloat16mf4_t, vfloat16mf4_t, vfloat16mf4_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vsoxseg4ei16_v)))
void vsoxseg4ei16_v_f16m1(_Float16 *, vuint16m1_t, vfloat16m1_t, vfloat16m1_t, vfloat16m1_t, vfloat16m1_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vsoxseg4ei16_v_m)))
void vsoxseg4ei16_v_f16m1_m(vbool16_t, _Float16 *, vuint16m1_t, vfloat16m1_t, vfloat16m1_t, vfloat16m1_t, vfloat16m1_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vsoxseg4ei16_v)))
void vsoxseg4ei16_v_f16m2(_Float16 *, vuint16m2_t, vfloat16m2_t, vfloat16m2_t, vfloat16m2_t, vfloat16m2_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vsoxseg4ei16_v_m)))
void vsoxseg4ei16_v_f16m2_m(vbool8_t, _Float16 *, vuint16m2_t, vfloat16m2_t, vfloat16m2_t, vfloat16m2_t, vfloat16m2_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vsoxseg4ei16_v)))
void vsoxseg4ei16_v_f16mf2(_Float16 *, vuint16mf2_t, vfloat16mf2_t, vfloat16mf2_t, vfloat16mf2_t, vfloat16mf2_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vsoxseg4ei16_v_m)))
void vsoxseg4ei16_v_f16mf2_m(vbool32_t, _Float16 *, vuint16mf2_t, vfloat16mf2_t, vfloat16mf2_t, vfloat16mf2_t, vfloat16mf2_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vsoxseg4ei16_v)))
void vsoxseg4ei16_v_f16mf4(_Float16 *, vuint16mf4_t, vfloat16mf4_t, vfloat16mf4_t, vfloat16mf4_t, vfloat16mf4_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vsoxseg4ei16_v_m)))
void vsoxseg4ei16_v_f16mf4_m(vbool64_t, _Float16 *, vuint16mf4_t, vfloat16mf4_t, vfloat16mf4_t, vfloat16mf4_t, vfloat16mf4_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vsoxseg5ei16_v)))
void vsoxseg5ei16_v_f16m1(_Float16 *, vuint16m1_t, vfloat16m1_t, vfloat16m1_t, vfloat16m1_t, vfloat16m1_t, vfloat16m1_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vsoxseg5ei16_v_m)))
void vsoxseg5ei16_v_f16m1_m(vbool16_t, _Float16 *, vuint16m1_t, vfloat16m1_t, vfloat16m1_t, vfloat16m1_t, vfloat16m1_t, vfloat16m1_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vsoxseg5ei16_v)))
void vsoxseg5ei16_v_f16mf2(_Float16 *, vuint16mf2_t, vfloat16mf2_t, vfloat16mf2_t, vfloat16mf2_t, vfloat16mf2_t, vfloat16mf2_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vsoxseg5ei16_v_m)))
void vsoxseg5ei16_v_f16mf2_m(vbool32_t, _Float16 *, vuint16mf2_t, vfloat16mf2_t, vfloat16mf2_t, vfloat16mf2_t, vfloat16mf2_t, vfloat16mf2_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vsoxseg5ei16_v)))
void vsoxseg5ei16_v_f16mf4(_Float16 *, vuint16mf4_t, vfloat16mf4_t, vfloat16mf4_t, vfloat16mf4_t, vfloat16mf4_t, vfloat16mf4_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vsoxseg5ei16_v_m)))
void vsoxseg5ei16_v_f16mf4_m(vbool64_t, _Float16 *, vuint16mf4_t, vfloat16mf4_t, vfloat16mf4_t, vfloat16mf4_t, vfloat16mf4_t, vfloat16mf4_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vsoxseg6ei16_v)))
void vsoxseg6ei16_v_f16m1(_Float16 *, vuint16m1_t, vfloat16m1_t, vfloat16m1_t, vfloat16m1_t, vfloat16m1_t, vfloat16m1_t, vfloat16m1_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vsoxseg6ei16_v_m)))
void vsoxseg6ei16_v_f16m1_m(vbool16_t, _Float16 *, vuint16m1_t, vfloat16m1_t, vfloat16m1_t, vfloat16m1_t, vfloat16m1_t, vfloat16m1_t, vfloat16m1_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vsoxseg6ei16_v)))
void vsoxseg6ei16_v_f16mf2(_Float16 *, vuint16mf2_t, vfloat16mf2_t, vfloat16mf2_t, vfloat16mf2_t, vfloat16mf2_t, vfloat16mf2_t, vfloat16mf2_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vsoxseg6ei16_v_m)))
void vsoxseg6ei16_v_f16mf2_m(vbool32_t, _Float16 *, vuint16mf2_t, vfloat16mf2_t, vfloat16mf2_t, vfloat16mf2_t, vfloat16mf2_t, vfloat16mf2_t, vfloat16mf2_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vsoxseg6ei16_v)))
void vsoxseg6ei16_v_f16mf4(_Float16 *, vuint16mf4_t, vfloat16mf4_t, vfloat16mf4_t, vfloat16mf4_t, vfloat16mf4_t, vfloat16mf4_t, vfloat16mf4_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vsoxseg6ei16_v_m)))
void vsoxseg6ei16_v_f16mf4_m(vbool64_t, _Float16 *, vuint16mf4_t, vfloat16mf4_t, vfloat16mf4_t, vfloat16mf4_t, vfloat16mf4_t, vfloat16mf4_t, vfloat16mf4_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vsoxseg7ei16_v)))
void vsoxseg7ei16_v_f16m1(_Float16 *, vuint16m1_t, vfloat16m1_t, vfloat16m1_t, vfloat16m1_t, vfloat16m1_t, vfloat16m1_t, vfloat16m1_t, vfloat16m1_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vsoxseg7ei16_v_m)))
void vsoxseg7ei16_v_f16m1_m(vbool16_t, _Float16 *, vuint16m1_t, vfloat16m1_t, vfloat16m1_t, vfloat16m1_t, vfloat16m1_t, vfloat16m1_t, vfloat16m1_t, vfloat16m1_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vsoxseg7ei16_v)))
void vsoxseg7ei16_v_f16mf2(_Float16 *, vuint16mf2_t, vfloat16mf2_t, vfloat16mf2_t, vfloat16mf2_t, vfloat16mf2_t, vfloat16mf2_t, vfloat16mf2_t, vfloat16mf2_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vsoxseg7ei16_v_m)))
void vsoxseg7ei16_v_f16mf2_m(vbool32_t, _Float16 *, vuint16mf2_t, vfloat16mf2_t, vfloat16mf2_t, vfloat16mf2_t, vfloat16mf2_t, vfloat16mf2_t, vfloat16mf2_t, vfloat16mf2_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vsoxseg7ei16_v)))
void vsoxseg7ei16_v_f16mf4(_Float16 *, vuint16mf4_t, vfloat16mf4_t, vfloat16mf4_t, vfloat16mf4_t, vfloat16mf4_t, vfloat16mf4_t, vfloat16mf4_t, vfloat16mf4_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vsoxseg7ei16_v_m)))
void vsoxseg7ei16_v_f16mf4_m(vbool64_t, _Float16 *, vuint16mf4_t, vfloat16mf4_t, vfloat16mf4_t, vfloat16mf4_t, vfloat16mf4_t, vfloat16mf4_t, vfloat16mf4_t, vfloat16mf4_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vsoxseg8ei16_v)))
void vsoxseg8ei16_v_f16m1(_Float16 *, vuint16m1_t, vfloat16m1_t, vfloat16m1_t, vfloat16m1_t, vfloat16m1_t, vfloat16m1_t, vfloat16m1_t, vfloat16m1_t, vfloat16m1_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vsoxseg8ei16_v_m)))
void vsoxseg8ei16_v_f16m1_m(vbool16_t, _Float16 *, vuint16m1_t, vfloat16m1_t, vfloat16m1_t, vfloat16m1_t, vfloat16m1_t, vfloat16m1_t, vfloat16m1_t, vfloat16m1_t, vfloat16m1_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vsoxseg8ei16_v)))
void vsoxseg8ei16_v_f16mf2(_Float16 *, vuint16mf2_t, vfloat16mf2_t, vfloat16mf2_t, vfloat16mf2_t, vfloat16mf2_t, vfloat16mf2_t, vfloat16mf2_t, vfloat16mf2_t, vfloat16mf2_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vsoxseg8ei16_v_m)))
void vsoxseg8ei16_v_f16mf2_m(vbool32_t, _Float16 *, vuint16mf2_t, vfloat16mf2_t, vfloat16mf2_t, vfloat16mf2_t, vfloat16mf2_t, vfloat16mf2_t, vfloat16mf2_t, vfloat16mf2_t, vfloat16mf2_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vsoxseg8ei16_v)))
void vsoxseg8ei16_v_f16mf4(_Float16 *, vuint16mf4_t, vfloat16mf4_t, vfloat16mf4_t, vfloat16mf4_t, vfloat16mf4_t, vfloat16mf4_t, vfloat16mf4_t, vfloat16mf4_t, vfloat16mf4_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vsoxseg8ei16_v_m)))
void vsoxseg8ei16_v_f16mf4_m(vbool64_t, _Float16 *, vuint16mf4_t, vfloat16mf4_t, vfloat16mf4_t, vfloat16mf4_t, vfloat16mf4_t, vfloat16mf4_t, vfloat16mf4_t, vfloat16mf4_t, vfloat16mf4_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vsoxseg2ei32_v)))
void vsoxseg2ei32_v_f16m1(_Float16 *, vuint32m2_t, vfloat16m1_t, vfloat16m1_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vsoxseg2ei32_v_m)))
void vsoxseg2ei32_v_f16m1_m(vbool16_t, _Float16 *, vuint32m2_t, vfloat16m1_t, vfloat16m1_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vsoxseg2ei32_v)))
void vsoxseg2ei32_v_f16m2(_Float16 *, vuint32m4_t, vfloat16m2_t, vfloat16m2_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vsoxseg2ei32_v_m)))
void vsoxseg2ei32_v_f16m2_m(vbool8_t, _Float16 *, vuint32m4_t, vfloat16m2_t, vfloat16m2_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vsoxseg2ei32_v)))
void vsoxseg2ei32_v_f16m4(_Float16 *, vuint32m8_t, vfloat16m4_t, vfloat16m4_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vsoxseg2ei32_v_m)))
void vsoxseg2ei32_v_f16m4_m(vbool4_t, _Float16 *, vuint32m8_t, vfloat16m4_t, vfloat16m4_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vsoxseg2ei32_v)))
void vsoxseg2ei32_v_f16mf2(_Float16 *, vuint32m1_t, vfloat16mf2_t, vfloat16mf2_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vsoxseg2ei32_v_m)))
void vsoxseg2ei32_v_f16mf2_m(vbool32_t, _Float16 *, vuint32m1_t, vfloat16mf2_t, vfloat16mf2_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vsoxseg2ei32_v)))
void vsoxseg2ei32_v_f16mf4(_Float16 *, vuint32mf2_t, vfloat16mf4_t, vfloat16mf4_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vsoxseg2ei32_v_m)))
void vsoxseg2ei32_v_f16mf4_m(vbool64_t, _Float16 *, vuint32mf2_t, vfloat16mf4_t, vfloat16mf4_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vsoxseg3ei32_v)))
void vsoxseg3ei32_v_f16m1(_Float16 *, vuint32m2_t, vfloat16m1_t, vfloat16m1_t, vfloat16m1_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vsoxseg3ei32_v_m)))
void vsoxseg3ei32_v_f16m1_m(vbool16_t, _Float16 *, vuint32m2_t, vfloat16m1_t, vfloat16m1_t, vfloat16m1_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vsoxseg3ei32_v)))
void vsoxseg3ei32_v_f16m2(_Float16 *, vuint32m4_t, vfloat16m2_t, vfloat16m2_t, vfloat16m2_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vsoxseg3ei32_v_m)))
void vsoxseg3ei32_v_f16m2_m(vbool8_t, _Float16 *, vuint32m4_t, vfloat16m2_t, vfloat16m2_t, vfloat16m2_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vsoxseg3ei32_v)))
void vsoxseg3ei32_v_f16mf2(_Float16 *, vuint32m1_t, vfloat16mf2_t, vfloat16mf2_t, vfloat16mf2_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vsoxseg3ei32_v_m)))
void vsoxseg3ei32_v_f16mf2_m(vbool32_t, _Float16 *, vuint32m1_t, vfloat16mf2_t, vfloat16mf2_t, vfloat16mf2_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vsoxseg3ei32_v)))
void vsoxseg3ei32_v_f16mf4(_Float16 *, vuint32mf2_t, vfloat16mf4_t, vfloat16mf4_t, vfloat16mf4_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vsoxseg3ei32_v_m)))
void vsoxseg3ei32_v_f16mf4_m(vbool64_t, _Float16 *, vuint32mf2_t, vfloat16mf4_t, vfloat16mf4_t, vfloat16mf4_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vsoxseg4ei32_v)))
void vsoxseg4ei32_v_f16m1(_Float16 *, vuint32m2_t, vfloat16m1_t, vfloat16m1_t, vfloat16m1_t, vfloat16m1_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vsoxseg4ei32_v_m)))
void vsoxseg4ei32_v_f16m1_m(vbool16_t, _Float16 *, vuint32m2_t, vfloat16m1_t, vfloat16m1_t, vfloat16m1_t, vfloat16m1_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vsoxseg4ei32_v)))
void vsoxseg4ei32_v_f16m2(_Float16 *, vuint32m4_t, vfloat16m2_t, vfloat16m2_t, vfloat16m2_t, vfloat16m2_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vsoxseg4ei32_v_m)))
void vsoxseg4ei32_v_f16m2_m(vbool8_t, _Float16 *, vuint32m4_t, vfloat16m2_t, vfloat16m2_t, vfloat16m2_t, vfloat16m2_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vsoxseg4ei32_v)))
void vsoxseg4ei32_v_f16mf2(_Float16 *, vuint32m1_t, vfloat16mf2_t, vfloat16mf2_t, vfloat16mf2_t, vfloat16mf2_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vsoxseg4ei32_v_m)))
void vsoxseg4ei32_v_f16mf2_m(vbool32_t, _Float16 *, vuint32m1_t, vfloat16mf2_t, vfloat16mf2_t, vfloat16mf2_t, vfloat16mf2_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vsoxseg4ei32_v)))
void vsoxseg4ei32_v_f16mf4(_Float16 *, vuint32mf2_t, vfloat16mf4_t, vfloat16mf4_t, vfloat16mf4_t, vfloat16mf4_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vsoxseg4ei32_v_m)))
void vsoxseg4ei32_v_f16mf4_m(vbool64_t, _Float16 *, vuint32mf2_t, vfloat16mf4_t, vfloat16mf4_t, vfloat16mf4_t, vfloat16mf4_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vsoxseg5ei32_v)))
void vsoxseg5ei32_v_f16m1(_Float16 *, vuint32m2_t, vfloat16m1_t, vfloat16m1_t, vfloat16m1_t, vfloat16m1_t, vfloat16m1_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vsoxseg5ei32_v_m)))
void vsoxseg5ei32_v_f16m1_m(vbool16_t, _Float16 *, vuint32m2_t, vfloat16m1_t, vfloat16m1_t, vfloat16m1_t, vfloat16m1_t, vfloat16m1_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vsoxseg5ei32_v)))
void vsoxseg5ei32_v_f16mf2(_Float16 *, vuint32m1_t, vfloat16mf2_t, vfloat16mf2_t, vfloat16mf2_t, vfloat16mf2_t, vfloat16mf2_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vsoxseg5ei32_v_m)))
void vsoxseg5ei32_v_f16mf2_m(vbool32_t, _Float16 *, vuint32m1_t, vfloat16mf2_t, vfloat16mf2_t, vfloat16mf2_t, vfloat16mf2_t, vfloat16mf2_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vsoxseg5ei32_v)))
void vsoxseg5ei32_v_f16mf4(_Float16 *, vuint32mf2_t, vfloat16mf4_t, vfloat16mf4_t, vfloat16mf4_t, vfloat16mf4_t, vfloat16mf4_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vsoxseg5ei32_v_m)))
void vsoxseg5ei32_v_f16mf4_m(vbool64_t, _Float16 *, vuint32mf2_t, vfloat16mf4_t, vfloat16mf4_t, vfloat16mf4_t, vfloat16mf4_t, vfloat16mf4_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vsoxseg6ei32_v)))
void vsoxseg6ei32_v_f16m1(_Float16 *, vuint32m2_t, vfloat16m1_t, vfloat16m1_t, vfloat16m1_t, vfloat16m1_t, vfloat16m1_t, vfloat16m1_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vsoxseg6ei32_v_m)))
void vsoxseg6ei32_v_f16m1_m(vbool16_t, _Float16 *, vuint32m2_t, vfloat16m1_t, vfloat16m1_t, vfloat16m1_t, vfloat16m1_t, vfloat16m1_t, vfloat16m1_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vsoxseg6ei32_v)))
void vsoxseg6ei32_v_f16mf2(_Float16 *, vuint32m1_t, vfloat16mf2_t, vfloat16mf2_t, vfloat16mf2_t, vfloat16mf2_t, vfloat16mf2_t, vfloat16mf2_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vsoxseg6ei32_v_m)))
void vsoxseg6ei32_v_f16mf2_m(vbool32_t, _Float16 *, vuint32m1_t, vfloat16mf2_t, vfloat16mf2_t, vfloat16mf2_t, vfloat16mf2_t, vfloat16mf2_t, vfloat16mf2_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vsoxseg6ei32_v)))
void vsoxseg6ei32_v_f16mf4(_Float16 *, vuint32mf2_t, vfloat16mf4_t, vfloat16mf4_t, vfloat16mf4_t, vfloat16mf4_t, vfloat16mf4_t, vfloat16mf4_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vsoxseg6ei32_v_m)))
void vsoxseg6ei32_v_f16mf4_m(vbool64_t, _Float16 *, vuint32mf2_t, vfloat16mf4_t, vfloat16mf4_t, vfloat16mf4_t, vfloat16mf4_t, vfloat16mf4_t, vfloat16mf4_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vsoxseg7ei32_v)))
void vsoxseg7ei32_v_f16m1(_Float16 *, vuint32m2_t, vfloat16m1_t, vfloat16m1_t, vfloat16m1_t, vfloat16m1_t, vfloat16m1_t, vfloat16m1_t, vfloat16m1_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vsoxseg7ei32_v_m)))
void vsoxseg7ei32_v_f16m1_m(vbool16_t, _Float16 *, vuint32m2_t, vfloat16m1_t, vfloat16m1_t, vfloat16m1_t, vfloat16m1_t, vfloat16m1_t, vfloat16m1_t, vfloat16m1_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vsoxseg7ei32_v)))
void vsoxseg7ei32_v_f16mf2(_Float16 *, vuint32m1_t, vfloat16mf2_t, vfloat16mf2_t, vfloat16mf2_t, vfloat16mf2_t, vfloat16mf2_t, vfloat16mf2_t, vfloat16mf2_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vsoxseg7ei32_v_m)))
void vsoxseg7ei32_v_f16mf2_m(vbool32_t, _Float16 *, vuint32m1_t, vfloat16mf2_t, vfloat16mf2_t, vfloat16mf2_t, vfloat16mf2_t, vfloat16mf2_t, vfloat16mf2_t, vfloat16mf2_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vsoxseg7ei32_v)))
void vsoxseg7ei32_v_f16mf4(_Float16 *, vuint32mf2_t, vfloat16mf4_t, vfloat16mf4_t, vfloat16mf4_t, vfloat16mf4_t, vfloat16mf4_t, vfloat16mf4_t, vfloat16mf4_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vsoxseg7ei32_v_m)))
void vsoxseg7ei32_v_f16mf4_m(vbool64_t, _Float16 *, vuint32mf2_t, vfloat16mf4_t, vfloat16mf4_t, vfloat16mf4_t, vfloat16mf4_t, vfloat16mf4_t, vfloat16mf4_t, vfloat16mf4_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vsoxseg8ei32_v)))
void vsoxseg8ei32_v_f16m1(_Float16 *, vuint32m2_t, vfloat16m1_t, vfloat16m1_t, vfloat16m1_t, vfloat16m1_t, vfloat16m1_t, vfloat16m1_t, vfloat16m1_t, vfloat16m1_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vsoxseg8ei32_v_m)))
void vsoxseg8ei32_v_f16m1_m(vbool16_t, _Float16 *, vuint32m2_t, vfloat16m1_t, vfloat16m1_t, vfloat16m1_t, vfloat16m1_t, vfloat16m1_t, vfloat16m1_t, vfloat16m1_t, vfloat16m1_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vsoxseg8ei32_v)))
void vsoxseg8ei32_v_f16mf2(_Float16 *, vuint32m1_t, vfloat16mf2_t, vfloat16mf2_t, vfloat16mf2_t, vfloat16mf2_t, vfloat16mf2_t, vfloat16mf2_t, vfloat16mf2_t, vfloat16mf2_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vsoxseg8ei32_v_m)))
void vsoxseg8ei32_v_f16mf2_m(vbool32_t, _Float16 *, vuint32m1_t, vfloat16mf2_t, vfloat16mf2_t, vfloat16mf2_t, vfloat16mf2_t, vfloat16mf2_t, vfloat16mf2_t, vfloat16mf2_t, vfloat16mf2_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vsoxseg8ei32_v)))
void vsoxseg8ei32_v_f16mf4(_Float16 *, vuint32mf2_t, vfloat16mf4_t, vfloat16mf4_t, vfloat16mf4_t, vfloat16mf4_t, vfloat16mf4_t, vfloat16mf4_t, vfloat16mf4_t, vfloat16mf4_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vsoxseg8ei32_v_m)))
void vsoxseg8ei32_v_f16mf4_m(vbool64_t, _Float16 *, vuint32mf2_t, vfloat16mf4_t, vfloat16mf4_t, vfloat16mf4_t, vfloat16mf4_t, vfloat16mf4_t, vfloat16mf4_t, vfloat16mf4_t, vfloat16mf4_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vloxei8_v)))
vfloat16m1_t vloxei8_v_f16m1(const _Float16 *, vuint8mf2_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vloxei8_v_m)))
vfloat16m1_t vloxei8_v_f16m1_m(vbool16_t, vfloat16m1_t, const _Float16 *, vuint8mf2_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vloxei8_v)))
vfloat16m2_t vloxei8_v_f16m2(const _Float16 *, vuint8m1_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vloxei8_v_m)))
vfloat16m2_t vloxei8_v_f16m2_m(vbool8_t, vfloat16m2_t, const _Float16 *, vuint8m1_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vloxei8_v)))
vfloat16m4_t vloxei8_v_f16m4(const _Float16 *, vuint8m2_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vloxei8_v_m)))
vfloat16m4_t vloxei8_v_f16m4_m(vbool4_t, vfloat16m4_t, const _Float16 *, vuint8m2_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vloxei8_v)))
vfloat16m8_t vloxei8_v_f16m8(const _Float16 *, vuint8m4_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vloxei8_v_m)))
vfloat16m8_t vloxei8_v_f16m8_m(vbool2_t, vfloat16m8_t, const _Float16 *, vuint8m4_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vloxei8_v)))
vfloat16mf2_t vloxei8_v_f16mf2(const _Float16 *, vuint8mf4_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vloxei8_v_m)))
vfloat16mf2_t vloxei8_v_f16mf2_m(vbool32_t, vfloat16mf2_t, const _Float16 *, vuint8mf4_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vloxei8_v)))
vfloat16mf4_t vloxei8_v_f16mf4(const _Float16 *, vuint8mf8_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vloxei8_v_m)))
vfloat16mf4_t vloxei8_v_f16mf4_m(vbool64_t, vfloat16mf4_t, const _Float16 *, vuint8mf8_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vloxei16_v)))
vfloat16m1_t vloxei16_v_f16m1(const _Float16 *, vuint16m1_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vloxei16_v_m)))
vfloat16m1_t vloxei16_v_f16m1_m(vbool16_t, vfloat16m1_t, const _Float16 *, vuint16m1_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vloxei16_v)))
vfloat16m2_t vloxei16_v_f16m2(const _Float16 *, vuint16m2_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vloxei16_v_m)))
vfloat16m2_t vloxei16_v_f16m2_m(vbool8_t, vfloat16m2_t, const _Float16 *, vuint16m2_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vloxei16_v)))
vfloat16m4_t vloxei16_v_f16m4(const _Float16 *, vuint16m4_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vloxei16_v_m)))
vfloat16m4_t vloxei16_v_f16m4_m(vbool4_t, vfloat16m4_t, const _Float16 *, vuint16m4_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vloxei16_v)))
vfloat16m8_t vloxei16_v_f16m8(const _Float16 *, vuint16m8_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vloxei16_v_m)))
vfloat16m8_t vloxei16_v_f16m8_m(vbool2_t, vfloat16m8_t, const _Float16 *, vuint16m8_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vloxei16_v)))
vfloat16mf2_t vloxei16_v_f16mf2(const _Float16 *, vuint16mf2_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vloxei16_v_m)))
vfloat16mf2_t vloxei16_v_f16mf2_m(vbool32_t, vfloat16mf2_t, const _Float16 *, vuint16mf2_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vloxei16_v)))
vfloat16mf4_t vloxei16_v_f16mf4(const _Float16 *, vuint16mf4_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vloxei16_v_m)))
vfloat16mf4_t vloxei16_v_f16mf4_m(vbool64_t, vfloat16mf4_t, const _Float16 *, vuint16mf4_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vloxei32_v)))
vfloat16m1_t vloxei32_v_f16m1(const _Float16 *, vuint32m2_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vloxei32_v_m)))
vfloat16m1_t vloxei32_v_f16m1_m(vbool16_t, vfloat16m1_t, const _Float16 *, vuint32m2_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vloxei32_v)))
vfloat16m2_t vloxei32_v_f16m2(const _Float16 *, vuint32m4_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vloxei32_v_m)))
vfloat16m2_t vloxei32_v_f16m2_m(vbool8_t, vfloat16m2_t, const _Float16 *, vuint32m4_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vloxei32_v)))
vfloat16m4_t vloxei32_v_f16m4(const _Float16 *, vuint32m8_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vloxei32_v_m)))
vfloat16m4_t vloxei32_v_f16m4_m(vbool4_t, vfloat16m4_t, const _Float16 *, vuint32m8_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vloxei32_v)))
vfloat16mf2_t vloxei32_v_f16mf2(const _Float16 *, vuint32m1_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vloxei32_v_m)))
vfloat16mf2_t vloxei32_v_f16mf2_m(vbool32_t, vfloat16mf2_t, const _Float16 *, vuint32m1_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vloxei32_v)))
vfloat16mf4_t vloxei32_v_f16mf4(const _Float16 *, vuint32mf2_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vloxei32_v_m)))
vfloat16mf4_t vloxei32_v_f16mf4_m(vbool64_t, vfloat16mf4_t, const _Float16 *, vuint32mf2_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vmv_v_v)))
vfloat16m1_t vmv_v_v_f16m1(vfloat16m1_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vmv_v_v)))
vfloat16m2_t vmv_v_v_f16m2(vfloat16m2_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vmv_v_v)))
vfloat16m4_t vmv_v_v_f16m4(vfloat16m4_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vmv_v_v)))
vfloat16m8_t vmv_v_v_f16m8(vfloat16m8_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vmv_v_v)))
vfloat16mf2_t vmv_v_v_f16mf2(vfloat16mf2_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vmv_v_v)))
vfloat16mf4_t vmv_v_v_f16mf4(vfloat16mf4_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vfadd_vv)))
vfloat16m1_t vfadd_vv_f16m1(vfloat16m1_t, vfloat16m1_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vfadd_vv_m)))
vfloat16m1_t vfadd_vv_f16m1_m(vbool16_t, vfloat16m1_t, vfloat16m1_t, vfloat16m1_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vfadd_vv)))
vfloat16m2_t vfadd_vv_f16m2(vfloat16m2_t, vfloat16m2_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vfadd_vv_m)))
vfloat16m2_t vfadd_vv_f16m2_m(vbool8_t, vfloat16m2_t, vfloat16m2_t, vfloat16m2_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vfadd_vv)))
vfloat16m4_t vfadd_vv_f16m4(vfloat16m4_t, vfloat16m4_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vfadd_vv_m)))
vfloat16m4_t vfadd_vv_f16m4_m(vbool4_t, vfloat16m4_t, vfloat16m4_t, vfloat16m4_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vfadd_vv)))
vfloat16m8_t vfadd_vv_f16m8(vfloat16m8_t, vfloat16m8_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vfadd_vv_m)))
vfloat16m8_t vfadd_vv_f16m8_m(vbool2_t, vfloat16m8_t, vfloat16m8_t, vfloat16m8_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vfadd_vv)))
vfloat16mf2_t vfadd_vv_f16mf2(vfloat16mf2_t, vfloat16mf2_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vfadd_vv_m)))
vfloat16mf2_t vfadd_vv_f16mf2_m(vbool32_t, vfloat16mf2_t, vfloat16mf2_t, vfloat16mf2_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vfadd_vv)))
vfloat16mf4_t vfadd_vv_f16mf4(vfloat16mf4_t, vfloat16mf4_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vfadd_vv_m)))
vfloat16mf4_t vfadd_vv_f16mf4_m(vbool64_t, vfloat16mf4_t, vfloat16mf4_t, vfloat16mf4_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vfadd_vf)))
vfloat16m1_t vfadd_vf_f16m1(vfloat16m1_t, _Float16, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vfadd_vf_m)))
vfloat16m1_t vfadd_vf_f16m1_m(vbool16_t, vfloat16m1_t, vfloat16m1_t, _Float16, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vfadd_vf)))
vfloat16m2_t vfadd_vf_f16m2(vfloat16m2_t, _Float16, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vfadd_vf_m)))
vfloat16m2_t vfadd_vf_f16m2_m(vbool8_t, vfloat16m2_t, vfloat16m2_t, _Float16, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vfadd_vf)))
vfloat16m4_t vfadd_vf_f16m4(vfloat16m4_t, _Float16, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vfadd_vf_m)))
vfloat16m4_t vfadd_vf_f16m4_m(vbool4_t, vfloat16m4_t, vfloat16m4_t, _Float16, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vfadd_vf)))
vfloat16m8_t vfadd_vf_f16m8(vfloat16m8_t, _Float16, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vfadd_vf_m)))
vfloat16m8_t vfadd_vf_f16m8_m(vbool2_t, vfloat16m8_t, vfloat16m8_t, _Float16, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vfadd_vf)))
vfloat16mf2_t vfadd_vf_f16mf2(vfloat16mf2_t, _Float16, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vfadd_vf_m)))
vfloat16mf2_t vfadd_vf_f16mf2_m(vbool32_t, vfloat16mf2_t, vfloat16mf2_t, _Float16, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vfadd_vf)))
vfloat16mf4_t vfadd_vf_f16mf4(vfloat16mf4_t, _Float16, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vfadd_vf_m)))
vfloat16mf4_t vfadd_vf_f16mf4_m(vbool64_t, vfloat16mf4_t, vfloat16mf4_t, _Float16, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vfsub_vv)))
vfloat16m1_t vfsub_vv_f16m1(vfloat16m1_t, vfloat16m1_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vfsub_vv_m)))
vfloat16m1_t vfsub_vv_f16m1_m(vbool16_t, vfloat16m1_t, vfloat16m1_t, vfloat16m1_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vfsub_vv)))
vfloat16m2_t vfsub_vv_f16m2(vfloat16m2_t, vfloat16m2_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vfsub_vv_m)))
vfloat16m2_t vfsub_vv_f16m2_m(vbool8_t, vfloat16m2_t, vfloat16m2_t, vfloat16m2_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vfsub_vv)))
vfloat16m4_t vfsub_vv_f16m4(vfloat16m4_t, vfloat16m4_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vfsub_vv_m)))
vfloat16m4_t vfsub_vv_f16m4_m(vbool4_t, vfloat16m4_t, vfloat16m4_t, vfloat16m4_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vfsub_vv)))
vfloat16m8_t vfsub_vv_f16m8(vfloat16m8_t, vfloat16m8_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vfsub_vv_m)))
vfloat16m8_t vfsub_vv_f16m8_m(vbool2_t, vfloat16m8_t, vfloat16m8_t, vfloat16m8_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vfsub_vv)))
vfloat16mf2_t vfsub_vv_f16mf2(vfloat16mf2_t, vfloat16mf2_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vfsub_vv_m)))
vfloat16mf2_t vfsub_vv_f16mf2_m(vbool32_t, vfloat16mf2_t, vfloat16mf2_t, vfloat16mf2_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vfsub_vv)))
vfloat16mf4_t vfsub_vv_f16mf4(vfloat16mf4_t, vfloat16mf4_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vfsub_vv_m)))
vfloat16mf4_t vfsub_vv_f16mf4_m(vbool64_t, vfloat16mf4_t, vfloat16mf4_t, vfloat16mf4_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vfsub_vf)))
vfloat16m1_t vfsub_vf_f16m1(vfloat16m1_t, _Float16, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vfsub_vf_m)))
vfloat16m1_t vfsub_vf_f16m1_m(vbool16_t, vfloat16m1_t, vfloat16m1_t, _Float16, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vfsub_vf)))
vfloat16m2_t vfsub_vf_f16m2(vfloat16m2_t, _Float16, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vfsub_vf_m)))
vfloat16m2_t vfsub_vf_f16m2_m(vbool8_t, vfloat16m2_t, vfloat16m2_t, _Float16, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vfsub_vf)))
vfloat16m4_t vfsub_vf_f16m4(vfloat16m4_t, _Float16, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vfsub_vf_m)))
vfloat16m4_t vfsub_vf_f16m4_m(vbool4_t, vfloat16m4_t, vfloat16m4_t, _Float16, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vfsub_vf)))
vfloat16m8_t vfsub_vf_f16m8(vfloat16m8_t, _Float16, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vfsub_vf_m)))
vfloat16m8_t vfsub_vf_f16m8_m(vbool2_t, vfloat16m8_t, vfloat16m8_t, _Float16, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vfsub_vf)))
vfloat16mf2_t vfsub_vf_f16mf2(vfloat16mf2_t, _Float16, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vfsub_vf_m)))
vfloat16mf2_t vfsub_vf_f16mf2_m(vbool32_t, vfloat16mf2_t, vfloat16mf2_t, _Float16, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vfsub_vf)))
vfloat16mf4_t vfsub_vf_f16mf4(vfloat16mf4_t, _Float16, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vfsub_vf_m)))
vfloat16mf4_t vfsub_vf_f16mf4_m(vbool64_t, vfloat16mf4_t, vfloat16mf4_t, _Float16, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vfrsub_vf)))
vfloat16m1_t vfrsub_vf_f16m1(vfloat16m1_t, _Float16, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vfrsub_vf_m)))
vfloat16m1_t vfrsub_vf_f16m1_m(vbool16_t, vfloat16m1_t, vfloat16m1_t, _Float16, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vfrsub_vf)))
vfloat16m2_t vfrsub_vf_f16m2(vfloat16m2_t, _Float16, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vfrsub_vf_m)))
vfloat16m2_t vfrsub_vf_f16m2_m(vbool8_t, vfloat16m2_t, vfloat16m2_t, _Float16, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vfrsub_vf)))
vfloat16m4_t vfrsub_vf_f16m4(vfloat16m4_t, _Float16, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vfrsub_vf_m)))
vfloat16m4_t vfrsub_vf_f16m4_m(vbool4_t, vfloat16m4_t, vfloat16m4_t, _Float16, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vfrsub_vf)))
vfloat16m8_t vfrsub_vf_f16m8(vfloat16m8_t, _Float16, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vfrsub_vf_m)))
vfloat16m8_t vfrsub_vf_f16m8_m(vbool2_t, vfloat16m8_t, vfloat16m8_t, _Float16, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vfrsub_vf)))
vfloat16mf2_t vfrsub_vf_f16mf2(vfloat16mf2_t, _Float16, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vfrsub_vf_m)))
vfloat16mf2_t vfrsub_vf_f16mf2_m(vbool32_t, vfloat16mf2_t, vfloat16mf2_t, _Float16, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vfrsub_vf)))
vfloat16mf4_t vfrsub_vf_f16mf4(vfloat16mf4_t, _Float16, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vfrsub_vf_m)))
vfloat16mf4_t vfrsub_vf_f16mf4_m(vbool64_t, vfloat16mf4_t, vfloat16mf4_t, _Float16, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vfmul_vv)))
vfloat16m1_t vfmul_vv_f16m1(vfloat16m1_t, vfloat16m1_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vfmul_vv_m)))
vfloat16m1_t vfmul_vv_f16m1_m(vbool16_t, vfloat16m1_t, vfloat16m1_t, vfloat16m1_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vfmul_vv)))
vfloat16m2_t vfmul_vv_f16m2(vfloat16m2_t, vfloat16m2_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vfmul_vv_m)))
vfloat16m2_t vfmul_vv_f16m2_m(vbool8_t, vfloat16m2_t, vfloat16m2_t, vfloat16m2_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vfmul_vv)))
vfloat16m4_t vfmul_vv_f16m4(vfloat16m4_t, vfloat16m4_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vfmul_vv_m)))
vfloat16m4_t vfmul_vv_f16m4_m(vbool4_t, vfloat16m4_t, vfloat16m4_t, vfloat16m4_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vfmul_vv)))
vfloat16m8_t vfmul_vv_f16m8(vfloat16m8_t, vfloat16m8_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vfmul_vv_m)))
vfloat16m8_t vfmul_vv_f16m8_m(vbool2_t, vfloat16m8_t, vfloat16m8_t, vfloat16m8_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vfmul_vv)))
vfloat16mf2_t vfmul_vv_f16mf2(vfloat16mf2_t, vfloat16mf2_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vfmul_vv_m)))
vfloat16mf2_t vfmul_vv_f16mf2_m(vbool32_t, vfloat16mf2_t, vfloat16mf2_t, vfloat16mf2_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vfmul_vv)))
vfloat16mf4_t vfmul_vv_f16mf4(vfloat16mf4_t, vfloat16mf4_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vfmul_vv_m)))
vfloat16mf4_t vfmul_vv_f16mf4_m(vbool64_t, vfloat16mf4_t, vfloat16mf4_t, vfloat16mf4_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vfmul_vf)))
vfloat16m1_t vfmul_vf_f16m1(vfloat16m1_t, _Float16, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vfmul_vf_m)))
vfloat16m1_t vfmul_vf_f16m1_m(vbool16_t, vfloat16m1_t, vfloat16m1_t, _Float16, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vfmul_vf)))
vfloat16m2_t vfmul_vf_f16m2(vfloat16m2_t, _Float16, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vfmul_vf_m)))
vfloat16m2_t vfmul_vf_f16m2_m(vbool8_t, vfloat16m2_t, vfloat16m2_t, _Float16, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vfmul_vf)))
vfloat16m4_t vfmul_vf_f16m4(vfloat16m4_t, _Float16, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vfmul_vf_m)))
vfloat16m4_t vfmul_vf_f16m4_m(vbool4_t, vfloat16m4_t, vfloat16m4_t, _Float16, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vfmul_vf)))
vfloat16m8_t vfmul_vf_f16m8(vfloat16m8_t, _Float16, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vfmul_vf_m)))
vfloat16m8_t vfmul_vf_f16m8_m(vbool2_t, vfloat16m8_t, vfloat16m8_t, _Float16, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vfmul_vf)))
vfloat16mf2_t vfmul_vf_f16mf2(vfloat16mf2_t, _Float16, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vfmul_vf_m)))
vfloat16mf2_t vfmul_vf_f16mf2_m(vbool32_t, vfloat16mf2_t, vfloat16mf2_t, _Float16, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vfmul_vf)))
vfloat16mf4_t vfmul_vf_f16mf4(vfloat16mf4_t, _Float16, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vfmul_vf_m)))
vfloat16mf4_t vfmul_vf_f16mf4_m(vbool64_t, vfloat16mf4_t, vfloat16mf4_t, _Float16, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vfdiv_vv)))
vfloat16m1_t vfdiv_vv_f16m1(vfloat16m1_t, vfloat16m1_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vfdiv_vv_m)))
vfloat16m1_t vfdiv_vv_f16m1_m(vbool16_t, vfloat16m1_t, vfloat16m1_t, vfloat16m1_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vfdiv_vv)))
vfloat16m2_t vfdiv_vv_f16m2(vfloat16m2_t, vfloat16m2_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vfdiv_vv_m)))
vfloat16m2_t vfdiv_vv_f16m2_m(vbool8_t, vfloat16m2_t, vfloat16m2_t, vfloat16m2_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vfdiv_vv)))
vfloat16m4_t vfdiv_vv_f16m4(vfloat16m4_t, vfloat16m4_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vfdiv_vv_m)))
vfloat16m4_t vfdiv_vv_f16m4_m(vbool4_t, vfloat16m4_t, vfloat16m4_t, vfloat16m4_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vfdiv_vv)))
vfloat16m8_t vfdiv_vv_f16m8(vfloat16m8_t, vfloat16m8_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vfdiv_vv_m)))
vfloat16m8_t vfdiv_vv_f16m8_m(vbool2_t, vfloat16m8_t, vfloat16m8_t, vfloat16m8_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vfdiv_vv)))
vfloat16mf2_t vfdiv_vv_f16mf2(vfloat16mf2_t, vfloat16mf2_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vfdiv_vv_m)))
vfloat16mf2_t vfdiv_vv_f16mf2_m(vbool32_t, vfloat16mf2_t, vfloat16mf2_t, vfloat16mf2_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vfdiv_vv)))
vfloat16mf4_t vfdiv_vv_f16mf4(vfloat16mf4_t, vfloat16mf4_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vfdiv_vv_m)))
vfloat16mf4_t vfdiv_vv_f16mf4_m(vbool64_t, vfloat16mf4_t, vfloat16mf4_t, vfloat16mf4_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vfdiv_vf)))
vfloat16m1_t vfdiv_vf_f16m1(vfloat16m1_t, _Float16, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vfdiv_vf_m)))
vfloat16m1_t vfdiv_vf_f16m1_m(vbool16_t, vfloat16m1_t, vfloat16m1_t, _Float16, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vfdiv_vf)))
vfloat16m2_t vfdiv_vf_f16m2(vfloat16m2_t, _Float16, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vfdiv_vf_m)))
vfloat16m2_t vfdiv_vf_f16m2_m(vbool8_t, vfloat16m2_t, vfloat16m2_t, _Float16, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vfdiv_vf)))
vfloat16m4_t vfdiv_vf_f16m4(vfloat16m4_t, _Float16, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vfdiv_vf_m)))
vfloat16m4_t vfdiv_vf_f16m4_m(vbool4_t, vfloat16m4_t, vfloat16m4_t, _Float16, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vfdiv_vf)))
vfloat16m8_t vfdiv_vf_f16m8(vfloat16m8_t, _Float16, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vfdiv_vf_m)))
vfloat16m8_t vfdiv_vf_f16m8_m(vbool2_t, vfloat16m8_t, vfloat16m8_t, _Float16, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vfdiv_vf)))
vfloat16mf2_t vfdiv_vf_f16mf2(vfloat16mf2_t, _Float16, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vfdiv_vf_m)))
vfloat16mf2_t vfdiv_vf_f16mf2_m(vbool32_t, vfloat16mf2_t, vfloat16mf2_t, _Float16, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vfdiv_vf)))
vfloat16mf4_t vfdiv_vf_f16mf4(vfloat16mf4_t, _Float16, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vfdiv_vf_m)))
vfloat16mf4_t vfdiv_vf_f16mf4_m(vbool64_t, vfloat16mf4_t, vfloat16mf4_t, _Float16, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vfrdiv_vf)))
vfloat16m1_t vfrdiv_vf_f16m1(vfloat16m1_t, _Float16, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vfrdiv_vf_m)))
vfloat16m1_t vfrdiv_vf_f16m1_m(vbool16_t, vfloat16m1_t, vfloat16m1_t, _Float16, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vfrdiv_vf)))
vfloat16m2_t vfrdiv_vf_f16m2(vfloat16m2_t, _Float16, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vfrdiv_vf_m)))
vfloat16m2_t vfrdiv_vf_f16m2_m(vbool8_t, vfloat16m2_t, vfloat16m2_t, _Float16, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vfrdiv_vf)))
vfloat16m4_t vfrdiv_vf_f16m4(vfloat16m4_t, _Float16, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vfrdiv_vf_m)))
vfloat16m4_t vfrdiv_vf_f16m4_m(vbool4_t, vfloat16m4_t, vfloat16m4_t, _Float16, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vfrdiv_vf)))
vfloat16m8_t vfrdiv_vf_f16m8(vfloat16m8_t, _Float16, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vfrdiv_vf_m)))
vfloat16m8_t vfrdiv_vf_f16m8_m(vbool2_t, vfloat16m8_t, vfloat16m8_t, _Float16, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vfrdiv_vf)))
vfloat16mf2_t vfrdiv_vf_f16mf2(vfloat16mf2_t, _Float16, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vfrdiv_vf_m)))
vfloat16mf2_t vfrdiv_vf_f16mf2_m(vbool32_t, vfloat16mf2_t, vfloat16mf2_t, _Float16, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vfrdiv_vf)))
vfloat16mf4_t vfrdiv_vf_f16mf4(vfloat16mf4_t, _Float16, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vfrdiv_vf_m)))
vfloat16mf4_t vfrdiv_vf_f16mf4_m(vbool64_t, vfloat16mf4_t, vfloat16mf4_t, _Float16, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vfmacc_vv)))
vfloat16m1_t vfmacc_vv_f16m1(vfloat16m1_t, vfloat16m1_t, vfloat16m1_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vfmacc_vv_m)))
vfloat16m1_t vfmacc_vv_f16m1_m(vbool16_t, vfloat16m1_t, vfloat16m1_t, vfloat16m1_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vfmacc_vv)))
vfloat16m2_t vfmacc_vv_f16m2(vfloat16m2_t, vfloat16m2_t, vfloat16m2_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vfmacc_vv_m)))
vfloat16m2_t vfmacc_vv_f16m2_m(vbool8_t, vfloat16m2_t, vfloat16m2_t, vfloat16m2_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vfmacc_vv)))
vfloat16m4_t vfmacc_vv_f16m4(vfloat16m4_t, vfloat16m4_t, vfloat16m4_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vfmacc_vv_m)))
vfloat16m4_t vfmacc_vv_f16m4_m(vbool4_t, vfloat16m4_t, vfloat16m4_t, vfloat16m4_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vfmacc_vv)))
vfloat16m8_t vfmacc_vv_f16m8(vfloat16m8_t, vfloat16m8_t, vfloat16m8_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vfmacc_vv_m)))
vfloat16m8_t vfmacc_vv_f16m8_m(vbool2_t, vfloat16m8_t, vfloat16m8_t, vfloat16m8_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vfmacc_vv)))
vfloat16mf2_t vfmacc_vv_f16mf2(vfloat16mf2_t, vfloat16mf2_t, vfloat16mf2_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vfmacc_vv_m)))
vfloat16mf2_t vfmacc_vv_f16mf2_m(vbool32_t, vfloat16mf2_t, vfloat16mf2_t, vfloat16mf2_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vfmacc_vv)))
vfloat16mf4_t vfmacc_vv_f16mf4(vfloat16mf4_t, vfloat16mf4_t, vfloat16mf4_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vfmacc_vv_m)))
vfloat16mf4_t vfmacc_vv_f16mf4_m(vbool64_t, vfloat16mf4_t, vfloat16mf4_t, vfloat16mf4_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vfmacc_vf)))
vfloat16m1_t vfmacc_vf_f16m1(vfloat16m1_t, _Float16, vfloat16m1_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vfmacc_vf_m)))
vfloat16m1_t vfmacc_vf_f16m1_m(vbool16_t, vfloat16m1_t, _Float16, vfloat16m1_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vfmacc_vf)))
vfloat16m2_t vfmacc_vf_f16m2(vfloat16m2_t, _Float16, vfloat16m2_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vfmacc_vf_m)))
vfloat16m2_t vfmacc_vf_f16m2_m(vbool8_t, vfloat16m2_t, _Float16, vfloat16m2_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vfmacc_vf)))
vfloat16m4_t vfmacc_vf_f16m4(vfloat16m4_t, _Float16, vfloat16m4_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vfmacc_vf_m)))
vfloat16m4_t vfmacc_vf_f16m4_m(vbool4_t, vfloat16m4_t, _Float16, vfloat16m4_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vfmacc_vf)))
vfloat16m8_t vfmacc_vf_f16m8(vfloat16m8_t, _Float16, vfloat16m8_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vfmacc_vf_m)))
vfloat16m8_t vfmacc_vf_f16m8_m(vbool2_t, vfloat16m8_t, _Float16, vfloat16m8_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vfmacc_vf)))
vfloat16mf2_t vfmacc_vf_f16mf2(vfloat16mf2_t, _Float16, vfloat16mf2_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vfmacc_vf_m)))
vfloat16mf2_t vfmacc_vf_f16mf2_m(vbool32_t, vfloat16mf2_t, _Float16, vfloat16mf2_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vfmacc_vf)))
vfloat16mf4_t vfmacc_vf_f16mf4(vfloat16mf4_t, _Float16, vfloat16mf4_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vfmacc_vf_m)))
vfloat16mf4_t vfmacc_vf_f16mf4_m(vbool64_t, vfloat16mf4_t, _Float16, vfloat16mf4_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vfnmacc_vv)))
vfloat16m1_t vfnmacc_vv_f16m1(vfloat16m1_t, vfloat16m1_t, vfloat16m1_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vfnmacc_vv_m)))
vfloat16m1_t vfnmacc_vv_f16m1_m(vbool16_t, vfloat16m1_t, vfloat16m1_t, vfloat16m1_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vfnmacc_vv)))
vfloat16m2_t vfnmacc_vv_f16m2(vfloat16m2_t, vfloat16m2_t, vfloat16m2_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vfnmacc_vv_m)))
vfloat16m2_t vfnmacc_vv_f16m2_m(vbool8_t, vfloat16m2_t, vfloat16m2_t, vfloat16m2_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vfnmacc_vv)))
vfloat16m4_t vfnmacc_vv_f16m4(vfloat16m4_t, vfloat16m4_t, vfloat16m4_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vfnmacc_vv_m)))
vfloat16m4_t vfnmacc_vv_f16m4_m(vbool4_t, vfloat16m4_t, vfloat16m4_t, vfloat16m4_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vfnmacc_vv)))
vfloat16m8_t vfnmacc_vv_f16m8(vfloat16m8_t, vfloat16m8_t, vfloat16m8_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vfnmacc_vv_m)))
vfloat16m8_t vfnmacc_vv_f16m8_m(vbool2_t, vfloat16m8_t, vfloat16m8_t, vfloat16m8_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vfnmacc_vv)))
vfloat16mf2_t vfnmacc_vv_f16mf2(vfloat16mf2_t, vfloat16mf2_t, vfloat16mf2_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vfnmacc_vv_m)))
vfloat16mf2_t vfnmacc_vv_f16mf2_m(vbool32_t, vfloat16mf2_t, vfloat16mf2_t, vfloat16mf2_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vfnmacc_vv)))
vfloat16mf4_t vfnmacc_vv_f16mf4(vfloat16mf4_t, vfloat16mf4_t, vfloat16mf4_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vfnmacc_vv_m)))
vfloat16mf4_t vfnmacc_vv_f16mf4_m(vbool64_t, vfloat16mf4_t, vfloat16mf4_t, vfloat16mf4_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vfnmacc_vf)))
vfloat16m1_t vfnmacc_vf_f16m1(vfloat16m1_t, _Float16, vfloat16m1_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vfnmacc_vf_m)))
vfloat16m1_t vfnmacc_vf_f16m1_m(vbool16_t, vfloat16m1_t, _Float16, vfloat16m1_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vfnmacc_vf)))
vfloat16m2_t vfnmacc_vf_f16m2(vfloat16m2_t, _Float16, vfloat16m2_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vfnmacc_vf_m)))
vfloat16m2_t vfnmacc_vf_f16m2_m(vbool8_t, vfloat16m2_t, _Float16, vfloat16m2_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vfnmacc_vf)))
vfloat16m4_t vfnmacc_vf_f16m4(vfloat16m4_t, _Float16, vfloat16m4_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vfnmacc_vf_m)))
vfloat16m4_t vfnmacc_vf_f16m4_m(vbool4_t, vfloat16m4_t, _Float16, vfloat16m4_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vfnmacc_vf)))
vfloat16m8_t vfnmacc_vf_f16m8(vfloat16m8_t, _Float16, vfloat16m8_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vfnmacc_vf_m)))
vfloat16m8_t vfnmacc_vf_f16m8_m(vbool2_t, vfloat16m8_t, _Float16, vfloat16m8_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vfnmacc_vf)))
vfloat16mf2_t vfnmacc_vf_f16mf2(vfloat16mf2_t, _Float16, vfloat16mf2_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vfnmacc_vf_m)))
vfloat16mf2_t vfnmacc_vf_f16mf2_m(vbool32_t, vfloat16mf2_t, _Float16, vfloat16mf2_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vfnmacc_vf)))
vfloat16mf4_t vfnmacc_vf_f16mf4(vfloat16mf4_t, _Float16, vfloat16mf4_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vfnmacc_vf_m)))
vfloat16mf4_t vfnmacc_vf_f16mf4_m(vbool64_t, vfloat16mf4_t, _Float16, vfloat16mf4_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vfmsac_vv)))
vfloat16m1_t vfmsac_vv_f16m1(vfloat16m1_t, vfloat16m1_t, vfloat16m1_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vfmsac_vv_m)))
vfloat16m1_t vfmsac_vv_f16m1_m(vbool16_t, vfloat16m1_t, vfloat16m1_t, vfloat16m1_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vfmsac_vv)))
vfloat16m2_t vfmsac_vv_f16m2(vfloat16m2_t, vfloat16m2_t, vfloat16m2_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vfmsac_vv_m)))
vfloat16m2_t vfmsac_vv_f16m2_m(vbool8_t, vfloat16m2_t, vfloat16m2_t, vfloat16m2_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vfmsac_vv)))
vfloat16m4_t vfmsac_vv_f16m4(vfloat16m4_t, vfloat16m4_t, vfloat16m4_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vfmsac_vv_m)))
vfloat16m4_t vfmsac_vv_f16m4_m(vbool4_t, vfloat16m4_t, vfloat16m4_t, vfloat16m4_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vfmsac_vv)))
vfloat16m8_t vfmsac_vv_f16m8(vfloat16m8_t, vfloat16m8_t, vfloat16m8_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vfmsac_vv_m)))
vfloat16m8_t vfmsac_vv_f16m8_m(vbool2_t, vfloat16m8_t, vfloat16m8_t, vfloat16m8_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vfmsac_vv)))
vfloat16mf2_t vfmsac_vv_f16mf2(vfloat16mf2_t, vfloat16mf2_t, vfloat16mf2_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vfmsac_vv_m)))
vfloat16mf2_t vfmsac_vv_f16mf2_m(vbool32_t, vfloat16mf2_t, vfloat16mf2_t, vfloat16mf2_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vfmsac_vv)))
vfloat16mf4_t vfmsac_vv_f16mf4(vfloat16mf4_t, vfloat16mf4_t, vfloat16mf4_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vfmsac_vv_m)))
vfloat16mf4_t vfmsac_vv_f16mf4_m(vbool64_t, vfloat16mf4_t, vfloat16mf4_t, vfloat16mf4_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vfmsac_vf)))
vfloat16m1_t vfmsac_vf_f16m1(vfloat16m1_t, _Float16, vfloat16m1_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vfmsac_vf_m)))
vfloat16m1_t vfmsac_vf_f16m1_m(vbool16_t, vfloat16m1_t, _Float16, vfloat16m1_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vfmsac_vf)))
vfloat16m2_t vfmsac_vf_f16m2(vfloat16m2_t, _Float16, vfloat16m2_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vfmsac_vf_m)))
vfloat16m2_t vfmsac_vf_f16m2_m(vbool8_t, vfloat16m2_t, _Float16, vfloat16m2_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vfmsac_vf)))
vfloat16m4_t vfmsac_vf_f16m4(vfloat16m4_t, _Float16, vfloat16m4_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vfmsac_vf_m)))
vfloat16m4_t vfmsac_vf_f16m4_m(vbool4_t, vfloat16m4_t, _Float16, vfloat16m4_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vfmsac_vf)))
vfloat16m8_t vfmsac_vf_f16m8(vfloat16m8_t, _Float16, vfloat16m8_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vfmsac_vf_m)))
vfloat16m8_t vfmsac_vf_f16m8_m(vbool2_t, vfloat16m8_t, _Float16, vfloat16m8_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vfmsac_vf)))
vfloat16mf2_t vfmsac_vf_f16mf2(vfloat16mf2_t, _Float16, vfloat16mf2_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vfmsac_vf_m)))
vfloat16mf2_t vfmsac_vf_f16mf2_m(vbool32_t, vfloat16mf2_t, _Float16, vfloat16mf2_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vfmsac_vf)))
vfloat16mf4_t vfmsac_vf_f16mf4(vfloat16mf4_t, _Float16, vfloat16mf4_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vfmsac_vf_m)))
vfloat16mf4_t vfmsac_vf_f16mf4_m(vbool64_t, vfloat16mf4_t, _Float16, vfloat16mf4_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vfnmsac_vv)))
vfloat16m1_t vfnmsac_vv_f16m1(vfloat16m1_t, vfloat16m1_t, vfloat16m1_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vfnmsac_vv_m)))
vfloat16m1_t vfnmsac_vv_f16m1_m(vbool16_t, vfloat16m1_t, vfloat16m1_t, vfloat16m1_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vfnmsac_vv)))
vfloat16m2_t vfnmsac_vv_f16m2(vfloat16m2_t, vfloat16m2_t, vfloat16m2_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vfnmsac_vv_m)))
vfloat16m2_t vfnmsac_vv_f16m2_m(vbool8_t, vfloat16m2_t, vfloat16m2_t, vfloat16m2_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vfnmsac_vv)))
vfloat16m4_t vfnmsac_vv_f16m4(vfloat16m4_t, vfloat16m4_t, vfloat16m4_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vfnmsac_vv_m)))
vfloat16m4_t vfnmsac_vv_f16m4_m(vbool4_t, vfloat16m4_t, vfloat16m4_t, vfloat16m4_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vfnmsac_vv)))
vfloat16m8_t vfnmsac_vv_f16m8(vfloat16m8_t, vfloat16m8_t, vfloat16m8_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vfnmsac_vv_m)))
vfloat16m8_t vfnmsac_vv_f16m8_m(vbool2_t, vfloat16m8_t, vfloat16m8_t, vfloat16m8_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vfnmsac_vv)))
vfloat16mf2_t vfnmsac_vv_f16mf2(vfloat16mf2_t, vfloat16mf2_t, vfloat16mf2_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vfnmsac_vv_m)))
vfloat16mf2_t vfnmsac_vv_f16mf2_m(vbool32_t, vfloat16mf2_t, vfloat16mf2_t, vfloat16mf2_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vfnmsac_vv)))
vfloat16mf4_t vfnmsac_vv_f16mf4(vfloat16mf4_t, vfloat16mf4_t, vfloat16mf4_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vfnmsac_vv_m)))
vfloat16mf4_t vfnmsac_vv_f16mf4_m(vbool64_t, vfloat16mf4_t, vfloat16mf4_t, vfloat16mf4_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vfnmsac_vf)))
vfloat16m1_t vfnmsac_vf_f16m1(vfloat16m1_t, _Float16, vfloat16m1_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vfnmsac_vf_m)))
vfloat16m1_t vfnmsac_vf_f16m1_m(vbool16_t, vfloat16m1_t, _Float16, vfloat16m1_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vfnmsac_vf)))
vfloat16m2_t vfnmsac_vf_f16m2(vfloat16m2_t, _Float16, vfloat16m2_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vfnmsac_vf_m)))
vfloat16m2_t vfnmsac_vf_f16m2_m(vbool8_t, vfloat16m2_t, _Float16, vfloat16m2_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vfnmsac_vf)))
vfloat16m4_t vfnmsac_vf_f16m4(vfloat16m4_t, _Float16, vfloat16m4_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vfnmsac_vf_m)))
vfloat16m4_t vfnmsac_vf_f16m4_m(vbool4_t, vfloat16m4_t, _Float16, vfloat16m4_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vfnmsac_vf)))
vfloat16m8_t vfnmsac_vf_f16m8(vfloat16m8_t, _Float16, vfloat16m8_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vfnmsac_vf_m)))
vfloat16m8_t vfnmsac_vf_f16m8_m(vbool2_t, vfloat16m8_t, _Float16, vfloat16m8_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vfnmsac_vf)))
vfloat16mf2_t vfnmsac_vf_f16mf2(vfloat16mf2_t, _Float16, vfloat16mf2_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vfnmsac_vf_m)))
vfloat16mf2_t vfnmsac_vf_f16mf2_m(vbool32_t, vfloat16mf2_t, _Float16, vfloat16mf2_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vfnmsac_vf)))
vfloat16mf4_t vfnmsac_vf_f16mf4(vfloat16mf4_t, _Float16, vfloat16mf4_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vfnmsac_vf_m)))
vfloat16mf4_t vfnmsac_vf_f16mf4_m(vbool64_t, vfloat16mf4_t, _Float16, vfloat16mf4_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vfmadd_vv)))
vfloat16m1_t vfmadd_vv_f16m1(vfloat16m1_t, vfloat16m1_t, vfloat16m1_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vfmadd_vv_m)))
vfloat16m1_t vfmadd_vv_f16m1_m(vbool16_t, vfloat16m1_t, vfloat16m1_t, vfloat16m1_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vfmadd_vv)))
vfloat16m2_t vfmadd_vv_f16m2(vfloat16m2_t, vfloat16m2_t, vfloat16m2_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vfmadd_vv_m)))
vfloat16m2_t vfmadd_vv_f16m2_m(vbool8_t, vfloat16m2_t, vfloat16m2_t, vfloat16m2_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vfmadd_vv)))
vfloat16m4_t vfmadd_vv_f16m4(vfloat16m4_t, vfloat16m4_t, vfloat16m4_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vfmadd_vv_m)))
vfloat16m4_t vfmadd_vv_f16m4_m(vbool4_t, vfloat16m4_t, vfloat16m4_t, vfloat16m4_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vfmadd_vv)))
vfloat16m8_t vfmadd_vv_f16m8(vfloat16m8_t, vfloat16m8_t, vfloat16m8_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vfmadd_vv_m)))
vfloat16m8_t vfmadd_vv_f16m8_m(vbool2_t, vfloat16m8_t, vfloat16m8_t, vfloat16m8_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vfmadd_vv)))
vfloat16mf2_t vfmadd_vv_f16mf2(vfloat16mf2_t, vfloat16mf2_t, vfloat16mf2_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vfmadd_vv_m)))
vfloat16mf2_t vfmadd_vv_f16mf2_m(vbool32_t, vfloat16mf2_t, vfloat16mf2_t, vfloat16mf2_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vfmadd_vv)))
vfloat16mf4_t vfmadd_vv_f16mf4(vfloat16mf4_t, vfloat16mf4_t, vfloat16mf4_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vfmadd_vv_m)))
vfloat16mf4_t vfmadd_vv_f16mf4_m(vbool64_t, vfloat16mf4_t, vfloat16mf4_t, vfloat16mf4_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vfmadd_vf)))
vfloat16m1_t vfmadd_vf_f16m1(vfloat16m1_t, _Float16, vfloat16m1_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vfmadd_vf_m)))
vfloat16m1_t vfmadd_vf_f16m1_m(vbool16_t, vfloat16m1_t, _Float16, vfloat16m1_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vfmadd_vf)))
vfloat16m2_t vfmadd_vf_f16m2(vfloat16m2_t, _Float16, vfloat16m2_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vfmadd_vf_m)))
vfloat16m2_t vfmadd_vf_f16m2_m(vbool8_t, vfloat16m2_t, _Float16, vfloat16m2_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vfmadd_vf)))
vfloat16m4_t vfmadd_vf_f16m4(vfloat16m4_t, _Float16, vfloat16m4_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vfmadd_vf_m)))
vfloat16m4_t vfmadd_vf_f16m4_m(vbool4_t, vfloat16m4_t, _Float16, vfloat16m4_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vfmadd_vf)))
vfloat16m8_t vfmadd_vf_f16m8(vfloat16m8_t, _Float16, vfloat16m8_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vfmadd_vf_m)))
vfloat16m8_t vfmadd_vf_f16m8_m(vbool2_t, vfloat16m8_t, _Float16, vfloat16m8_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vfmadd_vf)))
vfloat16mf2_t vfmadd_vf_f16mf2(vfloat16mf2_t, _Float16, vfloat16mf2_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vfmadd_vf_m)))
vfloat16mf2_t vfmadd_vf_f16mf2_m(vbool32_t, vfloat16mf2_t, _Float16, vfloat16mf2_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vfmadd_vf)))
vfloat16mf4_t vfmadd_vf_f16mf4(vfloat16mf4_t, _Float16, vfloat16mf4_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vfmadd_vf_m)))
vfloat16mf4_t vfmadd_vf_f16mf4_m(vbool64_t, vfloat16mf4_t, _Float16, vfloat16mf4_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vfnmadd_vv)))
vfloat16m1_t vfnmadd_vv_f16m1(vfloat16m1_t, vfloat16m1_t, vfloat16m1_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vfnmadd_vv_m)))
vfloat16m1_t vfnmadd_vv_f16m1_m(vbool16_t, vfloat16m1_t, vfloat16m1_t, vfloat16m1_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vfnmadd_vv)))
vfloat16m2_t vfnmadd_vv_f16m2(vfloat16m2_t, vfloat16m2_t, vfloat16m2_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vfnmadd_vv_m)))
vfloat16m2_t vfnmadd_vv_f16m2_m(vbool8_t, vfloat16m2_t, vfloat16m2_t, vfloat16m2_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vfnmadd_vv)))
vfloat16m4_t vfnmadd_vv_f16m4(vfloat16m4_t, vfloat16m4_t, vfloat16m4_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vfnmadd_vv_m)))
vfloat16m4_t vfnmadd_vv_f16m4_m(vbool4_t, vfloat16m4_t, vfloat16m4_t, vfloat16m4_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vfnmadd_vv)))
vfloat16m8_t vfnmadd_vv_f16m8(vfloat16m8_t, vfloat16m8_t, vfloat16m8_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vfnmadd_vv_m)))
vfloat16m8_t vfnmadd_vv_f16m8_m(vbool2_t, vfloat16m8_t, vfloat16m8_t, vfloat16m8_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vfnmadd_vv)))
vfloat16mf2_t vfnmadd_vv_f16mf2(vfloat16mf2_t, vfloat16mf2_t, vfloat16mf2_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vfnmadd_vv_m)))
vfloat16mf2_t vfnmadd_vv_f16mf2_m(vbool32_t, vfloat16mf2_t, vfloat16mf2_t, vfloat16mf2_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vfnmadd_vv)))
vfloat16mf4_t vfnmadd_vv_f16mf4(vfloat16mf4_t, vfloat16mf4_t, vfloat16mf4_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vfnmadd_vv_m)))
vfloat16mf4_t vfnmadd_vv_f16mf4_m(vbool64_t, vfloat16mf4_t, vfloat16mf4_t, vfloat16mf4_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vfnmadd_vf)))
vfloat16m1_t vfnmadd_vf_f16m1(vfloat16m1_t, _Float16, vfloat16m1_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vfnmadd_vf_m)))
vfloat16m1_t vfnmadd_vf_f16m1_m(vbool16_t, vfloat16m1_t, _Float16, vfloat16m1_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vfnmadd_vf)))
vfloat16m2_t vfnmadd_vf_f16m2(vfloat16m2_t, _Float16, vfloat16m2_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vfnmadd_vf_m)))
vfloat16m2_t vfnmadd_vf_f16m2_m(vbool8_t, vfloat16m2_t, _Float16, vfloat16m2_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vfnmadd_vf)))
vfloat16m4_t vfnmadd_vf_f16m4(vfloat16m4_t, _Float16, vfloat16m4_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vfnmadd_vf_m)))
vfloat16m4_t vfnmadd_vf_f16m4_m(vbool4_t, vfloat16m4_t, _Float16, vfloat16m4_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vfnmadd_vf)))
vfloat16m8_t vfnmadd_vf_f16m8(vfloat16m8_t, _Float16, vfloat16m8_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vfnmadd_vf_m)))
vfloat16m8_t vfnmadd_vf_f16m8_m(vbool2_t, vfloat16m8_t, _Float16, vfloat16m8_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vfnmadd_vf)))
vfloat16mf2_t vfnmadd_vf_f16mf2(vfloat16mf2_t, _Float16, vfloat16mf2_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vfnmadd_vf_m)))
vfloat16mf2_t vfnmadd_vf_f16mf2_m(vbool32_t, vfloat16mf2_t, _Float16, vfloat16mf2_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vfnmadd_vf)))
vfloat16mf4_t vfnmadd_vf_f16mf4(vfloat16mf4_t, _Float16, vfloat16mf4_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vfnmadd_vf_m)))
vfloat16mf4_t vfnmadd_vf_f16mf4_m(vbool64_t, vfloat16mf4_t, _Float16, vfloat16mf4_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vfmsub_vv)))
vfloat16m1_t vfmsub_vv_f16m1(vfloat16m1_t, vfloat16m1_t, vfloat16m1_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vfmsub_vv_m)))
vfloat16m1_t vfmsub_vv_f16m1_m(vbool16_t, vfloat16m1_t, vfloat16m1_t, vfloat16m1_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vfmsub_vv)))
vfloat16m2_t vfmsub_vv_f16m2(vfloat16m2_t, vfloat16m2_t, vfloat16m2_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vfmsub_vv_m)))
vfloat16m2_t vfmsub_vv_f16m2_m(vbool8_t, vfloat16m2_t, vfloat16m2_t, vfloat16m2_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vfmsub_vv)))
vfloat16m4_t vfmsub_vv_f16m4(vfloat16m4_t, vfloat16m4_t, vfloat16m4_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vfmsub_vv_m)))
vfloat16m4_t vfmsub_vv_f16m4_m(vbool4_t, vfloat16m4_t, vfloat16m4_t, vfloat16m4_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vfmsub_vv)))
vfloat16m8_t vfmsub_vv_f16m8(vfloat16m8_t, vfloat16m8_t, vfloat16m8_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vfmsub_vv_m)))
vfloat16m8_t vfmsub_vv_f16m8_m(vbool2_t, vfloat16m8_t, vfloat16m8_t, vfloat16m8_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vfmsub_vv)))
vfloat16mf2_t vfmsub_vv_f16mf2(vfloat16mf2_t, vfloat16mf2_t, vfloat16mf2_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vfmsub_vv_m)))
vfloat16mf2_t vfmsub_vv_f16mf2_m(vbool32_t, vfloat16mf2_t, vfloat16mf2_t, vfloat16mf2_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vfmsub_vv)))
vfloat16mf4_t vfmsub_vv_f16mf4(vfloat16mf4_t, vfloat16mf4_t, vfloat16mf4_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vfmsub_vv_m)))
vfloat16mf4_t vfmsub_vv_f16mf4_m(vbool64_t, vfloat16mf4_t, vfloat16mf4_t, vfloat16mf4_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vfmsub_vf)))
vfloat16m1_t vfmsub_vf_f16m1(vfloat16m1_t, _Float16, vfloat16m1_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vfmsub_vf_m)))
vfloat16m1_t vfmsub_vf_f16m1_m(vbool16_t, vfloat16m1_t, _Float16, vfloat16m1_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vfmsub_vf)))
vfloat16m2_t vfmsub_vf_f16m2(vfloat16m2_t, _Float16, vfloat16m2_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vfmsub_vf_m)))
vfloat16m2_t vfmsub_vf_f16m2_m(vbool8_t, vfloat16m2_t, _Float16, vfloat16m2_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vfmsub_vf)))
vfloat16m4_t vfmsub_vf_f16m4(vfloat16m4_t, _Float16, vfloat16m4_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vfmsub_vf_m)))
vfloat16m4_t vfmsub_vf_f16m4_m(vbool4_t, vfloat16m4_t, _Float16, vfloat16m4_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vfmsub_vf)))
vfloat16m8_t vfmsub_vf_f16m8(vfloat16m8_t, _Float16, vfloat16m8_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vfmsub_vf_m)))
vfloat16m8_t vfmsub_vf_f16m8_m(vbool2_t, vfloat16m8_t, _Float16, vfloat16m8_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vfmsub_vf)))
vfloat16mf2_t vfmsub_vf_f16mf2(vfloat16mf2_t, _Float16, vfloat16mf2_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vfmsub_vf_m)))
vfloat16mf2_t vfmsub_vf_f16mf2_m(vbool32_t, vfloat16mf2_t, _Float16, vfloat16mf2_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vfmsub_vf)))
vfloat16mf4_t vfmsub_vf_f16mf4(vfloat16mf4_t, _Float16, vfloat16mf4_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vfmsub_vf_m)))
vfloat16mf4_t vfmsub_vf_f16mf4_m(vbool64_t, vfloat16mf4_t, _Float16, vfloat16mf4_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vfnmsub_vv)))
vfloat16m1_t vfnmsub_vv_f16m1(vfloat16m1_t, vfloat16m1_t, vfloat16m1_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vfnmsub_vv_m)))
vfloat16m1_t vfnmsub_vv_f16m1_m(vbool16_t, vfloat16m1_t, vfloat16m1_t, vfloat16m1_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vfnmsub_vv)))
vfloat16m2_t vfnmsub_vv_f16m2(vfloat16m2_t, vfloat16m2_t, vfloat16m2_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vfnmsub_vv_m)))
vfloat16m2_t vfnmsub_vv_f16m2_m(vbool8_t, vfloat16m2_t, vfloat16m2_t, vfloat16m2_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vfnmsub_vv)))
vfloat16m4_t vfnmsub_vv_f16m4(vfloat16m4_t, vfloat16m4_t, vfloat16m4_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vfnmsub_vv_m)))
vfloat16m4_t vfnmsub_vv_f16m4_m(vbool4_t, vfloat16m4_t, vfloat16m4_t, vfloat16m4_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vfnmsub_vv)))
vfloat16m8_t vfnmsub_vv_f16m8(vfloat16m8_t, vfloat16m8_t, vfloat16m8_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vfnmsub_vv_m)))
vfloat16m8_t vfnmsub_vv_f16m8_m(vbool2_t, vfloat16m8_t, vfloat16m8_t, vfloat16m8_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vfnmsub_vv)))
vfloat16mf2_t vfnmsub_vv_f16mf2(vfloat16mf2_t, vfloat16mf2_t, vfloat16mf2_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vfnmsub_vv_m)))
vfloat16mf2_t vfnmsub_vv_f16mf2_m(vbool32_t, vfloat16mf2_t, vfloat16mf2_t, vfloat16mf2_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vfnmsub_vv)))
vfloat16mf4_t vfnmsub_vv_f16mf4(vfloat16mf4_t, vfloat16mf4_t, vfloat16mf4_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vfnmsub_vv_m)))
vfloat16mf4_t vfnmsub_vv_f16mf4_m(vbool64_t, vfloat16mf4_t, vfloat16mf4_t, vfloat16mf4_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vfnmsub_vf)))
vfloat16m1_t vfnmsub_vf_f16m1(vfloat16m1_t, _Float16, vfloat16m1_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vfnmsub_vf_m)))
vfloat16m1_t vfnmsub_vf_f16m1_m(vbool16_t, vfloat16m1_t, _Float16, vfloat16m1_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vfnmsub_vf)))
vfloat16m2_t vfnmsub_vf_f16m2(vfloat16m2_t, _Float16, vfloat16m2_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vfnmsub_vf_m)))
vfloat16m2_t vfnmsub_vf_f16m2_m(vbool8_t, vfloat16m2_t, _Float16, vfloat16m2_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vfnmsub_vf)))
vfloat16m4_t vfnmsub_vf_f16m4(vfloat16m4_t, _Float16, vfloat16m4_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vfnmsub_vf_m)))
vfloat16m4_t vfnmsub_vf_f16m4_m(vbool4_t, vfloat16m4_t, _Float16, vfloat16m4_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vfnmsub_vf)))
vfloat16m8_t vfnmsub_vf_f16m8(vfloat16m8_t, _Float16, vfloat16m8_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vfnmsub_vf_m)))
vfloat16m8_t vfnmsub_vf_f16m8_m(vbool2_t, vfloat16m8_t, _Float16, vfloat16m8_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vfnmsub_vf)))
vfloat16mf2_t vfnmsub_vf_f16mf2(vfloat16mf2_t, _Float16, vfloat16mf2_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vfnmsub_vf_m)))
vfloat16mf2_t vfnmsub_vf_f16mf2_m(vbool32_t, vfloat16mf2_t, _Float16, vfloat16mf2_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vfnmsub_vf)))
vfloat16mf4_t vfnmsub_vf_f16mf4(vfloat16mf4_t, _Float16, vfloat16mf4_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vfnmsub_vf_m)))
vfloat16mf4_t vfnmsub_vf_f16mf4_m(vbool64_t, vfloat16mf4_t, _Float16, vfloat16mf4_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vfmin_vv)))
vfloat16m1_t vfmin_vv_f16m1(vfloat16m1_t, vfloat16m1_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vfmin_vv_m)))
vfloat16m1_t vfmin_vv_f16m1_m(vbool16_t, vfloat16m1_t, vfloat16m1_t, vfloat16m1_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vfmin_vv)))
vfloat16m2_t vfmin_vv_f16m2(vfloat16m2_t, vfloat16m2_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vfmin_vv_m)))
vfloat16m2_t vfmin_vv_f16m2_m(vbool8_t, vfloat16m2_t, vfloat16m2_t, vfloat16m2_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vfmin_vv)))
vfloat16m4_t vfmin_vv_f16m4(vfloat16m4_t, vfloat16m4_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vfmin_vv_m)))
vfloat16m4_t vfmin_vv_f16m4_m(vbool4_t, vfloat16m4_t, vfloat16m4_t, vfloat16m4_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vfmin_vv)))
vfloat16m8_t vfmin_vv_f16m8(vfloat16m8_t, vfloat16m8_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vfmin_vv_m)))
vfloat16m8_t vfmin_vv_f16m8_m(vbool2_t, vfloat16m8_t, vfloat16m8_t, vfloat16m8_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vfmin_vv)))
vfloat16mf2_t vfmin_vv_f16mf2(vfloat16mf2_t, vfloat16mf2_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vfmin_vv_m)))
vfloat16mf2_t vfmin_vv_f16mf2_m(vbool32_t, vfloat16mf2_t, vfloat16mf2_t, vfloat16mf2_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vfmin_vv)))
vfloat16mf4_t vfmin_vv_f16mf4(vfloat16mf4_t, vfloat16mf4_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vfmin_vv_m)))
vfloat16mf4_t vfmin_vv_f16mf4_m(vbool64_t, vfloat16mf4_t, vfloat16mf4_t, vfloat16mf4_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vfmin_vf)))
vfloat16m1_t vfmin_vf_f16m1(vfloat16m1_t, _Float16, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vfmin_vf_m)))
vfloat16m1_t vfmin_vf_f16m1_m(vbool16_t, vfloat16m1_t, vfloat16m1_t, _Float16, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vfmin_vf)))
vfloat16m2_t vfmin_vf_f16m2(vfloat16m2_t, _Float16, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vfmin_vf_m)))
vfloat16m2_t vfmin_vf_f16m2_m(vbool8_t, vfloat16m2_t, vfloat16m2_t, _Float16, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vfmin_vf)))
vfloat16m4_t vfmin_vf_f16m4(vfloat16m4_t, _Float16, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vfmin_vf_m)))
vfloat16m4_t vfmin_vf_f16m4_m(vbool4_t, vfloat16m4_t, vfloat16m4_t, _Float16, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vfmin_vf)))
vfloat16m8_t vfmin_vf_f16m8(vfloat16m8_t, _Float16, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vfmin_vf_m)))
vfloat16m8_t vfmin_vf_f16m8_m(vbool2_t, vfloat16m8_t, vfloat16m8_t, _Float16, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vfmin_vf)))
vfloat16mf2_t vfmin_vf_f16mf2(vfloat16mf2_t, _Float16, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vfmin_vf_m)))
vfloat16mf2_t vfmin_vf_f16mf2_m(vbool32_t, vfloat16mf2_t, vfloat16mf2_t, _Float16, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vfmin_vf)))
vfloat16mf4_t vfmin_vf_f16mf4(vfloat16mf4_t, _Float16, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vfmin_vf_m)))
vfloat16mf4_t vfmin_vf_f16mf4_m(vbool64_t, vfloat16mf4_t, vfloat16mf4_t, _Float16, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vfmax_vv)))
vfloat16m1_t vfmax_vv_f16m1(vfloat16m1_t, vfloat16m1_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vfmax_vv_m)))
vfloat16m1_t vfmax_vv_f16m1_m(vbool16_t, vfloat16m1_t, vfloat16m1_t, vfloat16m1_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vfmax_vv)))
vfloat16m2_t vfmax_vv_f16m2(vfloat16m2_t, vfloat16m2_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vfmax_vv_m)))
vfloat16m2_t vfmax_vv_f16m2_m(vbool8_t, vfloat16m2_t, vfloat16m2_t, vfloat16m2_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vfmax_vv)))
vfloat16m4_t vfmax_vv_f16m4(vfloat16m4_t, vfloat16m4_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vfmax_vv_m)))
vfloat16m4_t vfmax_vv_f16m4_m(vbool4_t, vfloat16m4_t, vfloat16m4_t, vfloat16m4_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vfmax_vv)))
vfloat16m8_t vfmax_vv_f16m8(vfloat16m8_t, vfloat16m8_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vfmax_vv_m)))
vfloat16m8_t vfmax_vv_f16m8_m(vbool2_t, vfloat16m8_t, vfloat16m8_t, vfloat16m8_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vfmax_vv)))
vfloat16mf2_t vfmax_vv_f16mf2(vfloat16mf2_t, vfloat16mf2_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vfmax_vv_m)))
vfloat16mf2_t vfmax_vv_f16mf2_m(vbool32_t, vfloat16mf2_t, vfloat16mf2_t, vfloat16mf2_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vfmax_vv)))
vfloat16mf4_t vfmax_vv_f16mf4(vfloat16mf4_t, vfloat16mf4_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vfmax_vv_m)))
vfloat16mf4_t vfmax_vv_f16mf4_m(vbool64_t, vfloat16mf4_t, vfloat16mf4_t, vfloat16mf4_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vfmax_vf)))
vfloat16m1_t vfmax_vf_f16m1(vfloat16m1_t, _Float16, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vfmax_vf_m)))
vfloat16m1_t vfmax_vf_f16m1_m(vbool16_t, vfloat16m1_t, vfloat16m1_t, _Float16, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vfmax_vf)))
vfloat16m2_t vfmax_vf_f16m2(vfloat16m2_t, _Float16, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vfmax_vf_m)))
vfloat16m2_t vfmax_vf_f16m2_m(vbool8_t, vfloat16m2_t, vfloat16m2_t, _Float16, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vfmax_vf)))
vfloat16m4_t vfmax_vf_f16m4(vfloat16m4_t, _Float16, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vfmax_vf_m)))
vfloat16m4_t vfmax_vf_f16m4_m(vbool4_t, vfloat16m4_t, vfloat16m4_t, _Float16, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vfmax_vf)))
vfloat16m8_t vfmax_vf_f16m8(vfloat16m8_t, _Float16, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vfmax_vf_m)))
vfloat16m8_t vfmax_vf_f16m8_m(vbool2_t, vfloat16m8_t, vfloat16m8_t, _Float16, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vfmax_vf)))
vfloat16mf2_t vfmax_vf_f16mf2(vfloat16mf2_t, _Float16, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vfmax_vf_m)))
vfloat16mf2_t vfmax_vf_f16mf2_m(vbool32_t, vfloat16mf2_t, vfloat16mf2_t, _Float16, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vfmax_vf)))
vfloat16mf4_t vfmax_vf_f16mf4(vfloat16mf4_t, _Float16, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vfmax_vf_m)))
vfloat16mf4_t vfmax_vf_f16mf4_m(vbool64_t, vfloat16mf4_t, vfloat16mf4_t, _Float16, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vfsgnj_vv)))
vfloat16m1_t vfsgnj_vv_f16m1(vfloat16m1_t, vfloat16m1_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vfsgnj_vv_m)))
vfloat16m1_t vfsgnj_vv_f16m1_m(vbool16_t, vfloat16m1_t, vfloat16m1_t, vfloat16m1_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vfsgnj_vv)))
vfloat16m2_t vfsgnj_vv_f16m2(vfloat16m2_t, vfloat16m2_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vfsgnj_vv_m)))
vfloat16m2_t vfsgnj_vv_f16m2_m(vbool8_t, vfloat16m2_t, vfloat16m2_t, vfloat16m2_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vfsgnj_vv)))
vfloat16m4_t vfsgnj_vv_f16m4(vfloat16m4_t, vfloat16m4_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vfsgnj_vv_m)))
vfloat16m4_t vfsgnj_vv_f16m4_m(vbool4_t, vfloat16m4_t, vfloat16m4_t, vfloat16m4_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vfsgnj_vv)))
vfloat16m8_t vfsgnj_vv_f16m8(vfloat16m8_t, vfloat16m8_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vfsgnj_vv_m)))
vfloat16m8_t vfsgnj_vv_f16m8_m(vbool2_t, vfloat16m8_t, vfloat16m8_t, vfloat16m8_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vfsgnj_vv)))
vfloat16mf2_t vfsgnj_vv_f16mf2(vfloat16mf2_t, vfloat16mf2_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vfsgnj_vv_m)))
vfloat16mf2_t vfsgnj_vv_f16mf2_m(vbool32_t, vfloat16mf2_t, vfloat16mf2_t, vfloat16mf2_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vfsgnj_vv)))
vfloat16mf4_t vfsgnj_vv_f16mf4(vfloat16mf4_t, vfloat16mf4_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vfsgnj_vv_m)))
vfloat16mf4_t vfsgnj_vv_f16mf4_m(vbool64_t, vfloat16mf4_t, vfloat16mf4_t, vfloat16mf4_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vfsgnj_vf)))
vfloat16m1_t vfsgnj_vf_f16m1(vfloat16m1_t, _Float16, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vfsgnj_vf_m)))
vfloat16m1_t vfsgnj_vf_f16m1_m(vbool16_t, vfloat16m1_t, vfloat16m1_t, _Float16, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vfsgnj_vf)))
vfloat16m2_t vfsgnj_vf_f16m2(vfloat16m2_t, _Float16, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vfsgnj_vf_m)))
vfloat16m2_t vfsgnj_vf_f16m2_m(vbool8_t, vfloat16m2_t, vfloat16m2_t, _Float16, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vfsgnj_vf)))
vfloat16m4_t vfsgnj_vf_f16m4(vfloat16m4_t, _Float16, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vfsgnj_vf_m)))
vfloat16m4_t vfsgnj_vf_f16m4_m(vbool4_t, vfloat16m4_t, vfloat16m4_t, _Float16, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vfsgnj_vf)))
vfloat16m8_t vfsgnj_vf_f16m8(vfloat16m8_t, _Float16, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vfsgnj_vf_m)))
vfloat16m8_t vfsgnj_vf_f16m8_m(vbool2_t, vfloat16m8_t, vfloat16m8_t, _Float16, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vfsgnj_vf)))
vfloat16mf2_t vfsgnj_vf_f16mf2(vfloat16mf2_t, _Float16, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vfsgnj_vf_m)))
vfloat16mf2_t vfsgnj_vf_f16mf2_m(vbool32_t, vfloat16mf2_t, vfloat16mf2_t, _Float16, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vfsgnj_vf)))
vfloat16mf4_t vfsgnj_vf_f16mf4(vfloat16mf4_t, _Float16, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vfsgnj_vf_m)))
vfloat16mf4_t vfsgnj_vf_f16mf4_m(vbool64_t, vfloat16mf4_t, vfloat16mf4_t, _Float16, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vfsgnjn_vv)))
vfloat16m1_t vfsgnjn_vv_f16m1(vfloat16m1_t, vfloat16m1_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vfsgnjn_vv_m)))
vfloat16m1_t vfsgnjn_vv_f16m1_m(vbool16_t, vfloat16m1_t, vfloat16m1_t, vfloat16m1_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vfsgnjn_vv)))
vfloat16m2_t vfsgnjn_vv_f16m2(vfloat16m2_t, vfloat16m2_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vfsgnjn_vv_m)))
vfloat16m2_t vfsgnjn_vv_f16m2_m(vbool8_t, vfloat16m2_t, vfloat16m2_t, vfloat16m2_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vfsgnjn_vv)))
vfloat16m4_t vfsgnjn_vv_f16m4(vfloat16m4_t, vfloat16m4_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vfsgnjn_vv_m)))
vfloat16m4_t vfsgnjn_vv_f16m4_m(vbool4_t, vfloat16m4_t, vfloat16m4_t, vfloat16m4_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vfsgnjn_vv)))
vfloat16m8_t vfsgnjn_vv_f16m8(vfloat16m8_t, vfloat16m8_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vfsgnjn_vv_m)))
vfloat16m8_t vfsgnjn_vv_f16m8_m(vbool2_t, vfloat16m8_t, vfloat16m8_t, vfloat16m8_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vfsgnjn_vv)))
vfloat16mf2_t vfsgnjn_vv_f16mf2(vfloat16mf2_t, vfloat16mf2_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vfsgnjn_vv_m)))
vfloat16mf2_t vfsgnjn_vv_f16mf2_m(vbool32_t, vfloat16mf2_t, vfloat16mf2_t, vfloat16mf2_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vfsgnjn_vv)))
vfloat16mf4_t vfsgnjn_vv_f16mf4(vfloat16mf4_t, vfloat16mf4_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vfsgnjn_vv_m)))
vfloat16mf4_t vfsgnjn_vv_f16mf4_m(vbool64_t, vfloat16mf4_t, vfloat16mf4_t, vfloat16mf4_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vfsgnjn_vf)))
vfloat16m1_t vfsgnjn_vf_f16m1(vfloat16m1_t, _Float16, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vfsgnjn_vf_m)))
vfloat16m1_t vfsgnjn_vf_f16m1_m(vbool16_t, vfloat16m1_t, vfloat16m1_t, _Float16, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vfsgnjn_vf)))
vfloat16m2_t vfsgnjn_vf_f16m2(vfloat16m2_t, _Float16, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vfsgnjn_vf_m)))
vfloat16m2_t vfsgnjn_vf_f16m2_m(vbool8_t, vfloat16m2_t, vfloat16m2_t, _Float16, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vfsgnjn_vf)))
vfloat16m4_t vfsgnjn_vf_f16m4(vfloat16m4_t, _Float16, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vfsgnjn_vf_m)))
vfloat16m4_t vfsgnjn_vf_f16m4_m(vbool4_t, vfloat16m4_t, vfloat16m4_t, _Float16, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vfsgnjn_vf)))
vfloat16m8_t vfsgnjn_vf_f16m8(vfloat16m8_t, _Float16, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vfsgnjn_vf_m)))
vfloat16m8_t vfsgnjn_vf_f16m8_m(vbool2_t, vfloat16m8_t, vfloat16m8_t, _Float16, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vfsgnjn_vf)))
vfloat16mf2_t vfsgnjn_vf_f16mf2(vfloat16mf2_t, _Float16, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vfsgnjn_vf_m)))
vfloat16mf2_t vfsgnjn_vf_f16mf2_m(vbool32_t, vfloat16mf2_t, vfloat16mf2_t, _Float16, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vfsgnjn_vf)))
vfloat16mf4_t vfsgnjn_vf_f16mf4(vfloat16mf4_t, _Float16, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vfsgnjn_vf_m)))
vfloat16mf4_t vfsgnjn_vf_f16mf4_m(vbool64_t, vfloat16mf4_t, vfloat16mf4_t, _Float16, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vfsgnjx_vv)))
vfloat16m1_t vfsgnjx_vv_f16m1(vfloat16m1_t, vfloat16m1_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vfsgnjx_vv_m)))
vfloat16m1_t vfsgnjx_vv_f16m1_m(vbool16_t, vfloat16m1_t, vfloat16m1_t, vfloat16m1_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vfsgnjx_vv)))
vfloat16m2_t vfsgnjx_vv_f16m2(vfloat16m2_t, vfloat16m2_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vfsgnjx_vv_m)))
vfloat16m2_t vfsgnjx_vv_f16m2_m(vbool8_t, vfloat16m2_t, vfloat16m2_t, vfloat16m2_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vfsgnjx_vv)))
vfloat16m4_t vfsgnjx_vv_f16m4(vfloat16m4_t, vfloat16m4_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vfsgnjx_vv_m)))
vfloat16m4_t vfsgnjx_vv_f16m4_m(vbool4_t, vfloat16m4_t, vfloat16m4_t, vfloat16m4_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vfsgnjx_vv)))
vfloat16m8_t vfsgnjx_vv_f16m8(vfloat16m8_t, vfloat16m8_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vfsgnjx_vv_m)))
vfloat16m8_t vfsgnjx_vv_f16m8_m(vbool2_t, vfloat16m8_t, vfloat16m8_t, vfloat16m8_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vfsgnjx_vv)))
vfloat16mf2_t vfsgnjx_vv_f16mf2(vfloat16mf2_t, vfloat16mf2_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vfsgnjx_vv_m)))
vfloat16mf2_t vfsgnjx_vv_f16mf2_m(vbool32_t, vfloat16mf2_t, vfloat16mf2_t, vfloat16mf2_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vfsgnjx_vv)))
vfloat16mf4_t vfsgnjx_vv_f16mf4(vfloat16mf4_t, vfloat16mf4_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vfsgnjx_vv_m)))
vfloat16mf4_t vfsgnjx_vv_f16mf4_m(vbool64_t, vfloat16mf4_t, vfloat16mf4_t, vfloat16mf4_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vfsgnjx_vf)))
vfloat16m1_t vfsgnjx_vf_f16m1(vfloat16m1_t, _Float16, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vfsgnjx_vf_m)))
vfloat16m1_t vfsgnjx_vf_f16m1_m(vbool16_t, vfloat16m1_t, vfloat16m1_t, _Float16, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vfsgnjx_vf)))
vfloat16m2_t vfsgnjx_vf_f16m2(vfloat16m2_t, _Float16, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vfsgnjx_vf_m)))
vfloat16m2_t vfsgnjx_vf_f16m2_m(vbool8_t, vfloat16m2_t, vfloat16m2_t, _Float16, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vfsgnjx_vf)))
vfloat16m4_t vfsgnjx_vf_f16m4(vfloat16m4_t, _Float16, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vfsgnjx_vf_m)))
vfloat16m4_t vfsgnjx_vf_f16m4_m(vbool4_t, vfloat16m4_t, vfloat16m4_t, _Float16, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vfsgnjx_vf)))
vfloat16m8_t vfsgnjx_vf_f16m8(vfloat16m8_t, _Float16, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vfsgnjx_vf_m)))
vfloat16m8_t vfsgnjx_vf_f16m8_m(vbool2_t, vfloat16m8_t, vfloat16m8_t, _Float16, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vfsgnjx_vf)))
vfloat16mf2_t vfsgnjx_vf_f16mf2(vfloat16mf2_t, _Float16, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vfsgnjx_vf_m)))
vfloat16mf2_t vfsgnjx_vf_f16mf2_m(vbool32_t, vfloat16mf2_t, vfloat16mf2_t, _Float16, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vfsgnjx_vf)))
vfloat16mf4_t vfsgnjx_vf_f16mf4(vfloat16mf4_t, _Float16, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vfsgnjx_vf_m)))
vfloat16mf4_t vfsgnjx_vf_f16mf4_m(vbool64_t, vfloat16mf4_t, vfloat16mf4_t, _Float16, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vfabs_v)))
vfloat16m1_t vfabs_v_f16m1(vfloat16m1_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vfabs_v_m)))
vfloat16m1_t vfabs_v_f16m1_m(vbool16_t, vfloat16m1_t, vfloat16m1_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vfabs_v)))
vfloat16m2_t vfabs_v_f16m2(vfloat16m2_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vfabs_v_m)))
vfloat16m2_t vfabs_v_f16m2_m(vbool8_t, vfloat16m2_t, vfloat16m2_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vfabs_v)))
vfloat16m4_t vfabs_v_f16m4(vfloat16m4_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vfabs_v_m)))
vfloat16m4_t vfabs_v_f16m4_m(vbool4_t, vfloat16m4_t, vfloat16m4_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vfabs_v)))
vfloat16m8_t vfabs_v_f16m8(vfloat16m8_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vfabs_v_m)))
vfloat16m8_t vfabs_v_f16m8_m(vbool2_t, vfloat16m8_t, vfloat16m8_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vfabs_v)))
vfloat16mf2_t vfabs_v_f16mf2(vfloat16mf2_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vfabs_v_m)))
vfloat16mf2_t vfabs_v_f16mf2_m(vbool32_t, vfloat16mf2_t, vfloat16mf2_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vfabs_v)))
vfloat16mf4_t vfabs_v_f16mf4(vfloat16mf4_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vfabs_v_m)))
vfloat16mf4_t vfabs_v_f16mf4_m(vbool64_t, vfloat16mf4_t, vfloat16mf4_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vmfeq_vv)))
vbool16_t vmfeq_vv_f16m1_b16(vfloat16m1_t, vfloat16m1_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vmfeq_vv_m)))
vbool16_t vmfeq_vv_f16m1_b16_m(vbool16_t, vbool16_t, vfloat16m1_t, vfloat16m1_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vmfeq_vv)))
vbool8_t vmfeq_vv_f16m2_b8(vfloat16m2_t, vfloat16m2_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vmfeq_vv_m)))
vbool8_t vmfeq_vv_f16m2_b8_m(vbool8_t, vbool8_t, vfloat16m2_t, vfloat16m2_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vmfeq_vv)))
vbool4_t vmfeq_vv_f16m4_b4(vfloat16m4_t, vfloat16m4_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vmfeq_vv_m)))
vbool4_t vmfeq_vv_f16m4_b4_m(vbool4_t, vbool4_t, vfloat16m4_t, vfloat16m4_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vmfeq_vv)))
vbool2_t vmfeq_vv_f16m8_b2(vfloat16m8_t, vfloat16m8_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vmfeq_vv_m)))
vbool2_t vmfeq_vv_f16m8_b2_m(vbool2_t, vbool2_t, vfloat16m8_t, vfloat16m8_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vmfeq_vv)))
vbool32_t vmfeq_vv_f16mf2_b32(vfloat16mf2_t, vfloat16mf2_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vmfeq_vv_m)))
vbool32_t vmfeq_vv_f16mf2_b32_m(vbool32_t, vbool32_t, vfloat16mf2_t, vfloat16mf2_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vmfeq_vv)))
vbool64_t vmfeq_vv_f16mf4_b64(vfloat16mf4_t, vfloat16mf4_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vmfeq_vv_m)))
vbool64_t vmfeq_vv_f16mf4_b64_m(vbool64_t, vbool64_t, vfloat16mf4_t, vfloat16mf4_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vmfeq_vf)))
vbool16_t vmfeq_vf_f16m1_b16(vfloat16m1_t, _Float16, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vmfeq_vf_m)))
vbool16_t vmfeq_vf_f16m1_b16_m(vbool16_t, vbool16_t, vfloat16m1_t, _Float16, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vmfeq_vf)))
vbool8_t vmfeq_vf_f16m2_b8(vfloat16m2_t, _Float16, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vmfeq_vf_m)))
vbool8_t vmfeq_vf_f16m2_b8_m(vbool8_t, vbool8_t, vfloat16m2_t, _Float16, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vmfeq_vf)))
vbool4_t vmfeq_vf_f16m4_b4(vfloat16m4_t, _Float16, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vmfeq_vf_m)))
vbool4_t vmfeq_vf_f16m4_b4_m(vbool4_t, vbool4_t, vfloat16m4_t, _Float16, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vmfeq_vf)))
vbool2_t vmfeq_vf_f16m8_b2(vfloat16m8_t, _Float16, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vmfeq_vf_m)))
vbool2_t vmfeq_vf_f16m8_b2_m(vbool2_t, vbool2_t, vfloat16m8_t, _Float16, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vmfeq_vf)))
vbool32_t vmfeq_vf_f16mf2_b32(vfloat16mf2_t, _Float16, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vmfeq_vf_m)))
vbool32_t vmfeq_vf_f16mf2_b32_m(vbool32_t, vbool32_t, vfloat16mf2_t, _Float16, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vmfeq_vf)))
vbool64_t vmfeq_vf_f16mf4_b64(vfloat16mf4_t, _Float16, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vmfeq_vf_m)))
vbool64_t vmfeq_vf_f16mf4_b64_m(vbool64_t, vbool64_t, vfloat16mf4_t, _Float16, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vmfne_vv)))
vbool16_t vmfne_vv_f16m1_b16(vfloat16m1_t, vfloat16m1_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vmfne_vv_m)))
vbool16_t vmfne_vv_f16m1_b16_m(vbool16_t, vbool16_t, vfloat16m1_t, vfloat16m1_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vmfne_vv)))
vbool8_t vmfne_vv_f16m2_b8(vfloat16m2_t, vfloat16m2_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vmfne_vv_m)))
vbool8_t vmfne_vv_f16m2_b8_m(vbool8_t, vbool8_t, vfloat16m2_t, vfloat16m2_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vmfne_vv)))
vbool4_t vmfne_vv_f16m4_b4(vfloat16m4_t, vfloat16m4_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vmfne_vv_m)))
vbool4_t vmfne_vv_f16m4_b4_m(vbool4_t, vbool4_t, vfloat16m4_t, vfloat16m4_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vmfne_vv)))
vbool2_t vmfne_vv_f16m8_b2(vfloat16m8_t, vfloat16m8_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vmfne_vv_m)))
vbool2_t vmfne_vv_f16m8_b2_m(vbool2_t, vbool2_t, vfloat16m8_t, vfloat16m8_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vmfne_vv)))
vbool32_t vmfne_vv_f16mf2_b32(vfloat16mf2_t, vfloat16mf2_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vmfne_vv_m)))
vbool32_t vmfne_vv_f16mf2_b32_m(vbool32_t, vbool32_t, vfloat16mf2_t, vfloat16mf2_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vmfne_vv)))
vbool64_t vmfne_vv_f16mf4_b64(vfloat16mf4_t, vfloat16mf4_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vmfne_vv_m)))
vbool64_t vmfne_vv_f16mf4_b64_m(vbool64_t, vbool64_t, vfloat16mf4_t, vfloat16mf4_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vmfne_vf)))
vbool16_t vmfne_vf_f16m1_b16(vfloat16m1_t, _Float16, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vmfne_vf_m)))
vbool16_t vmfne_vf_f16m1_b16_m(vbool16_t, vbool16_t, vfloat16m1_t, _Float16, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vmfne_vf)))
vbool8_t vmfne_vf_f16m2_b8(vfloat16m2_t, _Float16, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vmfne_vf_m)))
vbool8_t vmfne_vf_f16m2_b8_m(vbool8_t, vbool8_t, vfloat16m2_t, _Float16, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vmfne_vf)))
vbool4_t vmfne_vf_f16m4_b4(vfloat16m4_t, _Float16, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vmfne_vf_m)))
vbool4_t vmfne_vf_f16m4_b4_m(vbool4_t, vbool4_t, vfloat16m4_t, _Float16, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vmfne_vf)))
vbool2_t vmfne_vf_f16m8_b2(vfloat16m8_t, _Float16, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vmfne_vf_m)))
vbool2_t vmfne_vf_f16m8_b2_m(vbool2_t, vbool2_t, vfloat16m8_t, _Float16, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vmfne_vf)))
vbool32_t vmfne_vf_f16mf2_b32(vfloat16mf2_t, _Float16, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vmfne_vf_m)))
vbool32_t vmfne_vf_f16mf2_b32_m(vbool32_t, vbool32_t, vfloat16mf2_t, _Float16, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vmfne_vf)))
vbool64_t vmfne_vf_f16mf4_b64(vfloat16mf4_t, _Float16, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vmfne_vf_m)))
vbool64_t vmfne_vf_f16mf4_b64_m(vbool64_t, vbool64_t, vfloat16mf4_t, _Float16, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vmflt_vv)))
vbool16_t vmflt_vv_f16m1_b16(vfloat16m1_t, vfloat16m1_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vmflt_vv_m)))
vbool16_t vmflt_vv_f16m1_b16_m(vbool16_t, vbool16_t, vfloat16m1_t, vfloat16m1_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vmflt_vv)))
vbool8_t vmflt_vv_f16m2_b8(vfloat16m2_t, vfloat16m2_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vmflt_vv_m)))
vbool8_t vmflt_vv_f16m2_b8_m(vbool8_t, vbool8_t, vfloat16m2_t, vfloat16m2_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vmflt_vv)))
vbool4_t vmflt_vv_f16m4_b4(vfloat16m4_t, vfloat16m4_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vmflt_vv_m)))
vbool4_t vmflt_vv_f16m4_b4_m(vbool4_t, vbool4_t, vfloat16m4_t, vfloat16m4_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vmflt_vv)))
vbool2_t vmflt_vv_f16m8_b2(vfloat16m8_t, vfloat16m8_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vmflt_vv_m)))
vbool2_t vmflt_vv_f16m8_b2_m(vbool2_t, vbool2_t, vfloat16m8_t, vfloat16m8_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vmflt_vv)))
vbool32_t vmflt_vv_f16mf2_b32(vfloat16mf2_t, vfloat16mf2_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vmflt_vv_m)))
vbool32_t vmflt_vv_f16mf2_b32_m(vbool32_t, vbool32_t, vfloat16mf2_t, vfloat16mf2_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vmflt_vv)))
vbool64_t vmflt_vv_f16mf4_b64(vfloat16mf4_t, vfloat16mf4_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vmflt_vv_m)))
vbool64_t vmflt_vv_f16mf4_b64_m(vbool64_t, vbool64_t, vfloat16mf4_t, vfloat16mf4_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vmflt_vf)))
vbool16_t vmflt_vf_f16m1_b16(vfloat16m1_t, _Float16, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vmflt_vf_m)))
vbool16_t vmflt_vf_f16m1_b16_m(vbool16_t, vbool16_t, vfloat16m1_t, _Float16, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vmflt_vf)))
vbool8_t vmflt_vf_f16m2_b8(vfloat16m2_t, _Float16, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vmflt_vf_m)))
vbool8_t vmflt_vf_f16m2_b8_m(vbool8_t, vbool8_t, vfloat16m2_t, _Float16, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vmflt_vf)))
vbool4_t vmflt_vf_f16m4_b4(vfloat16m4_t, _Float16, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vmflt_vf_m)))
vbool4_t vmflt_vf_f16m4_b4_m(vbool4_t, vbool4_t, vfloat16m4_t, _Float16, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vmflt_vf)))
vbool2_t vmflt_vf_f16m8_b2(vfloat16m8_t, _Float16, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vmflt_vf_m)))
vbool2_t vmflt_vf_f16m8_b2_m(vbool2_t, vbool2_t, vfloat16m8_t, _Float16, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vmflt_vf)))
vbool32_t vmflt_vf_f16mf2_b32(vfloat16mf2_t, _Float16, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vmflt_vf_m)))
vbool32_t vmflt_vf_f16mf2_b32_m(vbool32_t, vbool32_t, vfloat16mf2_t, _Float16, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vmflt_vf)))
vbool64_t vmflt_vf_f16mf4_b64(vfloat16mf4_t, _Float16, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vmflt_vf_m)))
vbool64_t vmflt_vf_f16mf4_b64_m(vbool64_t, vbool64_t, vfloat16mf4_t, _Float16, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vmfle_vv)))
vbool16_t vmfle_vv_f16m1_b16(vfloat16m1_t, vfloat16m1_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vmfle_vv_m)))
vbool16_t vmfle_vv_f16m1_b16_m(vbool16_t, vbool16_t, vfloat16m1_t, vfloat16m1_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vmfle_vv)))
vbool8_t vmfle_vv_f16m2_b8(vfloat16m2_t, vfloat16m2_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vmfle_vv_m)))
vbool8_t vmfle_vv_f16m2_b8_m(vbool8_t, vbool8_t, vfloat16m2_t, vfloat16m2_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vmfle_vv)))
vbool4_t vmfle_vv_f16m4_b4(vfloat16m4_t, vfloat16m4_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vmfle_vv_m)))
vbool4_t vmfle_vv_f16m4_b4_m(vbool4_t, vbool4_t, vfloat16m4_t, vfloat16m4_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vmfle_vv)))
vbool2_t vmfle_vv_f16m8_b2(vfloat16m8_t, vfloat16m8_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vmfle_vv_m)))
vbool2_t vmfle_vv_f16m8_b2_m(vbool2_t, vbool2_t, vfloat16m8_t, vfloat16m8_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vmfle_vv)))
vbool32_t vmfle_vv_f16mf2_b32(vfloat16mf2_t, vfloat16mf2_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vmfle_vv_m)))
vbool32_t vmfle_vv_f16mf2_b32_m(vbool32_t, vbool32_t, vfloat16mf2_t, vfloat16mf2_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vmfle_vv)))
vbool64_t vmfle_vv_f16mf4_b64(vfloat16mf4_t, vfloat16mf4_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vmfle_vv_m)))
vbool64_t vmfle_vv_f16mf4_b64_m(vbool64_t, vbool64_t, vfloat16mf4_t, vfloat16mf4_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vmfle_vf)))
vbool16_t vmfle_vf_f16m1_b16(vfloat16m1_t, _Float16, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vmfle_vf_m)))
vbool16_t vmfle_vf_f16m1_b16_m(vbool16_t, vbool16_t, vfloat16m1_t, _Float16, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vmfle_vf)))
vbool8_t vmfle_vf_f16m2_b8(vfloat16m2_t, _Float16, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vmfle_vf_m)))
vbool8_t vmfle_vf_f16m2_b8_m(vbool8_t, vbool8_t, vfloat16m2_t, _Float16, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vmfle_vf)))
vbool4_t vmfle_vf_f16m4_b4(vfloat16m4_t, _Float16, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vmfle_vf_m)))
vbool4_t vmfle_vf_f16m4_b4_m(vbool4_t, vbool4_t, vfloat16m4_t, _Float16, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vmfle_vf)))
vbool2_t vmfle_vf_f16m8_b2(vfloat16m8_t, _Float16, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vmfle_vf_m)))
vbool2_t vmfle_vf_f16m8_b2_m(vbool2_t, vbool2_t, vfloat16m8_t, _Float16, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vmfle_vf)))
vbool32_t vmfle_vf_f16mf2_b32(vfloat16mf2_t, _Float16, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vmfle_vf_m)))
vbool32_t vmfle_vf_f16mf2_b32_m(vbool32_t, vbool32_t, vfloat16mf2_t, _Float16, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vmfle_vf)))
vbool64_t vmfle_vf_f16mf4_b64(vfloat16mf4_t, _Float16, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vmfle_vf_m)))
vbool64_t vmfle_vf_f16mf4_b64_m(vbool64_t, vbool64_t, vfloat16mf4_t, _Float16, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vmfgt_vv)))
vbool16_t vmfgt_vv_f16m1_b16(vfloat16m1_t, vfloat16m1_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vmfgt_vv_m)))
vbool16_t vmfgt_vv_f16m1_b16_m(vbool16_t, vbool16_t, vfloat16m1_t, vfloat16m1_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vmfgt_vv)))
vbool8_t vmfgt_vv_f16m2_b8(vfloat16m2_t, vfloat16m2_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vmfgt_vv_m)))
vbool8_t vmfgt_vv_f16m2_b8_m(vbool8_t, vbool8_t, vfloat16m2_t, vfloat16m2_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vmfgt_vv)))
vbool4_t vmfgt_vv_f16m4_b4(vfloat16m4_t, vfloat16m4_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vmfgt_vv_m)))
vbool4_t vmfgt_vv_f16m4_b4_m(vbool4_t, vbool4_t, vfloat16m4_t, vfloat16m4_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vmfgt_vv)))
vbool2_t vmfgt_vv_f16m8_b2(vfloat16m8_t, vfloat16m8_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vmfgt_vv_m)))
vbool2_t vmfgt_vv_f16m8_b2_m(vbool2_t, vbool2_t, vfloat16m8_t, vfloat16m8_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vmfgt_vv)))
vbool32_t vmfgt_vv_f16mf2_b32(vfloat16mf2_t, vfloat16mf2_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vmfgt_vv_m)))
vbool32_t vmfgt_vv_f16mf2_b32_m(vbool32_t, vbool32_t, vfloat16mf2_t, vfloat16mf2_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vmfgt_vv)))
vbool64_t vmfgt_vv_f16mf4_b64(vfloat16mf4_t, vfloat16mf4_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vmfgt_vv_m)))
vbool64_t vmfgt_vv_f16mf4_b64_m(vbool64_t, vbool64_t, vfloat16mf4_t, vfloat16mf4_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vmfgt_vf)))
vbool16_t vmfgt_vf_f16m1_b16(vfloat16m1_t, _Float16, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vmfgt_vf_m)))
vbool16_t vmfgt_vf_f16m1_b16_m(vbool16_t, vbool16_t, vfloat16m1_t, _Float16, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vmfgt_vf)))
vbool8_t vmfgt_vf_f16m2_b8(vfloat16m2_t, _Float16, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vmfgt_vf_m)))
vbool8_t vmfgt_vf_f16m2_b8_m(vbool8_t, vbool8_t, vfloat16m2_t, _Float16, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vmfgt_vf)))
vbool4_t vmfgt_vf_f16m4_b4(vfloat16m4_t, _Float16, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vmfgt_vf_m)))
vbool4_t vmfgt_vf_f16m4_b4_m(vbool4_t, vbool4_t, vfloat16m4_t, _Float16, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vmfgt_vf)))
vbool2_t vmfgt_vf_f16m8_b2(vfloat16m8_t, _Float16, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vmfgt_vf_m)))
vbool2_t vmfgt_vf_f16m8_b2_m(vbool2_t, vbool2_t, vfloat16m8_t, _Float16, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vmfgt_vf)))
vbool32_t vmfgt_vf_f16mf2_b32(vfloat16mf2_t, _Float16, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vmfgt_vf_m)))
vbool32_t vmfgt_vf_f16mf2_b32_m(vbool32_t, vbool32_t, vfloat16mf2_t, _Float16, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vmfgt_vf)))
vbool64_t vmfgt_vf_f16mf4_b64(vfloat16mf4_t, _Float16, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vmfgt_vf_m)))
vbool64_t vmfgt_vf_f16mf4_b64_m(vbool64_t, vbool64_t, vfloat16mf4_t, _Float16, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vmfge_vv)))
vbool16_t vmfge_vv_f16m1_b16(vfloat16m1_t, vfloat16m1_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vmfge_vv_m)))
vbool16_t vmfge_vv_f16m1_b16_m(vbool16_t, vbool16_t, vfloat16m1_t, vfloat16m1_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vmfge_vv)))
vbool8_t vmfge_vv_f16m2_b8(vfloat16m2_t, vfloat16m2_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vmfge_vv_m)))
vbool8_t vmfge_vv_f16m2_b8_m(vbool8_t, vbool8_t, vfloat16m2_t, vfloat16m2_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vmfge_vv)))
vbool4_t vmfge_vv_f16m4_b4(vfloat16m4_t, vfloat16m4_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vmfge_vv_m)))
vbool4_t vmfge_vv_f16m4_b4_m(vbool4_t, vbool4_t, vfloat16m4_t, vfloat16m4_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vmfge_vv)))
vbool2_t vmfge_vv_f16m8_b2(vfloat16m8_t, vfloat16m8_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vmfge_vv_m)))
vbool2_t vmfge_vv_f16m8_b2_m(vbool2_t, vbool2_t, vfloat16m8_t, vfloat16m8_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vmfge_vv)))
vbool32_t vmfge_vv_f16mf2_b32(vfloat16mf2_t, vfloat16mf2_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vmfge_vv_m)))
vbool32_t vmfge_vv_f16mf2_b32_m(vbool32_t, vbool32_t, vfloat16mf2_t, vfloat16mf2_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vmfge_vv)))
vbool64_t vmfge_vv_f16mf4_b64(vfloat16mf4_t, vfloat16mf4_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vmfge_vv_m)))
vbool64_t vmfge_vv_f16mf4_b64_m(vbool64_t, vbool64_t, vfloat16mf4_t, vfloat16mf4_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vmfge_vf)))
vbool16_t vmfge_vf_f16m1_b16(vfloat16m1_t, _Float16, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vmfge_vf_m)))
vbool16_t vmfge_vf_f16m1_b16_m(vbool16_t, vbool16_t, vfloat16m1_t, _Float16, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vmfge_vf)))
vbool8_t vmfge_vf_f16m2_b8(vfloat16m2_t, _Float16, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vmfge_vf_m)))
vbool8_t vmfge_vf_f16m2_b8_m(vbool8_t, vbool8_t, vfloat16m2_t, _Float16, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vmfge_vf)))
vbool4_t vmfge_vf_f16m4_b4(vfloat16m4_t, _Float16, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vmfge_vf_m)))
vbool4_t vmfge_vf_f16m4_b4_m(vbool4_t, vbool4_t, vfloat16m4_t, _Float16, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vmfge_vf)))
vbool2_t vmfge_vf_f16m8_b2(vfloat16m8_t, _Float16, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vmfge_vf_m)))
vbool2_t vmfge_vf_f16m8_b2_m(vbool2_t, vbool2_t, vfloat16m8_t, _Float16, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vmfge_vf)))
vbool32_t vmfge_vf_f16mf2_b32(vfloat16mf2_t, _Float16, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vmfge_vf_m)))
vbool32_t vmfge_vf_f16mf2_b32_m(vbool32_t, vbool32_t, vfloat16mf2_t, _Float16, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vmfge_vf)))
vbool64_t vmfge_vf_f16mf4_b64(vfloat16mf4_t, _Float16, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vmfge_vf_m)))
vbool64_t vmfge_vf_f16mf4_b64_m(vbool64_t, vbool64_t, vfloat16mf4_t, _Float16, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vmerge_vvm)))
vfloat16m1_t vmerge_vvm_f16m1(vbool16_t, vfloat16m1_t, vfloat16m1_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vmerge_vvm)))
vfloat16m2_t vmerge_vvm_f16m2(vbool8_t, vfloat16m2_t, vfloat16m2_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vmerge_vvm)))
vfloat16m4_t vmerge_vvm_f16m4(vbool4_t, vfloat16m4_t, vfloat16m4_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vmerge_vvm)))
vfloat16m8_t vmerge_vvm_f16m8(vbool2_t, vfloat16m8_t, vfloat16m8_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vmerge_vvm)))
vfloat16mf2_t vmerge_vvm_f16mf2(vbool32_t, vfloat16mf2_t, vfloat16mf2_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vmerge_vvm)))
vfloat16mf4_t vmerge_vvm_f16mf4(vbool64_t, vfloat16mf4_t, vfloat16mf4_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vfmerge_vfm)))
vfloat16m1_t vfmerge_vfm_f16m1(vbool16_t, vfloat16m1_t, _Float16, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vfmerge_vfm)))
vfloat16m2_t vfmerge_vfm_f16m2(vbool8_t, vfloat16m2_t, _Float16, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vfmerge_vfm)))
vfloat16m4_t vfmerge_vfm_f16m4(vbool4_t, vfloat16m4_t, _Float16, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vfmerge_vfm)))
vfloat16m8_t vfmerge_vfm_f16m8(vbool2_t, vfloat16m8_t, _Float16, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vfmerge_vfm)))
vfloat16mf2_t vfmerge_vfm_f16mf2(vbool32_t, vfloat16mf2_t, _Float16, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vfmerge_vfm)))
vfloat16mf4_t vfmerge_vfm_f16mf4(vbool64_t, vfloat16mf4_t, _Float16, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vfmv_v_f)))
vfloat16m1_t vfmv_v_f_f16m1(_Float16, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vfmv_v_f)))
vfloat16m2_t vfmv_v_f_f16m2(_Float16, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vfmv_v_f)))
vfloat16m4_t vfmv_v_f_f16m4(_Float16, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vfmv_v_f)))
vfloat16m8_t vfmv_v_f_f16m8(_Float16, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vfmv_v_f)))
vfloat16mf2_t vfmv_v_f_f16mf2(_Float16, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vfmv_v_f)))
vfloat16mf4_t vfmv_v_f_f16mf4(_Float16, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vfredmax_vs)))
vfloat16m1_t vfredmax_vs_f16m1_f16m1(vfloat16m1_t, vfloat16m1_t, vfloat16m1_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vfredmax_vs_m)))
vfloat16m1_t vfredmax_vs_f16m1_f16m1_m(vbool16_t, vfloat16m1_t, vfloat16m1_t, vfloat16m1_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vfredmax_vs)))
vfloat16m1_t vfredmax_vs_f16m2_f16m1(vfloat16m1_t, vfloat16m2_t, vfloat16m1_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vfredmax_vs_m)))
vfloat16m1_t vfredmax_vs_f16m2_f16m1_m(vbool8_t, vfloat16m1_t, vfloat16m2_t, vfloat16m1_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vfredmax_vs)))
vfloat16m1_t vfredmax_vs_f16m4_f16m1(vfloat16m1_t, vfloat16m4_t, vfloat16m1_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vfredmax_vs_m)))
vfloat16m1_t vfredmax_vs_f16m4_f16m1_m(vbool4_t, vfloat16m1_t, vfloat16m4_t, vfloat16m1_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vfredmax_vs)))
vfloat16m1_t vfredmax_vs_f16m8_f16m1(vfloat16m1_t, vfloat16m8_t, vfloat16m1_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vfredmax_vs_m)))
vfloat16m1_t vfredmax_vs_f16m8_f16m1_m(vbool2_t, vfloat16m1_t, vfloat16m8_t, vfloat16m1_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vfredmax_vs)))
vfloat16m1_t vfredmax_vs_f16mf2_f16m1(vfloat16m1_t, vfloat16mf2_t, vfloat16m1_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vfredmax_vs_m)))
vfloat16m1_t vfredmax_vs_f16mf2_f16m1_m(vbool32_t, vfloat16m1_t, vfloat16mf2_t, vfloat16m1_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vfredmax_vs)))
vfloat16m1_t vfredmax_vs_f16mf4_f16m1(vfloat16m1_t, vfloat16mf4_t, vfloat16m1_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vfredmax_vs_m)))
vfloat16m1_t vfredmax_vs_f16mf4_f16m1_m(vbool64_t, vfloat16m1_t, vfloat16mf4_t, vfloat16m1_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vfredmin_vs)))
vfloat16m1_t vfredmin_vs_f16m1_f16m1(vfloat16m1_t, vfloat16m1_t, vfloat16m1_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vfredmin_vs_m)))
vfloat16m1_t vfredmin_vs_f16m1_f16m1_m(vbool16_t, vfloat16m1_t, vfloat16m1_t, vfloat16m1_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vfredmin_vs)))
vfloat16m1_t vfredmin_vs_f16m2_f16m1(vfloat16m1_t, vfloat16m2_t, vfloat16m1_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vfredmin_vs_m)))
vfloat16m1_t vfredmin_vs_f16m2_f16m1_m(vbool8_t, vfloat16m1_t, vfloat16m2_t, vfloat16m1_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vfredmin_vs)))
vfloat16m1_t vfredmin_vs_f16m4_f16m1(vfloat16m1_t, vfloat16m4_t, vfloat16m1_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vfredmin_vs_m)))
vfloat16m1_t vfredmin_vs_f16m4_f16m1_m(vbool4_t, vfloat16m1_t, vfloat16m4_t, vfloat16m1_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vfredmin_vs)))
vfloat16m1_t vfredmin_vs_f16m8_f16m1(vfloat16m1_t, vfloat16m8_t, vfloat16m1_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vfredmin_vs_m)))
vfloat16m1_t vfredmin_vs_f16m8_f16m1_m(vbool2_t, vfloat16m1_t, vfloat16m8_t, vfloat16m1_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vfredmin_vs)))
vfloat16m1_t vfredmin_vs_f16mf2_f16m1(vfloat16m1_t, vfloat16mf2_t, vfloat16m1_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vfredmin_vs_m)))
vfloat16m1_t vfredmin_vs_f16mf2_f16m1_m(vbool32_t, vfloat16m1_t, vfloat16mf2_t, vfloat16m1_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vfredmin_vs)))
vfloat16m1_t vfredmin_vs_f16mf4_f16m1(vfloat16m1_t, vfloat16mf4_t, vfloat16m1_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vfredmin_vs_m)))
vfloat16m1_t vfredmin_vs_f16mf4_f16m1_m(vbool64_t, vfloat16m1_t, vfloat16mf4_t, vfloat16m1_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vfredusum_vs)))
vfloat16m1_t vfredusum_vs_f16m1_f16m1(vfloat16m1_t, vfloat16m1_t, vfloat16m1_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vfredusum_vs_m)))
vfloat16m1_t vfredusum_vs_f16m1_f16m1_m(vbool16_t, vfloat16m1_t, vfloat16m1_t, vfloat16m1_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vfredusum_vs)))
vfloat16m1_t vfredusum_vs_f16m2_f16m1(vfloat16m1_t, vfloat16m2_t, vfloat16m1_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vfredusum_vs_m)))
vfloat16m1_t vfredusum_vs_f16m2_f16m1_m(vbool8_t, vfloat16m1_t, vfloat16m2_t, vfloat16m1_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vfredusum_vs)))
vfloat16m1_t vfredusum_vs_f16m4_f16m1(vfloat16m1_t, vfloat16m4_t, vfloat16m1_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vfredusum_vs_m)))
vfloat16m1_t vfredusum_vs_f16m4_f16m1_m(vbool4_t, vfloat16m1_t, vfloat16m4_t, vfloat16m1_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vfredusum_vs)))
vfloat16m1_t vfredusum_vs_f16m8_f16m1(vfloat16m1_t, vfloat16m8_t, vfloat16m1_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vfredusum_vs_m)))
vfloat16m1_t vfredusum_vs_f16m8_f16m1_m(vbool2_t, vfloat16m1_t, vfloat16m8_t, vfloat16m1_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vfredusum_vs)))
vfloat16m1_t vfredusum_vs_f16mf2_f16m1(vfloat16m1_t, vfloat16mf2_t, vfloat16m1_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vfredusum_vs_m)))
vfloat16m1_t vfredusum_vs_f16mf2_f16m1_m(vbool32_t, vfloat16m1_t, vfloat16mf2_t, vfloat16m1_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vfredusum_vs)))
vfloat16m1_t vfredusum_vs_f16mf4_f16m1(vfloat16m1_t, vfloat16mf4_t, vfloat16m1_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vfredusum_vs_m)))
vfloat16m1_t vfredusum_vs_f16mf4_f16m1_m(vbool64_t, vfloat16m1_t, vfloat16mf4_t, vfloat16m1_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vfredosum_vs)))
vfloat16m1_t vfredosum_vs_f16m1_f16m1(vfloat16m1_t, vfloat16m1_t, vfloat16m1_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vfredosum_vs_m)))
vfloat16m1_t vfredosum_vs_f16m1_f16m1_m(vbool16_t, vfloat16m1_t, vfloat16m1_t, vfloat16m1_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vfredosum_vs)))
vfloat16m1_t vfredosum_vs_f16m2_f16m1(vfloat16m1_t, vfloat16m2_t, vfloat16m1_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vfredosum_vs_m)))
vfloat16m1_t vfredosum_vs_f16m2_f16m1_m(vbool8_t, vfloat16m1_t, vfloat16m2_t, vfloat16m1_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vfredosum_vs)))
vfloat16m1_t vfredosum_vs_f16m4_f16m1(vfloat16m1_t, vfloat16m4_t, vfloat16m1_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vfredosum_vs_m)))
vfloat16m1_t vfredosum_vs_f16m4_f16m1_m(vbool4_t, vfloat16m1_t, vfloat16m4_t, vfloat16m1_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vfredosum_vs)))
vfloat16m1_t vfredosum_vs_f16m8_f16m1(vfloat16m1_t, vfloat16m8_t, vfloat16m1_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vfredosum_vs_m)))
vfloat16m1_t vfredosum_vs_f16m8_f16m1_m(vbool2_t, vfloat16m1_t, vfloat16m8_t, vfloat16m1_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vfredosum_vs)))
vfloat16m1_t vfredosum_vs_f16mf2_f16m1(vfloat16m1_t, vfloat16mf2_t, vfloat16m1_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vfredosum_vs_m)))
vfloat16m1_t vfredosum_vs_f16mf2_f16m1_m(vbool32_t, vfloat16m1_t, vfloat16mf2_t, vfloat16m1_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vfredosum_vs)))
vfloat16m1_t vfredosum_vs_f16mf4_f16m1(vfloat16m1_t, vfloat16mf4_t, vfloat16m1_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vfredosum_vs_m)))
vfloat16m1_t vfredosum_vs_f16mf4_f16m1_m(vbool64_t, vfloat16m1_t, vfloat16mf4_t, vfloat16m1_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vfmv_f_s)))
_Float16 vfmv_f_s_f16m1_f16(vfloat16m1_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vfmv_f_s)))
_Float16 vfmv_f_s_f16m2_f16(vfloat16m2_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vfmv_f_s)))
_Float16 vfmv_f_s_f16m4_f16(vfloat16m4_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vfmv_f_s)))
_Float16 vfmv_f_s_f16m8_f16(vfloat16m8_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vfmv_f_s)))
_Float16 vfmv_f_s_f16mf2_f16(vfloat16mf2_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vfmv_f_s)))
_Float16 vfmv_f_s_f16mf4_f16(vfloat16mf4_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vfmv_s_f)))
vfloat16m1_t vfmv_s_f_f16m1(vfloat16m1_t, _Float16, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vfmv_s_f)))
vfloat16m2_t vfmv_s_f_f16m2(vfloat16m2_t, _Float16, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vfmv_s_f)))
vfloat16m4_t vfmv_s_f_f16m4(vfloat16m4_t, _Float16, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vfmv_s_f)))
vfloat16m8_t vfmv_s_f_f16m8(vfloat16m8_t, _Float16, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vfmv_s_f)))
vfloat16mf2_t vfmv_s_f_f16mf2(vfloat16mf2_t, _Float16, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vfmv_s_f)))
vfloat16mf4_t vfmv_s_f_f16mf4(vfloat16mf4_t, _Float16, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vslideup_vx)))
vfloat16m1_t vslideup_vx_f16m1(vfloat16m1_t, vfloat16m1_t, size_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vslideup_vx_m)))
vfloat16m1_t vslideup_vx_f16m1_m(vbool16_t, vfloat16m1_t, vfloat16m1_t, size_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vslideup_vx)))
vfloat16m2_t vslideup_vx_f16m2(vfloat16m2_t, vfloat16m2_t, size_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vslideup_vx_m)))
vfloat16m2_t vslideup_vx_f16m2_m(vbool8_t, vfloat16m2_t, vfloat16m2_t, size_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vslideup_vx)))
vfloat16m4_t vslideup_vx_f16m4(vfloat16m4_t, vfloat16m4_t, size_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vslideup_vx_m)))
vfloat16m4_t vslideup_vx_f16m4_m(vbool4_t, vfloat16m4_t, vfloat16m4_t, size_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vslideup_vx)))
vfloat16m8_t vslideup_vx_f16m8(vfloat16m8_t, vfloat16m8_t, size_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vslideup_vx_m)))
vfloat16m8_t vslideup_vx_f16m8_m(vbool2_t, vfloat16m8_t, vfloat16m8_t, size_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vslideup_vx)))
vfloat16mf2_t vslideup_vx_f16mf2(vfloat16mf2_t, vfloat16mf2_t, size_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vslideup_vx_m)))
vfloat16mf2_t vslideup_vx_f16mf2_m(vbool32_t, vfloat16mf2_t, vfloat16mf2_t, size_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vslideup_vx)))
vfloat16mf4_t vslideup_vx_f16mf4(vfloat16mf4_t, vfloat16mf4_t, size_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vslideup_vx_m)))
vfloat16mf4_t vslideup_vx_f16mf4_m(vbool64_t, vfloat16mf4_t, vfloat16mf4_t, size_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vslidedown_vx)))
vfloat16m1_t vslidedown_vx_f16m1(vfloat16m1_t, vfloat16m1_t, size_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vslidedown_vx_m)))
vfloat16m1_t vslidedown_vx_f16m1_m(vbool16_t, vfloat16m1_t, vfloat16m1_t, size_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vslidedown_vx)))
vfloat16m2_t vslidedown_vx_f16m2(vfloat16m2_t, vfloat16m2_t, size_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vslidedown_vx_m)))
vfloat16m2_t vslidedown_vx_f16m2_m(vbool8_t, vfloat16m2_t, vfloat16m2_t, size_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vslidedown_vx)))
vfloat16m4_t vslidedown_vx_f16m4(vfloat16m4_t, vfloat16m4_t, size_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vslidedown_vx_m)))
vfloat16m4_t vslidedown_vx_f16m4_m(vbool4_t, vfloat16m4_t, vfloat16m4_t, size_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vslidedown_vx)))
vfloat16m8_t vslidedown_vx_f16m8(vfloat16m8_t, vfloat16m8_t, size_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vslidedown_vx_m)))
vfloat16m8_t vslidedown_vx_f16m8_m(vbool2_t, vfloat16m8_t, vfloat16m8_t, size_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vslidedown_vx)))
vfloat16mf2_t vslidedown_vx_f16mf2(vfloat16mf2_t, vfloat16mf2_t, size_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vslidedown_vx_m)))
vfloat16mf2_t vslidedown_vx_f16mf2_m(vbool32_t, vfloat16mf2_t, vfloat16mf2_t, size_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vslidedown_vx)))
vfloat16mf4_t vslidedown_vx_f16mf4(vfloat16mf4_t, vfloat16mf4_t, size_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vslidedown_vx_m)))
vfloat16mf4_t vslidedown_vx_f16mf4_m(vbool64_t, vfloat16mf4_t, vfloat16mf4_t, size_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vfslide1up_vf)))
vfloat16m1_t vfslide1up_vf_f16m1(vfloat16m1_t, _Float16, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vfslide1up_vf_m)))
vfloat16m1_t vfslide1up_vf_f16m1_m(vbool16_t, vfloat16m1_t, vfloat16m1_t, _Float16, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vfslide1up_vf)))
vfloat16m2_t vfslide1up_vf_f16m2(vfloat16m2_t, _Float16, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vfslide1up_vf_m)))
vfloat16m2_t vfslide1up_vf_f16m2_m(vbool8_t, vfloat16m2_t, vfloat16m2_t, _Float16, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vfslide1up_vf)))
vfloat16m4_t vfslide1up_vf_f16m4(vfloat16m4_t, _Float16, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vfslide1up_vf_m)))
vfloat16m4_t vfslide1up_vf_f16m4_m(vbool4_t, vfloat16m4_t, vfloat16m4_t, _Float16, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vfslide1up_vf)))
vfloat16m8_t vfslide1up_vf_f16m8(vfloat16m8_t, _Float16, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vfslide1up_vf_m)))
vfloat16m8_t vfslide1up_vf_f16m8_m(vbool2_t, vfloat16m8_t, vfloat16m8_t, _Float16, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vfslide1up_vf)))
vfloat16mf2_t vfslide1up_vf_f16mf2(vfloat16mf2_t, _Float16, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vfslide1up_vf_m)))
vfloat16mf2_t vfslide1up_vf_f16mf2_m(vbool32_t, vfloat16mf2_t, vfloat16mf2_t, _Float16, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vfslide1up_vf)))
vfloat16mf4_t vfslide1up_vf_f16mf4(vfloat16mf4_t, _Float16, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vfslide1up_vf_m)))
vfloat16mf4_t vfslide1up_vf_f16mf4_m(vbool64_t, vfloat16mf4_t, vfloat16mf4_t, _Float16, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vfslide1down_vf)))
vfloat16m1_t vfslide1down_vf_f16m1(vfloat16m1_t, _Float16, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vfslide1down_vf_m)))
vfloat16m1_t vfslide1down_vf_f16m1_m(vbool16_t, vfloat16m1_t, vfloat16m1_t, _Float16, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vfslide1down_vf)))
vfloat16m2_t vfslide1down_vf_f16m2(vfloat16m2_t, _Float16, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vfslide1down_vf_m)))
vfloat16m2_t vfslide1down_vf_f16m2_m(vbool8_t, vfloat16m2_t, vfloat16m2_t, _Float16, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vfslide1down_vf)))
vfloat16m4_t vfslide1down_vf_f16m4(vfloat16m4_t, _Float16, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vfslide1down_vf_m)))
vfloat16m4_t vfslide1down_vf_f16m4_m(vbool4_t, vfloat16m4_t, vfloat16m4_t, _Float16, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vfslide1down_vf)))
vfloat16m8_t vfslide1down_vf_f16m8(vfloat16m8_t, _Float16, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vfslide1down_vf_m)))
vfloat16m8_t vfslide1down_vf_f16m8_m(vbool2_t, vfloat16m8_t, vfloat16m8_t, _Float16, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vfslide1down_vf)))
vfloat16mf2_t vfslide1down_vf_f16mf2(vfloat16mf2_t, _Float16, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vfslide1down_vf_m)))
vfloat16mf2_t vfslide1down_vf_f16mf2_m(vbool32_t, vfloat16mf2_t, vfloat16mf2_t, _Float16, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vfslide1down_vf)))
vfloat16mf4_t vfslide1down_vf_f16mf4(vfloat16mf4_t, _Float16, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vfslide1down_vf_m)))
vfloat16mf4_t vfslide1down_vf_f16mf4_m(vbool64_t, vfloat16mf4_t, vfloat16mf4_t, _Float16, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vrgather_vv)))
vfloat16m1_t vrgather_vv_f16m1(vfloat16m1_t, vuint16m1_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vrgather_vv_m)))
vfloat16m1_t vrgather_vv_f16m1_m(vbool16_t, vfloat16m1_t, vfloat16m1_t, vuint16m1_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vrgather_vv)))
vfloat16m2_t vrgather_vv_f16m2(vfloat16m2_t, vuint16m2_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vrgather_vv_m)))
vfloat16m2_t vrgather_vv_f16m2_m(vbool8_t, vfloat16m2_t, vfloat16m2_t, vuint16m2_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vrgather_vv)))
vfloat16m4_t vrgather_vv_f16m4(vfloat16m4_t, vuint16m4_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vrgather_vv_m)))
vfloat16m4_t vrgather_vv_f16m4_m(vbool4_t, vfloat16m4_t, vfloat16m4_t, vuint16m4_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vrgather_vv)))
vfloat16m8_t vrgather_vv_f16m8(vfloat16m8_t, vuint16m8_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vrgather_vv_m)))
vfloat16m8_t vrgather_vv_f16m8_m(vbool2_t, vfloat16m8_t, vfloat16m8_t, vuint16m8_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vrgather_vv)))
vfloat16mf2_t vrgather_vv_f16mf2(vfloat16mf2_t, vuint16mf2_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vrgather_vv_m)))
vfloat16mf2_t vrgather_vv_f16mf2_m(vbool32_t, vfloat16mf2_t, vfloat16mf2_t, vuint16mf2_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vrgather_vv)))
vfloat16mf4_t vrgather_vv_f16mf4(vfloat16mf4_t, vuint16mf4_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vrgather_vv_m)))
vfloat16mf4_t vrgather_vv_f16mf4_m(vbool64_t, vfloat16mf4_t, vfloat16mf4_t, vuint16mf4_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vrgather_vx)))
vfloat16m1_t vrgather_vx_f16m1(vfloat16m1_t, size_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vrgather_vx_m)))
vfloat16m1_t vrgather_vx_f16m1_m(vbool16_t, vfloat16m1_t, vfloat16m1_t, size_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vrgather_vx)))
vfloat16m2_t vrgather_vx_f16m2(vfloat16m2_t, size_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vrgather_vx_m)))
vfloat16m2_t vrgather_vx_f16m2_m(vbool8_t, vfloat16m2_t, vfloat16m2_t, size_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vrgather_vx)))
vfloat16m4_t vrgather_vx_f16m4(vfloat16m4_t, size_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vrgather_vx_m)))
vfloat16m4_t vrgather_vx_f16m4_m(vbool4_t, vfloat16m4_t, vfloat16m4_t, size_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vrgather_vx)))
vfloat16m8_t vrgather_vx_f16m8(vfloat16m8_t, size_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vrgather_vx_m)))
vfloat16m8_t vrgather_vx_f16m8_m(vbool2_t, vfloat16m8_t, vfloat16m8_t, size_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vrgather_vx)))
vfloat16mf2_t vrgather_vx_f16mf2(vfloat16mf2_t, size_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vrgather_vx_m)))
vfloat16mf2_t vrgather_vx_f16mf2_m(vbool32_t, vfloat16mf2_t, vfloat16mf2_t, size_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vrgather_vx)))
vfloat16mf4_t vrgather_vx_f16mf4(vfloat16mf4_t, size_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vrgather_vx_m)))
vfloat16mf4_t vrgather_vx_f16mf4_m(vbool64_t, vfloat16mf4_t, vfloat16mf4_t, size_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vrgatherei16_vv)))
vfloat16m1_t vrgatherei16_vv_f16m1(vfloat16m1_t, vuint16m1_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vrgatherei16_vv_m)))
vfloat16m1_t vrgatherei16_vv_f16m1_m(vbool16_t, vfloat16m1_t, vfloat16m1_t, vuint16m1_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vrgatherei16_vv)))
vfloat16m2_t vrgatherei16_vv_f16m2(vfloat16m2_t, vuint16m2_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vrgatherei16_vv_m)))
vfloat16m2_t vrgatherei16_vv_f16m2_m(vbool8_t, vfloat16m2_t, vfloat16m2_t, vuint16m2_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vrgatherei16_vv)))
vfloat16m4_t vrgatherei16_vv_f16m4(vfloat16m4_t, vuint16m4_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vrgatherei16_vv_m)))
vfloat16m4_t vrgatherei16_vv_f16m4_m(vbool4_t, vfloat16m4_t, vfloat16m4_t, vuint16m4_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vrgatherei16_vv)))
vfloat16m8_t vrgatherei16_vv_f16m8(vfloat16m8_t, vuint16m8_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vrgatherei16_vv_m)))
vfloat16m8_t vrgatherei16_vv_f16m8_m(vbool2_t, vfloat16m8_t, vfloat16m8_t, vuint16m8_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vrgatherei16_vv)))
vfloat16mf2_t vrgatherei16_vv_f16mf2(vfloat16mf2_t, vuint16mf2_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vrgatherei16_vv_m)))
vfloat16mf2_t vrgatherei16_vv_f16mf2_m(vbool32_t, vfloat16mf2_t, vfloat16mf2_t, vuint16mf2_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vrgatherei16_vv)))
vfloat16mf4_t vrgatherei16_vv_f16mf4(vfloat16mf4_t, vuint16mf4_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vrgatherei16_vv_m)))
vfloat16mf4_t vrgatherei16_vv_f16mf4_m(vbool64_t, vfloat16mf4_t, vfloat16mf4_t, vuint16mf4_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vcompress_vm)))
vfloat16m1_t vcompress_vm_f16m1(vbool16_t, vfloat16m1_t, vfloat16m1_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vcompress_vm)))
vfloat16m2_t vcompress_vm_f16m2(vbool8_t, vfloat16m2_t, vfloat16m2_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vcompress_vm)))
vfloat16m4_t vcompress_vm_f16m4(vbool4_t, vfloat16m4_t, vfloat16m4_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vcompress_vm)))
vfloat16m8_t vcompress_vm_f16m8(vbool2_t, vfloat16m8_t, vfloat16m8_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vcompress_vm)))
vfloat16mf2_t vcompress_vm_f16mf2(vbool32_t, vfloat16mf2_t, vfloat16mf2_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vcompress_vm)))
vfloat16mf4_t vcompress_vm_f16mf4(vbool64_t, vfloat16mf4_t, vfloat16mf4_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vget_v)))
vfloat16m1_t vget_v_f16m2_f16m1(vfloat16m2_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vget_v)))
vfloat16m1_t vget_v_f16m4_f16m1(vfloat16m4_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vget_v)))
vfloat16m1_t vget_v_f16m8_f16m1(vfloat16m8_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vget_v)))
vfloat16m2_t vget_v_f16m4_f16m2(vfloat16m4_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vget_v)))
vfloat16m2_t vget_v_f16m8_f16m2(vfloat16m8_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vget_v)))
vfloat16m4_t vget_v_f16m8_f16m4(vfloat16m8_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vset_v)))
vfloat16m2_t vset_v_f16m1_f16m2(vfloat16m2_t, size_t, vfloat16m1_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vset_v)))
vfloat16m4_t vset_v_f16m1_f16m4(vfloat16m4_t, size_t, vfloat16m1_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vset_v)))
vfloat16m4_t vset_v_f16m2_f16m4(vfloat16m4_t, size_t, vfloat16m2_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vset_v)))
vfloat16m8_t vset_v_f16m1_f16m8(vfloat16m8_t, size_t, vfloat16m1_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vset_v)))
vfloat16m8_t vset_v_f16m2_f16m8(vfloat16m8_t, size_t, vfloat16m2_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vset_v)))
vfloat16m8_t vset_v_f16m4_f16m8(vfloat16m8_t, size_t, vfloat16m4_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vsuxei8_v)))
void vsuxei8_v_f16m1(_Float16 *, vuint8mf2_t, vfloat16m1_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vsuxei8_v_m)))
void vsuxei8_v_f16m1_m(vbool16_t, _Float16 *, vuint8mf2_t, vfloat16m1_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vsuxei8_v)))
void vsuxei8_v_f16m2(_Float16 *, vuint8m1_t, vfloat16m2_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vsuxei8_v_m)))
void vsuxei8_v_f16m2_m(vbool8_t, _Float16 *, vuint8m1_t, vfloat16m2_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vsuxei8_v)))
void vsuxei8_v_f16m4(_Float16 *, vuint8m2_t, vfloat16m4_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vsuxei8_v_m)))
void vsuxei8_v_f16m4_m(vbool4_t, _Float16 *, vuint8m2_t, vfloat16m4_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vsuxei8_v)))
void vsuxei8_v_f16m8(_Float16 *, vuint8m4_t, vfloat16m8_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vsuxei8_v_m)))
void vsuxei8_v_f16m8_m(vbool2_t, _Float16 *, vuint8m4_t, vfloat16m8_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vsuxei8_v)))
void vsuxei8_v_f16mf2(_Float16 *, vuint8mf4_t, vfloat16mf2_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vsuxei8_v_m)))
void vsuxei8_v_f16mf2_m(vbool32_t, _Float16 *, vuint8mf4_t, vfloat16mf2_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vsuxei8_v)))
void vsuxei8_v_f16mf4(_Float16 *, vuint8mf8_t, vfloat16mf4_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vsuxei8_v_m)))
void vsuxei8_v_f16mf4_m(vbool64_t, _Float16 *, vuint8mf8_t, vfloat16mf4_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vsuxei16_v)))
void vsuxei16_v_f16m1(_Float16 *, vuint16m1_t, vfloat16m1_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vsuxei16_v_m)))
void vsuxei16_v_f16m1_m(vbool16_t, _Float16 *, vuint16m1_t, vfloat16m1_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vsuxei16_v)))
void vsuxei16_v_f16m2(_Float16 *, vuint16m2_t, vfloat16m2_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vsuxei16_v_m)))
void vsuxei16_v_f16m2_m(vbool8_t, _Float16 *, vuint16m2_t, vfloat16m2_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vsuxei16_v)))
void vsuxei16_v_f16m4(_Float16 *, vuint16m4_t, vfloat16m4_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vsuxei16_v_m)))
void vsuxei16_v_f16m4_m(vbool4_t, _Float16 *, vuint16m4_t, vfloat16m4_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vsuxei16_v)))
void vsuxei16_v_f16m8(_Float16 *, vuint16m8_t, vfloat16m8_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vsuxei16_v_m)))
void vsuxei16_v_f16m8_m(vbool2_t, _Float16 *, vuint16m8_t, vfloat16m8_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vsuxei16_v)))
void vsuxei16_v_f16mf2(_Float16 *, vuint16mf2_t, vfloat16mf2_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vsuxei16_v_m)))
void vsuxei16_v_f16mf2_m(vbool32_t, _Float16 *, vuint16mf2_t, vfloat16mf2_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vsuxei16_v)))
void vsuxei16_v_f16mf4(_Float16 *, vuint16mf4_t, vfloat16mf4_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vsuxei16_v_m)))
void vsuxei16_v_f16mf4_m(vbool64_t, _Float16 *, vuint16mf4_t, vfloat16mf4_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vsuxei32_v)))
void vsuxei32_v_f16m1(_Float16 *, vuint32m2_t, vfloat16m1_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vsuxei32_v_m)))
void vsuxei32_v_f16m1_m(vbool16_t, _Float16 *, vuint32m2_t, vfloat16m1_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vsuxei32_v)))
void vsuxei32_v_f16m2(_Float16 *, vuint32m4_t, vfloat16m2_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vsuxei32_v_m)))
void vsuxei32_v_f16m2_m(vbool8_t, _Float16 *, vuint32m4_t, vfloat16m2_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vsuxei32_v)))
void vsuxei32_v_f16m4(_Float16 *, vuint32m8_t, vfloat16m4_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vsuxei32_v_m)))
void vsuxei32_v_f16m4_m(vbool4_t, _Float16 *, vuint32m8_t, vfloat16m4_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vsuxei32_v)))
void vsuxei32_v_f16mf2(_Float16 *, vuint32m1_t, vfloat16mf2_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vsuxei32_v_m)))
void vsuxei32_v_f16mf2_m(vbool32_t, _Float16 *, vuint32m1_t, vfloat16mf2_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vsuxei32_v)))
void vsuxei32_v_f16mf4(_Float16 *, vuint32mf2_t, vfloat16mf4_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vsuxei32_v_m)))
void vsuxei32_v_f16mf4_m(vbool64_t, _Float16 *, vuint32mf2_t, vfloat16mf4_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vsoxei8_v)))
void vsoxei8_v_f16m1(_Float16 *, vuint8mf2_t, vfloat16m1_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vsoxei8_v_m)))
void vsoxei8_v_f16m1_m(vbool16_t, _Float16 *, vuint8mf2_t, vfloat16m1_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vsoxei8_v)))
void vsoxei8_v_f16m2(_Float16 *, vuint8m1_t, vfloat16m2_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vsoxei8_v_m)))
void vsoxei8_v_f16m2_m(vbool8_t, _Float16 *, vuint8m1_t, vfloat16m2_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vsoxei8_v)))
void vsoxei8_v_f16m4(_Float16 *, vuint8m2_t, vfloat16m4_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vsoxei8_v_m)))
void vsoxei8_v_f16m4_m(vbool4_t, _Float16 *, vuint8m2_t, vfloat16m4_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vsoxei8_v)))
void vsoxei8_v_f16m8(_Float16 *, vuint8m4_t, vfloat16m8_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vsoxei8_v_m)))
void vsoxei8_v_f16m8_m(vbool2_t, _Float16 *, vuint8m4_t, vfloat16m8_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vsoxei8_v)))
void vsoxei8_v_f16mf2(_Float16 *, vuint8mf4_t, vfloat16mf2_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vsoxei8_v_m)))
void vsoxei8_v_f16mf2_m(vbool32_t, _Float16 *, vuint8mf4_t, vfloat16mf2_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vsoxei8_v)))
void vsoxei8_v_f16mf4(_Float16 *, vuint8mf8_t, vfloat16mf4_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vsoxei8_v_m)))
void vsoxei8_v_f16mf4_m(vbool64_t, _Float16 *, vuint8mf8_t, vfloat16mf4_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vsoxei16_v)))
void vsoxei16_v_f16m1(_Float16 *, vuint16m1_t, vfloat16m1_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vsoxei16_v_m)))
void vsoxei16_v_f16m1_m(vbool16_t, _Float16 *, vuint16m1_t, vfloat16m1_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vsoxei16_v)))
void vsoxei16_v_f16m2(_Float16 *, vuint16m2_t, vfloat16m2_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vsoxei16_v_m)))
void vsoxei16_v_f16m2_m(vbool8_t, _Float16 *, vuint16m2_t, vfloat16m2_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vsoxei16_v)))
void vsoxei16_v_f16m4(_Float16 *, vuint16m4_t, vfloat16m4_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vsoxei16_v_m)))
void vsoxei16_v_f16m4_m(vbool4_t, _Float16 *, vuint16m4_t, vfloat16m4_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vsoxei16_v)))
void vsoxei16_v_f16m8(_Float16 *, vuint16m8_t, vfloat16m8_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vsoxei16_v_m)))
void vsoxei16_v_f16m8_m(vbool2_t, _Float16 *, vuint16m8_t, vfloat16m8_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vsoxei16_v)))
void vsoxei16_v_f16mf2(_Float16 *, vuint16mf2_t, vfloat16mf2_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vsoxei16_v_m)))
void vsoxei16_v_f16mf2_m(vbool32_t, _Float16 *, vuint16mf2_t, vfloat16mf2_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vsoxei16_v)))
void vsoxei16_v_f16mf4(_Float16 *, vuint16mf4_t, vfloat16mf4_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vsoxei16_v_m)))
void vsoxei16_v_f16mf4_m(vbool64_t, _Float16 *, vuint16mf4_t, vfloat16mf4_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vsoxei32_v)))
void vsoxei32_v_f16m1(_Float16 *, vuint32m2_t, vfloat16m1_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vsoxei32_v_m)))
void vsoxei32_v_f16m1_m(vbool16_t, _Float16 *, vuint32m2_t, vfloat16m1_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vsoxei32_v)))
void vsoxei32_v_f16m2(_Float16 *, vuint32m4_t, vfloat16m2_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vsoxei32_v_m)))
void vsoxei32_v_f16m2_m(vbool8_t, _Float16 *, vuint32m4_t, vfloat16m2_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vsoxei32_v)))
void vsoxei32_v_f16m4(_Float16 *, vuint32m8_t, vfloat16m4_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vsoxei32_v_m)))
void vsoxei32_v_f16m4_m(vbool4_t, _Float16 *, vuint32m8_t, vfloat16m4_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vsoxei32_v)))
void vsoxei32_v_f16mf2(_Float16 *, vuint32m1_t, vfloat16mf2_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vsoxei32_v_m)))
void vsoxei32_v_f16mf2_m(vbool32_t, _Float16 *, vuint32m1_t, vfloat16mf2_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vsoxei32_v)))
void vsoxei32_v_f16mf4(_Float16 *, vuint32mf2_t, vfloat16mf4_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vsoxei32_v_m)))
void vsoxei32_v_f16mf4_m(vbool64_t, _Float16 *, vuint32mf2_t, vfloat16mf4_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vle16ff_v)))
vfloat16m1_t vle16ff_v_f16m1(const _Float16 *, size_t *, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vle16ff_v_m)))
vfloat16m1_t vle16ff_v_f16m1_m(vbool16_t, vfloat16m1_t, const _Float16 *, size_t *, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vle16ff_v)))
vfloat16m2_t vle16ff_v_f16m2(const _Float16 *, size_t *, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vle16ff_v_m)))
vfloat16m2_t vle16ff_v_f16m2_m(vbool8_t, vfloat16m2_t, const _Float16 *, size_t *, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vle16ff_v)))
vfloat16m4_t vle16ff_v_f16m4(const _Float16 *, size_t *, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vle16ff_v_m)))
vfloat16m4_t vle16ff_v_f16m4_m(vbool4_t, vfloat16m4_t, const _Float16 *, size_t *, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vle16ff_v)))
vfloat16m8_t vle16ff_v_f16m8(const _Float16 *, size_t *, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vle16ff_v_m)))
vfloat16m8_t vle16ff_v_f16m8_m(vbool2_t, vfloat16m8_t, const _Float16 *, size_t *, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vle16ff_v)))
vfloat16mf2_t vle16ff_v_f16mf2(const _Float16 *, size_t *, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vle16ff_v_m)))
vfloat16mf2_t vle16ff_v_f16mf2_m(vbool32_t, vfloat16mf2_t, const _Float16 *, size_t *, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vle16ff_v)))
vfloat16mf4_t vle16ff_v_f16mf4(const _Float16 *, size_t *, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vle16ff_v_m)))
vfloat16mf4_t vle16ff_v_f16mf4_m(vbool64_t, vfloat16mf4_t, const _Float16 *, size_t *, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vlseg2e16_v)))
void vlseg2e16_v_f16m1(vfloat16m1_t *, vfloat16m1_t *, const _Float16 *, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vlseg2e16_v_m)))
void vlseg2e16_v_f16m1_m(vfloat16m1_t *, vfloat16m1_t *, vbool16_t, vfloat16m1_t, vfloat16m1_t, const _Float16 *, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vlseg2e16_v)))
void vlseg2e16_v_f16m2(vfloat16m2_t *, vfloat16m2_t *, const _Float16 *, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vlseg2e16_v_m)))
void vlseg2e16_v_f16m2_m(vfloat16m2_t *, vfloat16m2_t *, vbool8_t, vfloat16m2_t, vfloat16m2_t, const _Float16 *, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vlseg2e16_v)))
void vlseg2e16_v_f16m4(vfloat16m4_t *, vfloat16m4_t *, const _Float16 *, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vlseg2e16_v_m)))
void vlseg2e16_v_f16m4_m(vfloat16m4_t *, vfloat16m4_t *, vbool4_t, vfloat16m4_t, vfloat16m4_t, const _Float16 *, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vlseg2e16_v)))
void vlseg2e16_v_f16mf2(vfloat16mf2_t *, vfloat16mf2_t *, const _Float16 *, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vlseg2e16_v_m)))
void vlseg2e16_v_f16mf2_m(vfloat16mf2_t *, vfloat16mf2_t *, vbool32_t, vfloat16mf2_t, vfloat16mf2_t, const _Float16 *, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vlseg2e16_v)))
void vlseg2e16_v_f16mf4(vfloat16mf4_t *, vfloat16mf4_t *, const _Float16 *, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vlseg2e16_v_m)))
void vlseg2e16_v_f16mf4_m(vfloat16mf4_t *, vfloat16mf4_t *, vbool64_t, vfloat16mf4_t, vfloat16mf4_t, const _Float16 *, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vlseg3e16_v)))
void vlseg3e16_v_f16m1(vfloat16m1_t *, vfloat16m1_t *, vfloat16m1_t *, const _Float16 *, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vlseg3e16_v_m)))
void vlseg3e16_v_f16m1_m(vfloat16m1_t *, vfloat16m1_t *, vfloat16m1_t *, vbool16_t, vfloat16m1_t, vfloat16m1_t, vfloat16m1_t, const _Float16 *, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vlseg3e16_v)))
void vlseg3e16_v_f16m2(vfloat16m2_t *, vfloat16m2_t *, vfloat16m2_t *, const _Float16 *, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vlseg3e16_v_m)))
void vlseg3e16_v_f16m2_m(vfloat16m2_t *, vfloat16m2_t *, vfloat16m2_t *, vbool8_t, vfloat16m2_t, vfloat16m2_t, vfloat16m2_t, const _Float16 *, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vlseg3e16_v)))
void vlseg3e16_v_f16mf2(vfloat16mf2_t *, vfloat16mf2_t *, vfloat16mf2_t *, const _Float16 *, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vlseg3e16_v_m)))
void vlseg3e16_v_f16mf2_m(vfloat16mf2_t *, vfloat16mf2_t *, vfloat16mf2_t *, vbool32_t, vfloat16mf2_t, vfloat16mf2_t, vfloat16mf2_t, const _Float16 *, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vlseg3e16_v)))
void vlseg3e16_v_f16mf4(vfloat16mf4_t *, vfloat16mf4_t *, vfloat16mf4_t *, const _Float16 *, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vlseg3e16_v_m)))
void vlseg3e16_v_f16mf4_m(vfloat16mf4_t *, vfloat16mf4_t *, vfloat16mf4_t *, vbool64_t, vfloat16mf4_t, vfloat16mf4_t, vfloat16mf4_t, const _Float16 *, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vlseg4e16_v)))
void vlseg4e16_v_f16m1(vfloat16m1_t *, vfloat16m1_t *, vfloat16m1_t *, vfloat16m1_t *, const _Float16 *, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vlseg4e16_v_m)))
void vlseg4e16_v_f16m1_m(vfloat16m1_t *, vfloat16m1_t *, vfloat16m1_t *, vfloat16m1_t *, vbool16_t, vfloat16m1_t, vfloat16m1_t, vfloat16m1_t, vfloat16m1_t, const _Float16 *, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vlseg4e16_v)))
void vlseg4e16_v_f16m2(vfloat16m2_t *, vfloat16m2_t *, vfloat16m2_t *, vfloat16m2_t *, const _Float16 *, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vlseg4e16_v_m)))
void vlseg4e16_v_f16m2_m(vfloat16m2_t *, vfloat16m2_t *, vfloat16m2_t *, vfloat16m2_t *, vbool8_t, vfloat16m2_t, vfloat16m2_t, vfloat16m2_t, vfloat16m2_t, const _Float16 *, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vlseg4e16_v)))
void vlseg4e16_v_f16mf2(vfloat16mf2_t *, vfloat16mf2_t *, vfloat16mf2_t *, vfloat16mf2_t *, const _Float16 *, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vlseg4e16_v_m)))
void vlseg4e16_v_f16mf2_m(vfloat16mf2_t *, vfloat16mf2_t *, vfloat16mf2_t *, vfloat16mf2_t *, vbool32_t, vfloat16mf2_t, vfloat16mf2_t, vfloat16mf2_t, vfloat16mf2_t, const _Float16 *, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vlseg4e16_v)))
void vlseg4e16_v_f16mf4(vfloat16mf4_t *, vfloat16mf4_t *, vfloat16mf4_t *, vfloat16mf4_t *, const _Float16 *, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vlseg4e16_v_m)))
void vlseg4e16_v_f16mf4_m(vfloat16mf4_t *, vfloat16mf4_t *, vfloat16mf4_t *, vfloat16mf4_t *, vbool64_t, vfloat16mf4_t, vfloat16mf4_t, vfloat16mf4_t, vfloat16mf4_t, const _Float16 *, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vlseg5e16_v)))
void vlseg5e16_v_f16m1(vfloat16m1_t *, vfloat16m1_t *, vfloat16m1_t *, vfloat16m1_t *, vfloat16m1_t *, const _Float16 *, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vlseg5e16_v_m)))
void vlseg5e16_v_f16m1_m(vfloat16m1_t *, vfloat16m1_t *, vfloat16m1_t *, vfloat16m1_t *, vfloat16m1_t *, vbool16_t, vfloat16m1_t, vfloat16m1_t, vfloat16m1_t, vfloat16m1_t, vfloat16m1_t, const _Float16 *, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vlseg5e16_v)))
void vlseg5e16_v_f16mf2(vfloat16mf2_t *, vfloat16mf2_t *, vfloat16mf2_t *, vfloat16mf2_t *, vfloat16mf2_t *, const _Float16 *, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vlseg5e16_v_m)))
void vlseg5e16_v_f16mf2_m(vfloat16mf2_t *, vfloat16mf2_t *, vfloat16mf2_t *, vfloat16mf2_t *, vfloat16mf2_t *, vbool32_t, vfloat16mf2_t, vfloat16mf2_t, vfloat16mf2_t, vfloat16mf2_t, vfloat16mf2_t, const _Float16 *, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vlseg5e16_v)))
void vlseg5e16_v_f16mf4(vfloat16mf4_t *, vfloat16mf4_t *, vfloat16mf4_t *, vfloat16mf4_t *, vfloat16mf4_t *, const _Float16 *, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vlseg5e16_v_m)))
void vlseg5e16_v_f16mf4_m(vfloat16mf4_t *, vfloat16mf4_t *, vfloat16mf4_t *, vfloat16mf4_t *, vfloat16mf4_t *, vbool64_t, vfloat16mf4_t, vfloat16mf4_t, vfloat16mf4_t, vfloat16mf4_t, vfloat16mf4_t, const _Float16 *, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vlseg6e16_v)))
void vlseg6e16_v_f16m1(vfloat16m1_t *, vfloat16m1_t *, vfloat16m1_t *, vfloat16m1_t *, vfloat16m1_t *, vfloat16m1_t *, const _Float16 *, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vlseg6e16_v_m)))
void vlseg6e16_v_f16m1_m(vfloat16m1_t *, vfloat16m1_t *, vfloat16m1_t *, vfloat16m1_t *, vfloat16m1_t *, vfloat16m1_t *, vbool16_t, vfloat16m1_t, vfloat16m1_t, vfloat16m1_t, vfloat16m1_t, vfloat16m1_t, vfloat16m1_t, const _Float16 *, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vlseg6e16_v)))
void vlseg6e16_v_f16mf2(vfloat16mf2_t *, vfloat16mf2_t *, vfloat16mf2_t *, vfloat16mf2_t *, vfloat16mf2_t *, vfloat16mf2_t *, const _Float16 *, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vlseg6e16_v_m)))
void vlseg6e16_v_f16mf2_m(vfloat16mf2_t *, vfloat16mf2_t *, vfloat16mf2_t *, vfloat16mf2_t *, vfloat16mf2_t *, vfloat16mf2_t *, vbool32_t, vfloat16mf2_t, vfloat16mf2_t, vfloat16mf2_t, vfloat16mf2_t, vfloat16mf2_t, vfloat16mf2_t, const _Float16 *, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vlseg6e16_v)))
void vlseg6e16_v_f16mf4(vfloat16mf4_t *, vfloat16mf4_t *, vfloat16mf4_t *, vfloat16mf4_t *, vfloat16mf4_t *, vfloat16mf4_t *, const _Float16 *, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vlseg6e16_v_m)))
void vlseg6e16_v_f16mf4_m(vfloat16mf4_t *, vfloat16mf4_t *, vfloat16mf4_t *, vfloat16mf4_t *, vfloat16mf4_t *, vfloat16mf4_t *, vbool64_t, vfloat16mf4_t, vfloat16mf4_t, vfloat16mf4_t, vfloat16mf4_t, vfloat16mf4_t, vfloat16mf4_t, const _Float16 *, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vlseg7e16_v)))
void vlseg7e16_v_f16m1(vfloat16m1_t *, vfloat16m1_t *, vfloat16m1_t *, vfloat16m1_t *, vfloat16m1_t *, vfloat16m1_t *, vfloat16m1_t *, const _Float16 *, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vlseg7e16_v_m)))
void vlseg7e16_v_f16m1_m(vfloat16m1_t *, vfloat16m1_t *, vfloat16m1_t *, vfloat16m1_t *, vfloat16m1_t *, vfloat16m1_t *, vfloat16m1_t *, vbool16_t, vfloat16m1_t, vfloat16m1_t, vfloat16m1_t, vfloat16m1_t, vfloat16m1_t, vfloat16m1_t, vfloat16m1_t, const _Float16 *, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vlseg7e16_v)))
void vlseg7e16_v_f16mf2(vfloat16mf2_t *, vfloat16mf2_t *, vfloat16mf2_t *, vfloat16mf2_t *, vfloat16mf2_t *, vfloat16mf2_t *, vfloat16mf2_t *, const _Float16 *, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vlseg7e16_v_m)))
void vlseg7e16_v_f16mf2_m(vfloat16mf2_t *, vfloat16mf2_t *, vfloat16mf2_t *, vfloat16mf2_t *, vfloat16mf2_t *, vfloat16mf2_t *, vfloat16mf2_t *, vbool32_t, vfloat16mf2_t, vfloat16mf2_t, vfloat16mf2_t, vfloat16mf2_t, vfloat16mf2_t, vfloat16mf2_t, vfloat16mf2_t, const _Float16 *, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vlseg7e16_v)))
void vlseg7e16_v_f16mf4(vfloat16mf4_t *, vfloat16mf4_t *, vfloat16mf4_t *, vfloat16mf4_t *, vfloat16mf4_t *, vfloat16mf4_t *, vfloat16mf4_t *, const _Float16 *, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vlseg7e16_v_m)))
void vlseg7e16_v_f16mf4_m(vfloat16mf4_t *, vfloat16mf4_t *, vfloat16mf4_t *, vfloat16mf4_t *, vfloat16mf4_t *, vfloat16mf4_t *, vfloat16mf4_t *, vbool64_t, vfloat16mf4_t, vfloat16mf4_t, vfloat16mf4_t, vfloat16mf4_t, vfloat16mf4_t, vfloat16mf4_t, vfloat16mf4_t, const _Float16 *, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vlseg8e16_v)))
void vlseg8e16_v_f16m1(vfloat16m1_t *, vfloat16m1_t *, vfloat16m1_t *, vfloat16m1_t *, vfloat16m1_t *, vfloat16m1_t *, vfloat16m1_t *, vfloat16m1_t *, const _Float16 *, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vlseg8e16_v_m)))
void vlseg8e16_v_f16m1_m(vfloat16m1_t *, vfloat16m1_t *, vfloat16m1_t *, vfloat16m1_t *, vfloat16m1_t *, vfloat16m1_t *, vfloat16m1_t *, vfloat16m1_t *, vbool16_t, vfloat16m1_t, vfloat16m1_t, vfloat16m1_t, vfloat16m1_t, vfloat16m1_t, vfloat16m1_t, vfloat16m1_t, vfloat16m1_t, const _Float16 *, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vlseg8e16_v)))
void vlseg8e16_v_f16mf2(vfloat16mf2_t *, vfloat16mf2_t *, vfloat16mf2_t *, vfloat16mf2_t *, vfloat16mf2_t *, vfloat16mf2_t *, vfloat16mf2_t *, vfloat16mf2_t *, const _Float16 *, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vlseg8e16_v_m)))
void vlseg8e16_v_f16mf2_m(vfloat16mf2_t *, vfloat16mf2_t *, vfloat16mf2_t *, vfloat16mf2_t *, vfloat16mf2_t *, vfloat16mf2_t *, vfloat16mf2_t *, vfloat16mf2_t *, vbool32_t, vfloat16mf2_t, vfloat16mf2_t, vfloat16mf2_t, vfloat16mf2_t, vfloat16mf2_t, vfloat16mf2_t, vfloat16mf2_t, vfloat16mf2_t, const _Float16 *, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vlseg8e16_v)))
void vlseg8e16_v_f16mf4(vfloat16mf4_t *, vfloat16mf4_t *, vfloat16mf4_t *, vfloat16mf4_t *, vfloat16mf4_t *, vfloat16mf4_t *, vfloat16mf4_t *, vfloat16mf4_t *, const _Float16 *, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vlseg8e16_v_m)))
void vlseg8e16_v_f16mf4_m(vfloat16mf4_t *, vfloat16mf4_t *, vfloat16mf4_t *, vfloat16mf4_t *, vfloat16mf4_t *, vfloat16mf4_t *, vfloat16mf4_t *, vfloat16mf4_t *, vbool64_t, vfloat16mf4_t, vfloat16mf4_t, vfloat16mf4_t, vfloat16mf4_t, vfloat16mf4_t, vfloat16mf4_t, vfloat16mf4_t, vfloat16mf4_t, const _Float16 *, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vlseg2e16ff_v)))
void vlseg2e16ff_v_f16m1(vfloat16m1_t *, vfloat16m1_t *, const _Float16 *, size_t *, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vlseg2e16ff_v_m)))
void vlseg2e16ff_v_f16m1_m(vfloat16m1_t *, vfloat16m1_t *, vbool16_t, vfloat16m1_t, vfloat16m1_t, const _Float16 *, size_t *, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vlseg2e16ff_v)))
void vlseg2e16ff_v_f16m2(vfloat16m2_t *, vfloat16m2_t *, const _Float16 *, size_t *, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vlseg2e16ff_v_m)))
void vlseg2e16ff_v_f16m2_m(vfloat16m2_t *, vfloat16m2_t *, vbool8_t, vfloat16m2_t, vfloat16m2_t, const _Float16 *, size_t *, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vlseg2e16ff_v)))
void vlseg2e16ff_v_f16m4(vfloat16m4_t *, vfloat16m4_t *, const _Float16 *, size_t *, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vlseg2e16ff_v_m)))
void vlseg2e16ff_v_f16m4_m(vfloat16m4_t *, vfloat16m4_t *, vbool4_t, vfloat16m4_t, vfloat16m4_t, const _Float16 *, size_t *, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vlseg2e16ff_v)))
void vlseg2e16ff_v_f16mf2(vfloat16mf2_t *, vfloat16mf2_t *, const _Float16 *, size_t *, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vlseg2e16ff_v_m)))
void vlseg2e16ff_v_f16mf2_m(vfloat16mf2_t *, vfloat16mf2_t *, vbool32_t, vfloat16mf2_t, vfloat16mf2_t, const _Float16 *, size_t *, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vlseg2e16ff_v)))
void vlseg2e16ff_v_f16mf4(vfloat16mf4_t *, vfloat16mf4_t *, const _Float16 *, size_t *, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vlseg2e16ff_v_m)))
void vlseg2e16ff_v_f16mf4_m(vfloat16mf4_t *, vfloat16mf4_t *, vbool64_t, vfloat16mf4_t, vfloat16mf4_t, const _Float16 *, size_t *, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vlseg3e16ff_v)))
void vlseg3e16ff_v_f16m1(vfloat16m1_t *, vfloat16m1_t *, vfloat16m1_t *, const _Float16 *, size_t *, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vlseg3e16ff_v_m)))
void vlseg3e16ff_v_f16m1_m(vfloat16m1_t *, vfloat16m1_t *, vfloat16m1_t *, vbool16_t, vfloat16m1_t, vfloat16m1_t, vfloat16m1_t, const _Float16 *, size_t *, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vlseg3e16ff_v)))
void vlseg3e16ff_v_f16m2(vfloat16m2_t *, vfloat16m2_t *, vfloat16m2_t *, const _Float16 *, size_t *, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vlseg3e16ff_v_m)))
void vlseg3e16ff_v_f16m2_m(vfloat16m2_t *, vfloat16m2_t *, vfloat16m2_t *, vbool8_t, vfloat16m2_t, vfloat16m2_t, vfloat16m2_t, const _Float16 *, size_t *, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vlseg3e16ff_v)))
void vlseg3e16ff_v_f16mf2(vfloat16mf2_t *, vfloat16mf2_t *, vfloat16mf2_t *, const _Float16 *, size_t *, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vlseg3e16ff_v_m)))
void vlseg3e16ff_v_f16mf2_m(vfloat16mf2_t *, vfloat16mf2_t *, vfloat16mf2_t *, vbool32_t, vfloat16mf2_t, vfloat16mf2_t, vfloat16mf2_t, const _Float16 *, size_t *, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vlseg3e16ff_v)))
void vlseg3e16ff_v_f16mf4(vfloat16mf4_t *, vfloat16mf4_t *, vfloat16mf4_t *, const _Float16 *, size_t *, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vlseg3e16ff_v_m)))
void vlseg3e16ff_v_f16mf4_m(vfloat16mf4_t *, vfloat16mf4_t *, vfloat16mf4_t *, vbool64_t, vfloat16mf4_t, vfloat16mf4_t, vfloat16mf4_t, const _Float16 *, size_t *, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vlseg4e16ff_v)))
void vlseg4e16ff_v_f16m1(vfloat16m1_t *, vfloat16m1_t *, vfloat16m1_t *, vfloat16m1_t *, const _Float16 *, size_t *, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vlseg4e16ff_v_m)))
void vlseg4e16ff_v_f16m1_m(vfloat16m1_t *, vfloat16m1_t *, vfloat16m1_t *, vfloat16m1_t *, vbool16_t, vfloat16m1_t, vfloat16m1_t, vfloat16m1_t, vfloat16m1_t, const _Float16 *, size_t *, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vlseg4e16ff_v)))
void vlseg4e16ff_v_f16m2(vfloat16m2_t *, vfloat16m2_t *, vfloat16m2_t *, vfloat16m2_t *, const _Float16 *, size_t *, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vlseg4e16ff_v_m)))
void vlseg4e16ff_v_f16m2_m(vfloat16m2_t *, vfloat16m2_t *, vfloat16m2_t *, vfloat16m2_t *, vbool8_t, vfloat16m2_t, vfloat16m2_t, vfloat16m2_t, vfloat16m2_t, const _Float16 *, size_t *, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vlseg4e16ff_v)))
void vlseg4e16ff_v_f16mf2(vfloat16mf2_t *, vfloat16mf2_t *, vfloat16mf2_t *, vfloat16mf2_t *, const _Float16 *, size_t *, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vlseg4e16ff_v_m)))
void vlseg4e16ff_v_f16mf2_m(vfloat16mf2_t *, vfloat16mf2_t *, vfloat16mf2_t *, vfloat16mf2_t *, vbool32_t, vfloat16mf2_t, vfloat16mf2_t, vfloat16mf2_t, vfloat16mf2_t, const _Float16 *, size_t *, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vlseg4e16ff_v)))
void vlseg4e16ff_v_f16mf4(vfloat16mf4_t *, vfloat16mf4_t *, vfloat16mf4_t *, vfloat16mf4_t *, const _Float16 *, size_t *, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vlseg4e16ff_v_m)))
void vlseg4e16ff_v_f16mf4_m(vfloat16mf4_t *, vfloat16mf4_t *, vfloat16mf4_t *, vfloat16mf4_t *, vbool64_t, vfloat16mf4_t, vfloat16mf4_t, vfloat16mf4_t, vfloat16mf4_t, const _Float16 *, size_t *, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vlseg5e16ff_v)))
void vlseg5e16ff_v_f16m1(vfloat16m1_t *, vfloat16m1_t *, vfloat16m1_t *, vfloat16m1_t *, vfloat16m1_t *, const _Float16 *, size_t *, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vlseg5e16ff_v_m)))
void vlseg5e16ff_v_f16m1_m(vfloat16m1_t *, vfloat16m1_t *, vfloat16m1_t *, vfloat16m1_t *, vfloat16m1_t *, vbool16_t, vfloat16m1_t, vfloat16m1_t, vfloat16m1_t, vfloat16m1_t, vfloat16m1_t, const _Float16 *, size_t *, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vlseg5e16ff_v)))
void vlseg5e16ff_v_f16mf2(vfloat16mf2_t *, vfloat16mf2_t *, vfloat16mf2_t *, vfloat16mf2_t *, vfloat16mf2_t *, const _Float16 *, size_t *, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vlseg5e16ff_v_m)))
void vlseg5e16ff_v_f16mf2_m(vfloat16mf2_t *, vfloat16mf2_t *, vfloat16mf2_t *, vfloat16mf2_t *, vfloat16mf2_t *, vbool32_t, vfloat16mf2_t, vfloat16mf2_t, vfloat16mf2_t, vfloat16mf2_t, vfloat16mf2_t, const _Float16 *, size_t *, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vlseg5e16ff_v)))
void vlseg5e16ff_v_f16mf4(vfloat16mf4_t *, vfloat16mf4_t *, vfloat16mf4_t *, vfloat16mf4_t *, vfloat16mf4_t *, const _Float16 *, size_t *, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vlseg5e16ff_v_m)))
void vlseg5e16ff_v_f16mf4_m(vfloat16mf4_t *, vfloat16mf4_t *, vfloat16mf4_t *, vfloat16mf4_t *, vfloat16mf4_t *, vbool64_t, vfloat16mf4_t, vfloat16mf4_t, vfloat16mf4_t, vfloat16mf4_t, vfloat16mf4_t, const _Float16 *, size_t *, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vlseg6e16ff_v)))
void vlseg6e16ff_v_f16m1(vfloat16m1_t *, vfloat16m1_t *, vfloat16m1_t *, vfloat16m1_t *, vfloat16m1_t *, vfloat16m1_t *, const _Float16 *, size_t *, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vlseg6e16ff_v_m)))
void vlseg6e16ff_v_f16m1_m(vfloat16m1_t *, vfloat16m1_t *, vfloat16m1_t *, vfloat16m1_t *, vfloat16m1_t *, vfloat16m1_t *, vbool16_t, vfloat16m1_t, vfloat16m1_t, vfloat16m1_t, vfloat16m1_t, vfloat16m1_t, vfloat16m1_t, const _Float16 *, size_t *, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vlseg6e16ff_v)))
void vlseg6e16ff_v_f16mf2(vfloat16mf2_t *, vfloat16mf2_t *, vfloat16mf2_t *, vfloat16mf2_t *, vfloat16mf2_t *, vfloat16mf2_t *, const _Float16 *, size_t *, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vlseg6e16ff_v_m)))
void vlseg6e16ff_v_f16mf2_m(vfloat16mf2_t *, vfloat16mf2_t *, vfloat16mf2_t *, vfloat16mf2_t *, vfloat16mf2_t *, vfloat16mf2_t *, vbool32_t, vfloat16mf2_t, vfloat16mf2_t, vfloat16mf2_t, vfloat16mf2_t, vfloat16mf2_t, vfloat16mf2_t, const _Float16 *, size_t *, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vlseg6e16ff_v)))
void vlseg6e16ff_v_f16mf4(vfloat16mf4_t *, vfloat16mf4_t *, vfloat16mf4_t *, vfloat16mf4_t *, vfloat16mf4_t *, vfloat16mf4_t *, const _Float16 *, size_t *, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vlseg6e16ff_v_m)))
void vlseg6e16ff_v_f16mf4_m(vfloat16mf4_t *, vfloat16mf4_t *, vfloat16mf4_t *, vfloat16mf4_t *, vfloat16mf4_t *, vfloat16mf4_t *, vbool64_t, vfloat16mf4_t, vfloat16mf4_t, vfloat16mf4_t, vfloat16mf4_t, vfloat16mf4_t, vfloat16mf4_t, const _Float16 *, size_t *, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vlseg7e16ff_v)))
void vlseg7e16ff_v_f16m1(vfloat16m1_t *, vfloat16m1_t *, vfloat16m1_t *, vfloat16m1_t *, vfloat16m1_t *, vfloat16m1_t *, vfloat16m1_t *, const _Float16 *, size_t *, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vlseg7e16ff_v_m)))
void vlseg7e16ff_v_f16m1_m(vfloat16m1_t *, vfloat16m1_t *, vfloat16m1_t *, vfloat16m1_t *, vfloat16m1_t *, vfloat16m1_t *, vfloat16m1_t *, vbool16_t, vfloat16m1_t, vfloat16m1_t, vfloat16m1_t, vfloat16m1_t, vfloat16m1_t, vfloat16m1_t, vfloat16m1_t, const _Float16 *, size_t *, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vlseg7e16ff_v)))
void vlseg7e16ff_v_f16mf2(vfloat16mf2_t *, vfloat16mf2_t *, vfloat16mf2_t *, vfloat16mf2_t *, vfloat16mf2_t *, vfloat16mf2_t *, vfloat16mf2_t *, const _Float16 *, size_t *, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vlseg7e16ff_v_m)))
void vlseg7e16ff_v_f16mf2_m(vfloat16mf2_t *, vfloat16mf2_t *, vfloat16mf2_t *, vfloat16mf2_t *, vfloat16mf2_t *, vfloat16mf2_t *, vfloat16mf2_t *, vbool32_t, vfloat16mf2_t, vfloat16mf2_t, vfloat16mf2_t, vfloat16mf2_t, vfloat16mf2_t, vfloat16mf2_t, vfloat16mf2_t, const _Float16 *, size_t *, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vlseg7e16ff_v)))
void vlseg7e16ff_v_f16mf4(vfloat16mf4_t *, vfloat16mf4_t *, vfloat16mf4_t *, vfloat16mf4_t *, vfloat16mf4_t *, vfloat16mf4_t *, vfloat16mf4_t *, const _Float16 *, size_t *, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vlseg7e16ff_v_m)))
void vlseg7e16ff_v_f16mf4_m(vfloat16mf4_t *, vfloat16mf4_t *, vfloat16mf4_t *, vfloat16mf4_t *, vfloat16mf4_t *, vfloat16mf4_t *, vfloat16mf4_t *, vbool64_t, vfloat16mf4_t, vfloat16mf4_t, vfloat16mf4_t, vfloat16mf4_t, vfloat16mf4_t, vfloat16mf4_t, vfloat16mf4_t, const _Float16 *, size_t *, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vlseg8e16ff_v)))
void vlseg8e16ff_v_f16m1(vfloat16m1_t *, vfloat16m1_t *, vfloat16m1_t *, vfloat16m1_t *, vfloat16m1_t *, vfloat16m1_t *, vfloat16m1_t *, vfloat16m1_t *, const _Float16 *, size_t *, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vlseg8e16ff_v_m)))
void vlseg8e16ff_v_f16m1_m(vfloat16m1_t *, vfloat16m1_t *, vfloat16m1_t *, vfloat16m1_t *, vfloat16m1_t *, vfloat16m1_t *, vfloat16m1_t *, vfloat16m1_t *, vbool16_t, vfloat16m1_t, vfloat16m1_t, vfloat16m1_t, vfloat16m1_t, vfloat16m1_t, vfloat16m1_t, vfloat16m1_t, vfloat16m1_t, const _Float16 *, size_t *, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vlseg8e16ff_v)))
void vlseg8e16ff_v_f16mf2(vfloat16mf2_t *, vfloat16mf2_t *, vfloat16mf2_t *, vfloat16mf2_t *, vfloat16mf2_t *, vfloat16mf2_t *, vfloat16mf2_t *, vfloat16mf2_t *, const _Float16 *, size_t *, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vlseg8e16ff_v_m)))
void vlseg8e16ff_v_f16mf2_m(vfloat16mf2_t *, vfloat16mf2_t *, vfloat16mf2_t *, vfloat16mf2_t *, vfloat16mf2_t *, vfloat16mf2_t *, vfloat16mf2_t *, vfloat16mf2_t *, vbool32_t, vfloat16mf2_t, vfloat16mf2_t, vfloat16mf2_t, vfloat16mf2_t, vfloat16mf2_t, vfloat16mf2_t, vfloat16mf2_t, vfloat16mf2_t, const _Float16 *, size_t *, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vlseg8e16ff_v)))
void vlseg8e16ff_v_f16mf4(vfloat16mf4_t *, vfloat16mf4_t *, vfloat16mf4_t *, vfloat16mf4_t *, vfloat16mf4_t *, vfloat16mf4_t *, vfloat16mf4_t *, vfloat16mf4_t *, const _Float16 *, size_t *, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vlseg8e16ff_v_m)))
void vlseg8e16ff_v_f16mf4_m(vfloat16mf4_t *, vfloat16mf4_t *, vfloat16mf4_t *, vfloat16mf4_t *, vfloat16mf4_t *, vfloat16mf4_t *, vfloat16mf4_t *, vfloat16mf4_t *, vbool64_t, vfloat16mf4_t, vfloat16mf4_t, vfloat16mf4_t, vfloat16mf4_t, vfloat16mf4_t, vfloat16mf4_t, vfloat16mf4_t, vfloat16mf4_t, const _Float16 *, size_t *, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vlsseg2e16_v)))
void vlsseg2e16_v_f16m1(vfloat16m1_t *, vfloat16m1_t *, const _Float16 *, ptrdiff_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vlsseg2e16_v_m)))
void vlsseg2e16_v_f16m1_m(vfloat16m1_t *, vfloat16m1_t *, vbool16_t, vfloat16m1_t, vfloat16m1_t, const _Float16 *, ptrdiff_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vlsseg2e16_v)))
void vlsseg2e16_v_f16m2(vfloat16m2_t *, vfloat16m2_t *, const _Float16 *, ptrdiff_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vlsseg2e16_v_m)))
void vlsseg2e16_v_f16m2_m(vfloat16m2_t *, vfloat16m2_t *, vbool8_t, vfloat16m2_t, vfloat16m2_t, const _Float16 *, ptrdiff_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vlsseg2e16_v)))
void vlsseg2e16_v_f16m4(vfloat16m4_t *, vfloat16m4_t *, const _Float16 *, ptrdiff_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vlsseg2e16_v_m)))
void vlsseg2e16_v_f16m4_m(vfloat16m4_t *, vfloat16m4_t *, vbool4_t, vfloat16m4_t, vfloat16m4_t, const _Float16 *, ptrdiff_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vlsseg2e16_v)))
void vlsseg2e16_v_f16mf2(vfloat16mf2_t *, vfloat16mf2_t *, const _Float16 *, ptrdiff_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vlsseg2e16_v_m)))
void vlsseg2e16_v_f16mf2_m(vfloat16mf2_t *, vfloat16mf2_t *, vbool32_t, vfloat16mf2_t, vfloat16mf2_t, const _Float16 *, ptrdiff_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vlsseg2e16_v)))
void vlsseg2e16_v_f16mf4(vfloat16mf4_t *, vfloat16mf4_t *, const _Float16 *, ptrdiff_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vlsseg2e16_v_m)))
void vlsseg2e16_v_f16mf4_m(vfloat16mf4_t *, vfloat16mf4_t *, vbool64_t, vfloat16mf4_t, vfloat16mf4_t, const _Float16 *, ptrdiff_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vlsseg3e16_v)))
void vlsseg3e16_v_f16m1(vfloat16m1_t *, vfloat16m1_t *, vfloat16m1_t *, const _Float16 *, ptrdiff_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vlsseg3e16_v_m)))
void vlsseg3e16_v_f16m1_m(vfloat16m1_t *, vfloat16m1_t *, vfloat16m1_t *, vbool16_t, vfloat16m1_t, vfloat16m1_t, vfloat16m1_t, const _Float16 *, ptrdiff_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vlsseg3e16_v)))
void vlsseg3e16_v_f16m2(vfloat16m2_t *, vfloat16m2_t *, vfloat16m2_t *, const _Float16 *, ptrdiff_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vlsseg3e16_v_m)))
void vlsseg3e16_v_f16m2_m(vfloat16m2_t *, vfloat16m2_t *, vfloat16m2_t *, vbool8_t, vfloat16m2_t, vfloat16m2_t, vfloat16m2_t, const _Float16 *, ptrdiff_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vlsseg3e16_v)))
void vlsseg3e16_v_f16mf2(vfloat16mf2_t *, vfloat16mf2_t *, vfloat16mf2_t *, const _Float16 *, ptrdiff_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vlsseg3e16_v_m)))
void vlsseg3e16_v_f16mf2_m(vfloat16mf2_t *, vfloat16mf2_t *, vfloat16mf2_t *, vbool32_t, vfloat16mf2_t, vfloat16mf2_t, vfloat16mf2_t, const _Float16 *, ptrdiff_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vlsseg3e16_v)))
void vlsseg3e16_v_f16mf4(vfloat16mf4_t *, vfloat16mf4_t *, vfloat16mf4_t *, const _Float16 *, ptrdiff_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vlsseg3e16_v_m)))
void vlsseg3e16_v_f16mf4_m(vfloat16mf4_t *, vfloat16mf4_t *, vfloat16mf4_t *, vbool64_t, vfloat16mf4_t, vfloat16mf4_t, vfloat16mf4_t, const _Float16 *, ptrdiff_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vlsseg4e16_v)))
void vlsseg4e16_v_f16m1(vfloat16m1_t *, vfloat16m1_t *, vfloat16m1_t *, vfloat16m1_t *, const _Float16 *, ptrdiff_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vlsseg4e16_v_m)))
void vlsseg4e16_v_f16m1_m(vfloat16m1_t *, vfloat16m1_t *, vfloat16m1_t *, vfloat16m1_t *, vbool16_t, vfloat16m1_t, vfloat16m1_t, vfloat16m1_t, vfloat16m1_t, const _Float16 *, ptrdiff_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vlsseg4e16_v)))
void vlsseg4e16_v_f16m2(vfloat16m2_t *, vfloat16m2_t *, vfloat16m2_t *, vfloat16m2_t *, const _Float16 *, ptrdiff_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vlsseg4e16_v_m)))
void vlsseg4e16_v_f16m2_m(vfloat16m2_t *, vfloat16m2_t *, vfloat16m2_t *, vfloat16m2_t *, vbool8_t, vfloat16m2_t, vfloat16m2_t, vfloat16m2_t, vfloat16m2_t, const _Float16 *, ptrdiff_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vlsseg4e16_v)))
void vlsseg4e16_v_f16mf2(vfloat16mf2_t *, vfloat16mf2_t *, vfloat16mf2_t *, vfloat16mf2_t *, const _Float16 *, ptrdiff_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vlsseg4e16_v_m)))
void vlsseg4e16_v_f16mf2_m(vfloat16mf2_t *, vfloat16mf2_t *, vfloat16mf2_t *, vfloat16mf2_t *, vbool32_t, vfloat16mf2_t, vfloat16mf2_t, vfloat16mf2_t, vfloat16mf2_t, const _Float16 *, ptrdiff_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vlsseg4e16_v)))
void vlsseg4e16_v_f16mf4(vfloat16mf4_t *, vfloat16mf4_t *, vfloat16mf4_t *, vfloat16mf4_t *, const _Float16 *, ptrdiff_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vlsseg4e16_v_m)))
void vlsseg4e16_v_f16mf4_m(vfloat16mf4_t *, vfloat16mf4_t *, vfloat16mf4_t *, vfloat16mf4_t *, vbool64_t, vfloat16mf4_t, vfloat16mf4_t, vfloat16mf4_t, vfloat16mf4_t, const _Float16 *, ptrdiff_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vlsseg5e16_v)))
void vlsseg5e16_v_f16m1(vfloat16m1_t *, vfloat16m1_t *, vfloat16m1_t *, vfloat16m1_t *, vfloat16m1_t *, const _Float16 *, ptrdiff_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vlsseg5e16_v_m)))
void vlsseg5e16_v_f16m1_m(vfloat16m1_t *, vfloat16m1_t *, vfloat16m1_t *, vfloat16m1_t *, vfloat16m1_t *, vbool16_t, vfloat16m1_t, vfloat16m1_t, vfloat16m1_t, vfloat16m1_t, vfloat16m1_t, const _Float16 *, ptrdiff_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vlsseg5e16_v)))
void vlsseg5e16_v_f16mf2(vfloat16mf2_t *, vfloat16mf2_t *, vfloat16mf2_t *, vfloat16mf2_t *, vfloat16mf2_t *, const _Float16 *, ptrdiff_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vlsseg5e16_v_m)))
void vlsseg5e16_v_f16mf2_m(vfloat16mf2_t *, vfloat16mf2_t *, vfloat16mf2_t *, vfloat16mf2_t *, vfloat16mf2_t *, vbool32_t, vfloat16mf2_t, vfloat16mf2_t, vfloat16mf2_t, vfloat16mf2_t, vfloat16mf2_t, const _Float16 *, ptrdiff_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vlsseg5e16_v)))
void vlsseg5e16_v_f16mf4(vfloat16mf4_t *, vfloat16mf4_t *, vfloat16mf4_t *, vfloat16mf4_t *, vfloat16mf4_t *, const _Float16 *, ptrdiff_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vlsseg5e16_v_m)))
void vlsseg5e16_v_f16mf4_m(vfloat16mf4_t *, vfloat16mf4_t *, vfloat16mf4_t *, vfloat16mf4_t *, vfloat16mf4_t *, vbool64_t, vfloat16mf4_t, vfloat16mf4_t, vfloat16mf4_t, vfloat16mf4_t, vfloat16mf4_t, const _Float16 *, ptrdiff_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vlsseg6e16_v)))
void vlsseg6e16_v_f16m1(vfloat16m1_t *, vfloat16m1_t *, vfloat16m1_t *, vfloat16m1_t *, vfloat16m1_t *, vfloat16m1_t *, const _Float16 *, ptrdiff_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vlsseg6e16_v_m)))
void vlsseg6e16_v_f16m1_m(vfloat16m1_t *, vfloat16m1_t *, vfloat16m1_t *, vfloat16m1_t *, vfloat16m1_t *, vfloat16m1_t *, vbool16_t, vfloat16m1_t, vfloat16m1_t, vfloat16m1_t, vfloat16m1_t, vfloat16m1_t, vfloat16m1_t, const _Float16 *, ptrdiff_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vlsseg6e16_v)))
void vlsseg6e16_v_f16mf2(vfloat16mf2_t *, vfloat16mf2_t *, vfloat16mf2_t *, vfloat16mf2_t *, vfloat16mf2_t *, vfloat16mf2_t *, const _Float16 *, ptrdiff_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vlsseg6e16_v_m)))
void vlsseg6e16_v_f16mf2_m(vfloat16mf2_t *, vfloat16mf2_t *, vfloat16mf2_t *, vfloat16mf2_t *, vfloat16mf2_t *, vfloat16mf2_t *, vbool32_t, vfloat16mf2_t, vfloat16mf2_t, vfloat16mf2_t, vfloat16mf2_t, vfloat16mf2_t, vfloat16mf2_t, const _Float16 *, ptrdiff_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vlsseg6e16_v)))
void vlsseg6e16_v_f16mf4(vfloat16mf4_t *, vfloat16mf4_t *, vfloat16mf4_t *, vfloat16mf4_t *, vfloat16mf4_t *, vfloat16mf4_t *, const _Float16 *, ptrdiff_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vlsseg6e16_v_m)))
void vlsseg6e16_v_f16mf4_m(vfloat16mf4_t *, vfloat16mf4_t *, vfloat16mf4_t *, vfloat16mf4_t *, vfloat16mf4_t *, vfloat16mf4_t *, vbool64_t, vfloat16mf4_t, vfloat16mf4_t, vfloat16mf4_t, vfloat16mf4_t, vfloat16mf4_t, vfloat16mf4_t, const _Float16 *, ptrdiff_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vlsseg7e16_v)))
void vlsseg7e16_v_f16m1(vfloat16m1_t *, vfloat16m1_t *, vfloat16m1_t *, vfloat16m1_t *, vfloat16m1_t *, vfloat16m1_t *, vfloat16m1_t *, const _Float16 *, ptrdiff_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vlsseg7e16_v_m)))
void vlsseg7e16_v_f16m1_m(vfloat16m1_t *, vfloat16m1_t *, vfloat16m1_t *, vfloat16m1_t *, vfloat16m1_t *, vfloat16m1_t *, vfloat16m1_t *, vbool16_t, vfloat16m1_t, vfloat16m1_t, vfloat16m1_t, vfloat16m1_t, vfloat16m1_t, vfloat16m1_t, vfloat16m1_t, const _Float16 *, ptrdiff_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vlsseg7e16_v)))
void vlsseg7e16_v_f16mf2(vfloat16mf2_t *, vfloat16mf2_t *, vfloat16mf2_t *, vfloat16mf2_t *, vfloat16mf2_t *, vfloat16mf2_t *, vfloat16mf2_t *, const _Float16 *, ptrdiff_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vlsseg7e16_v_m)))
void vlsseg7e16_v_f16mf2_m(vfloat16mf2_t *, vfloat16mf2_t *, vfloat16mf2_t *, vfloat16mf2_t *, vfloat16mf2_t *, vfloat16mf2_t *, vfloat16mf2_t *, vbool32_t, vfloat16mf2_t, vfloat16mf2_t, vfloat16mf2_t, vfloat16mf2_t, vfloat16mf2_t, vfloat16mf2_t, vfloat16mf2_t, const _Float16 *, ptrdiff_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vlsseg7e16_v)))
void vlsseg7e16_v_f16mf4(vfloat16mf4_t *, vfloat16mf4_t *, vfloat16mf4_t *, vfloat16mf4_t *, vfloat16mf4_t *, vfloat16mf4_t *, vfloat16mf4_t *, const _Float16 *, ptrdiff_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vlsseg7e16_v_m)))
void vlsseg7e16_v_f16mf4_m(vfloat16mf4_t *, vfloat16mf4_t *, vfloat16mf4_t *, vfloat16mf4_t *, vfloat16mf4_t *, vfloat16mf4_t *, vfloat16mf4_t *, vbool64_t, vfloat16mf4_t, vfloat16mf4_t, vfloat16mf4_t, vfloat16mf4_t, vfloat16mf4_t, vfloat16mf4_t, vfloat16mf4_t, const _Float16 *, ptrdiff_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vlsseg8e16_v)))
void vlsseg8e16_v_f16m1(vfloat16m1_t *, vfloat16m1_t *, vfloat16m1_t *, vfloat16m1_t *, vfloat16m1_t *, vfloat16m1_t *, vfloat16m1_t *, vfloat16m1_t *, const _Float16 *, ptrdiff_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vlsseg8e16_v_m)))
void vlsseg8e16_v_f16m1_m(vfloat16m1_t *, vfloat16m1_t *, vfloat16m1_t *, vfloat16m1_t *, vfloat16m1_t *, vfloat16m1_t *, vfloat16m1_t *, vfloat16m1_t *, vbool16_t, vfloat16m1_t, vfloat16m1_t, vfloat16m1_t, vfloat16m1_t, vfloat16m1_t, vfloat16m1_t, vfloat16m1_t, vfloat16m1_t, const _Float16 *, ptrdiff_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vlsseg8e16_v)))
void vlsseg8e16_v_f16mf2(vfloat16mf2_t *, vfloat16mf2_t *, vfloat16mf2_t *, vfloat16mf2_t *, vfloat16mf2_t *, vfloat16mf2_t *, vfloat16mf2_t *, vfloat16mf2_t *, const _Float16 *, ptrdiff_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vlsseg8e16_v_m)))
void vlsseg8e16_v_f16mf2_m(vfloat16mf2_t *, vfloat16mf2_t *, vfloat16mf2_t *, vfloat16mf2_t *, vfloat16mf2_t *, vfloat16mf2_t *, vfloat16mf2_t *, vfloat16mf2_t *, vbool32_t, vfloat16mf2_t, vfloat16mf2_t, vfloat16mf2_t, vfloat16mf2_t, vfloat16mf2_t, vfloat16mf2_t, vfloat16mf2_t, vfloat16mf2_t, const _Float16 *, ptrdiff_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vlsseg8e16_v)))
void vlsseg8e16_v_f16mf4(vfloat16mf4_t *, vfloat16mf4_t *, vfloat16mf4_t *, vfloat16mf4_t *, vfloat16mf4_t *, vfloat16mf4_t *, vfloat16mf4_t *, vfloat16mf4_t *, const _Float16 *, ptrdiff_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vlsseg8e16_v_m)))
void vlsseg8e16_v_f16mf4_m(vfloat16mf4_t *, vfloat16mf4_t *, vfloat16mf4_t *, vfloat16mf4_t *, vfloat16mf4_t *, vfloat16mf4_t *, vfloat16mf4_t *, vfloat16mf4_t *, vbool64_t, vfloat16mf4_t, vfloat16mf4_t, vfloat16mf4_t, vfloat16mf4_t, vfloat16mf4_t, vfloat16mf4_t, vfloat16mf4_t, vfloat16mf4_t, const _Float16 *, ptrdiff_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vfneg_v)))
vfloat16m1_t vfneg_v_f16m1(vfloat16m1_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vfneg_v_m)))
vfloat16m1_t vfneg_v_f16m1_m(vbool16_t, vfloat16m1_t, vfloat16m1_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vfneg_v)))
vfloat16m2_t vfneg_v_f16m2(vfloat16m2_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vfneg_v_m)))
vfloat16m2_t vfneg_v_f16m2_m(vbool8_t, vfloat16m2_t, vfloat16m2_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vfneg_v)))
vfloat16m4_t vfneg_v_f16m4(vfloat16m4_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vfneg_v_m)))
vfloat16m4_t vfneg_v_f16m4_m(vbool4_t, vfloat16m4_t, vfloat16m4_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vfneg_v)))
vfloat16m8_t vfneg_v_f16m8(vfloat16m8_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vfneg_v_m)))
vfloat16m8_t vfneg_v_f16m8_m(vbool2_t, vfloat16m8_t, vfloat16m8_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vfneg_v)))
vfloat16mf2_t vfneg_v_f16mf2(vfloat16mf2_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vfneg_v_m)))
vfloat16mf2_t vfneg_v_f16mf2_m(vbool32_t, vfloat16mf2_t, vfloat16mf2_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vfneg_v)))
vfloat16mf4_t vfneg_v_f16mf4(vfloat16mf4_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vfneg_v_m)))
vfloat16mf4_t vfneg_v_f16mf4_m(vbool64_t, vfloat16mf4_t, vfloat16mf4_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vluxseg2ei8_v)))
void vluxseg2ei8_v_f16m1(vfloat16m1_t *, vfloat16m1_t *, const _Float16 *, vuint8mf2_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vluxseg2ei8_v_m)))
void vluxseg2ei8_v_f16m1_m(vfloat16m1_t *, vfloat16m1_t *, vbool16_t, vfloat16m1_t, vfloat16m1_t, const _Float16 *, vuint8mf2_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vluxseg2ei8_v)))
void vluxseg2ei8_v_f16m2(vfloat16m2_t *, vfloat16m2_t *, const _Float16 *, vuint8m1_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vluxseg2ei8_v_m)))
void vluxseg2ei8_v_f16m2_m(vfloat16m2_t *, vfloat16m2_t *, vbool8_t, vfloat16m2_t, vfloat16m2_t, const _Float16 *, vuint8m1_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vluxseg2ei8_v)))
void vluxseg2ei8_v_f16m4(vfloat16m4_t *, vfloat16m4_t *, const _Float16 *, vuint8m2_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vluxseg2ei8_v_m)))
void vluxseg2ei8_v_f16m4_m(vfloat16m4_t *, vfloat16m4_t *, vbool4_t, vfloat16m4_t, vfloat16m4_t, const _Float16 *, vuint8m2_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vluxseg2ei8_v)))
void vluxseg2ei8_v_f16mf2(vfloat16mf2_t *, vfloat16mf2_t *, const _Float16 *, vuint8mf4_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vluxseg2ei8_v_m)))
void vluxseg2ei8_v_f16mf2_m(vfloat16mf2_t *, vfloat16mf2_t *, vbool32_t, vfloat16mf2_t, vfloat16mf2_t, const _Float16 *, vuint8mf4_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vluxseg2ei8_v)))
void vluxseg2ei8_v_f16mf4(vfloat16mf4_t *, vfloat16mf4_t *, const _Float16 *, vuint8mf8_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vluxseg2ei8_v_m)))
void vluxseg2ei8_v_f16mf4_m(vfloat16mf4_t *, vfloat16mf4_t *, vbool64_t, vfloat16mf4_t, vfloat16mf4_t, const _Float16 *, vuint8mf8_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vluxseg3ei8_v)))
void vluxseg3ei8_v_f16m1(vfloat16m1_t *, vfloat16m1_t *, vfloat16m1_t *, const _Float16 *, vuint8mf2_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vluxseg3ei8_v_m)))
void vluxseg3ei8_v_f16m1_m(vfloat16m1_t *, vfloat16m1_t *, vfloat16m1_t *, vbool16_t, vfloat16m1_t, vfloat16m1_t, vfloat16m1_t, const _Float16 *, vuint8mf2_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vluxseg3ei8_v)))
void vluxseg3ei8_v_f16m2(vfloat16m2_t *, vfloat16m2_t *, vfloat16m2_t *, const _Float16 *, vuint8m1_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vluxseg3ei8_v_m)))
void vluxseg3ei8_v_f16m2_m(vfloat16m2_t *, vfloat16m2_t *, vfloat16m2_t *, vbool8_t, vfloat16m2_t, vfloat16m2_t, vfloat16m2_t, const _Float16 *, vuint8m1_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vluxseg3ei8_v)))
void vluxseg3ei8_v_f16mf2(vfloat16mf2_t *, vfloat16mf2_t *, vfloat16mf2_t *, const _Float16 *, vuint8mf4_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vluxseg3ei8_v_m)))
void vluxseg3ei8_v_f16mf2_m(vfloat16mf2_t *, vfloat16mf2_t *, vfloat16mf2_t *, vbool32_t, vfloat16mf2_t, vfloat16mf2_t, vfloat16mf2_t, const _Float16 *, vuint8mf4_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vluxseg3ei8_v)))
void vluxseg3ei8_v_f16mf4(vfloat16mf4_t *, vfloat16mf4_t *, vfloat16mf4_t *, const _Float16 *, vuint8mf8_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vluxseg3ei8_v_m)))
void vluxseg3ei8_v_f16mf4_m(vfloat16mf4_t *, vfloat16mf4_t *, vfloat16mf4_t *, vbool64_t, vfloat16mf4_t, vfloat16mf4_t, vfloat16mf4_t, const _Float16 *, vuint8mf8_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vluxseg4ei8_v)))
void vluxseg4ei8_v_f16m1(vfloat16m1_t *, vfloat16m1_t *, vfloat16m1_t *, vfloat16m1_t *, const _Float16 *, vuint8mf2_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vluxseg4ei8_v_m)))
void vluxseg4ei8_v_f16m1_m(vfloat16m1_t *, vfloat16m1_t *, vfloat16m1_t *, vfloat16m1_t *, vbool16_t, vfloat16m1_t, vfloat16m1_t, vfloat16m1_t, vfloat16m1_t, const _Float16 *, vuint8mf2_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vluxseg4ei8_v)))
void vluxseg4ei8_v_f16m2(vfloat16m2_t *, vfloat16m2_t *, vfloat16m2_t *, vfloat16m2_t *, const _Float16 *, vuint8m1_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vluxseg4ei8_v_m)))
void vluxseg4ei8_v_f16m2_m(vfloat16m2_t *, vfloat16m2_t *, vfloat16m2_t *, vfloat16m2_t *, vbool8_t, vfloat16m2_t, vfloat16m2_t, vfloat16m2_t, vfloat16m2_t, const _Float16 *, vuint8m1_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vluxseg4ei8_v)))
void vluxseg4ei8_v_f16mf2(vfloat16mf2_t *, vfloat16mf2_t *, vfloat16mf2_t *, vfloat16mf2_t *, const _Float16 *, vuint8mf4_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vluxseg4ei8_v_m)))
void vluxseg4ei8_v_f16mf2_m(vfloat16mf2_t *, vfloat16mf2_t *, vfloat16mf2_t *, vfloat16mf2_t *, vbool32_t, vfloat16mf2_t, vfloat16mf2_t, vfloat16mf2_t, vfloat16mf2_t, const _Float16 *, vuint8mf4_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vluxseg4ei8_v)))
void vluxseg4ei8_v_f16mf4(vfloat16mf4_t *, vfloat16mf4_t *, vfloat16mf4_t *, vfloat16mf4_t *, const _Float16 *, vuint8mf8_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vluxseg4ei8_v_m)))
void vluxseg4ei8_v_f16mf4_m(vfloat16mf4_t *, vfloat16mf4_t *, vfloat16mf4_t *, vfloat16mf4_t *, vbool64_t, vfloat16mf4_t, vfloat16mf4_t, vfloat16mf4_t, vfloat16mf4_t, const _Float16 *, vuint8mf8_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vluxseg5ei8_v)))
void vluxseg5ei8_v_f16m1(vfloat16m1_t *, vfloat16m1_t *, vfloat16m1_t *, vfloat16m1_t *, vfloat16m1_t *, const _Float16 *, vuint8mf2_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vluxseg5ei8_v_m)))
void vluxseg5ei8_v_f16m1_m(vfloat16m1_t *, vfloat16m1_t *, vfloat16m1_t *, vfloat16m1_t *, vfloat16m1_t *, vbool16_t, vfloat16m1_t, vfloat16m1_t, vfloat16m1_t, vfloat16m1_t, vfloat16m1_t, const _Float16 *, vuint8mf2_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vluxseg5ei8_v)))
void vluxseg5ei8_v_f16mf2(vfloat16mf2_t *, vfloat16mf2_t *, vfloat16mf2_t *, vfloat16mf2_t *, vfloat16mf2_t *, const _Float16 *, vuint8mf4_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vluxseg5ei8_v_m)))
void vluxseg5ei8_v_f16mf2_m(vfloat16mf2_t *, vfloat16mf2_t *, vfloat16mf2_t *, vfloat16mf2_t *, vfloat16mf2_t *, vbool32_t, vfloat16mf2_t, vfloat16mf2_t, vfloat16mf2_t, vfloat16mf2_t, vfloat16mf2_t, const _Float16 *, vuint8mf4_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vluxseg5ei8_v)))
void vluxseg5ei8_v_f16mf4(vfloat16mf4_t *, vfloat16mf4_t *, vfloat16mf4_t *, vfloat16mf4_t *, vfloat16mf4_t *, const _Float16 *, vuint8mf8_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vluxseg5ei8_v_m)))
void vluxseg5ei8_v_f16mf4_m(vfloat16mf4_t *, vfloat16mf4_t *, vfloat16mf4_t *, vfloat16mf4_t *, vfloat16mf4_t *, vbool64_t, vfloat16mf4_t, vfloat16mf4_t, vfloat16mf4_t, vfloat16mf4_t, vfloat16mf4_t, const _Float16 *, vuint8mf8_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vluxseg6ei8_v)))
void vluxseg6ei8_v_f16m1(vfloat16m1_t *, vfloat16m1_t *, vfloat16m1_t *, vfloat16m1_t *, vfloat16m1_t *, vfloat16m1_t *, const _Float16 *, vuint8mf2_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vluxseg6ei8_v_m)))
void vluxseg6ei8_v_f16m1_m(vfloat16m1_t *, vfloat16m1_t *, vfloat16m1_t *, vfloat16m1_t *, vfloat16m1_t *, vfloat16m1_t *, vbool16_t, vfloat16m1_t, vfloat16m1_t, vfloat16m1_t, vfloat16m1_t, vfloat16m1_t, vfloat16m1_t, const _Float16 *, vuint8mf2_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vluxseg6ei8_v)))
void vluxseg6ei8_v_f16mf2(vfloat16mf2_t *, vfloat16mf2_t *, vfloat16mf2_t *, vfloat16mf2_t *, vfloat16mf2_t *, vfloat16mf2_t *, const _Float16 *, vuint8mf4_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vluxseg6ei8_v_m)))
void vluxseg6ei8_v_f16mf2_m(vfloat16mf2_t *, vfloat16mf2_t *, vfloat16mf2_t *, vfloat16mf2_t *, vfloat16mf2_t *, vfloat16mf2_t *, vbool32_t, vfloat16mf2_t, vfloat16mf2_t, vfloat16mf2_t, vfloat16mf2_t, vfloat16mf2_t, vfloat16mf2_t, const _Float16 *, vuint8mf4_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vluxseg6ei8_v)))
void vluxseg6ei8_v_f16mf4(vfloat16mf4_t *, vfloat16mf4_t *, vfloat16mf4_t *, vfloat16mf4_t *, vfloat16mf4_t *, vfloat16mf4_t *, const _Float16 *, vuint8mf8_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vluxseg6ei8_v_m)))
void vluxseg6ei8_v_f16mf4_m(vfloat16mf4_t *, vfloat16mf4_t *, vfloat16mf4_t *, vfloat16mf4_t *, vfloat16mf4_t *, vfloat16mf4_t *, vbool64_t, vfloat16mf4_t, vfloat16mf4_t, vfloat16mf4_t, vfloat16mf4_t, vfloat16mf4_t, vfloat16mf4_t, const _Float16 *, vuint8mf8_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vluxseg7ei8_v)))
void vluxseg7ei8_v_f16m1(vfloat16m1_t *, vfloat16m1_t *, vfloat16m1_t *, vfloat16m1_t *, vfloat16m1_t *, vfloat16m1_t *, vfloat16m1_t *, const _Float16 *, vuint8mf2_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vluxseg7ei8_v_m)))
void vluxseg7ei8_v_f16m1_m(vfloat16m1_t *, vfloat16m1_t *, vfloat16m1_t *, vfloat16m1_t *, vfloat16m1_t *, vfloat16m1_t *, vfloat16m1_t *, vbool16_t, vfloat16m1_t, vfloat16m1_t, vfloat16m1_t, vfloat16m1_t, vfloat16m1_t, vfloat16m1_t, vfloat16m1_t, const _Float16 *, vuint8mf2_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vluxseg7ei8_v)))
void vluxseg7ei8_v_f16mf2(vfloat16mf2_t *, vfloat16mf2_t *, vfloat16mf2_t *, vfloat16mf2_t *, vfloat16mf2_t *, vfloat16mf2_t *, vfloat16mf2_t *, const _Float16 *, vuint8mf4_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vluxseg7ei8_v_m)))
void vluxseg7ei8_v_f16mf2_m(vfloat16mf2_t *, vfloat16mf2_t *, vfloat16mf2_t *, vfloat16mf2_t *, vfloat16mf2_t *, vfloat16mf2_t *, vfloat16mf2_t *, vbool32_t, vfloat16mf2_t, vfloat16mf2_t, vfloat16mf2_t, vfloat16mf2_t, vfloat16mf2_t, vfloat16mf2_t, vfloat16mf2_t, const _Float16 *, vuint8mf4_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vluxseg7ei8_v)))
void vluxseg7ei8_v_f16mf4(vfloat16mf4_t *, vfloat16mf4_t *, vfloat16mf4_t *, vfloat16mf4_t *, vfloat16mf4_t *, vfloat16mf4_t *, vfloat16mf4_t *, const _Float16 *, vuint8mf8_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vluxseg7ei8_v_m)))
void vluxseg7ei8_v_f16mf4_m(vfloat16mf4_t *, vfloat16mf4_t *, vfloat16mf4_t *, vfloat16mf4_t *, vfloat16mf4_t *, vfloat16mf4_t *, vfloat16mf4_t *, vbool64_t, vfloat16mf4_t, vfloat16mf4_t, vfloat16mf4_t, vfloat16mf4_t, vfloat16mf4_t, vfloat16mf4_t, vfloat16mf4_t, const _Float16 *, vuint8mf8_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vluxseg8ei8_v)))
void vluxseg8ei8_v_f16m1(vfloat16m1_t *, vfloat16m1_t *, vfloat16m1_t *, vfloat16m1_t *, vfloat16m1_t *, vfloat16m1_t *, vfloat16m1_t *, vfloat16m1_t *, const _Float16 *, vuint8mf2_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vluxseg8ei8_v_m)))
void vluxseg8ei8_v_f16m1_m(vfloat16m1_t *, vfloat16m1_t *, vfloat16m1_t *, vfloat16m1_t *, vfloat16m1_t *, vfloat16m1_t *, vfloat16m1_t *, vfloat16m1_t *, vbool16_t, vfloat16m1_t, vfloat16m1_t, vfloat16m1_t, vfloat16m1_t, vfloat16m1_t, vfloat16m1_t, vfloat16m1_t, vfloat16m1_t, const _Float16 *, vuint8mf2_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vluxseg8ei8_v)))
void vluxseg8ei8_v_f16mf2(vfloat16mf2_t *, vfloat16mf2_t *, vfloat16mf2_t *, vfloat16mf2_t *, vfloat16mf2_t *, vfloat16mf2_t *, vfloat16mf2_t *, vfloat16mf2_t *, const _Float16 *, vuint8mf4_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vluxseg8ei8_v_m)))
void vluxseg8ei8_v_f16mf2_m(vfloat16mf2_t *, vfloat16mf2_t *, vfloat16mf2_t *, vfloat16mf2_t *, vfloat16mf2_t *, vfloat16mf2_t *, vfloat16mf2_t *, vfloat16mf2_t *, vbool32_t, vfloat16mf2_t, vfloat16mf2_t, vfloat16mf2_t, vfloat16mf2_t, vfloat16mf2_t, vfloat16mf2_t, vfloat16mf2_t, vfloat16mf2_t, const _Float16 *, vuint8mf4_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vluxseg8ei8_v)))
void vluxseg8ei8_v_f16mf4(vfloat16mf4_t *, vfloat16mf4_t *, vfloat16mf4_t *, vfloat16mf4_t *, vfloat16mf4_t *, vfloat16mf4_t *, vfloat16mf4_t *, vfloat16mf4_t *, const _Float16 *, vuint8mf8_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vluxseg8ei8_v_m)))
void vluxseg8ei8_v_f16mf4_m(vfloat16mf4_t *, vfloat16mf4_t *, vfloat16mf4_t *, vfloat16mf4_t *, vfloat16mf4_t *, vfloat16mf4_t *, vfloat16mf4_t *, vfloat16mf4_t *, vbool64_t, vfloat16mf4_t, vfloat16mf4_t, vfloat16mf4_t, vfloat16mf4_t, vfloat16mf4_t, vfloat16mf4_t, vfloat16mf4_t, vfloat16mf4_t, const _Float16 *, vuint8mf8_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vluxseg2ei16_v)))
void vluxseg2ei16_v_f16m1(vfloat16m1_t *, vfloat16m1_t *, const _Float16 *, vuint16m1_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vluxseg2ei16_v_m)))
void vluxseg2ei16_v_f16m1_m(vfloat16m1_t *, vfloat16m1_t *, vbool16_t, vfloat16m1_t, vfloat16m1_t, const _Float16 *, vuint16m1_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vluxseg2ei16_v)))
void vluxseg2ei16_v_f16m2(vfloat16m2_t *, vfloat16m2_t *, const _Float16 *, vuint16m2_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vluxseg2ei16_v_m)))
void vluxseg2ei16_v_f16m2_m(vfloat16m2_t *, vfloat16m2_t *, vbool8_t, vfloat16m2_t, vfloat16m2_t, const _Float16 *, vuint16m2_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vluxseg2ei16_v)))
void vluxseg2ei16_v_f16m4(vfloat16m4_t *, vfloat16m4_t *, const _Float16 *, vuint16m4_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vluxseg2ei16_v_m)))
void vluxseg2ei16_v_f16m4_m(vfloat16m4_t *, vfloat16m4_t *, vbool4_t, vfloat16m4_t, vfloat16m4_t, const _Float16 *, vuint16m4_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vluxseg2ei16_v)))
void vluxseg2ei16_v_f16mf2(vfloat16mf2_t *, vfloat16mf2_t *, const _Float16 *, vuint16mf2_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vluxseg2ei16_v_m)))
void vluxseg2ei16_v_f16mf2_m(vfloat16mf2_t *, vfloat16mf2_t *, vbool32_t, vfloat16mf2_t, vfloat16mf2_t, const _Float16 *, vuint16mf2_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vluxseg2ei16_v)))
void vluxseg2ei16_v_f16mf4(vfloat16mf4_t *, vfloat16mf4_t *, const _Float16 *, vuint16mf4_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vluxseg2ei16_v_m)))
void vluxseg2ei16_v_f16mf4_m(vfloat16mf4_t *, vfloat16mf4_t *, vbool64_t, vfloat16mf4_t, vfloat16mf4_t, const _Float16 *, vuint16mf4_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vluxseg3ei16_v)))
void vluxseg3ei16_v_f16m1(vfloat16m1_t *, vfloat16m1_t *, vfloat16m1_t *, const _Float16 *, vuint16m1_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vluxseg3ei16_v_m)))
void vluxseg3ei16_v_f16m1_m(vfloat16m1_t *, vfloat16m1_t *, vfloat16m1_t *, vbool16_t, vfloat16m1_t, vfloat16m1_t, vfloat16m1_t, const _Float16 *, vuint16m1_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vluxseg3ei16_v)))
void vluxseg3ei16_v_f16m2(vfloat16m2_t *, vfloat16m2_t *, vfloat16m2_t *, const _Float16 *, vuint16m2_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vluxseg3ei16_v_m)))
void vluxseg3ei16_v_f16m2_m(vfloat16m2_t *, vfloat16m2_t *, vfloat16m2_t *, vbool8_t, vfloat16m2_t, vfloat16m2_t, vfloat16m2_t, const _Float16 *, vuint16m2_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vluxseg3ei16_v)))
void vluxseg3ei16_v_f16mf2(vfloat16mf2_t *, vfloat16mf2_t *, vfloat16mf2_t *, const _Float16 *, vuint16mf2_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vluxseg3ei16_v_m)))
void vluxseg3ei16_v_f16mf2_m(vfloat16mf2_t *, vfloat16mf2_t *, vfloat16mf2_t *, vbool32_t, vfloat16mf2_t, vfloat16mf2_t, vfloat16mf2_t, const _Float16 *, vuint16mf2_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vluxseg3ei16_v)))
void vluxseg3ei16_v_f16mf4(vfloat16mf4_t *, vfloat16mf4_t *, vfloat16mf4_t *, const _Float16 *, vuint16mf4_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vluxseg3ei16_v_m)))
void vluxseg3ei16_v_f16mf4_m(vfloat16mf4_t *, vfloat16mf4_t *, vfloat16mf4_t *, vbool64_t, vfloat16mf4_t, vfloat16mf4_t, vfloat16mf4_t, const _Float16 *, vuint16mf4_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vluxseg4ei16_v)))
void vluxseg4ei16_v_f16m1(vfloat16m1_t *, vfloat16m1_t *, vfloat16m1_t *, vfloat16m1_t *, const _Float16 *, vuint16m1_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vluxseg4ei16_v_m)))
void vluxseg4ei16_v_f16m1_m(vfloat16m1_t *, vfloat16m1_t *, vfloat16m1_t *, vfloat16m1_t *, vbool16_t, vfloat16m1_t, vfloat16m1_t, vfloat16m1_t, vfloat16m1_t, const _Float16 *, vuint16m1_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vluxseg4ei16_v)))
void vluxseg4ei16_v_f16m2(vfloat16m2_t *, vfloat16m2_t *, vfloat16m2_t *, vfloat16m2_t *, const _Float16 *, vuint16m2_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vluxseg4ei16_v_m)))
void vluxseg4ei16_v_f16m2_m(vfloat16m2_t *, vfloat16m2_t *, vfloat16m2_t *, vfloat16m2_t *, vbool8_t, vfloat16m2_t, vfloat16m2_t, vfloat16m2_t, vfloat16m2_t, const _Float16 *, vuint16m2_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vluxseg4ei16_v)))
void vluxseg4ei16_v_f16mf2(vfloat16mf2_t *, vfloat16mf2_t *, vfloat16mf2_t *, vfloat16mf2_t *, const _Float16 *, vuint16mf2_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vluxseg4ei16_v_m)))
void vluxseg4ei16_v_f16mf2_m(vfloat16mf2_t *, vfloat16mf2_t *, vfloat16mf2_t *, vfloat16mf2_t *, vbool32_t, vfloat16mf2_t, vfloat16mf2_t, vfloat16mf2_t, vfloat16mf2_t, const _Float16 *, vuint16mf2_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vluxseg4ei16_v)))
void vluxseg4ei16_v_f16mf4(vfloat16mf4_t *, vfloat16mf4_t *, vfloat16mf4_t *, vfloat16mf4_t *, const _Float16 *, vuint16mf4_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vluxseg4ei16_v_m)))
void vluxseg4ei16_v_f16mf4_m(vfloat16mf4_t *, vfloat16mf4_t *, vfloat16mf4_t *, vfloat16mf4_t *, vbool64_t, vfloat16mf4_t, vfloat16mf4_t, vfloat16mf4_t, vfloat16mf4_t, const _Float16 *, vuint16mf4_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vluxseg5ei16_v)))
void vluxseg5ei16_v_f16m1(vfloat16m1_t *, vfloat16m1_t *, vfloat16m1_t *, vfloat16m1_t *, vfloat16m1_t *, const _Float16 *, vuint16m1_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vluxseg5ei16_v_m)))
void vluxseg5ei16_v_f16m1_m(vfloat16m1_t *, vfloat16m1_t *, vfloat16m1_t *, vfloat16m1_t *, vfloat16m1_t *, vbool16_t, vfloat16m1_t, vfloat16m1_t, vfloat16m1_t, vfloat16m1_t, vfloat16m1_t, const _Float16 *, vuint16m1_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vluxseg5ei16_v)))
void vluxseg5ei16_v_f16mf2(vfloat16mf2_t *, vfloat16mf2_t *, vfloat16mf2_t *, vfloat16mf2_t *, vfloat16mf2_t *, const _Float16 *, vuint16mf2_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vluxseg5ei16_v_m)))
void vluxseg5ei16_v_f16mf2_m(vfloat16mf2_t *, vfloat16mf2_t *, vfloat16mf2_t *, vfloat16mf2_t *, vfloat16mf2_t *, vbool32_t, vfloat16mf2_t, vfloat16mf2_t, vfloat16mf2_t, vfloat16mf2_t, vfloat16mf2_t, const _Float16 *, vuint16mf2_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vluxseg5ei16_v)))
void vluxseg5ei16_v_f16mf4(vfloat16mf4_t *, vfloat16mf4_t *, vfloat16mf4_t *, vfloat16mf4_t *, vfloat16mf4_t *, const _Float16 *, vuint16mf4_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vluxseg5ei16_v_m)))
void vluxseg5ei16_v_f16mf4_m(vfloat16mf4_t *, vfloat16mf4_t *, vfloat16mf4_t *, vfloat16mf4_t *, vfloat16mf4_t *, vbool64_t, vfloat16mf4_t, vfloat16mf4_t, vfloat16mf4_t, vfloat16mf4_t, vfloat16mf4_t, const _Float16 *, vuint16mf4_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vluxseg6ei16_v)))
void vluxseg6ei16_v_f16m1(vfloat16m1_t *, vfloat16m1_t *, vfloat16m1_t *, vfloat16m1_t *, vfloat16m1_t *, vfloat16m1_t *, const _Float16 *, vuint16m1_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vluxseg6ei16_v_m)))
void vluxseg6ei16_v_f16m1_m(vfloat16m1_t *, vfloat16m1_t *, vfloat16m1_t *, vfloat16m1_t *, vfloat16m1_t *, vfloat16m1_t *, vbool16_t, vfloat16m1_t, vfloat16m1_t, vfloat16m1_t, vfloat16m1_t, vfloat16m1_t, vfloat16m1_t, const _Float16 *, vuint16m1_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vluxseg6ei16_v)))
void vluxseg6ei16_v_f16mf2(vfloat16mf2_t *, vfloat16mf2_t *, vfloat16mf2_t *, vfloat16mf2_t *, vfloat16mf2_t *, vfloat16mf2_t *, const _Float16 *, vuint16mf2_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vluxseg6ei16_v_m)))
void vluxseg6ei16_v_f16mf2_m(vfloat16mf2_t *, vfloat16mf2_t *, vfloat16mf2_t *, vfloat16mf2_t *, vfloat16mf2_t *, vfloat16mf2_t *, vbool32_t, vfloat16mf2_t, vfloat16mf2_t, vfloat16mf2_t, vfloat16mf2_t, vfloat16mf2_t, vfloat16mf2_t, const _Float16 *, vuint16mf2_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vluxseg6ei16_v)))
void vluxseg6ei16_v_f16mf4(vfloat16mf4_t *, vfloat16mf4_t *, vfloat16mf4_t *, vfloat16mf4_t *, vfloat16mf4_t *, vfloat16mf4_t *, const _Float16 *, vuint16mf4_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vluxseg6ei16_v_m)))
void vluxseg6ei16_v_f16mf4_m(vfloat16mf4_t *, vfloat16mf4_t *, vfloat16mf4_t *, vfloat16mf4_t *, vfloat16mf4_t *, vfloat16mf4_t *, vbool64_t, vfloat16mf4_t, vfloat16mf4_t, vfloat16mf4_t, vfloat16mf4_t, vfloat16mf4_t, vfloat16mf4_t, const _Float16 *, vuint16mf4_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vluxseg7ei16_v)))
void vluxseg7ei16_v_f16m1(vfloat16m1_t *, vfloat16m1_t *, vfloat16m1_t *, vfloat16m1_t *, vfloat16m1_t *, vfloat16m1_t *, vfloat16m1_t *, const _Float16 *, vuint16m1_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vluxseg7ei16_v_m)))
void vluxseg7ei16_v_f16m1_m(vfloat16m1_t *, vfloat16m1_t *, vfloat16m1_t *, vfloat16m1_t *, vfloat16m1_t *, vfloat16m1_t *, vfloat16m1_t *, vbool16_t, vfloat16m1_t, vfloat16m1_t, vfloat16m1_t, vfloat16m1_t, vfloat16m1_t, vfloat16m1_t, vfloat16m1_t, const _Float16 *, vuint16m1_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vluxseg7ei16_v)))
void vluxseg7ei16_v_f16mf2(vfloat16mf2_t *, vfloat16mf2_t *, vfloat16mf2_t *, vfloat16mf2_t *, vfloat16mf2_t *, vfloat16mf2_t *, vfloat16mf2_t *, const _Float16 *, vuint16mf2_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vluxseg7ei16_v_m)))
void vluxseg7ei16_v_f16mf2_m(vfloat16mf2_t *, vfloat16mf2_t *, vfloat16mf2_t *, vfloat16mf2_t *, vfloat16mf2_t *, vfloat16mf2_t *, vfloat16mf2_t *, vbool32_t, vfloat16mf2_t, vfloat16mf2_t, vfloat16mf2_t, vfloat16mf2_t, vfloat16mf2_t, vfloat16mf2_t, vfloat16mf2_t, const _Float16 *, vuint16mf2_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vluxseg7ei16_v)))
void vluxseg7ei16_v_f16mf4(vfloat16mf4_t *, vfloat16mf4_t *, vfloat16mf4_t *, vfloat16mf4_t *, vfloat16mf4_t *, vfloat16mf4_t *, vfloat16mf4_t *, const _Float16 *, vuint16mf4_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vluxseg7ei16_v_m)))
void vluxseg7ei16_v_f16mf4_m(vfloat16mf4_t *, vfloat16mf4_t *, vfloat16mf4_t *, vfloat16mf4_t *, vfloat16mf4_t *, vfloat16mf4_t *, vfloat16mf4_t *, vbool64_t, vfloat16mf4_t, vfloat16mf4_t, vfloat16mf4_t, vfloat16mf4_t, vfloat16mf4_t, vfloat16mf4_t, vfloat16mf4_t, const _Float16 *, vuint16mf4_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vluxseg8ei16_v)))
void vluxseg8ei16_v_f16m1(vfloat16m1_t *, vfloat16m1_t *, vfloat16m1_t *, vfloat16m1_t *, vfloat16m1_t *, vfloat16m1_t *, vfloat16m1_t *, vfloat16m1_t *, const _Float16 *, vuint16m1_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vluxseg8ei16_v_m)))
void vluxseg8ei16_v_f16m1_m(vfloat16m1_t *, vfloat16m1_t *, vfloat16m1_t *, vfloat16m1_t *, vfloat16m1_t *, vfloat16m1_t *, vfloat16m1_t *, vfloat16m1_t *, vbool16_t, vfloat16m1_t, vfloat16m1_t, vfloat16m1_t, vfloat16m1_t, vfloat16m1_t, vfloat16m1_t, vfloat16m1_t, vfloat16m1_t, const _Float16 *, vuint16m1_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vluxseg8ei16_v)))
void vluxseg8ei16_v_f16mf2(vfloat16mf2_t *, vfloat16mf2_t *, vfloat16mf2_t *, vfloat16mf2_t *, vfloat16mf2_t *, vfloat16mf2_t *, vfloat16mf2_t *, vfloat16mf2_t *, const _Float16 *, vuint16mf2_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vluxseg8ei16_v_m)))
void vluxseg8ei16_v_f16mf2_m(vfloat16mf2_t *, vfloat16mf2_t *, vfloat16mf2_t *, vfloat16mf2_t *, vfloat16mf2_t *, vfloat16mf2_t *, vfloat16mf2_t *, vfloat16mf2_t *, vbool32_t, vfloat16mf2_t, vfloat16mf2_t, vfloat16mf2_t, vfloat16mf2_t, vfloat16mf2_t, vfloat16mf2_t, vfloat16mf2_t, vfloat16mf2_t, const _Float16 *, vuint16mf2_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vluxseg8ei16_v)))
void vluxseg8ei16_v_f16mf4(vfloat16mf4_t *, vfloat16mf4_t *, vfloat16mf4_t *, vfloat16mf4_t *, vfloat16mf4_t *, vfloat16mf4_t *, vfloat16mf4_t *, vfloat16mf4_t *, const _Float16 *, vuint16mf4_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vluxseg8ei16_v_m)))
void vluxseg8ei16_v_f16mf4_m(vfloat16mf4_t *, vfloat16mf4_t *, vfloat16mf4_t *, vfloat16mf4_t *, vfloat16mf4_t *, vfloat16mf4_t *, vfloat16mf4_t *, vfloat16mf4_t *, vbool64_t, vfloat16mf4_t, vfloat16mf4_t, vfloat16mf4_t, vfloat16mf4_t, vfloat16mf4_t, vfloat16mf4_t, vfloat16mf4_t, vfloat16mf4_t, const _Float16 *, vuint16mf4_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vluxseg2ei32_v)))
void vluxseg2ei32_v_f16m1(vfloat16m1_t *, vfloat16m1_t *, const _Float16 *, vuint32m2_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vluxseg2ei32_v_m)))
void vluxseg2ei32_v_f16m1_m(vfloat16m1_t *, vfloat16m1_t *, vbool16_t, vfloat16m1_t, vfloat16m1_t, const _Float16 *, vuint32m2_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vluxseg2ei32_v)))
void vluxseg2ei32_v_f16m2(vfloat16m2_t *, vfloat16m2_t *, const _Float16 *, vuint32m4_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vluxseg2ei32_v_m)))
void vluxseg2ei32_v_f16m2_m(vfloat16m2_t *, vfloat16m2_t *, vbool8_t, vfloat16m2_t, vfloat16m2_t, const _Float16 *, vuint32m4_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vluxseg2ei32_v)))
void vluxseg2ei32_v_f16m4(vfloat16m4_t *, vfloat16m4_t *, const _Float16 *, vuint32m8_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vluxseg2ei32_v_m)))
void vluxseg2ei32_v_f16m4_m(vfloat16m4_t *, vfloat16m4_t *, vbool4_t, vfloat16m4_t, vfloat16m4_t, const _Float16 *, vuint32m8_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vluxseg2ei32_v)))
void vluxseg2ei32_v_f16mf2(vfloat16mf2_t *, vfloat16mf2_t *, const _Float16 *, vuint32m1_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vluxseg2ei32_v_m)))
void vluxseg2ei32_v_f16mf2_m(vfloat16mf2_t *, vfloat16mf2_t *, vbool32_t, vfloat16mf2_t, vfloat16mf2_t, const _Float16 *, vuint32m1_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vluxseg2ei32_v)))
void vluxseg2ei32_v_f16mf4(vfloat16mf4_t *, vfloat16mf4_t *, const _Float16 *, vuint32mf2_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vluxseg2ei32_v_m)))
void vluxseg2ei32_v_f16mf4_m(vfloat16mf4_t *, vfloat16mf4_t *, vbool64_t, vfloat16mf4_t, vfloat16mf4_t, const _Float16 *, vuint32mf2_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vluxseg3ei32_v)))
void vluxseg3ei32_v_f16m1(vfloat16m1_t *, vfloat16m1_t *, vfloat16m1_t *, const _Float16 *, vuint32m2_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vluxseg3ei32_v_m)))
void vluxseg3ei32_v_f16m1_m(vfloat16m1_t *, vfloat16m1_t *, vfloat16m1_t *, vbool16_t, vfloat16m1_t, vfloat16m1_t, vfloat16m1_t, const _Float16 *, vuint32m2_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vluxseg3ei32_v)))
void vluxseg3ei32_v_f16m2(vfloat16m2_t *, vfloat16m2_t *, vfloat16m2_t *, const _Float16 *, vuint32m4_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vluxseg3ei32_v_m)))
void vluxseg3ei32_v_f16m2_m(vfloat16m2_t *, vfloat16m2_t *, vfloat16m2_t *, vbool8_t, vfloat16m2_t, vfloat16m2_t, vfloat16m2_t, const _Float16 *, vuint32m4_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vluxseg3ei32_v)))
void vluxseg3ei32_v_f16mf2(vfloat16mf2_t *, vfloat16mf2_t *, vfloat16mf2_t *, const _Float16 *, vuint32m1_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vluxseg3ei32_v_m)))
void vluxseg3ei32_v_f16mf2_m(vfloat16mf2_t *, vfloat16mf2_t *, vfloat16mf2_t *, vbool32_t, vfloat16mf2_t, vfloat16mf2_t, vfloat16mf2_t, const _Float16 *, vuint32m1_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vluxseg3ei32_v)))
void vluxseg3ei32_v_f16mf4(vfloat16mf4_t *, vfloat16mf4_t *, vfloat16mf4_t *, const _Float16 *, vuint32mf2_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vluxseg3ei32_v_m)))
void vluxseg3ei32_v_f16mf4_m(vfloat16mf4_t *, vfloat16mf4_t *, vfloat16mf4_t *, vbool64_t, vfloat16mf4_t, vfloat16mf4_t, vfloat16mf4_t, const _Float16 *, vuint32mf2_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vluxseg4ei32_v)))
void vluxseg4ei32_v_f16m1(vfloat16m1_t *, vfloat16m1_t *, vfloat16m1_t *, vfloat16m1_t *, const _Float16 *, vuint32m2_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vluxseg4ei32_v_m)))
void vluxseg4ei32_v_f16m1_m(vfloat16m1_t *, vfloat16m1_t *, vfloat16m1_t *, vfloat16m1_t *, vbool16_t, vfloat16m1_t, vfloat16m1_t, vfloat16m1_t, vfloat16m1_t, const _Float16 *, vuint32m2_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vluxseg4ei32_v)))
void vluxseg4ei32_v_f16m2(vfloat16m2_t *, vfloat16m2_t *, vfloat16m2_t *, vfloat16m2_t *, const _Float16 *, vuint32m4_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vluxseg4ei32_v_m)))
void vluxseg4ei32_v_f16m2_m(vfloat16m2_t *, vfloat16m2_t *, vfloat16m2_t *, vfloat16m2_t *, vbool8_t, vfloat16m2_t, vfloat16m2_t, vfloat16m2_t, vfloat16m2_t, const _Float16 *, vuint32m4_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vluxseg4ei32_v)))
void vluxseg4ei32_v_f16mf2(vfloat16mf2_t *, vfloat16mf2_t *, vfloat16mf2_t *, vfloat16mf2_t *, const _Float16 *, vuint32m1_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vluxseg4ei32_v_m)))
void vluxseg4ei32_v_f16mf2_m(vfloat16mf2_t *, vfloat16mf2_t *, vfloat16mf2_t *, vfloat16mf2_t *, vbool32_t, vfloat16mf2_t, vfloat16mf2_t, vfloat16mf2_t, vfloat16mf2_t, const _Float16 *, vuint32m1_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vluxseg4ei32_v)))
void vluxseg4ei32_v_f16mf4(vfloat16mf4_t *, vfloat16mf4_t *, vfloat16mf4_t *, vfloat16mf4_t *, const _Float16 *, vuint32mf2_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vluxseg4ei32_v_m)))
void vluxseg4ei32_v_f16mf4_m(vfloat16mf4_t *, vfloat16mf4_t *, vfloat16mf4_t *, vfloat16mf4_t *, vbool64_t, vfloat16mf4_t, vfloat16mf4_t, vfloat16mf4_t, vfloat16mf4_t, const _Float16 *, vuint32mf2_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vluxseg5ei32_v)))
void vluxseg5ei32_v_f16m1(vfloat16m1_t *, vfloat16m1_t *, vfloat16m1_t *, vfloat16m1_t *, vfloat16m1_t *, const _Float16 *, vuint32m2_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vluxseg5ei32_v_m)))
void vluxseg5ei32_v_f16m1_m(vfloat16m1_t *, vfloat16m1_t *, vfloat16m1_t *, vfloat16m1_t *, vfloat16m1_t *, vbool16_t, vfloat16m1_t, vfloat16m1_t, vfloat16m1_t, vfloat16m1_t, vfloat16m1_t, const _Float16 *, vuint32m2_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vluxseg5ei32_v)))
void vluxseg5ei32_v_f16mf2(vfloat16mf2_t *, vfloat16mf2_t *, vfloat16mf2_t *, vfloat16mf2_t *, vfloat16mf2_t *, const _Float16 *, vuint32m1_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vluxseg5ei32_v_m)))
void vluxseg5ei32_v_f16mf2_m(vfloat16mf2_t *, vfloat16mf2_t *, vfloat16mf2_t *, vfloat16mf2_t *, vfloat16mf2_t *, vbool32_t, vfloat16mf2_t, vfloat16mf2_t, vfloat16mf2_t, vfloat16mf2_t, vfloat16mf2_t, const _Float16 *, vuint32m1_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vluxseg5ei32_v)))
void vluxseg5ei32_v_f16mf4(vfloat16mf4_t *, vfloat16mf4_t *, vfloat16mf4_t *, vfloat16mf4_t *, vfloat16mf4_t *, const _Float16 *, vuint32mf2_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vluxseg5ei32_v_m)))
void vluxseg5ei32_v_f16mf4_m(vfloat16mf4_t *, vfloat16mf4_t *, vfloat16mf4_t *, vfloat16mf4_t *, vfloat16mf4_t *, vbool64_t, vfloat16mf4_t, vfloat16mf4_t, vfloat16mf4_t, vfloat16mf4_t, vfloat16mf4_t, const _Float16 *, vuint32mf2_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vluxseg6ei32_v)))
void vluxseg6ei32_v_f16m1(vfloat16m1_t *, vfloat16m1_t *, vfloat16m1_t *, vfloat16m1_t *, vfloat16m1_t *, vfloat16m1_t *, const _Float16 *, vuint32m2_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vluxseg6ei32_v_m)))
void vluxseg6ei32_v_f16m1_m(vfloat16m1_t *, vfloat16m1_t *, vfloat16m1_t *, vfloat16m1_t *, vfloat16m1_t *, vfloat16m1_t *, vbool16_t, vfloat16m1_t, vfloat16m1_t, vfloat16m1_t, vfloat16m1_t, vfloat16m1_t, vfloat16m1_t, const _Float16 *, vuint32m2_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vluxseg6ei32_v)))
void vluxseg6ei32_v_f16mf2(vfloat16mf2_t *, vfloat16mf2_t *, vfloat16mf2_t *, vfloat16mf2_t *, vfloat16mf2_t *, vfloat16mf2_t *, const _Float16 *, vuint32m1_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vluxseg6ei32_v_m)))
void vluxseg6ei32_v_f16mf2_m(vfloat16mf2_t *, vfloat16mf2_t *, vfloat16mf2_t *, vfloat16mf2_t *, vfloat16mf2_t *, vfloat16mf2_t *, vbool32_t, vfloat16mf2_t, vfloat16mf2_t, vfloat16mf2_t, vfloat16mf2_t, vfloat16mf2_t, vfloat16mf2_t, const _Float16 *, vuint32m1_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vluxseg6ei32_v)))
void vluxseg6ei32_v_f16mf4(vfloat16mf4_t *, vfloat16mf4_t *, vfloat16mf4_t *, vfloat16mf4_t *, vfloat16mf4_t *, vfloat16mf4_t *, const _Float16 *, vuint32mf2_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vluxseg6ei32_v_m)))
void vluxseg6ei32_v_f16mf4_m(vfloat16mf4_t *, vfloat16mf4_t *, vfloat16mf4_t *, vfloat16mf4_t *, vfloat16mf4_t *, vfloat16mf4_t *, vbool64_t, vfloat16mf4_t, vfloat16mf4_t, vfloat16mf4_t, vfloat16mf4_t, vfloat16mf4_t, vfloat16mf4_t, const _Float16 *, vuint32mf2_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vluxseg7ei32_v)))
void vluxseg7ei32_v_f16m1(vfloat16m1_t *, vfloat16m1_t *, vfloat16m1_t *, vfloat16m1_t *, vfloat16m1_t *, vfloat16m1_t *, vfloat16m1_t *, const _Float16 *, vuint32m2_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vluxseg7ei32_v_m)))
void vluxseg7ei32_v_f16m1_m(vfloat16m1_t *, vfloat16m1_t *, vfloat16m1_t *, vfloat16m1_t *, vfloat16m1_t *, vfloat16m1_t *, vfloat16m1_t *, vbool16_t, vfloat16m1_t, vfloat16m1_t, vfloat16m1_t, vfloat16m1_t, vfloat16m1_t, vfloat16m1_t, vfloat16m1_t, const _Float16 *, vuint32m2_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vluxseg7ei32_v)))
void vluxseg7ei32_v_f16mf2(vfloat16mf2_t *, vfloat16mf2_t *, vfloat16mf2_t *, vfloat16mf2_t *, vfloat16mf2_t *, vfloat16mf2_t *, vfloat16mf2_t *, const _Float16 *, vuint32m1_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vluxseg7ei32_v_m)))
void vluxseg7ei32_v_f16mf2_m(vfloat16mf2_t *, vfloat16mf2_t *, vfloat16mf2_t *, vfloat16mf2_t *, vfloat16mf2_t *, vfloat16mf2_t *, vfloat16mf2_t *, vbool32_t, vfloat16mf2_t, vfloat16mf2_t, vfloat16mf2_t, vfloat16mf2_t, vfloat16mf2_t, vfloat16mf2_t, vfloat16mf2_t, const _Float16 *, vuint32m1_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vluxseg7ei32_v)))
void vluxseg7ei32_v_f16mf4(vfloat16mf4_t *, vfloat16mf4_t *, vfloat16mf4_t *, vfloat16mf4_t *, vfloat16mf4_t *, vfloat16mf4_t *, vfloat16mf4_t *, const _Float16 *, vuint32mf2_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vluxseg7ei32_v_m)))
void vluxseg7ei32_v_f16mf4_m(vfloat16mf4_t *, vfloat16mf4_t *, vfloat16mf4_t *, vfloat16mf4_t *, vfloat16mf4_t *, vfloat16mf4_t *, vfloat16mf4_t *, vbool64_t, vfloat16mf4_t, vfloat16mf4_t, vfloat16mf4_t, vfloat16mf4_t, vfloat16mf4_t, vfloat16mf4_t, vfloat16mf4_t, const _Float16 *, vuint32mf2_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vluxseg8ei32_v)))
void vluxseg8ei32_v_f16m1(vfloat16m1_t *, vfloat16m1_t *, vfloat16m1_t *, vfloat16m1_t *, vfloat16m1_t *, vfloat16m1_t *, vfloat16m1_t *, vfloat16m1_t *, const _Float16 *, vuint32m2_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vluxseg8ei32_v_m)))
void vluxseg8ei32_v_f16m1_m(vfloat16m1_t *, vfloat16m1_t *, vfloat16m1_t *, vfloat16m1_t *, vfloat16m1_t *, vfloat16m1_t *, vfloat16m1_t *, vfloat16m1_t *, vbool16_t, vfloat16m1_t, vfloat16m1_t, vfloat16m1_t, vfloat16m1_t, vfloat16m1_t, vfloat16m1_t, vfloat16m1_t, vfloat16m1_t, const _Float16 *, vuint32m2_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vluxseg8ei32_v)))
void vluxseg8ei32_v_f16mf2(vfloat16mf2_t *, vfloat16mf2_t *, vfloat16mf2_t *, vfloat16mf2_t *, vfloat16mf2_t *, vfloat16mf2_t *, vfloat16mf2_t *, vfloat16mf2_t *, const _Float16 *, vuint32m1_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vluxseg8ei32_v_m)))
void vluxseg8ei32_v_f16mf2_m(vfloat16mf2_t *, vfloat16mf2_t *, vfloat16mf2_t *, vfloat16mf2_t *, vfloat16mf2_t *, vfloat16mf2_t *, vfloat16mf2_t *, vfloat16mf2_t *, vbool32_t, vfloat16mf2_t, vfloat16mf2_t, vfloat16mf2_t, vfloat16mf2_t, vfloat16mf2_t, vfloat16mf2_t, vfloat16mf2_t, vfloat16mf2_t, const _Float16 *, vuint32m1_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vluxseg8ei32_v)))
void vluxseg8ei32_v_f16mf4(vfloat16mf4_t *, vfloat16mf4_t *, vfloat16mf4_t *, vfloat16mf4_t *, vfloat16mf4_t *, vfloat16mf4_t *, vfloat16mf4_t *, vfloat16mf4_t *, const _Float16 *, vuint32mf2_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vluxseg8ei32_v_m)))
void vluxseg8ei32_v_f16mf4_m(vfloat16mf4_t *, vfloat16mf4_t *, vfloat16mf4_t *, vfloat16mf4_t *, vfloat16mf4_t *, vfloat16mf4_t *, vfloat16mf4_t *, vfloat16mf4_t *, vbool64_t, vfloat16mf4_t, vfloat16mf4_t, vfloat16mf4_t, vfloat16mf4_t, vfloat16mf4_t, vfloat16mf4_t, vfloat16mf4_t, vfloat16mf4_t, const _Float16 *, vuint32mf2_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vle16_v)))
vfloat16m1_t vle16_v_f16m1(const _Float16 *, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vle16_v_m)))
vfloat16m1_t vle16_v_f16m1_m(vbool16_t, vfloat16m1_t, const _Float16 *, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vle16_v)))
vfloat16m2_t vle16_v_f16m2(const _Float16 *, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vle16_v_m)))
vfloat16m2_t vle16_v_f16m2_m(vbool8_t, vfloat16m2_t, const _Float16 *, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vle16_v)))
vfloat16m4_t vle16_v_f16m4(const _Float16 *, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vle16_v_m)))
vfloat16m4_t vle16_v_f16m4_m(vbool4_t, vfloat16m4_t, const _Float16 *, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vle16_v)))
vfloat16m8_t vle16_v_f16m8(const _Float16 *, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vle16_v_m)))
vfloat16m8_t vle16_v_f16m8_m(vbool2_t, vfloat16m8_t, const _Float16 *, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vle16_v)))
vfloat16mf2_t vle16_v_f16mf2(const _Float16 *, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vle16_v_m)))
vfloat16mf2_t vle16_v_f16mf2_m(vbool32_t, vfloat16mf2_t, const _Float16 *, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vle16_v)))
vfloat16mf4_t vle16_v_f16mf4(const _Float16 *, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vle16_v_m)))
vfloat16mf4_t vle16_v_f16mf4_m(vbool64_t, vfloat16mf4_t, const _Float16 *, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vse16_v)))
void vse16_v_f16m1(_Float16 *, vfloat16m1_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vse16_v_m)))
void vse16_v_f16m1_m(vbool16_t, _Float16 *, vfloat16m1_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vse16_v)))
void vse16_v_f16m2(_Float16 *, vfloat16m2_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vse16_v_m)))
void vse16_v_f16m2_m(vbool8_t, _Float16 *, vfloat16m2_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vse16_v)))
void vse16_v_f16m4(_Float16 *, vfloat16m4_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vse16_v_m)))
void vse16_v_f16m4_m(vbool4_t, _Float16 *, vfloat16m4_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vse16_v)))
void vse16_v_f16m8(_Float16 *, vfloat16m8_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vse16_v_m)))
void vse16_v_f16m8_m(vbool2_t, _Float16 *, vfloat16m8_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vse16_v)))
void vse16_v_f16mf2(_Float16 *, vfloat16mf2_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vse16_v_m)))
void vse16_v_f16mf2_m(vbool32_t, _Float16 *, vfloat16mf2_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vse16_v)))
void vse16_v_f16mf4(_Float16 *, vfloat16mf4_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vse16_v_m)))
void vse16_v_f16mf4_m(vbool64_t, _Float16 *, vfloat16mf4_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vlse16_v)))
vfloat16m1_t vlse16_v_f16m1(const _Float16 *, ptrdiff_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vlse16_v_m)))
vfloat16m1_t vlse16_v_f16m1_m(vbool16_t, vfloat16m1_t, const _Float16 *, ptrdiff_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vlse16_v)))
vfloat16m2_t vlse16_v_f16m2(const _Float16 *, ptrdiff_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vlse16_v_m)))
vfloat16m2_t vlse16_v_f16m2_m(vbool8_t, vfloat16m2_t, const _Float16 *, ptrdiff_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vlse16_v)))
vfloat16m4_t vlse16_v_f16m4(const _Float16 *, ptrdiff_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vlse16_v_m)))
vfloat16m4_t vlse16_v_f16m4_m(vbool4_t, vfloat16m4_t, const _Float16 *, ptrdiff_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vlse16_v)))
vfloat16m8_t vlse16_v_f16m8(const _Float16 *, ptrdiff_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vlse16_v_m)))
vfloat16m8_t vlse16_v_f16m8_m(vbool2_t, vfloat16m8_t, const _Float16 *, ptrdiff_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vlse16_v)))
vfloat16mf2_t vlse16_v_f16mf2(const _Float16 *, ptrdiff_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vlse16_v_m)))
vfloat16mf2_t vlse16_v_f16mf2_m(vbool32_t, vfloat16mf2_t, const _Float16 *, ptrdiff_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vlse16_v)))
vfloat16mf4_t vlse16_v_f16mf4(const _Float16 *, ptrdiff_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vlse16_v_m)))
vfloat16mf4_t vlse16_v_f16mf4_m(vbool64_t, vfloat16mf4_t, const _Float16 *, ptrdiff_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vfclass_v)))
vuint16m1_t vfclass_v_u16m1(vfloat16m1_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vfclass_v_m)))
vuint16m1_t vfclass_v_u16m1_m(vbool16_t, vuint16m1_t, vfloat16m1_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vfclass_v)))
vuint16m2_t vfclass_v_u16m2(vfloat16m2_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vfclass_v_m)))
vuint16m2_t vfclass_v_u16m2_m(vbool8_t, vuint16m2_t, vfloat16m2_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vfclass_v)))
vuint16m4_t vfclass_v_u16m4(vfloat16m4_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vfclass_v_m)))
vuint16m4_t vfclass_v_u16m4_m(vbool4_t, vuint16m4_t, vfloat16m4_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vfclass_v)))
vuint16m8_t vfclass_v_u16m8(vfloat16m8_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vfclass_v_m)))
vuint16m8_t vfclass_v_u16m8_m(vbool2_t, vuint16m8_t, vfloat16m8_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vfclass_v)))
vuint16mf2_t vfclass_v_u16mf2(vfloat16mf2_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vfclass_v_m)))
vuint16mf2_t vfclass_v_u16mf2_m(vbool32_t, vuint16mf2_t, vfloat16mf2_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vfclass_v)))
vuint16mf4_t vfclass_v_u16mf4(vfloat16mf4_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vfclass_v_m)))
vuint16mf4_t vfclass_v_u16mf4_m(vbool64_t, vuint16mf4_t, vfloat16mf4_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vfcvt_f_x_v)))
vfloat16m1_t vfcvt_f_x_v_f16m1(vint16m1_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vfcvt_f_x_v_m)))
vfloat16m1_t vfcvt_f_x_v_f16m1_m(vbool16_t, vfloat16m1_t, vint16m1_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vfcvt_f_x_v)))
vfloat16m2_t vfcvt_f_x_v_f16m2(vint16m2_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vfcvt_f_x_v_m)))
vfloat16m2_t vfcvt_f_x_v_f16m2_m(vbool8_t, vfloat16m2_t, vint16m2_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vfcvt_f_x_v)))
vfloat16m4_t vfcvt_f_x_v_f16m4(vint16m4_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vfcvt_f_x_v_m)))
vfloat16m4_t vfcvt_f_x_v_f16m4_m(vbool4_t, vfloat16m4_t, vint16m4_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vfcvt_f_x_v)))
vfloat16m8_t vfcvt_f_x_v_f16m8(vint16m8_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vfcvt_f_x_v_m)))
vfloat16m8_t vfcvt_f_x_v_f16m8_m(vbool2_t, vfloat16m8_t, vint16m8_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vfcvt_f_x_v)))
vfloat16mf2_t vfcvt_f_x_v_f16mf2(vint16mf2_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vfcvt_f_x_v_m)))
vfloat16mf2_t vfcvt_f_x_v_f16mf2_m(vbool32_t, vfloat16mf2_t, vint16mf2_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vfcvt_f_x_v)))
vfloat16mf4_t vfcvt_f_x_v_f16mf4(vint16mf4_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vfcvt_f_x_v_m)))
vfloat16mf4_t vfcvt_f_x_v_f16mf4_m(vbool64_t, vfloat16mf4_t, vint16mf4_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vfcvt_f_xu_v)))
vfloat16m1_t vfcvt_f_xu_v_f16m1(vuint16m1_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vfcvt_f_xu_v_m)))
vfloat16m1_t vfcvt_f_xu_v_f16m1_m(vbool16_t, vfloat16m1_t, vuint16m1_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vfcvt_f_xu_v)))
vfloat16m2_t vfcvt_f_xu_v_f16m2(vuint16m2_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vfcvt_f_xu_v_m)))
vfloat16m2_t vfcvt_f_xu_v_f16m2_m(vbool8_t, vfloat16m2_t, vuint16m2_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vfcvt_f_xu_v)))
vfloat16m4_t vfcvt_f_xu_v_f16m4(vuint16m4_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vfcvt_f_xu_v_m)))
vfloat16m4_t vfcvt_f_xu_v_f16m4_m(vbool4_t, vfloat16m4_t, vuint16m4_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vfcvt_f_xu_v)))
vfloat16m8_t vfcvt_f_xu_v_f16m8(vuint16m8_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vfcvt_f_xu_v_m)))
vfloat16m8_t vfcvt_f_xu_v_f16m8_m(vbool2_t, vfloat16m8_t, vuint16m8_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vfcvt_f_xu_v)))
vfloat16mf2_t vfcvt_f_xu_v_f16mf2(vuint16mf2_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vfcvt_f_xu_v_m)))
vfloat16mf2_t vfcvt_f_xu_v_f16mf2_m(vbool32_t, vfloat16mf2_t, vuint16mf2_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vfcvt_f_xu_v)))
vfloat16mf4_t vfcvt_f_xu_v_f16mf4(vuint16mf4_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vfcvt_f_xu_v_m)))
vfloat16mf4_t vfcvt_f_xu_v_f16mf4_m(vbool64_t, vfloat16mf4_t, vuint16mf4_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vfcvt_rtz_x_f_v)))
vint16m1_t vfcvt_rtz_x_f_v_i16m1(vfloat16m1_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vfcvt_rtz_x_f_v_m)))
vint16m1_t vfcvt_rtz_x_f_v_i16m1_m(vbool16_t, vint16m1_t, vfloat16m1_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vfcvt_rtz_x_f_v)))
vint16m2_t vfcvt_rtz_x_f_v_i16m2(vfloat16m2_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vfcvt_rtz_x_f_v_m)))
vint16m2_t vfcvt_rtz_x_f_v_i16m2_m(vbool8_t, vint16m2_t, vfloat16m2_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vfcvt_rtz_x_f_v)))
vint16m4_t vfcvt_rtz_x_f_v_i16m4(vfloat16m4_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vfcvt_rtz_x_f_v_m)))
vint16m4_t vfcvt_rtz_x_f_v_i16m4_m(vbool4_t, vint16m4_t, vfloat16m4_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vfcvt_rtz_x_f_v)))
vint16m8_t vfcvt_rtz_x_f_v_i16m8(vfloat16m8_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vfcvt_rtz_x_f_v_m)))
vint16m8_t vfcvt_rtz_x_f_v_i16m8_m(vbool2_t, vint16m8_t, vfloat16m8_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vfcvt_rtz_x_f_v)))
vint16mf2_t vfcvt_rtz_x_f_v_i16mf2(vfloat16mf2_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vfcvt_rtz_x_f_v_m)))
vint16mf2_t vfcvt_rtz_x_f_v_i16mf2_m(vbool32_t, vint16mf2_t, vfloat16mf2_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vfcvt_rtz_x_f_v)))
vint16mf4_t vfcvt_rtz_x_f_v_i16mf4(vfloat16mf4_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vfcvt_rtz_x_f_v_m)))
vint16mf4_t vfcvt_rtz_x_f_v_i16mf4_m(vbool64_t, vint16mf4_t, vfloat16mf4_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vfcvt_rtz_xu_f_v)))
vuint16m1_t vfcvt_rtz_xu_f_v_u16m1(vfloat16m1_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vfcvt_rtz_xu_f_v_m)))
vuint16m1_t vfcvt_rtz_xu_f_v_u16m1_m(vbool16_t, vuint16m1_t, vfloat16m1_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vfcvt_rtz_xu_f_v)))
vuint16m2_t vfcvt_rtz_xu_f_v_u16m2(vfloat16m2_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vfcvt_rtz_xu_f_v_m)))
vuint16m2_t vfcvt_rtz_xu_f_v_u16m2_m(vbool8_t, vuint16m2_t, vfloat16m2_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vfcvt_rtz_xu_f_v)))
vuint16m4_t vfcvt_rtz_xu_f_v_u16m4(vfloat16m4_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vfcvt_rtz_xu_f_v_m)))
vuint16m4_t vfcvt_rtz_xu_f_v_u16m4_m(vbool4_t, vuint16m4_t, vfloat16m4_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vfcvt_rtz_xu_f_v)))
vuint16m8_t vfcvt_rtz_xu_f_v_u16m8(vfloat16m8_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vfcvt_rtz_xu_f_v_m)))
vuint16m8_t vfcvt_rtz_xu_f_v_u16m8_m(vbool2_t, vuint16m8_t, vfloat16m8_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vfcvt_rtz_xu_f_v)))
vuint16mf2_t vfcvt_rtz_xu_f_v_u16mf2(vfloat16mf2_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vfcvt_rtz_xu_f_v_m)))
vuint16mf2_t vfcvt_rtz_xu_f_v_u16mf2_m(vbool32_t, vuint16mf2_t, vfloat16mf2_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vfcvt_rtz_xu_f_v)))
vuint16mf4_t vfcvt_rtz_xu_f_v_u16mf4(vfloat16mf4_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vfcvt_rtz_xu_f_v_m)))
vuint16mf4_t vfcvt_rtz_xu_f_v_u16mf4_m(vbool64_t, vuint16mf4_t, vfloat16mf4_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vfcvt_x_f_v)))
vint16m1_t vfcvt_x_f_v_i16m1(vfloat16m1_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vfcvt_x_f_v_m)))
vint16m1_t vfcvt_x_f_v_i16m1_m(vbool16_t, vint16m1_t, vfloat16m1_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vfcvt_x_f_v)))
vint16m2_t vfcvt_x_f_v_i16m2(vfloat16m2_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vfcvt_x_f_v_m)))
vint16m2_t vfcvt_x_f_v_i16m2_m(vbool8_t, vint16m2_t, vfloat16m2_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vfcvt_x_f_v)))
vint16m4_t vfcvt_x_f_v_i16m4(vfloat16m4_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vfcvt_x_f_v_m)))
vint16m4_t vfcvt_x_f_v_i16m4_m(vbool4_t, vint16m4_t, vfloat16m4_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vfcvt_x_f_v)))
vint16m8_t vfcvt_x_f_v_i16m8(vfloat16m8_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vfcvt_x_f_v_m)))
vint16m8_t vfcvt_x_f_v_i16m8_m(vbool2_t, vint16m8_t, vfloat16m8_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vfcvt_x_f_v)))
vint16mf2_t vfcvt_x_f_v_i16mf2(vfloat16mf2_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vfcvt_x_f_v_m)))
vint16mf2_t vfcvt_x_f_v_i16mf2_m(vbool32_t, vint16mf2_t, vfloat16mf2_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vfcvt_x_f_v)))
vint16mf4_t vfcvt_x_f_v_i16mf4(vfloat16mf4_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vfcvt_x_f_v_m)))
vint16mf4_t vfcvt_x_f_v_i16mf4_m(vbool64_t, vint16mf4_t, vfloat16mf4_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vfcvt_xu_f_v)))
vuint16m1_t vfcvt_xu_f_v_u16m1(vfloat16m1_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vfcvt_xu_f_v_m)))
vuint16m1_t vfcvt_xu_f_v_u16m1_m(vbool16_t, vuint16m1_t, vfloat16m1_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vfcvt_xu_f_v)))
vuint16m2_t vfcvt_xu_f_v_u16m2(vfloat16m2_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vfcvt_xu_f_v_m)))
vuint16m2_t vfcvt_xu_f_v_u16m2_m(vbool8_t, vuint16m2_t, vfloat16m2_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vfcvt_xu_f_v)))
vuint16m4_t vfcvt_xu_f_v_u16m4(vfloat16m4_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vfcvt_xu_f_v_m)))
vuint16m4_t vfcvt_xu_f_v_u16m4_m(vbool4_t, vuint16m4_t, vfloat16m4_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vfcvt_xu_f_v)))
vuint16m8_t vfcvt_xu_f_v_u16m8(vfloat16m8_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vfcvt_xu_f_v_m)))
vuint16m8_t vfcvt_xu_f_v_u16m8_m(vbool2_t, vuint16m8_t, vfloat16m8_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vfcvt_xu_f_v)))
vuint16mf2_t vfcvt_xu_f_v_u16mf2(vfloat16mf2_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vfcvt_xu_f_v_m)))
vuint16mf2_t vfcvt_xu_f_v_u16mf2_m(vbool32_t, vuint16mf2_t, vfloat16mf2_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vfcvt_xu_f_v)))
vuint16mf4_t vfcvt_xu_f_v_u16mf4(vfloat16mf4_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vfcvt_xu_f_v_m)))
vuint16mf4_t vfcvt_xu_f_v_u16mf4_m(vbool64_t, vuint16mf4_t, vfloat16mf4_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vfncvt_f_x_w)))
vfloat16mf4_t vfncvt_f_x_w_f16mf4(vint32mf2_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vfncvt_f_x_w_m)))
vfloat16mf4_t vfncvt_f_x_w_f16mf4_m(vbool64_t, vfloat16mf4_t, vint32mf2_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vfncvt_f_x_w)))
vfloat16mf2_t vfncvt_f_x_w_f16mf2(vint32m1_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vfncvt_f_x_w_m)))
vfloat16mf2_t vfncvt_f_x_w_f16mf2_m(vbool32_t, vfloat16mf2_t, vint32m1_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vfncvt_f_x_w)))
vfloat16m1_t vfncvt_f_x_w_f16m1(vint32m2_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vfncvt_f_x_w_m)))
vfloat16m1_t vfncvt_f_x_w_f16m1_m(vbool16_t, vfloat16m1_t, vint32m2_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vfncvt_f_x_w)))
vfloat16m2_t vfncvt_f_x_w_f16m2(vint32m4_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vfncvt_f_x_w_m)))
vfloat16m2_t vfncvt_f_x_w_f16m2_m(vbool8_t, vfloat16m2_t, vint32m4_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vfncvt_f_x_w)))
vfloat16m4_t vfncvt_f_x_w_f16m4(vint32m8_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vfncvt_f_x_w_m)))
vfloat16m4_t vfncvt_f_x_w_f16m4_m(vbool4_t, vfloat16m4_t, vint32m8_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vfncvt_f_xu_w)))
vfloat16mf4_t vfncvt_f_xu_w_f16mf4(vuint32mf2_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vfncvt_f_xu_w_m)))
vfloat16mf4_t vfncvt_f_xu_w_f16mf4_m(vbool64_t, vfloat16mf4_t, vuint32mf2_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vfncvt_f_xu_w)))
vfloat16mf2_t vfncvt_f_xu_w_f16mf2(vuint32m1_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vfncvt_f_xu_w_m)))
vfloat16mf2_t vfncvt_f_xu_w_f16mf2_m(vbool32_t, vfloat16mf2_t, vuint32m1_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vfncvt_f_xu_w)))
vfloat16m1_t vfncvt_f_xu_w_f16m1(vuint32m2_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vfncvt_f_xu_w_m)))
vfloat16m1_t vfncvt_f_xu_w_f16m1_m(vbool16_t, vfloat16m1_t, vuint32m2_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vfncvt_f_xu_w)))
vfloat16m2_t vfncvt_f_xu_w_f16m2(vuint32m4_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vfncvt_f_xu_w_m)))
vfloat16m2_t vfncvt_f_xu_w_f16m2_m(vbool8_t, vfloat16m2_t, vuint32m4_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vfncvt_f_xu_w)))
vfloat16m4_t vfncvt_f_xu_w_f16m4(vuint32m8_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vfncvt_f_xu_w_m)))
vfloat16m4_t vfncvt_f_xu_w_f16m4_m(vbool4_t, vfloat16m4_t, vuint32m8_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vfncvt_rtz_x_f_w)))
vint8mf8_t vfncvt_rtz_x_f_w_i8mf8(vfloat16mf4_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vfncvt_rtz_x_f_w_m)))
vint8mf8_t vfncvt_rtz_x_f_w_i8mf8_m(vbool64_t, vint8mf8_t, vfloat16mf4_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vfncvt_rtz_x_f_w)))
vint8mf4_t vfncvt_rtz_x_f_w_i8mf4(vfloat16mf2_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vfncvt_rtz_x_f_w_m)))
vint8mf4_t vfncvt_rtz_x_f_w_i8mf4_m(vbool32_t, vint8mf4_t, vfloat16mf2_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vfncvt_rtz_x_f_w)))
vint8mf2_t vfncvt_rtz_x_f_w_i8mf2(vfloat16m1_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vfncvt_rtz_x_f_w_m)))
vint8mf2_t vfncvt_rtz_x_f_w_i8mf2_m(vbool16_t, vint8mf2_t, vfloat16m1_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vfncvt_rtz_x_f_w)))
vint8m1_t vfncvt_rtz_x_f_w_i8m1(vfloat16m2_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vfncvt_rtz_x_f_w_m)))
vint8m1_t vfncvt_rtz_x_f_w_i8m1_m(vbool8_t, vint8m1_t, vfloat16m2_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vfncvt_rtz_x_f_w)))
vint8m2_t vfncvt_rtz_x_f_w_i8m2(vfloat16m4_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vfncvt_rtz_x_f_w_m)))
vint8m2_t vfncvt_rtz_x_f_w_i8m2_m(vbool4_t, vint8m2_t, vfloat16m4_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vfncvt_rtz_x_f_w)))
vint8m4_t vfncvt_rtz_x_f_w_i8m4(vfloat16m8_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vfncvt_rtz_x_f_w_m)))
vint8m4_t vfncvt_rtz_x_f_w_i8m4_m(vbool2_t, vint8m4_t, vfloat16m8_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vfncvt_rtz_xu_f_w)))
vuint8mf8_t vfncvt_rtz_xu_f_w_u8mf8(vfloat16mf4_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vfncvt_rtz_xu_f_w_m)))
vuint8mf8_t vfncvt_rtz_xu_f_w_u8mf8_m(vbool64_t, vuint8mf8_t, vfloat16mf4_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vfncvt_rtz_xu_f_w)))
vuint8mf4_t vfncvt_rtz_xu_f_w_u8mf4(vfloat16mf2_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vfncvt_rtz_xu_f_w_m)))
vuint8mf4_t vfncvt_rtz_xu_f_w_u8mf4_m(vbool32_t, vuint8mf4_t, vfloat16mf2_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vfncvt_rtz_xu_f_w)))
vuint8mf2_t vfncvt_rtz_xu_f_w_u8mf2(vfloat16m1_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vfncvt_rtz_xu_f_w_m)))
vuint8mf2_t vfncvt_rtz_xu_f_w_u8mf2_m(vbool16_t, vuint8mf2_t, vfloat16m1_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vfncvt_rtz_xu_f_w)))
vuint8m1_t vfncvt_rtz_xu_f_w_u8m1(vfloat16m2_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vfncvt_rtz_xu_f_w_m)))
vuint8m1_t vfncvt_rtz_xu_f_w_u8m1_m(vbool8_t, vuint8m1_t, vfloat16m2_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vfncvt_rtz_xu_f_w)))
vuint8m2_t vfncvt_rtz_xu_f_w_u8m2(vfloat16m4_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vfncvt_rtz_xu_f_w_m)))
vuint8m2_t vfncvt_rtz_xu_f_w_u8m2_m(vbool4_t, vuint8m2_t, vfloat16m4_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vfncvt_rtz_xu_f_w)))
vuint8m4_t vfncvt_rtz_xu_f_w_u8m4(vfloat16m8_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vfncvt_rtz_xu_f_w_m)))
vuint8m4_t vfncvt_rtz_xu_f_w_u8m4_m(vbool2_t, vuint8m4_t, vfloat16m8_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vfncvt_x_f_w)))
vint8mf8_t vfncvt_x_f_w_i8mf8(vfloat16mf4_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vfncvt_x_f_w_m)))
vint8mf8_t vfncvt_x_f_w_i8mf8_m(vbool64_t, vint8mf8_t, vfloat16mf4_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vfncvt_x_f_w)))
vint8mf4_t vfncvt_x_f_w_i8mf4(vfloat16mf2_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vfncvt_x_f_w_m)))
vint8mf4_t vfncvt_x_f_w_i8mf4_m(vbool32_t, vint8mf4_t, vfloat16mf2_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vfncvt_x_f_w)))
vint8mf2_t vfncvt_x_f_w_i8mf2(vfloat16m1_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vfncvt_x_f_w_m)))
vint8mf2_t vfncvt_x_f_w_i8mf2_m(vbool16_t, vint8mf2_t, vfloat16m1_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vfncvt_x_f_w)))
vint8m1_t vfncvt_x_f_w_i8m1(vfloat16m2_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vfncvt_x_f_w_m)))
vint8m1_t vfncvt_x_f_w_i8m1_m(vbool8_t, vint8m1_t, vfloat16m2_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vfncvt_x_f_w)))
vint8m2_t vfncvt_x_f_w_i8m2(vfloat16m4_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vfncvt_x_f_w_m)))
vint8m2_t vfncvt_x_f_w_i8m2_m(vbool4_t, vint8m2_t, vfloat16m4_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vfncvt_x_f_w)))
vint8m4_t vfncvt_x_f_w_i8m4(vfloat16m8_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vfncvt_x_f_w_m)))
vint8m4_t vfncvt_x_f_w_i8m4_m(vbool2_t, vint8m4_t, vfloat16m8_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vfncvt_xu_f_w)))
vuint8mf8_t vfncvt_xu_f_w_u8mf8(vfloat16mf4_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vfncvt_xu_f_w_m)))
vuint8mf8_t vfncvt_xu_f_w_u8mf8_m(vbool64_t, vuint8mf8_t, vfloat16mf4_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vfncvt_xu_f_w)))
vuint8mf4_t vfncvt_xu_f_w_u8mf4(vfloat16mf2_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vfncvt_xu_f_w_m)))
vuint8mf4_t vfncvt_xu_f_w_u8mf4_m(vbool32_t, vuint8mf4_t, vfloat16mf2_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vfncvt_xu_f_w)))
vuint8mf2_t vfncvt_xu_f_w_u8mf2(vfloat16m1_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vfncvt_xu_f_w_m)))
vuint8mf2_t vfncvt_xu_f_w_u8mf2_m(vbool16_t, vuint8mf2_t, vfloat16m1_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vfncvt_xu_f_w)))
vuint8m1_t vfncvt_xu_f_w_u8m1(vfloat16m2_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vfncvt_xu_f_w_m)))
vuint8m1_t vfncvt_xu_f_w_u8m1_m(vbool8_t, vuint8m1_t, vfloat16m2_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vfncvt_xu_f_w)))
vuint8m2_t vfncvt_xu_f_w_u8m2(vfloat16m4_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vfncvt_xu_f_w_m)))
vuint8m2_t vfncvt_xu_f_w_u8m2_m(vbool4_t, vuint8m2_t, vfloat16m4_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vfncvt_xu_f_w)))
vuint8m4_t vfncvt_xu_f_w_u8m4(vfloat16m8_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vfncvt_xu_f_w_m)))
vuint8m4_t vfncvt_xu_f_w_u8m4_m(vbool2_t, vuint8m4_t, vfloat16m8_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vfrec7_v)))
vfloat16m1_t vfrec7_v_f16m1(vfloat16m1_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vfrec7_v_m)))
vfloat16m1_t vfrec7_v_f16m1_m(vbool16_t, vfloat16m1_t, vfloat16m1_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vfrec7_v)))
vfloat16m2_t vfrec7_v_f16m2(vfloat16m2_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vfrec7_v_m)))
vfloat16m2_t vfrec7_v_f16m2_m(vbool8_t, vfloat16m2_t, vfloat16m2_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vfrec7_v)))
vfloat16m4_t vfrec7_v_f16m4(vfloat16m4_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vfrec7_v_m)))
vfloat16m4_t vfrec7_v_f16m4_m(vbool4_t, vfloat16m4_t, vfloat16m4_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vfrec7_v)))
vfloat16m8_t vfrec7_v_f16m8(vfloat16m8_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vfrec7_v_m)))
vfloat16m8_t vfrec7_v_f16m8_m(vbool2_t, vfloat16m8_t, vfloat16m8_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vfrec7_v)))
vfloat16mf2_t vfrec7_v_f16mf2(vfloat16mf2_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vfrec7_v_m)))
vfloat16mf2_t vfrec7_v_f16mf2_m(vbool32_t, vfloat16mf2_t, vfloat16mf2_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vfrec7_v)))
vfloat16mf4_t vfrec7_v_f16mf4(vfloat16mf4_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vfrec7_v_m)))
vfloat16mf4_t vfrec7_v_f16mf4_m(vbool64_t, vfloat16mf4_t, vfloat16mf4_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vfrsqrt7_v)))
vfloat16m1_t vfrsqrt7_v_f16m1(vfloat16m1_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vfrsqrt7_v_m)))
vfloat16m1_t vfrsqrt7_v_f16m1_m(vbool16_t, vfloat16m1_t, vfloat16m1_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vfrsqrt7_v)))
vfloat16m2_t vfrsqrt7_v_f16m2(vfloat16m2_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vfrsqrt7_v_m)))
vfloat16m2_t vfrsqrt7_v_f16m2_m(vbool8_t, vfloat16m2_t, vfloat16m2_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vfrsqrt7_v)))
vfloat16m4_t vfrsqrt7_v_f16m4(vfloat16m4_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vfrsqrt7_v_m)))
vfloat16m4_t vfrsqrt7_v_f16m4_m(vbool4_t, vfloat16m4_t, vfloat16m4_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vfrsqrt7_v)))
vfloat16m8_t vfrsqrt7_v_f16m8(vfloat16m8_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vfrsqrt7_v_m)))
vfloat16m8_t vfrsqrt7_v_f16m8_m(vbool2_t, vfloat16m8_t, vfloat16m8_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vfrsqrt7_v)))
vfloat16mf2_t vfrsqrt7_v_f16mf2(vfloat16mf2_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vfrsqrt7_v_m)))
vfloat16mf2_t vfrsqrt7_v_f16mf2_m(vbool32_t, vfloat16mf2_t, vfloat16mf2_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vfrsqrt7_v)))
vfloat16mf4_t vfrsqrt7_v_f16mf4(vfloat16mf4_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vfrsqrt7_v_m)))
vfloat16mf4_t vfrsqrt7_v_f16mf4_m(vbool64_t, vfloat16mf4_t, vfloat16mf4_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vfsqrt_v)))
vfloat16m1_t vfsqrt_v_f16m1(vfloat16m1_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vfsqrt_v_m)))
vfloat16m1_t vfsqrt_v_f16m1_m(vbool16_t, vfloat16m1_t, vfloat16m1_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vfsqrt_v)))
vfloat16m2_t vfsqrt_v_f16m2(vfloat16m2_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vfsqrt_v_m)))
vfloat16m2_t vfsqrt_v_f16m2_m(vbool8_t, vfloat16m2_t, vfloat16m2_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vfsqrt_v)))
vfloat16m4_t vfsqrt_v_f16m4(vfloat16m4_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vfsqrt_v_m)))
vfloat16m4_t vfsqrt_v_f16m4_m(vbool4_t, vfloat16m4_t, vfloat16m4_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vfsqrt_v)))
vfloat16m8_t vfsqrt_v_f16m8(vfloat16m8_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vfsqrt_v_m)))
vfloat16m8_t vfsqrt_v_f16m8_m(vbool2_t, vfloat16m8_t, vfloat16m8_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vfsqrt_v)))
vfloat16mf2_t vfsqrt_v_f16mf2(vfloat16mf2_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vfsqrt_v_m)))
vfloat16mf2_t vfsqrt_v_f16mf2_m(vbool32_t, vfloat16mf2_t, vfloat16mf2_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vfsqrt_v)))
vfloat16mf4_t vfsqrt_v_f16mf4(vfloat16mf4_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vfsqrt_v_m)))
vfloat16mf4_t vfsqrt_v_f16mf4_m(vbool64_t, vfloat16mf4_t, vfloat16mf4_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vfwcvt_f_x_v)))
vfloat16mf4_t vfwcvt_f_x_v_f16mf4(vint8mf8_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vfwcvt_f_x_v_m)))
vfloat16mf4_t vfwcvt_f_x_v_f16mf4_m(vbool64_t, vfloat16mf4_t, vint8mf8_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vfwcvt_f_x_v)))
vfloat16mf2_t vfwcvt_f_x_v_f16mf2(vint8mf4_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vfwcvt_f_x_v_m)))
vfloat16mf2_t vfwcvt_f_x_v_f16mf2_m(vbool32_t, vfloat16mf2_t, vint8mf4_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vfwcvt_f_x_v)))
vfloat16m1_t vfwcvt_f_x_v_f16m1(vint8mf2_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vfwcvt_f_x_v_m)))
vfloat16m1_t vfwcvt_f_x_v_f16m1_m(vbool16_t, vfloat16m1_t, vint8mf2_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vfwcvt_f_x_v)))
vfloat16m2_t vfwcvt_f_x_v_f16m2(vint8m1_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vfwcvt_f_x_v_m)))
vfloat16m2_t vfwcvt_f_x_v_f16m2_m(vbool8_t, vfloat16m2_t, vint8m1_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vfwcvt_f_x_v)))
vfloat16m4_t vfwcvt_f_x_v_f16m4(vint8m2_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vfwcvt_f_x_v_m)))
vfloat16m4_t vfwcvt_f_x_v_f16m4_m(vbool4_t, vfloat16m4_t, vint8m2_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vfwcvt_f_x_v)))
vfloat16m8_t vfwcvt_f_x_v_f16m8(vint8m4_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vfwcvt_f_x_v_m)))
vfloat16m8_t vfwcvt_f_x_v_f16m8_m(vbool2_t, vfloat16m8_t, vint8m4_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vfwcvt_f_xu_v)))
vfloat16mf4_t vfwcvt_f_xu_v_f16mf4(vuint8mf8_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vfwcvt_f_xu_v_m)))
vfloat16mf4_t vfwcvt_f_xu_v_f16mf4_m(vbool64_t, vfloat16mf4_t, vuint8mf8_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vfwcvt_f_xu_v)))
vfloat16mf2_t vfwcvt_f_xu_v_f16mf2(vuint8mf4_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vfwcvt_f_xu_v_m)))
vfloat16mf2_t vfwcvt_f_xu_v_f16mf2_m(vbool32_t, vfloat16mf2_t, vuint8mf4_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vfwcvt_f_xu_v)))
vfloat16m1_t vfwcvt_f_xu_v_f16m1(vuint8mf2_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vfwcvt_f_xu_v_m)))
vfloat16m1_t vfwcvt_f_xu_v_f16m1_m(vbool16_t, vfloat16m1_t, vuint8mf2_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vfwcvt_f_xu_v)))
vfloat16m2_t vfwcvt_f_xu_v_f16m2(vuint8m1_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vfwcvt_f_xu_v_m)))
vfloat16m2_t vfwcvt_f_xu_v_f16m2_m(vbool8_t, vfloat16m2_t, vuint8m1_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vfwcvt_f_xu_v)))
vfloat16m4_t vfwcvt_f_xu_v_f16m4(vuint8m2_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vfwcvt_f_xu_v_m)))
vfloat16m4_t vfwcvt_f_xu_v_f16m4_m(vbool4_t, vfloat16m4_t, vuint8m2_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vfwcvt_f_xu_v)))
vfloat16m8_t vfwcvt_f_xu_v_f16m8(vuint8m4_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vfwcvt_f_xu_v_m)))
vfloat16m8_t vfwcvt_f_xu_v_f16m8_m(vbool2_t, vfloat16m8_t, vuint8m4_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vfwcvt_rtz_x_f_v)))
vint32mf2_t vfwcvt_rtz_x_f_v_i32mf2(vfloat16mf4_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vfwcvt_rtz_x_f_v_m)))
vint32mf2_t vfwcvt_rtz_x_f_v_i32mf2_m(vbool64_t, vint32mf2_t, vfloat16mf4_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vfwcvt_rtz_x_f_v)))
vint32m1_t vfwcvt_rtz_x_f_v_i32m1(vfloat16mf2_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vfwcvt_rtz_x_f_v_m)))
vint32m1_t vfwcvt_rtz_x_f_v_i32m1_m(vbool32_t, vint32m1_t, vfloat16mf2_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vfwcvt_rtz_x_f_v)))
vint32m2_t vfwcvt_rtz_x_f_v_i32m2(vfloat16m1_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vfwcvt_rtz_x_f_v_m)))
vint32m2_t vfwcvt_rtz_x_f_v_i32m2_m(vbool16_t, vint32m2_t, vfloat16m1_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vfwcvt_rtz_x_f_v)))
vint32m4_t vfwcvt_rtz_x_f_v_i32m4(vfloat16m2_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vfwcvt_rtz_x_f_v_m)))
vint32m4_t vfwcvt_rtz_x_f_v_i32m4_m(vbool8_t, vint32m4_t, vfloat16m2_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vfwcvt_rtz_x_f_v)))
vint32m8_t vfwcvt_rtz_x_f_v_i32m8(vfloat16m4_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vfwcvt_rtz_x_f_v_m)))
vint32m8_t vfwcvt_rtz_x_f_v_i32m8_m(vbool4_t, vint32m8_t, vfloat16m4_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vfwcvt_rtz_xu_f_v)))
vuint32mf2_t vfwcvt_rtz_xu_f_v_u32mf2(vfloat16mf4_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vfwcvt_rtz_xu_f_v_m)))
vuint32mf2_t vfwcvt_rtz_xu_f_v_u32mf2_m(vbool64_t, vuint32mf2_t, vfloat16mf4_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vfwcvt_rtz_xu_f_v)))
vuint32m1_t vfwcvt_rtz_xu_f_v_u32m1(vfloat16mf2_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vfwcvt_rtz_xu_f_v_m)))
vuint32m1_t vfwcvt_rtz_xu_f_v_u32m1_m(vbool32_t, vuint32m1_t, vfloat16mf2_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vfwcvt_rtz_xu_f_v)))
vuint32m2_t vfwcvt_rtz_xu_f_v_u32m2(vfloat16m1_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vfwcvt_rtz_xu_f_v_m)))
vuint32m2_t vfwcvt_rtz_xu_f_v_u32m2_m(vbool16_t, vuint32m2_t, vfloat16m1_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vfwcvt_rtz_xu_f_v)))
vuint32m4_t vfwcvt_rtz_xu_f_v_u32m4(vfloat16m2_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vfwcvt_rtz_xu_f_v_m)))
vuint32m4_t vfwcvt_rtz_xu_f_v_u32m4_m(vbool8_t, vuint32m4_t, vfloat16m2_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vfwcvt_rtz_xu_f_v)))
vuint32m8_t vfwcvt_rtz_xu_f_v_u32m8(vfloat16m4_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vfwcvt_rtz_xu_f_v_m)))
vuint32m8_t vfwcvt_rtz_xu_f_v_u32m8_m(vbool4_t, vuint32m8_t, vfloat16m4_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vfwcvt_x_f_v)))
vint32mf2_t vfwcvt_x_f_v_i32mf2(vfloat16mf4_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vfwcvt_x_f_v_m)))
vint32mf2_t vfwcvt_x_f_v_i32mf2_m(vbool64_t, vint32mf2_t, vfloat16mf4_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vfwcvt_x_f_v)))
vint32m1_t vfwcvt_x_f_v_i32m1(vfloat16mf2_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vfwcvt_x_f_v_m)))
vint32m1_t vfwcvt_x_f_v_i32m1_m(vbool32_t, vint32m1_t, vfloat16mf2_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vfwcvt_x_f_v)))
vint32m2_t vfwcvt_x_f_v_i32m2(vfloat16m1_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vfwcvt_x_f_v_m)))
vint32m2_t vfwcvt_x_f_v_i32m2_m(vbool16_t, vint32m2_t, vfloat16m1_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vfwcvt_x_f_v)))
vint32m4_t vfwcvt_x_f_v_i32m4(vfloat16m2_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vfwcvt_x_f_v_m)))
vint32m4_t vfwcvt_x_f_v_i32m4_m(vbool8_t, vint32m4_t, vfloat16m2_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vfwcvt_x_f_v)))
vint32m8_t vfwcvt_x_f_v_i32m8(vfloat16m4_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vfwcvt_x_f_v_m)))
vint32m8_t vfwcvt_x_f_v_i32m8_m(vbool4_t, vint32m8_t, vfloat16m4_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vfwcvt_xu_f_v)))
vuint32mf2_t vfwcvt_xu_f_v_u32mf2(vfloat16mf4_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vfwcvt_xu_f_v_m)))
vuint32mf2_t vfwcvt_xu_f_v_u32mf2_m(vbool64_t, vuint32mf2_t, vfloat16mf4_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vfwcvt_xu_f_v)))
vuint32m1_t vfwcvt_xu_f_v_u32m1(vfloat16mf2_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vfwcvt_xu_f_v_m)))
vuint32m1_t vfwcvt_xu_f_v_u32m1_m(vbool32_t, vuint32m1_t, vfloat16mf2_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vfwcvt_xu_f_v)))
vuint32m2_t vfwcvt_xu_f_v_u32m2(vfloat16m1_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vfwcvt_xu_f_v_m)))
vuint32m2_t vfwcvt_xu_f_v_u32m2_m(vbool16_t, vuint32m2_t, vfloat16m1_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vfwcvt_xu_f_v)))
vuint32m4_t vfwcvt_xu_f_v_u32m4(vfloat16m2_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vfwcvt_xu_f_v_m)))
vuint32m4_t vfwcvt_xu_f_v_u32m4_m(vbool8_t, vuint32m4_t, vfloat16m2_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vfwcvt_xu_f_v)))
vuint32m8_t vfwcvt_xu_f_v_u32m8(vfloat16m4_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vfwcvt_xu_f_v_m)))
vuint32m8_t vfwcvt_xu_f_v_u32m8_m(vbool4_t, vuint32m8_t, vfloat16m4_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vlmul_ext_v)))
vfloat16m1_t vlmul_ext_v_f16mf2_f16m1(vfloat16mf2_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vlmul_ext_v)))
vfloat16m1_t vlmul_ext_v_f16mf4_f16m1(vfloat16mf4_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vlmul_ext_v)))
vfloat16mf2_t vlmul_ext_v_f16mf4_f16mf2(vfloat16mf4_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vlmul_ext_v)))
vfloat16m2_t vlmul_ext_v_f16m1_f16m2(vfloat16m1_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vlmul_ext_v)))
vfloat16m2_t vlmul_ext_v_f16mf2_f16m2(vfloat16mf2_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vlmul_ext_v)))
vfloat16m2_t vlmul_ext_v_f16mf4_f16m2(vfloat16mf4_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vlmul_ext_v)))
vfloat16m4_t vlmul_ext_v_f16m1_f16m4(vfloat16m1_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vlmul_ext_v)))
vfloat16m4_t vlmul_ext_v_f16m2_f16m4(vfloat16m2_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vlmul_ext_v)))
vfloat16m4_t vlmul_ext_v_f16mf2_f16m4(vfloat16mf2_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vlmul_ext_v)))
vfloat16m4_t vlmul_ext_v_f16mf4_f16m4(vfloat16mf4_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vlmul_ext_v)))
vfloat16m8_t vlmul_ext_v_f16m1_f16m8(vfloat16m1_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vlmul_ext_v)))
vfloat16m8_t vlmul_ext_v_f16m2_f16m8(vfloat16m2_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vlmul_ext_v)))
vfloat16m8_t vlmul_ext_v_f16m4_f16m8(vfloat16m4_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vlmul_ext_v)))
vfloat16m8_t vlmul_ext_v_f16mf2_f16m8(vfloat16mf2_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vlmul_ext_v)))
vfloat16m8_t vlmul_ext_v_f16mf4_f16m8(vfloat16mf4_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vlmul_trunc_v)))
vfloat16mf2_t vlmul_trunc_v_f16m1_f16mf2(vfloat16m1_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vlmul_trunc_v)))
vfloat16mf2_t vlmul_trunc_v_f16m2_f16mf2(vfloat16m2_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vlmul_trunc_v)))
vfloat16mf2_t vlmul_trunc_v_f16m4_f16mf2(vfloat16m4_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vlmul_trunc_v)))
vfloat16mf2_t vlmul_trunc_v_f16m8_f16mf2(vfloat16m8_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vlmul_trunc_v)))
vfloat16mf4_t vlmul_trunc_v_f16m1_f16mf4(vfloat16m1_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vlmul_trunc_v)))
vfloat16mf4_t vlmul_trunc_v_f16m2_f16mf4(vfloat16m2_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vlmul_trunc_v)))
vfloat16mf4_t vlmul_trunc_v_f16m4_f16mf4(vfloat16m4_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vlmul_trunc_v)))
vfloat16mf4_t vlmul_trunc_v_f16m8_f16mf4(vfloat16m8_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vlmul_trunc_v)))
vfloat16mf4_t vlmul_trunc_v_f16mf2_f16mf4(vfloat16mf2_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vlmul_trunc_v)))
vfloat16m1_t vlmul_trunc_v_f16m2_f16m1(vfloat16m2_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vlmul_trunc_v)))
vfloat16m1_t vlmul_trunc_v_f16m4_f16m1(vfloat16m4_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vlmul_trunc_v)))
vfloat16m1_t vlmul_trunc_v_f16m8_f16m1(vfloat16m8_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vlmul_trunc_v)))
vfloat16m2_t vlmul_trunc_v_f16m4_f16m2(vfloat16m4_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vlmul_trunc_v)))
vfloat16m2_t vlmul_trunc_v_f16m8_f16m2(vfloat16m8_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vlmul_trunc_v)))
vfloat16m4_t vlmul_trunc_v_f16m8_f16m4(vfloat16m8_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vreinterpret_v)))
vfloat16m1_t vreinterpret_v_i16m1_f16m1(vint16m1_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vreinterpret_v)))
vfloat16m2_t vreinterpret_v_i16m2_f16m2(vint16m2_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vreinterpret_v)))
vfloat16m4_t vreinterpret_v_i16m4_f16m4(vint16m4_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vreinterpret_v)))
vfloat16m8_t vreinterpret_v_i16m8_f16m8(vint16m8_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vreinterpret_v)))
vfloat16mf2_t vreinterpret_v_i16mf2_f16mf2(vint16mf2_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vreinterpret_v)))
vfloat16mf4_t vreinterpret_v_i16mf4_f16mf4(vint16mf4_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vreinterpret_v)))
vfloat16m1_t vreinterpret_v_u16m1_f16m1(vuint16m1_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vreinterpret_v)))
vfloat16m2_t vreinterpret_v_u16m2_f16m2(vuint16m2_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vreinterpret_v)))
vfloat16m4_t vreinterpret_v_u16m4_f16m4(vuint16m4_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vreinterpret_v)))
vfloat16m8_t vreinterpret_v_u16m8_f16m8(vuint16m8_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vreinterpret_v)))
vfloat16mf2_t vreinterpret_v_u16mf2_f16mf2(vuint16mf2_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vreinterpret_v)))
vfloat16mf4_t vreinterpret_v_u16mf4_f16mf4(vuint16mf4_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vreinterpret_v)))
vint16m1_t vreinterpret_v_f16m1_i16m1(vfloat16m1_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vreinterpret_v)))
vint16m2_t vreinterpret_v_f16m2_i16m2(vfloat16m2_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vreinterpret_v)))
vint16m4_t vreinterpret_v_f16m4_i16m4(vfloat16m4_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vreinterpret_v)))
vint16m8_t vreinterpret_v_f16m8_i16m8(vfloat16m8_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vreinterpret_v)))
vint16mf2_t vreinterpret_v_f16mf2_i16mf2(vfloat16mf2_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vreinterpret_v)))
vint16mf4_t vreinterpret_v_f16mf4_i16mf4(vfloat16mf4_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vreinterpret_v)))
vuint16m1_t vreinterpret_v_f16m1_u16m1(vfloat16m1_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vreinterpret_v)))
vuint16m2_t vreinterpret_v_f16m2_u16m2(vfloat16m2_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vreinterpret_v)))
vuint16m4_t vreinterpret_v_f16m4_u16m4(vfloat16m4_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vreinterpret_v)))
vuint16m8_t vreinterpret_v_f16m8_u16m8(vfloat16m8_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vreinterpret_v)))
vuint16mf2_t vreinterpret_v_f16mf2_u16mf2(vfloat16mf2_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vreinterpret_v)))
vuint16mf4_t vreinterpret_v_f16mf4_u16mf4(vfloat16mf4_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vundefined)))
vfloat16m1_t vundefined_f16m1();
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vundefined)))
vfloat16m2_t vundefined_f16m2();
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vundefined)))
vfloat16m4_t vundefined_f16m4();
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vundefined)))
vfloat16m8_t vundefined_f16m8();
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vundefined)))
vfloat16mf2_t vundefined_f16mf2();
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vundefined)))
vfloat16mf4_t vundefined_f16mf4();
#endif

#if (__riscv_v_elen >= 64)
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vadd_vv)))
vint64m1_t vadd_vv_i64m1(vint64m1_t, vint64m1_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vadd_vv_m)))
vint64m1_t vadd_vv_i64m1_m(vbool64_t, vint64m1_t, vint64m1_t, vint64m1_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vadd_vv)))
vint64m2_t vadd_vv_i64m2(vint64m2_t, vint64m2_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vadd_vv_m)))
vint64m2_t vadd_vv_i64m2_m(vbool32_t, vint64m2_t, vint64m2_t, vint64m2_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vadd_vv)))
vint64m4_t vadd_vv_i64m4(vint64m4_t, vint64m4_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vadd_vv_m)))
vint64m4_t vadd_vv_i64m4_m(vbool16_t, vint64m4_t, vint64m4_t, vint64m4_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vadd_vv)))
vint64m8_t vadd_vv_i64m8(vint64m8_t, vint64m8_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vadd_vv_m)))
vint64m8_t vadd_vv_i64m8_m(vbool8_t, vint64m8_t, vint64m8_t, vint64m8_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vwaddu_vv)))
vuint64m1_t vwaddu_vv_u64m1(vuint32mf2_t, vuint32mf2_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vwaddu_vv_m)))
vuint64m1_t vwaddu_vv_u64m1_m(vbool64_t, vuint64m1_t, vuint32mf2_t, vuint32mf2_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vwaddu_vv)))
vuint64m2_t vwaddu_vv_u64m2(vuint32m1_t, vuint32m1_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vwaddu_vv_m)))
vuint64m2_t vwaddu_vv_u64m2_m(vbool32_t, vuint64m2_t, vuint32m1_t, vuint32m1_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vwaddu_vv)))
vuint64m4_t vwaddu_vv_u64m4(vuint32m2_t, vuint32m2_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vwaddu_vv_m)))
vuint64m4_t vwaddu_vv_u64m4_m(vbool16_t, vuint64m4_t, vuint32m2_t, vuint32m2_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vwaddu_vv)))
vuint64m8_t vwaddu_vv_u64m8(vuint32m4_t, vuint32m4_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vwaddu_vv_m)))
vuint64m8_t vwaddu_vv_u64m8_m(vbool8_t, vuint64m8_t, vuint32m4_t, vuint32m4_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vloxseg3ei8_v)))
void vloxseg3ei8_v_i64m1(vint64m1_t *, vint64m1_t *, vint64m1_t *, const int64_t *, vuint8mf8_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vloxseg3ei8_v_m)))
void vloxseg3ei8_v_i64m1_m(vint64m1_t *, vint64m1_t *, vint64m1_t *, vbool64_t, vint64m1_t, vint64m1_t, vint64m1_t, const int64_t *, vuint8mf8_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vloxseg3ei8_v)))
void vloxseg3ei8_v_i64m2(vint64m2_t *, vint64m2_t *, vint64m2_t *, const int64_t *, vuint8mf4_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vloxseg3ei8_v_m)))
void vloxseg3ei8_v_i64m2_m(vint64m2_t *, vint64m2_t *, vint64m2_t *, vbool32_t, vint64m2_t, vint64m2_t, vint64m2_t, const int64_t *, vuint8mf4_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vloxseg3ei8_v)))
void vloxseg3ei8_v_u64m1(vuint64m1_t *, vuint64m1_t *, vuint64m1_t *, const uint64_t *, vuint8mf8_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vloxseg3ei8_v_m)))
void vloxseg3ei8_v_u64m1_m(vuint64m1_t *, vuint64m1_t *, vuint64m1_t *, vbool64_t, vuint64m1_t, vuint64m1_t, vuint64m1_t, const uint64_t *, vuint8mf8_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vloxseg3ei8_v)))
void vloxseg3ei8_v_u64m2(vuint64m2_t *, vuint64m2_t *, vuint64m2_t *, const uint64_t *, vuint8mf4_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vloxseg3ei8_v_m)))
void vloxseg3ei8_v_u64m2_m(vuint64m2_t *, vuint64m2_t *, vuint64m2_t *, vbool32_t, vuint64m2_t, vuint64m2_t, vuint64m2_t, const uint64_t *, vuint8mf4_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vloxseg4ei8_v)))
void vloxseg4ei8_v_i64m1(vint64m1_t *, vint64m1_t *, vint64m1_t *, vint64m1_t *, const int64_t *, vuint8mf8_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vloxseg4ei8_v_m)))
void vloxseg4ei8_v_i64m1_m(vint64m1_t *, vint64m1_t *, vint64m1_t *, vint64m1_t *, vbool64_t, vint64m1_t, vint64m1_t, vint64m1_t, vint64m1_t, const int64_t *, vuint8mf8_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vloxseg4ei8_v)))
void vloxseg4ei8_v_i64m2(vint64m2_t *, vint64m2_t *, vint64m2_t *, vint64m2_t *, const int64_t *, vuint8mf4_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vloxseg4ei8_v_m)))
void vloxseg4ei8_v_i64m2_m(vint64m2_t *, vint64m2_t *, vint64m2_t *, vint64m2_t *, vbool32_t, vint64m2_t, vint64m2_t, vint64m2_t, vint64m2_t, const int64_t *, vuint8mf4_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vloxseg4ei8_v)))
void vloxseg4ei8_v_u64m1(vuint64m1_t *, vuint64m1_t *, vuint64m1_t *, vuint64m1_t *, const uint64_t *, vuint8mf8_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vloxseg4ei8_v_m)))
void vloxseg4ei8_v_u64m1_m(vuint64m1_t *, vuint64m1_t *, vuint64m1_t *, vuint64m1_t *, vbool64_t, vuint64m1_t, vuint64m1_t, vuint64m1_t, vuint64m1_t, const uint64_t *, vuint8mf8_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vloxseg4ei8_v)))
void vloxseg4ei8_v_u64m2(vuint64m2_t *, vuint64m2_t *, vuint64m2_t *, vuint64m2_t *, const uint64_t *, vuint8mf4_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vloxseg4ei8_v_m)))
void vloxseg4ei8_v_u64m2_m(vuint64m2_t *, vuint64m2_t *, vuint64m2_t *, vuint64m2_t *, vbool32_t, vuint64m2_t, vuint64m2_t, vuint64m2_t, vuint64m2_t, const uint64_t *, vuint8mf4_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vloxseg5ei8_v)))
void vloxseg5ei8_v_i64m1(vint64m1_t *, vint64m1_t *, vint64m1_t *, vint64m1_t *, vint64m1_t *, const int64_t *, vuint8mf8_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vloxseg5ei8_v_m)))
void vloxseg5ei8_v_i64m1_m(vint64m1_t *, vint64m1_t *, vint64m1_t *, vint64m1_t *, vint64m1_t *, vbool64_t, vint64m1_t, vint64m1_t, vint64m1_t, vint64m1_t, vint64m1_t, const int64_t *, vuint8mf8_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vloxseg5ei8_v)))
void vloxseg5ei8_v_u64m1(vuint64m1_t *, vuint64m1_t *, vuint64m1_t *, vuint64m1_t *, vuint64m1_t *, const uint64_t *, vuint8mf8_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vloxseg5ei8_v_m)))
void vloxseg5ei8_v_u64m1_m(vuint64m1_t *, vuint64m1_t *, vuint64m1_t *, vuint64m1_t *, vuint64m1_t *, vbool64_t, vuint64m1_t, vuint64m1_t, vuint64m1_t, vuint64m1_t, vuint64m1_t, const uint64_t *, vuint8mf8_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vloxseg6ei8_v)))
void vloxseg6ei8_v_i64m1(vint64m1_t *, vint64m1_t *, vint64m1_t *, vint64m1_t *, vint64m1_t *, vint64m1_t *, const int64_t *, vuint8mf8_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vloxseg6ei8_v_m)))
void vloxseg6ei8_v_i64m1_m(vint64m1_t *, vint64m1_t *, vint64m1_t *, vint64m1_t *, vint64m1_t *, vint64m1_t *, vbool64_t, vint64m1_t, vint64m1_t, vint64m1_t, vint64m1_t, vint64m1_t, vint64m1_t, const int64_t *, vuint8mf8_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vloxseg6ei8_v)))
void vloxseg6ei8_v_u64m1(vuint64m1_t *, vuint64m1_t *, vuint64m1_t *, vuint64m1_t *, vuint64m1_t *, vuint64m1_t *, const uint64_t *, vuint8mf8_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vloxseg6ei8_v_m)))
void vloxseg6ei8_v_u64m1_m(vuint64m1_t *, vuint64m1_t *, vuint64m1_t *, vuint64m1_t *, vuint64m1_t *, vuint64m1_t *, vbool64_t, vuint64m1_t, vuint64m1_t, vuint64m1_t, vuint64m1_t, vuint64m1_t, vuint64m1_t, const uint64_t *, vuint8mf8_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vloxseg7ei8_v)))
void vloxseg7ei8_v_i64m1(vint64m1_t *, vint64m1_t *, vint64m1_t *, vint64m1_t *, vint64m1_t *, vint64m1_t *, vint64m1_t *, const int64_t *, vuint8mf8_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vloxseg7ei8_v_m)))
void vloxseg7ei8_v_i64m1_m(vint64m1_t *, vint64m1_t *, vint64m1_t *, vint64m1_t *, vint64m1_t *, vint64m1_t *, vint64m1_t *, vbool64_t, vint64m1_t, vint64m1_t, vint64m1_t, vint64m1_t, vint64m1_t, vint64m1_t, vint64m1_t, const int64_t *, vuint8mf8_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vloxseg7ei8_v)))
void vloxseg7ei8_v_u64m1(vuint64m1_t *, vuint64m1_t *, vuint64m1_t *, vuint64m1_t *, vuint64m1_t *, vuint64m1_t *, vuint64m1_t *, const uint64_t *, vuint8mf8_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vloxseg7ei8_v_m)))
void vloxseg7ei8_v_u64m1_m(vuint64m1_t *, vuint64m1_t *, vuint64m1_t *, vuint64m1_t *, vuint64m1_t *, vuint64m1_t *, vuint64m1_t *, vbool64_t, vuint64m1_t, vuint64m1_t, vuint64m1_t, vuint64m1_t, vuint64m1_t, vuint64m1_t, vuint64m1_t, const uint64_t *, vuint8mf8_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vlse64_v)))
vint64m1_t vlse64_v_i64m1(const int64_t *, ptrdiff_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vlse64_v_m)))
vint64m1_t vlse64_v_i64m1_m(vbool64_t, vint64m1_t, const int64_t *, ptrdiff_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vlse64_v)))
vint64m2_t vlse64_v_i64m2(const int64_t *, ptrdiff_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vlse64_v_m)))
vint64m2_t vlse64_v_i64m2_m(vbool32_t, vint64m2_t, const int64_t *, ptrdiff_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vlse64_v)))
vint64m4_t vlse64_v_i64m4(const int64_t *, ptrdiff_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vlse64_v_m)))
vint64m4_t vlse64_v_i64m4_m(vbool16_t, vint64m4_t, const int64_t *, ptrdiff_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vlse64_v)))
vint64m8_t vlse64_v_i64m8(const int64_t *, ptrdiff_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vlse64_v_m)))
vint64m8_t vlse64_v_i64m8_m(vbool8_t, vint64m8_t, const int64_t *, ptrdiff_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vloxseg8ei8_v)))
void vloxseg8ei8_v_i64m1(vint64m1_t *, vint64m1_t *, vint64m1_t *, vint64m1_t *, vint64m1_t *, vint64m1_t *, vint64m1_t *, vint64m1_t *, const int64_t *, vuint8mf8_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vloxseg8ei8_v_m)))
void vloxseg8ei8_v_i64m1_m(vint64m1_t *, vint64m1_t *, vint64m1_t *, vint64m1_t *, vint64m1_t *, vint64m1_t *, vint64m1_t *, vint64m1_t *, vbool64_t, vint64m1_t, vint64m1_t, vint64m1_t, vint64m1_t, vint64m1_t, vint64m1_t, vint64m1_t, vint64m1_t, const int64_t *, vuint8mf8_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vloxseg8ei8_v)))
void vloxseg8ei8_v_u64m1(vuint64m1_t *, vuint64m1_t *, vuint64m1_t *, vuint64m1_t *, vuint64m1_t *, vuint64m1_t *, vuint64m1_t *, vuint64m1_t *, const uint64_t *, vuint8mf8_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vloxseg8ei8_v_m)))
void vloxseg8ei8_v_u64m1_m(vuint64m1_t *, vuint64m1_t *, vuint64m1_t *, vuint64m1_t *, vuint64m1_t *, vuint64m1_t *, vuint64m1_t *, vuint64m1_t *, vbool64_t, vuint64m1_t, vuint64m1_t, vuint64m1_t, vuint64m1_t, vuint64m1_t, vuint64m1_t, vuint64m1_t, vuint64m1_t, const uint64_t *, vuint8mf8_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vloxseg2ei16_v)))
void vloxseg2ei16_v_i64m1(vint64m1_t *, vint64m1_t *, const int64_t *, vuint16mf4_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vloxseg2ei16_v_m)))
void vloxseg2ei16_v_i64m1_m(vint64m1_t *, vint64m1_t *, vbool64_t, vint64m1_t, vint64m1_t, const int64_t *, vuint16mf4_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vloxseg2ei16_v)))
void vloxseg2ei16_v_i64m2(vint64m2_t *, vint64m2_t *, const int64_t *, vuint16mf2_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vloxseg2ei16_v_m)))
void vloxseg2ei16_v_i64m2_m(vint64m2_t *, vint64m2_t *, vbool32_t, vint64m2_t, vint64m2_t, const int64_t *, vuint16mf2_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vloxseg2ei16_v)))
void vloxseg2ei16_v_i64m4(vint64m4_t *, vint64m4_t *, const int64_t *, vuint16m1_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vloxseg2ei16_v_m)))
void vloxseg2ei16_v_i64m4_m(vint64m4_t *, vint64m4_t *, vbool16_t, vint64m4_t, vint64m4_t, const int64_t *, vuint16m1_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vloxseg2ei16_v)))
void vloxseg2ei16_v_u64m1(vuint64m1_t *, vuint64m1_t *, const uint64_t *, vuint16mf4_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vloxseg2ei16_v_m)))
void vloxseg2ei16_v_u64m1_m(vuint64m1_t *, vuint64m1_t *, vbool64_t, vuint64m1_t, vuint64m1_t, const uint64_t *, vuint16mf4_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vloxseg2ei16_v)))
void vloxseg2ei16_v_u64m2(vuint64m2_t *, vuint64m2_t *, const uint64_t *, vuint16mf2_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vloxseg2ei16_v_m)))
void vloxseg2ei16_v_u64m2_m(vuint64m2_t *, vuint64m2_t *, vbool32_t, vuint64m2_t, vuint64m2_t, const uint64_t *, vuint16mf2_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vloxseg2ei16_v)))
void vloxseg2ei16_v_u64m4(vuint64m4_t *, vuint64m4_t *, const uint64_t *, vuint16m1_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vloxseg2ei16_v_m)))
void vloxseg2ei16_v_u64m4_m(vuint64m4_t *, vuint64m4_t *, vbool16_t, vuint64m4_t, vuint64m4_t, const uint64_t *, vuint16m1_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vloxseg3ei16_v)))
void vloxseg3ei16_v_i64m1(vint64m1_t *, vint64m1_t *, vint64m1_t *, const int64_t *, vuint16mf4_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vloxseg3ei16_v_m)))
void vloxseg3ei16_v_i64m1_m(vint64m1_t *, vint64m1_t *, vint64m1_t *, vbool64_t, vint64m1_t, vint64m1_t, vint64m1_t, const int64_t *, vuint16mf4_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vloxseg3ei16_v)))
void vloxseg3ei16_v_i64m2(vint64m2_t *, vint64m2_t *, vint64m2_t *, const int64_t *, vuint16mf2_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vloxseg3ei16_v_m)))
void vloxseg3ei16_v_i64m2_m(vint64m2_t *, vint64m2_t *, vint64m2_t *, vbool32_t, vint64m2_t, vint64m2_t, vint64m2_t, const int64_t *, vuint16mf2_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vloxseg3ei16_v)))
void vloxseg3ei16_v_u64m1(vuint64m1_t *, vuint64m1_t *, vuint64m1_t *, const uint64_t *, vuint16mf4_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vloxseg3ei16_v_m)))
void vloxseg3ei16_v_u64m1_m(vuint64m1_t *, vuint64m1_t *, vuint64m1_t *, vbool64_t, vuint64m1_t, vuint64m1_t, vuint64m1_t, const uint64_t *, vuint16mf4_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vloxseg3ei16_v)))
void vloxseg3ei16_v_u64m2(vuint64m2_t *, vuint64m2_t *, vuint64m2_t *, const uint64_t *, vuint16mf2_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vloxseg3ei16_v_m)))
void vloxseg3ei16_v_u64m2_m(vuint64m2_t *, vuint64m2_t *, vuint64m2_t *, vbool32_t, vuint64m2_t, vuint64m2_t, vuint64m2_t, const uint64_t *, vuint16mf2_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vloxseg4ei16_v)))
void vloxseg4ei16_v_i64m1(vint64m1_t *, vint64m1_t *, vint64m1_t *, vint64m1_t *, const int64_t *, vuint16mf4_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vloxseg4ei16_v_m)))
void vloxseg4ei16_v_i64m1_m(vint64m1_t *, vint64m1_t *, vint64m1_t *, vint64m1_t *, vbool64_t, vint64m1_t, vint64m1_t, vint64m1_t, vint64m1_t, const int64_t *, vuint16mf4_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vloxseg4ei16_v)))
void vloxseg4ei16_v_i64m2(vint64m2_t *, vint64m2_t *, vint64m2_t *, vint64m2_t *, const int64_t *, vuint16mf2_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vloxseg4ei16_v_m)))
void vloxseg4ei16_v_i64m2_m(vint64m2_t *, vint64m2_t *, vint64m2_t *, vint64m2_t *, vbool32_t, vint64m2_t, vint64m2_t, vint64m2_t, vint64m2_t, const int64_t *, vuint16mf2_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vloxseg4ei16_v)))
void vloxseg4ei16_v_u64m1(vuint64m1_t *, vuint64m1_t *, vuint64m1_t *, vuint64m1_t *, const uint64_t *, vuint16mf4_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vloxseg4ei16_v_m)))
void vloxseg4ei16_v_u64m1_m(vuint64m1_t *, vuint64m1_t *, vuint64m1_t *, vuint64m1_t *, vbool64_t, vuint64m1_t, vuint64m1_t, vuint64m1_t, vuint64m1_t, const uint64_t *, vuint16mf4_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vloxseg4ei16_v)))
void vloxseg4ei16_v_u64m2(vuint64m2_t *, vuint64m2_t *, vuint64m2_t *, vuint64m2_t *, const uint64_t *, vuint16mf2_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vloxseg4ei16_v_m)))
void vloxseg4ei16_v_u64m2_m(vuint64m2_t *, vuint64m2_t *, vuint64m2_t *, vuint64m2_t *, vbool32_t, vuint64m2_t, vuint64m2_t, vuint64m2_t, vuint64m2_t, const uint64_t *, vuint16mf2_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vloxseg5ei16_v)))
void vloxseg5ei16_v_i64m1(vint64m1_t *, vint64m1_t *, vint64m1_t *, vint64m1_t *, vint64m1_t *, const int64_t *, vuint16mf4_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vloxseg5ei16_v_m)))
void vloxseg5ei16_v_i64m1_m(vint64m1_t *, vint64m1_t *, vint64m1_t *, vint64m1_t *, vint64m1_t *, vbool64_t, vint64m1_t, vint64m1_t, vint64m1_t, vint64m1_t, vint64m1_t, const int64_t *, vuint16mf4_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vloxseg5ei16_v)))
void vloxseg5ei16_v_u64m1(vuint64m1_t *, vuint64m1_t *, vuint64m1_t *, vuint64m1_t *, vuint64m1_t *, const uint64_t *, vuint16mf4_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vloxseg5ei16_v_m)))
void vloxseg5ei16_v_u64m1_m(vuint64m1_t *, vuint64m1_t *, vuint64m1_t *, vuint64m1_t *, vuint64m1_t *, vbool64_t, vuint64m1_t, vuint64m1_t, vuint64m1_t, vuint64m1_t, vuint64m1_t, const uint64_t *, vuint16mf4_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vlse64_v)))
vuint64m1_t vlse64_v_u64m1(const uint64_t *, ptrdiff_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vlse64_v_m)))
vuint64m1_t vlse64_v_u64m1_m(vbool64_t, vuint64m1_t, const uint64_t *, ptrdiff_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vlse64_v)))
vuint64m2_t vlse64_v_u64m2(const uint64_t *, ptrdiff_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vlse64_v_m)))
vuint64m2_t vlse64_v_u64m2_m(vbool32_t, vuint64m2_t, const uint64_t *, ptrdiff_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vlse64_v)))
vuint64m4_t vlse64_v_u64m4(const uint64_t *, ptrdiff_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vlse64_v_m)))
vuint64m4_t vlse64_v_u64m4_m(vbool16_t, vuint64m4_t, const uint64_t *, ptrdiff_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vlse64_v)))
vuint64m8_t vlse64_v_u64m8(const uint64_t *, ptrdiff_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vlse64_v_m)))
vuint64m8_t vlse64_v_u64m8_m(vbool8_t, vuint64m8_t, const uint64_t *, ptrdiff_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vloxseg6ei16_v)))
void vloxseg6ei16_v_i64m1(vint64m1_t *, vint64m1_t *, vint64m1_t *, vint64m1_t *, vint64m1_t *, vint64m1_t *, const int64_t *, vuint16mf4_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vloxseg6ei16_v_m)))
void vloxseg6ei16_v_i64m1_m(vint64m1_t *, vint64m1_t *, vint64m1_t *, vint64m1_t *, vint64m1_t *, vint64m1_t *, vbool64_t, vint64m1_t, vint64m1_t, vint64m1_t, vint64m1_t, vint64m1_t, vint64m1_t, const int64_t *, vuint16mf4_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vloxseg6ei16_v)))
void vloxseg6ei16_v_u64m1(vuint64m1_t *, vuint64m1_t *, vuint64m1_t *, vuint64m1_t *, vuint64m1_t *, vuint64m1_t *, const uint64_t *, vuint16mf4_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vloxseg6ei16_v_m)))
void vloxseg6ei16_v_u64m1_m(vuint64m1_t *, vuint64m1_t *, vuint64m1_t *, vuint64m1_t *, vuint64m1_t *, vuint64m1_t *, vbool64_t, vuint64m1_t, vuint64m1_t, vuint64m1_t, vuint64m1_t, vuint64m1_t, vuint64m1_t, const uint64_t *, vuint16mf4_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vloxseg7ei16_v)))
void vloxseg7ei16_v_i64m1(vint64m1_t *, vint64m1_t *, vint64m1_t *, vint64m1_t *, vint64m1_t *, vint64m1_t *, vint64m1_t *, const int64_t *, vuint16mf4_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vloxseg7ei16_v_m)))
void vloxseg7ei16_v_i64m1_m(vint64m1_t *, vint64m1_t *, vint64m1_t *, vint64m1_t *, vint64m1_t *, vint64m1_t *, vint64m1_t *, vbool64_t, vint64m1_t, vint64m1_t, vint64m1_t, vint64m1_t, vint64m1_t, vint64m1_t, vint64m1_t, const int64_t *, vuint16mf4_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vloxseg7ei16_v)))
void vloxseg7ei16_v_u64m1(vuint64m1_t *, vuint64m1_t *, vuint64m1_t *, vuint64m1_t *, vuint64m1_t *, vuint64m1_t *, vuint64m1_t *, const uint64_t *, vuint16mf4_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vloxseg7ei16_v_m)))
void vloxseg7ei16_v_u64m1_m(vuint64m1_t *, vuint64m1_t *, vuint64m1_t *, vuint64m1_t *, vuint64m1_t *, vuint64m1_t *, vuint64m1_t *, vbool64_t, vuint64m1_t, vuint64m1_t, vuint64m1_t, vuint64m1_t, vuint64m1_t, vuint64m1_t, vuint64m1_t, const uint64_t *, vuint16mf4_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vloxseg8ei16_v)))
void vloxseg8ei16_v_i64m1(vint64m1_t *, vint64m1_t *, vint64m1_t *, vint64m1_t *, vint64m1_t *, vint64m1_t *, vint64m1_t *, vint64m1_t *, const int64_t *, vuint16mf4_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vloxseg8ei16_v_m)))
void vloxseg8ei16_v_i64m1_m(vint64m1_t *, vint64m1_t *, vint64m1_t *, vint64m1_t *, vint64m1_t *, vint64m1_t *, vint64m1_t *, vint64m1_t *, vbool64_t, vint64m1_t, vint64m1_t, vint64m1_t, vint64m1_t, vint64m1_t, vint64m1_t, vint64m1_t, vint64m1_t, const int64_t *, vuint16mf4_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vloxseg8ei16_v)))
void vloxseg8ei16_v_u64m1(vuint64m1_t *, vuint64m1_t *, vuint64m1_t *, vuint64m1_t *, vuint64m1_t *, vuint64m1_t *, vuint64m1_t *, vuint64m1_t *, const uint64_t *, vuint16mf4_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vloxseg8ei16_v_m)))
void vloxseg8ei16_v_u64m1_m(vuint64m1_t *, vuint64m1_t *, vuint64m1_t *, vuint64m1_t *, vuint64m1_t *, vuint64m1_t *, vuint64m1_t *, vuint64m1_t *, vbool64_t, vuint64m1_t, vuint64m1_t, vuint64m1_t, vuint64m1_t, vuint64m1_t, vuint64m1_t, vuint64m1_t, vuint64m1_t, const uint64_t *, vuint16mf4_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vloxseg2ei32_v)))
void vloxseg2ei32_v_i64m1(vint64m1_t *, vint64m1_t *, const int64_t *, vuint32mf2_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vloxseg2ei32_v_m)))
void vloxseg2ei32_v_i64m1_m(vint64m1_t *, vint64m1_t *, vbool64_t, vint64m1_t, vint64m1_t, const int64_t *, vuint32mf2_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vloxseg2ei32_v)))
void vloxseg2ei32_v_i64m2(vint64m2_t *, vint64m2_t *, const int64_t *, vuint32m1_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vloxseg2ei32_v_m)))
void vloxseg2ei32_v_i64m2_m(vint64m2_t *, vint64m2_t *, vbool32_t, vint64m2_t, vint64m2_t, const int64_t *, vuint32m1_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vloxseg2ei32_v)))
void vloxseg2ei32_v_i64m4(vint64m4_t *, vint64m4_t *, const int64_t *, vuint32m2_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vloxseg2ei32_v_m)))
void vloxseg2ei32_v_i64m4_m(vint64m4_t *, vint64m4_t *, vbool16_t, vint64m4_t, vint64m4_t, const int64_t *, vuint32m2_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vloxseg2ei32_v)))
void vloxseg2ei32_v_u64m1(vuint64m1_t *, vuint64m1_t *, const uint64_t *, vuint32mf2_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vloxseg2ei32_v_m)))
void vloxseg2ei32_v_u64m1_m(vuint64m1_t *, vuint64m1_t *, vbool64_t, vuint64m1_t, vuint64m1_t, const uint64_t *, vuint32mf2_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vloxseg2ei32_v)))
void vloxseg2ei32_v_u64m2(vuint64m2_t *, vuint64m2_t *, const uint64_t *, vuint32m1_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vloxseg2ei32_v_m)))
void vloxseg2ei32_v_u64m2_m(vuint64m2_t *, vuint64m2_t *, vbool32_t, vuint64m2_t, vuint64m2_t, const uint64_t *, vuint32m1_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vloxseg2ei32_v)))
void vloxseg2ei32_v_u64m4(vuint64m4_t *, vuint64m4_t *, const uint64_t *, vuint32m2_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vloxseg2ei32_v_m)))
void vloxseg2ei32_v_u64m4_m(vuint64m4_t *, vuint64m4_t *, vbool16_t, vuint64m4_t, vuint64m4_t, const uint64_t *, vuint32m2_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vloxseg3ei32_v)))
void vloxseg3ei32_v_i64m1(vint64m1_t *, vint64m1_t *, vint64m1_t *, const int64_t *, vuint32mf2_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vloxseg3ei32_v_m)))
void vloxseg3ei32_v_i64m1_m(vint64m1_t *, vint64m1_t *, vint64m1_t *, vbool64_t, vint64m1_t, vint64m1_t, vint64m1_t, const int64_t *, vuint32mf2_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vloxseg3ei32_v)))
void vloxseg3ei32_v_i64m2(vint64m2_t *, vint64m2_t *, vint64m2_t *, const int64_t *, vuint32m1_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vloxseg3ei32_v_m)))
void vloxseg3ei32_v_i64m2_m(vint64m2_t *, vint64m2_t *, vint64m2_t *, vbool32_t, vint64m2_t, vint64m2_t, vint64m2_t, const int64_t *, vuint32m1_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vloxseg3ei32_v)))
void vloxseg3ei32_v_u64m1(vuint64m1_t *, vuint64m1_t *, vuint64m1_t *, const uint64_t *, vuint32mf2_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vloxseg3ei32_v_m)))
void vloxseg3ei32_v_u64m1_m(vuint64m1_t *, vuint64m1_t *, vuint64m1_t *, vbool64_t, vuint64m1_t, vuint64m1_t, vuint64m1_t, const uint64_t *, vuint32mf2_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vloxseg3ei32_v)))
void vloxseg3ei32_v_u64m2(vuint64m2_t *, vuint64m2_t *, vuint64m2_t *, const uint64_t *, vuint32m1_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vloxseg3ei32_v_m)))
void vloxseg3ei32_v_u64m2_m(vuint64m2_t *, vuint64m2_t *, vuint64m2_t *, vbool32_t, vuint64m2_t, vuint64m2_t, vuint64m2_t, const uint64_t *, vuint32m1_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vloxseg4ei32_v)))
void vloxseg4ei32_v_i64m1(vint64m1_t *, vint64m1_t *, vint64m1_t *, vint64m1_t *, const int64_t *, vuint32mf2_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vloxseg4ei32_v_m)))
void vloxseg4ei32_v_i64m1_m(vint64m1_t *, vint64m1_t *, vint64m1_t *, vint64m1_t *, vbool64_t, vint64m1_t, vint64m1_t, vint64m1_t, vint64m1_t, const int64_t *, vuint32mf2_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vloxseg4ei32_v)))
void vloxseg4ei32_v_i64m2(vint64m2_t *, vint64m2_t *, vint64m2_t *, vint64m2_t *, const int64_t *, vuint32m1_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vloxseg4ei32_v_m)))
void vloxseg4ei32_v_i64m2_m(vint64m2_t *, vint64m2_t *, vint64m2_t *, vint64m2_t *, vbool32_t, vint64m2_t, vint64m2_t, vint64m2_t, vint64m2_t, const int64_t *, vuint32m1_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vloxseg4ei32_v)))
void vloxseg4ei32_v_u64m1(vuint64m1_t *, vuint64m1_t *, vuint64m1_t *, vuint64m1_t *, const uint64_t *, vuint32mf2_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vloxseg4ei32_v_m)))
void vloxseg4ei32_v_u64m1_m(vuint64m1_t *, vuint64m1_t *, vuint64m1_t *, vuint64m1_t *, vbool64_t, vuint64m1_t, vuint64m1_t, vuint64m1_t, vuint64m1_t, const uint64_t *, vuint32mf2_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vloxseg4ei32_v)))
void vloxseg4ei32_v_u64m2(vuint64m2_t *, vuint64m2_t *, vuint64m2_t *, vuint64m2_t *, const uint64_t *, vuint32m1_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vloxseg4ei32_v_m)))
void vloxseg4ei32_v_u64m2_m(vuint64m2_t *, vuint64m2_t *, vuint64m2_t *, vuint64m2_t *, vbool32_t, vuint64m2_t, vuint64m2_t, vuint64m2_t, vuint64m2_t, const uint64_t *, vuint32m1_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vloxseg5ei32_v)))
void vloxseg5ei32_v_i64m1(vint64m1_t *, vint64m1_t *, vint64m1_t *, vint64m1_t *, vint64m1_t *, const int64_t *, vuint32mf2_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vloxseg5ei32_v_m)))
void vloxseg5ei32_v_i64m1_m(vint64m1_t *, vint64m1_t *, vint64m1_t *, vint64m1_t *, vint64m1_t *, vbool64_t, vint64m1_t, vint64m1_t, vint64m1_t, vint64m1_t, vint64m1_t, const int64_t *, vuint32mf2_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vloxseg5ei32_v)))
void vloxseg5ei32_v_u64m1(vuint64m1_t *, vuint64m1_t *, vuint64m1_t *, vuint64m1_t *, vuint64m1_t *, const uint64_t *, vuint32mf2_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vloxseg5ei32_v_m)))
void vloxseg5ei32_v_u64m1_m(vuint64m1_t *, vuint64m1_t *, vuint64m1_t *, vuint64m1_t *, vuint64m1_t *, vbool64_t, vuint64m1_t, vuint64m1_t, vuint64m1_t, vuint64m1_t, vuint64m1_t, const uint64_t *, vuint32mf2_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vloxseg6ei32_v)))
void vloxseg6ei32_v_i64m1(vint64m1_t *, vint64m1_t *, vint64m1_t *, vint64m1_t *, vint64m1_t *, vint64m1_t *, const int64_t *, vuint32mf2_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vloxseg6ei32_v_m)))
void vloxseg6ei32_v_i64m1_m(vint64m1_t *, vint64m1_t *, vint64m1_t *, vint64m1_t *, vint64m1_t *, vint64m1_t *, vbool64_t, vint64m1_t, vint64m1_t, vint64m1_t, vint64m1_t, vint64m1_t, vint64m1_t, const int64_t *, vuint32mf2_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vloxseg6ei32_v)))
void vloxseg6ei32_v_u64m1(vuint64m1_t *, vuint64m1_t *, vuint64m1_t *, vuint64m1_t *, vuint64m1_t *, vuint64m1_t *, const uint64_t *, vuint32mf2_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vloxseg6ei32_v_m)))
void vloxseg6ei32_v_u64m1_m(vuint64m1_t *, vuint64m1_t *, vuint64m1_t *, vuint64m1_t *, vuint64m1_t *, vuint64m1_t *, vbool64_t, vuint64m1_t, vuint64m1_t, vuint64m1_t, vuint64m1_t, vuint64m1_t, vuint64m1_t, const uint64_t *, vuint32mf2_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vloxseg7ei32_v)))
void vloxseg7ei32_v_i64m1(vint64m1_t *, vint64m1_t *, vint64m1_t *, vint64m1_t *, vint64m1_t *, vint64m1_t *, vint64m1_t *, const int64_t *, vuint32mf2_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vloxseg7ei32_v_m)))
void vloxseg7ei32_v_i64m1_m(vint64m1_t *, vint64m1_t *, vint64m1_t *, vint64m1_t *, vint64m1_t *, vint64m1_t *, vint64m1_t *, vbool64_t, vint64m1_t, vint64m1_t, vint64m1_t, vint64m1_t, vint64m1_t, vint64m1_t, vint64m1_t, const int64_t *, vuint32mf2_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vloxseg7ei32_v)))
void vloxseg7ei32_v_u64m1(vuint64m1_t *, vuint64m1_t *, vuint64m1_t *, vuint64m1_t *, vuint64m1_t *, vuint64m1_t *, vuint64m1_t *, const uint64_t *, vuint32mf2_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vloxseg7ei32_v_m)))
void vloxseg7ei32_v_u64m1_m(vuint64m1_t *, vuint64m1_t *, vuint64m1_t *, vuint64m1_t *, vuint64m1_t *, vuint64m1_t *, vuint64m1_t *, vbool64_t, vuint64m1_t, vuint64m1_t, vuint64m1_t, vuint64m1_t, vuint64m1_t, vuint64m1_t, vuint64m1_t, const uint64_t *, vuint32mf2_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vloxseg8ei32_v)))
void vloxseg8ei32_v_i64m1(vint64m1_t *, vint64m1_t *, vint64m1_t *, vint64m1_t *, vint64m1_t *, vint64m1_t *, vint64m1_t *, vint64m1_t *, const int64_t *, vuint32mf2_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vloxseg8ei32_v_m)))
void vloxseg8ei32_v_i64m1_m(vint64m1_t *, vint64m1_t *, vint64m1_t *, vint64m1_t *, vint64m1_t *, vint64m1_t *, vint64m1_t *, vint64m1_t *, vbool64_t, vint64m1_t, vint64m1_t, vint64m1_t, vint64m1_t, vint64m1_t, vint64m1_t, vint64m1_t, vint64m1_t, const int64_t *, vuint32mf2_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vloxseg8ei32_v)))
void vloxseg8ei32_v_u64m1(vuint64m1_t *, vuint64m1_t *, vuint64m1_t *, vuint64m1_t *, vuint64m1_t *, vuint64m1_t *, vuint64m1_t *, vuint64m1_t *, const uint64_t *, vuint32mf2_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vloxseg8ei32_v_m)))
void vloxseg8ei32_v_u64m1_m(vuint64m1_t *, vuint64m1_t *, vuint64m1_t *, vuint64m1_t *, vuint64m1_t *, vuint64m1_t *, vuint64m1_t *, vuint64m1_t *, vbool64_t, vuint64m1_t, vuint64m1_t, vuint64m1_t, vuint64m1_t, vuint64m1_t, vuint64m1_t, vuint64m1_t, vuint64m1_t, const uint64_t *, vuint32mf2_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vloxseg2ei64_v)))
void vloxseg2ei64_v_i64m1(vint64m1_t *, vint64m1_t *, const int64_t *, vuint64m1_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vloxseg2ei64_v_m)))
void vloxseg2ei64_v_i64m1_m(vint64m1_t *, vint64m1_t *, vbool64_t, vint64m1_t, vint64m1_t, const int64_t *, vuint64m1_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vloxseg2ei64_v)))
void vloxseg2ei64_v_i64m2(vint64m2_t *, vint64m2_t *, const int64_t *, vuint64m2_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vloxseg2ei64_v_m)))
void vloxseg2ei64_v_i64m2_m(vint64m2_t *, vint64m2_t *, vbool32_t, vint64m2_t, vint64m2_t, const int64_t *, vuint64m2_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vloxseg2ei64_v)))
void vloxseg2ei64_v_i64m4(vint64m4_t *, vint64m4_t *, const int64_t *, vuint64m4_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vloxseg2ei64_v_m)))
void vloxseg2ei64_v_i64m4_m(vint64m4_t *, vint64m4_t *, vbool16_t, vint64m4_t, vint64m4_t, const int64_t *, vuint64m4_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vloxseg2ei64_v)))
void vloxseg2ei64_v_u64m1(vuint64m1_t *, vuint64m1_t *, const uint64_t *, vuint64m1_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vloxseg2ei64_v_m)))
void vloxseg2ei64_v_u64m1_m(vuint64m1_t *, vuint64m1_t *, vbool64_t, vuint64m1_t, vuint64m1_t, const uint64_t *, vuint64m1_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vloxseg2ei64_v)))
void vloxseg2ei64_v_u64m2(vuint64m2_t *, vuint64m2_t *, const uint64_t *, vuint64m2_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vloxseg2ei64_v_m)))
void vloxseg2ei64_v_u64m2_m(vuint64m2_t *, vuint64m2_t *, vbool32_t, vuint64m2_t, vuint64m2_t, const uint64_t *, vuint64m2_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vloxseg2ei64_v)))
void vloxseg2ei64_v_u64m4(vuint64m4_t *, vuint64m4_t *, const uint64_t *, vuint64m4_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vloxseg2ei64_v_m)))
void vloxseg2ei64_v_u64m4_m(vuint64m4_t *, vuint64m4_t *, vbool16_t, vuint64m4_t, vuint64m4_t, const uint64_t *, vuint64m4_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vloxseg3ei64_v)))
void vloxseg3ei64_v_i64m1(vint64m1_t *, vint64m1_t *, vint64m1_t *, const int64_t *, vuint64m1_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vloxseg3ei64_v_m)))
void vloxseg3ei64_v_i64m1_m(vint64m1_t *, vint64m1_t *, vint64m1_t *, vbool64_t, vint64m1_t, vint64m1_t, vint64m1_t, const int64_t *, vuint64m1_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vloxseg3ei64_v)))
void vloxseg3ei64_v_i64m2(vint64m2_t *, vint64m2_t *, vint64m2_t *, const int64_t *, vuint64m2_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vloxseg3ei64_v_m)))
void vloxseg3ei64_v_i64m2_m(vint64m2_t *, vint64m2_t *, vint64m2_t *, vbool32_t, vint64m2_t, vint64m2_t, vint64m2_t, const int64_t *, vuint64m2_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vloxseg3ei64_v)))
void vloxseg3ei64_v_u64m1(vuint64m1_t *, vuint64m1_t *, vuint64m1_t *, const uint64_t *, vuint64m1_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vloxseg3ei64_v_m)))
void vloxseg3ei64_v_u64m1_m(vuint64m1_t *, vuint64m1_t *, vuint64m1_t *, vbool64_t, vuint64m1_t, vuint64m1_t, vuint64m1_t, const uint64_t *, vuint64m1_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vloxseg3ei64_v)))
void vloxseg3ei64_v_u64m2(vuint64m2_t *, vuint64m2_t *, vuint64m2_t *, const uint64_t *, vuint64m2_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vloxseg3ei64_v_m)))
void vloxseg3ei64_v_u64m2_m(vuint64m2_t *, vuint64m2_t *, vuint64m2_t *, vbool32_t, vuint64m2_t, vuint64m2_t, vuint64m2_t, const uint64_t *, vuint64m2_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vloxseg4ei64_v)))
void vloxseg4ei64_v_i64m1(vint64m1_t *, vint64m1_t *, vint64m1_t *, vint64m1_t *, const int64_t *, vuint64m1_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vloxseg4ei64_v_m)))
void vloxseg4ei64_v_i64m1_m(vint64m1_t *, vint64m1_t *, vint64m1_t *, vint64m1_t *, vbool64_t, vint64m1_t, vint64m1_t, vint64m1_t, vint64m1_t, const int64_t *, vuint64m1_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vloxseg4ei64_v)))
void vloxseg4ei64_v_i64m2(vint64m2_t *, vint64m2_t *, vint64m2_t *, vint64m2_t *, const int64_t *, vuint64m2_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vloxseg4ei64_v_m)))
void vloxseg4ei64_v_i64m2_m(vint64m2_t *, vint64m2_t *, vint64m2_t *, vint64m2_t *, vbool32_t, vint64m2_t, vint64m2_t, vint64m2_t, vint64m2_t, const int64_t *, vuint64m2_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vloxseg4ei64_v)))
void vloxseg4ei64_v_u64m1(vuint64m1_t *, vuint64m1_t *, vuint64m1_t *, vuint64m1_t *, const uint64_t *, vuint64m1_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vloxseg4ei64_v_m)))
void vloxseg4ei64_v_u64m1_m(vuint64m1_t *, vuint64m1_t *, vuint64m1_t *, vuint64m1_t *, vbool64_t, vuint64m1_t, vuint64m1_t, vuint64m1_t, vuint64m1_t, const uint64_t *, vuint64m1_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vloxseg4ei64_v)))
void vloxseg4ei64_v_u64m2(vuint64m2_t *, vuint64m2_t *, vuint64m2_t *, vuint64m2_t *, const uint64_t *, vuint64m2_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vloxseg4ei64_v_m)))
void vloxseg4ei64_v_u64m2_m(vuint64m2_t *, vuint64m2_t *, vuint64m2_t *, vuint64m2_t *, vbool32_t, vuint64m2_t, vuint64m2_t, vuint64m2_t, vuint64m2_t, const uint64_t *, vuint64m2_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vloxseg5ei64_v)))
void vloxseg5ei64_v_i64m1(vint64m1_t *, vint64m1_t *, vint64m1_t *, vint64m1_t *, vint64m1_t *, const int64_t *, vuint64m1_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vloxseg5ei64_v_m)))
void vloxseg5ei64_v_i64m1_m(vint64m1_t *, vint64m1_t *, vint64m1_t *, vint64m1_t *, vint64m1_t *, vbool64_t, vint64m1_t, vint64m1_t, vint64m1_t, vint64m1_t, vint64m1_t, const int64_t *, vuint64m1_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vloxseg5ei64_v)))
void vloxseg5ei64_v_u64m1(vuint64m1_t *, vuint64m1_t *, vuint64m1_t *, vuint64m1_t *, vuint64m1_t *, const uint64_t *, vuint64m1_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vloxseg5ei64_v_m)))
void vloxseg5ei64_v_u64m1_m(vuint64m1_t *, vuint64m1_t *, vuint64m1_t *, vuint64m1_t *, vuint64m1_t *, vbool64_t, vuint64m1_t, vuint64m1_t, vuint64m1_t, vuint64m1_t, vuint64m1_t, const uint64_t *, vuint64m1_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vloxseg6ei64_v)))
void vloxseg6ei64_v_i64m1(vint64m1_t *, vint64m1_t *, vint64m1_t *, vint64m1_t *, vint64m1_t *, vint64m1_t *, const int64_t *, vuint64m1_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vloxseg6ei64_v_m)))
void vloxseg6ei64_v_i64m1_m(vint64m1_t *, vint64m1_t *, vint64m1_t *, vint64m1_t *, vint64m1_t *, vint64m1_t *, vbool64_t, vint64m1_t, vint64m1_t, vint64m1_t, vint64m1_t, vint64m1_t, vint64m1_t, const int64_t *, vuint64m1_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vloxseg6ei64_v)))
void vloxseg6ei64_v_u64m1(vuint64m1_t *, vuint64m1_t *, vuint64m1_t *, vuint64m1_t *, vuint64m1_t *, vuint64m1_t *, const uint64_t *, vuint64m1_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vloxseg6ei64_v_m)))
void vloxseg6ei64_v_u64m1_m(vuint64m1_t *, vuint64m1_t *, vuint64m1_t *, vuint64m1_t *, vuint64m1_t *, vuint64m1_t *, vbool64_t, vuint64m1_t, vuint64m1_t, vuint64m1_t, vuint64m1_t, vuint64m1_t, vuint64m1_t, const uint64_t *, vuint64m1_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vloxseg7ei64_v)))
void vloxseg7ei64_v_i64m1(vint64m1_t *, vint64m1_t *, vint64m1_t *, vint64m1_t *, vint64m1_t *, vint64m1_t *, vint64m1_t *, const int64_t *, vuint64m1_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vloxseg7ei64_v_m)))
void vloxseg7ei64_v_i64m1_m(vint64m1_t *, vint64m1_t *, vint64m1_t *, vint64m1_t *, vint64m1_t *, vint64m1_t *, vint64m1_t *, vbool64_t, vint64m1_t, vint64m1_t, vint64m1_t, vint64m1_t, vint64m1_t, vint64m1_t, vint64m1_t, const int64_t *, vuint64m1_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vloxseg7ei64_v)))
void vloxseg7ei64_v_u64m1(vuint64m1_t *, vuint64m1_t *, vuint64m1_t *, vuint64m1_t *, vuint64m1_t *, vuint64m1_t *, vuint64m1_t *, const uint64_t *, vuint64m1_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vloxseg7ei64_v_m)))
void vloxseg7ei64_v_u64m1_m(vuint64m1_t *, vuint64m1_t *, vuint64m1_t *, vuint64m1_t *, vuint64m1_t *, vuint64m1_t *, vuint64m1_t *, vbool64_t, vuint64m1_t, vuint64m1_t, vuint64m1_t, vuint64m1_t, vuint64m1_t, vuint64m1_t, vuint64m1_t, const uint64_t *, vuint64m1_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vloxseg8ei64_v)))
void vloxseg8ei64_v_i64m1(vint64m1_t *, vint64m1_t *, vint64m1_t *, vint64m1_t *, vint64m1_t *, vint64m1_t *, vint64m1_t *, vint64m1_t *, const int64_t *, vuint64m1_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vloxseg8ei64_v_m)))
void vloxseg8ei64_v_i64m1_m(vint64m1_t *, vint64m1_t *, vint64m1_t *, vint64m1_t *, vint64m1_t *, vint64m1_t *, vint64m1_t *, vint64m1_t *, vbool64_t, vint64m1_t, vint64m1_t, vint64m1_t, vint64m1_t, vint64m1_t, vint64m1_t, vint64m1_t, vint64m1_t, const int64_t *, vuint64m1_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vloxseg8ei64_v)))
void vloxseg8ei64_v_u64m1(vuint64m1_t *, vuint64m1_t *, vuint64m1_t *, vuint64m1_t *, vuint64m1_t *, vuint64m1_t *, vuint64m1_t *, vuint64m1_t *, const uint64_t *, vuint64m1_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vloxseg8ei64_v_m)))
void vloxseg8ei64_v_u64m1_m(vuint64m1_t *, vuint64m1_t *, vuint64m1_t *, vuint64m1_t *, vuint64m1_t *, vuint64m1_t *, vuint64m1_t *, vuint64m1_t *, vbool64_t, vuint64m1_t, vuint64m1_t, vuint64m1_t, vuint64m1_t, vuint64m1_t, vuint64m1_t, vuint64m1_t, vuint64m1_t, const uint64_t *, vuint64m1_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vsse64_v)))
void vsse64_v_i64m1(int64_t *, ptrdiff_t, vint64m1_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vsse64_v_m)))
void vsse64_v_i64m1_m(vbool64_t, int64_t *, ptrdiff_t, vint64m1_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vsse64_v)))
void vsse64_v_i64m2(int64_t *, ptrdiff_t, vint64m2_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vsse64_v_m)))
void vsse64_v_i64m2_m(vbool32_t, int64_t *, ptrdiff_t, vint64m2_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vsse64_v)))
void vsse64_v_i64m4(int64_t *, ptrdiff_t, vint64m4_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vsse64_v_m)))
void vsse64_v_i64m4_m(vbool16_t, int64_t *, ptrdiff_t, vint64m4_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vsse64_v)))
void vsse64_v_i64m8(int64_t *, ptrdiff_t, vint64m8_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vsse64_v_m)))
void vsse64_v_i64m8_m(vbool8_t, int64_t *, ptrdiff_t, vint64m8_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vsse64_v)))
void vsse64_v_u64m1(uint64_t *, ptrdiff_t, vuint64m1_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vsse64_v_m)))
void vsse64_v_u64m1_m(vbool64_t, uint64_t *, ptrdiff_t, vuint64m1_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vsse64_v)))
void vsse64_v_u64m2(uint64_t *, ptrdiff_t, vuint64m2_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vsse64_v_m)))
void vsse64_v_u64m2_m(vbool32_t, uint64_t *, ptrdiff_t, vuint64m2_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vsse64_v)))
void vsse64_v_u64m4(uint64_t *, ptrdiff_t, vuint64m4_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vsse64_v_m)))
void vsse64_v_u64m4_m(vbool16_t, uint64_t *, ptrdiff_t, vuint64m4_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vsse64_v)))
void vsse64_v_u64m8(uint64_t *, ptrdiff_t, vuint64m8_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vsse64_v_m)))
void vsse64_v_u64m8_m(vbool8_t, uint64_t *, ptrdiff_t, vuint64m8_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vsseg2e64_v)))
void vsseg2e64_v_i64m1(int64_t *, vint64m1_t, vint64m1_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vsseg2e64_v_m)))
void vsseg2e64_v_i64m1_m(vbool64_t, int64_t *, vint64m1_t, vint64m1_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vsseg2e64_v)))
void vsseg2e64_v_i64m2(int64_t *, vint64m2_t, vint64m2_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vsseg2e64_v_m)))
void vsseg2e64_v_i64m2_m(vbool32_t, int64_t *, vint64m2_t, vint64m2_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vsseg2e64_v)))
void vsseg2e64_v_i64m4(int64_t *, vint64m4_t, vint64m4_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vsseg2e64_v_m)))
void vsseg2e64_v_i64m4_m(vbool16_t, int64_t *, vint64m4_t, vint64m4_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vsseg2e64_v)))
void vsseg2e64_v_u64m1(uint64_t *, vuint64m1_t, vuint64m1_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vsseg2e64_v_m)))
void vsseg2e64_v_u64m1_m(vbool64_t, uint64_t *, vuint64m1_t, vuint64m1_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vsseg2e64_v)))
void vsseg2e64_v_u64m2(uint64_t *, vuint64m2_t, vuint64m2_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vsseg2e64_v_m)))
void vsseg2e64_v_u64m2_m(vbool32_t, uint64_t *, vuint64m2_t, vuint64m2_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vsseg2e64_v)))
void vsseg2e64_v_u64m4(uint64_t *, vuint64m4_t, vuint64m4_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vsseg2e64_v_m)))
void vsseg2e64_v_u64m4_m(vbool16_t, uint64_t *, vuint64m4_t, vuint64m4_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vsseg3e64_v)))
void vsseg3e64_v_i64m1(int64_t *, vint64m1_t, vint64m1_t, vint64m1_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vsseg3e64_v_m)))
void vsseg3e64_v_i64m1_m(vbool64_t, int64_t *, vint64m1_t, vint64m1_t, vint64m1_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vsseg3e64_v)))
void vsseg3e64_v_i64m2(int64_t *, vint64m2_t, vint64m2_t, vint64m2_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vsseg3e64_v_m)))
void vsseg3e64_v_i64m2_m(vbool32_t, int64_t *, vint64m2_t, vint64m2_t, vint64m2_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vsseg3e64_v)))
void vsseg3e64_v_u64m1(uint64_t *, vuint64m1_t, vuint64m1_t, vuint64m1_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vsseg3e64_v_m)))
void vsseg3e64_v_u64m1_m(vbool64_t, uint64_t *, vuint64m1_t, vuint64m1_t, vuint64m1_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vsseg3e64_v)))
void vsseg3e64_v_u64m2(uint64_t *, vuint64m2_t, vuint64m2_t, vuint64m2_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vsseg3e64_v_m)))
void vsseg3e64_v_u64m2_m(vbool32_t, uint64_t *, vuint64m2_t, vuint64m2_t, vuint64m2_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vsseg4e64_v)))
void vsseg4e64_v_i64m1(int64_t *, vint64m1_t, vint64m1_t, vint64m1_t, vint64m1_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vsseg4e64_v_m)))
void vsseg4e64_v_i64m1_m(vbool64_t, int64_t *, vint64m1_t, vint64m1_t, vint64m1_t, vint64m1_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vsseg4e64_v)))
void vsseg4e64_v_i64m2(int64_t *, vint64m2_t, vint64m2_t, vint64m2_t, vint64m2_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vsseg4e64_v_m)))
void vsseg4e64_v_i64m2_m(vbool32_t, int64_t *, vint64m2_t, vint64m2_t, vint64m2_t, vint64m2_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vsseg4e64_v)))
void vsseg4e64_v_u64m1(uint64_t *, vuint64m1_t, vuint64m1_t, vuint64m1_t, vuint64m1_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vsseg4e64_v_m)))
void vsseg4e64_v_u64m1_m(vbool64_t, uint64_t *, vuint64m1_t, vuint64m1_t, vuint64m1_t, vuint64m1_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vsseg4e64_v)))
void vsseg4e64_v_u64m2(uint64_t *, vuint64m2_t, vuint64m2_t, vuint64m2_t, vuint64m2_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vsseg4e64_v_m)))
void vsseg4e64_v_u64m2_m(vbool32_t, uint64_t *, vuint64m2_t, vuint64m2_t, vuint64m2_t, vuint64m2_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vsseg5e64_v)))
void vsseg5e64_v_i64m1(int64_t *, vint64m1_t, vint64m1_t, vint64m1_t, vint64m1_t, vint64m1_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vsseg5e64_v_m)))
void vsseg5e64_v_i64m1_m(vbool64_t, int64_t *, vint64m1_t, vint64m1_t, vint64m1_t, vint64m1_t, vint64m1_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vsseg5e64_v)))
void vsseg5e64_v_u64m1(uint64_t *, vuint64m1_t, vuint64m1_t, vuint64m1_t, vuint64m1_t, vuint64m1_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vsseg5e64_v_m)))
void vsseg5e64_v_u64m1_m(vbool64_t, uint64_t *, vuint64m1_t, vuint64m1_t, vuint64m1_t, vuint64m1_t, vuint64m1_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vsseg6e64_v)))
void vsseg6e64_v_i64m1(int64_t *, vint64m1_t, vint64m1_t, vint64m1_t, vint64m1_t, vint64m1_t, vint64m1_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vsseg6e64_v_m)))
void vsseg6e64_v_i64m1_m(vbool64_t, int64_t *, vint64m1_t, vint64m1_t, vint64m1_t, vint64m1_t, vint64m1_t, vint64m1_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vsseg6e64_v)))
void vsseg6e64_v_u64m1(uint64_t *, vuint64m1_t, vuint64m1_t, vuint64m1_t, vuint64m1_t, vuint64m1_t, vuint64m1_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vsseg6e64_v_m)))
void vsseg6e64_v_u64m1_m(vbool64_t, uint64_t *, vuint64m1_t, vuint64m1_t, vuint64m1_t, vuint64m1_t, vuint64m1_t, vuint64m1_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vsseg7e64_v)))
void vsseg7e64_v_i64m1(int64_t *, vint64m1_t, vint64m1_t, vint64m1_t, vint64m1_t, vint64m1_t, vint64m1_t, vint64m1_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vsseg7e64_v_m)))
void vsseg7e64_v_i64m1_m(vbool64_t, int64_t *, vint64m1_t, vint64m1_t, vint64m1_t, vint64m1_t, vint64m1_t, vint64m1_t, vint64m1_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vsseg7e64_v)))
void vsseg7e64_v_u64m1(uint64_t *, vuint64m1_t, vuint64m1_t, vuint64m1_t, vuint64m1_t, vuint64m1_t, vuint64m1_t, vuint64m1_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vsseg7e64_v_m)))
void vsseg7e64_v_u64m1_m(vbool64_t, uint64_t *, vuint64m1_t, vuint64m1_t, vuint64m1_t, vuint64m1_t, vuint64m1_t, vuint64m1_t, vuint64m1_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vsseg8e64_v)))
void vsseg8e64_v_i64m1(int64_t *, vint64m1_t, vint64m1_t, vint64m1_t, vint64m1_t, vint64m1_t, vint64m1_t, vint64m1_t, vint64m1_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vsseg8e64_v_m)))
void vsseg8e64_v_i64m1_m(vbool64_t, int64_t *, vint64m1_t, vint64m1_t, vint64m1_t, vint64m1_t, vint64m1_t, vint64m1_t, vint64m1_t, vint64m1_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vsseg8e64_v)))
void vsseg8e64_v_u64m1(uint64_t *, vuint64m1_t, vuint64m1_t, vuint64m1_t, vuint64m1_t, vuint64m1_t, vuint64m1_t, vuint64m1_t, vuint64m1_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vsseg8e64_v_m)))
void vsseg8e64_v_u64m1_m(vbool64_t, uint64_t *, vuint64m1_t, vuint64m1_t, vuint64m1_t, vuint64m1_t, vuint64m1_t, vuint64m1_t, vuint64m1_t, vuint64m1_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vssseg2e64_v)))
void vssseg2e64_v_i64m1(int64_t *, ptrdiff_t, vint64m1_t, vint64m1_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vssseg2e64_v_m)))
void vssseg2e64_v_i64m1_m(vbool64_t, int64_t *, ptrdiff_t, vint64m1_t, vint64m1_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vssseg2e64_v)))
void vssseg2e64_v_i64m2(int64_t *, ptrdiff_t, vint64m2_t, vint64m2_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vssseg2e64_v_m)))
void vssseg2e64_v_i64m2_m(vbool32_t, int64_t *, ptrdiff_t, vint64m2_t, vint64m2_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vssseg2e64_v)))
void vssseg2e64_v_i64m4(int64_t *, ptrdiff_t, vint64m4_t, vint64m4_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vssseg2e64_v_m)))
void vssseg2e64_v_i64m4_m(vbool16_t, int64_t *, ptrdiff_t, vint64m4_t, vint64m4_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vssseg2e64_v)))
void vssseg2e64_v_u64m1(uint64_t *, ptrdiff_t, vuint64m1_t, vuint64m1_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vssseg2e64_v_m)))
void vssseg2e64_v_u64m1_m(vbool64_t, uint64_t *, ptrdiff_t, vuint64m1_t, vuint64m1_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vssseg2e64_v)))
void vssseg2e64_v_u64m2(uint64_t *, ptrdiff_t, vuint64m2_t, vuint64m2_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vssseg2e64_v_m)))
void vssseg2e64_v_u64m2_m(vbool32_t, uint64_t *, ptrdiff_t, vuint64m2_t, vuint64m2_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vssseg2e64_v)))
void vssseg2e64_v_u64m4(uint64_t *, ptrdiff_t, vuint64m4_t, vuint64m4_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vssseg2e64_v_m)))
void vssseg2e64_v_u64m4_m(vbool16_t, uint64_t *, ptrdiff_t, vuint64m4_t, vuint64m4_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vssseg3e64_v)))
void vssseg3e64_v_i64m1(int64_t *, ptrdiff_t, vint64m1_t, vint64m1_t, vint64m1_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vssseg3e64_v_m)))
void vssseg3e64_v_i64m1_m(vbool64_t, int64_t *, ptrdiff_t, vint64m1_t, vint64m1_t, vint64m1_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vssseg3e64_v)))
void vssseg3e64_v_i64m2(int64_t *, ptrdiff_t, vint64m2_t, vint64m2_t, vint64m2_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vssseg3e64_v_m)))
void vssseg3e64_v_i64m2_m(vbool32_t, int64_t *, ptrdiff_t, vint64m2_t, vint64m2_t, vint64m2_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vssseg3e64_v)))
void vssseg3e64_v_u64m1(uint64_t *, ptrdiff_t, vuint64m1_t, vuint64m1_t, vuint64m1_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vssseg3e64_v_m)))
void vssseg3e64_v_u64m1_m(vbool64_t, uint64_t *, ptrdiff_t, vuint64m1_t, vuint64m1_t, vuint64m1_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vssseg3e64_v)))
void vssseg3e64_v_u64m2(uint64_t *, ptrdiff_t, vuint64m2_t, vuint64m2_t, vuint64m2_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vssseg3e64_v_m)))
void vssseg3e64_v_u64m2_m(vbool32_t, uint64_t *, ptrdiff_t, vuint64m2_t, vuint64m2_t, vuint64m2_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vssseg4e64_v)))
void vssseg4e64_v_i64m1(int64_t *, ptrdiff_t, vint64m1_t, vint64m1_t, vint64m1_t, vint64m1_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vssseg4e64_v_m)))
void vssseg4e64_v_i64m1_m(vbool64_t, int64_t *, ptrdiff_t, vint64m1_t, vint64m1_t, vint64m1_t, vint64m1_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vssseg4e64_v)))
void vssseg4e64_v_i64m2(int64_t *, ptrdiff_t, vint64m2_t, vint64m2_t, vint64m2_t, vint64m2_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vssseg4e64_v_m)))
void vssseg4e64_v_i64m2_m(vbool32_t, int64_t *, ptrdiff_t, vint64m2_t, vint64m2_t, vint64m2_t, vint64m2_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vssseg4e64_v)))
void vssseg4e64_v_u64m1(uint64_t *, ptrdiff_t, vuint64m1_t, vuint64m1_t, vuint64m1_t, vuint64m1_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vssseg4e64_v_m)))
void vssseg4e64_v_u64m1_m(vbool64_t, uint64_t *, ptrdiff_t, vuint64m1_t, vuint64m1_t, vuint64m1_t, vuint64m1_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vssseg4e64_v)))
void vssseg4e64_v_u64m2(uint64_t *, ptrdiff_t, vuint64m2_t, vuint64m2_t, vuint64m2_t, vuint64m2_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vssseg4e64_v_m)))
void vssseg4e64_v_u64m2_m(vbool32_t, uint64_t *, ptrdiff_t, vuint64m2_t, vuint64m2_t, vuint64m2_t, vuint64m2_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vssseg5e64_v)))
void vssseg5e64_v_i64m1(int64_t *, ptrdiff_t, vint64m1_t, vint64m1_t, vint64m1_t, vint64m1_t, vint64m1_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vssseg5e64_v_m)))
void vssseg5e64_v_i64m1_m(vbool64_t, int64_t *, ptrdiff_t, vint64m1_t, vint64m1_t, vint64m1_t, vint64m1_t, vint64m1_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vssseg5e64_v)))
void vssseg5e64_v_u64m1(uint64_t *, ptrdiff_t, vuint64m1_t, vuint64m1_t, vuint64m1_t, vuint64m1_t, vuint64m1_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vssseg5e64_v_m)))
void vssseg5e64_v_u64m1_m(vbool64_t, uint64_t *, ptrdiff_t, vuint64m1_t, vuint64m1_t, vuint64m1_t, vuint64m1_t, vuint64m1_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vssseg6e64_v)))
void vssseg6e64_v_i64m1(int64_t *, ptrdiff_t, vint64m1_t, vint64m1_t, vint64m1_t, vint64m1_t, vint64m1_t, vint64m1_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vssseg6e64_v_m)))
void vssseg6e64_v_i64m1_m(vbool64_t, int64_t *, ptrdiff_t, vint64m1_t, vint64m1_t, vint64m1_t, vint64m1_t, vint64m1_t, vint64m1_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vssseg6e64_v)))
void vssseg6e64_v_u64m1(uint64_t *, ptrdiff_t, vuint64m1_t, vuint64m1_t, vuint64m1_t, vuint64m1_t, vuint64m1_t, vuint64m1_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vssseg6e64_v_m)))
void vssseg6e64_v_u64m1_m(vbool64_t, uint64_t *, ptrdiff_t, vuint64m1_t, vuint64m1_t, vuint64m1_t, vuint64m1_t, vuint64m1_t, vuint64m1_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vssseg7e64_v)))
void vssseg7e64_v_i64m1(int64_t *, ptrdiff_t, vint64m1_t, vint64m1_t, vint64m1_t, vint64m1_t, vint64m1_t, vint64m1_t, vint64m1_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vssseg7e64_v_m)))
void vssseg7e64_v_i64m1_m(vbool64_t, int64_t *, ptrdiff_t, vint64m1_t, vint64m1_t, vint64m1_t, vint64m1_t, vint64m1_t, vint64m1_t, vint64m1_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vssseg7e64_v)))
void vssseg7e64_v_u64m1(uint64_t *, ptrdiff_t, vuint64m1_t, vuint64m1_t, vuint64m1_t, vuint64m1_t, vuint64m1_t, vuint64m1_t, vuint64m1_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vssseg7e64_v_m)))
void vssseg7e64_v_u64m1_m(vbool64_t, uint64_t *, ptrdiff_t, vuint64m1_t, vuint64m1_t, vuint64m1_t, vuint64m1_t, vuint64m1_t, vuint64m1_t, vuint64m1_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vssseg8e64_v)))
void vssseg8e64_v_i64m1(int64_t *, ptrdiff_t, vint64m1_t, vint64m1_t, vint64m1_t, vint64m1_t, vint64m1_t, vint64m1_t, vint64m1_t, vint64m1_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vssseg8e64_v_m)))
void vssseg8e64_v_i64m1_m(vbool64_t, int64_t *, ptrdiff_t, vint64m1_t, vint64m1_t, vint64m1_t, vint64m1_t, vint64m1_t, vint64m1_t, vint64m1_t, vint64m1_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vssseg8e64_v)))
void vssseg8e64_v_u64m1(uint64_t *, ptrdiff_t, vuint64m1_t, vuint64m1_t, vuint64m1_t, vuint64m1_t, vuint64m1_t, vuint64m1_t, vuint64m1_t, vuint64m1_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vssseg8e64_v_m)))
void vssseg8e64_v_u64m1_m(vbool64_t, uint64_t *, ptrdiff_t, vuint64m1_t, vuint64m1_t, vuint64m1_t, vuint64m1_t, vuint64m1_t, vuint64m1_t, vuint64m1_t, vuint64m1_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vsuxseg2ei64_v)))
void vsuxseg2ei64_v_i8m1(int8_t *, vuint64m8_t, vint8m1_t, vint8m1_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vsuxseg2ei64_v_m)))
void vsuxseg2ei64_v_i8m1_m(vbool8_t, int8_t *, vuint64m8_t, vint8m1_t, vint8m1_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vsuxseg2ei64_v)))
void vsuxseg2ei64_v_i8mf2(int8_t *, vuint64m4_t, vint8mf2_t, vint8mf2_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vsuxseg2ei64_v_m)))
void vsuxseg2ei64_v_i8mf2_m(vbool16_t, int8_t *, vuint64m4_t, vint8mf2_t, vint8mf2_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vsuxseg2ei64_v)))
void vsuxseg2ei64_v_i8mf4(int8_t *, vuint64m2_t, vint8mf4_t, vint8mf4_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vsuxseg2ei64_v_m)))
void vsuxseg2ei64_v_i8mf4_m(vbool32_t, int8_t *, vuint64m2_t, vint8mf4_t, vint8mf4_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vsuxseg2ei64_v)))
void vsuxseg2ei64_v_i8mf8(int8_t *, vuint64m1_t, vint8mf8_t, vint8mf8_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vsuxseg2ei64_v_m)))
void vsuxseg2ei64_v_i8mf8_m(vbool64_t, int8_t *, vuint64m1_t, vint8mf8_t, vint8mf8_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vsuxseg2ei64_v)))
void vsuxseg2ei64_v_u8m1(uint8_t *, vuint64m8_t, vuint8m1_t, vuint8m1_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vsuxseg2ei64_v_m)))
void vsuxseg2ei64_v_u8m1_m(vbool8_t, uint8_t *, vuint64m8_t, vuint8m1_t, vuint8m1_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vsuxseg2ei64_v)))
void vsuxseg2ei64_v_u8mf2(uint8_t *, vuint64m4_t, vuint8mf2_t, vuint8mf2_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vsuxseg2ei64_v_m)))
void vsuxseg2ei64_v_u8mf2_m(vbool16_t, uint8_t *, vuint64m4_t, vuint8mf2_t, vuint8mf2_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vsuxseg2ei64_v)))
void vsuxseg2ei64_v_u8mf4(uint8_t *, vuint64m2_t, vuint8mf4_t, vuint8mf4_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vsuxseg2ei64_v_m)))
void vsuxseg2ei64_v_u8mf4_m(vbool32_t, uint8_t *, vuint64m2_t, vuint8mf4_t, vuint8mf4_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vsuxseg2ei64_v)))
void vsuxseg2ei64_v_u8mf8(uint8_t *, vuint64m1_t, vuint8mf8_t, vuint8mf8_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vsuxseg2ei64_v_m)))
void vsuxseg2ei64_v_u8mf8_m(vbool64_t, uint8_t *, vuint64m1_t, vuint8mf8_t, vuint8mf8_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vsuxseg3ei64_v)))
void vsuxseg3ei64_v_i8m1(int8_t *, vuint64m8_t, vint8m1_t, vint8m1_t, vint8m1_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vsuxseg3ei64_v_m)))
void vsuxseg3ei64_v_i8m1_m(vbool8_t, int8_t *, vuint64m8_t, vint8m1_t, vint8m1_t, vint8m1_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vsuxseg3ei64_v)))
void vsuxseg3ei64_v_i8mf2(int8_t *, vuint64m4_t, vint8mf2_t, vint8mf2_t, vint8mf2_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vsuxseg3ei64_v_m)))
void vsuxseg3ei64_v_i8mf2_m(vbool16_t, int8_t *, vuint64m4_t, vint8mf2_t, vint8mf2_t, vint8mf2_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vsuxseg3ei64_v)))
void vsuxseg3ei64_v_i8mf4(int8_t *, vuint64m2_t, vint8mf4_t, vint8mf4_t, vint8mf4_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vsuxseg3ei64_v_m)))
void vsuxseg3ei64_v_i8mf4_m(vbool32_t, int8_t *, vuint64m2_t, vint8mf4_t, vint8mf4_t, vint8mf4_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vsuxseg3ei64_v)))
void vsuxseg3ei64_v_i8mf8(int8_t *, vuint64m1_t, vint8mf8_t, vint8mf8_t, vint8mf8_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vsuxseg3ei64_v_m)))
void vsuxseg3ei64_v_i8mf8_m(vbool64_t, int8_t *, vuint64m1_t, vint8mf8_t, vint8mf8_t, vint8mf8_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vsuxseg3ei64_v)))
void vsuxseg3ei64_v_u8m1(uint8_t *, vuint64m8_t, vuint8m1_t, vuint8m1_t, vuint8m1_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vsuxseg3ei64_v_m)))
void vsuxseg3ei64_v_u8m1_m(vbool8_t, uint8_t *, vuint64m8_t, vuint8m1_t, vuint8m1_t, vuint8m1_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vsuxseg3ei64_v)))
void vsuxseg3ei64_v_u8mf2(uint8_t *, vuint64m4_t, vuint8mf2_t, vuint8mf2_t, vuint8mf2_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vsuxseg3ei64_v_m)))
void vsuxseg3ei64_v_u8mf2_m(vbool16_t, uint8_t *, vuint64m4_t, vuint8mf2_t, vuint8mf2_t, vuint8mf2_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vsuxseg3ei64_v)))
void vsuxseg3ei64_v_u8mf4(uint8_t *, vuint64m2_t, vuint8mf4_t, vuint8mf4_t, vuint8mf4_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vsuxseg3ei64_v_m)))
void vsuxseg3ei64_v_u8mf4_m(vbool32_t, uint8_t *, vuint64m2_t, vuint8mf4_t, vuint8mf4_t, vuint8mf4_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vsuxseg3ei64_v)))
void vsuxseg3ei64_v_u8mf8(uint8_t *, vuint64m1_t, vuint8mf8_t, vuint8mf8_t, vuint8mf8_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vsuxseg3ei64_v_m)))
void vsuxseg3ei64_v_u8mf8_m(vbool64_t, uint8_t *, vuint64m1_t, vuint8mf8_t, vuint8mf8_t, vuint8mf8_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vsuxseg4ei64_v)))
void vsuxseg4ei64_v_i8m1(int8_t *, vuint64m8_t, vint8m1_t, vint8m1_t, vint8m1_t, vint8m1_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vsuxseg4ei64_v_m)))
void vsuxseg4ei64_v_i8m1_m(vbool8_t, int8_t *, vuint64m8_t, vint8m1_t, vint8m1_t, vint8m1_t, vint8m1_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vsuxseg4ei64_v)))
void vsuxseg4ei64_v_i8mf2(int8_t *, vuint64m4_t, vint8mf2_t, vint8mf2_t, vint8mf2_t, vint8mf2_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vsuxseg4ei64_v_m)))
void vsuxseg4ei64_v_i8mf2_m(vbool16_t, int8_t *, vuint64m4_t, vint8mf2_t, vint8mf2_t, vint8mf2_t, vint8mf2_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vsuxseg4ei64_v)))
void vsuxseg4ei64_v_i8mf4(int8_t *, vuint64m2_t, vint8mf4_t, vint8mf4_t, vint8mf4_t, vint8mf4_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vsuxseg4ei64_v_m)))
void vsuxseg4ei64_v_i8mf4_m(vbool32_t, int8_t *, vuint64m2_t, vint8mf4_t, vint8mf4_t, vint8mf4_t, vint8mf4_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vsuxseg4ei64_v)))
void vsuxseg4ei64_v_i8mf8(int8_t *, vuint64m1_t, vint8mf8_t, vint8mf8_t, vint8mf8_t, vint8mf8_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vsuxseg4ei64_v_m)))
void vsuxseg4ei64_v_i8mf8_m(vbool64_t, int8_t *, vuint64m1_t, vint8mf8_t, vint8mf8_t, vint8mf8_t, vint8mf8_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vsuxseg4ei64_v)))
void vsuxseg4ei64_v_u8m1(uint8_t *, vuint64m8_t, vuint8m1_t, vuint8m1_t, vuint8m1_t, vuint8m1_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vsuxseg4ei64_v_m)))
void vsuxseg4ei64_v_u8m1_m(vbool8_t, uint8_t *, vuint64m8_t, vuint8m1_t, vuint8m1_t, vuint8m1_t, vuint8m1_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vsuxseg4ei64_v)))
void vsuxseg4ei64_v_u8mf2(uint8_t *, vuint64m4_t, vuint8mf2_t, vuint8mf2_t, vuint8mf2_t, vuint8mf2_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vsuxseg4ei64_v_m)))
void vsuxseg4ei64_v_u8mf2_m(vbool16_t, uint8_t *, vuint64m4_t, vuint8mf2_t, vuint8mf2_t, vuint8mf2_t, vuint8mf2_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vsuxseg4ei64_v)))
void vsuxseg4ei64_v_u8mf4(uint8_t *, vuint64m2_t, vuint8mf4_t, vuint8mf4_t, vuint8mf4_t, vuint8mf4_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vsuxseg4ei64_v_m)))
void vsuxseg4ei64_v_u8mf4_m(vbool32_t, uint8_t *, vuint64m2_t, vuint8mf4_t, vuint8mf4_t, vuint8mf4_t, vuint8mf4_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vsuxseg4ei64_v)))
void vsuxseg4ei64_v_u8mf8(uint8_t *, vuint64m1_t, vuint8mf8_t, vuint8mf8_t, vuint8mf8_t, vuint8mf8_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vsuxseg4ei64_v_m)))
void vsuxseg4ei64_v_u8mf8_m(vbool64_t, uint8_t *, vuint64m1_t, vuint8mf8_t, vuint8mf8_t, vuint8mf8_t, vuint8mf8_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vsuxseg5ei64_v)))
void vsuxseg5ei64_v_i8m1(int8_t *, vuint64m8_t, vint8m1_t, vint8m1_t, vint8m1_t, vint8m1_t, vint8m1_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vsuxseg5ei64_v_m)))
void vsuxseg5ei64_v_i8m1_m(vbool8_t, int8_t *, vuint64m8_t, vint8m1_t, vint8m1_t, vint8m1_t, vint8m1_t, vint8m1_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vsuxseg5ei64_v)))
void vsuxseg5ei64_v_i8mf2(int8_t *, vuint64m4_t, vint8mf2_t, vint8mf2_t, vint8mf2_t, vint8mf2_t, vint8mf2_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vsuxseg5ei64_v_m)))
void vsuxseg5ei64_v_i8mf2_m(vbool16_t, int8_t *, vuint64m4_t, vint8mf2_t, vint8mf2_t, vint8mf2_t, vint8mf2_t, vint8mf2_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vsuxseg5ei64_v)))
void vsuxseg5ei64_v_i8mf4(int8_t *, vuint64m2_t, vint8mf4_t, vint8mf4_t, vint8mf4_t, vint8mf4_t, vint8mf4_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vsuxseg5ei64_v_m)))
void vsuxseg5ei64_v_i8mf4_m(vbool32_t, int8_t *, vuint64m2_t, vint8mf4_t, vint8mf4_t, vint8mf4_t, vint8mf4_t, vint8mf4_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vsuxseg5ei64_v)))
void vsuxseg5ei64_v_i8mf8(int8_t *, vuint64m1_t, vint8mf8_t, vint8mf8_t, vint8mf8_t, vint8mf8_t, vint8mf8_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vsuxseg5ei64_v_m)))
void vsuxseg5ei64_v_i8mf8_m(vbool64_t, int8_t *, vuint64m1_t, vint8mf8_t, vint8mf8_t, vint8mf8_t, vint8mf8_t, vint8mf8_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vsuxseg5ei64_v)))
void vsuxseg5ei64_v_u8m1(uint8_t *, vuint64m8_t, vuint8m1_t, vuint8m1_t, vuint8m1_t, vuint8m1_t, vuint8m1_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vsuxseg5ei64_v_m)))
void vsuxseg5ei64_v_u8m1_m(vbool8_t, uint8_t *, vuint64m8_t, vuint8m1_t, vuint8m1_t, vuint8m1_t, vuint8m1_t, vuint8m1_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vsuxseg5ei64_v)))
void vsuxseg5ei64_v_u8mf2(uint8_t *, vuint64m4_t, vuint8mf2_t, vuint8mf2_t, vuint8mf2_t, vuint8mf2_t, vuint8mf2_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vsuxseg5ei64_v_m)))
void vsuxseg5ei64_v_u8mf2_m(vbool16_t, uint8_t *, vuint64m4_t, vuint8mf2_t, vuint8mf2_t, vuint8mf2_t, vuint8mf2_t, vuint8mf2_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vsuxseg5ei64_v)))
void vsuxseg5ei64_v_u8mf4(uint8_t *, vuint64m2_t, vuint8mf4_t, vuint8mf4_t, vuint8mf4_t, vuint8mf4_t, vuint8mf4_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vsuxseg5ei64_v_m)))
void vsuxseg5ei64_v_u8mf4_m(vbool32_t, uint8_t *, vuint64m2_t, vuint8mf4_t, vuint8mf4_t, vuint8mf4_t, vuint8mf4_t, vuint8mf4_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vsuxseg5ei64_v)))
void vsuxseg5ei64_v_u8mf8(uint8_t *, vuint64m1_t, vuint8mf8_t, vuint8mf8_t, vuint8mf8_t, vuint8mf8_t, vuint8mf8_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vsuxseg5ei64_v_m)))
void vsuxseg5ei64_v_u8mf8_m(vbool64_t, uint8_t *, vuint64m1_t, vuint8mf8_t, vuint8mf8_t, vuint8mf8_t, vuint8mf8_t, vuint8mf8_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vsuxseg6ei64_v)))
void vsuxseg6ei64_v_i8m1(int8_t *, vuint64m8_t, vint8m1_t, vint8m1_t, vint8m1_t, vint8m1_t, vint8m1_t, vint8m1_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vsuxseg6ei64_v_m)))
void vsuxseg6ei64_v_i8m1_m(vbool8_t, int8_t *, vuint64m8_t, vint8m1_t, vint8m1_t, vint8m1_t, vint8m1_t, vint8m1_t, vint8m1_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vsuxseg6ei64_v)))
void vsuxseg6ei64_v_i8mf2(int8_t *, vuint64m4_t, vint8mf2_t, vint8mf2_t, vint8mf2_t, vint8mf2_t, vint8mf2_t, vint8mf2_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vsuxseg6ei64_v_m)))
void vsuxseg6ei64_v_i8mf2_m(vbool16_t, int8_t *, vuint64m4_t, vint8mf2_t, vint8mf2_t, vint8mf2_t, vint8mf2_t, vint8mf2_t, vint8mf2_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vsuxseg6ei64_v)))
void vsuxseg6ei64_v_i8mf4(int8_t *, vuint64m2_t, vint8mf4_t, vint8mf4_t, vint8mf4_t, vint8mf4_t, vint8mf4_t, vint8mf4_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vsuxseg6ei64_v_m)))
void vsuxseg6ei64_v_i8mf4_m(vbool32_t, int8_t *, vuint64m2_t, vint8mf4_t, vint8mf4_t, vint8mf4_t, vint8mf4_t, vint8mf4_t, vint8mf4_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vsuxseg6ei64_v)))
void vsuxseg6ei64_v_i8mf8(int8_t *, vuint64m1_t, vint8mf8_t, vint8mf8_t, vint8mf8_t, vint8mf8_t, vint8mf8_t, vint8mf8_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vsuxseg6ei64_v_m)))
void vsuxseg6ei64_v_i8mf8_m(vbool64_t, int8_t *, vuint64m1_t, vint8mf8_t, vint8mf8_t, vint8mf8_t, vint8mf8_t, vint8mf8_t, vint8mf8_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vluxei8_v)))
vint64m1_t vluxei8_v_i64m1(const int64_t *, vuint8mf8_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vluxei8_v_m)))
vint64m1_t vluxei8_v_i64m1_m(vbool64_t, vint64m1_t, const int64_t *, vuint8mf8_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vluxei8_v)))
vint64m2_t vluxei8_v_i64m2(const int64_t *, vuint8mf4_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vluxei8_v_m)))
vint64m2_t vluxei8_v_i64m2_m(vbool32_t, vint64m2_t, const int64_t *, vuint8mf4_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vluxei8_v)))
vint64m4_t vluxei8_v_i64m4(const int64_t *, vuint8mf2_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vluxei8_v_m)))
vint64m4_t vluxei8_v_i64m4_m(vbool16_t, vint64m4_t, const int64_t *, vuint8mf2_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vluxei8_v)))
vint64m8_t vluxei8_v_i64m8(const int64_t *, vuint8m1_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vluxei8_v_m)))
vint64m8_t vluxei8_v_i64m8_m(vbool8_t, vint64m8_t, const int64_t *, vuint8m1_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vsuxseg6ei64_v)))
void vsuxseg6ei64_v_u8m1(uint8_t *, vuint64m8_t, vuint8m1_t, vuint8m1_t, vuint8m1_t, vuint8m1_t, vuint8m1_t, vuint8m1_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vsuxseg6ei64_v_m)))
void vsuxseg6ei64_v_u8m1_m(vbool8_t, uint8_t *, vuint64m8_t, vuint8m1_t, vuint8m1_t, vuint8m1_t, vuint8m1_t, vuint8m1_t, vuint8m1_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vsuxseg6ei64_v)))
void vsuxseg6ei64_v_u8mf2(uint8_t *, vuint64m4_t, vuint8mf2_t, vuint8mf2_t, vuint8mf2_t, vuint8mf2_t, vuint8mf2_t, vuint8mf2_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vsuxseg6ei64_v_m)))
void vsuxseg6ei64_v_u8mf2_m(vbool16_t, uint8_t *, vuint64m4_t, vuint8mf2_t, vuint8mf2_t, vuint8mf2_t, vuint8mf2_t, vuint8mf2_t, vuint8mf2_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vsuxseg6ei64_v)))
void vsuxseg6ei64_v_u8mf4(uint8_t *, vuint64m2_t, vuint8mf4_t, vuint8mf4_t, vuint8mf4_t, vuint8mf4_t, vuint8mf4_t, vuint8mf4_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vsuxseg6ei64_v_m)))
void vsuxseg6ei64_v_u8mf4_m(vbool32_t, uint8_t *, vuint64m2_t, vuint8mf4_t, vuint8mf4_t, vuint8mf4_t, vuint8mf4_t, vuint8mf4_t, vuint8mf4_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vsuxseg6ei64_v)))
void vsuxseg6ei64_v_u8mf8(uint8_t *, vuint64m1_t, vuint8mf8_t, vuint8mf8_t, vuint8mf8_t, vuint8mf8_t, vuint8mf8_t, vuint8mf8_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vsuxseg6ei64_v_m)))
void vsuxseg6ei64_v_u8mf8_m(vbool64_t, uint8_t *, vuint64m1_t, vuint8mf8_t, vuint8mf8_t, vuint8mf8_t, vuint8mf8_t, vuint8mf8_t, vuint8mf8_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vsuxseg7ei64_v)))
void vsuxseg7ei64_v_i8m1(int8_t *, vuint64m8_t, vint8m1_t, vint8m1_t, vint8m1_t, vint8m1_t, vint8m1_t, vint8m1_t, vint8m1_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vsuxseg7ei64_v_m)))
void vsuxseg7ei64_v_i8m1_m(vbool8_t, int8_t *, vuint64m8_t, vint8m1_t, vint8m1_t, vint8m1_t, vint8m1_t, vint8m1_t, vint8m1_t, vint8m1_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vsuxseg7ei64_v)))
void vsuxseg7ei64_v_i8mf2(int8_t *, vuint64m4_t, vint8mf2_t, vint8mf2_t, vint8mf2_t, vint8mf2_t, vint8mf2_t, vint8mf2_t, vint8mf2_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vsuxseg7ei64_v_m)))
void vsuxseg7ei64_v_i8mf2_m(vbool16_t, int8_t *, vuint64m4_t, vint8mf2_t, vint8mf2_t, vint8mf2_t, vint8mf2_t, vint8mf2_t, vint8mf2_t, vint8mf2_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vsuxseg7ei64_v)))
void vsuxseg7ei64_v_i8mf4(int8_t *, vuint64m2_t, vint8mf4_t, vint8mf4_t, vint8mf4_t, vint8mf4_t, vint8mf4_t, vint8mf4_t, vint8mf4_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vsuxseg7ei64_v_m)))
void vsuxseg7ei64_v_i8mf4_m(vbool32_t, int8_t *, vuint64m2_t, vint8mf4_t, vint8mf4_t, vint8mf4_t, vint8mf4_t, vint8mf4_t, vint8mf4_t, vint8mf4_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vsuxseg7ei64_v)))
void vsuxseg7ei64_v_i8mf8(int8_t *, vuint64m1_t, vint8mf8_t, vint8mf8_t, vint8mf8_t, vint8mf8_t, vint8mf8_t, vint8mf8_t, vint8mf8_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vsuxseg7ei64_v_m)))
void vsuxseg7ei64_v_i8mf8_m(vbool64_t, int8_t *, vuint64m1_t, vint8mf8_t, vint8mf8_t, vint8mf8_t, vint8mf8_t, vint8mf8_t, vint8mf8_t, vint8mf8_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vsuxseg7ei64_v)))
void vsuxseg7ei64_v_u8m1(uint8_t *, vuint64m8_t, vuint8m1_t, vuint8m1_t, vuint8m1_t, vuint8m1_t, vuint8m1_t, vuint8m1_t, vuint8m1_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vsuxseg7ei64_v_m)))
void vsuxseg7ei64_v_u8m1_m(vbool8_t, uint8_t *, vuint64m8_t, vuint8m1_t, vuint8m1_t, vuint8m1_t, vuint8m1_t, vuint8m1_t, vuint8m1_t, vuint8m1_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vsuxseg7ei64_v)))
void vsuxseg7ei64_v_u8mf2(uint8_t *, vuint64m4_t, vuint8mf2_t, vuint8mf2_t, vuint8mf2_t, vuint8mf2_t, vuint8mf2_t, vuint8mf2_t, vuint8mf2_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vsuxseg7ei64_v_m)))
void vsuxseg7ei64_v_u8mf2_m(vbool16_t, uint8_t *, vuint64m4_t, vuint8mf2_t, vuint8mf2_t, vuint8mf2_t, vuint8mf2_t, vuint8mf2_t, vuint8mf2_t, vuint8mf2_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vsuxseg7ei64_v)))
void vsuxseg7ei64_v_u8mf4(uint8_t *, vuint64m2_t, vuint8mf4_t, vuint8mf4_t, vuint8mf4_t, vuint8mf4_t, vuint8mf4_t, vuint8mf4_t, vuint8mf4_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vsuxseg7ei64_v_m)))
void vsuxseg7ei64_v_u8mf4_m(vbool32_t, uint8_t *, vuint64m2_t, vuint8mf4_t, vuint8mf4_t, vuint8mf4_t, vuint8mf4_t, vuint8mf4_t, vuint8mf4_t, vuint8mf4_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vsuxseg7ei64_v)))
void vsuxseg7ei64_v_u8mf8(uint8_t *, vuint64m1_t, vuint8mf8_t, vuint8mf8_t, vuint8mf8_t, vuint8mf8_t, vuint8mf8_t, vuint8mf8_t, vuint8mf8_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vsuxseg7ei64_v_m)))
void vsuxseg7ei64_v_u8mf8_m(vbool64_t, uint8_t *, vuint64m1_t, vuint8mf8_t, vuint8mf8_t, vuint8mf8_t, vuint8mf8_t, vuint8mf8_t, vuint8mf8_t, vuint8mf8_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vsuxseg8ei64_v)))
void vsuxseg8ei64_v_i8m1(int8_t *, vuint64m8_t, vint8m1_t, vint8m1_t, vint8m1_t, vint8m1_t, vint8m1_t, vint8m1_t, vint8m1_t, vint8m1_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vsuxseg8ei64_v_m)))
void vsuxseg8ei64_v_i8m1_m(vbool8_t, int8_t *, vuint64m8_t, vint8m1_t, vint8m1_t, vint8m1_t, vint8m1_t, vint8m1_t, vint8m1_t, vint8m1_t, vint8m1_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vsuxseg8ei64_v)))
void vsuxseg8ei64_v_i8mf2(int8_t *, vuint64m4_t, vint8mf2_t, vint8mf2_t, vint8mf2_t, vint8mf2_t, vint8mf2_t, vint8mf2_t, vint8mf2_t, vint8mf2_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vsuxseg8ei64_v_m)))
void vsuxseg8ei64_v_i8mf2_m(vbool16_t, int8_t *, vuint64m4_t, vint8mf2_t, vint8mf2_t, vint8mf2_t, vint8mf2_t, vint8mf2_t, vint8mf2_t, vint8mf2_t, vint8mf2_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vsuxseg8ei64_v)))
void vsuxseg8ei64_v_i8mf4(int8_t *, vuint64m2_t, vint8mf4_t, vint8mf4_t, vint8mf4_t, vint8mf4_t, vint8mf4_t, vint8mf4_t, vint8mf4_t, vint8mf4_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vsuxseg8ei64_v_m)))
void vsuxseg8ei64_v_i8mf4_m(vbool32_t, int8_t *, vuint64m2_t, vint8mf4_t, vint8mf4_t, vint8mf4_t, vint8mf4_t, vint8mf4_t, vint8mf4_t, vint8mf4_t, vint8mf4_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vsuxseg8ei64_v)))
void vsuxseg8ei64_v_i8mf8(int8_t *, vuint64m1_t, vint8mf8_t, vint8mf8_t, vint8mf8_t, vint8mf8_t, vint8mf8_t, vint8mf8_t, vint8mf8_t, vint8mf8_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vsuxseg8ei64_v_m)))
void vsuxseg8ei64_v_i8mf8_m(vbool64_t, int8_t *, vuint64m1_t, vint8mf8_t, vint8mf8_t, vint8mf8_t, vint8mf8_t, vint8mf8_t, vint8mf8_t, vint8mf8_t, vint8mf8_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vsuxseg8ei64_v)))
void vsuxseg8ei64_v_u8m1(uint8_t *, vuint64m8_t, vuint8m1_t, vuint8m1_t, vuint8m1_t, vuint8m1_t, vuint8m1_t, vuint8m1_t, vuint8m1_t, vuint8m1_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vsuxseg8ei64_v_m)))
void vsuxseg8ei64_v_u8m1_m(vbool8_t, uint8_t *, vuint64m8_t, vuint8m1_t, vuint8m1_t, vuint8m1_t, vuint8m1_t, vuint8m1_t, vuint8m1_t, vuint8m1_t, vuint8m1_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vsuxseg8ei64_v)))
void vsuxseg8ei64_v_u8mf2(uint8_t *, vuint64m4_t, vuint8mf2_t, vuint8mf2_t, vuint8mf2_t, vuint8mf2_t, vuint8mf2_t, vuint8mf2_t, vuint8mf2_t, vuint8mf2_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vsuxseg8ei64_v_m)))
void vsuxseg8ei64_v_u8mf2_m(vbool16_t, uint8_t *, vuint64m4_t, vuint8mf2_t, vuint8mf2_t, vuint8mf2_t, vuint8mf2_t, vuint8mf2_t, vuint8mf2_t, vuint8mf2_t, vuint8mf2_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vsuxseg8ei64_v)))
void vsuxseg8ei64_v_u8mf4(uint8_t *, vuint64m2_t, vuint8mf4_t, vuint8mf4_t, vuint8mf4_t, vuint8mf4_t, vuint8mf4_t, vuint8mf4_t, vuint8mf4_t, vuint8mf4_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vsuxseg8ei64_v_m)))
void vsuxseg8ei64_v_u8mf4_m(vbool32_t, uint8_t *, vuint64m2_t, vuint8mf4_t, vuint8mf4_t, vuint8mf4_t, vuint8mf4_t, vuint8mf4_t, vuint8mf4_t, vuint8mf4_t, vuint8mf4_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vsuxseg8ei64_v)))
void vsuxseg8ei64_v_u8mf8(uint8_t *, vuint64m1_t, vuint8mf8_t, vuint8mf8_t, vuint8mf8_t, vuint8mf8_t, vuint8mf8_t, vuint8mf8_t, vuint8mf8_t, vuint8mf8_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vsuxseg8ei64_v_m)))
void vsuxseg8ei64_v_u8mf8_m(vbool64_t, uint8_t *, vuint64m1_t, vuint8mf8_t, vuint8mf8_t, vuint8mf8_t, vuint8mf8_t, vuint8mf8_t, vuint8mf8_t, vuint8mf8_t, vuint8mf8_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vluxei8_v)))
vuint64m1_t vluxei8_v_u64m1(const uint64_t *, vuint8mf8_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vluxei8_v_m)))
vuint64m1_t vluxei8_v_u64m1_m(vbool64_t, vuint64m1_t, const uint64_t *, vuint8mf8_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vluxei8_v)))
vuint64m2_t vluxei8_v_u64m2(const uint64_t *, vuint8mf4_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vluxei8_v_m)))
vuint64m2_t vluxei8_v_u64m2_m(vbool32_t, vuint64m2_t, const uint64_t *, vuint8mf4_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vluxei8_v)))
vuint64m4_t vluxei8_v_u64m4(const uint64_t *, vuint8mf2_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vluxei8_v_m)))
vuint64m4_t vluxei8_v_u64m4_m(vbool16_t, vuint64m4_t, const uint64_t *, vuint8mf2_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vluxei8_v)))
vuint64m8_t vluxei8_v_u64m8(const uint64_t *, vuint8m1_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vluxei8_v_m)))
vuint64m8_t vluxei8_v_u64m8_m(vbool8_t, vuint64m8_t, const uint64_t *, vuint8m1_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vluxei16_v)))
vint64m1_t vluxei16_v_i64m1(const int64_t *, vuint16mf4_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vluxei16_v_m)))
vint64m1_t vluxei16_v_i64m1_m(vbool64_t, vint64m1_t, const int64_t *, vuint16mf4_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vluxei16_v)))
vint64m2_t vluxei16_v_i64m2(const int64_t *, vuint16mf2_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vluxei16_v_m)))
vint64m2_t vluxei16_v_i64m2_m(vbool32_t, vint64m2_t, const int64_t *, vuint16mf2_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vluxei16_v)))
vint64m4_t vluxei16_v_i64m4(const int64_t *, vuint16m1_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vluxei16_v_m)))
vint64m4_t vluxei16_v_i64m4_m(vbool16_t, vint64m4_t, const int64_t *, vuint16m1_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vluxei16_v)))
vint64m8_t vluxei16_v_i64m8(const int64_t *, vuint16m2_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vluxei16_v_m)))
vint64m8_t vluxei16_v_i64m8_m(vbool8_t, vint64m8_t, const int64_t *, vuint16m2_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vluxei16_v)))
vuint64m1_t vluxei16_v_u64m1(const uint64_t *, vuint16mf4_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vluxei16_v_m)))
vuint64m1_t vluxei16_v_u64m1_m(vbool64_t, vuint64m1_t, const uint64_t *, vuint16mf4_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vluxei16_v)))
vuint64m2_t vluxei16_v_u64m2(const uint64_t *, vuint16mf2_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vluxei16_v_m)))
vuint64m2_t vluxei16_v_u64m2_m(vbool32_t, vuint64m2_t, const uint64_t *, vuint16mf2_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vluxei16_v)))
vuint64m4_t vluxei16_v_u64m4(const uint64_t *, vuint16m1_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vluxei16_v_m)))
vuint64m4_t vluxei16_v_u64m4_m(vbool16_t, vuint64m4_t, const uint64_t *, vuint16m1_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vluxei16_v)))
vuint64m8_t vluxei16_v_u64m8(const uint64_t *, vuint16m2_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vluxei16_v_m)))
vuint64m8_t vluxei16_v_u64m8_m(vbool8_t, vuint64m8_t, const uint64_t *, vuint16m2_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vluxei32_v)))
vint64m1_t vluxei32_v_i64m1(const int64_t *, vuint32mf2_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vluxei32_v_m)))
vint64m1_t vluxei32_v_i64m1_m(vbool64_t, vint64m1_t, const int64_t *, vuint32mf2_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vluxei32_v)))
vint64m2_t vluxei32_v_i64m2(const int64_t *, vuint32m1_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vluxei32_v_m)))
vint64m2_t vluxei32_v_i64m2_m(vbool32_t, vint64m2_t, const int64_t *, vuint32m1_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vluxei32_v)))
vint64m4_t vluxei32_v_i64m4(const int64_t *, vuint32m2_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vluxei32_v_m)))
vint64m4_t vluxei32_v_i64m4_m(vbool16_t, vint64m4_t, const int64_t *, vuint32m2_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vluxei32_v)))
vint64m8_t vluxei32_v_i64m8(const int64_t *, vuint32m4_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vluxei32_v_m)))
vint64m8_t vluxei32_v_i64m8_m(vbool8_t, vint64m8_t, const int64_t *, vuint32m4_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vsuxseg2ei64_v)))
void vsuxseg2ei64_v_i16m1(int16_t *, vuint64m4_t, vint16m1_t, vint16m1_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vsuxseg2ei64_v_m)))
void vsuxseg2ei64_v_i16m1_m(vbool16_t, int16_t *, vuint64m4_t, vint16m1_t, vint16m1_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vsuxseg2ei64_v)))
void vsuxseg2ei64_v_i16m2(int16_t *, vuint64m8_t, vint16m2_t, vint16m2_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vsuxseg2ei64_v_m)))
void vsuxseg2ei64_v_i16m2_m(vbool8_t, int16_t *, vuint64m8_t, vint16m2_t, vint16m2_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vsuxseg2ei64_v)))
void vsuxseg2ei64_v_i16mf2(int16_t *, vuint64m2_t, vint16mf2_t, vint16mf2_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vsuxseg2ei64_v_m)))
void vsuxseg2ei64_v_i16mf2_m(vbool32_t, int16_t *, vuint64m2_t, vint16mf2_t, vint16mf2_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vsuxseg2ei64_v)))
void vsuxseg2ei64_v_i16mf4(int16_t *, vuint64m1_t, vint16mf4_t, vint16mf4_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vsuxseg2ei64_v_m)))
void vsuxseg2ei64_v_i16mf4_m(vbool64_t, int16_t *, vuint64m1_t, vint16mf4_t, vint16mf4_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vsuxseg2ei64_v)))
void vsuxseg2ei64_v_u16m1(uint16_t *, vuint64m4_t, vuint16m1_t, vuint16m1_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vsuxseg2ei64_v_m)))
void vsuxseg2ei64_v_u16m1_m(vbool16_t, uint16_t *, vuint64m4_t, vuint16m1_t, vuint16m1_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vsuxseg2ei64_v)))
void vsuxseg2ei64_v_u16m2(uint16_t *, vuint64m8_t, vuint16m2_t, vuint16m2_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vsuxseg2ei64_v_m)))
void vsuxseg2ei64_v_u16m2_m(vbool8_t, uint16_t *, vuint64m8_t, vuint16m2_t, vuint16m2_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vsuxseg2ei64_v)))
void vsuxseg2ei64_v_u16mf2(uint16_t *, vuint64m2_t, vuint16mf2_t, vuint16mf2_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vsuxseg2ei64_v_m)))
void vsuxseg2ei64_v_u16mf2_m(vbool32_t, uint16_t *, vuint64m2_t, vuint16mf2_t, vuint16mf2_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vsuxseg2ei64_v)))
void vsuxseg2ei64_v_u16mf4(uint16_t *, vuint64m1_t, vuint16mf4_t, vuint16mf4_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vsuxseg2ei64_v_m)))
void vsuxseg2ei64_v_u16mf4_m(vbool64_t, uint16_t *, vuint64m1_t, vuint16mf4_t, vuint16mf4_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vsuxseg3ei64_v)))
void vsuxseg3ei64_v_i16m1(int16_t *, vuint64m4_t, vint16m1_t, vint16m1_t, vint16m1_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vsuxseg3ei64_v_m)))
void vsuxseg3ei64_v_i16m1_m(vbool16_t, int16_t *, vuint64m4_t, vint16m1_t, vint16m1_t, vint16m1_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vsuxseg3ei64_v)))
void vsuxseg3ei64_v_i16m2(int16_t *, vuint64m8_t, vint16m2_t, vint16m2_t, vint16m2_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vsuxseg3ei64_v_m)))
void vsuxseg3ei64_v_i16m2_m(vbool8_t, int16_t *, vuint64m8_t, vint16m2_t, vint16m2_t, vint16m2_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vsuxseg3ei64_v)))
void vsuxseg3ei64_v_i16mf2(int16_t *, vuint64m2_t, vint16mf2_t, vint16mf2_t, vint16mf2_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vsuxseg3ei64_v_m)))
void vsuxseg3ei64_v_i16mf2_m(vbool32_t, int16_t *, vuint64m2_t, vint16mf2_t, vint16mf2_t, vint16mf2_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vsuxseg3ei64_v)))
void vsuxseg3ei64_v_i16mf4(int16_t *, vuint64m1_t, vint16mf4_t, vint16mf4_t, vint16mf4_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vsuxseg3ei64_v_m)))
void vsuxseg3ei64_v_i16mf4_m(vbool64_t, int16_t *, vuint64m1_t, vint16mf4_t, vint16mf4_t, vint16mf4_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vluxei32_v)))
vuint64m1_t vluxei32_v_u64m1(const uint64_t *, vuint32mf2_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vluxei32_v_m)))
vuint64m1_t vluxei32_v_u64m1_m(vbool64_t, vuint64m1_t, const uint64_t *, vuint32mf2_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vluxei32_v)))
vuint64m2_t vluxei32_v_u64m2(const uint64_t *, vuint32m1_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vluxei32_v_m)))
vuint64m2_t vluxei32_v_u64m2_m(vbool32_t, vuint64m2_t, const uint64_t *, vuint32m1_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vluxei32_v)))
vuint64m4_t vluxei32_v_u64m4(const uint64_t *, vuint32m2_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vluxei32_v_m)))
vuint64m4_t vluxei32_v_u64m4_m(vbool16_t, vuint64m4_t, const uint64_t *, vuint32m2_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vluxei32_v)))
vuint64m8_t vluxei32_v_u64m8(const uint64_t *, vuint32m4_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vluxei32_v_m)))
vuint64m8_t vluxei32_v_u64m8_m(vbool8_t, vuint64m8_t, const uint64_t *, vuint32m4_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vsuxseg3ei64_v)))
void vsuxseg3ei64_v_u16m1(uint16_t *, vuint64m4_t, vuint16m1_t, vuint16m1_t, vuint16m1_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vsuxseg3ei64_v_m)))
void vsuxseg3ei64_v_u16m1_m(vbool16_t, uint16_t *, vuint64m4_t, vuint16m1_t, vuint16m1_t, vuint16m1_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vsuxseg3ei64_v)))
void vsuxseg3ei64_v_u16m2(uint16_t *, vuint64m8_t, vuint16m2_t, vuint16m2_t, vuint16m2_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vsuxseg3ei64_v_m)))
void vsuxseg3ei64_v_u16m2_m(vbool8_t, uint16_t *, vuint64m8_t, vuint16m2_t, vuint16m2_t, vuint16m2_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vsuxseg3ei64_v)))
void vsuxseg3ei64_v_u16mf2(uint16_t *, vuint64m2_t, vuint16mf2_t, vuint16mf2_t, vuint16mf2_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vsuxseg3ei64_v_m)))
void vsuxseg3ei64_v_u16mf2_m(vbool32_t, uint16_t *, vuint64m2_t, vuint16mf2_t, vuint16mf2_t, vuint16mf2_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vsuxseg3ei64_v)))
void vsuxseg3ei64_v_u16mf4(uint16_t *, vuint64m1_t, vuint16mf4_t, vuint16mf4_t, vuint16mf4_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vsuxseg3ei64_v_m)))
void vsuxseg3ei64_v_u16mf4_m(vbool64_t, uint16_t *, vuint64m1_t, vuint16mf4_t, vuint16mf4_t, vuint16mf4_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vsuxseg4ei64_v)))
void vsuxseg4ei64_v_i16m1(int16_t *, vuint64m4_t, vint16m1_t, vint16m1_t, vint16m1_t, vint16m1_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vsuxseg4ei64_v_m)))
void vsuxseg4ei64_v_i16m1_m(vbool16_t, int16_t *, vuint64m4_t, vint16m1_t, vint16m1_t, vint16m1_t, vint16m1_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vsuxseg4ei64_v)))
void vsuxseg4ei64_v_i16m2(int16_t *, vuint64m8_t, vint16m2_t, vint16m2_t, vint16m2_t, vint16m2_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vsuxseg4ei64_v_m)))
void vsuxseg4ei64_v_i16m2_m(vbool8_t, int16_t *, vuint64m8_t, vint16m2_t, vint16m2_t, vint16m2_t, vint16m2_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vsuxseg4ei64_v)))
void vsuxseg4ei64_v_i16mf2(int16_t *, vuint64m2_t, vint16mf2_t, vint16mf2_t, vint16mf2_t, vint16mf2_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vsuxseg4ei64_v_m)))
void vsuxseg4ei64_v_i16mf2_m(vbool32_t, int16_t *, vuint64m2_t, vint16mf2_t, vint16mf2_t, vint16mf2_t, vint16mf2_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vsuxseg4ei64_v)))
void vsuxseg4ei64_v_i16mf4(int16_t *, vuint64m1_t, vint16mf4_t, vint16mf4_t, vint16mf4_t, vint16mf4_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vsuxseg4ei64_v_m)))
void vsuxseg4ei64_v_i16mf4_m(vbool64_t, int16_t *, vuint64m1_t, vint16mf4_t, vint16mf4_t, vint16mf4_t, vint16mf4_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vsuxseg4ei64_v)))
void vsuxseg4ei64_v_u16m1(uint16_t *, vuint64m4_t, vuint16m1_t, vuint16m1_t, vuint16m1_t, vuint16m1_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vsuxseg4ei64_v_m)))
void vsuxseg4ei64_v_u16m1_m(vbool16_t, uint16_t *, vuint64m4_t, vuint16m1_t, vuint16m1_t, vuint16m1_t, vuint16m1_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vsuxseg4ei64_v)))
void vsuxseg4ei64_v_u16m2(uint16_t *, vuint64m8_t, vuint16m2_t, vuint16m2_t, vuint16m2_t, vuint16m2_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vsuxseg4ei64_v_m)))
void vsuxseg4ei64_v_u16m2_m(vbool8_t, uint16_t *, vuint64m8_t, vuint16m2_t, vuint16m2_t, vuint16m2_t, vuint16m2_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vsuxseg4ei64_v)))
void vsuxseg4ei64_v_u16mf2(uint16_t *, vuint64m2_t, vuint16mf2_t, vuint16mf2_t, vuint16mf2_t, vuint16mf2_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vsuxseg4ei64_v_m)))
void vsuxseg4ei64_v_u16mf2_m(vbool32_t, uint16_t *, vuint64m2_t, vuint16mf2_t, vuint16mf2_t, vuint16mf2_t, vuint16mf2_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vsuxseg4ei64_v)))
void vsuxseg4ei64_v_u16mf4(uint16_t *, vuint64m1_t, vuint16mf4_t, vuint16mf4_t, vuint16mf4_t, vuint16mf4_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vsuxseg4ei64_v_m)))
void vsuxseg4ei64_v_u16mf4_m(vbool64_t, uint16_t *, vuint64m1_t, vuint16mf4_t, vuint16mf4_t, vuint16mf4_t, vuint16mf4_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vsuxseg5ei64_v)))
void vsuxseg5ei64_v_i16m1(int16_t *, vuint64m4_t, vint16m1_t, vint16m1_t, vint16m1_t, vint16m1_t, vint16m1_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vsuxseg5ei64_v_m)))
void vsuxseg5ei64_v_i16m1_m(vbool16_t, int16_t *, vuint64m4_t, vint16m1_t, vint16m1_t, vint16m1_t, vint16m1_t, vint16m1_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vsuxseg5ei64_v)))
void vsuxseg5ei64_v_i16mf2(int16_t *, vuint64m2_t, vint16mf2_t, vint16mf2_t, vint16mf2_t, vint16mf2_t, vint16mf2_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vsuxseg5ei64_v_m)))
void vsuxseg5ei64_v_i16mf2_m(vbool32_t, int16_t *, vuint64m2_t, vint16mf2_t, vint16mf2_t, vint16mf2_t, vint16mf2_t, vint16mf2_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vsuxseg5ei64_v)))
void vsuxseg5ei64_v_i16mf4(int16_t *, vuint64m1_t, vint16mf4_t, vint16mf4_t, vint16mf4_t, vint16mf4_t, vint16mf4_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vsuxseg5ei64_v_m)))
void vsuxseg5ei64_v_i16mf4_m(vbool64_t, int16_t *, vuint64m1_t, vint16mf4_t, vint16mf4_t, vint16mf4_t, vint16mf4_t, vint16mf4_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vsuxseg5ei64_v)))
void vsuxseg5ei64_v_u16m1(uint16_t *, vuint64m4_t, vuint16m1_t, vuint16m1_t, vuint16m1_t, vuint16m1_t, vuint16m1_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vsuxseg5ei64_v_m)))
void vsuxseg5ei64_v_u16m1_m(vbool16_t, uint16_t *, vuint64m4_t, vuint16m1_t, vuint16m1_t, vuint16m1_t, vuint16m1_t, vuint16m1_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vsuxseg5ei64_v)))
void vsuxseg5ei64_v_u16mf2(uint16_t *, vuint64m2_t, vuint16mf2_t, vuint16mf2_t, vuint16mf2_t, vuint16mf2_t, vuint16mf2_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vsuxseg5ei64_v_m)))
void vsuxseg5ei64_v_u16mf2_m(vbool32_t, uint16_t *, vuint64m2_t, vuint16mf2_t, vuint16mf2_t, vuint16mf2_t, vuint16mf2_t, vuint16mf2_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vsuxseg5ei64_v)))
void vsuxseg5ei64_v_u16mf4(uint16_t *, vuint64m1_t, vuint16mf4_t, vuint16mf4_t, vuint16mf4_t, vuint16mf4_t, vuint16mf4_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vsuxseg5ei64_v_m)))
void vsuxseg5ei64_v_u16mf4_m(vbool64_t, uint16_t *, vuint64m1_t, vuint16mf4_t, vuint16mf4_t, vuint16mf4_t, vuint16mf4_t, vuint16mf4_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vsuxseg6ei64_v)))
void vsuxseg6ei64_v_i16m1(int16_t *, vuint64m4_t, vint16m1_t, vint16m1_t, vint16m1_t, vint16m1_t, vint16m1_t, vint16m1_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vsuxseg6ei64_v_m)))
void vsuxseg6ei64_v_i16m1_m(vbool16_t, int16_t *, vuint64m4_t, vint16m1_t, vint16m1_t, vint16m1_t, vint16m1_t, vint16m1_t, vint16m1_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vsuxseg6ei64_v)))
void vsuxseg6ei64_v_i16mf2(int16_t *, vuint64m2_t, vint16mf2_t, vint16mf2_t, vint16mf2_t, vint16mf2_t, vint16mf2_t, vint16mf2_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vsuxseg6ei64_v_m)))
void vsuxseg6ei64_v_i16mf2_m(vbool32_t, int16_t *, vuint64m2_t, vint16mf2_t, vint16mf2_t, vint16mf2_t, vint16mf2_t, vint16mf2_t, vint16mf2_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vsuxseg6ei64_v)))
void vsuxseg6ei64_v_i16mf4(int16_t *, vuint64m1_t, vint16mf4_t, vint16mf4_t, vint16mf4_t, vint16mf4_t, vint16mf4_t, vint16mf4_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vsuxseg6ei64_v_m)))
void vsuxseg6ei64_v_i16mf4_m(vbool64_t, int16_t *, vuint64m1_t, vint16mf4_t, vint16mf4_t, vint16mf4_t, vint16mf4_t, vint16mf4_t, vint16mf4_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vsuxseg6ei64_v)))
void vsuxseg6ei64_v_u16m1(uint16_t *, vuint64m4_t, vuint16m1_t, vuint16m1_t, vuint16m1_t, vuint16m1_t, vuint16m1_t, vuint16m1_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vsuxseg6ei64_v_m)))
void vsuxseg6ei64_v_u16m1_m(vbool16_t, uint16_t *, vuint64m4_t, vuint16m1_t, vuint16m1_t, vuint16m1_t, vuint16m1_t, vuint16m1_t, vuint16m1_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vsuxseg6ei64_v)))
void vsuxseg6ei64_v_u16mf2(uint16_t *, vuint64m2_t, vuint16mf2_t, vuint16mf2_t, vuint16mf2_t, vuint16mf2_t, vuint16mf2_t, vuint16mf2_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vsuxseg6ei64_v_m)))
void vsuxseg6ei64_v_u16mf2_m(vbool32_t, uint16_t *, vuint64m2_t, vuint16mf2_t, vuint16mf2_t, vuint16mf2_t, vuint16mf2_t, vuint16mf2_t, vuint16mf2_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vsuxseg6ei64_v)))
void vsuxseg6ei64_v_u16mf4(uint16_t *, vuint64m1_t, vuint16mf4_t, vuint16mf4_t, vuint16mf4_t, vuint16mf4_t, vuint16mf4_t, vuint16mf4_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vsuxseg6ei64_v_m)))
void vsuxseg6ei64_v_u16mf4_m(vbool64_t, uint16_t *, vuint64m1_t, vuint16mf4_t, vuint16mf4_t, vuint16mf4_t, vuint16mf4_t, vuint16mf4_t, vuint16mf4_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vsuxseg7ei64_v)))
void vsuxseg7ei64_v_i16m1(int16_t *, vuint64m4_t, vint16m1_t, vint16m1_t, vint16m1_t, vint16m1_t, vint16m1_t, vint16m1_t, vint16m1_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vsuxseg7ei64_v_m)))
void vsuxseg7ei64_v_i16m1_m(vbool16_t, int16_t *, vuint64m4_t, vint16m1_t, vint16m1_t, vint16m1_t, vint16m1_t, vint16m1_t, vint16m1_t, vint16m1_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vsuxseg7ei64_v)))
void vsuxseg7ei64_v_i16mf2(int16_t *, vuint64m2_t, vint16mf2_t, vint16mf2_t, vint16mf2_t, vint16mf2_t, vint16mf2_t, vint16mf2_t, vint16mf2_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vsuxseg7ei64_v_m)))
void vsuxseg7ei64_v_i16mf2_m(vbool32_t, int16_t *, vuint64m2_t, vint16mf2_t, vint16mf2_t, vint16mf2_t, vint16mf2_t, vint16mf2_t, vint16mf2_t, vint16mf2_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vsuxseg7ei64_v)))
void vsuxseg7ei64_v_i16mf4(int16_t *, vuint64m1_t, vint16mf4_t, vint16mf4_t, vint16mf4_t, vint16mf4_t, vint16mf4_t, vint16mf4_t, vint16mf4_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vsuxseg7ei64_v_m)))
void vsuxseg7ei64_v_i16mf4_m(vbool64_t, int16_t *, vuint64m1_t, vint16mf4_t, vint16mf4_t, vint16mf4_t, vint16mf4_t, vint16mf4_t, vint16mf4_t, vint16mf4_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vsuxseg7ei64_v)))
void vsuxseg7ei64_v_u16m1(uint16_t *, vuint64m4_t, vuint16m1_t, vuint16m1_t, vuint16m1_t, vuint16m1_t, vuint16m1_t, vuint16m1_t, vuint16m1_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vsuxseg7ei64_v_m)))
void vsuxseg7ei64_v_u16m1_m(vbool16_t, uint16_t *, vuint64m4_t, vuint16m1_t, vuint16m1_t, vuint16m1_t, vuint16m1_t, vuint16m1_t, vuint16m1_t, vuint16m1_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vsuxseg7ei64_v)))
void vsuxseg7ei64_v_u16mf2(uint16_t *, vuint64m2_t, vuint16mf2_t, vuint16mf2_t, vuint16mf2_t, vuint16mf2_t, vuint16mf2_t, vuint16mf2_t, vuint16mf2_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vsuxseg7ei64_v_m)))
void vsuxseg7ei64_v_u16mf2_m(vbool32_t, uint16_t *, vuint64m2_t, vuint16mf2_t, vuint16mf2_t, vuint16mf2_t, vuint16mf2_t, vuint16mf2_t, vuint16mf2_t, vuint16mf2_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vsuxseg7ei64_v)))
void vsuxseg7ei64_v_u16mf4(uint16_t *, vuint64m1_t, vuint16mf4_t, vuint16mf4_t, vuint16mf4_t, vuint16mf4_t, vuint16mf4_t, vuint16mf4_t, vuint16mf4_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vsuxseg7ei64_v_m)))
void vsuxseg7ei64_v_u16mf4_m(vbool64_t, uint16_t *, vuint64m1_t, vuint16mf4_t, vuint16mf4_t, vuint16mf4_t, vuint16mf4_t, vuint16mf4_t, vuint16mf4_t, vuint16mf4_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vsuxseg8ei64_v)))
void vsuxseg8ei64_v_i16m1(int16_t *, vuint64m4_t, vint16m1_t, vint16m1_t, vint16m1_t, vint16m1_t, vint16m1_t, vint16m1_t, vint16m1_t, vint16m1_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vsuxseg8ei64_v_m)))
void vsuxseg8ei64_v_i16m1_m(vbool16_t, int16_t *, vuint64m4_t, vint16m1_t, vint16m1_t, vint16m1_t, vint16m1_t, vint16m1_t, vint16m1_t, vint16m1_t, vint16m1_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vsuxseg8ei64_v)))
void vsuxseg8ei64_v_i16mf2(int16_t *, vuint64m2_t, vint16mf2_t, vint16mf2_t, vint16mf2_t, vint16mf2_t, vint16mf2_t, vint16mf2_t, vint16mf2_t, vint16mf2_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vsuxseg8ei64_v_m)))
void vsuxseg8ei64_v_i16mf2_m(vbool32_t, int16_t *, vuint64m2_t, vint16mf2_t, vint16mf2_t, vint16mf2_t, vint16mf2_t, vint16mf2_t, vint16mf2_t, vint16mf2_t, vint16mf2_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vsuxseg8ei64_v)))
void vsuxseg8ei64_v_i16mf4(int16_t *, vuint64m1_t, vint16mf4_t, vint16mf4_t, vint16mf4_t, vint16mf4_t, vint16mf4_t, vint16mf4_t, vint16mf4_t, vint16mf4_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vsuxseg8ei64_v_m)))
void vsuxseg8ei64_v_i16mf4_m(vbool64_t, int16_t *, vuint64m1_t, vint16mf4_t, vint16mf4_t, vint16mf4_t, vint16mf4_t, vint16mf4_t, vint16mf4_t, vint16mf4_t, vint16mf4_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vsuxseg8ei64_v)))
void vsuxseg8ei64_v_u16m1(uint16_t *, vuint64m4_t, vuint16m1_t, vuint16m1_t, vuint16m1_t, vuint16m1_t, vuint16m1_t, vuint16m1_t, vuint16m1_t, vuint16m1_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vsuxseg8ei64_v_m)))
void vsuxseg8ei64_v_u16m1_m(vbool16_t, uint16_t *, vuint64m4_t, vuint16m1_t, vuint16m1_t, vuint16m1_t, vuint16m1_t, vuint16m1_t, vuint16m1_t, vuint16m1_t, vuint16m1_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vsuxseg8ei64_v)))
void vsuxseg8ei64_v_u16mf2(uint16_t *, vuint64m2_t, vuint16mf2_t, vuint16mf2_t, vuint16mf2_t, vuint16mf2_t, vuint16mf2_t, vuint16mf2_t, vuint16mf2_t, vuint16mf2_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vsuxseg8ei64_v_m)))
void vsuxseg8ei64_v_u16mf2_m(vbool32_t, uint16_t *, vuint64m2_t, vuint16mf2_t, vuint16mf2_t, vuint16mf2_t, vuint16mf2_t, vuint16mf2_t, vuint16mf2_t, vuint16mf2_t, vuint16mf2_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vsuxseg8ei64_v)))
void vsuxseg8ei64_v_u16mf4(uint16_t *, vuint64m1_t, vuint16mf4_t, vuint16mf4_t, vuint16mf4_t, vuint16mf4_t, vuint16mf4_t, vuint16mf4_t, vuint16mf4_t, vuint16mf4_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vsuxseg8ei64_v_m)))
void vsuxseg8ei64_v_u16mf4_m(vbool64_t, uint16_t *, vuint64m1_t, vuint16mf4_t, vuint16mf4_t, vuint16mf4_t, vuint16mf4_t, vuint16mf4_t, vuint16mf4_t, vuint16mf4_t, vuint16mf4_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vsuxseg2ei64_v)))
void vsuxseg2ei64_v_i32m1(int32_t *, vuint64m2_t, vint32m1_t, vint32m1_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vsuxseg2ei64_v_m)))
void vsuxseg2ei64_v_i32m1_m(vbool32_t, int32_t *, vuint64m2_t, vint32m1_t, vint32m1_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vsuxseg2ei64_v)))
void vsuxseg2ei64_v_i32m2(int32_t *, vuint64m4_t, vint32m2_t, vint32m2_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vsuxseg2ei64_v_m)))
void vsuxseg2ei64_v_i32m2_m(vbool16_t, int32_t *, vuint64m4_t, vint32m2_t, vint32m2_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vsuxseg2ei64_v)))
void vsuxseg2ei64_v_i32m4(int32_t *, vuint64m8_t, vint32m4_t, vint32m4_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vsuxseg2ei64_v_m)))
void vsuxseg2ei64_v_i32m4_m(vbool8_t, int32_t *, vuint64m8_t, vint32m4_t, vint32m4_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vsuxseg2ei64_v)))
void vsuxseg2ei64_v_i32mf2(int32_t *, vuint64m1_t, vint32mf2_t, vint32mf2_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vsuxseg2ei64_v_m)))
void vsuxseg2ei64_v_i32mf2_m(vbool64_t, int32_t *, vuint64m1_t, vint32mf2_t, vint32mf2_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vsuxseg2ei64_v)))
void vsuxseg2ei64_v_u32m1(uint32_t *, vuint64m2_t, vuint32m1_t, vuint32m1_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vsuxseg2ei64_v_m)))
void vsuxseg2ei64_v_u32m1_m(vbool32_t, uint32_t *, vuint64m2_t, vuint32m1_t, vuint32m1_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vsuxseg2ei64_v)))
void vsuxseg2ei64_v_u32m2(uint32_t *, vuint64m4_t, vuint32m2_t, vuint32m2_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vsuxseg2ei64_v_m)))
void vsuxseg2ei64_v_u32m2_m(vbool16_t, uint32_t *, vuint64m4_t, vuint32m2_t, vuint32m2_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vsuxseg2ei64_v)))
void vsuxseg2ei64_v_u32m4(uint32_t *, vuint64m8_t, vuint32m4_t, vuint32m4_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vsuxseg2ei64_v_m)))
void vsuxseg2ei64_v_u32m4_m(vbool8_t, uint32_t *, vuint64m8_t, vuint32m4_t, vuint32m4_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vsuxseg2ei64_v)))
void vsuxseg2ei64_v_u32mf2(uint32_t *, vuint64m1_t, vuint32mf2_t, vuint32mf2_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vsuxseg2ei64_v_m)))
void vsuxseg2ei64_v_u32mf2_m(vbool64_t, uint32_t *, vuint64m1_t, vuint32mf2_t, vuint32mf2_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vsuxseg3ei64_v)))
void vsuxseg3ei64_v_i32m1(int32_t *, vuint64m2_t, vint32m1_t, vint32m1_t, vint32m1_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vsuxseg3ei64_v_m)))
void vsuxseg3ei64_v_i32m1_m(vbool32_t, int32_t *, vuint64m2_t, vint32m1_t, vint32m1_t, vint32m1_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vsuxseg3ei64_v)))
void vsuxseg3ei64_v_i32m2(int32_t *, vuint64m4_t, vint32m2_t, vint32m2_t, vint32m2_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vsuxseg3ei64_v_m)))
void vsuxseg3ei64_v_i32m2_m(vbool16_t, int32_t *, vuint64m4_t, vint32m2_t, vint32m2_t, vint32m2_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vsuxseg3ei64_v)))
void vsuxseg3ei64_v_i32mf2(int32_t *, vuint64m1_t, vint32mf2_t, vint32mf2_t, vint32mf2_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vsuxseg3ei64_v_m)))
void vsuxseg3ei64_v_i32mf2_m(vbool64_t, int32_t *, vuint64m1_t, vint32mf2_t, vint32mf2_t, vint32mf2_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vsuxseg3ei64_v)))
void vsuxseg3ei64_v_u32m1(uint32_t *, vuint64m2_t, vuint32m1_t, vuint32m1_t, vuint32m1_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vsuxseg3ei64_v_m)))
void vsuxseg3ei64_v_u32m1_m(vbool32_t, uint32_t *, vuint64m2_t, vuint32m1_t, vuint32m1_t, vuint32m1_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vsuxseg3ei64_v)))
void vsuxseg3ei64_v_u32m2(uint32_t *, vuint64m4_t, vuint32m2_t, vuint32m2_t, vuint32m2_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vsuxseg3ei64_v_m)))
void vsuxseg3ei64_v_u32m2_m(vbool16_t, uint32_t *, vuint64m4_t, vuint32m2_t, vuint32m2_t, vuint32m2_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vsuxseg3ei64_v)))
void vsuxseg3ei64_v_u32mf2(uint32_t *, vuint64m1_t, vuint32mf2_t, vuint32mf2_t, vuint32mf2_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vsuxseg3ei64_v_m)))
void vsuxseg3ei64_v_u32mf2_m(vbool64_t, uint32_t *, vuint64m1_t, vuint32mf2_t, vuint32mf2_t, vuint32mf2_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vsuxseg4ei64_v)))
void vsuxseg4ei64_v_i32m1(int32_t *, vuint64m2_t, vint32m1_t, vint32m1_t, vint32m1_t, vint32m1_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vsuxseg4ei64_v_m)))
void vsuxseg4ei64_v_i32m1_m(vbool32_t, int32_t *, vuint64m2_t, vint32m1_t, vint32m1_t, vint32m1_t, vint32m1_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vsuxseg4ei64_v)))
void vsuxseg4ei64_v_i32m2(int32_t *, vuint64m4_t, vint32m2_t, vint32m2_t, vint32m2_t, vint32m2_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vsuxseg4ei64_v_m)))
void vsuxseg4ei64_v_i32m2_m(vbool16_t, int32_t *, vuint64m4_t, vint32m2_t, vint32m2_t, vint32m2_t, vint32m2_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vsuxseg4ei64_v)))
void vsuxseg4ei64_v_i32mf2(int32_t *, vuint64m1_t, vint32mf2_t, vint32mf2_t, vint32mf2_t, vint32mf2_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vsuxseg4ei64_v_m)))
void vsuxseg4ei64_v_i32mf2_m(vbool64_t, int32_t *, vuint64m1_t, vint32mf2_t, vint32mf2_t, vint32mf2_t, vint32mf2_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vsuxseg4ei64_v)))
void vsuxseg4ei64_v_u32m1(uint32_t *, vuint64m2_t, vuint32m1_t, vuint32m1_t, vuint32m1_t, vuint32m1_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vsuxseg4ei64_v_m)))
void vsuxseg4ei64_v_u32m1_m(vbool32_t, uint32_t *, vuint64m2_t, vuint32m1_t, vuint32m1_t, vuint32m1_t, vuint32m1_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vsuxseg4ei64_v)))
void vsuxseg4ei64_v_u32m2(uint32_t *, vuint64m4_t, vuint32m2_t, vuint32m2_t, vuint32m2_t, vuint32m2_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vsuxseg4ei64_v_m)))
void vsuxseg4ei64_v_u32m2_m(vbool16_t, uint32_t *, vuint64m4_t, vuint32m2_t, vuint32m2_t, vuint32m2_t, vuint32m2_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vsuxseg4ei64_v)))
void vsuxseg4ei64_v_u32mf2(uint32_t *, vuint64m1_t, vuint32mf2_t, vuint32mf2_t, vuint32mf2_t, vuint32mf2_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vsuxseg4ei64_v_m)))
void vsuxseg4ei64_v_u32mf2_m(vbool64_t, uint32_t *, vuint64m1_t, vuint32mf2_t, vuint32mf2_t, vuint32mf2_t, vuint32mf2_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vsuxseg5ei64_v)))
void vsuxseg5ei64_v_i32m1(int32_t *, vuint64m2_t, vint32m1_t, vint32m1_t, vint32m1_t, vint32m1_t, vint32m1_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vsuxseg5ei64_v_m)))
void vsuxseg5ei64_v_i32m1_m(vbool32_t, int32_t *, vuint64m2_t, vint32m1_t, vint32m1_t, vint32m1_t, vint32m1_t, vint32m1_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vsuxseg5ei64_v)))
void vsuxseg5ei64_v_i32mf2(int32_t *, vuint64m1_t, vint32mf2_t, vint32mf2_t, vint32mf2_t, vint32mf2_t, vint32mf2_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vsuxseg5ei64_v_m)))
void vsuxseg5ei64_v_i32mf2_m(vbool64_t, int32_t *, vuint64m1_t, vint32mf2_t, vint32mf2_t, vint32mf2_t, vint32mf2_t, vint32mf2_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vsuxseg5ei64_v)))
void vsuxseg5ei64_v_u32m1(uint32_t *, vuint64m2_t, vuint32m1_t, vuint32m1_t, vuint32m1_t, vuint32m1_t, vuint32m1_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vsuxseg5ei64_v_m)))
void vsuxseg5ei64_v_u32m1_m(vbool32_t, uint32_t *, vuint64m2_t, vuint32m1_t, vuint32m1_t, vuint32m1_t, vuint32m1_t, vuint32m1_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vsuxseg5ei64_v)))
void vsuxseg5ei64_v_u32mf2(uint32_t *, vuint64m1_t, vuint32mf2_t, vuint32mf2_t, vuint32mf2_t, vuint32mf2_t, vuint32mf2_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vsuxseg5ei64_v_m)))
void vsuxseg5ei64_v_u32mf2_m(vbool64_t, uint32_t *, vuint64m1_t, vuint32mf2_t, vuint32mf2_t, vuint32mf2_t, vuint32mf2_t, vuint32mf2_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vsuxseg6ei64_v)))
void vsuxseg6ei64_v_i32m1(int32_t *, vuint64m2_t, vint32m1_t, vint32m1_t, vint32m1_t, vint32m1_t, vint32m1_t, vint32m1_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vsuxseg6ei64_v_m)))
void vsuxseg6ei64_v_i32m1_m(vbool32_t, int32_t *, vuint64m2_t, vint32m1_t, vint32m1_t, vint32m1_t, vint32m1_t, vint32m1_t, vint32m1_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vsuxseg6ei64_v)))
void vsuxseg6ei64_v_i32mf2(int32_t *, vuint64m1_t, vint32mf2_t, vint32mf2_t, vint32mf2_t, vint32mf2_t, vint32mf2_t, vint32mf2_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vsuxseg6ei64_v_m)))
void vsuxseg6ei64_v_i32mf2_m(vbool64_t, int32_t *, vuint64m1_t, vint32mf2_t, vint32mf2_t, vint32mf2_t, vint32mf2_t, vint32mf2_t, vint32mf2_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vsuxseg6ei64_v)))
void vsuxseg6ei64_v_u32m1(uint32_t *, vuint64m2_t, vuint32m1_t, vuint32m1_t, vuint32m1_t, vuint32m1_t, vuint32m1_t, vuint32m1_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vsuxseg6ei64_v_m)))
void vsuxseg6ei64_v_u32m1_m(vbool32_t, uint32_t *, vuint64m2_t, vuint32m1_t, vuint32m1_t, vuint32m1_t, vuint32m1_t, vuint32m1_t, vuint32m1_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vsuxseg6ei64_v)))
void vsuxseg6ei64_v_u32mf2(uint32_t *, vuint64m1_t, vuint32mf2_t, vuint32mf2_t, vuint32mf2_t, vuint32mf2_t, vuint32mf2_t, vuint32mf2_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vsuxseg6ei64_v_m)))
void vsuxseg6ei64_v_u32mf2_m(vbool64_t, uint32_t *, vuint64m1_t, vuint32mf2_t, vuint32mf2_t, vuint32mf2_t, vuint32mf2_t, vuint32mf2_t, vuint32mf2_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vsuxseg7ei64_v)))
void vsuxseg7ei64_v_i32m1(int32_t *, vuint64m2_t, vint32m1_t, vint32m1_t, vint32m1_t, vint32m1_t, vint32m1_t, vint32m1_t, vint32m1_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vsuxseg7ei64_v_m)))
void vsuxseg7ei64_v_i32m1_m(vbool32_t, int32_t *, vuint64m2_t, vint32m1_t, vint32m1_t, vint32m1_t, vint32m1_t, vint32m1_t, vint32m1_t, vint32m1_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vsuxseg7ei64_v)))
void vsuxseg7ei64_v_i32mf2(int32_t *, vuint64m1_t, vint32mf2_t, vint32mf2_t, vint32mf2_t, vint32mf2_t, vint32mf2_t, vint32mf2_t, vint32mf2_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vsuxseg7ei64_v_m)))
void vsuxseg7ei64_v_i32mf2_m(vbool64_t, int32_t *, vuint64m1_t, vint32mf2_t, vint32mf2_t, vint32mf2_t, vint32mf2_t, vint32mf2_t, vint32mf2_t, vint32mf2_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vsuxseg7ei64_v)))
void vsuxseg7ei64_v_u32m1(uint32_t *, vuint64m2_t, vuint32m1_t, vuint32m1_t, vuint32m1_t, vuint32m1_t, vuint32m1_t, vuint32m1_t, vuint32m1_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vsuxseg7ei64_v_m)))
void vsuxseg7ei64_v_u32m1_m(vbool32_t, uint32_t *, vuint64m2_t, vuint32m1_t, vuint32m1_t, vuint32m1_t, vuint32m1_t, vuint32m1_t, vuint32m1_t, vuint32m1_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vsuxseg7ei64_v)))
void vsuxseg7ei64_v_u32mf2(uint32_t *, vuint64m1_t, vuint32mf2_t, vuint32mf2_t, vuint32mf2_t, vuint32mf2_t, vuint32mf2_t, vuint32mf2_t, vuint32mf2_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vsuxseg7ei64_v_m)))
void vsuxseg7ei64_v_u32mf2_m(vbool64_t, uint32_t *, vuint64m1_t, vuint32mf2_t, vuint32mf2_t, vuint32mf2_t, vuint32mf2_t, vuint32mf2_t, vuint32mf2_t, vuint32mf2_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vsuxseg8ei64_v)))
void vsuxseg8ei64_v_i32m1(int32_t *, vuint64m2_t, vint32m1_t, vint32m1_t, vint32m1_t, vint32m1_t, vint32m1_t, vint32m1_t, vint32m1_t, vint32m1_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vsuxseg8ei64_v_m)))
void vsuxseg8ei64_v_i32m1_m(vbool32_t, int32_t *, vuint64m2_t, vint32m1_t, vint32m1_t, vint32m1_t, vint32m1_t, vint32m1_t, vint32m1_t, vint32m1_t, vint32m1_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vsuxseg8ei64_v)))
void vsuxseg8ei64_v_i32mf2(int32_t *, vuint64m1_t, vint32mf2_t, vint32mf2_t, vint32mf2_t, vint32mf2_t, vint32mf2_t, vint32mf2_t, vint32mf2_t, vint32mf2_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vsuxseg8ei64_v_m)))
void vsuxseg8ei64_v_i32mf2_m(vbool64_t, int32_t *, vuint64m1_t, vint32mf2_t, vint32mf2_t, vint32mf2_t, vint32mf2_t, vint32mf2_t, vint32mf2_t, vint32mf2_t, vint32mf2_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vsuxseg8ei64_v)))
void vsuxseg8ei64_v_u32m1(uint32_t *, vuint64m2_t, vuint32m1_t, vuint32m1_t, vuint32m1_t, vuint32m1_t, vuint32m1_t, vuint32m1_t, vuint32m1_t, vuint32m1_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vsuxseg8ei64_v_m)))
void vsuxseg8ei64_v_u32m1_m(vbool32_t, uint32_t *, vuint64m2_t, vuint32m1_t, vuint32m1_t, vuint32m1_t, vuint32m1_t, vuint32m1_t, vuint32m1_t, vuint32m1_t, vuint32m1_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vsuxseg8ei64_v)))
void vsuxseg8ei64_v_u32mf2(uint32_t *, vuint64m1_t, vuint32mf2_t, vuint32mf2_t, vuint32mf2_t, vuint32mf2_t, vuint32mf2_t, vuint32mf2_t, vuint32mf2_t, vuint32mf2_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vsuxseg8ei64_v_m)))
void vsuxseg8ei64_v_u32mf2_m(vbool64_t, uint32_t *, vuint64m1_t, vuint32mf2_t, vuint32mf2_t, vuint32mf2_t, vuint32mf2_t, vuint32mf2_t, vuint32mf2_t, vuint32mf2_t, vuint32mf2_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vsuxseg2ei8_v)))
void vsuxseg2ei8_v_i64m1(int64_t *, vuint8mf8_t, vint64m1_t, vint64m1_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vsuxseg2ei8_v_m)))
void vsuxseg2ei8_v_i64m1_m(vbool64_t, int64_t *, vuint8mf8_t, vint64m1_t, vint64m1_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vsuxseg2ei8_v)))
void vsuxseg2ei8_v_i64m2(int64_t *, vuint8mf4_t, vint64m2_t, vint64m2_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vsuxseg2ei8_v_m)))
void vsuxseg2ei8_v_i64m2_m(vbool32_t, int64_t *, vuint8mf4_t, vint64m2_t, vint64m2_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vsuxseg2ei8_v)))
void vsuxseg2ei8_v_i64m4(int64_t *, vuint8mf2_t, vint64m4_t, vint64m4_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vsuxseg2ei8_v_m)))
void vsuxseg2ei8_v_i64m4_m(vbool16_t, int64_t *, vuint8mf2_t, vint64m4_t, vint64m4_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vsuxseg2ei8_v)))
void vsuxseg2ei8_v_u64m1(uint64_t *, vuint8mf8_t, vuint64m1_t, vuint64m1_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vsuxseg2ei8_v_m)))
void vsuxseg2ei8_v_u64m1_m(vbool64_t, uint64_t *, vuint8mf8_t, vuint64m1_t, vuint64m1_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vsuxseg2ei8_v)))
void vsuxseg2ei8_v_u64m2(uint64_t *, vuint8mf4_t, vuint64m2_t, vuint64m2_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vsuxseg2ei8_v_m)))
void vsuxseg2ei8_v_u64m2_m(vbool32_t, uint64_t *, vuint8mf4_t, vuint64m2_t, vuint64m2_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vsuxseg2ei8_v)))
void vsuxseg2ei8_v_u64m4(uint64_t *, vuint8mf2_t, vuint64m4_t, vuint64m4_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vsuxseg2ei8_v_m)))
void vsuxseg2ei8_v_u64m4_m(vbool16_t, uint64_t *, vuint8mf2_t, vuint64m4_t, vuint64m4_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vsuxseg3ei8_v)))
void vsuxseg3ei8_v_i64m1(int64_t *, vuint8mf8_t, vint64m1_t, vint64m1_t, vint64m1_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vsuxseg3ei8_v_m)))
void vsuxseg3ei8_v_i64m1_m(vbool64_t, int64_t *, vuint8mf8_t, vint64m1_t, vint64m1_t, vint64m1_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vsuxseg3ei8_v)))
void vsuxseg3ei8_v_i64m2(int64_t *, vuint8mf4_t, vint64m2_t, vint64m2_t, vint64m2_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vsuxseg3ei8_v_m)))
void vsuxseg3ei8_v_i64m2_m(vbool32_t, int64_t *, vuint8mf4_t, vint64m2_t, vint64m2_t, vint64m2_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vsuxseg3ei8_v)))
void vsuxseg3ei8_v_u64m1(uint64_t *, vuint8mf8_t, vuint64m1_t, vuint64m1_t, vuint64m1_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vsuxseg3ei8_v_m)))
void vsuxseg3ei8_v_u64m1_m(vbool64_t, uint64_t *, vuint8mf8_t, vuint64m1_t, vuint64m1_t, vuint64m1_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vsuxseg3ei8_v)))
void vsuxseg3ei8_v_u64m2(uint64_t *, vuint8mf4_t, vuint64m2_t, vuint64m2_t, vuint64m2_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vsuxseg3ei8_v_m)))
void vsuxseg3ei8_v_u64m2_m(vbool32_t, uint64_t *, vuint8mf4_t, vuint64m2_t, vuint64m2_t, vuint64m2_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vsuxseg4ei8_v)))
void vsuxseg4ei8_v_i64m1(int64_t *, vuint8mf8_t, vint64m1_t, vint64m1_t, vint64m1_t, vint64m1_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vsuxseg4ei8_v_m)))
void vsuxseg4ei8_v_i64m1_m(vbool64_t, int64_t *, vuint8mf8_t, vint64m1_t, vint64m1_t, vint64m1_t, vint64m1_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vsuxseg4ei8_v)))
void vsuxseg4ei8_v_i64m2(int64_t *, vuint8mf4_t, vint64m2_t, vint64m2_t, vint64m2_t, vint64m2_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vsuxseg4ei8_v_m)))
void vsuxseg4ei8_v_i64m2_m(vbool32_t, int64_t *, vuint8mf4_t, vint64m2_t, vint64m2_t, vint64m2_t, vint64m2_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vsuxseg4ei8_v)))
void vsuxseg4ei8_v_u64m1(uint64_t *, vuint8mf8_t, vuint64m1_t, vuint64m1_t, vuint64m1_t, vuint64m1_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vsuxseg4ei8_v_m)))
void vsuxseg4ei8_v_u64m1_m(vbool64_t, uint64_t *, vuint8mf8_t, vuint64m1_t, vuint64m1_t, vuint64m1_t, vuint64m1_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vsuxseg4ei8_v)))
void vsuxseg4ei8_v_u64m2(uint64_t *, vuint8mf4_t, vuint64m2_t, vuint64m2_t, vuint64m2_t, vuint64m2_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vsuxseg4ei8_v_m)))
void vsuxseg4ei8_v_u64m2_m(vbool32_t, uint64_t *, vuint8mf4_t, vuint64m2_t, vuint64m2_t, vuint64m2_t, vuint64m2_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vsuxseg5ei8_v)))
void vsuxseg5ei8_v_i64m1(int64_t *, vuint8mf8_t, vint64m1_t, vint64m1_t, vint64m1_t, vint64m1_t, vint64m1_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vsuxseg5ei8_v_m)))
void vsuxseg5ei8_v_i64m1_m(vbool64_t, int64_t *, vuint8mf8_t, vint64m1_t, vint64m1_t, vint64m1_t, vint64m1_t, vint64m1_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vsuxseg5ei8_v)))
void vsuxseg5ei8_v_u64m1(uint64_t *, vuint8mf8_t, vuint64m1_t, vuint64m1_t, vuint64m1_t, vuint64m1_t, vuint64m1_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vsuxseg5ei8_v_m)))
void vsuxseg5ei8_v_u64m1_m(vbool64_t, uint64_t *, vuint8mf8_t, vuint64m1_t, vuint64m1_t, vuint64m1_t, vuint64m1_t, vuint64m1_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vsuxseg6ei8_v)))
void vsuxseg6ei8_v_i64m1(int64_t *, vuint8mf8_t, vint64m1_t, vint64m1_t, vint64m1_t, vint64m1_t, vint64m1_t, vint64m1_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vsuxseg6ei8_v_m)))
void vsuxseg6ei8_v_i64m1_m(vbool64_t, int64_t *, vuint8mf8_t, vint64m1_t, vint64m1_t, vint64m1_t, vint64m1_t, vint64m1_t, vint64m1_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vsuxseg6ei8_v)))
void vsuxseg6ei8_v_u64m1(uint64_t *, vuint8mf8_t, vuint64m1_t, vuint64m1_t, vuint64m1_t, vuint64m1_t, vuint64m1_t, vuint64m1_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vsuxseg6ei8_v_m)))
void vsuxseg6ei8_v_u64m1_m(vbool64_t, uint64_t *, vuint8mf8_t, vuint64m1_t, vuint64m1_t, vuint64m1_t, vuint64m1_t, vuint64m1_t, vuint64m1_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vsuxseg7ei8_v)))
void vsuxseg7ei8_v_i64m1(int64_t *, vuint8mf8_t, vint64m1_t, vint64m1_t, vint64m1_t, vint64m1_t, vint64m1_t, vint64m1_t, vint64m1_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vsuxseg7ei8_v_m)))
void vsuxseg7ei8_v_i64m1_m(vbool64_t, int64_t *, vuint8mf8_t, vint64m1_t, vint64m1_t, vint64m1_t, vint64m1_t, vint64m1_t, vint64m1_t, vint64m1_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vsuxseg7ei8_v)))
void vsuxseg7ei8_v_u64m1(uint64_t *, vuint8mf8_t, vuint64m1_t, vuint64m1_t, vuint64m1_t, vuint64m1_t, vuint64m1_t, vuint64m1_t, vuint64m1_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vsuxseg7ei8_v_m)))
void vsuxseg7ei8_v_u64m1_m(vbool64_t, uint64_t *, vuint8mf8_t, vuint64m1_t, vuint64m1_t, vuint64m1_t, vuint64m1_t, vuint64m1_t, vuint64m1_t, vuint64m1_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vsuxseg8ei8_v)))
void vsuxseg8ei8_v_i64m1(int64_t *, vuint8mf8_t, vint64m1_t, vint64m1_t, vint64m1_t, vint64m1_t, vint64m1_t, vint64m1_t, vint64m1_t, vint64m1_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vsuxseg8ei8_v_m)))
void vsuxseg8ei8_v_i64m1_m(vbool64_t, int64_t *, vuint8mf8_t, vint64m1_t, vint64m1_t, vint64m1_t, vint64m1_t, vint64m1_t, vint64m1_t, vint64m1_t, vint64m1_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vsuxseg8ei8_v)))
void vsuxseg8ei8_v_u64m1(uint64_t *, vuint8mf8_t, vuint64m1_t, vuint64m1_t, vuint64m1_t, vuint64m1_t, vuint64m1_t, vuint64m1_t, vuint64m1_t, vuint64m1_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vsuxseg8ei8_v_m)))
void vsuxseg8ei8_v_u64m1_m(vbool64_t, uint64_t *, vuint8mf8_t, vuint64m1_t, vuint64m1_t, vuint64m1_t, vuint64m1_t, vuint64m1_t, vuint64m1_t, vuint64m1_t, vuint64m1_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vsuxseg2ei16_v)))
void vsuxseg2ei16_v_i64m1(int64_t *, vuint16mf4_t, vint64m1_t, vint64m1_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vsuxseg2ei16_v_m)))
void vsuxseg2ei16_v_i64m1_m(vbool64_t, int64_t *, vuint16mf4_t, vint64m1_t, vint64m1_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vsuxseg2ei16_v)))
void vsuxseg2ei16_v_i64m2(int64_t *, vuint16mf2_t, vint64m2_t, vint64m2_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vsuxseg2ei16_v_m)))
void vsuxseg2ei16_v_i64m2_m(vbool32_t, int64_t *, vuint16mf2_t, vint64m2_t, vint64m2_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vsuxseg2ei16_v)))
void vsuxseg2ei16_v_i64m4(int64_t *, vuint16m1_t, vint64m4_t, vint64m4_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vsuxseg2ei16_v_m)))
void vsuxseg2ei16_v_i64m4_m(vbool16_t, int64_t *, vuint16m1_t, vint64m4_t, vint64m4_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vsuxseg2ei16_v)))
void vsuxseg2ei16_v_u64m1(uint64_t *, vuint16mf4_t, vuint64m1_t, vuint64m1_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vsuxseg2ei16_v_m)))
void vsuxseg2ei16_v_u64m1_m(vbool64_t, uint64_t *, vuint16mf4_t, vuint64m1_t, vuint64m1_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vsuxseg2ei16_v)))
void vsuxseg2ei16_v_u64m2(uint64_t *, vuint16mf2_t, vuint64m2_t, vuint64m2_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vsuxseg2ei16_v_m)))
void vsuxseg2ei16_v_u64m2_m(vbool32_t, uint64_t *, vuint16mf2_t, vuint64m2_t, vuint64m2_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vsuxseg2ei16_v)))
void vsuxseg2ei16_v_u64m4(uint64_t *, vuint16m1_t, vuint64m4_t, vuint64m4_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vsuxseg2ei16_v_m)))
void vsuxseg2ei16_v_u64m4_m(vbool16_t, uint64_t *, vuint16m1_t, vuint64m4_t, vuint64m4_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vsuxseg3ei16_v)))
void vsuxseg3ei16_v_i64m1(int64_t *, vuint16mf4_t, vint64m1_t, vint64m1_t, vint64m1_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vsuxseg3ei16_v_m)))
void vsuxseg3ei16_v_i64m1_m(vbool64_t, int64_t *, vuint16mf4_t, vint64m1_t, vint64m1_t, vint64m1_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vsuxseg3ei16_v)))
void vsuxseg3ei16_v_i64m2(int64_t *, vuint16mf2_t, vint64m2_t, vint64m2_t, vint64m2_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vsuxseg3ei16_v_m)))
void vsuxseg3ei16_v_i64m2_m(vbool32_t, int64_t *, vuint16mf2_t, vint64m2_t, vint64m2_t, vint64m2_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vsuxseg3ei16_v)))
void vsuxseg3ei16_v_u64m1(uint64_t *, vuint16mf4_t, vuint64m1_t, vuint64m1_t, vuint64m1_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vsuxseg3ei16_v_m)))
void vsuxseg3ei16_v_u64m1_m(vbool64_t, uint64_t *, vuint16mf4_t, vuint64m1_t, vuint64m1_t, vuint64m1_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vsuxseg3ei16_v)))
void vsuxseg3ei16_v_u64m2(uint64_t *, vuint16mf2_t, vuint64m2_t, vuint64m2_t, vuint64m2_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vsuxseg3ei16_v_m)))
void vsuxseg3ei16_v_u64m2_m(vbool32_t, uint64_t *, vuint16mf2_t, vuint64m2_t, vuint64m2_t, vuint64m2_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vsuxseg4ei16_v)))
void vsuxseg4ei16_v_i64m1(int64_t *, vuint16mf4_t, vint64m1_t, vint64m1_t, vint64m1_t, vint64m1_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vsuxseg4ei16_v_m)))
void vsuxseg4ei16_v_i64m1_m(vbool64_t, int64_t *, vuint16mf4_t, vint64m1_t, vint64m1_t, vint64m1_t, vint64m1_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vsuxseg4ei16_v)))
void vsuxseg4ei16_v_i64m2(int64_t *, vuint16mf2_t, vint64m2_t, vint64m2_t, vint64m2_t, vint64m2_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vsuxseg4ei16_v_m)))
void vsuxseg4ei16_v_i64m2_m(vbool32_t, int64_t *, vuint16mf2_t, vint64m2_t, vint64m2_t, vint64m2_t, vint64m2_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vsuxseg4ei16_v)))
void vsuxseg4ei16_v_u64m1(uint64_t *, vuint16mf4_t, vuint64m1_t, vuint64m1_t, vuint64m1_t, vuint64m1_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vsuxseg4ei16_v_m)))
void vsuxseg4ei16_v_u64m1_m(vbool64_t, uint64_t *, vuint16mf4_t, vuint64m1_t, vuint64m1_t, vuint64m1_t, vuint64m1_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vsuxseg4ei16_v)))
void vsuxseg4ei16_v_u64m2(uint64_t *, vuint16mf2_t, vuint64m2_t, vuint64m2_t, vuint64m2_t, vuint64m2_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vsuxseg4ei16_v_m)))
void vsuxseg4ei16_v_u64m2_m(vbool32_t, uint64_t *, vuint16mf2_t, vuint64m2_t, vuint64m2_t, vuint64m2_t, vuint64m2_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vsuxseg5ei16_v)))
void vsuxseg5ei16_v_i64m1(int64_t *, vuint16mf4_t, vint64m1_t, vint64m1_t, vint64m1_t, vint64m1_t, vint64m1_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vsuxseg5ei16_v_m)))
void vsuxseg5ei16_v_i64m1_m(vbool64_t, int64_t *, vuint16mf4_t, vint64m1_t, vint64m1_t, vint64m1_t, vint64m1_t, vint64m1_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vsuxseg5ei16_v)))
void vsuxseg5ei16_v_u64m1(uint64_t *, vuint16mf4_t, vuint64m1_t, vuint64m1_t, vuint64m1_t, vuint64m1_t, vuint64m1_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vsuxseg5ei16_v_m)))
void vsuxseg5ei16_v_u64m1_m(vbool64_t, uint64_t *, vuint16mf4_t, vuint64m1_t, vuint64m1_t, vuint64m1_t, vuint64m1_t, vuint64m1_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vsuxseg6ei16_v)))
void vsuxseg6ei16_v_i64m1(int64_t *, vuint16mf4_t, vint64m1_t, vint64m1_t, vint64m1_t, vint64m1_t, vint64m1_t, vint64m1_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vsuxseg6ei16_v_m)))
void vsuxseg6ei16_v_i64m1_m(vbool64_t, int64_t *, vuint16mf4_t, vint64m1_t, vint64m1_t, vint64m1_t, vint64m1_t, vint64m1_t, vint64m1_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vsuxseg6ei16_v)))
void vsuxseg6ei16_v_u64m1(uint64_t *, vuint16mf4_t, vuint64m1_t, vuint64m1_t, vuint64m1_t, vuint64m1_t, vuint64m1_t, vuint64m1_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vsuxseg6ei16_v_m)))
void vsuxseg6ei16_v_u64m1_m(vbool64_t, uint64_t *, vuint16mf4_t, vuint64m1_t, vuint64m1_t, vuint64m1_t, vuint64m1_t, vuint64m1_t, vuint64m1_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vsuxseg7ei16_v)))
void vsuxseg7ei16_v_i64m1(int64_t *, vuint16mf4_t, vint64m1_t, vint64m1_t, vint64m1_t, vint64m1_t, vint64m1_t, vint64m1_t, vint64m1_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vsuxseg7ei16_v_m)))
void vsuxseg7ei16_v_i64m1_m(vbool64_t, int64_t *, vuint16mf4_t, vint64m1_t, vint64m1_t, vint64m1_t, vint64m1_t, vint64m1_t, vint64m1_t, vint64m1_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vsuxseg7ei16_v)))
void vsuxseg7ei16_v_u64m1(uint64_t *, vuint16mf4_t, vuint64m1_t, vuint64m1_t, vuint64m1_t, vuint64m1_t, vuint64m1_t, vuint64m1_t, vuint64m1_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vsuxseg7ei16_v_m)))
void vsuxseg7ei16_v_u64m1_m(vbool64_t, uint64_t *, vuint16mf4_t, vuint64m1_t, vuint64m1_t, vuint64m1_t, vuint64m1_t, vuint64m1_t, vuint64m1_t, vuint64m1_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vsuxseg8ei16_v)))
void vsuxseg8ei16_v_i64m1(int64_t *, vuint16mf4_t, vint64m1_t, vint64m1_t, vint64m1_t, vint64m1_t, vint64m1_t, vint64m1_t, vint64m1_t, vint64m1_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vsuxseg8ei16_v_m)))
void vsuxseg8ei16_v_i64m1_m(vbool64_t, int64_t *, vuint16mf4_t, vint64m1_t, vint64m1_t, vint64m1_t, vint64m1_t, vint64m1_t, vint64m1_t, vint64m1_t, vint64m1_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vsuxseg8ei16_v)))
void vsuxseg8ei16_v_u64m1(uint64_t *, vuint16mf4_t, vuint64m1_t, vuint64m1_t, vuint64m1_t, vuint64m1_t, vuint64m1_t, vuint64m1_t, vuint64m1_t, vuint64m1_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vsuxseg8ei16_v_m)))
void vsuxseg8ei16_v_u64m1_m(vbool64_t, uint64_t *, vuint16mf4_t, vuint64m1_t, vuint64m1_t, vuint64m1_t, vuint64m1_t, vuint64m1_t, vuint64m1_t, vuint64m1_t, vuint64m1_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vsuxseg2ei32_v)))
void vsuxseg2ei32_v_i64m1(int64_t *, vuint32mf2_t, vint64m1_t, vint64m1_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vsuxseg2ei32_v_m)))
void vsuxseg2ei32_v_i64m1_m(vbool64_t, int64_t *, vuint32mf2_t, vint64m1_t, vint64m1_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vsuxseg2ei32_v)))
void vsuxseg2ei32_v_i64m2(int64_t *, vuint32m1_t, vint64m2_t, vint64m2_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vsuxseg2ei32_v_m)))
void vsuxseg2ei32_v_i64m2_m(vbool32_t, int64_t *, vuint32m1_t, vint64m2_t, vint64m2_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vsuxseg2ei32_v)))
void vsuxseg2ei32_v_i64m4(int64_t *, vuint32m2_t, vint64m4_t, vint64m4_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vsuxseg2ei32_v_m)))
void vsuxseg2ei32_v_i64m4_m(vbool16_t, int64_t *, vuint32m2_t, vint64m4_t, vint64m4_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vsuxseg2ei32_v)))
void vsuxseg2ei32_v_u64m1(uint64_t *, vuint32mf2_t, vuint64m1_t, vuint64m1_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vsuxseg2ei32_v_m)))
void vsuxseg2ei32_v_u64m1_m(vbool64_t, uint64_t *, vuint32mf2_t, vuint64m1_t, vuint64m1_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vsuxseg2ei32_v)))
void vsuxseg2ei32_v_u64m2(uint64_t *, vuint32m1_t, vuint64m2_t, vuint64m2_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vsuxseg2ei32_v_m)))
void vsuxseg2ei32_v_u64m2_m(vbool32_t, uint64_t *, vuint32m1_t, vuint64m2_t, vuint64m2_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vsuxseg2ei32_v)))
void vsuxseg2ei32_v_u64m4(uint64_t *, vuint32m2_t, vuint64m4_t, vuint64m4_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vsuxseg2ei32_v_m)))
void vsuxseg2ei32_v_u64m4_m(vbool16_t, uint64_t *, vuint32m2_t, vuint64m4_t, vuint64m4_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vsuxseg3ei32_v)))
void vsuxseg3ei32_v_i64m1(int64_t *, vuint32mf2_t, vint64m1_t, vint64m1_t, vint64m1_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vsuxseg3ei32_v_m)))
void vsuxseg3ei32_v_i64m1_m(vbool64_t, int64_t *, vuint32mf2_t, vint64m1_t, vint64m1_t, vint64m1_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vsuxseg3ei32_v)))
void vsuxseg3ei32_v_i64m2(int64_t *, vuint32m1_t, vint64m2_t, vint64m2_t, vint64m2_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vsuxseg3ei32_v_m)))
void vsuxseg3ei32_v_i64m2_m(vbool32_t, int64_t *, vuint32m1_t, vint64m2_t, vint64m2_t, vint64m2_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vsuxseg3ei32_v)))
void vsuxseg3ei32_v_u64m1(uint64_t *, vuint32mf2_t, vuint64m1_t, vuint64m1_t, vuint64m1_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vsuxseg3ei32_v_m)))
void vsuxseg3ei32_v_u64m1_m(vbool64_t, uint64_t *, vuint32mf2_t, vuint64m1_t, vuint64m1_t, vuint64m1_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vsuxseg3ei32_v)))
void vsuxseg3ei32_v_u64m2(uint64_t *, vuint32m1_t, vuint64m2_t, vuint64m2_t, vuint64m2_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vsuxseg3ei32_v_m)))
void vsuxseg3ei32_v_u64m2_m(vbool32_t, uint64_t *, vuint32m1_t, vuint64m2_t, vuint64m2_t, vuint64m2_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vsuxseg4ei32_v)))
void vsuxseg4ei32_v_i64m1(int64_t *, vuint32mf2_t, vint64m1_t, vint64m1_t, vint64m1_t, vint64m1_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vsuxseg4ei32_v_m)))
void vsuxseg4ei32_v_i64m1_m(vbool64_t, int64_t *, vuint32mf2_t, vint64m1_t, vint64m1_t, vint64m1_t, vint64m1_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vsuxseg4ei32_v)))
void vsuxseg4ei32_v_i64m2(int64_t *, vuint32m1_t, vint64m2_t, vint64m2_t, vint64m2_t, vint64m2_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vsuxseg4ei32_v_m)))
void vsuxseg4ei32_v_i64m2_m(vbool32_t, int64_t *, vuint32m1_t, vint64m2_t, vint64m2_t, vint64m2_t, vint64m2_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vsuxseg4ei32_v)))
void vsuxseg4ei32_v_u64m1(uint64_t *, vuint32mf2_t, vuint64m1_t, vuint64m1_t, vuint64m1_t, vuint64m1_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vsuxseg4ei32_v_m)))
void vsuxseg4ei32_v_u64m1_m(vbool64_t, uint64_t *, vuint32mf2_t, vuint64m1_t, vuint64m1_t, vuint64m1_t, vuint64m1_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vsuxseg4ei32_v)))
void vsuxseg4ei32_v_u64m2(uint64_t *, vuint32m1_t, vuint64m2_t, vuint64m2_t, vuint64m2_t, vuint64m2_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vsuxseg4ei32_v_m)))
void vsuxseg4ei32_v_u64m2_m(vbool32_t, uint64_t *, vuint32m1_t, vuint64m2_t, vuint64m2_t, vuint64m2_t, vuint64m2_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vsuxseg5ei32_v)))
void vsuxseg5ei32_v_i64m1(int64_t *, vuint32mf2_t, vint64m1_t, vint64m1_t, vint64m1_t, vint64m1_t, vint64m1_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vsuxseg5ei32_v_m)))
void vsuxseg5ei32_v_i64m1_m(vbool64_t, int64_t *, vuint32mf2_t, vint64m1_t, vint64m1_t, vint64m1_t, vint64m1_t, vint64m1_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vsuxseg5ei32_v)))
void vsuxseg5ei32_v_u64m1(uint64_t *, vuint32mf2_t, vuint64m1_t, vuint64m1_t, vuint64m1_t, vuint64m1_t, vuint64m1_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vsuxseg5ei32_v_m)))
void vsuxseg5ei32_v_u64m1_m(vbool64_t, uint64_t *, vuint32mf2_t, vuint64m1_t, vuint64m1_t, vuint64m1_t, vuint64m1_t, vuint64m1_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vsuxseg6ei32_v)))
void vsuxseg6ei32_v_i64m1(int64_t *, vuint32mf2_t, vint64m1_t, vint64m1_t, vint64m1_t, vint64m1_t, vint64m1_t, vint64m1_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vsuxseg6ei32_v_m)))
void vsuxseg6ei32_v_i64m1_m(vbool64_t, int64_t *, vuint32mf2_t, vint64m1_t, vint64m1_t, vint64m1_t, vint64m1_t, vint64m1_t, vint64m1_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vsuxseg6ei32_v)))
void vsuxseg6ei32_v_u64m1(uint64_t *, vuint32mf2_t, vuint64m1_t, vuint64m1_t, vuint64m1_t, vuint64m1_t, vuint64m1_t, vuint64m1_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vsuxseg6ei32_v_m)))
void vsuxseg6ei32_v_u64m1_m(vbool64_t, uint64_t *, vuint32mf2_t, vuint64m1_t, vuint64m1_t, vuint64m1_t, vuint64m1_t, vuint64m1_t, vuint64m1_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vsuxseg7ei32_v)))
void vsuxseg7ei32_v_i64m1(int64_t *, vuint32mf2_t, vint64m1_t, vint64m1_t, vint64m1_t, vint64m1_t, vint64m1_t, vint64m1_t, vint64m1_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vsuxseg7ei32_v_m)))
void vsuxseg7ei32_v_i64m1_m(vbool64_t, int64_t *, vuint32mf2_t, vint64m1_t, vint64m1_t, vint64m1_t, vint64m1_t, vint64m1_t, vint64m1_t, vint64m1_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vsuxseg7ei32_v)))
void vsuxseg7ei32_v_u64m1(uint64_t *, vuint32mf2_t, vuint64m1_t, vuint64m1_t, vuint64m1_t, vuint64m1_t, vuint64m1_t, vuint64m1_t, vuint64m1_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vsuxseg7ei32_v_m)))
void vsuxseg7ei32_v_u64m1_m(vbool64_t, uint64_t *, vuint32mf2_t, vuint64m1_t, vuint64m1_t, vuint64m1_t, vuint64m1_t, vuint64m1_t, vuint64m1_t, vuint64m1_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vsuxseg8ei32_v)))
void vsuxseg8ei32_v_i64m1(int64_t *, vuint32mf2_t, vint64m1_t, vint64m1_t, vint64m1_t, vint64m1_t, vint64m1_t, vint64m1_t, vint64m1_t, vint64m1_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vsuxseg8ei32_v_m)))
void vsuxseg8ei32_v_i64m1_m(vbool64_t, int64_t *, vuint32mf2_t, vint64m1_t, vint64m1_t, vint64m1_t, vint64m1_t, vint64m1_t, vint64m1_t, vint64m1_t, vint64m1_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vsuxseg8ei32_v)))
void vsuxseg8ei32_v_u64m1(uint64_t *, vuint32mf2_t, vuint64m1_t, vuint64m1_t, vuint64m1_t, vuint64m1_t, vuint64m1_t, vuint64m1_t, vuint64m1_t, vuint64m1_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vsuxseg8ei32_v_m)))
void vsuxseg8ei32_v_u64m1_m(vbool64_t, uint64_t *, vuint32mf2_t, vuint64m1_t, vuint64m1_t, vuint64m1_t, vuint64m1_t, vuint64m1_t, vuint64m1_t, vuint64m1_t, vuint64m1_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vsuxseg2ei64_v)))
void vsuxseg2ei64_v_i64m1(int64_t *, vuint64m1_t, vint64m1_t, vint64m1_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vsuxseg2ei64_v_m)))
void vsuxseg2ei64_v_i64m1_m(vbool64_t, int64_t *, vuint64m1_t, vint64m1_t, vint64m1_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vsuxseg2ei64_v)))
void vsuxseg2ei64_v_i64m2(int64_t *, vuint64m2_t, vint64m2_t, vint64m2_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vsuxseg2ei64_v_m)))
void vsuxseg2ei64_v_i64m2_m(vbool32_t, int64_t *, vuint64m2_t, vint64m2_t, vint64m2_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vsuxseg2ei64_v)))
void vsuxseg2ei64_v_i64m4(int64_t *, vuint64m4_t, vint64m4_t, vint64m4_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vsuxseg2ei64_v_m)))
void vsuxseg2ei64_v_i64m4_m(vbool16_t, int64_t *, vuint64m4_t, vint64m4_t, vint64m4_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vsuxseg2ei64_v)))
void vsuxseg2ei64_v_u64m1(uint64_t *, vuint64m1_t, vuint64m1_t, vuint64m1_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vsuxseg2ei64_v_m)))
void vsuxseg2ei64_v_u64m1_m(vbool64_t, uint64_t *, vuint64m1_t, vuint64m1_t, vuint64m1_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vsuxseg2ei64_v)))
void vsuxseg2ei64_v_u64m2(uint64_t *, vuint64m2_t, vuint64m2_t, vuint64m2_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vsuxseg2ei64_v_m)))
void vsuxseg2ei64_v_u64m2_m(vbool32_t, uint64_t *, vuint64m2_t, vuint64m2_t, vuint64m2_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vsuxseg2ei64_v)))
void vsuxseg2ei64_v_u64m4(uint64_t *, vuint64m4_t, vuint64m4_t, vuint64m4_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vsuxseg2ei64_v_m)))
void vsuxseg2ei64_v_u64m4_m(vbool16_t, uint64_t *, vuint64m4_t, vuint64m4_t, vuint64m4_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vsuxseg3ei64_v)))
void vsuxseg3ei64_v_i64m1(int64_t *, vuint64m1_t, vint64m1_t, vint64m1_t, vint64m1_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vsuxseg3ei64_v_m)))
void vsuxseg3ei64_v_i64m1_m(vbool64_t, int64_t *, vuint64m1_t, vint64m1_t, vint64m1_t, vint64m1_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vsuxseg3ei64_v)))
void vsuxseg3ei64_v_i64m2(int64_t *, vuint64m2_t, vint64m2_t, vint64m2_t, vint64m2_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vsuxseg3ei64_v_m)))
void vsuxseg3ei64_v_i64m2_m(vbool32_t, int64_t *, vuint64m2_t, vint64m2_t, vint64m2_t, vint64m2_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vsuxseg3ei64_v)))
void vsuxseg3ei64_v_u64m1(uint64_t *, vuint64m1_t, vuint64m1_t, vuint64m1_t, vuint64m1_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vsuxseg3ei64_v_m)))
void vsuxseg3ei64_v_u64m1_m(vbool64_t, uint64_t *, vuint64m1_t, vuint64m1_t, vuint64m1_t, vuint64m1_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vsuxseg3ei64_v)))
void vsuxseg3ei64_v_u64m2(uint64_t *, vuint64m2_t, vuint64m2_t, vuint64m2_t, vuint64m2_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vsuxseg3ei64_v_m)))
void vsuxseg3ei64_v_u64m2_m(vbool32_t, uint64_t *, vuint64m2_t, vuint64m2_t, vuint64m2_t, vuint64m2_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vsuxseg4ei64_v)))
void vsuxseg4ei64_v_i64m1(int64_t *, vuint64m1_t, vint64m1_t, vint64m1_t, vint64m1_t, vint64m1_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vsuxseg4ei64_v_m)))
void vsuxseg4ei64_v_i64m1_m(vbool64_t, int64_t *, vuint64m1_t, vint64m1_t, vint64m1_t, vint64m1_t, vint64m1_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vsuxseg4ei64_v)))
void vsuxseg4ei64_v_i64m2(int64_t *, vuint64m2_t, vint64m2_t, vint64m2_t, vint64m2_t, vint64m2_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vsuxseg4ei64_v_m)))
void vsuxseg4ei64_v_i64m2_m(vbool32_t, int64_t *, vuint64m2_t, vint64m2_t, vint64m2_t, vint64m2_t, vint64m2_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vsuxseg4ei64_v)))
void vsuxseg4ei64_v_u64m1(uint64_t *, vuint64m1_t, vuint64m1_t, vuint64m1_t, vuint64m1_t, vuint64m1_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vsuxseg4ei64_v_m)))
void vsuxseg4ei64_v_u64m1_m(vbool64_t, uint64_t *, vuint64m1_t, vuint64m1_t, vuint64m1_t, vuint64m1_t, vuint64m1_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vsuxseg4ei64_v)))
void vsuxseg4ei64_v_u64m2(uint64_t *, vuint64m2_t, vuint64m2_t, vuint64m2_t, vuint64m2_t, vuint64m2_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vsuxseg4ei64_v_m)))
void vsuxseg4ei64_v_u64m2_m(vbool32_t, uint64_t *, vuint64m2_t, vuint64m2_t, vuint64m2_t, vuint64m2_t, vuint64m2_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vsuxseg5ei64_v)))
void vsuxseg5ei64_v_i64m1(int64_t *, vuint64m1_t, vint64m1_t, vint64m1_t, vint64m1_t, vint64m1_t, vint64m1_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vsuxseg5ei64_v_m)))
void vsuxseg5ei64_v_i64m1_m(vbool64_t, int64_t *, vuint64m1_t, vint64m1_t, vint64m1_t, vint64m1_t, vint64m1_t, vint64m1_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vsuxseg5ei64_v)))
void vsuxseg5ei64_v_u64m1(uint64_t *, vuint64m1_t, vuint64m1_t, vuint64m1_t, vuint64m1_t, vuint64m1_t, vuint64m1_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vsuxseg5ei64_v_m)))
void vsuxseg5ei64_v_u64m1_m(vbool64_t, uint64_t *, vuint64m1_t, vuint64m1_t, vuint64m1_t, vuint64m1_t, vuint64m1_t, vuint64m1_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vsuxseg6ei64_v)))
void vsuxseg6ei64_v_i64m1(int64_t *, vuint64m1_t, vint64m1_t, vint64m1_t, vint64m1_t, vint64m1_t, vint64m1_t, vint64m1_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vsuxseg6ei64_v_m)))
void vsuxseg6ei64_v_i64m1_m(vbool64_t, int64_t *, vuint64m1_t, vint64m1_t, vint64m1_t, vint64m1_t, vint64m1_t, vint64m1_t, vint64m1_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vsuxseg6ei64_v)))
void vsuxseg6ei64_v_u64m1(uint64_t *, vuint64m1_t, vuint64m1_t, vuint64m1_t, vuint64m1_t, vuint64m1_t, vuint64m1_t, vuint64m1_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vsuxseg6ei64_v_m)))
void vsuxseg6ei64_v_u64m1_m(vbool64_t, uint64_t *, vuint64m1_t, vuint64m1_t, vuint64m1_t, vuint64m1_t, vuint64m1_t, vuint64m1_t, vuint64m1_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vsuxseg7ei64_v)))
void vsuxseg7ei64_v_i64m1(int64_t *, vuint64m1_t, vint64m1_t, vint64m1_t, vint64m1_t, vint64m1_t, vint64m1_t, vint64m1_t, vint64m1_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vsuxseg7ei64_v_m)))
void vsuxseg7ei64_v_i64m1_m(vbool64_t, int64_t *, vuint64m1_t, vint64m1_t, vint64m1_t, vint64m1_t, vint64m1_t, vint64m1_t, vint64m1_t, vint64m1_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vsuxseg7ei64_v)))
void vsuxseg7ei64_v_u64m1(uint64_t *, vuint64m1_t, vuint64m1_t, vuint64m1_t, vuint64m1_t, vuint64m1_t, vuint64m1_t, vuint64m1_t, vuint64m1_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vsuxseg7ei64_v_m)))
void vsuxseg7ei64_v_u64m1_m(vbool64_t, uint64_t *, vuint64m1_t, vuint64m1_t, vuint64m1_t, vuint64m1_t, vuint64m1_t, vuint64m1_t, vuint64m1_t, vuint64m1_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vsuxseg8ei64_v)))
void vsuxseg8ei64_v_i64m1(int64_t *, vuint64m1_t, vint64m1_t, vint64m1_t, vint64m1_t, vint64m1_t, vint64m1_t, vint64m1_t, vint64m1_t, vint64m1_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vsuxseg8ei64_v_m)))
void vsuxseg8ei64_v_i64m1_m(vbool64_t, int64_t *, vuint64m1_t, vint64m1_t, vint64m1_t, vint64m1_t, vint64m1_t, vint64m1_t, vint64m1_t, vint64m1_t, vint64m1_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vsuxseg8ei64_v)))
void vsuxseg8ei64_v_u64m1(uint64_t *, vuint64m1_t, vuint64m1_t, vuint64m1_t, vuint64m1_t, vuint64m1_t, vuint64m1_t, vuint64m1_t, vuint64m1_t, vuint64m1_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vsuxseg8ei64_v_m)))
void vsuxseg8ei64_v_u64m1_m(vbool64_t, uint64_t *, vuint64m1_t, vuint64m1_t, vuint64m1_t, vuint64m1_t, vuint64m1_t, vuint64m1_t, vuint64m1_t, vuint64m1_t, vuint64m1_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vsoxseg2ei64_v)))
void vsoxseg2ei64_v_i8m1(int8_t *, vuint64m8_t, vint8m1_t, vint8m1_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vsoxseg2ei64_v_m)))
void vsoxseg2ei64_v_i8m1_m(vbool8_t, int8_t *, vuint64m8_t, vint8m1_t, vint8m1_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vsoxseg2ei64_v)))
void vsoxseg2ei64_v_i8mf2(int8_t *, vuint64m4_t, vint8mf2_t, vint8mf2_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vsoxseg2ei64_v_m)))
void vsoxseg2ei64_v_i8mf2_m(vbool16_t, int8_t *, vuint64m4_t, vint8mf2_t, vint8mf2_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vsoxseg2ei64_v)))
void vsoxseg2ei64_v_i8mf4(int8_t *, vuint64m2_t, vint8mf4_t, vint8mf4_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vsoxseg2ei64_v_m)))
void vsoxseg2ei64_v_i8mf4_m(vbool32_t, int8_t *, vuint64m2_t, vint8mf4_t, vint8mf4_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vsoxseg2ei64_v)))
void vsoxseg2ei64_v_i8mf8(int8_t *, vuint64m1_t, vint8mf8_t, vint8mf8_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vsoxseg2ei64_v_m)))
void vsoxseg2ei64_v_i8mf8_m(vbool64_t, int8_t *, vuint64m1_t, vint8mf8_t, vint8mf8_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vsoxseg2ei64_v)))
void vsoxseg2ei64_v_u8m1(uint8_t *, vuint64m8_t, vuint8m1_t, vuint8m1_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vsoxseg2ei64_v_m)))
void vsoxseg2ei64_v_u8m1_m(vbool8_t, uint8_t *, vuint64m8_t, vuint8m1_t, vuint8m1_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vsoxseg2ei64_v)))
void vsoxseg2ei64_v_u8mf2(uint8_t *, vuint64m4_t, vuint8mf2_t, vuint8mf2_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vsoxseg2ei64_v_m)))
void vsoxseg2ei64_v_u8mf2_m(vbool16_t, uint8_t *, vuint64m4_t, vuint8mf2_t, vuint8mf2_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vsoxseg2ei64_v)))
void vsoxseg2ei64_v_u8mf4(uint8_t *, vuint64m2_t, vuint8mf4_t, vuint8mf4_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vsoxseg2ei64_v_m)))
void vsoxseg2ei64_v_u8mf4_m(vbool32_t, uint8_t *, vuint64m2_t, vuint8mf4_t, vuint8mf4_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vsoxseg2ei64_v)))
void vsoxseg2ei64_v_u8mf8(uint8_t *, vuint64m1_t, vuint8mf8_t, vuint8mf8_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vsoxseg2ei64_v_m)))
void vsoxseg2ei64_v_u8mf8_m(vbool64_t, uint8_t *, vuint64m1_t, vuint8mf8_t, vuint8mf8_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vsoxseg3ei64_v)))
void vsoxseg3ei64_v_i8m1(int8_t *, vuint64m8_t, vint8m1_t, vint8m1_t, vint8m1_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vsoxseg3ei64_v_m)))
void vsoxseg3ei64_v_i8m1_m(vbool8_t, int8_t *, vuint64m8_t, vint8m1_t, vint8m1_t, vint8m1_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vsoxseg3ei64_v)))
void vsoxseg3ei64_v_i8mf2(int8_t *, vuint64m4_t, vint8mf2_t, vint8mf2_t, vint8mf2_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vsoxseg3ei64_v_m)))
void vsoxseg3ei64_v_i8mf2_m(vbool16_t, int8_t *, vuint64m4_t, vint8mf2_t, vint8mf2_t, vint8mf2_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vsoxseg3ei64_v)))
void vsoxseg3ei64_v_i8mf4(int8_t *, vuint64m2_t, vint8mf4_t, vint8mf4_t, vint8mf4_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vsoxseg3ei64_v_m)))
void vsoxseg3ei64_v_i8mf4_m(vbool32_t, int8_t *, vuint64m2_t, vint8mf4_t, vint8mf4_t, vint8mf4_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vsoxseg3ei64_v)))
void vsoxseg3ei64_v_i8mf8(int8_t *, vuint64m1_t, vint8mf8_t, vint8mf8_t, vint8mf8_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vsoxseg3ei64_v_m)))
void vsoxseg3ei64_v_i8mf8_m(vbool64_t, int8_t *, vuint64m1_t, vint8mf8_t, vint8mf8_t, vint8mf8_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vsoxseg3ei64_v)))
void vsoxseg3ei64_v_u8m1(uint8_t *, vuint64m8_t, vuint8m1_t, vuint8m1_t, vuint8m1_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vsoxseg3ei64_v_m)))
void vsoxseg3ei64_v_u8m1_m(vbool8_t, uint8_t *, vuint64m8_t, vuint8m1_t, vuint8m1_t, vuint8m1_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vsoxseg3ei64_v)))
void vsoxseg3ei64_v_u8mf2(uint8_t *, vuint64m4_t, vuint8mf2_t, vuint8mf2_t, vuint8mf2_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vsoxseg3ei64_v_m)))
void vsoxseg3ei64_v_u8mf2_m(vbool16_t, uint8_t *, vuint64m4_t, vuint8mf2_t, vuint8mf2_t, vuint8mf2_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vsoxseg3ei64_v)))
void vsoxseg3ei64_v_u8mf4(uint8_t *, vuint64m2_t, vuint8mf4_t, vuint8mf4_t, vuint8mf4_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vsoxseg3ei64_v_m)))
void vsoxseg3ei64_v_u8mf4_m(vbool32_t, uint8_t *, vuint64m2_t, vuint8mf4_t, vuint8mf4_t, vuint8mf4_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vsoxseg3ei64_v)))
void vsoxseg3ei64_v_u8mf8(uint8_t *, vuint64m1_t, vuint8mf8_t, vuint8mf8_t, vuint8mf8_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vsoxseg3ei64_v_m)))
void vsoxseg3ei64_v_u8mf8_m(vbool64_t, uint8_t *, vuint64m1_t, vuint8mf8_t, vuint8mf8_t, vuint8mf8_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vsoxseg4ei64_v)))
void vsoxseg4ei64_v_i8m1(int8_t *, vuint64m8_t, vint8m1_t, vint8m1_t, vint8m1_t, vint8m1_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vsoxseg4ei64_v_m)))
void vsoxseg4ei64_v_i8m1_m(vbool8_t, int8_t *, vuint64m8_t, vint8m1_t, vint8m1_t, vint8m1_t, vint8m1_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vsoxseg4ei64_v)))
void vsoxseg4ei64_v_i8mf2(int8_t *, vuint64m4_t, vint8mf2_t, vint8mf2_t, vint8mf2_t, vint8mf2_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vsoxseg4ei64_v_m)))
void vsoxseg4ei64_v_i8mf2_m(vbool16_t, int8_t *, vuint64m4_t, vint8mf2_t, vint8mf2_t, vint8mf2_t, vint8mf2_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vsoxseg4ei64_v)))
void vsoxseg4ei64_v_i8mf4(int8_t *, vuint64m2_t, vint8mf4_t, vint8mf4_t, vint8mf4_t, vint8mf4_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vsoxseg4ei64_v_m)))
void vsoxseg4ei64_v_i8mf4_m(vbool32_t, int8_t *, vuint64m2_t, vint8mf4_t, vint8mf4_t, vint8mf4_t, vint8mf4_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vsoxseg4ei64_v)))
void vsoxseg4ei64_v_i8mf8(int8_t *, vuint64m1_t, vint8mf8_t, vint8mf8_t, vint8mf8_t, vint8mf8_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vsoxseg4ei64_v_m)))
void vsoxseg4ei64_v_i8mf8_m(vbool64_t, int8_t *, vuint64m1_t, vint8mf8_t, vint8mf8_t, vint8mf8_t, vint8mf8_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vsoxseg4ei64_v)))
void vsoxseg4ei64_v_u8m1(uint8_t *, vuint64m8_t, vuint8m1_t, vuint8m1_t, vuint8m1_t, vuint8m1_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vsoxseg4ei64_v_m)))
void vsoxseg4ei64_v_u8m1_m(vbool8_t, uint8_t *, vuint64m8_t, vuint8m1_t, vuint8m1_t, vuint8m1_t, vuint8m1_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vsoxseg4ei64_v)))
void vsoxseg4ei64_v_u8mf2(uint8_t *, vuint64m4_t, vuint8mf2_t, vuint8mf2_t, vuint8mf2_t, vuint8mf2_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vsoxseg4ei64_v_m)))
void vsoxseg4ei64_v_u8mf2_m(vbool16_t, uint8_t *, vuint64m4_t, vuint8mf2_t, vuint8mf2_t, vuint8mf2_t, vuint8mf2_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vsoxseg4ei64_v)))
void vsoxseg4ei64_v_u8mf4(uint8_t *, vuint64m2_t, vuint8mf4_t, vuint8mf4_t, vuint8mf4_t, vuint8mf4_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vsoxseg4ei64_v_m)))
void vsoxseg4ei64_v_u8mf4_m(vbool32_t, uint8_t *, vuint64m2_t, vuint8mf4_t, vuint8mf4_t, vuint8mf4_t, vuint8mf4_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vsoxseg4ei64_v)))
void vsoxseg4ei64_v_u8mf8(uint8_t *, vuint64m1_t, vuint8mf8_t, vuint8mf8_t, vuint8mf8_t, vuint8mf8_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vsoxseg4ei64_v_m)))
void vsoxseg4ei64_v_u8mf8_m(vbool64_t, uint8_t *, vuint64m1_t, vuint8mf8_t, vuint8mf8_t, vuint8mf8_t, vuint8mf8_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vsoxseg5ei64_v)))
void vsoxseg5ei64_v_i8m1(int8_t *, vuint64m8_t, vint8m1_t, vint8m1_t, vint8m1_t, vint8m1_t, vint8m1_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vsoxseg5ei64_v_m)))
void vsoxseg5ei64_v_i8m1_m(vbool8_t, int8_t *, vuint64m8_t, vint8m1_t, vint8m1_t, vint8m1_t, vint8m1_t, vint8m1_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vsoxseg5ei64_v)))
void vsoxseg5ei64_v_i8mf2(int8_t *, vuint64m4_t, vint8mf2_t, vint8mf2_t, vint8mf2_t, vint8mf2_t, vint8mf2_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vsoxseg5ei64_v_m)))
void vsoxseg5ei64_v_i8mf2_m(vbool16_t, int8_t *, vuint64m4_t, vint8mf2_t, vint8mf2_t, vint8mf2_t, vint8mf2_t, vint8mf2_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vsoxseg5ei64_v)))
void vsoxseg5ei64_v_i8mf4(int8_t *, vuint64m2_t, vint8mf4_t, vint8mf4_t, vint8mf4_t, vint8mf4_t, vint8mf4_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vsoxseg5ei64_v_m)))
void vsoxseg5ei64_v_i8mf4_m(vbool32_t, int8_t *, vuint64m2_t, vint8mf4_t, vint8mf4_t, vint8mf4_t, vint8mf4_t, vint8mf4_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vsoxseg5ei64_v)))
void vsoxseg5ei64_v_i8mf8(int8_t *, vuint64m1_t, vint8mf8_t, vint8mf8_t, vint8mf8_t, vint8mf8_t, vint8mf8_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vsoxseg5ei64_v_m)))
void vsoxseg5ei64_v_i8mf8_m(vbool64_t, int8_t *, vuint64m1_t, vint8mf8_t, vint8mf8_t, vint8mf8_t, vint8mf8_t, vint8mf8_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vsoxseg5ei64_v)))
void vsoxseg5ei64_v_u8m1(uint8_t *, vuint64m8_t, vuint8m1_t, vuint8m1_t, vuint8m1_t, vuint8m1_t, vuint8m1_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vsoxseg5ei64_v_m)))
void vsoxseg5ei64_v_u8m1_m(vbool8_t, uint8_t *, vuint64m8_t, vuint8m1_t, vuint8m1_t, vuint8m1_t, vuint8m1_t, vuint8m1_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vsoxseg5ei64_v)))
void vsoxseg5ei64_v_u8mf2(uint8_t *, vuint64m4_t, vuint8mf2_t, vuint8mf2_t, vuint8mf2_t, vuint8mf2_t, vuint8mf2_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vsoxseg5ei64_v_m)))
void vsoxseg5ei64_v_u8mf2_m(vbool16_t, uint8_t *, vuint64m4_t, vuint8mf2_t, vuint8mf2_t, vuint8mf2_t, vuint8mf2_t, vuint8mf2_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vsoxseg5ei64_v)))
void vsoxseg5ei64_v_u8mf4(uint8_t *, vuint64m2_t, vuint8mf4_t, vuint8mf4_t, vuint8mf4_t, vuint8mf4_t, vuint8mf4_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vsoxseg5ei64_v_m)))
void vsoxseg5ei64_v_u8mf4_m(vbool32_t, uint8_t *, vuint64m2_t, vuint8mf4_t, vuint8mf4_t, vuint8mf4_t, vuint8mf4_t, vuint8mf4_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vsoxseg5ei64_v)))
void vsoxseg5ei64_v_u8mf8(uint8_t *, vuint64m1_t, vuint8mf8_t, vuint8mf8_t, vuint8mf8_t, vuint8mf8_t, vuint8mf8_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vsoxseg5ei64_v_m)))
void vsoxseg5ei64_v_u8mf8_m(vbool64_t, uint8_t *, vuint64m1_t, vuint8mf8_t, vuint8mf8_t, vuint8mf8_t, vuint8mf8_t, vuint8mf8_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vsoxseg6ei64_v)))
void vsoxseg6ei64_v_i8m1(int8_t *, vuint64m8_t, vint8m1_t, vint8m1_t, vint8m1_t, vint8m1_t, vint8m1_t, vint8m1_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vsoxseg6ei64_v_m)))
void vsoxseg6ei64_v_i8m1_m(vbool8_t, int8_t *, vuint64m8_t, vint8m1_t, vint8m1_t, vint8m1_t, vint8m1_t, vint8m1_t, vint8m1_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vsoxseg6ei64_v)))
void vsoxseg6ei64_v_i8mf2(int8_t *, vuint64m4_t, vint8mf2_t, vint8mf2_t, vint8mf2_t, vint8mf2_t, vint8mf2_t, vint8mf2_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vsoxseg6ei64_v_m)))
void vsoxseg6ei64_v_i8mf2_m(vbool16_t, int8_t *, vuint64m4_t, vint8mf2_t, vint8mf2_t, vint8mf2_t, vint8mf2_t, vint8mf2_t, vint8mf2_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vsoxseg6ei64_v)))
void vsoxseg6ei64_v_i8mf4(int8_t *, vuint64m2_t, vint8mf4_t, vint8mf4_t, vint8mf4_t, vint8mf4_t, vint8mf4_t, vint8mf4_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vsoxseg6ei64_v_m)))
void vsoxseg6ei64_v_i8mf4_m(vbool32_t, int8_t *, vuint64m2_t, vint8mf4_t, vint8mf4_t, vint8mf4_t, vint8mf4_t, vint8mf4_t, vint8mf4_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vsoxseg6ei64_v)))
void vsoxseg6ei64_v_i8mf8(int8_t *, vuint64m1_t, vint8mf8_t, vint8mf8_t, vint8mf8_t, vint8mf8_t, vint8mf8_t, vint8mf8_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vsoxseg6ei64_v_m)))
void vsoxseg6ei64_v_i8mf8_m(vbool64_t, int8_t *, vuint64m1_t, vint8mf8_t, vint8mf8_t, vint8mf8_t, vint8mf8_t, vint8mf8_t, vint8mf8_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vsoxseg6ei64_v)))
void vsoxseg6ei64_v_u8m1(uint8_t *, vuint64m8_t, vuint8m1_t, vuint8m1_t, vuint8m1_t, vuint8m1_t, vuint8m1_t, vuint8m1_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vsoxseg6ei64_v_m)))
void vsoxseg6ei64_v_u8m1_m(vbool8_t, uint8_t *, vuint64m8_t, vuint8m1_t, vuint8m1_t, vuint8m1_t, vuint8m1_t, vuint8m1_t, vuint8m1_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vsoxseg6ei64_v)))
void vsoxseg6ei64_v_u8mf2(uint8_t *, vuint64m4_t, vuint8mf2_t, vuint8mf2_t, vuint8mf2_t, vuint8mf2_t, vuint8mf2_t, vuint8mf2_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vsoxseg6ei64_v_m)))
void vsoxseg6ei64_v_u8mf2_m(vbool16_t, uint8_t *, vuint64m4_t, vuint8mf2_t, vuint8mf2_t, vuint8mf2_t, vuint8mf2_t, vuint8mf2_t, vuint8mf2_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vsoxseg6ei64_v)))
void vsoxseg6ei64_v_u8mf4(uint8_t *, vuint64m2_t, vuint8mf4_t, vuint8mf4_t, vuint8mf4_t, vuint8mf4_t, vuint8mf4_t, vuint8mf4_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vsoxseg6ei64_v_m)))
void vsoxseg6ei64_v_u8mf4_m(vbool32_t, uint8_t *, vuint64m2_t, vuint8mf4_t, vuint8mf4_t, vuint8mf4_t, vuint8mf4_t, vuint8mf4_t, vuint8mf4_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vsoxseg6ei64_v)))
void vsoxseg6ei64_v_u8mf8(uint8_t *, vuint64m1_t, vuint8mf8_t, vuint8mf8_t, vuint8mf8_t, vuint8mf8_t, vuint8mf8_t, vuint8mf8_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vsoxseg6ei64_v_m)))
void vsoxseg6ei64_v_u8mf8_m(vbool64_t, uint8_t *, vuint64m1_t, vuint8mf8_t, vuint8mf8_t, vuint8mf8_t, vuint8mf8_t, vuint8mf8_t, vuint8mf8_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vsoxseg7ei64_v)))
void vsoxseg7ei64_v_i8m1(int8_t *, vuint64m8_t, vint8m1_t, vint8m1_t, vint8m1_t, vint8m1_t, vint8m1_t, vint8m1_t, vint8m1_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vsoxseg7ei64_v_m)))
void vsoxseg7ei64_v_i8m1_m(vbool8_t, int8_t *, vuint64m8_t, vint8m1_t, vint8m1_t, vint8m1_t, vint8m1_t, vint8m1_t, vint8m1_t, vint8m1_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vsoxseg7ei64_v)))
void vsoxseg7ei64_v_i8mf2(int8_t *, vuint64m4_t, vint8mf2_t, vint8mf2_t, vint8mf2_t, vint8mf2_t, vint8mf2_t, vint8mf2_t, vint8mf2_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vsoxseg7ei64_v_m)))
void vsoxseg7ei64_v_i8mf2_m(vbool16_t, int8_t *, vuint64m4_t, vint8mf2_t, vint8mf2_t, vint8mf2_t, vint8mf2_t, vint8mf2_t, vint8mf2_t, vint8mf2_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vsoxseg7ei64_v)))
void vsoxseg7ei64_v_i8mf4(int8_t *, vuint64m2_t, vint8mf4_t, vint8mf4_t, vint8mf4_t, vint8mf4_t, vint8mf4_t, vint8mf4_t, vint8mf4_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vsoxseg7ei64_v_m)))
void vsoxseg7ei64_v_i8mf4_m(vbool32_t, int8_t *, vuint64m2_t, vint8mf4_t, vint8mf4_t, vint8mf4_t, vint8mf4_t, vint8mf4_t, vint8mf4_t, vint8mf4_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vsoxseg7ei64_v)))
void vsoxseg7ei64_v_i8mf8(int8_t *, vuint64m1_t, vint8mf8_t, vint8mf8_t, vint8mf8_t, vint8mf8_t, vint8mf8_t, vint8mf8_t, vint8mf8_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vsoxseg7ei64_v_m)))
void vsoxseg7ei64_v_i8mf8_m(vbool64_t, int8_t *, vuint64m1_t, vint8mf8_t, vint8mf8_t, vint8mf8_t, vint8mf8_t, vint8mf8_t, vint8mf8_t, vint8mf8_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vsoxseg7ei64_v)))
void vsoxseg7ei64_v_u8m1(uint8_t *, vuint64m8_t, vuint8m1_t, vuint8m1_t, vuint8m1_t, vuint8m1_t, vuint8m1_t, vuint8m1_t, vuint8m1_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vsoxseg7ei64_v_m)))
void vsoxseg7ei64_v_u8m1_m(vbool8_t, uint8_t *, vuint64m8_t, vuint8m1_t, vuint8m1_t, vuint8m1_t, vuint8m1_t, vuint8m1_t, vuint8m1_t, vuint8m1_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vsoxseg7ei64_v)))
void vsoxseg7ei64_v_u8mf2(uint8_t *, vuint64m4_t, vuint8mf2_t, vuint8mf2_t, vuint8mf2_t, vuint8mf2_t, vuint8mf2_t, vuint8mf2_t, vuint8mf2_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vsoxseg7ei64_v_m)))
void vsoxseg7ei64_v_u8mf2_m(vbool16_t, uint8_t *, vuint64m4_t, vuint8mf2_t, vuint8mf2_t, vuint8mf2_t, vuint8mf2_t, vuint8mf2_t, vuint8mf2_t, vuint8mf2_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vsoxseg7ei64_v)))
void vsoxseg7ei64_v_u8mf4(uint8_t *, vuint64m2_t, vuint8mf4_t, vuint8mf4_t, vuint8mf4_t, vuint8mf4_t, vuint8mf4_t, vuint8mf4_t, vuint8mf4_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vsoxseg7ei64_v_m)))
void vsoxseg7ei64_v_u8mf4_m(vbool32_t, uint8_t *, vuint64m2_t, vuint8mf4_t, vuint8mf4_t, vuint8mf4_t, vuint8mf4_t, vuint8mf4_t, vuint8mf4_t, vuint8mf4_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vsoxseg7ei64_v)))
void vsoxseg7ei64_v_u8mf8(uint8_t *, vuint64m1_t, vuint8mf8_t, vuint8mf8_t, vuint8mf8_t, vuint8mf8_t, vuint8mf8_t, vuint8mf8_t, vuint8mf8_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vsoxseg7ei64_v_m)))
void vsoxseg7ei64_v_u8mf8_m(vbool64_t, uint8_t *, vuint64m1_t, vuint8mf8_t, vuint8mf8_t, vuint8mf8_t, vuint8mf8_t, vuint8mf8_t, vuint8mf8_t, vuint8mf8_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vsoxseg8ei64_v)))
void vsoxseg8ei64_v_i8m1(int8_t *, vuint64m8_t, vint8m1_t, vint8m1_t, vint8m1_t, vint8m1_t, vint8m1_t, vint8m1_t, vint8m1_t, vint8m1_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vsoxseg8ei64_v_m)))
void vsoxseg8ei64_v_i8m1_m(vbool8_t, int8_t *, vuint64m8_t, vint8m1_t, vint8m1_t, vint8m1_t, vint8m1_t, vint8m1_t, vint8m1_t, vint8m1_t, vint8m1_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vsoxseg8ei64_v)))
void vsoxseg8ei64_v_i8mf2(int8_t *, vuint64m4_t, vint8mf2_t, vint8mf2_t, vint8mf2_t, vint8mf2_t, vint8mf2_t, vint8mf2_t, vint8mf2_t, vint8mf2_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vsoxseg8ei64_v_m)))
void vsoxseg8ei64_v_i8mf2_m(vbool16_t, int8_t *, vuint64m4_t, vint8mf2_t, vint8mf2_t, vint8mf2_t, vint8mf2_t, vint8mf2_t, vint8mf2_t, vint8mf2_t, vint8mf2_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vsoxseg8ei64_v)))
void vsoxseg8ei64_v_i8mf4(int8_t *, vuint64m2_t, vint8mf4_t, vint8mf4_t, vint8mf4_t, vint8mf4_t, vint8mf4_t, vint8mf4_t, vint8mf4_t, vint8mf4_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vsoxseg8ei64_v_m)))
void vsoxseg8ei64_v_i8mf4_m(vbool32_t, int8_t *, vuint64m2_t, vint8mf4_t, vint8mf4_t, vint8mf4_t, vint8mf4_t, vint8mf4_t, vint8mf4_t, vint8mf4_t, vint8mf4_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vsoxseg8ei64_v)))
void vsoxseg8ei64_v_i8mf8(int8_t *, vuint64m1_t, vint8mf8_t, vint8mf8_t, vint8mf8_t, vint8mf8_t, vint8mf8_t, vint8mf8_t, vint8mf8_t, vint8mf8_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vsoxseg8ei64_v_m)))
void vsoxseg8ei64_v_i8mf8_m(vbool64_t, int8_t *, vuint64m1_t, vint8mf8_t, vint8mf8_t, vint8mf8_t, vint8mf8_t, vint8mf8_t, vint8mf8_t, vint8mf8_t, vint8mf8_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vsoxseg8ei64_v)))
void vsoxseg8ei64_v_u8m1(uint8_t *, vuint64m8_t, vuint8m1_t, vuint8m1_t, vuint8m1_t, vuint8m1_t, vuint8m1_t, vuint8m1_t, vuint8m1_t, vuint8m1_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vsoxseg8ei64_v_m)))
void vsoxseg8ei64_v_u8m1_m(vbool8_t, uint8_t *, vuint64m8_t, vuint8m1_t, vuint8m1_t, vuint8m1_t, vuint8m1_t, vuint8m1_t, vuint8m1_t, vuint8m1_t, vuint8m1_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vsoxseg8ei64_v)))
void vsoxseg8ei64_v_u8mf2(uint8_t *, vuint64m4_t, vuint8mf2_t, vuint8mf2_t, vuint8mf2_t, vuint8mf2_t, vuint8mf2_t, vuint8mf2_t, vuint8mf2_t, vuint8mf2_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vsoxseg8ei64_v_m)))
void vsoxseg8ei64_v_u8mf2_m(vbool16_t, uint8_t *, vuint64m4_t, vuint8mf2_t, vuint8mf2_t, vuint8mf2_t, vuint8mf2_t, vuint8mf2_t, vuint8mf2_t, vuint8mf2_t, vuint8mf2_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vsoxseg8ei64_v)))
void vsoxseg8ei64_v_u8mf4(uint8_t *, vuint64m2_t, vuint8mf4_t, vuint8mf4_t, vuint8mf4_t, vuint8mf4_t, vuint8mf4_t, vuint8mf4_t, vuint8mf4_t, vuint8mf4_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vsoxseg8ei64_v_m)))
void vsoxseg8ei64_v_u8mf4_m(vbool32_t, uint8_t *, vuint64m2_t, vuint8mf4_t, vuint8mf4_t, vuint8mf4_t, vuint8mf4_t, vuint8mf4_t, vuint8mf4_t, vuint8mf4_t, vuint8mf4_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vsoxseg8ei64_v)))
void vsoxseg8ei64_v_u8mf8(uint8_t *, vuint64m1_t, vuint8mf8_t, vuint8mf8_t, vuint8mf8_t, vuint8mf8_t, vuint8mf8_t, vuint8mf8_t, vuint8mf8_t, vuint8mf8_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vsoxseg8ei64_v_m)))
void vsoxseg8ei64_v_u8mf8_m(vbool64_t, uint8_t *, vuint64m1_t, vuint8mf8_t, vuint8mf8_t, vuint8mf8_t, vuint8mf8_t, vuint8mf8_t, vuint8mf8_t, vuint8mf8_t, vuint8mf8_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vsoxseg2ei64_v)))
void vsoxseg2ei64_v_i16m1(int16_t *, vuint64m4_t, vint16m1_t, vint16m1_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vsoxseg2ei64_v_m)))
void vsoxseg2ei64_v_i16m1_m(vbool16_t, int16_t *, vuint64m4_t, vint16m1_t, vint16m1_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vsoxseg2ei64_v)))
void vsoxseg2ei64_v_i16m2(int16_t *, vuint64m8_t, vint16m2_t, vint16m2_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vsoxseg2ei64_v_m)))
void vsoxseg2ei64_v_i16m2_m(vbool8_t, int16_t *, vuint64m8_t, vint16m2_t, vint16m2_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vsoxseg2ei64_v)))
void vsoxseg2ei64_v_i16mf2(int16_t *, vuint64m2_t, vint16mf2_t, vint16mf2_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vsoxseg2ei64_v_m)))
void vsoxseg2ei64_v_i16mf2_m(vbool32_t, int16_t *, vuint64m2_t, vint16mf2_t, vint16mf2_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vsoxseg2ei64_v)))
void vsoxseg2ei64_v_i16mf4(int16_t *, vuint64m1_t, vint16mf4_t, vint16mf4_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vsoxseg2ei64_v_m)))
void vsoxseg2ei64_v_i16mf4_m(vbool64_t, int16_t *, vuint64m1_t, vint16mf4_t, vint16mf4_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vsoxseg2ei64_v)))
void vsoxseg2ei64_v_u16m1(uint16_t *, vuint64m4_t, vuint16m1_t, vuint16m1_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vsoxseg2ei64_v_m)))
void vsoxseg2ei64_v_u16m1_m(vbool16_t, uint16_t *, vuint64m4_t, vuint16m1_t, vuint16m1_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vsoxseg2ei64_v)))
void vsoxseg2ei64_v_u16m2(uint16_t *, vuint64m8_t, vuint16m2_t, vuint16m2_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vsoxseg2ei64_v_m)))
void vsoxseg2ei64_v_u16m2_m(vbool8_t, uint16_t *, vuint64m8_t, vuint16m2_t, vuint16m2_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vsoxseg2ei64_v)))
void vsoxseg2ei64_v_u16mf2(uint16_t *, vuint64m2_t, vuint16mf2_t, vuint16mf2_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vsoxseg2ei64_v_m)))
void vsoxseg2ei64_v_u16mf2_m(vbool32_t, uint16_t *, vuint64m2_t, vuint16mf2_t, vuint16mf2_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vsoxseg2ei64_v)))
void vsoxseg2ei64_v_u16mf4(uint16_t *, vuint64m1_t, vuint16mf4_t, vuint16mf4_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vsoxseg2ei64_v_m)))
void vsoxseg2ei64_v_u16mf4_m(vbool64_t, uint16_t *, vuint64m1_t, vuint16mf4_t, vuint16mf4_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vsoxseg3ei64_v)))
void vsoxseg3ei64_v_i16m1(int16_t *, vuint64m4_t, vint16m1_t, vint16m1_t, vint16m1_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vsoxseg3ei64_v_m)))
void vsoxseg3ei64_v_i16m1_m(vbool16_t, int16_t *, vuint64m4_t, vint16m1_t, vint16m1_t, vint16m1_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vsoxseg3ei64_v)))
void vsoxseg3ei64_v_i16m2(int16_t *, vuint64m8_t, vint16m2_t, vint16m2_t, vint16m2_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vsoxseg3ei64_v_m)))
void vsoxseg3ei64_v_i16m2_m(vbool8_t, int16_t *, vuint64m8_t, vint16m2_t, vint16m2_t, vint16m2_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vsoxseg3ei64_v)))
void vsoxseg3ei64_v_i16mf2(int16_t *, vuint64m2_t, vint16mf2_t, vint16mf2_t, vint16mf2_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vsoxseg3ei64_v_m)))
void vsoxseg3ei64_v_i16mf2_m(vbool32_t, int16_t *, vuint64m2_t, vint16mf2_t, vint16mf2_t, vint16mf2_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vsoxseg3ei64_v)))
void vsoxseg3ei64_v_i16mf4(int16_t *, vuint64m1_t, vint16mf4_t, vint16mf4_t, vint16mf4_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vsoxseg3ei64_v_m)))
void vsoxseg3ei64_v_i16mf4_m(vbool64_t, int16_t *, vuint64m1_t, vint16mf4_t, vint16mf4_t, vint16mf4_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vsoxseg3ei64_v)))
void vsoxseg3ei64_v_u16m1(uint16_t *, vuint64m4_t, vuint16m1_t, vuint16m1_t, vuint16m1_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vsoxseg3ei64_v_m)))
void vsoxseg3ei64_v_u16m1_m(vbool16_t, uint16_t *, vuint64m4_t, vuint16m1_t, vuint16m1_t, vuint16m1_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vsoxseg3ei64_v)))
void vsoxseg3ei64_v_u16m2(uint16_t *, vuint64m8_t, vuint16m2_t, vuint16m2_t, vuint16m2_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vsoxseg3ei64_v_m)))
void vsoxseg3ei64_v_u16m2_m(vbool8_t, uint16_t *, vuint64m8_t, vuint16m2_t, vuint16m2_t, vuint16m2_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vsoxseg3ei64_v)))
void vsoxseg3ei64_v_u16mf2(uint16_t *, vuint64m2_t, vuint16mf2_t, vuint16mf2_t, vuint16mf2_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vsoxseg3ei64_v_m)))
void vsoxseg3ei64_v_u16mf2_m(vbool32_t, uint16_t *, vuint64m2_t, vuint16mf2_t, vuint16mf2_t, vuint16mf2_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vsoxseg3ei64_v)))
void vsoxseg3ei64_v_u16mf4(uint16_t *, vuint64m1_t, vuint16mf4_t, vuint16mf4_t, vuint16mf4_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vsoxseg3ei64_v_m)))
void vsoxseg3ei64_v_u16mf4_m(vbool64_t, uint16_t *, vuint64m1_t, vuint16mf4_t, vuint16mf4_t, vuint16mf4_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vsoxseg4ei64_v)))
void vsoxseg4ei64_v_i16m1(int16_t *, vuint64m4_t, vint16m1_t, vint16m1_t, vint16m1_t, vint16m1_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vsoxseg4ei64_v_m)))
void vsoxseg4ei64_v_i16m1_m(vbool16_t, int16_t *, vuint64m4_t, vint16m1_t, vint16m1_t, vint16m1_t, vint16m1_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vsoxseg4ei64_v)))
void vsoxseg4ei64_v_i16m2(int16_t *, vuint64m8_t, vint16m2_t, vint16m2_t, vint16m2_t, vint16m2_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vsoxseg4ei64_v_m)))
void vsoxseg4ei64_v_i16m2_m(vbool8_t, int16_t *, vuint64m8_t, vint16m2_t, vint16m2_t, vint16m2_t, vint16m2_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vsoxseg4ei64_v)))
void vsoxseg4ei64_v_i16mf2(int16_t *, vuint64m2_t, vint16mf2_t, vint16mf2_t, vint16mf2_t, vint16mf2_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vsoxseg4ei64_v_m)))
void vsoxseg4ei64_v_i16mf2_m(vbool32_t, int16_t *, vuint64m2_t, vint16mf2_t, vint16mf2_t, vint16mf2_t, vint16mf2_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vsoxseg4ei64_v)))
void vsoxseg4ei64_v_i16mf4(int16_t *, vuint64m1_t, vint16mf4_t, vint16mf4_t, vint16mf4_t, vint16mf4_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vsoxseg4ei64_v_m)))
void vsoxseg4ei64_v_i16mf4_m(vbool64_t, int16_t *, vuint64m1_t, vint16mf4_t, vint16mf4_t, vint16mf4_t, vint16mf4_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vsoxseg4ei64_v)))
void vsoxseg4ei64_v_u16m1(uint16_t *, vuint64m4_t, vuint16m1_t, vuint16m1_t, vuint16m1_t, vuint16m1_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vsoxseg4ei64_v_m)))
void vsoxseg4ei64_v_u16m1_m(vbool16_t, uint16_t *, vuint64m4_t, vuint16m1_t, vuint16m1_t, vuint16m1_t, vuint16m1_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vsoxseg4ei64_v)))
void vsoxseg4ei64_v_u16m2(uint16_t *, vuint64m8_t, vuint16m2_t, vuint16m2_t, vuint16m2_t, vuint16m2_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vsoxseg4ei64_v_m)))
void vsoxseg4ei64_v_u16m2_m(vbool8_t, uint16_t *, vuint64m8_t, vuint16m2_t, vuint16m2_t, vuint16m2_t, vuint16m2_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vsoxseg4ei64_v)))
void vsoxseg4ei64_v_u16mf2(uint16_t *, vuint64m2_t, vuint16mf2_t, vuint16mf2_t, vuint16mf2_t, vuint16mf2_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vsoxseg4ei64_v_m)))
void vsoxseg4ei64_v_u16mf2_m(vbool32_t, uint16_t *, vuint64m2_t, vuint16mf2_t, vuint16mf2_t, vuint16mf2_t, vuint16mf2_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vsoxseg4ei64_v)))
void vsoxseg4ei64_v_u16mf4(uint16_t *, vuint64m1_t, vuint16mf4_t, vuint16mf4_t, vuint16mf4_t, vuint16mf4_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vsoxseg4ei64_v_m)))
void vsoxseg4ei64_v_u16mf4_m(vbool64_t, uint16_t *, vuint64m1_t, vuint16mf4_t, vuint16mf4_t, vuint16mf4_t, vuint16mf4_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vsoxseg5ei64_v)))
void vsoxseg5ei64_v_i16m1(int16_t *, vuint64m4_t, vint16m1_t, vint16m1_t, vint16m1_t, vint16m1_t, vint16m1_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vsoxseg5ei64_v_m)))
void vsoxseg5ei64_v_i16m1_m(vbool16_t, int16_t *, vuint64m4_t, vint16m1_t, vint16m1_t, vint16m1_t, vint16m1_t, vint16m1_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vsoxseg5ei64_v)))
void vsoxseg5ei64_v_i16mf2(int16_t *, vuint64m2_t, vint16mf2_t, vint16mf2_t, vint16mf2_t, vint16mf2_t, vint16mf2_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vsoxseg5ei64_v_m)))
void vsoxseg5ei64_v_i16mf2_m(vbool32_t, int16_t *, vuint64m2_t, vint16mf2_t, vint16mf2_t, vint16mf2_t, vint16mf2_t, vint16mf2_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vsoxseg5ei64_v)))
void vsoxseg5ei64_v_i16mf4(int16_t *, vuint64m1_t, vint16mf4_t, vint16mf4_t, vint16mf4_t, vint16mf4_t, vint16mf4_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vsoxseg5ei64_v_m)))
void vsoxseg5ei64_v_i16mf4_m(vbool64_t, int16_t *, vuint64m1_t, vint16mf4_t, vint16mf4_t, vint16mf4_t, vint16mf4_t, vint16mf4_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vsoxseg5ei64_v)))
void vsoxseg5ei64_v_u16m1(uint16_t *, vuint64m4_t, vuint16m1_t, vuint16m1_t, vuint16m1_t, vuint16m1_t, vuint16m1_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vsoxseg5ei64_v_m)))
void vsoxseg5ei64_v_u16m1_m(vbool16_t, uint16_t *, vuint64m4_t, vuint16m1_t, vuint16m1_t, vuint16m1_t, vuint16m1_t, vuint16m1_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vsoxseg5ei64_v)))
void vsoxseg5ei64_v_u16mf2(uint16_t *, vuint64m2_t, vuint16mf2_t, vuint16mf2_t, vuint16mf2_t, vuint16mf2_t, vuint16mf2_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vsoxseg5ei64_v_m)))
void vsoxseg5ei64_v_u16mf2_m(vbool32_t, uint16_t *, vuint64m2_t, vuint16mf2_t, vuint16mf2_t, vuint16mf2_t, vuint16mf2_t, vuint16mf2_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vsoxseg5ei64_v)))
void vsoxseg5ei64_v_u16mf4(uint16_t *, vuint64m1_t, vuint16mf4_t, vuint16mf4_t, vuint16mf4_t, vuint16mf4_t, vuint16mf4_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vsoxseg5ei64_v_m)))
void vsoxseg5ei64_v_u16mf4_m(vbool64_t, uint16_t *, vuint64m1_t, vuint16mf4_t, vuint16mf4_t, vuint16mf4_t, vuint16mf4_t, vuint16mf4_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vsoxseg6ei64_v)))
void vsoxseg6ei64_v_i16m1(int16_t *, vuint64m4_t, vint16m1_t, vint16m1_t, vint16m1_t, vint16m1_t, vint16m1_t, vint16m1_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vsoxseg6ei64_v_m)))
void vsoxseg6ei64_v_i16m1_m(vbool16_t, int16_t *, vuint64m4_t, vint16m1_t, vint16m1_t, vint16m1_t, vint16m1_t, vint16m1_t, vint16m1_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vsoxseg6ei64_v)))
void vsoxseg6ei64_v_i16mf2(int16_t *, vuint64m2_t, vint16mf2_t, vint16mf2_t, vint16mf2_t, vint16mf2_t, vint16mf2_t, vint16mf2_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vsoxseg6ei64_v_m)))
void vsoxseg6ei64_v_i16mf2_m(vbool32_t, int16_t *, vuint64m2_t, vint16mf2_t, vint16mf2_t, vint16mf2_t, vint16mf2_t, vint16mf2_t, vint16mf2_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vsoxseg6ei64_v)))
void vsoxseg6ei64_v_i16mf4(int16_t *, vuint64m1_t, vint16mf4_t, vint16mf4_t, vint16mf4_t, vint16mf4_t, vint16mf4_t, vint16mf4_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vsoxseg6ei64_v_m)))
void vsoxseg6ei64_v_i16mf4_m(vbool64_t, int16_t *, vuint64m1_t, vint16mf4_t, vint16mf4_t, vint16mf4_t, vint16mf4_t, vint16mf4_t, vint16mf4_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vsoxseg6ei64_v)))
void vsoxseg6ei64_v_u16m1(uint16_t *, vuint64m4_t, vuint16m1_t, vuint16m1_t, vuint16m1_t, vuint16m1_t, vuint16m1_t, vuint16m1_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vsoxseg6ei64_v_m)))
void vsoxseg6ei64_v_u16m1_m(vbool16_t, uint16_t *, vuint64m4_t, vuint16m1_t, vuint16m1_t, vuint16m1_t, vuint16m1_t, vuint16m1_t, vuint16m1_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vsoxseg6ei64_v)))
void vsoxseg6ei64_v_u16mf2(uint16_t *, vuint64m2_t, vuint16mf2_t, vuint16mf2_t, vuint16mf2_t, vuint16mf2_t, vuint16mf2_t, vuint16mf2_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vsoxseg6ei64_v_m)))
void vsoxseg6ei64_v_u16mf2_m(vbool32_t, uint16_t *, vuint64m2_t, vuint16mf2_t, vuint16mf2_t, vuint16mf2_t, vuint16mf2_t, vuint16mf2_t, vuint16mf2_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vsoxseg6ei64_v)))
void vsoxseg6ei64_v_u16mf4(uint16_t *, vuint64m1_t, vuint16mf4_t, vuint16mf4_t, vuint16mf4_t, vuint16mf4_t, vuint16mf4_t, vuint16mf4_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vsoxseg6ei64_v_m)))
void vsoxseg6ei64_v_u16mf4_m(vbool64_t, uint16_t *, vuint64m1_t, vuint16mf4_t, vuint16mf4_t, vuint16mf4_t, vuint16mf4_t, vuint16mf4_t, vuint16mf4_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vsoxseg7ei64_v)))
void vsoxseg7ei64_v_i16m1(int16_t *, vuint64m4_t, vint16m1_t, vint16m1_t, vint16m1_t, vint16m1_t, vint16m1_t, vint16m1_t, vint16m1_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vsoxseg7ei64_v_m)))
void vsoxseg7ei64_v_i16m1_m(vbool16_t, int16_t *, vuint64m4_t, vint16m1_t, vint16m1_t, vint16m1_t, vint16m1_t, vint16m1_t, vint16m1_t, vint16m1_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vsoxseg7ei64_v)))
void vsoxseg7ei64_v_i16mf2(int16_t *, vuint64m2_t, vint16mf2_t, vint16mf2_t, vint16mf2_t, vint16mf2_t, vint16mf2_t, vint16mf2_t, vint16mf2_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vsoxseg7ei64_v_m)))
void vsoxseg7ei64_v_i16mf2_m(vbool32_t, int16_t *, vuint64m2_t, vint16mf2_t, vint16mf2_t, vint16mf2_t, vint16mf2_t, vint16mf2_t, vint16mf2_t, vint16mf2_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vsoxseg7ei64_v)))
void vsoxseg7ei64_v_i16mf4(int16_t *, vuint64m1_t, vint16mf4_t, vint16mf4_t, vint16mf4_t, vint16mf4_t, vint16mf4_t, vint16mf4_t, vint16mf4_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vsoxseg7ei64_v_m)))
void vsoxseg7ei64_v_i16mf4_m(vbool64_t, int16_t *, vuint64m1_t, vint16mf4_t, vint16mf4_t, vint16mf4_t, vint16mf4_t, vint16mf4_t, vint16mf4_t, vint16mf4_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vsoxseg7ei64_v)))
void vsoxseg7ei64_v_u16m1(uint16_t *, vuint64m4_t, vuint16m1_t, vuint16m1_t, vuint16m1_t, vuint16m1_t, vuint16m1_t, vuint16m1_t, vuint16m1_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vsoxseg7ei64_v_m)))
void vsoxseg7ei64_v_u16m1_m(vbool16_t, uint16_t *, vuint64m4_t, vuint16m1_t, vuint16m1_t, vuint16m1_t, vuint16m1_t, vuint16m1_t, vuint16m1_t, vuint16m1_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vsoxseg7ei64_v)))
void vsoxseg7ei64_v_u16mf2(uint16_t *, vuint64m2_t, vuint16mf2_t, vuint16mf2_t, vuint16mf2_t, vuint16mf2_t, vuint16mf2_t, vuint16mf2_t, vuint16mf2_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vsoxseg7ei64_v_m)))
void vsoxseg7ei64_v_u16mf2_m(vbool32_t, uint16_t *, vuint64m2_t, vuint16mf2_t, vuint16mf2_t, vuint16mf2_t, vuint16mf2_t, vuint16mf2_t, vuint16mf2_t, vuint16mf2_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vsoxseg7ei64_v)))
void vsoxseg7ei64_v_u16mf4(uint16_t *, vuint64m1_t, vuint16mf4_t, vuint16mf4_t, vuint16mf4_t, vuint16mf4_t, vuint16mf4_t, vuint16mf4_t, vuint16mf4_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vsoxseg7ei64_v_m)))
void vsoxseg7ei64_v_u16mf4_m(vbool64_t, uint16_t *, vuint64m1_t, vuint16mf4_t, vuint16mf4_t, vuint16mf4_t, vuint16mf4_t, vuint16mf4_t, vuint16mf4_t, vuint16mf4_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vsoxseg8ei64_v)))
void vsoxseg8ei64_v_i16m1(int16_t *, vuint64m4_t, vint16m1_t, vint16m1_t, vint16m1_t, vint16m1_t, vint16m1_t, vint16m1_t, vint16m1_t, vint16m1_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vsoxseg8ei64_v_m)))
void vsoxseg8ei64_v_i16m1_m(vbool16_t, int16_t *, vuint64m4_t, vint16m1_t, vint16m1_t, vint16m1_t, vint16m1_t, vint16m1_t, vint16m1_t, vint16m1_t, vint16m1_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vsoxseg8ei64_v)))
void vsoxseg8ei64_v_i16mf2(int16_t *, vuint64m2_t, vint16mf2_t, vint16mf2_t, vint16mf2_t, vint16mf2_t, vint16mf2_t, vint16mf2_t, vint16mf2_t, vint16mf2_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vsoxseg8ei64_v_m)))
void vsoxseg8ei64_v_i16mf2_m(vbool32_t, int16_t *, vuint64m2_t, vint16mf2_t, vint16mf2_t, vint16mf2_t, vint16mf2_t, vint16mf2_t, vint16mf2_t, vint16mf2_t, vint16mf2_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vsoxseg8ei64_v)))
void vsoxseg8ei64_v_i16mf4(int16_t *, vuint64m1_t, vint16mf4_t, vint16mf4_t, vint16mf4_t, vint16mf4_t, vint16mf4_t, vint16mf4_t, vint16mf4_t, vint16mf4_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vsoxseg8ei64_v_m)))
void vsoxseg8ei64_v_i16mf4_m(vbool64_t, int16_t *, vuint64m1_t, vint16mf4_t, vint16mf4_t, vint16mf4_t, vint16mf4_t, vint16mf4_t, vint16mf4_t, vint16mf4_t, vint16mf4_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vsoxseg8ei64_v)))
void vsoxseg8ei64_v_u16m1(uint16_t *, vuint64m4_t, vuint16m1_t, vuint16m1_t, vuint16m1_t, vuint16m1_t, vuint16m1_t, vuint16m1_t, vuint16m1_t, vuint16m1_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vsoxseg8ei64_v_m)))
void vsoxseg8ei64_v_u16m1_m(vbool16_t, uint16_t *, vuint64m4_t, vuint16m1_t, vuint16m1_t, vuint16m1_t, vuint16m1_t, vuint16m1_t, vuint16m1_t, vuint16m1_t, vuint16m1_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vsoxseg8ei64_v)))
void vsoxseg8ei64_v_u16mf2(uint16_t *, vuint64m2_t, vuint16mf2_t, vuint16mf2_t, vuint16mf2_t, vuint16mf2_t, vuint16mf2_t, vuint16mf2_t, vuint16mf2_t, vuint16mf2_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vsoxseg8ei64_v_m)))
void vsoxseg8ei64_v_u16mf2_m(vbool32_t, uint16_t *, vuint64m2_t, vuint16mf2_t, vuint16mf2_t, vuint16mf2_t, vuint16mf2_t, vuint16mf2_t, vuint16mf2_t, vuint16mf2_t, vuint16mf2_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vsoxseg8ei64_v)))
void vsoxseg8ei64_v_u16mf4(uint16_t *, vuint64m1_t, vuint16mf4_t, vuint16mf4_t, vuint16mf4_t, vuint16mf4_t, vuint16mf4_t, vuint16mf4_t, vuint16mf4_t, vuint16mf4_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vsoxseg8ei64_v_m)))
void vsoxseg8ei64_v_u16mf4_m(vbool64_t, uint16_t *, vuint64m1_t, vuint16mf4_t, vuint16mf4_t, vuint16mf4_t, vuint16mf4_t, vuint16mf4_t, vuint16mf4_t, vuint16mf4_t, vuint16mf4_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vsoxseg2ei64_v)))
void vsoxseg2ei64_v_i32m1(int32_t *, vuint64m2_t, vint32m1_t, vint32m1_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vsoxseg2ei64_v_m)))
void vsoxseg2ei64_v_i32m1_m(vbool32_t, int32_t *, vuint64m2_t, vint32m1_t, vint32m1_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vsoxseg2ei64_v)))
void vsoxseg2ei64_v_i32m2(int32_t *, vuint64m4_t, vint32m2_t, vint32m2_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vsoxseg2ei64_v_m)))
void vsoxseg2ei64_v_i32m2_m(vbool16_t, int32_t *, vuint64m4_t, vint32m2_t, vint32m2_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vsoxseg2ei64_v)))
void vsoxseg2ei64_v_i32m4(int32_t *, vuint64m8_t, vint32m4_t, vint32m4_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vsoxseg2ei64_v_m)))
void vsoxseg2ei64_v_i32m4_m(vbool8_t, int32_t *, vuint64m8_t, vint32m4_t, vint32m4_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vsoxseg2ei64_v)))
void vsoxseg2ei64_v_i32mf2(int32_t *, vuint64m1_t, vint32mf2_t, vint32mf2_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vsoxseg2ei64_v_m)))
void vsoxseg2ei64_v_i32mf2_m(vbool64_t, int32_t *, vuint64m1_t, vint32mf2_t, vint32mf2_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vsoxseg2ei64_v)))
void vsoxseg2ei64_v_u32m1(uint32_t *, vuint64m2_t, vuint32m1_t, vuint32m1_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vsoxseg2ei64_v_m)))
void vsoxseg2ei64_v_u32m1_m(vbool32_t, uint32_t *, vuint64m2_t, vuint32m1_t, vuint32m1_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vsoxseg2ei64_v)))
void vsoxseg2ei64_v_u32m2(uint32_t *, vuint64m4_t, vuint32m2_t, vuint32m2_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vsoxseg2ei64_v_m)))
void vsoxseg2ei64_v_u32m2_m(vbool16_t, uint32_t *, vuint64m4_t, vuint32m2_t, vuint32m2_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vsoxseg2ei64_v)))
void vsoxseg2ei64_v_u32m4(uint32_t *, vuint64m8_t, vuint32m4_t, vuint32m4_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vsoxseg2ei64_v_m)))
void vsoxseg2ei64_v_u32m4_m(vbool8_t, uint32_t *, vuint64m8_t, vuint32m4_t, vuint32m4_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vsoxseg2ei64_v)))
void vsoxseg2ei64_v_u32mf2(uint32_t *, vuint64m1_t, vuint32mf2_t, vuint32mf2_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vsoxseg2ei64_v_m)))
void vsoxseg2ei64_v_u32mf2_m(vbool64_t, uint32_t *, vuint64m1_t, vuint32mf2_t, vuint32mf2_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vsoxseg3ei64_v)))
void vsoxseg3ei64_v_i32m1(int32_t *, vuint64m2_t, vint32m1_t, vint32m1_t, vint32m1_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vsoxseg3ei64_v_m)))
void vsoxseg3ei64_v_i32m1_m(vbool32_t, int32_t *, vuint64m2_t, vint32m1_t, vint32m1_t, vint32m1_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vsoxseg3ei64_v)))
void vsoxseg3ei64_v_i32m2(int32_t *, vuint64m4_t, vint32m2_t, vint32m2_t, vint32m2_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vsoxseg3ei64_v_m)))
void vsoxseg3ei64_v_i32m2_m(vbool16_t, int32_t *, vuint64m4_t, vint32m2_t, vint32m2_t, vint32m2_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vsoxseg3ei64_v)))
void vsoxseg3ei64_v_i32mf2(int32_t *, vuint64m1_t, vint32mf2_t, vint32mf2_t, vint32mf2_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vsoxseg3ei64_v_m)))
void vsoxseg3ei64_v_i32mf2_m(vbool64_t, int32_t *, vuint64m1_t, vint32mf2_t, vint32mf2_t, vint32mf2_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vsoxseg3ei64_v)))
void vsoxseg3ei64_v_u32m1(uint32_t *, vuint64m2_t, vuint32m1_t, vuint32m1_t, vuint32m1_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vsoxseg3ei64_v_m)))
void vsoxseg3ei64_v_u32m1_m(vbool32_t, uint32_t *, vuint64m2_t, vuint32m1_t, vuint32m1_t, vuint32m1_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vsoxseg3ei64_v)))
void vsoxseg3ei64_v_u32m2(uint32_t *, vuint64m4_t, vuint32m2_t, vuint32m2_t, vuint32m2_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vsoxseg3ei64_v_m)))
void vsoxseg3ei64_v_u32m2_m(vbool16_t, uint32_t *, vuint64m4_t, vuint32m2_t, vuint32m2_t, vuint32m2_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vsoxseg3ei64_v)))
void vsoxseg3ei64_v_u32mf2(uint32_t *, vuint64m1_t, vuint32mf2_t, vuint32mf2_t, vuint32mf2_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vsoxseg3ei64_v_m)))
void vsoxseg3ei64_v_u32mf2_m(vbool64_t, uint32_t *, vuint64m1_t, vuint32mf2_t, vuint32mf2_t, vuint32mf2_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vsoxseg4ei64_v)))
void vsoxseg4ei64_v_i32m1(int32_t *, vuint64m2_t, vint32m1_t, vint32m1_t, vint32m1_t, vint32m1_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vsoxseg4ei64_v_m)))
void vsoxseg4ei64_v_i32m1_m(vbool32_t, int32_t *, vuint64m2_t, vint32m1_t, vint32m1_t, vint32m1_t, vint32m1_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vsoxseg4ei64_v)))
void vsoxseg4ei64_v_i32m2(int32_t *, vuint64m4_t, vint32m2_t, vint32m2_t, vint32m2_t, vint32m2_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vsoxseg4ei64_v_m)))
void vsoxseg4ei64_v_i32m2_m(vbool16_t, int32_t *, vuint64m4_t, vint32m2_t, vint32m2_t, vint32m2_t, vint32m2_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vsoxseg4ei64_v)))
void vsoxseg4ei64_v_i32mf2(int32_t *, vuint64m1_t, vint32mf2_t, vint32mf2_t, vint32mf2_t, vint32mf2_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vsoxseg4ei64_v_m)))
void vsoxseg4ei64_v_i32mf2_m(vbool64_t, int32_t *, vuint64m1_t, vint32mf2_t, vint32mf2_t, vint32mf2_t, vint32mf2_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vsoxseg4ei64_v)))
void vsoxseg4ei64_v_u32m1(uint32_t *, vuint64m2_t, vuint32m1_t, vuint32m1_t, vuint32m1_t, vuint32m1_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vsoxseg4ei64_v_m)))
void vsoxseg4ei64_v_u32m1_m(vbool32_t, uint32_t *, vuint64m2_t, vuint32m1_t, vuint32m1_t, vuint32m1_t, vuint32m1_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vsoxseg4ei64_v)))
void vsoxseg4ei64_v_u32m2(uint32_t *, vuint64m4_t, vuint32m2_t, vuint32m2_t, vuint32m2_t, vuint32m2_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vsoxseg4ei64_v_m)))
void vsoxseg4ei64_v_u32m2_m(vbool16_t, uint32_t *, vuint64m4_t, vuint32m2_t, vuint32m2_t, vuint32m2_t, vuint32m2_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vsoxseg4ei64_v)))
void vsoxseg4ei64_v_u32mf2(uint32_t *, vuint64m1_t, vuint32mf2_t, vuint32mf2_t, vuint32mf2_t, vuint32mf2_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vsoxseg4ei64_v_m)))
void vsoxseg4ei64_v_u32mf2_m(vbool64_t, uint32_t *, vuint64m1_t, vuint32mf2_t, vuint32mf2_t, vuint32mf2_t, vuint32mf2_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vsoxseg5ei64_v)))
void vsoxseg5ei64_v_i32m1(int32_t *, vuint64m2_t, vint32m1_t, vint32m1_t, vint32m1_t, vint32m1_t, vint32m1_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vsoxseg5ei64_v_m)))
void vsoxseg5ei64_v_i32m1_m(vbool32_t, int32_t *, vuint64m2_t, vint32m1_t, vint32m1_t, vint32m1_t, vint32m1_t, vint32m1_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vsoxseg5ei64_v)))
void vsoxseg5ei64_v_i32mf2(int32_t *, vuint64m1_t, vint32mf2_t, vint32mf2_t, vint32mf2_t, vint32mf2_t, vint32mf2_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vsoxseg5ei64_v_m)))
void vsoxseg5ei64_v_i32mf2_m(vbool64_t, int32_t *, vuint64m1_t, vint32mf2_t, vint32mf2_t, vint32mf2_t, vint32mf2_t, vint32mf2_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vsoxseg5ei64_v)))
void vsoxseg5ei64_v_u32m1(uint32_t *, vuint64m2_t, vuint32m1_t, vuint32m1_t, vuint32m1_t, vuint32m1_t, vuint32m1_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vsoxseg5ei64_v_m)))
void vsoxseg5ei64_v_u32m1_m(vbool32_t, uint32_t *, vuint64m2_t, vuint32m1_t, vuint32m1_t, vuint32m1_t, vuint32m1_t, vuint32m1_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vsoxseg5ei64_v)))
void vsoxseg5ei64_v_u32mf2(uint32_t *, vuint64m1_t, vuint32mf2_t, vuint32mf2_t, vuint32mf2_t, vuint32mf2_t, vuint32mf2_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vsoxseg5ei64_v_m)))
void vsoxseg5ei64_v_u32mf2_m(vbool64_t, uint32_t *, vuint64m1_t, vuint32mf2_t, vuint32mf2_t, vuint32mf2_t, vuint32mf2_t, vuint32mf2_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vsoxseg6ei64_v)))
void vsoxseg6ei64_v_i32m1(int32_t *, vuint64m2_t, vint32m1_t, vint32m1_t, vint32m1_t, vint32m1_t, vint32m1_t, vint32m1_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vsoxseg6ei64_v_m)))
void vsoxseg6ei64_v_i32m1_m(vbool32_t, int32_t *, vuint64m2_t, vint32m1_t, vint32m1_t, vint32m1_t, vint32m1_t, vint32m1_t, vint32m1_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vsoxseg6ei64_v)))
void vsoxseg6ei64_v_i32mf2(int32_t *, vuint64m1_t, vint32mf2_t, vint32mf2_t, vint32mf2_t, vint32mf2_t, vint32mf2_t, vint32mf2_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vsoxseg6ei64_v_m)))
void vsoxseg6ei64_v_i32mf2_m(vbool64_t, int32_t *, vuint64m1_t, vint32mf2_t, vint32mf2_t, vint32mf2_t, vint32mf2_t, vint32mf2_t, vint32mf2_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vsoxseg6ei64_v)))
void vsoxseg6ei64_v_u32m1(uint32_t *, vuint64m2_t, vuint32m1_t, vuint32m1_t, vuint32m1_t, vuint32m1_t, vuint32m1_t, vuint32m1_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vsoxseg6ei64_v_m)))
void vsoxseg6ei64_v_u32m1_m(vbool32_t, uint32_t *, vuint64m2_t, vuint32m1_t, vuint32m1_t, vuint32m1_t, vuint32m1_t, vuint32m1_t, vuint32m1_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vsoxseg6ei64_v)))
void vsoxseg6ei64_v_u32mf2(uint32_t *, vuint64m1_t, vuint32mf2_t, vuint32mf2_t, vuint32mf2_t, vuint32mf2_t, vuint32mf2_t, vuint32mf2_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vsoxseg6ei64_v_m)))
void vsoxseg6ei64_v_u32mf2_m(vbool64_t, uint32_t *, vuint64m1_t, vuint32mf2_t, vuint32mf2_t, vuint32mf2_t, vuint32mf2_t, vuint32mf2_t, vuint32mf2_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vsoxseg7ei64_v)))
void vsoxseg7ei64_v_i32m1(int32_t *, vuint64m2_t, vint32m1_t, vint32m1_t, vint32m1_t, vint32m1_t, vint32m1_t, vint32m1_t, vint32m1_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vsoxseg7ei64_v_m)))
void vsoxseg7ei64_v_i32m1_m(vbool32_t, int32_t *, vuint64m2_t, vint32m1_t, vint32m1_t, vint32m1_t, vint32m1_t, vint32m1_t, vint32m1_t, vint32m1_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vsoxseg7ei64_v)))
void vsoxseg7ei64_v_i32mf2(int32_t *, vuint64m1_t, vint32mf2_t, vint32mf2_t, vint32mf2_t, vint32mf2_t, vint32mf2_t, vint32mf2_t, vint32mf2_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vsoxseg7ei64_v_m)))
void vsoxseg7ei64_v_i32mf2_m(vbool64_t, int32_t *, vuint64m1_t, vint32mf2_t, vint32mf2_t, vint32mf2_t, vint32mf2_t, vint32mf2_t, vint32mf2_t, vint32mf2_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vsoxseg7ei64_v)))
void vsoxseg7ei64_v_u32m1(uint32_t *, vuint64m2_t, vuint32m1_t, vuint32m1_t, vuint32m1_t, vuint32m1_t, vuint32m1_t, vuint32m1_t, vuint32m1_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vsoxseg7ei64_v_m)))
void vsoxseg7ei64_v_u32m1_m(vbool32_t, uint32_t *, vuint64m2_t, vuint32m1_t, vuint32m1_t, vuint32m1_t, vuint32m1_t, vuint32m1_t, vuint32m1_t, vuint32m1_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vsoxseg7ei64_v)))
void vsoxseg7ei64_v_u32mf2(uint32_t *, vuint64m1_t, vuint32mf2_t, vuint32mf2_t, vuint32mf2_t, vuint32mf2_t, vuint32mf2_t, vuint32mf2_t, vuint32mf2_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vsoxseg7ei64_v_m)))
void vsoxseg7ei64_v_u32mf2_m(vbool64_t, uint32_t *, vuint64m1_t, vuint32mf2_t, vuint32mf2_t, vuint32mf2_t, vuint32mf2_t, vuint32mf2_t, vuint32mf2_t, vuint32mf2_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vsoxseg8ei64_v)))
void vsoxseg8ei64_v_i32m1(int32_t *, vuint64m2_t, vint32m1_t, vint32m1_t, vint32m1_t, vint32m1_t, vint32m1_t, vint32m1_t, vint32m1_t, vint32m1_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vsoxseg8ei64_v_m)))
void vsoxseg8ei64_v_i32m1_m(vbool32_t, int32_t *, vuint64m2_t, vint32m1_t, vint32m1_t, vint32m1_t, vint32m1_t, vint32m1_t, vint32m1_t, vint32m1_t, vint32m1_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vsoxseg8ei64_v)))
void vsoxseg8ei64_v_i32mf2(int32_t *, vuint64m1_t, vint32mf2_t, vint32mf2_t, vint32mf2_t, vint32mf2_t, vint32mf2_t, vint32mf2_t, vint32mf2_t, vint32mf2_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vsoxseg8ei64_v_m)))
void vsoxseg8ei64_v_i32mf2_m(vbool64_t, int32_t *, vuint64m1_t, vint32mf2_t, vint32mf2_t, vint32mf2_t, vint32mf2_t, vint32mf2_t, vint32mf2_t, vint32mf2_t, vint32mf2_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vsoxseg8ei64_v)))
void vsoxseg8ei64_v_u32m1(uint32_t *, vuint64m2_t, vuint32m1_t, vuint32m1_t, vuint32m1_t, vuint32m1_t, vuint32m1_t, vuint32m1_t, vuint32m1_t, vuint32m1_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vsoxseg8ei64_v_m)))
void vsoxseg8ei64_v_u32m1_m(vbool32_t, uint32_t *, vuint64m2_t, vuint32m1_t, vuint32m1_t, vuint32m1_t, vuint32m1_t, vuint32m1_t, vuint32m1_t, vuint32m1_t, vuint32m1_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vsoxseg8ei64_v)))
void vsoxseg8ei64_v_u32mf2(uint32_t *, vuint64m1_t, vuint32mf2_t, vuint32mf2_t, vuint32mf2_t, vuint32mf2_t, vuint32mf2_t, vuint32mf2_t, vuint32mf2_t, vuint32mf2_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vsoxseg8ei64_v_m)))
void vsoxseg8ei64_v_u32mf2_m(vbool64_t, uint32_t *, vuint64m1_t, vuint32mf2_t, vuint32mf2_t, vuint32mf2_t, vuint32mf2_t, vuint32mf2_t, vuint32mf2_t, vuint32mf2_t, vuint32mf2_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vsoxseg2ei8_v)))
void vsoxseg2ei8_v_i64m1(int64_t *, vuint8mf8_t, vint64m1_t, vint64m1_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vsoxseg2ei8_v_m)))
void vsoxseg2ei8_v_i64m1_m(vbool64_t, int64_t *, vuint8mf8_t, vint64m1_t, vint64m1_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vsoxseg2ei8_v)))
void vsoxseg2ei8_v_i64m2(int64_t *, vuint8mf4_t, vint64m2_t, vint64m2_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vsoxseg2ei8_v_m)))
void vsoxseg2ei8_v_i64m2_m(vbool32_t, int64_t *, vuint8mf4_t, vint64m2_t, vint64m2_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vsoxseg2ei8_v)))
void vsoxseg2ei8_v_i64m4(int64_t *, vuint8mf2_t, vint64m4_t, vint64m4_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vsoxseg2ei8_v_m)))
void vsoxseg2ei8_v_i64m4_m(vbool16_t, int64_t *, vuint8mf2_t, vint64m4_t, vint64m4_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vsoxseg2ei8_v)))
void vsoxseg2ei8_v_u64m1(uint64_t *, vuint8mf8_t, vuint64m1_t, vuint64m1_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vsoxseg2ei8_v_m)))
void vsoxseg2ei8_v_u64m1_m(vbool64_t, uint64_t *, vuint8mf8_t, vuint64m1_t, vuint64m1_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vsoxseg2ei8_v)))
void vsoxseg2ei8_v_u64m2(uint64_t *, vuint8mf4_t, vuint64m2_t, vuint64m2_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vsoxseg2ei8_v_m)))
void vsoxseg2ei8_v_u64m2_m(vbool32_t, uint64_t *, vuint8mf4_t, vuint64m2_t, vuint64m2_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vsoxseg2ei8_v)))
void vsoxseg2ei8_v_u64m4(uint64_t *, vuint8mf2_t, vuint64m4_t, vuint64m4_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vsoxseg2ei8_v_m)))
void vsoxseg2ei8_v_u64m4_m(vbool16_t, uint64_t *, vuint8mf2_t, vuint64m4_t, vuint64m4_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vsoxseg3ei8_v)))
void vsoxseg3ei8_v_i64m1(int64_t *, vuint8mf8_t, vint64m1_t, vint64m1_t, vint64m1_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vsoxseg3ei8_v_m)))
void vsoxseg3ei8_v_i64m1_m(vbool64_t, int64_t *, vuint8mf8_t, vint64m1_t, vint64m1_t, vint64m1_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vsoxseg3ei8_v)))
void vsoxseg3ei8_v_i64m2(int64_t *, vuint8mf4_t, vint64m2_t, vint64m2_t, vint64m2_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vsoxseg3ei8_v_m)))
void vsoxseg3ei8_v_i64m2_m(vbool32_t, int64_t *, vuint8mf4_t, vint64m2_t, vint64m2_t, vint64m2_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vsoxseg3ei8_v)))
void vsoxseg3ei8_v_u64m1(uint64_t *, vuint8mf8_t, vuint64m1_t, vuint64m1_t, vuint64m1_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vsoxseg3ei8_v_m)))
void vsoxseg3ei8_v_u64m1_m(vbool64_t, uint64_t *, vuint8mf8_t, vuint64m1_t, vuint64m1_t, vuint64m1_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vsoxseg3ei8_v)))
void vsoxseg3ei8_v_u64m2(uint64_t *, vuint8mf4_t, vuint64m2_t, vuint64m2_t, vuint64m2_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vsoxseg3ei8_v_m)))
void vsoxseg3ei8_v_u64m2_m(vbool32_t, uint64_t *, vuint8mf4_t, vuint64m2_t, vuint64m2_t, vuint64m2_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vsoxseg4ei8_v)))
void vsoxseg4ei8_v_i64m1(int64_t *, vuint8mf8_t, vint64m1_t, vint64m1_t, vint64m1_t, vint64m1_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vsoxseg4ei8_v_m)))
void vsoxseg4ei8_v_i64m1_m(vbool64_t, int64_t *, vuint8mf8_t, vint64m1_t, vint64m1_t, vint64m1_t, vint64m1_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vsoxseg4ei8_v)))
void vsoxseg4ei8_v_i64m2(int64_t *, vuint8mf4_t, vint64m2_t, vint64m2_t, vint64m2_t, vint64m2_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vsoxseg4ei8_v_m)))
void vsoxseg4ei8_v_i64m2_m(vbool32_t, int64_t *, vuint8mf4_t, vint64m2_t, vint64m2_t, vint64m2_t, vint64m2_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vsoxseg4ei8_v)))
void vsoxseg4ei8_v_u64m1(uint64_t *, vuint8mf8_t, vuint64m1_t, vuint64m1_t, vuint64m1_t, vuint64m1_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vsoxseg4ei8_v_m)))
void vsoxseg4ei8_v_u64m1_m(vbool64_t, uint64_t *, vuint8mf8_t, vuint64m1_t, vuint64m1_t, vuint64m1_t, vuint64m1_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vsoxseg4ei8_v)))
void vsoxseg4ei8_v_u64m2(uint64_t *, vuint8mf4_t, vuint64m2_t, vuint64m2_t, vuint64m2_t, vuint64m2_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vsoxseg4ei8_v_m)))
void vsoxseg4ei8_v_u64m2_m(vbool32_t, uint64_t *, vuint8mf4_t, vuint64m2_t, vuint64m2_t, vuint64m2_t, vuint64m2_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vsoxseg5ei8_v)))
void vsoxseg5ei8_v_i64m1(int64_t *, vuint8mf8_t, vint64m1_t, vint64m1_t, vint64m1_t, vint64m1_t, vint64m1_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vsoxseg5ei8_v_m)))
void vsoxseg5ei8_v_i64m1_m(vbool64_t, int64_t *, vuint8mf8_t, vint64m1_t, vint64m1_t, vint64m1_t, vint64m1_t, vint64m1_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vsoxseg5ei8_v)))
void vsoxseg5ei8_v_u64m1(uint64_t *, vuint8mf8_t, vuint64m1_t, vuint64m1_t, vuint64m1_t, vuint64m1_t, vuint64m1_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vsoxseg5ei8_v_m)))
void vsoxseg5ei8_v_u64m1_m(vbool64_t, uint64_t *, vuint8mf8_t, vuint64m1_t, vuint64m1_t, vuint64m1_t, vuint64m1_t, vuint64m1_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vsoxseg6ei8_v)))
void vsoxseg6ei8_v_i64m1(int64_t *, vuint8mf8_t, vint64m1_t, vint64m1_t, vint64m1_t, vint64m1_t, vint64m1_t, vint64m1_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vsoxseg6ei8_v_m)))
void vsoxseg6ei8_v_i64m1_m(vbool64_t, int64_t *, vuint8mf8_t, vint64m1_t, vint64m1_t, vint64m1_t, vint64m1_t, vint64m1_t, vint64m1_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vsoxseg6ei8_v)))
void vsoxseg6ei8_v_u64m1(uint64_t *, vuint8mf8_t, vuint64m1_t, vuint64m1_t, vuint64m1_t, vuint64m1_t, vuint64m1_t, vuint64m1_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vsoxseg6ei8_v_m)))
void vsoxseg6ei8_v_u64m1_m(vbool64_t, uint64_t *, vuint8mf8_t, vuint64m1_t, vuint64m1_t, vuint64m1_t, vuint64m1_t, vuint64m1_t, vuint64m1_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vsoxseg7ei8_v)))
void vsoxseg7ei8_v_i64m1(int64_t *, vuint8mf8_t, vint64m1_t, vint64m1_t, vint64m1_t, vint64m1_t, vint64m1_t, vint64m1_t, vint64m1_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vsoxseg7ei8_v_m)))
void vsoxseg7ei8_v_i64m1_m(vbool64_t, int64_t *, vuint8mf8_t, vint64m1_t, vint64m1_t, vint64m1_t, vint64m1_t, vint64m1_t, vint64m1_t, vint64m1_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vsoxseg7ei8_v)))
void vsoxseg7ei8_v_u64m1(uint64_t *, vuint8mf8_t, vuint64m1_t, vuint64m1_t, vuint64m1_t, vuint64m1_t, vuint64m1_t, vuint64m1_t, vuint64m1_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vsoxseg7ei8_v_m)))
void vsoxseg7ei8_v_u64m1_m(vbool64_t, uint64_t *, vuint8mf8_t, vuint64m1_t, vuint64m1_t, vuint64m1_t, vuint64m1_t, vuint64m1_t, vuint64m1_t, vuint64m1_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vsoxseg8ei8_v)))
void vsoxseg8ei8_v_i64m1(int64_t *, vuint8mf8_t, vint64m1_t, vint64m1_t, vint64m1_t, vint64m1_t, vint64m1_t, vint64m1_t, vint64m1_t, vint64m1_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vsoxseg8ei8_v_m)))
void vsoxseg8ei8_v_i64m1_m(vbool64_t, int64_t *, vuint8mf8_t, vint64m1_t, vint64m1_t, vint64m1_t, vint64m1_t, vint64m1_t, vint64m1_t, vint64m1_t, vint64m1_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vsoxseg8ei8_v)))
void vsoxseg8ei8_v_u64m1(uint64_t *, vuint8mf8_t, vuint64m1_t, vuint64m1_t, vuint64m1_t, vuint64m1_t, vuint64m1_t, vuint64m1_t, vuint64m1_t, vuint64m1_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vsoxseg8ei8_v_m)))
void vsoxseg8ei8_v_u64m1_m(vbool64_t, uint64_t *, vuint8mf8_t, vuint64m1_t, vuint64m1_t, vuint64m1_t, vuint64m1_t, vuint64m1_t, vuint64m1_t, vuint64m1_t, vuint64m1_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vsoxseg2ei16_v)))
void vsoxseg2ei16_v_i64m1(int64_t *, vuint16mf4_t, vint64m1_t, vint64m1_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vsoxseg2ei16_v_m)))
void vsoxseg2ei16_v_i64m1_m(vbool64_t, int64_t *, vuint16mf4_t, vint64m1_t, vint64m1_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vsoxseg2ei16_v)))
void vsoxseg2ei16_v_i64m2(int64_t *, vuint16mf2_t, vint64m2_t, vint64m2_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vsoxseg2ei16_v_m)))
void vsoxseg2ei16_v_i64m2_m(vbool32_t, int64_t *, vuint16mf2_t, vint64m2_t, vint64m2_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vsoxseg2ei16_v)))
void vsoxseg2ei16_v_i64m4(int64_t *, vuint16m1_t, vint64m4_t, vint64m4_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vsoxseg2ei16_v_m)))
void vsoxseg2ei16_v_i64m4_m(vbool16_t, int64_t *, vuint16m1_t, vint64m4_t, vint64m4_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vsoxseg2ei16_v)))
void vsoxseg2ei16_v_u64m1(uint64_t *, vuint16mf4_t, vuint64m1_t, vuint64m1_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vsoxseg2ei16_v_m)))
void vsoxseg2ei16_v_u64m1_m(vbool64_t, uint64_t *, vuint16mf4_t, vuint64m1_t, vuint64m1_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vsoxseg2ei16_v)))
void vsoxseg2ei16_v_u64m2(uint64_t *, vuint16mf2_t, vuint64m2_t, vuint64m2_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vsoxseg2ei16_v_m)))
void vsoxseg2ei16_v_u64m2_m(vbool32_t, uint64_t *, vuint16mf2_t, vuint64m2_t, vuint64m2_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vsoxseg2ei16_v)))
void vsoxseg2ei16_v_u64m4(uint64_t *, vuint16m1_t, vuint64m4_t, vuint64m4_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vsoxseg2ei16_v_m)))
void vsoxseg2ei16_v_u64m4_m(vbool16_t, uint64_t *, vuint16m1_t, vuint64m4_t, vuint64m4_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vsoxseg3ei16_v)))
void vsoxseg3ei16_v_i64m1(int64_t *, vuint16mf4_t, vint64m1_t, vint64m1_t, vint64m1_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vsoxseg3ei16_v_m)))
void vsoxseg3ei16_v_i64m1_m(vbool64_t, int64_t *, vuint16mf4_t, vint64m1_t, vint64m1_t, vint64m1_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vsoxseg3ei16_v)))
void vsoxseg3ei16_v_i64m2(int64_t *, vuint16mf2_t, vint64m2_t, vint64m2_t, vint64m2_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vsoxseg3ei16_v_m)))
void vsoxseg3ei16_v_i64m2_m(vbool32_t, int64_t *, vuint16mf2_t, vint64m2_t, vint64m2_t, vint64m2_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vsoxseg3ei16_v)))
void vsoxseg3ei16_v_u64m1(uint64_t *, vuint16mf4_t, vuint64m1_t, vuint64m1_t, vuint64m1_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vsoxseg3ei16_v_m)))
void vsoxseg3ei16_v_u64m1_m(vbool64_t, uint64_t *, vuint16mf4_t, vuint64m1_t, vuint64m1_t, vuint64m1_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vsoxseg3ei16_v)))
void vsoxseg3ei16_v_u64m2(uint64_t *, vuint16mf2_t, vuint64m2_t, vuint64m2_t, vuint64m2_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vsoxseg3ei16_v_m)))
void vsoxseg3ei16_v_u64m2_m(vbool32_t, uint64_t *, vuint16mf2_t, vuint64m2_t, vuint64m2_t, vuint64m2_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vsoxseg4ei16_v)))
void vsoxseg4ei16_v_i64m1(int64_t *, vuint16mf4_t, vint64m1_t, vint64m1_t, vint64m1_t, vint64m1_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vsoxseg4ei16_v_m)))
void vsoxseg4ei16_v_i64m1_m(vbool64_t, int64_t *, vuint16mf4_t, vint64m1_t, vint64m1_t, vint64m1_t, vint64m1_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vsoxseg4ei16_v)))
void vsoxseg4ei16_v_i64m2(int64_t *, vuint16mf2_t, vint64m2_t, vint64m2_t, vint64m2_t, vint64m2_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vsoxseg4ei16_v_m)))
void vsoxseg4ei16_v_i64m2_m(vbool32_t, int64_t *, vuint16mf2_t, vint64m2_t, vint64m2_t, vint64m2_t, vint64m2_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vsoxseg4ei16_v)))
void vsoxseg4ei16_v_u64m1(uint64_t *, vuint16mf4_t, vuint64m1_t, vuint64m1_t, vuint64m1_t, vuint64m1_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vsoxseg4ei16_v_m)))
void vsoxseg4ei16_v_u64m1_m(vbool64_t, uint64_t *, vuint16mf4_t, vuint64m1_t, vuint64m1_t, vuint64m1_t, vuint64m1_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vsoxseg4ei16_v)))
void vsoxseg4ei16_v_u64m2(uint64_t *, vuint16mf2_t, vuint64m2_t, vuint64m2_t, vuint64m2_t, vuint64m2_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vsoxseg4ei16_v_m)))
void vsoxseg4ei16_v_u64m2_m(vbool32_t, uint64_t *, vuint16mf2_t, vuint64m2_t, vuint64m2_t, vuint64m2_t, vuint64m2_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vsoxseg5ei16_v)))
void vsoxseg5ei16_v_i64m1(int64_t *, vuint16mf4_t, vint64m1_t, vint64m1_t, vint64m1_t, vint64m1_t, vint64m1_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vsoxseg5ei16_v_m)))
void vsoxseg5ei16_v_i64m1_m(vbool64_t, int64_t *, vuint16mf4_t, vint64m1_t, vint64m1_t, vint64m1_t, vint64m1_t, vint64m1_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vsoxseg5ei16_v)))
void vsoxseg5ei16_v_u64m1(uint64_t *, vuint16mf4_t, vuint64m1_t, vuint64m1_t, vuint64m1_t, vuint64m1_t, vuint64m1_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vsoxseg5ei16_v_m)))
void vsoxseg5ei16_v_u64m1_m(vbool64_t, uint64_t *, vuint16mf4_t, vuint64m1_t, vuint64m1_t, vuint64m1_t, vuint64m1_t, vuint64m1_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vsoxseg6ei16_v)))
void vsoxseg6ei16_v_i64m1(int64_t *, vuint16mf4_t, vint64m1_t, vint64m1_t, vint64m1_t, vint64m1_t, vint64m1_t, vint64m1_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vsoxseg6ei16_v_m)))
void vsoxseg6ei16_v_i64m1_m(vbool64_t, int64_t *, vuint16mf4_t, vint64m1_t, vint64m1_t, vint64m1_t, vint64m1_t, vint64m1_t, vint64m1_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vsoxseg6ei16_v)))
void vsoxseg6ei16_v_u64m1(uint64_t *, vuint16mf4_t, vuint64m1_t, vuint64m1_t, vuint64m1_t, vuint64m1_t, vuint64m1_t, vuint64m1_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vsoxseg6ei16_v_m)))
void vsoxseg6ei16_v_u64m1_m(vbool64_t, uint64_t *, vuint16mf4_t, vuint64m1_t, vuint64m1_t, vuint64m1_t, vuint64m1_t, vuint64m1_t, vuint64m1_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vloxei8_v)))
vint64m1_t vloxei8_v_i64m1(const int64_t *, vuint8mf8_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vloxei8_v_m)))
vint64m1_t vloxei8_v_i64m1_m(vbool64_t, vint64m1_t, const int64_t *, vuint8mf8_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vloxei8_v)))
vint64m2_t vloxei8_v_i64m2(const int64_t *, vuint8mf4_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vloxei8_v_m)))
vint64m2_t vloxei8_v_i64m2_m(vbool32_t, vint64m2_t, const int64_t *, vuint8mf4_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vloxei8_v)))
vint64m4_t vloxei8_v_i64m4(const int64_t *, vuint8mf2_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vloxei8_v_m)))
vint64m4_t vloxei8_v_i64m4_m(vbool16_t, vint64m4_t, const int64_t *, vuint8mf2_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vloxei8_v)))
vint64m8_t vloxei8_v_i64m8(const int64_t *, vuint8m1_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vloxei8_v_m)))
vint64m8_t vloxei8_v_i64m8_m(vbool8_t, vint64m8_t, const int64_t *, vuint8m1_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vsoxseg7ei16_v)))
void vsoxseg7ei16_v_i64m1(int64_t *, vuint16mf4_t, vint64m1_t, vint64m1_t, vint64m1_t, vint64m1_t, vint64m1_t, vint64m1_t, vint64m1_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vsoxseg7ei16_v_m)))
void vsoxseg7ei16_v_i64m1_m(vbool64_t, int64_t *, vuint16mf4_t, vint64m1_t, vint64m1_t, vint64m1_t, vint64m1_t, vint64m1_t, vint64m1_t, vint64m1_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vsoxseg7ei16_v)))
void vsoxseg7ei16_v_u64m1(uint64_t *, vuint16mf4_t, vuint64m1_t, vuint64m1_t, vuint64m1_t, vuint64m1_t, vuint64m1_t, vuint64m1_t, vuint64m1_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vsoxseg7ei16_v_m)))
void vsoxseg7ei16_v_u64m1_m(vbool64_t, uint64_t *, vuint16mf4_t, vuint64m1_t, vuint64m1_t, vuint64m1_t, vuint64m1_t, vuint64m1_t, vuint64m1_t, vuint64m1_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vsoxseg8ei16_v)))
void vsoxseg8ei16_v_i64m1(int64_t *, vuint16mf4_t, vint64m1_t, vint64m1_t, vint64m1_t, vint64m1_t, vint64m1_t, vint64m1_t, vint64m1_t, vint64m1_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vsoxseg8ei16_v_m)))
void vsoxseg8ei16_v_i64m1_m(vbool64_t, int64_t *, vuint16mf4_t, vint64m1_t, vint64m1_t, vint64m1_t, vint64m1_t, vint64m1_t, vint64m1_t, vint64m1_t, vint64m1_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vsoxseg8ei16_v)))
void vsoxseg8ei16_v_u64m1(uint64_t *, vuint16mf4_t, vuint64m1_t, vuint64m1_t, vuint64m1_t, vuint64m1_t, vuint64m1_t, vuint64m1_t, vuint64m1_t, vuint64m1_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vsoxseg8ei16_v_m)))
void vsoxseg8ei16_v_u64m1_m(vbool64_t, uint64_t *, vuint16mf4_t, vuint64m1_t, vuint64m1_t, vuint64m1_t, vuint64m1_t, vuint64m1_t, vuint64m1_t, vuint64m1_t, vuint64m1_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vsoxseg2ei32_v)))
void vsoxseg2ei32_v_i64m1(int64_t *, vuint32mf2_t, vint64m1_t, vint64m1_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vsoxseg2ei32_v_m)))
void vsoxseg2ei32_v_i64m1_m(vbool64_t, int64_t *, vuint32mf2_t, vint64m1_t, vint64m1_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vsoxseg2ei32_v)))
void vsoxseg2ei32_v_i64m2(int64_t *, vuint32m1_t, vint64m2_t, vint64m2_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vsoxseg2ei32_v_m)))
void vsoxseg2ei32_v_i64m2_m(vbool32_t, int64_t *, vuint32m1_t, vint64m2_t, vint64m2_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vsoxseg2ei32_v)))
void vsoxseg2ei32_v_i64m4(int64_t *, vuint32m2_t, vint64m4_t, vint64m4_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vsoxseg2ei32_v_m)))
void vsoxseg2ei32_v_i64m4_m(vbool16_t, int64_t *, vuint32m2_t, vint64m4_t, vint64m4_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vsoxseg2ei32_v)))
void vsoxseg2ei32_v_u64m1(uint64_t *, vuint32mf2_t, vuint64m1_t, vuint64m1_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vsoxseg2ei32_v_m)))
void vsoxseg2ei32_v_u64m1_m(vbool64_t, uint64_t *, vuint32mf2_t, vuint64m1_t, vuint64m1_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vsoxseg2ei32_v)))
void vsoxseg2ei32_v_u64m2(uint64_t *, vuint32m1_t, vuint64m2_t, vuint64m2_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vsoxseg2ei32_v_m)))
void vsoxseg2ei32_v_u64m2_m(vbool32_t, uint64_t *, vuint32m1_t, vuint64m2_t, vuint64m2_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vsoxseg2ei32_v)))
void vsoxseg2ei32_v_u64m4(uint64_t *, vuint32m2_t, vuint64m4_t, vuint64m4_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vsoxseg2ei32_v_m)))
void vsoxseg2ei32_v_u64m4_m(vbool16_t, uint64_t *, vuint32m2_t, vuint64m4_t, vuint64m4_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vsoxseg3ei32_v)))
void vsoxseg3ei32_v_i64m1(int64_t *, vuint32mf2_t, vint64m1_t, vint64m1_t, vint64m1_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vsoxseg3ei32_v_m)))
void vsoxseg3ei32_v_i64m1_m(vbool64_t, int64_t *, vuint32mf2_t, vint64m1_t, vint64m1_t, vint64m1_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vsoxseg3ei32_v)))
void vsoxseg3ei32_v_i64m2(int64_t *, vuint32m1_t, vint64m2_t, vint64m2_t, vint64m2_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vsoxseg3ei32_v_m)))
void vsoxseg3ei32_v_i64m2_m(vbool32_t, int64_t *, vuint32m1_t, vint64m2_t, vint64m2_t, vint64m2_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vsoxseg3ei32_v)))
void vsoxseg3ei32_v_u64m1(uint64_t *, vuint32mf2_t, vuint64m1_t, vuint64m1_t, vuint64m1_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vsoxseg3ei32_v_m)))
void vsoxseg3ei32_v_u64m1_m(vbool64_t, uint64_t *, vuint32mf2_t, vuint64m1_t, vuint64m1_t, vuint64m1_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vsoxseg3ei32_v)))
void vsoxseg3ei32_v_u64m2(uint64_t *, vuint32m1_t, vuint64m2_t, vuint64m2_t, vuint64m2_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vsoxseg3ei32_v_m)))
void vsoxseg3ei32_v_u64m2_m(vbool32_t, uint64_t *, vuint32m1_t, vuint64m2_t, vuint64m2_t, vuint64m2_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vsoxseg4ei32_v)))
void vsoxseg4ei32_v_i64m1(int64_t *, vuint32mf2_t, vint64m1_t, vint64m1_t, vint64m1_t, vint64m1_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vsoxseg4ei32_v_m)))
void vsoxseg4ei32_v_i64m1_m(vbool64_t, int64_t *, vuint32mf2_t, vint64m1_t, vint64m1_t, vint64m1_t, vint64m1_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vsoxseg4ei32_v)))
void vsoxseg4ei32_v_i64m2(int64_t *, vuint32m1_t, vint64m2_t, vint64m2_t, vint64m2_t, vint64m2_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vsoxseg4ei32_v_m)))
void vsoxseg4ei32_v_i64m2_m(vbool32_t, int64_t *, vuint32m1_t, vint64m2_t, vint64m2_t, vint64m2_t, vint64m2_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vsoxseg4ei32_v)))
void vsoxseg4ei32_v_u64m1(uint64_t *, vuint32mf2_t, vuint64m1_t, vuint64m1_t, vuint64m1_t, vuint64m1_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vsoxseg4ei32_v_m)))
void vsoxseg4ei32_v_u64m1_m(vbool64_t, uint64_t *, vuint32mf2_t, vuint64m1_t, vuint64m1_t, vuint64m1_t, vuint64m1_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vsoxseg4ei32_v)))
void vsoxseg4ei32_v_u64m2(uint64_t *, vuint32m1_t, vuint64m2_t, vuint64m2_t, vuint64m2_t, vuint64m2_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vsoxseg4ei32_v_m)))
void vsoxseg4ei32_v_u64m2_m(vbool32_t, uint64_t *, vuint32m1_t, vuint64m2_t, vuint64m2_t, vuint64m2_t, vuint64m2_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vloxei8_v)))
vuint64m1_t vloxei8_v_u64m1(const uint64_t *, vuint8mf8_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vloxei8_v_m)))
vuint64m1_t vloxei8_v_u64m1_m(vbool64_t, vuint64m1_t, const uint64_t *, vuint8mf8_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vloxei8_v)))
vuint64m2_t vloxei8_v_u64m2(const uint64_t *, vuint8mf4_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vloxei8_v_m)))
vuint64m2_t vloxei8_v_u64m2_m(vbool32_t, vuint64m2_t, const uint64_t *, vuint8mf4_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vloxei8_v)))
vuint64m4_t vloxei8_v_u64m4(const uint64_t *, vuint8mf2_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vloxei8_v_m)))
vuint64m4_t vloxei8_v_u64m4_m(vbool16_t, vuint64m4_t, const uint64_t *, vuint8mf2_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vloxei8_v)))
vuint64m8_t vloxei8_v_u64m8(const uint64_t *, vuint8m1_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vloxei8_v_m)))
vuint64m8_t vloxei8_v_u64m8_m(vbool8_t, vuint64m8_t, const uint64_t *, vuint8m1_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vsoxseg5ei32_v)))
void vsoxseg5ei32_v_i64m1(int64_t *, vuint32mf2_t, vint64m1_t, vint64m1_t, vint64m1_t, vint64m1_t, vint64m1_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vsoxseg5ei32_v_m)))
void vsoxseg5ei32_v_i64m1_m(vbool64_t, int64_t *, vuint32mf2_t, vint64m1_t, vint64m1_t, vint64m1_t, vint64m1_t, vint64m1_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vsoxseg5ei32_v)))
void vsoxseg5ei32_v_u64m1(uint64_t *, vuint32mf2_t, vuint64m1_t, vuint64m1_t, vuint64m1_t, vuint64m1_t, vuint64m1_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vsoxseg5ei32_v_m)))
void vsoxseg5ei32_v_u64m1_m(vbool64_t, uint64_t *, vuint32mf2_t, vuint64m1_t, vuint64m1_t, vuint64m1_t, vuint64m1_t, vuint64m1_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vsoxseg6ei32_v)))
void vsoxseg6ei32_v_i64m1(int64_t *, vuint32mf2_t, vint64m1_t, vint64m1_t, vint64m1_t, vint64m1_t, vint64m1_t, vint64m1_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vsoxseg6ei32_v_m)))
void vsoxseg6ei32_v_i64m1_m(vbool64_t, int64_t *, vuint32mf2_t, vint64m1_t, vint64m1_t, vint64m1_t, vint64m1_t, vint64m1_t, vint64m1_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vsoxseg6ei32_v)))
void vsoxseg6ei32_v_u64m1(uint64_t *, vuint32mf2_t, vuint64m1_t, vuint64m1_t, vuint64m1_t, vuint64m1_t, vuint64m1_t, vuint64m1_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vsoxseg6ei32_v_m)))
void vsoxseg6ei32_v_u64m1_m(vbool64_t, uint64_t *, vuint32mf2_t, vuint64m1_t, vuint64m1_t, vuint64m1_t, vuint64m1_t, vuint64m1_t, vuint64m1_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vsoxseg7ei32_v)))
void vsoxseg7ei32_v_i64m1(int64_t *, vuint32mf2_t, vint64m1_t, vint64m1_t, vint64m1_t, vint64m1_t, vint64m1_t, vint64m1_t, vint64m1_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vsoxseg7ei32_v_m)))
void vsoxseg7ei32_v_i64m1_m(vbool64_t, int64_t *, vuint32mf2_t, vint64m1_t, vint64m1_t, vint64m1_t, vint64m1_t, vint64m1_t, vint64m1_t, vint64m1_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vsoxseg7ei32_v)))
void vsoxseg7ei32_v_u64m1(uint64_t *, vuint32mf2_t, vuint64m1_t, vuint64m1_t, vuint64m1_t, vuint64m1_t, vuint64m1_t, vuint64m1_t, vuint64m1_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vsoxseg7ei32_v_m)))
void vsoxseg7ei32_v_u64m1_m(vbool64_t, uint64_t *, vuint32mf2_t, vuint64m1_t, vuint64m1_t, vuint64m1_t, vuint64m1_t, vuint64m1_t, vuint64m1_t, vuint64m1_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vsoxseg8ei32_v)))
void vsoxseg8ei32_v_i64m1(int64_t *, vuint32mf2_t, vint64m1_t, vint64m1_t, vint64m1_t, vint64m1_t, vint64m1_t, vint64m1_t, vint64m1_t, vint64m1_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vsoxseg8ei32_v_m)))
void vsoxseg8ei32_v_i64m1_m(vbool64_t, int64_t *, vuint32mf2_t, vint64m1_t, vint64m1_t, vint64m1_t, vint64m1_t, vint64m1_t, vint64m1_t, vint64m1_t, vint64m1_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vsoxseg8ei32_v)))
void vsoxseg8ei32_v_u64m1(uint64_t *, vuint32mf2_t, vuint64m1_t, vuint64m1_t, vuint64m1_t, vuint64m1_t, vuint64m1_t, vuint64m1_t, vuint64m1_t, vuint64m1_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vsoxseg8ei32_v_m)))
void vsoxseg8ei32_v_u64m1_m(vbool64_t, uint64_t *, vuint32mf2_t, vuint64m1_t, vuint64m1_t, vuint64m1_t, vuint64m1_t, vuint64m1_t, vuint64m1_t, vuint64m1_t, vuint64m1_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vsoxseg2ei64_v)))
void vsoxseg2ei64_v_i64m1(int64_t *, vuint64m1_t, vint64m1_t, vint64m1_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vsoxseg2ei64_v_m)))
void vsoxseg2ei64_v_i64m1_m(vbool64_t, int64_t *, vuint64m1_t, vint64m1_t, vint64m1_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vsoxseg2ei64_v)))
void vsoxseg2ei64_v_i64m2(int64_t *, vuint64m2_t, vint64m2_t, vint64m2_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vsoxseg2ei64_v_m)))
void vsoxseg2ei64_v_i64m2_m(vbool32_t, int64_t *, vuint64m2_t, vint64m2_t, vint64m2_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vsoxseg2ei64_v)))
void vsoxseg2ei64_v_i64m4(int64_t *, vuint64m4_t, vint64m4_t, vint64m4_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vsoxseg2ei64_v_m)))
void vsoxseg2ei64_v_i64m4_m(vbool16_t, int64_t *, vuint64m4_t, vint64m4_t, vint64m4_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vsoxseg2ei64_v)))
void vsoxseg2ei64_v_u64m1(uint64_t *, vuint64m1_t, vuint64m1_t, vuint64m1_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vsoxseg2ei64_v_m)))
void vsoxseg2ei64_v_u64m1_m(vbool64_t, uint64_t *, vuint64m1_t, vuint64m1_t, vuint64m1_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vsoxseg2ei64_v)))
void vsoxseg2ei64_v_u64m2(uint64_t *, vuint64m2_t, vuint64m2_t, vuint64m2_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vsoxseg2ei64_v_m)))
void vsoxseg2ei64_v_u64m2_m(vbool32_t, uint64_t *, vuint64m2_t, vuint64m2_t, vuint64m2_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vsoxseg2ei64_v)))
void vsoxseg2ei64_v_u64m4(uint64_t *, vuint64m4_t, vuint64m4_t, vuint64m4_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vsoxseg2ei64_v_m)))
void vsoxseg2ei64_v_u64m4_m(vbool16_t, uint64_t *, vuint64m4_t, vuint64m4_t, vuint64m4_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vloxei16_v)))
vint64m1_t vloxei16_v_i64m1(const int64_t *, vuint16mf4_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vloxei16_v_m)))
vint64m1_t vloxei16_v_i64m1_m(vbool64_t, vint64m1_t, const int64_t *, vuint16mf4_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vloxei16_v)))
vint64m2_t vloxei16_v_i64m2(const int64_t *, vuint16mf2_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vloxei16_v_m)))
vint64m2_t vloxei16_v_i64m2_m(vbool32_t, vint64m2_t, const int64_t *, vuint16mf2_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vloxei16_v)))
vint64m4_t vloxei16_v_i64m4(const int64_t *, vuint16m1_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vloxei16_v_m)))
vint64m4_t vloxei16_v_i64m4_m(vbool16_t, vint64m4_t, const int64_t *, vuint16m1_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vloxei16_v)))
vint64m8_t vloxei16_v_i64m8(const int64_t *, vuint16m2_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vloxei16_v_m)))
vint64m8_t vloxei16_v_i64m8_m(vbool8_t, vint64m8_t, const int64_t *, vuint16m2_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vsoxseg3ei64_v)))
void vsoxseg3ei64_v_i64m1(int64_t *, vuint64m1_t, vint64m1_t, vint64m1_t, vint64m1_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vsoxseg3ei64_v_m)))
void vsoxseg3ei64_v_i64m1_m(vbool64_t, int64_t *, vuint64m1_t, vint64m1_t, vint64m1_t, vint64m1_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vsoxseg3ei64_v)))
void vsoxseg3ei64_v_i64m2(int64_t *, vuint64m2_t, vint64m2_t, vint64m2_t, vint64m2_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vsoxseg3ei64_v_m)))
void vsoxseg3ei64_v_i64m2_m(vbool32_t, int64_t *, vuint64m2_t, vint64m2_t, vint64m2_t, vint64m2_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vsoxseg3ei64_v)))
void vsoxseg3ei64_v_u64m1(uint64_t *, vuint64m1_t, vuint64m1_t, vuint64m1_t, vuint64m1_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vsoxseg3ei64_v_m)))
void vsoxseg3ei64_v_u64m1_m(vbool64_t, uint64_t *, vuint64m1_t, vuint64m1_t, vuint64m1_t, vuint64m1_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vsoxseg3ei64_v)))
void vsoxseg3ei64_v_u64m2(uint64_t *, vuint64m2_t, vuint64m2_t, vuint64m2_t, vuint64m2_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vsoxseg3ei64_v_m)))
void vsoxseg3ei64_v_u64m2_m(vbool32_t, uint64_t *, vuint64m2_t, vuint64m2_t, vuint64m2_t, vuint64m2_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vsoxseg4ei64_v)))
void vsoxseg4ei64_v_i64m1(int64_t *, vuint64m1_t, vint64m1_t, vint64m1_t, vint64m1_t, vint64m1_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vsoxseg4ei64_v_m)))
void vsoxseg4ei64_v_i64m1_m(vbool64_t, int64_t *, vuint64m1_t, vint64m1_t, vint64m1_t, vint64m1_t, vint64m1_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vsoxseg4ei64_v)))
void vsoxseg4ei64_v_i64m2(int64_t *, vuint64m2_t, vint64m2_t, vint64m2_t, vint64m2_t, vint64m2_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vsoxseg4ei64_v_m)))
void vsoxseg4ei64_v_i64m2_m(vbool32_t, int64_t *, vuint64m2_t, vint64m2_t, vint64m2_t, vint64m2_t, vint64m2_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vsoxseg4ei64_v)))
void vsoxseg4ei64_v_u64m1(uint64_t *, vuint64m1_t, vuint64m1_t, vuint64m1_t, vuint64m1_t, vuint64m1_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vsoxseg4ei64_v_m)))
void vsoxseg4ei64_v_u64m1_m(vbool64_t, uint64_t *, vuint64m1_t, vuint64m1_t, vuint64m1_t, vuint64m1_t, vuint64m1_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vsoxseg4ei64_v)))
void vsoxseg4ei64_v_u64m2(uint64_t *, vuint64m2_t, vuint64m2_t, vuint64m2_t, vuint64m2_t, vuint64m2_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vsoxseg4ei64_v_m)))
void vsoxseg4ei64_v_u64m2_m(vbool32_t, uint64_t *, vuint64m2_t, vuint64m2_t, vuint64m2_t, vuint64m2_t, vuint64m2_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vsoxseg5ei64_v)))
void vsoxseg5ei64_v_i64m1(int64_t *, vuint64m1_t, vint64m1_t, vint64m1_t, vint64m1_t, vint64m1_t, vint64m1_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vsoxseg5ei64_v_m)))
void vsoxseg5ei64_v_i64m1_m(vbool64_t, int64_t *, vuint64m1_t, vint64m1_t, vint64m1_t, vint64m1_t, vint64m1_t, vint64m1_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vsoxseg5ei64_v)))
void vsoxseg5ei64_v_u64m1(uint64_t *, vuint64m1_t, vuint64m1_t, vuint64m1_t, vuint64m1_t, vuint64m1_t, vuint64m1_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vsoxseg5ei64_v_m)))
void vsoxseg5ei64_v_u64m1_m(vbool64_t, uint64_t *, vuint64m1_t, vuint64m1_t, vuint64m1_t, vuint64m1_t, vuint64m1_t, vuint64m1_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vsoxseg6ei64_v)))
void vsoxseg6ei64_v_i64m1(int64_t *, vuint64m1_t, vint64m1_t, vint64m1_t, vint64m1_t, vint64m1_t, vint64m1_t, vint64m1_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vsoxseg6ei64_v_m)))
void vsoxseg6ei64_v_i64m1_m(vbool64_t, int64_t *, vuint64m1_t, vint64m1_t, vint64m1_t, vint64m1_t, vint64m1_t, vint64m1_t, vint64m1_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vsoxseg6ei64_v)))
void vsoxseg6ei64_v_u64m1(uint64_t *, vuint64m1_t, vuint64m1_t, vuint64m1_t, vuint64m1_t, vuint64m1_t, vuint64m1_t, vuint64m1_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vsoxseg6ei64_v_m)))
void vsoxseg6ei64_v_u64m1_m(vbool64_t, uint64_t *, vuint64m1_t, vuint64m1_t, vuint64m1_t, vuint64m1_t, vuint64m1_t, vuint64m1_t, vuint64m1_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vsoxseg7ei64_v)))
void vsoxseg7ei64_v_i64m1(int64_t *, vuint64m1_t, vint64m1_t, vint64m1_t, vint64m1_t, vint64m1_t, vint64m1_t, vint64m1_t, vint64m1_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vsoxseg7ei64_v_m)))
void vsoxseg7ei64_v_i64m1_m(vbool64_t, int64_t *, vuint64m1_t, vint64m1_t, vint64m1_t, vint64m1_t, vint64m1_t, vint64m1_t, vint64m1_t, vint64m1_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vsoxseg7ei64_v)))
void vsoxseg7ei64_v_u64m1(uint64_t *, vuint64m1_t, vuint64m1_t, vuint64m1_t, vuint64m1_t, vuint64m1_t, vuint64m1_t, vuint64m1_t, vuint64m1_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vsoxseg7ei64_v_m)))
void vsoxseg7ei64_v_u64m1_m(vbool64_t, uint64_t *, vuint64m1_t, vuint64m1_t, vuint64m1_t, vuint64m1_t, vuint64m1_t, vuint64m1_t, vuint64m1_t, vuint64m1_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vloxei16_v)))
vuint64m1_t vloxei16_v_u64m1(const uint64_t *, vuint16mf4_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vloxei16_v_m)))
vuint64m1_t vloxei16_v_u64m1_m(vbool64_t, vuint64m1_t, const uint64_t *, vuint16mf4_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vloxei16_v)))
vuint64m2_t vloxei16_v_u64m2(const uint64_t *, vuint16mf2_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vloxei16_v_m)))
vuint64m2_t vloxei16_v_u64m2_m(vbool32_t, vuint64m2_t, const uint64_t *, vuint16mf2_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vloxei16_v)))
vuint64m4_t vloxei16_v_u64m4(const uint64_t *, vuint16m1_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vloxei16_v_m)))
vuint64m4_t vloxei16_v_u64m4_m(vbool16_t, vuint64m4_t, const uint64_t *, vuint16m1_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vloxei16_v)))
vuint64m8_t vloxei16_v_u64m8(const uint64_t *, vuint16m2_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vloxei16_v_m)))
vuint64m8_t vloxei16_v_u64m8_m(vbool8_t, vuint64m8_t, const uint64_t *, vuint16m2_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vsoxseg8ei64_v)))
void vsoxseg8ei64_v_i64m1(int64_t *, vuint64m1_t, vint64m1_t, vint64m1_t, vint64m1_t, vint64m1_t, vint64m1_t, vint64m1_t, vint64m1_t, vint64m1_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vsoxseg8ei64_v_m)))
void vsoxseg8ei64_v_i64m1_m(vbool64_t, int64_t *, vuint64m1_t, vint64m1_t, vint64m1_t, vint64m1_t, vint64m1_t, vint64m1_t, vint64m1_t, vint64m1_t, vint64m1_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vsoxseg8ei64_v)))
void vsoxseg8ei64_v_u64m1(uint64_t *, vuint64m1_t, vuint64m1_t, vuint64m1_t, vuint64m1_t, vuint64m1_t, vuint64m1_t, vuint64m1_t, vuint64m1_t, vuint64m1_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vsoxseg8ei64_v_m)))
void vsoxseg8ei64_v_u64m1_m(vbool64_t, uint64_t *, vuint64m1_t, vuint64m1_t, vuint64m1_t, vuint64m1_t, vuint64m1_t, vuint64m1_t, vuint64m1_t, vuint64m1_t, vuint64m1_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vloxei32_v)))
vint64m1_t vloxei32_v_i64m1(const int64_t *, vuint32mf2_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vloxei32_v_m)))
vint64m1_t vloxei32_v_i64m1_m(vbool64_t, vint64m1_t, const int64_t *, vuint32mf2_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vloxei32_v)))
vint64m2_t vloxei32_v_i64m2(const int64_t *, vuint32m1_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vloxei32_v_m)))
vint64m2_t vloxei32_v_i64m2_m(vbool32_t, vint64m2_t, const int64_t *, vuint32m1_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vloxei32_v)))
vint64m4_t vloxei32_v_i64m4(const int64_t *, vuint32m2_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vloxei32_v_m)))
vint64m4_t vloxei32_v_i64m4_m(vbool16_t, vint64m4_t, const int64_t *, vuint32m2_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vloxei32_v)))
vint64m8_t vloxei32_v_i64m8(const int64_t *, vuint32m4_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vloxei32_v_m)))
vint64m8_t vloxei32_v_i64m8_m(vbool8_t, vint64m8_t, const int64_t *, vuint32m4_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vloxei32_v)))
vuint64m1_t vloxei32_v_u64m1(const uint64_t *, vuint32mf2_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vloxei32_v_m)))
vuint64m1_t vloxei32_v_u64m1_m(vbool64_t, vuint64m1_t, const uint64_t *, vuint32mf2_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vloxei32_v)))
vuint64m2_t vloxei32_v_u64m2(const uint64_t *, vuint32m1_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vloxei32_v_m)))
vuint64m2_t vloxei32_v_u64m2_m(vbool32_t, vuint64m2_t, const uint64_t *, vuint32m1_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vloxei32_v)))
vuint64m4_t vloxei32_v_u64m4(const uint64_t *, vuint32m2_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vloxei32_v_m)))
vuint64m4_t vloxei32_v_u64m4_m(vbool16_t, vuint64m4_t, const uint64_t *, vuint32m2_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vloxei32_v)))
vuint64m8_t vloxei32_v_u64m8(const uint64_t *, vuint32m4_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vloxei32_v_m)))
vuint64m8_t vloxei32_v_u64m8_m(vbool8_t, vuint64m8_t, const uint64_t *, vuint32m4_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vadd_vx)))
vint64m1_t vadd_vx_i64m1(vint64m1_t, int64_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vadd_vx_m)))
vint64m1_t vadd_vx_i64m1_m(vbool64_t, vint64m1_t, vint64m1_t, int64_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vadd_vx)))
vint64m2_t vadd_vx_i64m2(vint64m2_t, int64_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vadd_vx_m)))
vint64m2_t vadd_vx_i64m2_m(vbool32_t, vint64m2_t, vint64m2_t, int64_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vadd_vx)))
vint64m4_t vadd_vx_i64m4(vint64m4_t, int64_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vadd_vx_m)))
vint64m4_t vadd_vx_i64m4_m(vbool16_t, vint64m4_t, vint64m4_t, int64_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vadd_vx)))
vint64m8_t vadd_vx_i64m8(vint64m8_t, int64_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vadd_vx_m)))
vint64m8_t vadd_vx_i64m8_m(vbool8_t, vint64m8_t, vint64m8_t, int64_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vadd_vv)))
vuint64m1_t vadd_vv_u64m1(vuint64m1_t, vuint64m1_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vadd_vv_m)))
vuint64m1_t vadd_vv_u64m1_m(vbool64_t, vuint64m1_t, vuint64m1_t, vuint64m1_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vadd_vv)))
vuint64m2_t vadd_vv_u64m2(vuint64m2_t, vuint64m2_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vadd_vv_m)))
vuint64m2_t vadd_vv_u64m2_m(vbool32_t, vuint64m2_t, vuint64m2_t, vuint64m2_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vadd_vv)))
vuint64m4_t vadd_vv_u64m4(vuint64m4_t, vuint64m4_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vadd_vv_m)))
vuint64m4_t vadd_vv_u64m4_m(vbool16_t, vuint64m4_t, vuint64m4_t, vuint64m4_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vadd_vv)))
vuint64m8_t vadd_vv_u64m8(vuint64m8_t, vuint64m8_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vadd_vv_m)))
vuint64m8_t vadd_vv_u64m8_m(vbool8_t, vuint64m8_t, vuint64m8_t, vuint64m8_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vadd_vx)))
vuint64m1_t vadd_vx_u64m1(vuint64m1_t, uint64_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vadd_vx_m)))
vuint64m1_t vadd_vx_u64m1_m(vbool64_t, vuint64m1_t, vuint64m1_t, uint64_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vadd_vx)))
vuint64m2_t vadd_vx_u64m2(vuint64m2_t, uint64_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vadd_vx_m)))
vuint64m2_t vadd_vx_u64m2_m(vbool32_t, vuint64m2_t, vuint64m2_t, uint64_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vadd_vx)))
vuint64m4_t vadd_vx_u64m4(vuint64m4_t, uint64_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vadd_vx_m)))
vuint64m4_t vadd_vx_u64m4_m(vbool16_t, vuint64m4_t, vuint64m4_t, uint64_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vadd_vx)))
vuint64m8_t vadd_vx_u64m8(vuint64m8_t, uint64_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vadd_vx_m)))
vuint64m8_t vadd_vx_u64m8_m(vbool8_t, vuint64m8_t, vuint64m8_t, uint64_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vsub_vv)))
vint64m1_t vsub_vv_i64m1(vint64m1_t, vint64m1_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vsub_vv_m)))
vint64m1_t vsub_vv_i64m1_m(vbool64_t, vint64m1_t, vint64m1_t, vint64m1_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vsub_vv)))
vint64m2_t vsub_vv_i64m2(vint64m2_t, vint64m2_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vsub_vv_m)))
vint64m2_t vsub_vv_i64m2_m(vbool32_t, vint64m2_t, vint64m2_t, vint64m2_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vsub_vv)))
vint64m4_t vsub_vv_i64m4(vint64m4_t, vint64m4_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vsub_vv_m)))
vint64m4_t vsub_vv_i64m4_m(vbool16_t, vint64m4_t, vint64m4_t, vint64m4_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vsub_vv)))
vint64m8_t vsub_vv_i64m8(vint64m8_t, vint64m8_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vsub_vv_m)))
vint64m8_t vsub_vv_i64m8_m(vbool8_t, vint64m8_t, vint64m8_t, vint64m8_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vsub_vx)))
vint64m1_t vsub_vx_i64m1(vint64m1_t, int64_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vsub_vx_m)))
vint64m1_t vsub_vx_i64m1_m(vbool64_t, vint64m1_t, vint64m1_t, int64_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vsub_vx)))
vint64m2_t vsub_vx_i64m2(vint64m2_t, int64_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vsub_vx_m)))
vint64m2_t vsub_vx_i64m2_m(vbool32_t, vint64m2_t, vint64m2_t, int64_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vsub_vx)))
vint64m4_t vsub_vx_i64m4(vint64m4_t, int64_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vsub_vx_m)))
vint64m4_t vsub_vx_i64m4_m(vbool16_t, vint64m4_t, vint64m4_t, int64_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vsub_vx)))
vint64m8_t vsub_vx_i64m8(vint64m8_t, int64_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vsub_vx_m)))
vint64m8_t vsub_vx_i64m8_m(vbool8_t, vint64m8_t, vint64m8_t, int64_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vsub_vv)))
vuint64m1_t vsub_vv_u64m1(vuint64m1_t, vuint64m1_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vsub_vv_m)))
vuint64m1_t vsub_vv_u64m1_m(vbool64_t, vuint64m1_t, vuint64m1_t, vuint64m1_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vsub_vv)))
vuint64m2_t vsub_vv_u64m2(vuint64m2_t, vuint64m2_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vsub_vv_m)))
vuint64m2_t vsub_vv_u64m2_m(vbool32_t, vuint64m2_t, vuint64m2_t, vuint64m2_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vsub_vv)))
vuint64m4_t vsub_vv_u64m4(vuint64m4_t, vuint64m4_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vsub_vv_m)))
vuint64m4_t vsub_vv_u64m4_m(vbool16_t, vuint64m4_t, vuint64m4_t, vuint64m4_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vsub_vv)))
vuint64m8_t vsub_vv_u64m8(vuint64m8_t, vuint64m8_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vsub_vv_m)))
vuint64m8_t vsub_vv_u64m8_m(vbool8_t, vuint64m8_t, vuint64m8_t, vuint64m8_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vsub_vx)))
vuint64m1_t vsub_vx_u64m1(vuint64m1_t, uint64_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vsub_vx_m)))
vuint64m1_t vsub_vx_u64m1_m(vbool64_t, vuint64m1_t, vuint64m1_t, uint64_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vsub_vx)))
vuint64m2_t vsub_vx_u64m2(vuint64m2_t, uint64_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vsub_vx_m)))
vuint64m2_t vsub_vx_u64m2_m(vbool32_t, vuint64m2_t, vuint64m2_t, uint64_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vsub_vx)))
vuint64m4_t vsub_vx_u64m4(vuint64m4_t, uint64_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vsub_vx_m)))
vuint64m4_t vsub_vx_u64m4_m(vbool16_t, vuint64m4_t, vuint64m4_t, uint64_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vsub_vx)))
vuint64m8_t vsub_vx_u64m8(vuint64m8_t, uint64_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vsub_vx_m)))
vuint64m8_t vsub_vx_u64m8_m(vbool8_t, vuint64m8_t, vuint64m8_t, uint64_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vrsub_vx)))
vint64m1_t vrsub_vx_i64m1(vint64m1_t, int64_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vrsub_vx_m)))
vint64m1_t vrsub_vx_i64m1_m(vbool64_t, vint64m1_t, vint64m1_t, int64_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vrsub_vx)))
vint64m2_t vrsub_vx_i64m2(vint64m2_t, int64_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vrsub_vx_m)))
vint64m2_t vrsub_vx_i64m2_m(vbool32_t, vint64m2_t, vint64m2_t, int64_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vrsub_vx)))
vint64m4_t vrsub_vx_i64m4(vint64m4_t, int64_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vrsub_vx_m)))
vint64m4_t vrsub_vx_i64m4_m(vbool16_t, vint64m4_t, vint64m4_t, int64_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vrsub_vx)))
vint64m8_t vrsub_vx_i64m8(vint64m8_t, int64_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vrsub_vx_m)))
vint64m8_t vrsub_vx_i64m8_m(vbool8_t, vint64m8_t, vint64m8_t, int64_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vrsub_vx)))
vuint64m1_t vrsub_vx_u64m1(vuint64m1_t, uint64_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vrsub_vx_m)))
vuint64m1_t vrsub_vx_u64m1_m(vbool64_t, vuint64m1_t, vuint64m1_t, uint64_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vrsub_vx)))
vuint64m2_t vrsub_vx_u64m2(vuint64m2_t, uint64_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vrsub_vx_m)))
vuint64m2_t vrsub_vx_u64m2_m(vbool32_t, vuint64m2_t, vuint64m2_t, uint64_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vrsub_vx)))
vuint64m4_t vrsub_vx_u64m4(vuint64m4_t, uint64_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vrsub_vx_m)))
vuint64m4_t vrsub_vx_u64m4_m(vbool16_t, vuint64m4_t, vuint64m4_t, uint64_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vrsub_vx)))
vuint64m8_t vrsub_vx_u64m8(vuint64m8_t, uint64_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vrsub_vx_m)))
vuint64m8_t vrsub_vx_u64m8_m(vbool8_t, vuint64m8_t, vuint64m8_t, uint64_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vwaddu_vx)))
vuint64m1_t vwaddu_vx_u64m1(vuint32mf2_t, uint32_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vwaddu_vx_m)))
vuint64m1_t vwaddu_vx_u64m1_m(vbool64_t, vuint64m1_t, vuint32mf2_t, uint32_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vwaddu_vx)))
vuint64m2_t vwaddu_vx_u64m2(vuint32m1_t, uint32_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vwaddu_vx_m)))
vuint64m2_t vwaddu_vx_u64m2_m(vbool32_t, vuint64m2_t, vuint32m1_t, uint32_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vwaddu_vx)))
vuint64m4_t vwaddu_vx_u64m4(vuint32m2_t, uint32_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vwaddu_vx_m)))
vuint64m4_t vwaddu_vx_u64m4_m(vbool16_t, vuint64m4_t, vuint32m2_t, uint32_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vwaddu_vx)))
vuint64m8_t vwaddu_vx_u64m8(vuint32m4_t, uint32_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vwaddu_vx_m)))
vuint64m8_t vwaddu_vx_u64m8_m(vbool8_t, vuint64m8_t, vuint32m4_t, uint32_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vwsubu_vv)))
vuint64m1_t vwsubu_vv_u64m1(vuint32mf2_t, vuint32mf2_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vwsubu_vv_m)))
vuint64m1_t vwsubu_vv_u64m1_m(vbool64_t, vuint64m1_t, vuint32mf2_t, vuint32mf2_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vwsubu_vv)))
vuint64m2_t vwsubu_vv_u64m2(vuint32m1_t, vuint32m1_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vwsubu_vv_m)))
vuint64m2_t vwsubu_vv_u64m2_m(vbool32_t, vuint64m2_t, vuint32m1_t, vuint32m1_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vwsubu_vv)))
vuint64m4_t vwsubu_vv_u64m4(vuint32m2_t, vuint32m2_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vwsubu_vv_m)))
vuint64m4_t vwsubu_vv_u64m4_m(vbool16_t, vuint64m4_t, vuint32m2_t, vuint32m2_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vwsubu_vv)))
vuint64m8_t vwsubu_vv_u64m8(vuint32m4_t, vuint32m4_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vwsubu_vv_m)))
vuint64m8_t vwsubu_vv_u64m8_m(vbool8_t, vuint64m8_t, vuint32m4_t, vuint32m4_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vwsubu_vx)))
vuint64m1_t vwsubu_vx_u64m1(vuint32mf2_t, uint32_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vwsubu_vx_m)))
vuint64m1_t vwsubu_vx_u64m1_m(vbool64_t, vuint64m1_t, vuint32mf2_t, uint32_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vwsubu_vx)))
vuint64m2_t vwsubu_vx_u64m2(vuint32m1_t, uint32_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vwsubu_vx_m)))
vuint64m2_t vwsubu_vx_u64m2_m(vbool32_t, vuint64m2_t, vuint32m1_t, uint32_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vwsubu_vx)))
vuint64m4_t vwsubu_vx_u64m4(vuint32m2_t, uint32_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vwsubu_vx_m)))
vuint64m4_t vwsubu_vx_u64m4_m(vbool16_t, vuint64m4_t, vuint32m2_t, uint32_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vwsubu_vx)))
vuint64m8_t vwsubu_vx_u64m8(vuint32m4_t, uint32_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vwsubu_vx_m)))
vuint64m8_t vwsubu_vx_u64m8_m(vbool8_t, vuint64m8_t, vuint32m4_t, uint32_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vwadd_vv)))
vint64m1_t vwadd_vv_i64m1(vint32mf2_t, vint32mf2_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vwadd_vv_m)))
vint64m1_t vwadd_vv_i64m1_m(vbool64_t, vint64m1_t, vint32mf2_t, vint32mf2_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vwadd_vv)))
vint64m2_t vwadd_vv_i64m2(vint32m1_t, vint32m1_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vwadd_vv_m)))
vint64m2_t vwadd_vv_i64m2_m(vbool32_t, vint64m2_t, vint32m1_t, vint32m1_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vwadd_vv)))
vint64m4_t vwadd_vv_i64m4(vint32m2_t, vint32m2_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vwadd_vv_m)))
vint64m4_t vwadd_vv_i64m4_m(vbool16_t, vint64m4_t, vint32m2_t, vint32m2_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vwadd_vv)))
vint64m8_t vwadd_vv_i64m8(vint32m4_t, vint32m4_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vwadd_vv_m)))
vint64m8_t vwadd_vv_i64m8_m(vbool8_t, vint64m8_t, vint32m4_t, vint32m4_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vwadd_vx)))
vint64m1_t vwadd_vx_i64m1(vint32mf2_t, int32_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vwadd_vx_m)))
vint64m1_t vwadd_vx_i64m1_m(vbool64_t, vint64m1_t, vint32mf2_t, int32_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vwadd_vx)))
vint64m2_t vwadd_vx_i64m2(vint32m1_t, int32_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vwadd_vx_m)))
vint64m2_t vwadd_vx_i64m2_m(vbool32_t, vint64m2_t, vint32m1_t, int32_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vwadd_vx)))
vint64m4_t vwadd_vx_i64m4(vint32m2_t, int32_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vwadd_vx_m)))
vint64m4_t vwadd_vx_i64m4_m(vbool16_t, vint64m4_t, vint32m2_t, int32_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vwadd_vx)))
vint64m8_t vwadd_vx_i64m8(vint32m4_t, int32_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vwadd_vx_m)))
vint64m8_t vwadd_vx_i64m8_m(vbool8_t, vint64m8_t, vint32m4_t, int32_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vwsub_vv)))
vint64m1_t vwsub_vv_i64m1(vint32mf2_t, vint32mf2_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vwsub_vv_m)))
vint64m1_t vwsub_vv_i64m1_m(vbool64_t, vint64m1_t, vint32mf2_t, vint32mf2_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vwsub_vv)))
vint64m2_t vwsub_vv_i64m2(vint32m1_t, vint32m1_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vwsub_vv_m)))
vint64m2_t vwsub_vv_i64m2_m(vbool32_t, vint64m2_t, vint32m1_t, vint32m1_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vwsub_vv)))
vint64m4_t vwsub_vv_i64m4(vint32m2_t, vint32m2_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vwsub_vv_m)))
vint64m4_t vwsub_vv_i64m4_m(vbool16_t, vint64m4_t, vint32m2_t, vint32m2_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vwsub_vv)))
vint64m8_t vwsub_vv_i64m8(vint32m4_t, vint32m4_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vwsub_vv_m)))
vint64m8_t vwsub_vv_i64m8_m(vbool8_t, vint64m8_t, vint32m4_t, vint32m4_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vwsub_vx)))
vint64m1_t vwsub_vx_i64m1(vint32mf2_t, int32_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vwsub_vx_m)))
vint64m1_t vwsub_vx_i64m1_m(vbool64_t, vint64m1_t, vint32mf2_t, int32_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vwsub_vx)))
vint64m2_t vwsub_vx_i64m2(vint32m1_t, int32_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vwsub_vx_m)))
vint64m2_t vwsub_vx_i64m2_m(vbool32_t, vint64m2_t, vint32m1_t, int32_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vwsub_vx)))
vint64m4_t vwsub_vx_i64m4(vint32m2_t, int32_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vwsub_vx_m)))
vint64m4_t vwsub_vx_i64m4_m(vbool16_t, vint64m4_t, vint32m2_t, int32_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vwsub_vx)))
vint64m8_t vwsub_vx_i64m8(vint32m4_t, int32_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vwsub_vx_m)))
vint64m8_t vwsub_vx_i64m8_m(vbool8_t, vint64m8_t, vint32m4_t, int32_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vwaddu_wx)))
vuint64m1_t vwaddu_wx_u64m1(vuint64m1_t, uint32_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vwaddu_wx_m)))
vuint64m1_t vwaddu_wx_u64m1_m(vbool64_t, vuint64m1_t, vuint64m1_t, uint32_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vwaddu_wx)))
vuint64m2_t vwaddu_wx_u64m2(vuint64m2_t, uint32_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vwaddu_wx_m)))
vuint64m2_t vwaddu_wx_u64m2_m(vbool32_t, vuint64m2_t, vuint64m2_t, uint32_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vwaddu_wx)))
vuint64m4_t vwaddu_wx_u64m4(vuint64m4_t, uint32_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vwaddu_wx_m)))
vuint64m4_t vwaddu_wx_u64m4_m(vbool16_t, vuint64m4_t, vuint64m4_t, uint32_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vwaddu_wx)))
vuint64m8_t vwaddu_wx_u64m8(vuint64m8_t, uint32_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vwaddu_wx_m)))
vuint64m8_t vwaddu_wx_u64m8_m(vbool8_t, vuint64m8_t, vuint64m8_t, uint32_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vwsubu_wv)))
vuint64m1_t vwsubu_wv_u64m1(vuint64m1_t, vuint32mf2_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vwsubu_wv_m)))
vuint64m1_t vwsubu_wv_u64m1_m(vbool64_t, vuint64m1_t, vuint64m1_t, vuint32mf2_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vwsubu_wv)))
vuint64m2_t vwsubu_wv_u64m2(vuint64m2_t, vuint32m1_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vwsubu_wv_m)))
vuint64m2_t vwsubu_wv_u64m2_m(vbool32_t, vuint64m2_t, vuint64m2_t, vuint32m1_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vwsubu_wv)))
vuint64m4_t vwsubu_wv_u64m4(vuint64m4_t, vuint32m2_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vwsubu_wv_m)))
vuint64m4_t vwsubu_wv_u64m4_m(vbool16_t, vuint64m4_t, vuint64m4_t, vuint32m2_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vwsubu_wv)))
vuint64m8_t vwsubu_wv_u64m8(vuint64m8_t, vuint32m4_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vwsubu_wv_m)))
vuint64m8_t vwsubu_wv_u64m8_m(vbool8_t, vuint64m8_t, vuint64m8_t, vuint32m4_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vwsubu_wx)))
vuint64m1_t vwsubu_wx_u64m1(vuint64m1_t, uint32_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vwsubu_wx_m)))
vuint64m1_t vwsubu_wx_u64m1_m(vbool64_t, vuint64m1_t, vuint64m1_t, uint32_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vwsubu_wx)))
vuint64m2_t vwsubu_wx_u64m2(vuint64m2_t, uint32_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vwsubu_wx_m)))
vuint64m2_t vwsubu_wx_u64m2_m(vbool32_t, vuint64m2_t, vuint64m2_t, uint32_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vwsubu_wx)))
vuint64m4_t vwsubu_wx_u64m4(vuint64m4_t, uint32_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vwsubu_wx_m)))
vuint64m4_t vwsubu_wx_u64m4_m(vbool16_t, vuint64m4_t, vuint64m4_t, uint32_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vwsubu_wx)))
vuint64m8_t vwsubu_wx_u64m8(vuint64m8_t, uint32_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vwsubu_wx_m)))
vuint64m8_t vwsubu_wx_u64m8_m(vbool8_t, vuint64m8_t, vuint64m8_t, uint32_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vwadd_wv)))
vint64m1_t vwadd_wv_i64m1(vint64m1_t, vint32mf2_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vwadd_wv_m)))
vint64m1_t vwadd_wv_i64m1_m(vbool64_t, vint64m1_t, vint64m1_t, vint32mf2_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vwadd_wv)))
vint64m2_t vwadd_wv_i64m2(vint64m2_t, vint32m1_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vwadd_wv_m)))
vint64m2_t vwadd_wv_i64m2_m(vbool32_t, vint64m2_t, vint64m2_t, vint32m1_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vwadd_wv)))
vint64m4_t vwadd_wv_i64m4(vint64m4_t, vint32m2_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vwadd_wv_m)))
vint64m4_t vwadd_wv_i64m4_m(vbool16_t, vint64m4_t, vint64m4_t, vint32m2_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vwadd_wv)))
vint64m8_t vwadd_wv_i64m8(vint64m8_t, vint32m4_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vwadd_wv_m)))
vint64m8_t vwadd_wv_i64m8_m(vbool8_t, vint64m8_t, vint64m8_t, vint32m4_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vwadd_wx)))
vint64m1_t vwadd_wx_i64m1(vint64m1_t, int32_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vwadd_wx_m)))
vint64m1_t vwadd_wx_i64m1_m(vbool64_t, vint64m1_t, vint64m1_t, int32_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vwadd_wx)))
vint64m2_t vwadd_wx_i64m2(vint64m2_t, int32_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vwadd_wx_m)))
vint64m2_t vwadd_wx_i64m2_m(vbool32_t, vint64m2_t, vint64m2_t, int32_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vwadd_wx)))
vint64m4_t vwadd_wx_i64m4(vint64m4_t, int32_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vwadd_wx_m)))
vint64m4_t vwadd_wx_i64m4_m(vbool16_t, vint64m4_t, vint64m4_t, int32_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vwadd_wx)))
vint64m8_t vwadd_wx_i64m8(vint64m8_t, int32_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vwadd_wx_m)))
vint64m8_t vwadd_wx_i64m8_m(vbool8_t, vint64m8_t, vint64m8_t, int32_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vwsub_wv)))
vint64m1_t vwsub_wv_i64m1(vint64m1_t, vint32mf2_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vwsub_wv_m)))
vint64m1_t vwsub_wv_i64m1_m(vbool64_t, vint64m1_t, vint64m1_t, vint32mf2_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vwsub_wv)))
vint64m2_t vwsub_wv_i64m2(vint64m2_t, vint32m1_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vwsub_wv_m)))
vint64m2_t vwsub_wv_i64m2_m(vbool32_t, vint64m2_t, vint64m2_t, vint32m1_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vwsub_wv)))
vint64m4_t vwsub_wv_i64m4(vint64m4_t, vint32m2_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vwsub_wv_m)))
vint64m4_t vwsub_wv_i64m4_m(vbool16_t, vint64m4_t, vint64m4_t, vint32m2_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vwsub_wv)))
vint64m8_t vwsub_wv_i64m8(vint64m8_t, vint32m4_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vwsub_wv_m)))
vint64m8_t vwsub_wv_i64m8_m(vbool8_t, vint64m8_t, vint64m8_t, vint32m4_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vwsub_wx)))
vint64m1_t vwsub_wx_i64m1(vint64m1_t, int32_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vwsub_wx_m)))
vint64m1_t vwsub_wx_i64m1_m(vbool64_t, vint64m1_t, vint64m1_t, int32_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vwsub_wx)))
vint64m2_t vwsub_wx_i64m2(vint64m2_t, int32_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vwsub_wx_m)))
vint64m2_t vwsub_wx_i64m2_m(vbool32_t, vint64m2_t, vint64m2_t, int32_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vwsub_wx)))
vint64m4_t vwsub_wx_i64m4(vint64m4_t, int32_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vwsub_wx_m)))
vint64m4_t vwsub_wx_i64m4_m(vbool16_t, vint64m4_t, vint64m4_t, int32_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vwsub_wx)))
vint64m8_t vwsub_wx_i64m8(vint64m8_t, int32_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vwsub_wx_m)))
vint64m8_t vwsub_wx_i64m8_m(vbool8_t, vint64m8_t, vint64m8_t, int32_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vwcvt_x_x_v)))
vint64m2_t vwcvt_x_x_v_i64m2(vint32m1_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vwcvt_x_x_v_m)))
vint64m2_t vwcvt_x_x_v_i64m2_m(vbool32_t, vint64m2_t, vint32m1_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vwcvt_x_x_v)))
vint64m4_t vwcvt_x_x_v_i64m4(vint32m2_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vwcvt_x_x_v_m)))
vint64m4_t vwcvt_x_x_v_i64m4_m(vbool16_t, vint64m4_t, vint32m2_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vwcvt_x_x_v)))
vint64m8_t vwcvt_x_x_v_i64m8(vint32m4_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vwcvt_x_x_v_m)))
vint64m8_t vwcvt_x_x_v_i64m8_m(vbool8_t, vint64m8_t, vint32m4_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vwcvt_x_x_v)))
vint64m1_t vwcvt_x_x_v_i64m1(vint32mf2_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vwcvt_x_x_v_m)))
vint64m1_t vwcvt_x_x_v_i64m1_m(vbool64_t, vint64m1_t, vint32mf2_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vadc_vvm)))
vint64m1_t vadc_vvm_i64m1(vint64m1_t, vint64m1_t, vbool64_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vadc_vvm)))
vint64m2_t vadc_vvm_i64m2(vint64m2_t, vint64m2_t, vbool32_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vadc_vvm)))
vint64m4_t vadc_vvm_i64m4(vint64m4_t, vint64m4_t, vbool16_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vadc_vvm)))
vint64m8_t vadc_vvm_i64m8(vint64m8_t, vint64m8_t, vbool8_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vadc_vxm)))
vint64m1_t vadc_vxm_i64m1(vint64m1_t, int64_t, vbool64_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vadc_vxm)))
vint64m2_t vadc_vxm_i64m2(vint64m2_t, int64_t, vbool32_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vadc_vxm)))
vint64m4_t vadc_vxm_i64m4(vint64m4_t, int64_t, vbool16_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vadc_vxm)))
vint64m8_t vadc_vxm_i64m8(vint64m8_t, int64_t, vbool8_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vadc_vvm)))
vuint64m1_t vadc_vvm_u64m1(vuint64m1_t, vuint64m1_t, vbool64_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vadc_vvm)))
vuint64m2_t vadc_vvm_u64m2(vuint64m2_t, vuint64m2_t, vbool32_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vadc_vvm)))
vuint64m4_t vadc_vvm_u64m4(vuint64m4_t, vuint64m4_t, vbool16_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vadc_vvm)))
vuint64m8_t vadc_vvm_u64m8(vuint64m8_t, vuint64m8_t, vbool8_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vadc_vxm)))
vuint64m1_t vadc_vxm_u64m1(vuint64m1_t, uint64_t, vbool64_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vadc_vxm)))
vuint64m2_t vadc_vxm_u64m2(vuint64m2_t, uint64_t, vbool32_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vadc_vxm)))
vuint64m4_t vadc_vxm_u64m4(vuint64m4_t, uint64_t, vbool16_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vadc_vxm)))
vuint64m8_t vadc_vxm_u64m8(vuint64m8_t, uint64_t, vbool8_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vmadc_vvm)))
vbool64_t vmadc_vvm_i64m1_b64(vint64m1_t, vint64m1_t, vbool64_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vmadc_vvm)))
vbool32_t vmadc_vvm_i64m2_b32(vint64m2_t, vint64m2_t, vbool32_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vmadc_vvm)))
vbool16_t vmadc_vvm_i64m4_b16(vint64m4_t, vint64m4_t, vbool16_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vmadc_vvm)))
vbool8_t vmadc_vvm_i64m8_b8(vint64m8_t, vint64m8_t, vbool8_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vmadc_vxm)))
vbool64_t vmadc_vxm_i64m1_b64(vint64m1_t, int64_t, vbool64_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vmadc_vxm)))
vbool32_t vmadc_vxm_i64m2_b32(vint64m2_t, int64_t, vbool32_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vmadc_vxm)))
vbool16_t vmadc_vxm_i64m4_b16(vint64m4_t, int64_t, vbool16_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vmadc_vxm)))
vbool8_t vmadc_vxm_i64m8_b8(vint64m8_t, int64_t, vbool8_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vmadc_vvm)))
vbool64_t vmadc_vvm_u64m1_b64(vuint64m1_t, vuint64m1_t, vbool64_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vmadc_vvm)))
vbool32_t vmadc_vvm_u64m2_b32(vuint64m2_t, vuint64m2_t, vbool32_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vmadc_vvm)))
vbool16_t vmadc_vvm_u64m4_b16(vuint64m4_t, vuint64m4_t, vbool16_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vmadc_vvm)))
vbool8_t vmadc_vvm_u64m8_b8(vuint64m8_t, vuint64m8_t, vbool8_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vmadc_vxm)))
vbool64_t vmadc_vxm_u64m1_b64(vuint64m1_t, uint64_t, vbool64_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vmadc_vxm)))
vbool32_t vmadc_vxm_u64m2_b32(vuint64m2_t, uint64_t, vbool32_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vmadc_vxm)))
vbool16_t vmadc_vxm_u64m4_b16(vuint64m4_t, uint64_t, vbool16_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vmadc_vxm)))
vbool8_t vmadc_vxm_u64m8_b8(vuint64m8_t, uint64_t, vbool8_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vmadc_vv)))
vbool64_t vmadc_vv_i64m1_b64(vint64m1_t, vint64m1_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vmadc_vv)))
vbool32_t vmadc_vv_i64m2_b32(vint64m2_t, vint64m2_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vmadc_vv)))
vbool16_t vmadc_vv_i64m4_b16(vint64m4_t, vint64m4_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vmadc_vv)))
vbool8_t vmadc_vv_i64m8_b8(vint64m8_t, vint64m8_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vmadc_vx)))
vbool64_t vmadc_vx_i64m1_b64(vint64m1_t, int64_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vmadc_vx)))
vbool32_t vmadc_vx_i64m2_b32(vint64m2_t, int64_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vmadc_vx)))
vbool16_t vmadc_vx_i64m4_b16(vint64m4_t, int64_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vmadc_vx)))
vbool8_t vmadc_vx_i64m8_b8(vint64m8_t, int64_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vmadc_vv)))
vbool64_t vmadc_vv_u64m1_b64(vuint64m1_t, vuint64m1_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vmadc_vv)))
vbool32_t vmadc_vv_u64m2_b32(vuint64m2_t, vuint64m2_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vmadc_vv)))
vbool16_t vmadc_vv_u64m4_b16(vuint64m4_t, vuint64m4_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vmadc_vv)))
vbool8_t vmadc_vv_u64m8_b8(vuint64m8_t, vuint64m8_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vmadc_vx)))
vbool64_t vmadc_vx_u64m1_b64(vuint64m1_t, uint64_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vmadc_vx)))
vbool32_t vmadc_vx_u64m2_b32(vuint64m2_t, uint64_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vmadc_vx)))
vbool16_t vmadc_vx_u64m4_b16(vuint64m4_t, uint64_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vmadc_vx)))
vbool8_t vmadc_vx_u64m8_b8(vuint64m8_t, uint64_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vsbc_vvm)))
vint64m1_t vsbc_vvm_i64m1(vint64m1_t, vint64m1_t, vbool64_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vsbc_vvm)))
vint64m2_t vsbc_vvm_i64m2(vint64m2_t, vint64m2_t, vbool32_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vsbc_vvm)))
vint64m4_t vsbc_vvm_i64m4(vint64m4_t, vint64m4_t, vbool16_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vsbc_vvm)))
vint64m8_t vsbc_vvm_i64m8(vint64m8_t, vint64m8_t, vbool8_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vsbc_vxm)))
vint64m1_t vsbc_vxm_i64m1(vint64m1_t, int64_t, vbool64_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vsbc_vxm)))
vint64m2_t vsbc_vxm_i64m2(vint64m2_t, int64_t, vbool32_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vsbc_vxm)))
vint64m4_t vsbc_vxm_i64m4(vint64m4_t, int64_t, vbool16_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vsbc_vxm)))
vint64m8_t vsbc_vxm_i64m8(vint64m8_t, int64_t, vbool8_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vsbc_vvm)))
vuint64m1_t vsbc_vvm_u64m1(vuint64m1_t, vuint64m1_t, vbool64_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vsbc_vvm)))
vuint64m2_t vsbc_vvm_u64m2(vuint64m2_t, vuint64m2_t, vbool32_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vsbc_vvm)))
vuint64m4_t vsbc_vvm_u64m4(vuint64m4_t, vuint64m4_t, vbool16_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vsbc_vvm)))
vuint64m8_t vsbc_vvm_u64m8(vuint64m8_t, vuint64m8_t, vbool8_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vsbc_vxm)))
vuint64m1_t vsbc_vxm_u64m1(vuint64m1_t, uint64_t, vbool64_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vsbc_vxm)))
vuint64m2_t vsbc_vxm_u64m2(vuint64m2_t, uint64_t, vbool32_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vsbc_vxm)))
vuint64m4_t vsbc_vxm_u64m4(vuint64m4_t, uint64_t, vbool16_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vsbc_vxm)))
vuint64m8_t vsbc_vxm_u64m8(vuint64m8_t, uint64_t, vbool8_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vmsbc_vvm)))
vbool64_t vmsbc_vvm_i64m1_b64(vint64m1_t, vint64m1_t, vbool64_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vmsbc_vvm)))
vbool32_t vmsbc_vvm_i64m2_b32(vint64m2_t, vint64m2_t, vbool32_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vmsbc_vvm)))
vbool16_t vmsbc_vvm_i64m4_b16(vint64m4_t, vint64m4_t, vbool16_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vmsbc_vvm)))
vbool8_t vmsbc_vvm_i64m8_b8(vint64m8_t, vint64m8_t, vbool8_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vmsbc_vxm)))
vbool64_t vmsbc_vxm_i64m1_b64(vint64m1_t, int64_t, vbool64_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vmsbc_vxm)))
vbool32_t vmsbc_vxm_i64m2_b32(vint64m2_t, int64_t, vbool32_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vmsbc_vxm)))
vbool16_t vmsbc_vxm_i64m4_b16(vint64m4_t, int64_t, vbool16_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vmsbc_vxm)))
vbool8_t vmsbc_vxm_i64m8_b8(vint64m8_t, int64_t, vbool8_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vmsbc_vvm)))
vbool64_t vmsbc_vvm_u64m1_b64(vuint64m1_t, vuint64m1_t, vbool64_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vmsbc_vvm)))
vbool32_t vmsbc_vvm_u64m2_b32(vuint64m2_t, vuint64m2_t, vbool32_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vmsbc_vvm)))
vbool16_t vmsbc_vvm_u64m4_b16(vuint64m4_t, vuint64m4_t, vbool16_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vmsbc_vvm)))
vbool8_t vmsbc_vvm_u64m8_b8(vuint64m8_t, vuint64m8_t, vbool8_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vmsbc_vxm)))
vbool64_t vmsbc_vxm_u64m1_b64(vuint64m1_t, uint64_t, vbool64_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vmsbc_vxm)))
vbool32_t vmsbc_vxm_u64m2_b32(vuint64m2_t, uint64_t, vbool32_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vmsbc_vxm)))
vbool16_t vmsbc_vxm_u64m4_b16(vuint64m4_t, uint64_t, vbool16_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vmsbc_vxm)))
vbool8_t vmsbc_vxm_u64m8_b8(vuint64m8_t, uint64_t, vbool8_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vmsbc_vv)))
vbool64_t vmsbc_vv_i64m1_b64(vint64m1_t, vint64m1_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vmsbc_vv)))
vbool32_t vmsbc_vv_i64m2_b32(vint64m2_t, vint64m2_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vmsbc_vv)))
vbool16_t vmsbc_vv_i64m4_b16(vint64m4_t, vint64m4_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vmsbc_vv)))
vbool8_t vmsbc_vv_i64m8_b8(vint64m8_t, vint64m8_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vmsbc_vx)))
vbool64_t vmsbc_vx_i64m1_b64(vint64m1_t, int64_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vmsbc_vx)))
vbool32_t vmsbc_vx_i64m2_b32(vint64m2_t, int64_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vmsbc_vx)))
vbool16_t vmsbc_vx_i64m4_b16(vint64m4_t, int64_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vmsbc_vx)))
vbool8_t vmsbc_vx_i64m8_b8(vint64m8_t, int64_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vmsbc_vv)))
vbool64_t vmsbc_vv_u64m1_b64(vuint64m1_t, vuint64m1_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vmsbc_vv)))
vbool32_t vmsbc_vv_u64m2_b32(vuint64m2_t, vuint64m2_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vmsbc_vv)))
vbool16_t vmsbc_vv_u64m4_b16(vuint64m4_t, vuint64m4_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vmsbc_vv)))
vbool8_t vmsbc_vv_u64m8_b8(vuint64m8_t, vuint64m8_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vmsbc_vx)))
vbool64_t vmsbc_vx_u64m1_b64(vuint64m1_t, uint64_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vmsbc_vx)))
vbool32_t vmsbc_vx_u64m2_b32(vuint64m2_t, uint64_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vmsbc_vx)))
vbool16_t vmsbc_vx_u64m4_b16(vuint64m4_t, uint64_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vmsbc_vx)))
vbool8_t vmsbc_vx_u64m8_b8(vuint64m8_t, uint64_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vand_vv)))
vint64m1_t vand_vv_i64m1(vint64m1_t, vint64m1_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vand_vv_m)))
vint64m1_t vand_vv_i64m1_m(vbool64_t, vint64m1_t, vint64m1_t, vint64m1_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vand_vv)))
vint64m2_t vand_vv_i64m2(vint64m2_t, vint64m2_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vand_vv_m)))
vint64m2_t vand_vv_i64m2_m(vbool32_t, vint64m2_t, vint64m2_t, vint64m2_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vand_vv)))
vint64m4_t vand_vv_i64m4(vint64m4_t, vint64m4_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vand_vv_m)))
vint64m4_t vand_vv_i64m4_m(vbool16_t, vint64m4_t, vint64m4_t, vint64m4_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vand_vv)))
vint64m8_t vand_vv_i64m8(vint64m8_t, vint64m8_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vand_vv_m)))
vint64m8_t vand_vv_i64m8_m(vbool8_t, vint64m8_t, vint64m8_t, vint64m8_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vand_vx)))
vint64m1_t vand_vx_i64m1(vint64m1_t, int64_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vand_vx_m)))
vint64m1_t vand_vx_i64m1_m(vbool64_t, vint64m1_t, vint64m1_t, int64_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vand_vx)))
vint64m2_t vand_vx_i64m2(vint64m2_t, int64_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vand_vx_m)))
vint64m2_t vand_vx_i64m2_m(vbool32_t, vint64m2_t, vint64m2_t, int64_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vand_vx)))
vint64m4_t vand_vx_i64m4(vint64m4_t, int64_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vand_vx_m)))
vint64m4_t vand_vx_i64m4_m(vbool16_t, vint64m4_t, vint64m4_t, int64_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vand_vx)))
vint64m8_t vand_vx_i64m8(vint64m8_t, int64_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vand_vx_m)))
vint64m8_t vand_vx_i64m8_m(vbool8_t, vint64m8_t, vint64m8_t, int64_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vand_vv)))
vuint64m1_t vand_vv_u64m1(vuint64m1_t, vuint64m1_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vand_vv_m)))
vuint64m1_t vand_vv_u64m1_m(vbool64_t, vuint64m1_t, vuint64m1_t, vuint64m1_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vand_vv)))
vuint64m2_t vand_vv_u64m2(vuint64m2_t, vuint64m2_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vand_vv_m)))
vuint64m2_t vand_vv_u64m2_m(vbool32_t, vuint64m2_t, vuint64m2_t, vuint64m2_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vand_vv)))
vuint64m4_t vand_vv_u64m4(vuint64m4_t, vuint64m4_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vand_vv_m)))
vuint64m4_t vand_vv_u64m4_m(vbool16_t, vuint64m4_t, vuint64m4_t, vuint64m4_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vand_vv)))
vuint64m8_t vand_vv_u64m8(vuint64m8_t, vuint64m8_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vand_vv_m)))
vuint64m8_t vand_vv_u64m8_m(vbool8_t, vuint64m8_t, vuint64m8_t, vuint64m8_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vand_vx)))
vuint64m1_t vand_vx_u64m1(vuint64m1_t, uint64_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vand_vx_m)))
vuint64m1_t vand_vx_u64m1_m(vbool64_t, vuint64m1_t, vuint64m1_t, uint64_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vand_vx)))
vuint64m2_t vand_vx_u64m2(vuint64m2_t, uint64_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vand_vx_m)))
vuint64m2_t vand_vx_u64m2_m(vbool32_t, vuint64m2_t, vuint64m2_t, uint64_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vand_vx)))
vuint64m4_t vand_vx_u64m4(vuint64m4_t, uint64_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vand_vx_m)))
vuint64m4_t vand_vx_u64m4_m(vbool16_t, vuint64m4_t, vuint64m4_t, uint64_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vand_vx)))
vuint64m8_t vand_vx_u64m8(vuint64m8_t, uint64_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vand_vx_m)))
vuint64m8_t vand_vx_u64m8_m(vbool8_t, vuint64m8_t, vuint64m8_t, uint64_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vxor_vv)))
vint64m1_t vxor_vv_i64m1(vint64m1_t, vint64m1_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vxor_vv_m)))
vint64m1_t vxor_vv_i64m1_m(vbool64_t, vint64m1_t, vint64m1_t, vint64m1_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vxor_vv)))
vint64m2_t vxor_vv_i64m2(vint64m2_t, vint64m2_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vxor_vv_m)))
vint64m2_t vxor_vv_i64m2_m(vbool32_t, vint64m2_t, vint64m2_t, vint64m2_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vxor_vv)))
vint64m4_t vxor_vv_i64m4(vint64m4_t, vint64m4_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vxor_vv_m)))
vint64m4_t vxor_vv_i64m4_m(vbool16_t, vint64m4_t, vint64m4_t, vint64m4_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vxor_vv)))
vint64m8_t vxor_vv_i64m8(vint64m8_t, vint64m8_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vxor_vv_m)))
vint64m8_t vxor_vv_i64m8_m(vbool8_t, vint64m8_t, vint64m8_t, vint64m8_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vxor_vx)))
vint64m1_t vxor_vx_i64m1(vint64m1_t, int64_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vxor_vx_m)))
vint64m1_t vxor_vx_i64m1_m(vbool64_t, vint64m1_t, vint64m1_t, int64_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vxor_vx)))
vint64m2_t vxor_vx_i64m2(vint64m2_t, int64_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vxor_vx_m)))
vint64m2_t vxor_vx_i64m2_m(vbool32_t, vint64m2_t, vint64m2_t, int64_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vxor_vx)))
vint64m4_t vxor_vx_i64m4(vint64m4_t, int64_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vxor_vx_m)))
vint64m4_t vxor_vx_i64m4_m(vbool16_t, vint64m4_t, vint64m4_t, int64_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vxor_vx)))
vint64m8_t vxor_vx_i64m8(vint64m8_t, int64_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vxor_vx_m)))
vint64m8_t vxor_vx_i64m8_m(vbool8_t, vint64m8_t, vint64m8_t, int64_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vxor_vv)))
vuint64m1_t vxor_vv_u64m1(vuint64m1_t, vuint64m1_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vxor_vv_m)))
vuint64m1_t vxor_vv_u64m1_m(vbool64_t, vuint64m1_t, vuint64m1_t, vuint64m1_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vxor_vv)))
vuint64m2_t vxor_vv_u64m2(vuint64m2_t, vuint64m2_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vxor_vv_m)))
vuint64m2_t vxor_vv_u64m2_m(vbool32_t, vuint64m2_t, vuint64m2_t, vuint64m2_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vxor_vv)))
vuint64m4_t vxor_vv_u64m4(vuint64m4_t, vuint64m4_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vxor_vv_m)))
vuint64m4_t vxor_vv_u64m4_m(vbool16_t, vuint64m4_t, vuint64m4_t, vuint64m4_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vxor_vv)))
vuint64m8_t vxor_vv_u64m8(vuint64m8_t, vuint64m8_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vxor_vv_m)))
vuint64m8_t vxor_vv_u64m8_m(vbool8_t, vuint64m8_t, vuint64m8_t, vuint64m8_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vxor_vx)))
vuint64m1_t vxor_vx_u64m1(vuint64m1_t, uint64_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vxor_vx_m)))
vuint64m1_t vxor_vx_u64m1_m(vbool64_t, vuint64m1_t, vuint64m1_t, uint64_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vxor_vx)))
vuint64m2_t vxor_vx_u64m2(vuint64m2_t, uint64_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vxor_vx_m)))
vuint64m2_t vxor_vx_u64m2_m(vbool32_t, vuint64m2_t, vuint64m2_t, uint64_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vxor_vx)))
vuint64m4_t vxor_vx_u64m4(vuint64m4_t, uint64_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vxor_vx_m)))
vuint64m4_t vxor_vx_u64m4_m(vbool16_t, vuint64m4_t, vuint64m4_t, uint64_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vxor_vx)))
vuint64m8_t vxor_vx_u64m8(vuint64m8_t, uint64_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vxor_vx_m)))
vuint64m8_t vxor_vx_u64m8_m(vbool8_t, vuint64m8_t, vuint64m8_t, uint64_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vor_vv)))
vint64m1_t vor_vv_i64m1(vint64m1_t, vint64m1_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vor_vv_m)))
vint64m1_t vor_vv_i64m1_m(vbool64_t, vint64m1_t, vint64m1_t, vint64m1_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vor_vv)))
vint64m2_t vor_vv_i64m2(vint64m2_t, vint64m2_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vor_vv_m)))
vint64m2_t vor_vv_i64m2_m(vbool32_t, vint64m2_t, vint64m2_t, vint64m2_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vor_vv)))
vint64m4_t vor_vv_i64m4(vint64m4_t, vint64m4_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vor_vv_m)))
vint64m4_t vor_vv_i64m4_m(vbool16_t, vint64m4_t, vint64m4_t, vint64m4_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vor_vv)))
vint64m8_t vor_vv_i64m8(vint64m8_t, vint64m8_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vor_vv_m)))
vint64m8_t vor_vv_i64m8_m(vbool8_t, vint64m8_t, vint64m8_t, vint64m8_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vor_vx)))
vint64m1_t vor_vx_i64m1(vint64m1_t, int64_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vor_vx_m)))
vint64m1_t vor_vx_i64m1_m(vbool64_t, vint64m1_t, vint64m1_t, int64_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vor_vx)))
vint64m2_t vor_vx_i64m2(vint64m2_t, int64_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vor_vx_m)))
vint64m2_t vor_vx_i64m2_m(vbool32_t, vint64m2_t, vint64m2_t, int64_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vor_vx)))
vint64m4_t vor_vx_i64m4(vint64m4_t, int64_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vor_vx_m)))
vint64m4_t vor_vx_i64m4_m(vbool16_t, vint64m4_t, vint64m4_t, int64_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vor_vx)))
vint64m8_t vor_vx_i64m8(vint64m8_t, int64_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vor_vx_m)))
vint64m8_t vor_vx_i64m8_m(vbool8_t, vint64m8_t, vint64m8_t, int64_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vor_vv)))
vuint64m1_t vor_vv_u64m1(vuint64m1_t, vuint64m1_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vor_vv_m)))
vuint64m1_t vor_vv_u64m1_m(vbool64_t, vuint64m1_t, vuint64m1_t, vuint64m1_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vor_vv)))
vuint64m2_t vor_vv_u64m2(vuint64m2_t, vuint64m2_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vor_vv_m)))
vuint64m2_t vor_vv_u64m2_m(vbool32_t, vuint64m2_t, vuint64m2_t, vuint64m2_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vor_vv)))
vuint64m4_t vor_vv_u64m4(vuint64m4_t, vuint64m4_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vor_vv_m)))
vuint64m4_t vor_vv_u64m4_m(vbool16_t, vuint64m4_t, vuint64m4_t, vuint64m4_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vor_vv)))
vuint64m8_t vor_vv_u64m8(vuint64m8_t, vuint64m8_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vor_vv_m)))
vuint64m8_t vor_vv_u64m8_m(vbool8_t, vuint64m8_t, vuint64m8_t, vuint64m8_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vor_vx)))
vuint64m1_t vor_vx_u64m1(vuint64m1_t, uint64_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vor_vx_m)))
vuint64m1_t vor_vx_u64m1_m(vbool64_t, vuint64m1_t, vuint64m1_t, uint64_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vor_vx)))
vuint64m2_t vor_vx_u64m2(vuint64m2_t, uint64_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vor_vx_m)))
vuint64m2_t vor_vx_u64m2_m(vbool32_t, vuint64m2_t, vuint64m2_t, uint64_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vor_vx)))
vuint64m4_t vor_vx_u64m4(vuint64m4_t, uint64_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vor_vx_m)))
vuint64m4_t vor_vx_u64m4_m(vbool16_t, vuint64m4_t, vuint64m4_t, uint64_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vor_vx)))
vuint64m8_t vor_vx_u64m8(vuint64m8_t, uint64_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vor_vx_m)))
vuint64m8_t vor_vx_u64m8_m(vbool8_t, vuint64m8_t, vuint64m8_t, uint64_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vsll_vv)))
vint64m1_t vsll_vv_i64m1(vint64m1_t, vuint64m1_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vsll_vv_m)))
vint64m1_t vsll_vv_i64m1_m(vbool64_t, vint64m1_t, vint64m1_t, vuint64m1_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vsll_vv)))
vint64m2_t vsll_vv_i64m2(vint64m2_t, vuint64m2_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vsll_vv_m)))
vint64m2_t vsll_vv_i64m2_m(vbool32_t, vint64m2_t, vint64m2_t, vuint64m2_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vsll_vv)))
vint64m4_t vsll_vv_i64m4(vint64m4_t, vuint64m4_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vsll_vv_m)))
vint64m4_t vsll_vv_i64m4_m(vbool16_t, vint64m4_t, vint64m4_t, vuint64m4_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vsll_vv)))
vint64m8_t vsll_vv_i64m8(vint64m8_t, vuint64m8_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vsll_vv_m)))
vint64m8_t vsll_vv_i64m8_m(vbool8_t, vint64m8_t, vint64m8_t, vuint64m8_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vsll_vx)))
vint64m1_t vsll_vx_i64m1(vint64m1_t, size_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vsll_vx_m)))
vint64m1_t vsll_vx_i64m1_m(vbool64_t, vint64m1_t, vint64m1_t, size_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vsll_vx)))
vint64m2_t vsll_vx_i64m2(vint64m2_t, size_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vsll_vx_m)))
vint64m2_t vsll_vx_i64m2_m(vbool32_t, vint64m2_t, vint64m2_t, size_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vsll_vx)))
vint64m4_t vsll_vx_i64m4(vint64m4_t, size_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vsll_vx_m)))
vint64m4_t vsll_vx_i64m4_m(vbool16_t, vint64m4_t, vint64m4_t, size_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vsll_vx)))
vint64m8_t vsll_vx_i64m8(vint64m8_t, size_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vsll_vx_m)))
vint64m8_t vsll_vx_i64m8_m(vbool8_t, vint64m8_t, vint64m8_t, size_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vsll_vv)))
vuint64m1_t vsll_vv_u64m1(vuint64m1_t, vuint64m1_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vsll_vv_m)))
vuint64m1_t vsll_vv_u64m1_m(vbool64_t, vuint64m1_t, vuint64m1_t, vuint64m1_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vsll_vv)))
vuint64m2_t vsll_vv_u64m2(vuint64m2_t, vuint64m2_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vsll_vv_m)))
vuint64m2_t vsll_vv_u64m2_m(vbool32_t, vuint64m2_t, vuint64m2_t, vuint64m2_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vsll_vv)))
vuint64m4_t vsll_vv_u64m4(vuint64m4_t, vuint64m4_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vsll_vv_m)))
vuint64m4_t vsll_vv_u64m4_m(vbool16_t, vuint64m4_t, vuint64m4_t, vuint64m4_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vsll_vv)))
vuint64m8_t vsll_vv_u64m8(vuint64m8_t, vuint64m8_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vsll_vv_m)))
vuint64m8_t vsll_vv_u64m8_m(vbool8_t, vuint64m8_t, vuint64m8_t, vuint64m8_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vsll_vx)))
vuint64m1_t vsll_vx_u64m1(vuint64m1_t, size_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vsll_vx_m)))
vuint64m1_t vsll_vx_u64m1_m(vbool64_t, vuint64m1_t, vuint64m1_t, size_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vsll_vx)))
vuint64m2_t vsll_vx_u64m2(vuint64m2_t, size_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vsll_vx_m)))
vuint64m2_t vsll_vx_u64m2_m(vbool32_t, vuint64m2_t, vuint64m2_t, size_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vsll_vx)))
vuint64m4_t vsll_vx_u64m4(vuint64m4_t, size_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vsll_vx_m)))
vuint64m4_t vsll_vx_u64m4_m(vbool16_t, vuint64m4_t, vuint64m4_t, size_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vsll_vx)))
vuint64m8_t vsll_vx_u64m8(vuint64m8_t, size_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vsll_vx_m)))
vuint64m8_t vsll_vx_u64m8_m(vbool8_t, vuint64m8_t, vuint64m8_t, size_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vsrl_vv)))
vuint64m1_t vsrl_vv_u64m1(vuint64m1_t, vuint64m1_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vsrl_vv_m)))
vuint64m1_t vsrl_vv_u64m1_m(vbool64_t, vuint64m1_t, vuint64m1_t, vuint64m1_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vsrl_vv)))
vuint64m2_t vsrl_vv_u64m2(vuint64m2_t, vuint64m2_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vsrl_vv_m)))
vuint64m2_t vsrl_vv_u64m2_m(vbool32_t, vuint64m2_t, vuint64m2_t, vuint64m2_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vsrl_vv)))
vuint64m4_t vsrl_vv_u64m4(vuint64m4_t, vuint64m4_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vsrl_vv_m)))
vuint64m4_t vsrl_vv_u64m4_m(vbool16_t, vuint64m4_t, vuint64m4_t, vuint64m4_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vsrl_vv)))
vuint64m8_t vsrl_vv_u64m8(vuint64m8_t, vuint64m8_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vsrl_vv_m)))
vuint64m8_t vsrl_vv_u64m8_m(vbool8_t, vuint64m8_t, vuint64m8_t, vuint64m8_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vsrl_vx)))
vuint64m1_t vsrl_vx_u64m1(vuint64m1_t, size_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vsrl_vx_m)))
vuint64m1_t vsrl_vx_u64m1_m(vbool64_t, vuint64m1_t, vuint64m1_t, size_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vsrl_vx)))
vuint64m2_t vsrl_vx_u64m2(vuint64m2_t, size_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vsrl_vx_m)))
vuint64m2_t vsrl_vx_u64m2_m(vbool32_t, vuint64m2_t, vuint64m2_t, size_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vsrl_vx)))
vuint64m4_t vsrl_vx_u64m4(vuint64m4_t, size_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vsrl_vx_m)))
vuint64m4_t vsrl_vx_u64m4_m(vbool16_t, vuint64m4_t, vuint64m4_t, size_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vsrl_vx)))
vuint64m8_t vsrl_vx_u64m8(vuint64m8_t, size_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vsrl_vx_m)))
vuint64m8_t vsrl_vx_u64m8_m(vbool8_t, vuint64m8_t, vuint64m8_t, size_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vsra_vv)))
vint64m1_t vsra_vv_i64m1(vint64m1_t, vuint64m1_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vsra_vv_m)))
vint64m1_t vsra_vv_i64m1_m(vbool64_t, vint64m1_t, vint64m1_t, vuint64m1_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vsra_vv)))
vint64m2_t vsra_vv_i64m2(vint64m2_t, vuint64m2_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vsra_vv_m)))
vint64m2_t vsra_vv_i64m2_m(vbool32_t, vint64m2_t, vint64m2_t, vuint64m2_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vsra_vv)))
vint64m4_t vsra_vv_i64m4(vint64m4_t, vuint64m4_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vsra_vv_m)))
vint64m4_t vsra_vv_i64m4_m(vbool16_t, vint64m4_t, vint64m4_t, vuint64m4_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vsra_vv)))
vint64m8_t vsra_vv_i64m8(vint64m8_t, vuint64m8_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vsra_vv_m)))
vint64m8_t vsra_vv_i64m8_m(vbool8_t, vint64m8_t, vint64m8_t, vuint64m8_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vsra_vx)))
vint64m1_t vsra_vx_i64m1(vint64m1_t, size_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vsra_vx_m)))
vint64m1_t vsra_vx_i64m1_m(vbool64_t, vint64m1_t, vint64m1_t, size_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vsra_vx)))
vint64m2_t vsra_vx_i64m2(vint64m2_t, size_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vsra_vx_m)))
vint64m2_t vsra_vx_i64m2_m(vbool32_t, vint64m2_t, vint64m2_t, size_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vsra_vx)))
vint64m4_t vsra_vx_i64m4(vint64m4_t, size_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vsra_vx_m)))
vint64m4_t vsra_vx_i64m4_m(vbool16_t, vint64m4_t, vint64m4_t, size_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vsra_vx)))
vint64m8_t vsra_vx_i64m8(vint64m8_t, size_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vsra_vx_m)))
vint64m8_t vsra_vx_i64m8_m(vbool8_t, vint64m8_t, vint64m8_t, size_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vnsrl_wv)))
vuint32m1_t vnsrl_wv_u32m1(vuint64m2_t, vuint32m1_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vnsrl_wv_m)))
vuint32m1_t vnsrl_wv_u32m1_m(vbool32_t, vuint32m1_t, vuint64m2_t, vuint32m1_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vnsrl_wv)))
vuint32m2_t vnsrl_wv_u32m2(vuint64m4_t, vuint32m2_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vnsrl_wv_m)))
vuint32m2_t vnsrl_wv_u32m2_m(vbool16_t, vuint32m2_t, vuint64m4_t, vuint32m2_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vnsrl_wv)))
vuint32m4_t vnsrl_wv_u32m4(vuint64m8_t, vuint32m4_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vnsrl_wv_m)))
vuint32m4_t vnsrl_wv_u32m4_m(vbool8_t, vuint32m4_t, vuint64m8_t, vuint32m4_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vnsrl_wv)))
vuint32mf2_t vnsrl_wv_u32mf2(vuint64m1_t, vuint32mf2_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vnsrl_wv_m)))
vuint32mf2_t vnsrl_wv_u32mf2_m(vbool64_t, vuint32mf2_t, vuint64m1_t, vuint32mf2_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vnsrl_wx)))
vuint32m1_t vnsrl_wx_u32m1(vuint64m2_t, size_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vnsrl_wx_m)))
vuint32m1_t vnsrl_wx_u32m1_m(vbool32_t, vuint32m1_t, vuint64m2_t, size_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vnsrl_wx)))
vuint32m2_t vnsrl_wx_u32m2(vuint64m4_t, size_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vnsrl_wx_m)))
vuint32m2_t vnsrl_wx_u32m2_m(vbool16_t, vuint32m2_t, vuint64m4_t, size_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vnsrl_wx)))
vuint32m4_t vnsrl_wx_u32m4(vuint64m8_t, size_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vnsrl_wx_m)))
vuint32m4_t vnsrl_wx_u32m4_m(vbool8_t, vuint32m4_t, vuint64m8_t, size_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vnsrl_wx)))
vuint32mf2_t vnsrl_wx_u32mf2(vuint64m1_t, size_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vnsrl_wx_m)))
vuint32mf2_t vnsrl_wx_u32mf2_m(vbool64_t, vuint32mf2_t, vuint64m1_t, size_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vnsra_wv)))
vint32m1_t vnsra_wv_i32m1(vint64m2_t, vuint32m1_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vnsra_wv_m)))
vint32m1_t vnsra_wv_i32m1_m(vbool32_t, vint32m1_t, vint64m2_t, vuint32m1_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vnsra_wv)))
vint32m2_t vnsra_wv_i32m2(vint64m4_t, vuint32m2_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vnsra_wv_m)))
vint32m2_t vnsra_wv_i32m2_m(vbool16_t, vint32m2_t, vint64m4_t, vuint32m2_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vnsra_wv)))
vint32m4_t vnsra_wv_i32m4(vint64m8_t, vuint32m4_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vnsra_wv_m)))
vint32m4_t vnsra_wv_i32m4_m(vbool8_t, vint32m4_t, vint64m8_t, vuint32m4_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vnsra_wv)))
vint32mf2_t vnsra_wv_i32mf2(vint64m1_t, vuint32mf2_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vnsra_wv_m)))
vint32mf2_t vnsra_wv_i32mf2_m(vbool64_t, vint32mf2_t, vint64m1_t, vuint32mf2_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vnsra_wx)))
vint32m1_t vnsra_wx_i32m1(vint64m2_t, size_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vnsra_wx_m)))
vint32m1_t vnsra_wx_i32m1_m(vbool32_t, vint32m1_t, vint64m2_t, size_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vnsra_wx)))
vint32m2_t vnsra_wx_i32m2(vint64m4_t, size_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vnsra_wx_m)))
vint32m2_t vnsra_wx_i32m2_m(vbool16_t, vint32m2_t, vint64m4_t, size_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vnsra_wx)))
vint32m4_t vnsra_wx_i32m4(vint64m8_t, size_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vnsra_wx_m)))
vint32m4_t vnsra_wx_i32m4_m(vbool8_t, vint32m4_t, vint64m8_t, size_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vnsra_wx)))
vint32mf2_t vnsra_wx_i32mf2(vint64m1_t, size_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vnsra_wx_m)))
vint32mf2_t vnsra_wx_i32mf2_m(vbool64_t, vint32mf2_t, vint64m1_t, size_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vncvt_x_x_w)))
vuint32m1_t vncvt_x_x_w_u32m1(vuint64m2_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vncvt_x_x_w_m)))
vuint32m1_t vncvt_x_x_w_u32m1_m(vbool32_t, vuint32m1_t, vuint64m2_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vncvt_x_x_w)))
vuint32m2_t vncvt_x_x_w_u32m2(vuint64m4_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vncvt_x_x_w_m)))
vuint32m2_t vncvt_x_x_w_u32m2_m(vbool16_t, vuint32m2_t, vuint64m4_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vncvt_x_x_w)))
vuint32m4_t vncvt_x_x_w_u32m4(vuint64m8_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vncvt_x_x_w_m)))
vuint32m4_t vncvt_x_x_w_u32m4_m(vbool8_t, vuint32m4_t, vuint64m8_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vncvt_x_x_w)))
vuint32mf2_t vncvt_x_x_w_u32mf2(vuint64m1_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vncvt_x_x_w_m)))
vuint32mf2_t vncvt_x_x_w_u32mf2_m(vbool64_t, vuint32mf2_t, vuint64m1_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vmseq_vv)))
vbool64_t vmseq_vv_i64m1_b64(vint64m1_t, vint64m1_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vmseq_vv_m)))
vbool64_t vmseq_vv_i64m1_b64_m(vbool64_t, vbool64_t, vint64m1_t, vint64m1_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vmseq_vv)))
vbool32_t vmseq_vv_i64m2_b32(vint64m2_t, vint64m2_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vmseq_vv_m)))
vbool32_t vmseq_vv_i64m2_b32_m(vbool32_t, vbool32_t, vint64m2_t, vint64m2_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vmseq_vv)))
vbool16_t vmseq_vv_i64m4_b16(vint64m4_t, vint64m4_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vmseq_vv_m)))
vbool16_t vmseq_vv_i64m4_b16_m(vbool16_t, vbool16_t, vint64m4_t, vint64m4_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vmseq_vv)))
vbool8_t vmseq_vv_i64m8_b8(vint64m8_t, vint64m8_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vmseq_vv_m)))
vbool8_t vmseq_vv_i64m8_b8_m(vbool8_t, vbool8_t, vint64m8_t, vint64m8_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vmseq_vx)))
vbool64_t vmseq_vx_i64m1_b64(vint64m1_t, int64_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vmseq_vx_m)))
vbool64_t vmseq_vx_i64m1_b64_m(vbool64_t, vbool64_t, vint64m1_t, int64_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vmseq_vx)))
vbool32_t vmseq_vx_i64m2_b32(vint64m2_t, int64_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vmseq_vx_m)))
vbool32_t vmseq_vx_i64m2_b32_m(vbool32_t, vbool32_t, vint64m2_t, int64_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vmseq_vx)))
vbool16_t vmseq_vx_i64m4_b16(vint64m4_t, int64_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vmseq_vx_m)))
vbool16_t vmseq_vx_i64m4_b16_m(vbool16_t, vbool16_t, vint64m4_t, int64_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vmseq_vx)))
vbool8_t vmseq_vx_i64m8_b8(vint64m8_t, int64_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vmseq_vx_m)))
vbool8_t vmseq_vx_i64m8_b8_m(vbool8_t, vbool8_t, vint64m8_t, int64_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vmseq_vv)))
vbool64_t vmseq_vv_u64m1_b64(vuint64m1_t, vuint64m1_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vmseq_vv_m)))
vbool64_t vmseq_vv_u64m1_b64_m(vbool64_t, vbool64_t, vuint64m1_t, vuint64m1_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vmseq_vv)))
vbool32_t vmseq_vv_u64m2_b32(vuint64m2_t, vuint64m2_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vmseq_vv_m)))
vbool32_t vmseq_vv_u64m2_b32_m(vbool32_t, vbool32_t, vuint64m2_t, vuint64m2_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vmseq_vv)))
vbool16_t vmseq_vv_u64m4_b16(vuint64m4_t, vuint64m4_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vmseq_vv_m)))
vbool16_t vmseq_vv_u64m4_b16_m(vbool16_t, vbool16_t, vuint64m4_t, vuint64m4_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vmseq_vv)))
vbool8_t vmseq_vv_u64m8_b8(vuint64m8_t, vuint64m8_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vmseq_vv_m)))
vbool8_t vmseq_vv_u64m8_b8_m(vbool8_t, vbool8_t, vuint64m8_t, vuint64m8_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vmseq_vx)))
vbool64_t vmseq_vx_u64m1_b64(vuint64m1_t, uint64_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vmseq_vx_m)))
vbool64_t vmseq_vx_u64m1_b64_m(vbool64_t, vbool64_t, vuint64m1_t, uint64_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vmseq_vx)))
vbool32_t vmseq_vx_u64m2_b32(vuint64m2_t, uint64_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vmseq_vx_m)))
vbool32_t vmseq_vx_u64m2_b32_m(vbool32_t, vbool32_t, vuint64m2_t, uint64_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vmseq_vx)))
vbool16_t vmseq_vx_u64m4_b16(vuint64m4_t, uint64_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vmseq_vx_m)))
vbool16_t vmseq_vx_u64m4_b16_m(vbool16_t, vbool16_t, vuint64m4_t, uint64_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vmseq_vx)))
vbool8_t vmseq_vx_u64m8_b8(vuint64m8_t, uint64_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vmseq_vx_m)))
vbool8_t vmseq_vx_u64m8_b8_m(vbool8_t, vbool8_t, vuint64m8_t, uint64_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vmsne_vv)))
vbool64_t vmsne_vv_i64m1_b64(vint64m1_t, vint64m1_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vmsne_vv_m)))
vbool64_t vmsne_vv_i64m1_b64_m(vbool64_t, vbool64_t, vint64m1_t, vint64m1_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vmsne_vv)))
vbool32_t vmsne_vv_i64m2_b32(vint64m2_t, vint64m2_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vmsne_vv_m)))
vbool32_t vmsne_vv_i64m2_b32_m(vbool32_t, vbool32_t, vint64m2_t, vint64m2_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vmsne_vv)))
vbool16_t vmsne_vv_i64m4_b16(vint64m4_t, vint64m4_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vmsne_vv_m)))
vbool16_t vmsne_vv_i64m4_b16_m(vbool16_t, vbool16_t, vint64m4_t, vint64m4_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vmsne_vv)))
vbool8_t vmsne_vv_i64m8_b8(vint64m8_t, vint64m8_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vmsne_vv_m)))
vbool8_t vmsne_vv_i64m8_b8_m(vbool8_t, vbool8_t, vint64m8_t, vint64m8_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vmsne_vx)))
vbool64_t vmsne_vx_i64m1_b64(vint64m1_t, int64_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vmsne_vx_m)))
vbool64_t vmsne_vx_i64m1_b64_m(vbool64_t, vbool64_t, vint64m1_t, int64_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vmsne_vx)))
vbool32_t vmsne_vx_i64m2_b32(vint64m2_t, int64_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vmsne_vx_m)))
vbool32_t vmsne_vx_i64m2_b32_m(vbool32_t, vbool32_t, vint64m2_t, int64_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vmsne_vx)))
vbool16_t vmsne_vx_i64m4_b16(vint64m4_t, int64_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vmsne_vx_m)))
vbool16_t vmsne_vx_i64m4_b16_m(vbool16_t, vbool16_t, vint64m4_t, int64_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vmsne_vx)))
vbool8_t vmsne_vx_i64m8_b8(vint64m8_t, int64_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vmsne_vx_m)))
vbool8_t vmsne_vx_i64m8_b8_m(vbool8_t, vbool8_t, vint64m8_t, int64_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vmsne_vv)))
vbool64_t vmsne_vv_u64m1_b64(vuint64m1_t, vuint64m1_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vmsne_vv_m)))
vbool64_t vmsne_vv_u64m1_b64_m(vbool64_t, vbool64_t, vuint64m1_t, vuint64m1_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vmsne_vv)))
vbool32_t vmsne_vv_u64m2_b32(vuint64m2_t, vuint64m2_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vmsne_vv_m)))
vbool32_t vmsne_vv_u64m2_b32_m(vbool32_t, vbool32_t, vuint64m2_t, vuint64m2_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vmsne_vv)))
vbool16_t vmsne_vv_u64m4_b16(vuint64m4_t, vuint64m4_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vmsne_vv_m)))
vbool16_t vmsne_vv_u64m4_b16_m(vbool16_t, vbool16_t, vuint64m4_t, vuint64m4_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vmsne_vv)))
vbool8_t vmsne_vv_u64m8_b8(vuint64m8_t, vuint64m8_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vmsne_vv_m)))
vbool8_t vmsne_vv_u64m8_b8_m(vbool8_t, vbool8_t, vuint64m8_t, vuint64m8_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vmsne_vx)))
vbool64_t vmsne_vx_u64m1_b64(vuint64m1_t, uint64_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vmsne_vx_m)))
vbool64_t vmsne_vx_u64m1_b64_m(vbool64_t, vbool64_t, vuint64m1_t, uint64_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vmsne_vx)))
vbool32_t vmsne_vx_u64m2_b32(vuint64m2_t, uint64_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vmsne_vx_m)))
vbool32_t vmsne_vx_u64m2_b32_m(vbool32_t, vbool32_t, vuint64m2_t, uint64_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vmsne_vx)))
vbool16_t vmsne_vx_u64m4_b16(vuint64m4_t, uint64_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vmsne_vx_m)))
vbool16_t vmsne_vx_u64m4_b16_m(vbool16_t, vbool16_t, vuint64m4_t, uint64_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vmsne_vx)))
vbool8_t vmsne_vx_u64m8_b8(vuint64m8_t, uint64_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vmsne_vx_m)))
vbool8_t vmsne_vx_u64m8_b8_m(vbool8_t, vbool8_t, vuint64m8_t, uint64_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vmsltu_vv)))
vbool64_t vmsltu_vv_u64m1_b64(vuint64m1_t, vuint64m1_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vmsltu_vv_m)))
vbool64_t vmsltu_vv_u64m1_b64_m(vbool64_t, vbool64_t, vuint64m1_t, vuint64m1_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vmsltu_vv)))
vbool32_t vmsltu_vv_u64m2_b32(vuint64m2_t, vuint64m2_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vmsltu_vv_m)))
vbool32_t vmsltu_vv_u64m2_b32_m(vbool32_t, vbool32_t, vuint64m2_t, vuint64m2_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vmsltu_vv)))
vbool16_t vmsltu_vv_u64m4_b16(vuint64m4_t, vuint64m4_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vmsltu_vv_m)))
vbool16_t vmsltu_vv_u64m4_b16_m(vbool16_t, vbool16_t, vuint64m4_t, vuint64m4_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vmsltu_vv)))
vbool8_t vmsltu_vv_u64m8_b8(vuint64m8_t, vuint64m8_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vmsltu_vv_m)))
vbool8_t vmsltu_vv_u64m8_b8_m(vbool8_t, vbool8_t, vuint64m8_t, vuint64m8_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vmsltu_vx)))
vbool64_t vmsltu_vx_u64m1_b64(vuint64m1_t, uint64_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vmsltu_vx_m)))
vbool64_t vmsltu_vx_u64m1_b64_m(vbool64_t, vbool64_t, vuint64m1_t, uint64_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vmsltu_vx)))
vbool32_t vmsltu_vx_u64m2_b32(vuint64m2_t, uint64_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vmsltu_vx_m)))
vbool32_t vmsltu_vx_u64m2_b32_m(vbool32_t, vbool32_t, vuint64m2_t, uint64_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vmsltu_vx)))
vbool16_t vmsltu_vx_u64m4_b16(vuint64m4_t, uint64_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vmsltu_vx_m)))
vbool16_t vmsltu_vx_u64m4_b16_m(vbool16_t, vbool16_t, vuint64m4_t, uint64_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vmsltu_vx)))
vbool8_t vmsltu_vx_u64m8_b8(vuint64m8_t, uint64_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vmsltu_vx_m)))
vbool8_t vmsltu_vx_u64m8_b8_m(vbool8_t, vbool8_t, vuint64m8_t, uint64_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vmslt_vv)))
vbool64_t vmslt_vv_i64m1_b64(vint64m1_t, vint64m1_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vmslt_vv_m)))
vbool64_t vmslt_vv_i64m1_b64_m(vbool64_t, vbool64_t, vint64m1_t, vint64m1_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vmslt_vv)))
vbool32_t vmslt_vv_i64m2_b32(vint64m2_t, vint64m2_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vmslt_vv_m)))
vbool32_t vmslt_vv_i64m2_b32_m(vbool32_t, vbool32_t, vint64m2_t, vint64m2_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vmslt_vv)))
vbool16_t vmslt_vv_i64m4_b16(vint64m4_t, vint64m4_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vmslt_vv_m)))
vbool16_t vmslt_vv_i64m4_b16_m(vbool16_t, vbool16_t, vint64m4_t, vint64m4_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vmslt_vv)))
vbool8_t vmslt_vv_i64m8_b8(vint64m8_t, vint64m8_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vmslt_vv_m)))
vbool8_t vmslt_vv_i64m8_b8_m(vbool8_t, vbool8_t, vint64m8_t, vint64m8_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vmslt_vx)))
vbool64_t vmslt_vx_i64m1_b64(vint64m1_t, int64_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vmslt_vx_m)))
vbool64_t vmslt_vx_i64m1_b64_m(vbool64_t, vbool64_t, vint64m1_t, int64_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vmslt_vx)))
vbool32_t vmslt_vx_i64m2_b32(vint64m2_t, int64_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vmslt_vx_m)))
vbool32_t vmslt_vx_i64m2_b32_m(vbool32_t, vbool32_t, vint64m2_t, int64_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vmslt_vx)))
vbool16_t vmslt_vx_i64m4_b16(vint64m4_t, int64_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vmslt_vx_m)))
vbool16_t vmslt_vx_i64m4_b16_m(vbool16_t, vbool16_t, vint64m4_t, int64_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vmslt_vx)))
vbool8_t vmslt_vx_i64m8_b8(vint64m8_t, int64_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vmslt_vx_m)))
vbool8_t vmslt_vx_i64m8_b8_m(vbool8_t, vbool8_t, vint64m8_t, int64_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vmsleu_vv)))
vbool64_t vmsleu_vv_u64m1_b64(vuint64m1_t, vuint64m1_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vmsleu_vv_m)))
vbool64_t vmsleu_vv_u64m1_b64_m(vbool64_t, vbool64_t, vuint64m1_t, vuint64m1_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vmsleu_vv)))
vbool32_t vmsleu_vv_u64m2_b32(vuint64m2_t, vuint64m2_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vmsleu_vv_m)))
vbool32_t vmsleu_vv_u64m2_b32_m(vbool32_t, vbool32_t, vuint64m2_t, vuint64m2_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vmsleu_vv)))
vbool16_t vmsleu_vv_u64m4_b16(vuint64m4_t, vuint64m4_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vmsleu_vv_m)))
vbool16_t vmsleu_vv_u64m4_b16_m(vbool16_t, vbool16_t, vuint64m4_t, vuint64m4_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vmsleu_vv)))
vbool8_t vmsleu_vv_u64m8_b8(vuint64m8_t, vuint64m8_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vmsleu_vv_m)))
vbool8_t vmsleu_vv_u64m8_b8_m(vbool8_t, vbool8_t, vuint64m8_t, vuint64m8_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vmsleu_vx)))
vbool64_t vmsleu_vx_u64m1_b64(vuint64m1_t, uint64_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vmsleu_vx_m)))
vbool64_t vmsleu_vx_u64m1_b64_m(vbool64_t, vbool64_t, vuint64m1_t, uint64_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vmsleu_vx)))
vbool32_t vmsleu_vx_u64m2_b32(vuint64m2_t, uint64_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vmsleu_vx_m)))
vbool32_t vmsleu_vx_u64m2_b32_m(vbool32_t, vbool32_t, vuint64m2_t, uint64_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vmsleu_vx)))
vbool16_t vmsleu_vx_u64m4_b16(vuint64m4_t, uint64_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vmsleu_vx_m)))
vbool16_t vmsleu_vx_u64m4_b16_m(vbool16_t, vbool16_t, vuint64m4_t, uint64_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vmsleu_vx)))
vbool8_t vmsleu_vx_u64m8_b8(vuint64m8_t, uint64_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vmsleu_vx_m)))
vbool8_t vmsleu_vx_u64m8_b8_m(vbool8_t, vbool8_t, vuint64m8_t, uint64_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vmsle_vv)))
vbool64_t vmsle_vv_i64m1_b64(vint64m1_t, vint64m1_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vmsle_vv_m)))
vbool64_t vmsle_vv_i64m1_b64_m(vbool64_t, vbool64_t, vint64m1_t, vint64m1_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vmsle_vv)))
vbool32_t vmsle_vv_i64m2_b32(vint64m2_t, vint64m2_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vmsle_vv_m)))
vbool32_t vmsle_vv_i64m2_b32_m(vbool32_t, vbool32_t, vint64m2_t, vint64m2_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vmsle_vv)))
vbool16_t vmsle_vv_i64m4_b16(vint64m4_t, vint64m4_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vmsle_vv_m)))
vbool16_t vmsle_vv_i64m4_b16_m(vbool16_t, vbool16_t, vint64m4_t, vint64m4_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vmsle_vv)))
vbool8_t vmsle_vv_i64m8_b8(vint64m8_t, vint64m8_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vmsle_vv_m)))
vbool8_t vmsle_vv_i64m8_b8_m(vbool8_t, vbool8_t, vint64m8_t, vint64m8_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vmsle_vx)))
vbool64_t vmsle_vx_i64m1_b64(vint64m1_t, int64_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vmsle_vx_m)))
vbool64_t vmsle_vx_i64m1_b64_m(vbool64_t, vbool64_t, vint64m1_t, int64_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vmsle_vx)))
vbool32_t vmsle_vx_i64m2_b32(vint64m2_t, int64_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vmsle_vx_m)))
vbool32_t vmsle_vx_i64m2_b32_m(vbool32_t, vbool32_t, vint64m2_t, int64_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vmsle_vx)))
vbool16_t vmsle_vx_i64m4_b16(vint64m4_t, int64_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vmsle_vx_m)))
vbool16_t vmsle_vx_i64m4_b16_m(vbool16_t, vbool16_t, vint64m4_t, int64_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vmsle_vx)))
vbool8_t vmsle_vx_i64m8_b8(vint64m8_t, int64_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vmsle_vx_m)))
vbool8_t vmsle_vx_i64m8_b8_m(vbool8_t, vbool8_t, vint64m8_t, int64_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vmsgtu_vv)))
vbool64_t vmsgtu_vv_u64m1_b64(vuint64m1_t, vuint64m1_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vmsgtu_vv_m)))
vbool64_t vmsgtu_vv_u64m1_b64_m(vbool64_t, vbool64_t, vuint64m1_t, vuint64m1_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vmsgtu_vv)))
vbool32_t vmsgtu_vv_u64m2_b32(vuint64m2_t, vuint64m2_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vmsgtu_vv_m)))
vbool32_t vmsgtu_vv_u64m2_b32_m(vbool32_t, vbool32_t, vuint64m2_t, vuint64m2_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vmsgtu_vv)))
vbool16_t vmsgtu_vv_u64m4_b16(vuint64m4_t, vuint64m4_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vmsgtu_vv_m)))
vbool16_t vmsgtu_vv_u64m4_b16_m(vbool16_t, vbool16_t, vuint64m4_t, vuint64m4_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vmsgtu_vv)))
vbool8_t vmsgtu_vv_u64m8_b8(vuint64m8_t, vuint64m8_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vmsgtu_vv_m)))
vbool8_t vmsgtu_vv_u64m8_b8_m(vbool8_t, vbool8_t, vuint64m8_t, vuint64m8_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vmsgtu_vx)))
vbool64_t vmsgtu_vx_u64m1_b64(vuint64m1_t, uint64_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vmsgtu_vx_m)))
vbool64_t vmsgtu_vx_u64m1_b64_m(vbool64_t, vbool64_t, vuint64m1_t, uint64_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vmsgtu_vx)))
vbool32_t vmsgtu_vx_u64m2_b32(vuint64m2_t, uint64_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vmsgtu_vx_m)))
vbool32_t vmsgtu_vx_u64m2_b32_m(vbool32_t, vbool32_t, vuint64m2_t, uint64_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vmsgtu_vx)))
vbool16_t vmsgtu_vx_u64m4_b16(vuint64m4_t, uint64_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vmsgtu_vx_m)))
vbool16_t vmsgtu_vx_u64m4_b16_m(vbool16_t, vbool16_t, vuint64m4_t, uint64_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vmsgtu_vx)))
vbool8_t vmsgtu_vx_u64m8_b8(vuint64m8_t, uint64_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vmsgtu_vx_m)))
vbool8_t vmsgtu_vx_u64m8_b8_m(vbool8_t, vbool8_t, vuint64m8_t, uint64_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vmsgt_vv)))
vbool64_t vmsgt_vv_i64m1_b64(vint64m1_t, vint64m1_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vmsgt_vv_m)))
vbool64_t vmsgt_vv_i64m1_b64_m(vbool64_t, vbool64_t, vint64m1_t, vint64m1_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vmsgt_vv)))
vbool32_t vmsgt_vv_i64m2_b32(vint64m2_t, vint64m2_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vmsgt_vv_m)))
vbool32_t vmsgt_vv_i64m2_b32_m(vbool32_t, vbool32_t, vint64m2_t, vint64m2_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vmsgt_vv)))
vbool16_t vmsgt_vv_i64m4_b16(vint64m4_t, vint64m4_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vmsgt_vv_m)))
vbool16_t vmsgt_vv_i64m4_b16_m(vbool16_t, vbool16_t, vint64m4_t, vint64m4_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vmsgt_vv)))
vbool8_t vmsgt_vv_i64m8_b8(vint64m8_t, vint64m8_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vmsgt_vv_m)))
vbool8_t vmsgt_vv_i64m8_b8_m(vbool8_t, vbool8_t, vint64m8_t, vint64m8_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vmsgt_vx)))
vbool64_t vmsgt_vx_i64m1_b64(vint64m1_t, int64_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vmsgt_vx_m)))
vbool64_t vmsgt_vx_i64m1_b64_m(vbool64_t, vbool64_t, vint64m1_t, int64_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vmsgt_vx)))
vbool32_t vmsgt_vx_i64m2_b32(vint64m2_t, int64_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vmsgt_vx_m)))
vbool32_t vmsgt_vx_i64m2_b32_m(vbool32_t, vbool32_t, vint64m2_t, int64_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vmsgt_vx)))
vbool16_t vmsgt_vx_i64m4_b16(vint64m4_t, int64_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vmsgt_vx_m)))
vbool16_t vmsgt_vx_i64m4_b16_m(vbool16_t, vbool16_t, vint64m4_t, int64_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vmsgt_vx)))
vbool8_t vmsgt_vx_i64m8_b8(vint64m8_t, int64_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vmsgt_vx_m)))
vbool8_t vmsgt_vx_i64m8_b8_m(vbool8_t, vbool8_t, vint64m8_t, int64_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vmsgeu_vv)))
vbool64_t vmsgeu_vv_u64m1_b64(vuint64m1_t, vuint64m1_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vmsgeu_vv_m)))
vbool64_t vmsgeu_vv_u64m1_b64_m(vbool64_t, vbool64_t, vuint64m1_t, vuint64m1_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vmsgeu_vv)))
vbool32_t vmsgeu_vv_u64m2_b32(vuint64m2_t, vuint64m2_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vmsgeu_vv_m)))
vbool32_t vmsgeu_vv_u64m2_b32_m(vbool32_t, vbool32_t, vuint64m2_t, vuint64m2_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vmsgeu_vv)))
vbool16_t vmsgeu_vv_u64m4_b16(vuint64m4_t, vuint64m4_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vmsgeu_vv_m)))
vbool16_t vmsgeu_vv_u64m4_b16_m(vbool16_t, vbool16_t, vuint64m4_t, vuint64m4_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vmsgeu_vv)))
vbool8_t vmsgeu_vv_u64m8_b8(vuint64m8_t, vuint64m8_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vmsgeu_vv_m)))
vbool8_t vmsgeu_vv_u64m8_b8_m(vbool8_t, vbool8_t, vuint64m8_t, vuint64m8_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vwaddu_wv)))
vuint64m1_t vwaddu_wv_u64m1(vuint64m1_t, vuint32mf2_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vwaddu_wv_m)))
vuint64m1_t vwaddu_wv_u64m1_m(vbool64_t, vuint64m1_t, vuint64m1_t, vuint32mf2_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vwaddu_wv)))
vuint64m2_t vwaddu_wv_u64m2(vuint64m2_t, vuint32m1_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vwaddu_wv_m)))
vuint64m2_t vwaddu_wv_u64m2_m(vbool32_t, vuint64m2_t, vuint64m2_t, vuint32m1_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vwaddu_wv)))
vuint64m4_t vwaddu_wv_u64m4(vuint64m4_t, vuint32m2_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vwaddu_wv_m)))
vuint64m4_t vwaddu_wv_u64m4_m(vbool16_t, vuint64m4_t, vuint64m4_t, vuint32m2_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vwaddu_wv)))
vuint64m8_t vwaddu_wv_u64m8(vuint64m8_t, vuint32m4_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vwaddu_wv_m)))
vuint64m8_t vwaddu_wv_u64m8_m(vbool8_t, vuint64m8_t, vuint64m8_t, vuint32m4_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vmsgeu_vx)))
vbool64_t vmsgeu_vx_u64m1_b64(vuint64m1_t, uint64_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vmsgeu_vx_m)))
vbool64_t vmsgeu_vx_u64m1_b64_m(vbool64_t, vbool64_t, vuint64m1_t, uint64_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vmsgeu_vx)))
vbool32_t vmsgeu_vx_u64m2_b32(vuint64m2_t, uint64_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vmsgeu_vx_m)))
vbool32_t vmsgeu_vx_u64m2_b32_m(vbool32_t, vbool32_t, vuint64m2_t, uint64_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vmsgeu_vx)))
vbool16_t vmsgeu_vx_u64m4_b16(vuint64m4_t, uint64_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vmsgeu_vx_m)))
vbool16_t vmsgeu_vx_u64m4_b16_m(vbool16_t, vbool16_t, vuint64m4_t, uint64_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vmsgeu_vx)))
vbool8_t vmsgeu_vx_u64m8_b8(vuint64m8_t, uint64_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vmsgeu_vx_m)))
vbool8_t vmsgeu_vx_u64m8_b8_m(vbool8_t, vbool8_t, vuint64m8_t, uint64_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vmsge_vv)))
vbool64_t vmsge_vv_i64m1_b64(vint64m1_t, vint64m1_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vmsge_vv_m)))
vbool64_t vmsge_vv_i64m1_b64_m(vbool64_t, vbool64_t, vint64m1_t, vint64m1_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vmsge_vv)))
vbool32_t vmsge_vv_i64m2_b32(vint64m2_t, vint64m2_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vmsge_vv_m)))
vbool32_t vmsge_vv_i64m2_b32_m(vbool32_t, vbool32_t, vint64m2_t, vint64m2_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vmsge_vv)))
vbool16_t vmsge_vv_i64m4_b16(vint64m4_t, vint64m4_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vmsge_vv_m)))
vbool16_t vmsge_vv_i64m4_b16_m(vbool16_t, vbool16_t, vint64m4_t, vint64m4_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vmsge_vv)))
vbool8_t vmsge_vv_i64m8_b8(vint64m8_t, vint64m8_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vmsge_vv_m)))
vbool8_t vmsge_vv_i64m8_b8_m(vbool8_t, vbool8_t, vint64m8_t, vint64m8_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vmsge_vx)))
vbool64_t vmsge_vx_i64m1_b64(vint64m1_t, int64_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vmsge_vx_m)))
vbool64_t vmsge_vx_i64m1_b64_m(vbool64_t, vbool64_t, vint64m1_t, int64_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vmsge_vx)))
vbool32_t vmsge_vx_i64m2_b32(vint64m2_t, int64_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vmsge_vx_m)))
vbool32_t vmsge_vx_i64m2_b32_m(vbool32_t, vbool32_t, vint64m2_t, int64_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vmsge_vx)))
vbool16_t vmsge_vx_i64m4_b16(vint64m4_t, int64_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vmsge_vx_m)))
vbool16_t vmsge_vx_i64m4_b16_m(vbool16_t, vbool16_t, vint64m4_t, int64_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vmsge_vx)))
vbool8_t vmsge_vx_i64m8_b8(vint64m8_t, int64_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vmsge_vx_m)))
vbool8_t vmsge_vx_i64m8_b8_m(vbool8_t, vbool8_t, vint64m8_t, int64_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vminu_vv)))
vuint64m1_t vminu_vv_u64m1(vuint64m1_t, vuint64m1_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vminu_vv_m)))
vuint64m1_t vminu_vv_u64m1_m(vbool64_t, vuint64m1_t, vuint64m1_t, vuint64m1_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vminu_vv)))
vuint64m2_t vminu_vv_u64m2(vuint64m2_t, vuint64m2_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vminu_vv_m)))
vuint64m2_t vminu_vv_u64m2_m(vbool32_t, vuint64m2_t, vuint64m2_t, vuint64m2_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vminu_vv)))
vuint64m4_t vminu_vv_u64m4(vuint64m4_t, vuint64m4_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vminu_vv_m)))
vuint64m4_t vminu_vv_u64m4_m(vbool16_t, vuint64m4_t, vuint64m4_t, vuint64m4_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vminu_vv)))
vuint64m8_t vminu_vv_u64m8(vuint64m8_t, vuint64m8_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vminu_vv_m)))
vuint64m8_t vminu_vv_u64m8_m(vbool8_t, vuint64m8_t, vuint64m8_t, vuint64m8_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vminu_vx)))
vuint64m1_t vminu_vx_u64m1(vuint64m1_t, uint64_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vminu_vx_m)))
vuint64m1_t vminu_vx_u64m1_m(vbool64_t, vuint64m1_t, vuint64m1_t, uint64_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vminu_vx)))
vuint64m2_t vminu_vx_u64m2(vuint64m2_t, uint64_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vminu_vx_m)))
vuint64m2_t vminu_vx_u64m2_m(vbool32_t, vuint64m2_t, vuint64m2_t, uint64_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vminu_vx)))
vuint64m4_t vminu_vx_u64m4(vuint64m4_t, uint64_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vminu_vx_m)))
vuint64m4_t vminu_vx_u64m4_m(vbool16_t, vuint64m4_t, vuint64m4_t, uint64_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vminu_vx)))
vuint64m8_t vminu_vx_u64m8(vuint64m8_t, uint64_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vminu_vx_m)))
vuint64m8_t vminu_vx_u64m8_m(vbool8_t, vuint64m8_t, vuint64m8_t, uint64_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vmin_vv)))
vint64m1_t vmin_vv_i64m1(vint64m1_t, vint64m1_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vmin_vv_m)))
vint64m1_t vmin_vv_i64m1_m(vbool64_t, vint64m1_t, vint64m1_t, vint64m1_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vmin_vv)))
vint64m2_t vmin_vv_i64m2(vint64m2_t, vint64m2_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vmin_vv_m)))
vint64m2_t vmin_vv_i64m2_m(vbool32_t, vint64m2_t, vint64m2_t, vint64m2_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vmin_vv)))
vint64m4_t vmin_vv_i64m4(vint64m4_t, vint64m4_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vmin_vv_m)))
vint64m4_t vmin_vv_i64m4_m(vbool16_t, vint64m4_t, vint64m4_t, vint64m4_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vmin_vv)))
vint64m8_t vmin_vv_i64m8(vint64m8_t, vint64m8_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vmin_vv_m)))
vint64m8_t vmin_vv_i64m8_m(vbool8_t, vint64m8_t, vint64m8_t, vint64m8_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vmin_vx)))
vint64m1_t vmin_vx_i64m1(vint64m1_t, int64_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vmin_vx_m)))
vint64m1_t vmin_vx_i64m1_m(vbool64_t, vint64m1_t, vint64m1_t, int64_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vmin_vx)))
vint64m2_t vmin_vx_i64m2(vint64m2_t, int64_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vmin_vx_m)))
vint64m2_t vmin_vx_i64m2_m(vbool32_t, vint64m2_t, vint64m2_t, int64_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vmin_vx)))
vint64m4_t vmin_vx_i64m4(vint64m4_t, int64_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vmin_vx_m)))
vint64m4_t vmin_vx_i64m4_m(vbool16_t, vint64m4_t, vint64m4_t, int64_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vmin_vx)))
vint64m8_t vmin_vx_i64m8(vint64m8_t, int64_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vmin_vx_m)))
vint64m8_t vmin_vx_i64m8_m(vbool8_t, vint64m8_t, vint64m8_t, int64_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vmaxu_vv)))
vuint64m1_t vmaxu_vv_u64m1(vuint64m1_t, vuint64m1_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vmaxu_vv_m)))
vuint64m1_t vmaxu_vv_u64m1_m(vbool64_t, vuint64m1_t, vuint64m1_t, vuint64m1_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vmaxu_vv)))
vuint64m2_t vmaxu_vv_u64m2(vuint64m2_t, vuint64m2_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vmaxu_vv_m)))
vuint64m2_t vmaxu_vv_u64m2_m(vbool32_t, vuint64m2_t, vuint64m2_t, vuint64m2_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vmaxu_vv)))
vuint64m4_t vmaxu_vv_u64m4(vuint64m4_t, vuint64m4_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vmaxu_vv_m)))
vuint64m4_t vmaxu_vv_u64m4_m(vbool16_t, vuint64m4_t, vuint64m4_t, vuint64m4_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vmaxu_vv)))
vuint64m8_t vmaxu_vv_u64m8(vuint64m8_t, vuint64m8_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vmaxu_vv_m)))
vuint64m8_t vmaxu_vv_u64m8_m(vbool8_t, vuint64m8_t, vuint64m8_t, vuint64m8_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vmaxu_vx)))
vuint64m1_t vmaxu_vx_u64m1(vuint64m1_t, uint64_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vmaxu_vx_m)))
vuint64m1_t vmaxu_vx_u64m1_m(vbool64_t, vuint64m1_t, vuint64m1_t, uint64_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vmaxu_vx)))
vuint64m2_t vmaxu_vx_u64m2(vuint64m2_t, uint64_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vmaxu_vx_m)))
vuint64m2_t vmaxu_vx_u64m2_m(vbool32_t, vuint64m2_t, vuint64m2_t, uint64_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vmaxu_vx)))
vuint64m4_t vmaxu_vx_u64m4(vuint64m4_t, uint64_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vmaxu_vx_m)))
vuint64m4_t vmaxu_vx_u64m4_m(vbool16_t, vuint64m4_t, vuint64m4_t, uint64_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vmaxu_vx)))
vuint64m8_t vmaxu_vx_u64m8(vuint64m8_t, uint64_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vmaxu_vx_m)))
vuint64m8_t vmaxu_vx_u64m8_m(vbool8_t, vuint64m8_t, vuint64m8_t, uint64_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vmax_vv)))
vint64m1_t vmax_vv_i64m1(vint64m1_t, vint64m1_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vmax_vv_m)))
vint64m1_t vmax_vv_i64m1_m(vbool64_t, vint64m1_t, vint64m1_t, vint64m1_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vmax_vv)))
vint64m2_t vmax_vv_i64m2(vint64m2_t, vint64m2_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vmax_vv_m)))
vint64m2_t vmax_vv_i64m2_m(vbool32_t, vint64m2_t, vint64m2_t, vint64m2_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vmax_vv)))
vint64m4_t vmax_vv_i64m4(vint64m4_t, vint64m4_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vmax_vv_m)))
vint64m4_t vmax_vv_i64m4_m(vbool16_t, vint64m4_t, vint64m4_t, vint64m4_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vmax_vv)))
vint64m8_t vmax_vv_i64m8(vint64m8_t, vint64m8_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vmax_vv_m)))
vint64m8_t vmax_vv_i64m8_m(vbool8_t, vint64m8_t, vint64m8_t, vint64m8_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vmax_vx)))
vint64m1_t vmax_vx_i64m1(vint64m1_t, int64_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vmax_vx_m)))
vint64m1_t vmax_vx_i64m1_m(vbool64_t, vint64m1_t, vint64m1_t, int64_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vmax_vx)))
vint64m2_t vmax_vx_i64m2(vint64m2_t, int64_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vmax_vx_m)))
vint64m2_t vmax_vx_i64m2_m(vbool32_t, vint64m2_t, vint64m2_t, int64_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vmax_vx)))
vint64m4_t vmax_vx_i64m4(vint64m4_t, int64_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vmax_vx_m)))
vint64m4_t vmax_vx_i64m4_m(vbool16_t, vint64m4_t, vint64m4_t, int64_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vmax_vx)))
vint64m8_t vmax_vx_i64m8(vint64m8_t, int64_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vmax_vx_m)))
vint64m8_t vmax_vx_i64m8_m(vbool8_t, vint64m8_t, vint64m8_t, int64_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vmul_vv)))
vint64m1_t vmul_vv_i64m1(vint64m1_t, vint64m1_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vmul_vv_m)))
vint64m1_t vmul_vv_i64m1_m(vbool64_t, vint64m1_t, vint64m1_t, vint64m1_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vmul_vv)))
vint64m2_t vmul_vv_i64m2(vint64m2_t, vint64m2_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vmul_vv_m)))
vint64m2_t vmul_vv_i64m2_m(vbool32_t, vint64m2_t, vint64m2_t, vint64m2_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vmul_vv)))
vint64m4_t vmul_vv_i64m4(vint64m4_t, vint64m4_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vmul_vv_m)))
vint64m4_t vmul_vv_i64m4_m(vbool16_t, vint64m4_t, vint64m4_t, vint64m4_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vmul_vv)))
vint64m8_t vmul_vv_i64m8(vint64m8_t, vint64m8_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vmul_vv_m)))
vint64m8_t vmul_vv_i64m8_m(vbool8_t, vint64m8_t, vint64m8_t, vint64m8_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vmul_vx)))
vint64m1_t vmul_vx_i64m1(vint64m1_t, int64_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vmul_vx_m)))
vint64m1_t vmul_vx_i64m1_m(vbool64_t, vint64m1_t, vint64m1_t, int64_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vmul_vx)))
vint64m2_t vmul_vx_i64m2(vint64m2_t, int64_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vmul_vx_m)))
vint64m2_t vmul_vx_i64m2_m(vbool32_t, vint64m2_t, vint64m2_t, int64_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vmul_vx)))
vint64m4_t vmul_vx_i64m4(vint64m4_t, int64_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vmul_vx_m)))
vint64m4_t vmul_vx_i64m4_m(vbool16_t, vint64m4_t, vint64m4_t, int64_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vmul_vx)))
vint64m8_t vmul_vx_i64m8(vint64m8_t, int64_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vmul_vx_m)))
vint64m8_t vmul_vx_i64m8_m(vbool8_t, vint64m8_t, vint64m8_t, int64_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vmul_vv)))
vuint64m1_t vmul_vv_u64m1(vuint64m1_t, vuint64m1_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vmul_vv_m)))
vuint64m1_t vmul_vv_u64m1_m(vbool64_t, vuint64m1_t, vuint64m1_t, vuint64m1_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vmul_vv)))
vuint64m2_t vmul_vv_u64m2(vuint64m2_t, vuint64m2_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vmul_vv_m)))
vuint64m2_t vmul_vv_u64m2_m(vbool32_t, vuint64m2_t, vuint64m2_t, vuint64m2_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vmul_vv)))
vuint64m4_t vmul_vv_u64m4(vuint64m4_t, vuint64m4_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vmul_vv_m)))
vuint64m4_t vmul_vv_u64m4_m(vbool16_t, vuint64m4_t, vuint64m4_t, vuint64m4_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vmul_vv)))
vuint64m8_t vmul_vv_u64m8(vuint64m8_t, vuint64m8_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vmul_vv_m)))
vuint64m8_t vmul_vv_u64m8_m(vbool8_t, vuint64m8_t, vuint64m8_t, vuint64m8_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vmul_vx)))
vuint64m1_t vmul_vx_u64m1(vuint64m1_t, uint64_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vmul_vx_m)))
vuint64m1_t vmul_vx_u64m1_m(vbool64_t, vuint64m1_t, vuint64m1_t, uint64_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vmul_vx)))
vuint64m2_t vmul_vx_u64m2(vuint64m2_t, uint64_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vmul_vx_m)))
vuint64m2_t vmul_vx_u64m2_m(vbool32_t, vuint64m2_t, vuint64m2_t, uint64_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vmul_vx)))
vuint64m4_t vmul_vx_u64m4(vuint64m4_t, uint64_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vmul_vx_m)))
vuint64m4_t vmul_vx_u64m4_m(vbool16_t, vuint64m4_t, vuint64m4_t, uint64_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vmul_vx)))
vuint64m8_t vmul_vx_u64m8(vuint64m8_t, uint64_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vmul_vx_m)))
vuint64m8_t vmul_vx_u64m8_m(vbool8_t, vuint64m8_t, vuint64m8_t, uint64_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vdivu_vv)))
vuint64m1_t vdivu_vv_u64m1(vuint64m1_t, vuint64m1_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vdivu_vv_m)))
vuint64m1_t vdivu_vv_u64m1_m(vbool64_t, vuint64m1_t, vuint64m1_t, vuint64m1_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vdivu_vv)))
vuint64m2_t vdivu_vv_u64m2(vuint64m2_t, vuint64m2_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vdivu_vv_m)))
vuint64m2_t vdivu_vv_u64m2_m(vbool32_t, vuint64m2_t, vuint64m2_t, vuint64m2_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vdivu_vv)))
vuint64m4_t vdivu_vv_u64m4(vuint64m4_t, vuint64m4_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vdivu_vv_m)))
vuint64m4_t vdivu_vv_u64m4_m(vbool16_t, vuint64m4_t, vuint64m4_t, vuint64m4_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vdivu_vv)))
vuint64m8_t vdivu_vv_u64m8(vuint64m8_t, vuint64m8_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vdivu_vv_m)))
vuint64m8_t vdivu_vv_u64m8_m(vbool8_t, vuint64m8_t, vuint64m8_t, vuint64m8_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vdivu_vx)))
vuint64m1_t vdivu_vx_u64m1(vuint64m1_t, uint64_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vdivu_vx_m)))
vuint64m1_t vdivu_vx_u64m1_m(vbool64_t, vuint64m1_t, vuint64m1_t, uint64_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vdivu_vx)))
vuint64m2_t vdivu_vx_u64m2(vuint64m2_t, uint64_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vdivu_vx_m)))
vuint64m2_t vdivu_vx_u64m2_m(vbool32_t, vuint64m2_t, vuint64m2_t, uint64_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vdivu_vx)))
vuint64m4_t vdivu_vx_u64m4(vuint64m4_t, uint64_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vdivu_vx_m)))
vuint64m4_t vdivu_vx_u64m4_m(vbool16_t, vuint64m4_t, vuint64m4_t, uint64_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vdivu_vx)))
vuint64m8_t vdivu_vx_u64m8(vuint64m8_t, uint64_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vdivu_vx_m)))
vuint64m8_t vdivu_vx_u64m8_m(vbool8_t, vuint64m8_t, vuint64m8_t, uint64_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vdiv_vv)))
vint64m1_t vdiv_vv_i64m1(vint64m1_t, vint64m1_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vdiv_vv_m)))
vint64m1_t vdiv_vv_i64m1_m(vbool64_t, vint64m1_t, vint64m1_t, vint64m1_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vdiv_vv)))
vint64m2_t vdiv_vv_i64m2(vint64m2_t, vint64m2_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vdiv_vv_m)))
vint64m2_t vdiv_vv_i64m2_m(vbool32_t, vint64m2_t, vint64m2_t, vint64m2_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vdiv_vv)))
vint64m4_t vdiv_vv_i64m4(vint64m4_t, vint64m4_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vdiv_vv_m)))
vint64m4_t vdiv_vv_i64m4_m(vbool16_t, vint64m4_t, vint64m4_t, vint64m4_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vdiv_vv)))
vint64m8_t vdiv_vv_i64m8(vint64m8_t, vint64m8_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vdiv_vv_m)))
vint64m8_t vdiv_vv_i64m8_m(vbool8_t, vint64m8_t, vint64m8_t, vint64m8_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vdiv_vx)))
vint64m1_t vdiv_vx_i64m1(vint64m1_t, int64_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vdiv_vx_m)))
vint64m1_t vdiv_vx_i64m1_m(vbool64_t, vint64m1_t, vint64m1_t, int64_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vdiv_vx)))
vint64m2_t vdiv_vx_i64m2(vint64m2_t, int64_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vdiv_vx_m)))
vint64m2_t vdiv_vx_i64m2_m(vbool32_t, vint64m2_t, vint64m2_t, int64_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vdiv_vx)))
vint64m4_t vdiv_vx_i64m4(vint64m4_t, int64_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vdiv_vx_m)))
vint64m4_t vdiv_vx_i64m4_m(vbool16_t, vint64m4_t, vint64m4_t, int64_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vdiv_vx)))
vint64m8_t vdiv_vx_i64m8(vint64m8_t, int64_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vdiv_vx_m)))
vint64m8_t vdiv_vx_i64m8_m(vbool8_t, vint64m8_t, vint64m8_t, int64_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vremu_vv)))
vuint64m1_t vremu_vv_u64m1(vuint64m1_t, vuint64m1_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vremu_vv_m)))
vuint64m1_t vremu_vv_u64m1_m(vbool64_t, vuint64m1_t, vuint64m1_t, vuint64m1_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vremu_vv)))
vuint64m2_t vremu_vv_u64m2(vuint64m2_t, vuint64m2_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vremu_vv_m)))
vuint64m2_t vremu_vv_u64m2_m(vbool32_t, vuint64m2_t, vuint64m2_t, vuint64m2_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vremu_vv)))
vuint64m4_t vremu_vv_u64m4(vuint64m4_t, vuint64m4_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vremu_vv_m)))
vuint64m4_t vremu_vv_u64m4_m(vbool16_t, vuint64m4_t, vuint64m4_t, vuint64m4_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vremu_vv)))
vuint64m8_t vremu_vv_u64m8(vuint64m8_t, vuint64m8_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vremu_vv_m)))
vuint64m8_t vremu_vv_u64m8_m(vbool8_t, vuint64m8_t, vuint64m8_t, vuint64m8_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vremu_vx)))
vuint64m1_t vremu_vx_u64m1(vuint64m1_t, uint64_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vremu_vx_m)))
vuint64m1_t vremu_vx_u64m1_m(vbool64_t, vuint64m1_t, vuint64m1_t, uint64_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vremu_vx)))
vuint64m2_t vremu_vx_u64m2(vuint64m2_t, uint64_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vremu_vx_m)))
vuint64m2_t vremu_vx_u64m2_m(vbool32_t, vuint64m2_t, vuint64m2_t, uint64_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vremu_vx)))
vuint64m4_t vremu_vx_u64m4(vuint64m4_t, uint64_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vremu_vx_m)))
vuint64m4_t vremu_vx_u64m4_m(vbool16_t, vuint64m4_t, vuint64m4_t, uint64_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vremu_vx)))
vuint64m8_t vremu_vx_u64m8(vuint64m8_t, uint64_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vremu_vx_m)))
vuint64m8_t vremu_vx_u64m8_m(vbool8_t, vuint64m8_t, vuint64m8_t, uint64_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vrem_vv)))
vint64m1_t vrem_vv_i64m1(vint64m1_t, vint64m1_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vrem_vv_m)))
vint64m1_t vrem_vv_i64m1_m(vbool64_t, vint64m1_t, vint64m1_t, vint64m1_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vrem_vv)))
vint64m2_t vrem_vv_i64m2(vint64m2_t, vint64m2_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vrem_vv_m)))
vint64m2_t vrem_vv_i64m2_m(vbool32_t, vint64m2_t, vint64m2_t, vint64m2_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vrem_vv)))
vint64m4_t vrem_vv_i64m4(vint64m4_t, vint64m4_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vrem_vv_m)))
vint64m4_t vrem_vv_i64m4_m(vbool16_t, vint64m4_t, vint64m4_t, vint64m4_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vrem_vv)))
vint64m8_t vrem_vv_i64m8(vint64m8_t, vint64m8_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vrem_vv_m)))
vint64m8_t vrem_vv_i64m8_m(vbool8_t, vint64m8_t, vint64m8_t, vint64m8_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vrem_vx)))
vint64m1_t vrem_vx_i64m1(vint64m1_t, int64_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vrem_vx_m)))
vint64m1_t vrem_vx_i64m1_m(vbool64_t, vint64m1_t, vint64m1_t, int64_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vrem_vx)))
vint64m2_t vrem_vx_i64m2(vint64m2_t, int64_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vrem_vx_m)))
vint64m2_t vrem_vx_i64m2_m(vbool32_t, vint64m2_t, vint64m2_t, int64_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vrem_vx)))
vint64m4_t vrem_vx_i64m4(vint64m4_t, int64_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vrem_vx_m)))
vint64m4_t vrem_vx_i64m4_m(vbool16_t, vint64m4_t, vint64m4_t, int64_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vrem_vx)))
vint64m8_t vrem_vx_i64m8(vint64m8_t, int64_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vrem_vx_m)))
vint64m8_t vrem_vx_i64m8_m(vbool8_t, vint64m8_t, vint64m8_t, int64_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vwmul_vv)))
vint64m1_t vwmul_vv_i64m1(vint32mf2_t, vint32mf2_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vwmul_vv_m)))
vint64m1_t vwmul_vv_i64m1_m(vbool64_t, vint64m1_t, vint32mf2_t, vint32mf2_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vwmul_vv)))
vint64m2_t vwmul_vv_i64m2(vint32m1_t, vint32m1_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vwmul_vv_m)))
vint64m2_t vwmul_vv_i64m2_m(vbool32_t, vint64m2_t, vint32m1_t, vint32m1_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vwmul_vv)))
vint64m4_t vwmul_vv_i64m4(vint32m2_t, vint32m2_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vwmul_vv_m)))
vint64m4_t vwmul_vv_i64m4_m(vbool16_t, vint64m4_t, vint32m2_t, vint32m2_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vwmul_vv)))
vint64m8_t vwmul_vv_i64m8(vint32m4_t, vint32m4_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vwmul_vv_m)))
vint64m8_t vwmul_vv_i64m8_m(vbool8_t, vint64m8_t, vint32m4_t, vint32m4_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vwmul_vx)))
vint64m1_t vwmul_vx_i64m1(vint32mf2_t, int32_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vwmul_vx_m)))
vint64m1_t vwmul_vx_i64m1_m(vbool64_t, vint64m1_t, vint32mf2_t, int32_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vwmul_vx)))
vint64m2_t vwmul_vx_i64m2(vint32m1_t, int32_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vwmul_vx_m)))
vint64m2_t vwmul_vx_i64m2_m(vbool32_t, vint64m2_t, vint32m1_t, int32_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vwmul_vx)))
vint64m4_t vwmul_vx_i64m4(vint32m2_t, int32_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vwmul_vx_m)))
vint64m4_t vwmul_vx_i64m4_m(vbool16_t, vint64m4_t, vint32m2_t, int32_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vwmul_vx)))
vint64m8_t vwmul_vx_i64m8(vint32m4_t, int32_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vwmul_vx_m)))
vint64m8_t vwmul_vx_i64m8_m(vbool8_t, vint64m8_t, vint32m4_t, int32_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vwmulu_vv)))
vuint64m1_t vwmulu_vv_u64m1(vuint32mf2_t, vuint32mf2_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vwmulu_vv_m)))
vuint64m1_t vwmulu_vv_u64m1_m(vbool64_t, vuint64m1_t, vuint32mf2_t, vuint32mf2_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vwmulu_vv)))
vuint64m2_t vwmulu_vv_u64m2(vuint32m1_t, vuint32m1_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vwmulu_vv_m)))
vuint64m2_t vwmulu_vv_u64m2_m(vbool32_t, vuint64m2_t, vuint32m1_t, vuint32m1_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vwmulu_vv)))
vuint64m4_t vwmulu_vv_u64m4(vuint32m2_t, vuint32m2_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vwmulu_vv_m)))
vuint64m4_t vwmulu_vv_u64m4_m(vbool16_t, vuint64m4_t, vuint32m2_t, vuint32m2_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vwmulu_vv)))
vuint64m8_t vwmulu_vv_u64m8(vuint32m4_t, vuint32m4_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vwmulu_vv_m)))
vuint64m8_t vwmulu_vv_u64m8_m(vbool8_t, vuint64m8_t, vuint32m4_t, vuint32m4_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vwmulu_vx)))
vuint64m1_t vwmulu_vx_u64m1(vuint32mf2_t, uint32_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vwmulu_vx_m)))
vuint64m1_t vwmulu_vx_u64m1_m(vbool64_t, vuint64m1_t, vuint32mf2_t, uint32_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vwmulu_vx)))
vuint64m2_t vwmulu_vx_u64m2(vuint32m1_t, uint32_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vwmulu_vx_m)))
vuint64m2_t vwmulu_vx_u64m2_m(vbool32_t, vuint64m2_t, vuint32m1_t, uint32_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vwmulu_vx)))
vuint64m4_t vwmulu_vx_u64m4(vuint32m2_t, uint32_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vwmulu_vx_m)))
vuint64m4_t vwmulu_vx_u64m4_m(vbool16_t, vuint64m4_t, vuint32m2_t, uint32_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vwmulu_vx)))
vuint64m8_t vwmulu_vx_u64m8(vuint32m4_t, uint32_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vwmulu_vx_m)))
vuint64m8_t vwmulu_vx_u64m8_m(vbool8_t, vuint64m8_t, vuint32m4_t, uint32_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vwmulsu_vv)))
vint64m1_t vwmulsu_vv_i64m1(vint32mf2_t, vuint32mf2_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vwmulsu_vv_m)))
vint64m1_t vwmulsu_vv_i64m1_m(vbool64_t, vint64m1_t, vint32mf2_t, vuint32mf2_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vwmulsu_vv)))
vint64m2_t vwmulsu_vv_i64m2(vint32m1_t, vuint32m1_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vwmulsu_vv_m)))
vint64m2_t vwmulsu_vv_i64m2_m(vbool32_t, vint64m2_t, vint32m1_t, vuint32m1_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vwmulsu_vv)))
vint64m4_t vwmulsu_vv_i64m4(vint32m2_t, vuint32m2_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vwmulsu_vv_m)))
vint64m4_t vwmulsu_vv_i64m4_m(vbool16_t, vint64m4_t, vint32m2_t, vuint32m2_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vwmulsu_vv)))
vint64m8_t vwmulsu_vv_i64m8(vint32m4_t, vuint32m4_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vwmulsu_vv_m)))
vint64m8_t vwmulsu_vv_i64m8_m(vbool8_t, vint64m8_t, vint32m4_t, vuint32m4_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vwmulsu_vx)))
vint64m1_t vwmulsu_vx_i64m1(vint32mf2_t, uint32_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vwmulsu_vx_m)))
vint64m1_t vwmulsu_vx_i64m1_m(vbool64_t, vint64m1_t, vint32mf2_t, uint32_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vwmulsu_vx)))
vint64m2_t vwmulsu_vx_i64m2(vint32m1_t, uint32_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vwmulsu_vx_m)))
vint64m2_t vwmulsu_vx_i64m2_m(vbool32_t, vint64m2_t, vint32m1_t, uint32_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vwmulsu_vx)))
vint64m4_t vwmulsu_vx_i64m4(vint32m2_t, uint32_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vwmulsu_vx_m)))
vint64m4_t vwmulsu_vx_i64m4_m(vbool16_t, vint64m4_t, vint32m2_t, uint32_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vwmulsu_vx)))
vint64m8_t vwmulsu_vx_i64m8(vint32m4_t, uint32_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vwmulsu_vx_m)))
vint64m8_t vwmulsu_vx_i64m8_m(vbool8_t, vint64m8_t, vint32m4_t, uint32_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vmacc_vv)))
vint64m1_t vmacc_vv_i64m1(vint64m1_t, vint64m1_t, vint64m1_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vmacc_vv_m)))
vint64m1_t vmacc_vv_i64m1_m(vbool64_t, vint64m1_t, vint64m1_t, vint64m1_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vmacc_vv)))
vint64m2_t vmacc_vv_i64m2(vint64m2_t, vint64m2_t, vint64m2_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vmacc_vv_m)))
vint64m2_t vmacc_vv_i64m2_m(vbool32_t, vint64m2_t, vint64m2_t, vint64m2_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vmacc_vv)))
vint64m4_t vmacc_vv_i64m4(vint64m4_t, vint64m4_t, vint64m4_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vmacc_vv_m)))
vint64m4_t vmacc_vv_i64m4_m(vbool16_t, vint64m4_t, vint64m4_t, vint64m4_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vmacc_vv)))
vint64m8_t vmacc_vv_i64m8(vint64m8_t, vint64m8_t, vint64m8_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vmacc_vv_m)))
vint64m8_t vmacc_vv_i64m8_m(vbool8_t, vint64m8_t, vint64m8_t, vint64m8_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vmacc_vx)))
vint64m1_t vmacc_vx_i64m1(vint64m1_t, int64_t, vint64m1_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vmacc_vx_m)))
vint64m1_t vmacc_vx_i64m1_m(vbool64_t, vint64m1_t, int64_t, vint64m1_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vmacc_vx)))
vint64m2_t vmacc_vx_i64m2(vint64m2_t, int64_t, vint64m2_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vmacc_vx_m)))
vint64m2_t vmacc_vx_i64m2_m(vbool32_t, vint64m2_t, int64_t, vint64m2_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vmacc_vx)))
vint64m4_t vmacc_vx_i64m4(vint64m4_t, int64_t, vint64m4_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vmacc_vx_m)))
vint64m4_t vmacc_vx_i64m4_m(vbool16_t, vint64m4_t, int64_t, vint64m4_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vmacc_vx)))
vint64m8_t vmacc_vx_i64m8(vint64m8_t, int64_t, vint64m8_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vmacc_vx_m)))
vint64m8_t vmacc_vx_i64m8_m(vbool8_t, vint64m8_t, int64_t, vint64m8_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vmacc_vv)))
vuint64m1_t vmacc_vv_u64m1(vuint64m1_t, vuint64m1_t, vuint64m1_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vmacc_vv_m)))
vuint64m1_t vmacc_vv_u64m1_m(vbool64_t, vuint64m1_t, vuint64m1_t, vuint64m1_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vmacc_vv)))
vuint64m2_t vmacc_vv_u64m2(vuint64m2_t, vuint64m2_t, vuint64m2_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vmacc_vv_m)))
vuint64m2_t vmacc_vv_u64m2_m(vbool32_t, vuint64m2_t, vuint64m2_t, vuint64m2_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vmacc_vv)))
vuint64m4_t vmacc_vv_u64m4(vuint64m4_t, vuint64m4_t, vuint64m4_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vmacc_vv_m)))
vuint64m4_t vmacc_vv_u64m4_m(vbool16_t, vuint64m4_t, vuint64m4_t, vuint64m4_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vmacc_vv)))
vuint64m8_t vmacc_vv_u64m8(vuint64m8_t, vuint64m8_t, vuint64m8_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vmacc_vv_m)))
vuint64m8_t vmacc_vv_u64m8_m(vbool8_t, vuint64m8_t, vuint64m8_t, vuint64m8_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vmacc_vx)))
vuint64m1_t vmacc_vx_u64m1(vuint64m1_t, uint64_t, vuint64m1_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vmacc_vx_m)))
vuint64m1_t vmacc_vx_u64m1_m(vbool64_t, vuint64m1_t, uint64_t, vuint64m1_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vmacc_vx)))
vuint64m2_t vmacc_vx_u64m2(vuint64m2_t, uint64_t, vuint64m2_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vmacc_vx_m)))
vuint64m2_t vmacc_vx_u64m2_m(vbool32_t, vuint64m2_t, uint64_t, vuint64m2_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vmacc_vx)))
vuint64m4_t vmacc_vx_u64m4(vuint64m4_t, uint64_t, vuint64m4_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vmacc_vx_m)))
vuint64m4_t vmacc_vx_u64m4_m(vbool16_t, vuint64m4_t, uint64_t, vuint64m4_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vmacc_vx)))
vuint64m8_t vmacc_vx_u64m8(vuint64m8_t, uint64_t, vuint64m8_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vmacc_vx_m)))
vuint64m8_t vmacc_vx_u64m8_m(vbool8_t, vuint64m8_t, uint64_t, vuint64m8_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vnmsac_vv)))
vint64m1_t vnmsac_vv_i64m1(vint64m1_t, vint64m1_t, vint64m1_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vnmsac_vv_m)))
vint64m1_t vnmsac_vv_i64m1_m(vbool64_t, vint64m1_t, vint64m1_t, vint64m1_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vnmsac_vv)))
vint64m2_t vnmsac_vv_i64m2(vint64m2_t, vint64m2_t, vint64m2_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vnmsac_vv_m)))
vint64m2_t vnmsac_vv_i64m2_m(vbool32_t, vint64m2_t, vint64m2_t, vint64m2_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vnmsac_vv)))
vint64m4_t vnmsac_vv_i64m4(vint64m4_t, vint64m4_t, vint64m4_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vnmsac_vv_m)))
vint64m4_t vnmsac_vv_i64m4_m(vbool16_t, vint64m4_t, vint64m4_t, vint64m4_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vnmsac_vv)))
vint64m8_t vnmsac_vv_i64m8(vint64m8_t, vint64m8_t, vint64m8_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vnmsac_vv_m)))
vint64m8_t vnmsac_vv_i64m8_m(vbool8_t, vint64m8_t, vint64m8_t, vint64m8_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vnmsac_vx)))
vint64m1_t vnmsac_vx_i64m1(vint64m1_t, int64_t, vint64m1_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vnmsac_vx_m)))
vint64m1_t vnmsac_vx_i64m1_m(vbool64_t, vint64m1_t, int64_t, vint64m1_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vnmsac_vx)))
vint64m2_t vnmsac_vx_i64m2(vint64m2_t, int64_t, vint64m2_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vnmsac_vx_m)))
vint64m2_t vnmsac_vx_i64m2_m(vbool32_t, vint64m2_t, int64_t, vint64m2_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vnmsac_vx)))
vint64m4_t vnmsac_vx_i64m4(vint64m4_t, int64_t, vint64m4_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vnmsac_vx_m)))
vint64m4_t vnmsac_vx_i64m4_m(vbool16_t, vint64m4_t, int64_t, vint64m4_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vnmsac_vx)))
vint64m8_t vnmsac_vx_i64m8(vint64m8_t, int64_t, vint64m8_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vnmsac_vx_m)))
vint64m8_t vnmsac_vx_i64m8_m(vbool8_t, vint64m8_t, int64_t, vint64m8_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vnmsac_vv)))
vuint64m1_t vnmsac_vv_u64m1(vuint64m1_t, vuint64m1_t, vuint64m1_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vnmsac_vv_m)))
vuint64m1_t vnmsac_vv_u64m1_m(vbool64_t, vuint64m1_t, vuint64m1_t, vuint64m1_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vnmsac_vv)))
vuint64m2_t vnmsac_vv_u64m2(vuint64m2_t, vuint64m2_t, vuint64m2_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vnmsac_vv_m)))
vuint64m2_t vnmsac_vv_u64m2_m(vbool32_t, vuint64m2_t, vuint64m2_t, vuint64m2_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vnmsac_vv)))
vuint64m4_t vnmsac_vv_u64m4(vuint64m4_t, vuint64m4_t, vuint64m4_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vnmsac_vv_m)))
vuint64m4_t vnmsac_vv_u64m4_m(vbool16_t, vuint64m4_t, vuint64m4_t, vuint64m4_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vnmsac_vv)))
vuint64m8_t vnmsac_vv_u64m8(vuint64m8_t, vuint64m8_t, vuint64m8_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vnmsac_vv_m)))
vuint64m8_t vnmsac_vv_u64m8_m(vbool8_t, vuint64m8_t, vuint64m8_t, vuint64m8_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vnmsac_vx)))
vuint64m1_t vnmsac_vx_u64m1(vuint64m1_t, uint64_t, vuint64m1_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vnmsac_vx_m)))
vuint64m1_t vnmsac_vx_u64m1_m(vbool64_t, vuint64m1_t, uint64_t, vuint64m1_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vnmsac_vx)))
vuint64m2_t vnmsac_vx_u64m2(vuint64m2_t, uint64_t, vuint64m2_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vnmsac_vx_m)))
vuint64m2_t vnmsac_vx_u64m2_m(vbool32_t, vuint64m2_t, uint64_t, vuint64m2_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vnmsac_vx)))
vuint64m4_t vnmsac_vx_u64m4(vuint64m4_t, uint64_t, vuint64m4_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vnmsac_vx_m)))
vuint64m4_t vnmsac_vx_u64m4_m(vbool16_t, vuint64m4_t, uint64_t, vuint64m4_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vnmsac_vx)))
vuint64m8_t vnmsac_vx_u64m8(vuint64m8_t, uint64_t, vuint64m8_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vnmsac_vx_m)))
vuint64m8_t vnmsac_vx_u64m8_m(vbool8_t, vuint64m8_t, uint64_t, vuint64m8_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vmadd_vv)))
vint64m1_t vmadd_vv_i64m1(vint64m1_t, vint64m1_t, vint64m1_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vmadd_vv_m)))
vint64m1_t vmadd_vv_i64m1_m(vbool64_t, vint64m1_t, vint64m1_t, vint64m1_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vmadd_vv)))
vint64m2_t vmadd_vv_i64m2(vint64m2_t, vint64m2_t, vint64m2_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vmadd_vv_m)))
vint64m2_t vmadd_vv_i64m2_m(vbool32_t, vint64m2_t, vint64m2_t, vint64m2_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vmadd_vv)))
vint64m4_t vmadd_vv_i64m4(vint64m4_t, vint64m4_t, vint64m4_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vmadd_vv_m)))
vint64m4_t vmadd_vv_i64m4_m(vbool16_t, vint64m4_t, vint64m4_t, vint64m4_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vmadd_vv)))
vint64m8_t vmadd_vv_i64m8(vint64m8_t, vint64m8_t, vint64m8_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vmadd_vv_m)))
vint64m8_t vmadd_vv_i64m8_m(vbool8_t, vint64m8_t, vint64m8_t, vint64m8_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vmadd_vx)))
vint64m1_t vmadd_vx_i64m1(vint64m1_t, int64_t, vint64m1_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vmadd_vx_m)))
vint64m1_t vmadd_vx_i64m1_m(vbool64_t, vint64m1_t, int64_t, vint64m1_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vmadd_vx)))
vint64m2_t vmadd_vx_i64m2(vint64m2_t, int64_t, vint64m2_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vmadd_vx_m)))
vint64m2_t vmadd_vx_i64m2_m(vbool32_t, vint64m2_t, int64_t, vint64m2_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vmadd_vx)))
vint64m4_t vmadd_vx_i64m4(vint64m4_t, int64_t, vint64m4_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vmadd_vx_m)))
vint64m4_t vmadd_vx_i64m4_m(vbool16_t, vint64m4_t, int64_t, vint64m4_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vmadd_vx)))
vint64m8_t vmadd_vx_i64m8(vint64m8_t, int64_t, vint64m8_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vmadd_vx_m)))
vint64m8_t vmadd_vx_i64m8_m(vbool8_t, vint64m8_t, int64_t, vint64m8_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vmadd_vv)))
vuint64m1_t vmadd_vv_u64m1(vuint64m1_t, vuint64m1_t, vuint64m1_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vmadd_vv_m)))
vuint64m1_t vmadd_vv_u64m1_m(vbool64_t, vuint64m1_t, vuint64m1_t, vuint64m1_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vmadd_vv)))
vuint64m2_t vmadd_vv_u64m2(vuint64m2_t, vuint64m2_t, vuint64m2_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vmadd_vv_m)))
vuint64m2_t vmadd_vv_u64m2_m(vbool32_t, vuint64m2_t, vuint64m2_t, vuint64m2_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vmadd_vv)))
vuint64m4_t vmadd_vv_u64m4(vuint64m4_t, vuint64m4_t, vuint64m4_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vmadd_vv_m)))
vuint64m4_t vmadd_vv_u64m4_m(vbool16_t, vuint64m4_t, vuint64m4_t, vuint64m4_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vmadd_vv)))
vuint64m8_t vmadd_vv_u64m8(vuint64m8_t, vuint64m8_t, vuint64m8_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vmadd_vv_m)))
vuint64m8_t vmadd_vv_u64m8_m(vbool8_t, vuint64m8_t, vuint64m8_t, vuint64m8_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vmadd_vx)))
vuint64m1_t vmadd_vx_u64m1(vuint64m1_t, uint64_t, vuint64m1_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vmadd_vx_m)))
vuint64m1_t vmadd_vx_u64m1_m(vbool64_t, vuint64m1_t, uint64_t, vuint64m1_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vmadd_vx)))
vuint64m2_t vmadd_vx_u64m2(vuint64m2_t, uint64_t, vuint64m2_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vmadd_vx_m)))
vuint64m2_t vmadd_vx_u64m2_m(vbool32_t, vuint64m2_t, uint64_t, vuint64m2_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vmadd_vx)))
vuint64m4_t vmadd_vx_u64m4(vuint64m4_t, uint64_t, vuint64m4_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vmadd_vx_m)))
vuint64m4_t vmadd_vx_u64m4_m(vbool16_t, vuint64m4_t, uint64_t, vuint64m4_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vmadd_vx)))
vuint64m8_t vmadd_vx_u64m8(vuint64m8_t, uint64_t, vuint64m8_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vmadd_vx_m)))
vuint64m8_t vmadd_vx_u64m8_m(vbool8_t, vuint64m8_t, uint64_t, vuint64m8_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vnmsub_vv)))
vint64m1_t vnmsub_vv_i64m1(vint64m1_t, vint64m1_t, vint64m1_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vnmsub_vv_m)))
vint64m1_t vnmsub_vv_i64m1_m(vbool64_t, vint64m1_t, vint64m1_t, vint64m1_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vnmsub_vv)))
vint64m2_t vnmsub_vv_i64m2(vint64m2_t, vint64m2_t, vint64m2_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vnmsub_vv_m)))
vint64m2_t vnmsub_vv_i64m2_m(vbool32_t, vint64m2_t, vint64m2_t, vint64m2_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vnmsub_vv)))
vint64m4_t vnmsub_vv_i64m4(vint64m4_t, vint64m4_t, vint64m4_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vnmsub_vv_m)))
vint64m4_t vnmsub_vv_i64m4_m(vbool16_t, vint64m4_t, vint64m4_t, vint64m4_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vnmsub_vv)))
vint64m8_t vnmsub_vv_i64m8(vint64m8_t, vint64m8_t, vint64m8_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vnmsub_vv_m)))
vint64m8_t vnmsub_vv_i64m8_m(vbool8_t, vint64m8_t, vint64m8_t, vint64m8_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vnmsub_vx)))
vint64m1_t vnmsub_vx_i64m1(vint64m1_t, int64_t, vint64m1_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vnmsub_vx_m)))
vint64m1_t vnmsub_vx_i64m1_m(vbool64_t, vint64m1_t, int64_t, vint64m1_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vnmsub_vx)))
vint64m2_t vnmsub_vx_i64m2(vint64m2_t, int64_t, vint64m2_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vnmsub_vx_m)))
vint64m2_t vnmsub_vx_i64m2_m(vbool32_t, vint64m2_t, int64_t, vint64m2_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vnmsub_vx)))
vint64m4_t vnmsub_vx_i64m4(vint64m4_t, int64_t, vint64m4_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vnmsub_vx_m)))
vint64m4_t vnmsub_vx_i64m4_m(vbool16_t, vint64m4_t, int64_t, vint64m4_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vnmsub_vx)))
vint64m8_t vnmsub_vx_i64m8(vint64m8_t, int64_t, vint64m8_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vnmsub_vx_m)))
vint64m8_t vnmsub_vx_i64m8_m(vbool8_t, vint64m8_t, int64_t, vint64m8_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vnmsub_vv)))
vuint64m1_t vnmsub_vv_u64m1(vuint64m1_t, vuint64m1_t, vuint64m1_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vnmsub_vv_m)))
vuint64m1_t vnmsub_vv_u64m1_m(vbool64_t, vuint64m1_t, vuint64m1_t, vuint64m1_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vnmsub_vv)))
vuint64m2_t vnmsub_vv_u64m2(vuint64m2_t, vuint64m2_t, vuint64m2_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vnmsub_vv_m)))
vuint64m2_t vnmsub_vv_u64m2_m(vbool32_t, vuint64m2_t, vuint64m2_t, vuint64m2_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vnmsub_vv)))
vuint64m4_t vnmsub_vv_u64m4(vuint64m4_t, vuint64m4_t, vuint64m4_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vnmsub_vv_m)))
vuint64m4_t vnmsub_vv_u64m4_m(vbool16_t, vuint64m4_t, vuint64m4_t, vuint64m4_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vnmsub_vv)))
vuint64m8_t vnmsub_vv_u64m8(vuint64m8_t, vuint64m8_t, vuint64m8_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vnmsub_vv_m)))
vuint64m8_t vnmsub_vv_u64m8_m(vbool8_t, vuint64m8_t, vuint64m8_t, vuint64m8_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vnmsub_vx)))
vuint64m1_t vnmsub_vx_u64m1(vuint64m1_t, uint64_t, vuint64m1_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vnmsub_vx_m)))
vuint64m1_t vnmsub_vx_u64m1_m(vbool64_t, vuint64m1_t, uint64_t, vuint64m1_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vnmsub_vx)))
vuint64m2_t vnmsub_vx_u64m2(vuint64m2_t, uint64_t, vuint64m2_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vnmsub_vx_m)))
vuint64m2_t vnmsub_vx_u64m2_m(vbool32_t, vuint64m2_t, uint64_t, vuint64m2_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vnmsub_vx)))
vuint64m4_t vnmsub_vx_u64m4(vuint64m4_t, uint64_t, vuint64m4_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vnmsub_vx_m)))
vuint64m4_t vnmsub_vx_u64m4_m(vbool16_t, vuint64m4_t, uint64_t, vuint64m4_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vnmsub_vx)))
vuint64m8_t vnmsub_vx_u64m8(vuint64m8_t, uint64_t, vuint64m8_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vnmsub_vx_m)))
vuint64m8_t vnmsub_vx_u64m8_m(vbool8_t, vuint64m8_t, uint64_t, vuint64m8_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vwmaccu_vv)))
vuint64m1_t vwmaccu_vv_u64m1(vuint64m1_t, vuint32mf2_t, vuint32mf2_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vwmaccu_vv_m)))
vuint64m1_t vwmaccu_vv_u64m1_m(vbool64_t, vuint64m1_t, vuint32mf2_t, vuint32mf2_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vwmaccu_vv)))
vuint64m2_t vwmaccu_vv_u64m2(vuint64m2_t, vuint32m1_t, vuint32m1_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vwmaccu_vv_m)))
vuint64m2_t vwmaccu_vv_u64m2_m(vbool32_t, vuint64m2_t, vuint32m1_t, vuint32m1_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vwmaccu_vv)))
vuint64m4_t vwmaccu_vv_u64m4(vuint64m4_t, vuint32m2_t, vuint32m2_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vwmaccu_vv_m)))
vuint64m4_t vwmaccu_vv_u64m4_m(vbool16_t, vuint64m4_t, vuint32m2_t, vuint32m2_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vwmaccu_vv)))
vuint64m8_t vwmaccu_vv_u64m8(vuint64m8_t, vuint32m4_t, vuint32m4_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vwmaccu_vv_m)))
vuint64m8_t vwmaccu_vv_u64m8_m(vbool8_t, vuint64m8_t, vuint32m4_t, vuint32m4_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vwmaccu_vx)))
vuint64m1_t vwmaccu_vx_u64m1(vuint64m1_t, uint32_t, vuint32mf2_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vwmaccu_vx_m)))
vuint64m1_t vwmaccu_vx_u64m1_m(vbool64_t, vuint64m1_t, uint32_t, vuint32mf2_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vwmaccu_vx)))
vuint64m2_t vwmaccu_vx_u64m2(vuint64m2_t, uint32_t, vuint32m1_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vwmaccu_vx_m)))
vuint64m2_t vwmaccu_vx_u64m2_m(vbool32_t, vuint64m2_t, uint32_t, vuint32m1_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vwmaccu_vx)))
vuint64m4_t vwmaccu_vx_u64m4(vuint64m4_t, uint32_t, vuint32m2_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vwmaccu_vx_m)))
vuint64m4_t vwmaccu_vx_u64m4_m(vbool16_t, vuint64m4_t, uint32_t, vuint32m2_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vwmaccu_vx)))
vuint64m8_t vwmaccu_vx_u64m8(vuint64m8_t, uint32_t, vuint32m4_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vwmaccu_vx_m)))
vuint64m8_t vwmaccu_vx_u64m8_m(vbool8_t, vuint64m8_t, uint32_t, vuint32m4_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vwmacc_vv)))
vint64m1_t vwmacc_vv_i64m1(vint64m1_t, vint32mf2_t, vint32mf2_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vwmacc_vv_m)))
vint64m1_t vwmacc_vv_i64m1_m(vbool64_t, vint64m1_t, vint32mf2_t, vint32mf2_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vwmacc_vv)))
vint64m2_t vwmacc_vv_i64m2(vint64m2_t, vint32m1_t, vint32m1_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vwmacc_vv_m)))
vint64m2_t vwmacc_vv_i64m2_m(vbool32_t, vint64m2_t, vint32m1_t, vint32m1_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vwmacc_vv)))
vint64m4_t vwmacc_vv_i64m4(vint64m4_t, vint32m2_t, vint32m2_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vwmacc_vv_m)))
vint64m4_t vwmacc_vv_i64m4_m(vbool16_t, vint64m4_t, vint32m2_t, vint32m2_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vwmacc_vv)))
vint64m8_t vwmacc_vv_i64m8(vint64m8_t, vint32m4_t, vint32m4_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vwmacc_vv_m)))
vint64m8_t vwmacc_vv_i64m8_m(vbool8_t, vint64m8_t, vint32m4_t, vint32m4_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vwmacc_vx)))
vint64m1_t vwmacc_vx_i64m1(vint64m1_t, int32_t, vint32mf2_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vwmacc_vx_m)))
vint64m1_t vwmacc_vx_i64m1_m(vbool64_t, vint64m1_t, int32_t, vint32mf2_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vwmacc_vx)))
vint64m2_t vwmacc_vx_i64m2(vint64m2_t, int32_t, vint32m1_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vwmacc_vx_m)))
vint64m2_t vwmacc_vx_i64m2_m(vbool32_t, vint64m2_t, int32_t, vint32m1_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vwmacc_vx)))
vint64m4_t vwmacc_vx_i64m4(vint64m4_t, int32_t, vint32m2_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vwmacc_vx_m)))
vint64m4_t vwmacc_vx_i64m4_m(vbool16_t, vint64m4_t, int32_t, vint32m2_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vwmacc_vx)))
vint64m8_t vwmacc_vx_i64m8(vint64m8_t, int32_t, vint32m4_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vwmacc_vx_m)))
vint64m8_t vwmacc_vx_i64m8_m(vbool8_t, vint64m8_t, int32_t, vint32m4_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vwmaccsu_vv)))
vint64m1_t vwmaccsu_vv_i64m1(vint64m1_t, vint32mf2_t, vuint32mf2_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vwmaccsu_vv_m)))
vint64m1_t vwmaccsu_vv_i64m1_m(vbool64_t, vint64m1_t, vint32mf2_t, vuint32mf2_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vwmaccsu_vv)))
vint64m2_t vwmaccsu_vv_i64m2(vint64m2_t, vint32m1_t, vuint32m1_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vwmaccsu_vv_m)))
vint64m2_t vwmaccsu_vv_i64m2_m(vbool32_t, vint64m2_t, vint32m1_t, vuint32m1_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vwmaccsu_vv)))
vint64m4_t vwmaccsu_vv_i64m4(vint64m4_t, vint32m2_t, vuint32m2_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vwmaccsu_vv_m)))
vint64m4_t vwmaccsu_vv_i64m4_m(vbool16_t, vint64m4_t, vint32m2_t, vuint32m2_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vwmaccsu_vv)))
vint64m8_t vwmaccsu_vv_i64m8(vint64m8_t, vint32m4_t, vuint32m4_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vwmaccsu_vv_m)))
vint64m8_t vwmaccsu_vv_i64m8_m(vbool8_t, vint64m8_t, vint32m4_t, vuint32m4_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vwmaccsu_vx)))
vint64m1_t vwmaccsu_vx_i64m1(vint64m1_t, int32_t, vuint32mf2_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vwmaccsu_vx_m)))
vint64m1_t vwmaccsu_vx_i64m1_m(vbool64_t, vint64m1_t, int32_t, vuint32mf2_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vwmaccsu_vx)))
vint64m2_t vwmaccsu_vx_i64m2(vint64m2_t, int32_t, vuint32m1_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vwmaccsu_vx_m)))
vint64m2_t vwmaccsu_vx_i64m2_m(vbool32_t, vint64m2_t, int32_t, vuint32m1_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vwmaccsu_vx)))
vint64m4_t vwmaccsu_vx_i64m4(vint64m4_t, int32_t, vuint32m2_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vwmaccsu_vx_m)))
vint64m4_t vwmaccsu_vx_i64m4_m(vbool16_t, vint64m4_t, int32_t, vuint32m2_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vwmaccsu_vx)))
vint64m8_t vwmaccsu_vx_i64m8(vint64m8_t, int32_t, vuint32m4_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vwmaccsu_vx_m)))
vint64m8_t vwmaccsu_vx_i64m8_m(vbool8_t, vint64m8_t, int32_t, vuint32m4_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vwmaccus_vx)))
vint64m1_t vwmaccus_vx_i64m1(vint64m1_t, uint32_t, vint32mf2_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vwmaccus_vx_m)))
vint64m1_t vwmaccus_vx_i64m1_m(vbool64_t, vint64m1_t, uint32_t, vint32mf2_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vwmaccus_vx)))
vint64m2_t vwmaccus_vx_i64m2(vint64m2_t, uint32_t, vint32m1_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vwmaccus_vx_m)))
vint64m2_t vwmaccus_vx_i64m2_m(vbool32_t, vint64m2_t, uint32_t, vint32m1_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vwmaccus_vx)))
vint64m4_t vwmaccus_vx_i64m4(vint64m4_t, uint32_t, vint32m2_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vwmaccus_vx_m)))
vint64m4_t vwmaccus_vx_i64m4_m(vbool16_t, vint64m4_t, uint32_t, vint32m2_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vwmaccus_vx)))
vint64m8_t vwmaccus_vx_i64m8(vint64m8_t, uint32_t, vint32m4_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vwmaccus_vx_m)))
vint64m8_t vwmaccus_vx_i64m8_m(vbool8_t, vint64m8_t, uint32_t, vint32m4_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vmerge_vvm)))
vint64m1_t vmerge_vvm_i64m1(vbool64_t, vint64m1_t, vint64m1_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vmerge_vvm)))
vint64m2_t vmerge_vvm_i64m2(vbool32_t, vint64m2_t, vint64m2_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vmerge_vvm)))
vint64m4_t vmerge_vvm_i64m4(vbool16_t, vint64m4_t, vint64m4_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vmerge_vvm)))
vint64m8_t vmerge_vvm_i64m8(vbool8_t, vint64m8_t, vint64m8_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vmerge_vxm)))
vint64m1_t vmerge_vxm_i64m1(vbool64_t, vint64m1_t, int64_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vmerge_vxm)))
vint64m2_t vmerge_vxm_i64m2(vbool32_t, vint64m2_t, int64_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vmerge_vxm)))
vint64m4_t vmerge_vxm_i64m4(vbool16_t, vint64m4_t, int64_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vmerge_vxm)))
vint64m8_t vmerge_vxm_i64m8(vbool8_t, vint64m8_t, int64_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vmerge_vvm)))
vuint64m1_t vmerge_vvm_u64m1(vbool64_t, vuint64m1_t, vuint64m1_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vmerge_vvm)))
vuint64m2_t vmerge_vvm_u64m2(vbool32_t, vuint64m2_t, vuint64m2_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vmerge_vvm)))
vuint64m4_t vmerge_vvm_u64m4(vbool16_t, vuint64m4_t, vuint64m4_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vmerge_vvm)))
vuint64m8_t vmerge_vvm_u64m8(vbool8_t, vuint64m8_t, vuint64m8_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vmerge_vxm)))
vuint64m1_t vmerge_vxm_u64m1(vbool64_t, vuint64m1_t, uint64_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vmerge_vxm)))
vuint64m2_t vmerge_vxm_u64m2(vbool32_t, vuint64m2_t, uint64_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vmerge_vxm)))
vuint64m4_t vmerge_vxm_u64m4(vbool16_t, vuint64m4_t, uint64_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vmerge_vxm)))
vuint64m8_t vmerge_vxm_u64m8(vbool8_t, vuint64m8_t, uint64_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vmv_v_v)))
vuint64m1_t vmv_v_v_u64m1(vuint64m1_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vmv_v_v)))
vuint64m2_t vmv_v_v_u64m2(vuint64m2_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vmv_v_v)))
vuint64m4_t vmv_v_v_u64m4(vuint64m4_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vmv_v_v)))
vuint64m8_t vmv_v_v_u64m8(vuint64m8_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vmv_v_v)))
vint64m1_t vmv_v_v_i64m1(vint64m1_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vmv_v_v)))
vint64m2_t vmv_v_v_i64m2(vint64m2_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vmv_v_v)))
vint64m4_t vmv_v_v_i64m4(vint64m4_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vmv_v_v)))
vint64m8_t vmv_v_v_i64m8(vint64m8_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vmv_v_x)))
vint64m1_t vmv_v_x_i64m1(int64_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vmv_v_x)))
vint64m2_t vmv_v_x_i64m2(int64_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vmv_v_x)))
vint64m4_t vmv_v_x_i64m4(int64_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vmv_v_x)))
vint64m8_t vmv_v_x_i64m8(int64_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vmv_v_x)))
vuint64m1_t vmv_v_x_u64m1(uint64_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vmv_v_x)))
vuint64m2_t vmv_v_x_u64m2(uint64_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vmv_v_x)))
vuint64m4_t vmv_v_x_u64m4(uint64_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vmv_v_x)))
vuint64m8_t vmv_v_x_u64m8(uint64_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vsaddu_vv)))
vuint64m1_t vsaddu_vv_u64m1(vuint64m1_t, vuint64m1_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vsaddu_vv_m)))
vuint64m1_t vsaddu_vv_u64m1_m(vbool64_t, vuint64m1_t, vuint64m1_t, vuint64m1_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vsaddu_vv)))
vuint64m2_t vsaddu_vv_u64m2(vuint64m2_t, vuint64m2_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vsaddu_vv_m)))
vuint64m2_t vsaddu_vv_u64m2_m(vbool32_t, vuint64m2_t, vuint64m2_t, vuint64m2_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vsaddu_vv)))
vuint64m4_t vsaddu_vv_u64m4(vuint64m4_t, vuint64m4_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vsaddu_vv_m)))
vuint64m4_t vsaddu_vv_u64m4_m(vbool16_t, vuint64m4_t, vuint64m4_t, vuint64m4_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vsaddu_vv)))
vuint64m8_t vsaddu_vv_u64m8(vuint64m8_t, vuint64m8_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vsaddu_vv_m)))
vuint64m8_t vsaddu_vv_u64m8_m(vbool8_t, vuint64m8_t, vuint64m8_t, vuint64m8_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vsaddu_vx)))
vuint64m1_t vsaddu_vx_u64m1(vuint64m1_t, uint64_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vsaddu_vx_m)))
vuint64m1_t vsaddu_vx_u64m1_m(vbool64_t, vuint64m1_t, vuint64m1_t, uint64_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vsaddu_vx)))
vuint64m2_t vsaddu_vx_u64m2(vuint64m2_t, uint64_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vsaddu_vx_m)))
vuint64m2_t vsaddu_vx_u64m2_m(vbool32_t, vuint64m2_t, vuint64m2_t, uint64_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vsaddu_vx)))
vuint64m4_t vsaddu_vx_u64m4(vuint64m4_t, uint64_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vsaddu_vx_m)))
vuint64m4_t vsaddu_vx_u64m4_m(vbool16_t, vuint64m4_t, vuint64m4_t, uint64_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vsaddu_vx)))
vuint64m8_t vsaddu_vx_u64m8(vuint64m8_t, uint64_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vsaddu_vx_m)))
vuint64m8_t vsaddu_vx_u64m8_m(vbool8_t, vuint64m8_t, vuint64m8_t, uint64_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vsadd_vv)))
vint64m1_t vsadd_vv_i64m1(vint64m1_t, vint64m1_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vsadd_vv_m)))
vint64m1_t vsadd_vv_i64m1_m(vbool64_t, vint64m1_t, vint64m1_t, vint64m1_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vsadd_vv)))
vint64m2_t vsadd_vv_i64m2(vint64m2_t, vint64m2_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vsadd_vv_m)))
vint64m2_t vsadd_vv_i64m2_m(vbool32_t, vint64m2_t, vint64m2_t, vint64m2_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vsadd_vv)))
vint64m4_t vsadd_vv_i64m4(vint64m4_t, vint64m4_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vsadd_vv_m)))
vint64m4_t vsadd_vv_i64m4_m(vbool16_t, vint64m4_t, vint64m4_t, vint64m4_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vsadd_vv)))
vint64m8_t vsadd_vv_i64m8(vint64m8_t, vint64m8_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vsadd_vv_m)))
vint64m8_t vsadd_vv_i64m8_m(vbool8_t, vint64m8_t, vint64m8_t, vint64m8_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vsadd_vx)))
vint64m1_t vsadd_vx_i64m1(vint64m1_t, int64_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vsadd_vx_m)))
vint64m1_t vsadd_vx_i64m1_m(vbool64_t, vint64m1_t, vint64m1_t, int64_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vsadd_vx)))
vint64m2_t vsadd_vx_i64m2(vint64m2_t, int64_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vsadd_vx_m)))
vint64m2_t vsadd_vx_i64m2_m(vbool32_t, vint64m2_t, vint64m2_t, int64_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vsadd_vx)))
vint64m4_t vsadd_vx_i64m4(vint64m4_t, int64_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vsadd_vx_m)))
vint64m4_t vsadd_vx_i64m4_m(vbool16_t, vint64m4_t, vint64m4_t, int64_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vsadd_vx)))
vint64m8_t vsadd_vx_i64m8(vint64m8_t, int64_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vsadd_vx_m)))
vint64m8_t vsadd_vx_i64m8_m(vbool8_t, vint64m8_t, vint64m8_t, int64_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vssubu_vv)))
vuint64m1_t vssubu_vv_u64m1(vuint64m1_t, vuint64m1_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vssubu_vv_m)))
vuint64m1_t vssubu_vv_u64m1_m(vbool64_t, vuint64m1_t, vuint64m1_t, vuint64m1_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vssubu_vv)))
vuint64m2_t vssubu_vv_u64m2(vuint64m2_t, vuint64m2_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vssubu_vv_m)))
vuint64m2_t vssubu_vv_u64m2_m(vbool32_t, vuint64m2_t, vuint64m2_t, vuint64m2_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vssubu_vv)))
vuint64m4_t vssubu_vv_u64m4(vuint64m4_t, vuint64m4_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vssubu_vv_m)))
vuint64m4_t vssubu_vv_u64m4_m(vbool16_t, vuint64m4_t, vuint64m4_t, vuint64m4_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vssubu_vv)))
vuint64m8_t vssubu_vv_u64m8(vuint64m8_t, vuint64m8_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vssubu_vv_m)))
vuint64m8_t vssubu_vv_u64m8_m(vbool8_t, vuint64m8_t, vuint64m8_t, vuint64m8_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vssubu_vx)))
vuint64m1_t vssubu_vx_u64m1(vuint64m1_t, uint64_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vssubu_vx_m)))
vuint64m1_t vssubu_vx_u64m1_m(vbool64_t, vuint64m1_t, vuint64m1_t, uint64_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vssubu_vx)))
vuint64m2_t vssubu_vx_u64m2(vuint64m2_t, uint64_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vssubu_vx_m)))
vuint64m2_t vssubu_vx_u64m2_m(vbool32_t, vuint64m2_t, vuint64m2_t, uint64_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vssubu_vx)))
vuint64m4_t vssubu_vx_u64m4(vuint64m4_t, uint64_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vssubu_vx_m)))
vuint64m4_t vssubu_vx_u64m4_m(vbool16_t, vuint64m4_t, vuint64m4_t, uint64_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vssubu_vx)))
vuint64m8_t vssubu_vx_u64m8(vuint64m8_t, uint64_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vssubu_vx_m)))
vuint64m8_t vssubu_vx_u64m8_m(vbool8_t, vuint64m8_t, vuint64m8_t, uint64_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vssub_vv)))
vint64m1_t vssub_vv_i64m1(vint64m1_t, vint64m1_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vssub_vv_m)))
vint64m1_t vssub_vv_i64m1_m(vbool64_t, vint64m1_t, vint64m1_t, vint64m1_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vssub_vv)))
vint64m2_t vssub_vv_i64m2(vint64m2_t, vint64m2_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vssub_vv_m)))
vint64m2_t vssub_vv_i64m2_m(vbool32_t, vint64m2_t, vint64m2_t, vint64m2_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vssub_vv)))
vint64m4_t vssub_vv_i64m4(vint64m4_t, vint64m4_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vssub_vv_m)))
vint64m4_t vssub_vv_i64m4_m(vbool16_t, vint64m4_t, vint64m4_t, vint64m4_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vssub_vv)))
vint64m8_t vssub_vv_i64m8(vint64m8_t, vint64m8_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vssub_vv_m)))
vint64m8_t vssub_vv_i64m8_m(vbool8_t, vint64m8_t, vint64m8_t, vint64m8_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vssub_vx)))
vint64m1_t vssub_vx_i64m1(vint64m1_t, int64_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vssub_vx_m)))
vint64m1_t vssub_vx_i64m1_m(vbool64_t, vint64m1_t, vint64m1_t, int64_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vssub_vx)))
vint64m2_t vssub_vx_i64m2(vint64m2_t, int64_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vssub_vx_m)))
vint64m2_t vssub_vx_i64m2_m(vbool32_t, vint64m2_t, vint64m2_t, int64_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vssub_vx)))
vint64m4_t vssub_vx_i64m4(vint64m4_t, int64_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vssub_vx_m)))
vint64m4_t vssub_vx_i64m4_m(vbool16_t, vint64m4_t, vint64m4_t, int64_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vssub_vx)))
vint64m8_t vssub_vx_i64m8(vint64m8_t, int64_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vssub_vx_m)))
vint64m8_t vssub_vx_i64m8_m(vbool8_t, vint64m8_t, vint64m8_t, int64_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vaaddu_vv)))
vuint64m1_t vaaddu_vv_u64m1(vuint64m1_t, vuint64m1_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vaaddu_vv_m)))
vuint64m1_t vaaddu_vv_u64m1_m(vbool64_t, vuint64m1_t, vuint64m1_t, vuint64m1_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vaaddu_vv)))
vuint64m2_t vaaddu_vv_u64m2(vuint64m2_t, vuint64m2_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vaaddu_vv_m)))
vuint64m2_t vaaddu_vv_u64m2_m(vbool32_t, vuint64m2_t, vuint64m2_t, vuint64m2_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vaaddu_vv)))
vuint64m4_t vaaddu_vv_u64m4(vuint64m4_t, vuint64m4_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vaaddu_vv_m)))
vuint64m4_t vaaddu_vv_u64m4_m(vbool16_t, vuint64m4_t, vuint64m4_t, vuint64m4_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vaaddu_vv)))
vuint64m8_t vaaddu_vv_u64m8(vuint64m8_t, vuint64m8_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vaaddu_vv_m)))
vuint64m8_t vaaddu_vv_u64m8_m(vbool8_t, vuint64m8_t, vuint64m8_t, vuint64m8_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vaaddu_vx)))
vuint64m1_t vaaddu_vx_u64m1(vuint64m1_t, uint64_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vaaddu_vx_m)))
vuint64m1_t vaaddu_vx_u64m1_m(vbool64_t, vuint64m1_t, vuint64m1_t, uint64_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vaaddu_vx)))
vuint64m2_t vaaddu_vx_u64m2(vuint64m2_t, uint64_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vaaddu_vx_m)))
vuint64m2_t vaaddu_vx_u64m2_m(vbool32_t, vuint64m2_t, vuint64m2_t, uint64_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vaaddu_vx)))
vuint64m4_t vaaddu_vx_u64m4(vuint64m4_t, uint64_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vaaddu_vx_m)))
vuint64m4_t vaaddu_vx_u64m4_m(vbool16_t, vuint64m4_t, vuint64m4_t, uint64_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vaaddu_vx)))
vuint64m8_t vaaddu_vx_u64m8(vuint64m8_t, uint64_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vaaddu_vx_m)))
vuint64m8_t vaaddu_vx_u64m8_m(vbool8_t, vuint64m8_t, vuint64m8_t, uint64_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vaadd_vv)))
vint64m1_t vaadd_vv_i64m1(vint64m1_t, vint64m1_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vaadd_vv_m)))
vint64m1_t vaadd_vv_i64m1_m(vbool64_t, vint64m1_t, vint64m1_t, vint64m1_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vaadd_vv)))
vint64m2_t vaadd_vv_i64m2(vint64m2_t, vint64m2_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vaadd_vv_m)))
vint64m2_t vaadd_vv_i64m2_m(vbool32_t, vint64m2_t, vint64m2_t, vint64m2_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vaadd_vv)))
vint64m4_t vaadd_vv_i64m4(vint64m4_t, vint64m4_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vaadd_vv_m)))
vint64m4_t vaadd_vv_i64m4_m(vbool16_t, vint64m4_t, vint64m4_t, vint64m4_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vaadd_vv)))
vint64m8_t vaadd_vv_i64m8(vint64m8_t, vint64m8_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vaadd_vv_m)))
vint64m8_t vaadd_vv_i64m8_m(vbool8_t, vint64m8_t, vint64m8_t, vint64m8_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vaadd_vx)))
vint64m1_t vaadd_vx_i64m1(vint64m1_t, int64_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vaadd_vx_m)))
vint64m1_t vaadd_vx_i64m1_m(vbool64_t, vint64m1_t, vint64m1_t, int64_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vaadd_vx)))
vint64m2_t vaadd_vx_i64m2(vint64m2_t, int64_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vaadd_vx_m)))
vint64m2_t vaadd_vx_i64m2_m(vbool32_t, vint64m2_t, vint64m2_t, int64_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vaadd_vx)))
vint64m4_t vaadd_vx_i64m4(vint64m4_t, int64_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vaadd_vx_m)))
vint64m4_t vaadd_vx_i64m4_m(vbool16_t, vint64m4_t, vint64m4_t, int64_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vaadd_vx)))
vint64m8_t vaadd_vx_i64m8(vint64m8_t, int64_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vaadd_vx_m)))
vint64m8_t vaadd_vx_i64m8_m(vbool8_t, vint64m8_t, vint64m8_t, int64_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vasubu_vv)))
vuint64m1_t vasubu_vv_u64m1(vuint64m1_t, vuint64m1_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vasubu_vv_m)))
vuint64m1_t vasubu_vv_u64m1_m(vbool64_t, vuint64m1_t, vuint64m1_t, vuint64m1_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vasubu_vv)))
vuint64m2_t vasubu_vv_u64m2(vuint64m2_t, vuint64m2_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vasubu_vv_m)))
vuint64m2_t vasubu_vv_u64m2_m(vbool32_t, vuint64m2_t, vuint64m2_t, vuint64m2_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vasubu_vv)))
vuint64m4_t vasubu_vv_u64m4(vuint64m4_t, vuint64m4_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vasubu_vv_m)))
vuint64m4_t vasubu_vv_u64m4_m(vbool16_t, vuint64m4_t, vuint64m4_t, vuint64m4_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vasubu_vv)))
vuint64m8_t vasubu_vv_u64m8(vuint64m8_t, vuint64m8_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vasubu_vv_m)))
vuint64m8_t vasubu_vv_u64m8_m(vbool8_t, vuint64m8_t, vuint64m8_t, vuint64m8_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vasubu_vx)))
vuint64m1_t vasubu_vx_u64m1(vuint64m1_t, uint64_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vasubu_vx_m)))
vuint64m1_t vasubu_vx_u64m1_m(vbool64_t, vuint64m1_t, vuint64m1_t, uint64_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vasubu_vx)))
vuint64m2_t vasubu_vx_u64m2(vuint64m2_t, uint64_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vasubu_vx_m)))
vuint64m2_t vasubu_vx_u64m2_m(vbool32_t, vuint64m2_t, vuint64m2_t, uint64_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vasubu_vx)))
vuint64m4_t vasubu_vx_u64m4(vuint64m4_t, uint64_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vasubu_vx_m)))
vuint64m4_t vasubu_vx_u64m4_m(vbool16_t, vuint64m4_t, vuint64m4_t, uint64_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vasubu_vx)))
vuint64m8_t vasubu_vx_u64m8(vuint64m8_t, uint64_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vasubu_vx_m)))
vuint64m8_t vasubu_vx_u64m8_m(vbool8_t, vuint64m8_t, vuint64m8_t, uint64_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vasub_vv)))
vint64m1_t vasub_vv_i64m1(vint64m1_t, vint64m1_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vasub_vv_m)))
vint64m1_t vasub_vv_i64m1_m(vbool64_t, vint64m1_t, vint64m1_t, vint64m1_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vasub_vv)))
vint64m2_t vasub_vv_i64m2(vint64m2_t, vint64m2_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vasub_vv_m)))
vint64m2_t vasub_vv_i64m2_m(vbool32_t, vint64m2_t, vint64m2_t, vint64m2_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vasub_vv)))
vint64m4_t vasub_vv_i64m4(vint64m4_t, vint64m4_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vasub_vv_m)))
vint64m4_t vasub_vv_i64m4_m(vbool16_t, vint64m4_t, vint64m4_t, vint64m4_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vasub_vv)))
vint64m8_t vasub_vv_i64m8(vint64m8_t, vint64m8_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vasub_vv_m)))
vint64m8_t vasub_vv_i64m8_m(vbool8_t, vint64m8_t, vint64m8_t, vint64m8_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vasub_vx)))
vint64m1_t vasub_vx_i64m1(vint64m1_t, int64_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vasub_vx_m)))
vint64m1_t vasub_vx_i64m1_m(vbool64_t, vint64m1_t, vint64m1_t, int64_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vasub_vx)))
vint64m2_t vasub_vx_i64m2(vint64m2_t, int64_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vasub_vx_m)))
vint64m2_t vasub_vx_i64m2_m(vbool32_t, vint64m2_t, vint64m2_t, int64_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vasub_vx)))
vint64m4_t vasub_vx_i64m4(vint64m4_t, int64_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vasub_vx_m)))
vint64m4_t vasub_vx_i64m4_m(vbool16_t, vint64m4_t, vint64m4_t, int64_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vasub_vx)))
vint64m8_t vasub_vx_i64m8(vint64m8_t, int64_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vasub_vx_m)))
vint64m8_t vasub_vx_i64m8_m(vbool8_t, vint64m8_t, vint64m8_t, int64_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vssrl_vv)))
vuint64m1_t vssrl_vv_u64m1(vuint64m1_t, vuint64m1_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vssrl_vv_m)))
vuint64m1_t vssrl_vv_u64m1_m(vbool64_t, vuint64m1_t, vuint64m1_t, vuint64m1_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vssrl_vv)))
vuint64m2_t vssrl_vv_u64m2(vuint64m2_t, vuint64m2_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vssrl_vv_m)))
vuint64m2_t vssrl_vv_u64m2_m(vbool32_t, vuint64m2_t, vuint64m2_t, vuint64m2_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vssrl_vv)))
vuint64m4_t vssrl_vv_u64m4(vuint64m4_t, vuint64m4_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vssrl_vv_m)))
vuint64m4_t vssrl_vv_u64m4_m(vbool16_t, vuint64m4_t, vuint64m4_t, vuint64m4_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vssrl_vv)))
vuint64m8_t vssrl_vv_u64m8(vuint64m8_t, vuint64m8_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vssrl_vv_m)))
vuint64m8_t vssrl_vv_u64m8_m(vbool8_t, vuint64m8_t, vuint64m8_t, vuint64m8_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vssrl_vx)))
vuint64m1_t vssrl_vx_u64m1(vuint64m1_t, size_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vssrl_vx_m)))
vuint64m1_t vssrl_vx_u64m1_m(vbool64_t, vuint64m1_t, vuint64m1_t, size_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vssrl_vx)))
vuint64m2_t vssrl_vx_u64m2(vuint64m2_t, size_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vssrl_vx_m)))
vuint64m2_t vssrl_vx_u64m2_m(vbool32_t, vuint64m2_t, vuint64m2_t, size_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vssrl_vx)))
vuint64m4_t vssrl_vx_u64m4(vuint64m4_t, size_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vssrl_vx_m)))
vuint64m4_t vssrl_vx_u64m4_m(vbool16_t, vuint64m4_t, vuint64m4_t, size_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vssrl_vx)))
vuint64m8_t vssrl_vx_u64m8(vuint64m8_t, size_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vssrl_vx_m)))
vuint64m8_t vssrl_vx_u64m8_m(vbool8_t, vuint64m8_t, vuint64m8_t, size_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vssra_vv)))
vint64m1_t vssra_vv_i64m1(vint64m1_t, vuint64m1_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vssra_vv_m)))
vint64m1_t vssra_vv_i64m1_m(vbool64_t, vint64m1_t, vint64m1_t, vuint64m1_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vssra_vv)))
vint64m2_t vssra_vv_i64m2(vint64m2_t, vuint64m2_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vssra_vv_m)))
vint64m2_t vssra_vv_i64m2_m(vbool32_t, vint64m2_t, vint64m2_t, vuint64m2_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vssra_vv)))
vint64m4_t vssra_vv_i64m4(vint64m4_t, vuint64m4_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vssra_vv_m)))
vint64m4_t vssra_vv_i64m4_m(vbool16_t, vint64m4_t, vint64m4_t, vuint64m4_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vssra_vv)))
vint64m8_t vssra_vv_i64m8(vint64m8_t, vuint64m8_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vssra_vv_m)))
vint64m8_t vssra_vv_i64m8_m(vbool8_t, vint64m8_t, vint64m8_t, vuint64m8_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vssra_vx)))
vint64m1_t vssra_vx_i64m1(vint64m1_t, size_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vssra_vx_m)))
vint64m1_t vssra_vx_i64m1_m(vbool64_t, vint64m1_t, vint64m1_t, size_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vssra_vx)))
vint64m2_t vssra_vx_i64m2(vint64m2_t, size_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vssra_vx_m)))
vint64m2_t vssra_vx_i64m2_m(vbool32_t, vint64m2_t, vint64m2_t, size_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vssra_vx)))
vint64m4_t vssra_vx_i64m4(vint64m4_t, size_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vssra_vx_m)))
vint64m4_t vssra_vx_i64m4_m(vbool16_t, vint64m4_t, vint64m4_t, size_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vssra_vx)))
vint64m8_t vssra_vx_i64m8(vint64m8_t, size_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vssra_vx_m)))
vint64m8_t vssra_vx_i64m8_m(vbool8_t, vint64m8_t, vint64m8_t, size_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vnclipu_wv)))
vuint32m1_t vnclipu_wv_u32m1(vuint64m2_t, vuint32m1_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vnclipu_wv_m)))
vuint32m1_t vnclipu_wv_u32m1_m(vbool32_t, vuint32m1_t, vuint64m2_t, vuint32m1_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vnclipu_wv)))
vuint32m2_t vnclipu_wv_u32m2(vuint64m4_t, vuint32m2_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vnclipu_wv_m)))
vuint32m2_t vnclipu_wv_u32m2_m(vbool16_t, vuint32m2_t, vuint64m4_t, vuint32m2_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vnclipu_wv)))
vuint32m4_t vnclipu_wv_u32m4(vuint64m8_t, vuint32m4_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vnclipu_wv_m)))
vuint32m4_t vnclipu_wv_u32m4_m(vbool8_t, vuint32m4_t, vuint64m8_t, vuint32m4_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vnclipu_wv)))
vuint32mf2_t vnclipu_wv_u32mf2(vuint64m1_t, vuint32mf2_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vnclipu_wv_m)))
vuint32mf2_t vnclipu_wv_u32mf2_m(vbool64_t, vuint32mf2_t, vuint64m1_t, vuint32mf2_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vnclipu_wx)))
vuint32m1_t vnclipu_wx_u32m1(vuint64m2_t, size_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vnclipu_wx_m)))
vuint32m1_t vnclipu_wx_u32m1_m(vbool32_t, vuint32m1_t, vuint64m2_t, size_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vnclipu_wx)))
vuint32m2_t vnclipu_wx_u32m2(vuint64m4_t, size_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vnclipu_wx_m)))
vuint32m2_t vnclipu_wx_u32m2_m(vbool16_t, vuint32m2_t, vuint64m4_t, size_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vnclipu_wx)))
vuint32m4_t vnclipu_wx_u32m4(vuint64m8_t, size_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vnclipu_wx_m)))
vuint32m4_t vnclipu_wx_u32m4_m(vbool8_t, vuint32m4_t, vuint64m8_t, size_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vnclipu_wx)))
vuint32mf2_t vnclipu_wx_u32mf2(vuint64m1_t, size_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vnclipu_wx_m)))
vuint32mf2_t vnclipu_wx_u32mf2_m(vbool64_t, vuint32mf2_t, vuint64m1_t, size_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vnclip_wv)))
vint32m1_t vnclip_wv_i32m1(vint64m2_t, vuint32m1_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vnclip_wv_m)))
vint32m1_t vnclip_wv_i32m1_m(vbool32_t, vint32m1_t, vint64m2_t, vuint32m1_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vnclip_wv)))
vint32m2_t vnclip_wv_i32m2(vint64m4_t, vuint32m2_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vnclip_wv_m)))
vint32m2_t vnclip_wv_i32m2_m(vbool16_t, vint32m2_t, vint64m4_t, vuint32m2_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vnclip_wv)))
vint32m4_t vnclip_wv_i32m4(vint64m8_t, vuint32m4_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vnclip_wv_m)))
vint32m4_t vnclip_wv_i32m4_m(vbool8_t, vint32m4_t, vint64m8_t, vuint32m4_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vnclip_wv)))
vint32mf2_t vnclip_wv_i32mf2(vint64m1_t, vuint32mf2_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vnclip_wv_m)))
vint32mf2_t vnclip_wv_i32mf2_m(vbool64_t, vint32mf2_t, vint64m1_t, vuint32mf2_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vnclip_wx)))
vint32m1_t vnclip_wx_i32m1(vint64m2_t, size_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vnclip_wx_m)))
vint32m1_t vnclip_wx_i32m1_m(vbool32_t, vint32m1_t, vint64m2_t, size_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vnclip_wx)))
vint32m2_t vnclip_wx_i32m2(vint64m4_t, size_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vnclip_wx_m)))
vint32m2_t vnclip_wx_i32m2_m(vbool16_t, vint32m2_t, vint64m4_t, size_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vnclip_wx)))
vint32m4_t vnclip_wx_i32m4(vint64m8_t, size_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vnclip_wx_m)))
vint32m4_t vnclip_wx_i32m4_m(vbool8_t, vint32m4_t, vint64m8_t, size_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vnclip_wx)))
vint32mf2_t vnclip_wx_i32mf2(vint64m1_t, size_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vnclip_wx_m)))
vint32mf2_t vnclip_wx_i32mf2_m(vbool64_t, vint32mf2_t, vint64m1_t, size_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vredsum_vs)))
vint64m1_t vredsum_vs_i64m1_i64m1(vint64m1_t, vint64m1_t, vint64m1_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vredsum_vs_m)))
vint64m1_t vredsum_vs_i64m1_i64m1_m(vbool64_t, vint64m1_t, vint64m1_t, vint64m1_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vredsum_vs)))
vint64m1_t vredsum_vs_i64m2_i64m1(vint64m1_t, vint64m2_t, vint64m1_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vredsum_vs_m)))
vint64m1_t vredsum_vs_i64m2_i64m1_m(vbool32_t, vint64m1_t, vint64m2_t, vint64m1_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vredsum_vs)))
vint64m1_t vredsum_vs_i64m4_i64m1(vint64m1_t, vint64m4_t, vint64m1_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vredsum_vs_m)))
vint64m1_t vredsum_vs_i64m4_i64m1_m(vbool16_t, vint64m1_t, vint64m4_t, vint64m1_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vredsum_vs)))
vint64m1_t vredsum_vs_i64m8_i64m1(vint64m1_t, vint64m8_t, vint64m1_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vredsum_vs_m)))
vint64m1_t vredsum_vs_i64m8_i64m1_m(vbool8_t, vint64m1_t, vint64m8_t, vint64m1_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vredsum_vs)))
vuint64m1_t vredsum_vs_u64m1_u64m1(vuint64m1_t, vuint64m1_t, vuint64m1_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vredsum_vs_m)))
vuint64m1_t vredsum_vs_u64m1_u64m1_m(vbool64_t, vuint64m1_t, vuint64m1_t, vuint64m1_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vredsum_vs)))
vuint64m1_t vredsum_vs_u64m2_u64m1(vuint64m1_t, vuint64m2_t, vuint64m1_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vredsum_vs_m)))
vuint64m1_t vredsum_vs_u64m2_u64m1_m(vbool32_t, vuint64m1_t, vuint64m2_t, vuint64m1_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vredsum_vs)))
vuint64m1_t vredsum_vs_u64m4_u64m1(vuint64m1_t, vuint64m4_t, vuint64m1_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vredsum_vs_m)))
vuint64m1_t vredsum_vs_u64m4_u64m1_m(vbool16_t, vuint64m1_t, vuint64m4_t, vuint64m1_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vredsum_vs)))
vuint64m1_t vredsum_vs_u64m8_u64m1(vuint64m1_t, vuint64m8_t, vuint64m1_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vredsum_vs_m)))
vuint64m1_t vredsum_vs_u64m8_u64m1_m(vbool8_t, vuint64m1_t, vuint64m8_t, vuint64m1_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vredmaxu_vs)))
vuint64m1_t vredmaxu_vs_u64m1_u64m1(vuint64m1_t, vuint64m1_t, vuint64m1_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vredmaxu_vs_m)))
vuint64m1_t vredmaxu_vs_u64m1_u64m1_m(vbool64_t, vuint64m1_t, vuint64m1_t, vuint64m1_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vredmaxu_vs)))
vuint64m1_t vredmaxu_vs_u64m2_u64m1(vuint64m1_t, vuint64m2_t, vuint64m1_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vredmaxu_vs_m)))
vuint64m1_t vredmaxu_vs_u64m2_u64m1_m(vbool32_t, vuint64m1_t, vuint64m2_t, vuint64m1_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vredmaxu_vs)))
vuint64m1_t vredmaxu_vs_u64m4_u64m1(vuint64m1_t, vuint64m4_t, vuint64m1_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vredmaxu_vs_m)))
vuint64m1_t vredmaxu_vs_u64m4_u64m1_m(vbool16_t, vuint64m1_t, vuint64m4_t, vuint64m1_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vredmaxu_vs)))
vuint64m1_t vredmaxu_vs_u64m8_u64m1(vuint64m1_t, vuint64m8_t, vuint64m1_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vredmaxu_vs_m)))
vuint64m1_t vredmaxu_vs_u64m8_u64m1_m(vbool8_t, vuint64m1_t, vuint64m8_t, vuint64m1_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vredmax_vs)))
vint64m1_t vredmax_vs_i64m1_i64m1(vint64m1_t, vint64m1_t, vint64m1_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vredmax_vs_m)))
vint64m1_t vredmax_vs_i64m1_i64m1_m(vbool64_t, vint64m1_t, vint64m1_t, vint64m1_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vredmax_vs)))
vint64m1_t vredmax_vs_i64m2_i64m1(vint64m1_t, vint64m2_t, vint64m1_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vredmax_vs_m)))
vint64m1_t vredmax_vs_i64m2_i64m1_m(vbool32_t, vint64m1_t, vint64m2_t, vint64m1_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vredmax_vs)))
vint64m1_t vredmax_vs_i64m4_i64m1(vint64m1_t, vint64m4_t, vint64m1_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vredmax_vs_m)))
vint64m1_t vredmax_vs_i64m4_i64m1_m(vbool16_t, vint64m1_t, vint64m4_t, vint64m1_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vredmax_vs)))
vint64m1_t vredmax_vs_i64m8_i64m1(vint64m1_t, vint64m8_t, vint64m1_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vredmax_vs_m)))
vint64m1_t vredmax_vs_i64m8_i64m1_m(vbool8_t, vint64m1_t, vint64m8_t, vint64m1_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vredminu_vs)))
vuint64m1_t vredminu_vs_u64m1_u64m1(vuint64m1_t, vuint64m1_t, vuint64m1_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vredminu_vs_m)))
vuint64m1_t vredminu_vs_u64m1_u64m1_m(vbool64_t, vuint64m1_t, vuint64m1_t, vuint64m1_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vredminu_vs)))
vuint64m1_t vredminu_vs_u64m2_u64m1(vuint64m1_t, vuint64m2_t, vuint64m1_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vredminu_vs_m)))
vuint64m1_t vredminu_vs_u64m2_u64m1_m(vbool32_t, vuint64m1_t, vuint64m2_t, vuint64m1_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vredminu_vs)))
vuint64m1_t vredminu_vs_u64m4_u64m1(vuint64m1_t, vuint64m4_t, vuint64m1_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vredminu_vs_m)))
vuint64m1_t vredminu_vs_u64m4_u64m1_m(vbool16_t, vuint64m1_t, vuint64m4_t, vuint64m1_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vredminu_vs)))
vuint64m1_t vredminu_vs_u64m8_u64m1(vuint64m1_t, vuint64m8_t, vuint64m1_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vredminu_vs_m)))
vuint64m1_t vredminu_vs_u64m8_u64m1_m(vbool8_t, vuint64m1_t, vuint64m8_t, vuint64m1_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vredmin_vs)))
vint64m1_t vredmin_vs_i64m1_i64m1(vint64m1_t, vint64m1_t, vint64m1_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vredmin_vs_m)))
vint64m1_t vredmin_vs_i64m1_i64m1_m(vbool64_t, vint64m1_t, vint64m1_t, vint64m1_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vredmin_vs)))
vint64m1_t vredmin_vs_i64m2_i64m1(vint64m1_t, vint64m2_t, vint64m1_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vredmin_vs_m)))
vint64m1_t vredmin_vs_i64m2_i64m1_m(vbool32_t, vint64m1_t, vint64m2_t, vint64m1_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vredmin_vs)))
vint64m1_t vredmin_vs_i64m4_i64m1(vint64m1_t, vint64m4_t, vint64m1_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vredmin_vs_m)))
vint64m1_t vredmin_vs_i64m4_i64m1_m(vbool16_t, vint64m1_t, vint64m4_t, vint64m1_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vredmin_vs)))
vint64m1_t vredmin_vs_i64m8_i64m1(vint64m1_t, vint64m8_t, vint64m1_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vredmin_vs_m)))
vint64m1_t vredmin_vs_i64m8_i64m1_m(vbool8_t, vint64m1_t, vint64m8_t, vint64m1_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vredand_vs)))
vint64m1_t vredand_vs_i64m1_i64m1(vint64m1_t, vint64m1_t, vint64m1_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vredand_vs_m)))
vint64m1_t vredand_vs_i64m1_i64m1_m(vbool64_t, vint64m1_t, vint64m1_t, vint64m1_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vredand_vs)))
vint64m1_t vredand_vs_i64m2_i64m1(vint64m1_t, vint64m2_t, vint64m1_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vredand_vs_m)))
vint64m1_t vredand_vs_i64m2_i64m1_m(vbool32_t, vint64m1_t, vint64m2_t, vint64m1_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vredand_vs)))
vint64m1_t vredand_vs_i64m4_i64m1(vint64m1_t, vint64m4_t, vint64m1_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vredand_vs_m)))
vint64m1_t vredand_vs_i64m4_i64m1_m(vbool16_t, vint64m1_t, vint64m4_t, vint64m1_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vredand_vs)))
vint64m1_t vredand_vs_i64m8_i64m1(vint64m1_t, vint64m8_t, vint64m1_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vredand_vs_m)))
vint64m1_t vredand_vs_i64m8_i64m1_m(vbool8_t, vint64m1_t, vint64m8_t, vint64m1_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vredand_vs)))
vuint64m1_t vredand_vs_u64m1_u64m1(vuint64m1_t, vuint64m1_t, vuint64m1_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vredand_vs_m)))
vuint64m1_t vredand_vs_u64m1_u64m1_m(vbool64_t, vuint64m1_t, vuint64m1_t, vuint64m1_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vredand_vs)))
vuint64m1_t vredand_vs_u64m2_u64m1(vuint64m1_t, vuint64m2_t, vuint64m1_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vredand_vs_m)))
vuint64m1_t vredand_vs_u64m2_u64m1_m(vbool32_t, vuint64m1_t, vuint64m2_t, vuint64m1_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vredand_vs)))
vuint64m1_t vredand_vs_u64m4_u64m1(vuint64m1_t, vuint64m4_t, vuint64m1_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vredand_vs_m)))
vuint64m1_t vredand_vs_u64m4_u64m1_m(vbool16_t, vuint64m1_t, vuint64m4_t, vuint64m1_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vredand_vs)))
vuint64m1_t vredand_vs_u64m8_u64m1(vuint64m1_t, vuint64m8_t, vuint64m1_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vredand_vs_m)))
vuint64m1_t vredand_vs_u64m8_u64m1_m(vbool8_t, vuint64m1_t, vuint64m8_t, vuint64m1_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vredor_vs)))
vint64m1_t vredor_vs_i64m1_i64m1(vint64m1_t, vint64m1_t, vint64m1_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vredor_vs_m)))
vint64m1_t vredor_vs_i64m1_i64m1_m(vbool64_t, vint64m1_t, vint64m1_t, vint64m1_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vredor_vs)))
vint64m1_t vredor_vs_i64m2_i64m1(vint64m1_t, vint64m2_t, vint64m1_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vredor_vs_m)))
vint64m1_t vredor_vs_i64m2_i64m1_m(vbool32_t, vint64m1_t, vint64m2_t, vint64m1_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vredor_vs)))
vint64m1_t vredor_vs_i64m4_i64m1(vint64m1_t, vint64m4_t, vint64m1_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vredor_vs_m)))
vint64m1_t vredor_vs_i64m4_i64m1_m(vbool16_t, vint64m1_t, vint64m4_t, vint64m1_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vredor_vs)))
vint64m1_t vredor_vs_i64m8_i64m1(vint64m1_t, vint64m8_t, vint64m1_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vredor_vs_m)))
vint64m1_t vredor_vs_i64m8_i64m1_m(vbool8_t, vint64m1_t, vint64m8_t, vint64m1_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vredor_vs)))
vuint64m1_t vredor_vs_u64m1_u64m1(vuint64m1_t, vuint64m1_t, vuint64m1_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vredor_vs_m)))
vuint64m1_t vredor_vs_u64m1_u64m1_m(vbool64_t, vuint64m1_t, vuint64m1_t, vuint64m1_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vredor_vs)))
vuint64m1_t vredor_vs_u64m2_u64m1(vuint64m1_t, vuint64m2_t, vuint64m1_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vredor_vs_m)))
vuint64m1_t vredor_vs_u64m2_u64m1_m(vbool32_t, vuint64m1_t, vuint64m2_t, vuint64m1_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vredor_vs)))
vuint64m1_t vredor_vs_u64m4_u64m1(vuint64m1_t, vuint64m4_t, vuint64m1_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vredor_vs_m)))
vuint64m1_t vredor_vs_u64m4_u64m1_m(vbool16_t, vuint64m1_t, vuint64m4_t, vuint64m1_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vredor_vs)))
vuint64m1_t vredor_vs_u64m8_u64m1(vuint64m1_t, vuint64m8_t, vuint64m1_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vredor_vs_m)))
vuint64m1_t vredor_vs_u64m8_u64m1_m(vbool8_t, vuint64m1_t, vuint64m8_t, vuint64m1_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vredxor_vs)))
vint64m1_t vredxor_vs_i64m1_i64m1(vint64m1_t, vint64m1_t, vint64m1_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vredxor_vs_m)))
vint64m1_t vredxor_vs_i64m1_i64m1_m(vbool64_t, vint64m1_t, vint64m1_t, vint64m1_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vredxor_vs)))
vint64m1_t vredxor_vs_i64m2_i64m1(vint64m1_t, vint64m2_t, vint64m1_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vredxor_vs_m)))
vint64m1_t vredxor_vs_i64m2_i64m1_m(vbool32_t, vint64m1_t, vint64m2_t, vint64m1_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vredxor_vs)))
vint64m1_t vredxor_vs_i64m4_i64m1(vint64m1_t, vint64m4_t, vint64m1_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vredxor_vs_m)))
vint64m1_t vredxor_vs_i64m4_i64m1_m(vbool16_t, vint64m1_t, vint64m4_t, vint64m1_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vredxor_vs)))
vint64m1_t vredxor_vs_i64m8_i64m1(vint64m1_t, vint64m8_t, vint64m1_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vredxor_vs_m)))
vint64m1_t vredxor_vs_i64m8_i64m1_m(vbool8_t, vint64m1_t, vint64m8_t, vint64m1_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vredxor_vs)))
vuint64m1_t vredxor_vs_u64m1_u64m1(vuint64m1_t, vuint64m1_t, vuint64m1_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vredxor_vs_m)))
vuint64m1_t vredxor_vs_u64m1_u64m1_m(vbool64_t, vuint64m1_t, vuint64m1_t, vuint64m1_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vredxor_vs)))
vuint64m1_t vredxor_vs_u64m2_u64m1(vuint64m1_t, vuint64m2_t, vuint64m1_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vredxor_vs_m)))
vuint64m1_t vredxor_vs_u64m2_u64m1_m(vbool32_t, vuint64m1_t, vuint64m2_t, vuint64m1_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vredxor_vs)))
vuint64m1_t vredxor_vs_u64m4_u64m1(vuint64m1_t, vuint64m4_t, vuint64m1_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vredxor_vs_m)))
vuint64m1_t vredxor_vs_u64m4_u64m1_m(vbool16_t, vuint64m1_t, vuint64m4_t, vuint64m1_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vredxor_vs)))
vuint64m1_t vredxor_vs_u64m8_u64m1(vuint64m1_t, vuint64m8_t, vuint64m1_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vredxor_vs_m)))
vuint64m1_t vredxor_vs_u64m8_u64m1_m(vbool8_t, vuint64m1_t, vuint64m8_t, vuint64m1_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vwredsum_vs)))
vint64m1_t vwredsum_vs_i32m1_i64m1(vint64m1_t, vint32m1_t, vint64m1_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vwredsum_vs_m)))
vint64m1_t vwredsum_vs_i32m1_i64m1_m(vbool32_t, vint64m1_t, vint32m1_t, vint64m1_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vwredsum_vs)))
vint64m1_t vwredsum_vs_i32m2_i64m1(vint64m1_t, vint32m2_t, vint64m1_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vwredsum_vs_m)))
vint64m1_t vwredsum_vs_i32m2_i64m1_m(vbool16_t, vint64m1_t, vint32m2_t, vint64m1_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vwredsum_vs)))
vint64m1_t vwredsum_vs_i32m4_i64m1(vint64m1_t, vint32m4_t, vint64m1_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vwredsum_vs_m)))
vint64m1_t vwredsum_vs_i32m4_i64m1_m(vbool8_t, vint64m1_t, vint32m4_t, vint64m1_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vwredsum_vs)))
vint64m1_t vwredsum_vs_i32m8_i64m1(vint64m1_t, vint32m8_t, vint64m1_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vwredsum_vs_m)))
vint64m1_t vwredsum_vs_i32m8_i64m1_m(vbool4_t, vint64m1_t, vint32m8_t, vint64m1_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vwredsum_vs)))
vint64m1_t vwredsum_vs_i32mf2_i64m1(vint64m1_t, vint32mf2_t, vint64m1_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vwredsum_vs_m)))
vint64m1_t vwredsum_vs_i32mf2_i64m1_m(vbool64_t, vint64m1_t, vint32mf2_t, vint64m1_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vwredsumu_vs)))
vuint64m1_t vwredsumu_vs_u32m1_u64m1(vuint64m1_t, vuint32m1_t, vuint64m1_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vwredsumu_vs_m)))
vuint64m1_t vwredsumu_vs_u32m1_u64m1_m(vbool32_t, vuint64m1_t, vuint32m1_t, vuint64m1_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vwredsumu_vs)))
vuint64m1_t vwredsumu_vs_u32m2_u64m1(vuint64m1_t, vuint32m2_t, vuint64m1_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vwredsumu_vs_m)))
vuint64m1_t vwredsumu_vs_u32m2_u64m1_m(vbool16_t, vuint64m1_t, vuint32m2_t, vuint64m1_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vwredsumu_vs)))
vuint64m1_t vwredsumu_vs_u32m4_u64m1(vuint64m1_t, vuint32m4_t, vuint64m1_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vwredsumu_vs_m)))
vuint64m1_t vwredsumu_vs_u32m4_u64m1_m(vbool8_t, vuint64m1_t, vuint32m4_t, vuint64m1_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vwredsumu_vs)))
vuint64m1_t vwredsumu_vs_u32m8_u64m1(vuint64m1_t, vuint32m8_t, vuint64m1_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vwredsumu_vs_m)))
vuint64m1_t vwredsumu_vs_u32m8_u64m1_m(vbool4_t, vuint64m1_t, vuint32m8_t, vuint64m1_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vwredsumu_vs)))
vuint64m1_t vwredsumu_vs_u32mf2_u64m1(vuint64m1_t, vuint32mf2_t, vuint64m1_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vwredsumu_vs_m)))
vuint64m1_t vwredsumu_vs_u32mf2_u64m1_m(vbool64_t, vuint64m1_t, vuint32mf2_t, vuint64m1_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_viota_m)))
vuint64m1_t viota_m_u64m1(vbool64_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_viota_m_m)))
vuint64m1_t viota_m_u64m1_m(vbool64_t, vuint64m1_t, vbool64_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_viota_m)))
vuint64m2_t viota_m_u64m2(vbool32_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_viota_m_m)))
vuint64m2_t viota_m_u64m2_m(vbool32_t, vuint64m2_t, vbool32_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_viota_m)))
vuint64m4_t viota_m_u64m4(vbool16_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_viota_m_m)))
vuint64m4_t viota_m_u64m4_m(vbool16_t, vuint64m4_t, vbool16_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_viota_m)))
vuint64m8_t viota_m_u64m8(vbool8_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_viota_m_m)))
vuint64m8_t viota_m_u64m8_m(vbool8_t, vuint64m8_t, vbool8_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vid_v)))
vint64m1_t vid_v_i64m1(size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vid_v_m)))
vint64m1_t vid_v_i64m1_m(vbool64_t, vint64m1_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vid_v)))
vint64m2_t vid_v_i64m2(size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vid_v_m)))
vint64m2_t vid_v_i64m2_m(vbool32_t, vint64m2_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vid_v)))
vint64m4_t vid_v_i64m4(size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vid_v_m)))
vint64m4_t vid_v_i64m4_m(vbool16_t, vint64m4_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vid_v)))
vint64m8_t vid_v_i64m8(size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vid_v_m)))
vint64m8_t vid_v_i64m8_m(vbool8_t, vint64m8_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vid_v)))
vuint64m1_t vid_v_u64m1(size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vid_v_m)))
vuint64m1_t vid_v_u64m1_m(vbool64_t, vuint64m1_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vid_v)))
vuint64m2_t vid_v_u64m2(size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vid_v_m)))
vuint64m2_t vid_v_u64m2_m(vbool32_t, vuint64m2_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vid_v)))
vuint64m4_t vid_v_u64m4(size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vid_v_m)))
vuint64m4_t vid_v_u64m4_m(vbool16_t, vuint64m4_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vid_v)))
vuint64m8_t vid_v_u64m8(size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vid_v_m)))
vuint64m8_t vid_v_u64m8_m(vbool8_t, vuint64m8_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vmv_x_s)))
int64_t vmv_x_s_i64m1_i64(vint64m1_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vmv_x_s)))
int64_t vmv_x_s_i64m2_i64(vint64m2_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vmv_x_s)))
int64_t vmv_x_s_i64m4_i64(vint64m4_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vmv_x_s)))
int64_t vmv_x_s_i64m8_i64(vint64m8_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vmv_x_s)))
uint64_t vmv_x_s_u64m1_u64(vuint64m1_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vmv_x_s)))
uint64_t vmv_x_s_u64m2_u64(vuint64m2_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vmv_x_s)))
uint64_t vmv_x_s_u64m4_u64(vuint64m4_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vmv_x_s)))
uint64_t vmv_x_s_u64m8_u64(vuint64m8_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vmv_s_x)))
vint64m1_t vmv_s_x_i64m1(vint64m1_t, int64_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vmv_s_x)))
vint64m2_t vmv_s_x_i64m2(vint64m2_t, int64_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vmv_s_x)))
vint64m4_t vmv_s_x_i64m4(vint64m4_t, int64_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vmv_s_x)))
vint64m8_t vmv_s_x_i64m8(vint64m8_t, int64_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vmv_s_x)))
vuint64m1_t vmv_s_x_u64m1(vuint64m1_t, uint64_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vmv_s_x)))
vuint64m2_t vmv_s_x_u64m2(vuint64m2_t, uint64_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vmv_s_x)))
vuint64m4_t vmv_s_x_u64m4(vuint64m4_t, uint64_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vmv_s_x)))
vuint64m8_t vmv_s_x_u64m8(vuint64m8_t, uint64_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vfmv_s_x)))
vuint64m1_t vfmv_s_x_u64m1(vuint64m1_t, uint64_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vfmv_s_x)))
vuint64m2_t vfmv_s_x_u64m2(vuint64m2_t, uint64_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vfmv_s_x)))
vuint64m4_t vfmv_s_x_u64m4(vuint64m4_t, uint64_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vfmv_s_x)))
vuint64m8_t vfmv_s_x_u64m8(vuint64m8_t, uint64_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vslideup_vx)))
vint64m1_t vslideup_vx_i64m1(vint64m1_t, vint64m1_t, size_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vslideup_vx_m)))
vint64m1_t vslideup_vx_i64m1_m(vbool64_t, vint64m1_t, vint64m1_t, size_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vslideup_vx)))
vint64m2_t vslideup_vx_i64m2(vint64m2_t, vint64m2_t, size_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vslideup_vx_m)))
vint64m2_t vslideup_vx_i64m2_m(vbool32_t, vint64m2_t, vint64m2_t, size_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vslideup_vx)))
vint64m4_t vslideup_vx_i64m4(vint64m4_t, vint64m4_t, size_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vslideup_vx_m)))
vint64m4_t vslideup_vx_i64m4_m(vbool16_t, vint64m4_t, vint64m4_t, size_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vslideup_vx)))
vint64m8_t vslideup_vx_i64m8(vint64m8_t, vint64m8_t, size_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vslideup_vx_m)))
vint64m8_t vslideup_vx_i64m8_m(vbool8_t, vint64m8_t, vint64m8_t, size_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vslideup_vx)))
vuint64m1_t vslideup_vx_u64m1(vuint64m1_t, vuint64m1_t, size_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vslideup_vx_m)))
vuint64m1_t vslideup_vx_u64m1_m(vbool64_t, vuint64m1_t, vuint64m1_t, size_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vslideup_vx)))
vuint64m2_t vslideup_vx_u64m2(vuint64m2_t, vuint64m2_t, size_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vslideup_vx_m)))
vuint64m2_t vslideup_vx_u64m2_m(vbool32_t, vuint64m2_t, vuint64m2_t, size_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vslideup_vx)))
vuint64m4_t vslideup_vx_u64m4(vuint64m4_t, vuint64m4_t, size_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vslideup_vx_m)))
vuint64m4_t vslideup_vx_u64m4_m(vbool16_t, vuint64m4_t, vuint64m4_t, size_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vslideup_vx)))
vuint64m8_t vslideup_vx_u64m8(vuint64m8_t, vuint64m8_t, size_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vslideup_vx_m)))
vuint64m8_t vslideup_vx_u64m8_m(vbool8_t, vuint64m8_t, vuint64m8_t, size_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vslidedown_vx)))
vint64m1_t vslidedown_vx_i64m1(vint64m1_t, vint64m1_t, size_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vslidedown_vx_m)))
vint64m1_t vslidedown_vx_i64m1_m(vbool64_t, vint64m1_t, vint64m1_t, size_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vslidedown_vx)))
vint64m2_t vslidedown_vx_i64m2(vint64m2_t, vint64m2_t, size_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vslidedown_vx_m)))
vint64m2_t vslidedown_vx_i64m2_m(vbool32_t, vint64m2_t, vint64m2_t, size_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vslidedown_vx)))
vint64m4_t vslidedown_vx_i64m4(vint64m4_t, vint64m4_t, size_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vslidedown_vx_m)))
vint64m4_t vslidedown_vx_i64m4_m(vbool16_t, vint64m4_t, vint64m4_t, size_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vslidedown_vx)))
vint64m8_t vslidedown_vx_i64m8(vint64m8_t, vint64m8_t, size_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vslidedown_vx_m)))
vint64m8_t vslidedown_vx_i64m8_m(vbool8_t, vint64m8_t, vint64m8_t, size_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vslidedown_vx)))
vuint64m1_t vslidedown_vx_u64m1(vuint64m1_t, vuint64m1_t, size_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vslidedown_vx_m)))
vuint64m1_t vslidedown_vx_u64m1_m(vbool64_t, vuint64m1_t, vuint64m1_t, size_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vslidedown_vx)))
vuint64m2_t vslidedown_vx_u64m2(vuint64m2_t, vuint64m2_t, size_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vslidedown_vx_m)))
vuint64m2_t vslidedown_vx_u64m2_m(vbool32_t, vuint64m2_t, vuint64m2_t, size_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vslidedown_vx)))
vuint64m4_t vslidedown_vx_u64m4(vuint64m4_t, vuint64m4_t, size_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vslidedown_vx_m)))
vuint64m4_t vslidedown_vx_u64m4_m(vbool16_t, vuint64m4_t, vuint64m4_t, size_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vslidedown_vx)))
vuint64m8_t vslidedown_vx_u64m8(vuint64m8_t, vuint64m8_t, size_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vslidedown_vx_m)))
vuint64m8_t vslidedown_vx_u64m8_m(vbool8_t, vuint64m8_t, vuint64m8_t, size_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vslide1up_vx)))
vint64m1_t vslide1up_vx_i64m1(vint64m1_t, int64_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vslide1up_vx_m)))
vint64m1_t vslide1up_vx_i64m1_m(vbool64_t, vint64m1_t, vint64m1_t, int64_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vslide1up_vx)))
vint64m2_t vslide1up_vx_i64m2(vint64m2_t, int64_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vslide1up_vx_m)))
vint64m2_t vslide1up_vx_i64m2_m(vbool32_t, vint64m2_t, vint64m2_t, int64_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vslide1up_vx)))
vint64m4_t vslide1up_vx_i64m4(vint64m4_t, int64_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vslide1up_vx_m)))
vint64m4_t vslide1up_vx_i64m4_m(vbool16_t, vint64m4_t, vint64m4_t, int64_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vslide1up_vx)))
vint64m8_t vslide1up_vx_i64m8(vint64m8_t, int64_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vslide1up_vx_m)))
vint64m8_t vslide1up_vx_i64m8_m(vbool8_t, vint64m8_t, vint64m8_t, int64_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vslide1up_vx)))
vuint64m1_t vslide1up_vx_u64m1(vuint64m1_t, int64_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vslide1up_vx_m)))
vuint64m1_t vslide1up_vx_u64m1_m(vbool64_t, vuint64m1_t, vuint64m1_t, int64_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vslide1up_vx)))
vuint64m2_t vslide1up_vx_u64m2(vuint64m2_t, int64_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vslide1up_vx_m)))
vuint64m2_t vslide1up_vx_u64m2_m(vbool32_t, vuint64m2_t, vuint64m2_t, int64_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vslide1up_vx)))
vuint64m4_t vslide1up_vx_u64m4(vuint64m4_t, int64_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vslide1up_vx_m)))
vuint64m4_t vslide1up_vx_u64m4_m(vbool16_t, vuint64m4_t, vuint64m4_t, int64_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vslide1up_vx)))
vuint64m8_t vslide1up_vx_u64m8(vuint64m8_t, int64_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vslide1up_vx_m)))
vuint64m8_t vslide1up_vx_u64m8_m(vbool8_t, vuint64m8_t, vuint64m8_t, int64_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vsuxei8_v)))
void vsuxei8_v_i64m1(int64_t *, vuint8mf8_t, vint64m1_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vsuxei8_v_m)))
void vsuxei8_v_i64m1_m(vbool64_t, int64_t *, vuint8mf8_t, vint64m1_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vsuxei8_v)))
void vsuxei8_v_i64m2(int64_t *, vuint8mf4_t, vint64m2_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vsuxei8_v_m)))
void vsuxei8_v_i64m2_m(vbool32_t, int64_t *, vuint8mf4_t, vint64m2_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vsuxei8_v)))
void vsuxei8_v_i64m4(int64_t *, vuint8mf2_t, vint64m4_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vsuxei8_v_m)))
void vsuxei8_v_i64m4_m(vbool16_t, int64_t *, vuint8mf2_t, vint64m4_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vsuxei8_v)))
void vsuxei8_v_i64m8(int64_t *, vuint8m1_t, vint64m8_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vsuxei8_v_m)))
void vsuxei8_v_i64m8_m(vbool8_t, int64_t *, vuint8m1_t, vint64m8_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vslide1down_vx)))
vint64m1_t vslide1down_vx_i64m1(vint64m1_t, int64_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vslide1down_vx_m)))
vint64m1_t vslide1down_vx_i64m1_m(vbool64_t, vint64m1_t, vint64m1_t, int64_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vslide1down_vx)))
vint64m2_t vslide1down_vx_i64m2(vint64m2_t, int64_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vslide1down_vx_m)))
vint64m2_t vslide1down_vx_i64m2_m(vbool32_t, vint64m2_t, vint64m2_t, int64_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vslide1down_vx)))
vint64m4_t vslide1down_vx_i64m4(vint64m4_t, int64_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vslide1down_vx_m)))
vint64m4_t vslide1down_vx_i64m4_m(vbool16_t, vint64m4_t, vint64m4_t, int64_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vslide1down_vx)))
vint64m8_t vslide1down_vx_i64m8(vint64m8_t, int64_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vslide1down_vx_m)))
vint64m8_t vslide1down_vx_i64m8_m(vbool8_t, vint64m8_t, vint64m8_t, int64_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vslide1down_vx)))
vuint64m1_t vslide1down_vx_u64m1(vuint64m1_t, int64_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vslide1down_vx_m)))
vuint64m1_t vslide1down_vx_u64m1_m(vbool64_t, vuint64m1_t, vuint64m1_t, int64_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vslide1down_vx)))
vuint64m2_t vslide1down_vx_u64m2(vuint64m2_t, int64_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vslide1down_vx_m)))
vuint64m2_t vslide1down_vx_u64m2_m(vbool32_t, vuint64m2_t, vuint64m2_t, int64_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vslide1down_vx)))
vuint64m4_t vslide1down_vx_u64m4(vuint64m4_t, int64_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vslide1down_vx_m)))
vuint64m4_t vslide1down_vx_u64m4_m(vbool16_t, vuint64m4_t, vuint64m4_t, int64_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vslide1down_vx)))
vuint64m8_t vslide1down_vx_u64m8(vuint64m8_t, int64_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vslide1down_vx_m)))
vuint64m8_t vslide1down_vx_u64m8_m(vbool8_t, vuint64m8_t, vuint64m8_t, int64_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vrgather_vv)))
vint64m1_t vrgather_vv_i64m1(vint64m1_t, vuint64m1_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vrgather_vv_m)))
vint64m1_t vrgather_vv_i64m1_m(vbool64_t, vint64m1_t, vint64m1_t, vuint64m1_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vrgather_vv)))
vint64m2_t vrgather_vv_i64m2(vint64m2_t, vuint64m2_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vrgather_vv_m)))
vint64m2_t vrgather_vv_i64m2_m(vbool32_t, vint64m2_t, vint64m2_t, vuint64m2_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vrgather_vv)))
vint64m4_t vrgather_vv_i64m4(vint64m4_t, vuint64m4_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vrgather_vv_m)))
vint64m4_t vrgather_vv_i64m4_m(vbool16_t, vint64m4_t, vint64m4_t, vuint64m4_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vrgather_vv)))
vint64m8_t vrgather_vv_i64m8(vint64m8_t, vuint64m8_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vrgather_vv_m)))
vint64m8_t vrgather_vv_i64m8_m(vbool8_t, vint64m8_t, vint64m8_t, vuint64m8_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vrgather_vx)))
vint64m1_t vrgather_vx_i64m1(vint64m1_t, size_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vrgather_vx_m)))
vint64m1_t vrgather_vx_i64m1_m(vbool64_t, vint64m1_t, vint64m1_t, size_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vrgather_vx)))
vint64m2_t vrgather_vx_i64m2(vint64m2_t, size_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vrgather_vx_m)))
vint64m2_t vrgather_vx_i64m2_m(vbool32_t, vint64m2_t, vint64m2_t, size_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vrgather_vx)))
vint64m4_t vrgather_vx_i64m4(vint64m4_t, size_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vrgather_vx_m)))
vint64m4_t vrgather_vx_i64m4_m(vbool16_t, vint64m4_t, vint64m4_t, size_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vrgather_vx)))
vint64m8_t vrgather_vx_i64m8(vint64m8_t, size_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vrgather_vx_m)))
vint64m8_t vrgather_vx_i64m8_m(vbool8_t, vint64m8_t, vint64m8_t, size_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vrgatherei16_vv)))
vint64m1_t vrgatherei16_vv_i64m1(vint64m1_t, vuint16mf4_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vrgatherei16_vv_m)))
vint64m1_t vrgatherei16_vv_i64m1_m(vbool64_t, vint64m1_t, vint64m1_t, vuint16mf4_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vrgatherei16_vv)))
vint64m2_t vrgatherei16_vv_i64m2(vint64m2_t, vuint16mf2_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vrgatherei16_vv_m)))
vint64m2_t vrgatherei16_vv_i64m2_m(vbool32_t, vint64m2_t, vint64m2_t, vuint16mf2_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vrgatherei16_vv)))
vint64m4_t vrgatherei16_vv_i64m4(vint64m4_t, vuint16m1_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vrgatherei16_vv_m)))
vint64m4_t vrgatherei16_vv_i64m4_m(vbool16_t, vint64m4_t, vint64m4_t, vuint16m1_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vrgatherei16_vv)))
vint64m8_t vrgatherei16_vv_i64m8(vint64m8_t, vuint16m2_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vrgatherei16_vv_m)))
vint64m8_t vrgatherei16_vv_i64m8_m(vbool8_t, vint64m8_t, vint64m8_t, vuint16m2_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vrgather_vv)))
vuint64m1_t vrgather_vv_u64m1(vuint64m1_t, vuint64m1_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vrgather_vv_m)))
vuint64m1_t vrgather_vv_u64m1_m(vbool64_t, vuint64m1_t, vuint64m1_t, vuint64m1_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vrgather_vv)))
vuint64m2_t vrgather_vv_u64m2(vuint64m2_t, vuint64m2_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vrgather_vv_m)))
vuint64m2_t vrgather_vv_u64m2_m(vbool32_t, vuint64m2_t, vuint64m2_t, vuint64m2_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vrgather_vv)))
vuint64m4_t vrgather_vv_u64m4(vuint64m4_t, vuint64m4_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vrgather_vv_m)))
vuint64m4_t vrgather_vv_u64m4_m(vbool16_t, vuint64m4_t, vuint64m4_t, vuint64m4_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vrgather_vv)))
vuint64m8_t vrgather_vv_u64m8(vuint64m8_t, vuint64m8_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vrgather_vv_m)))
vuint64m8_t vrgather_vv_u64m8_m(vbool8_t, vuint64m8_t, vuint64m8_t, vuint64m8_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vrgather_vx)))
vuint64m1_t vrgather_vx_u64m1(vuint64m1_t, size_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vrgather_vx_m)))
vuint64m1_t vrgather_vx_u64m1_m(vbool64_t, vuint64m1_t, vuint64m1_t, size_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vrgather_vx)))
vuint64m2_t vrgather_vx_u64m2(vuint64m2_t, size_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vrgather_vx_m)))
vuint64m2_t vrgather_vx_u64m2_m(vbool32_t, vuint64m2_t, vuint64m2_t, size_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vrgather_vx)))
vuint64m4_t vrgather_vx_u64m4(vuint64m4_t, size_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vrgather_vx_m)))
vuint64m4_t vrgather_vx_u64m4_m(vbool16_t, vuint64m4_t, vuint64m4_t, size_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vrgather_vx)))
vuint64m8_t vrgather_vx_u64m8(vuint64m8_t, size_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vrgather_vx_m)))
vuint64m8_t vrgather_vx_u64m8_m(vbool8_t, vuint64m8_t, vuint64m8_t, size_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vrgatherei16_vv)))
vuint64m1_t vrgatherei16_vv_u64m1(vuint64m1_t, vuint16mf4_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vrgatherei16_vv_m)))
vuint64m1_t vrgatherei16_vv_u64m1_m(vbool64_t, vuint64m1_t, vuint64m1_t, vuint16mf4_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vrgatherei16_vv)))
vuint64m2_t vrgatherei16_vv_u64m2(vuint64m2_t, vuint16mf2_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vrgatherei16_vv_m)))
vuint64m2_t vrgatherei16_vv_u64m2_m(vbool32_t, vuint64m2_t, vuint64m2_t, vuint16mf2_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vrgatherei16_vv)))
vuint64m4_t vrgatherei16_vv_u64m4(vuint64m4_t, vuint16m1_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vrgatherei16_vv_m)))
vuint64m4_t vrgatherei16_vv_u64m4_m(vbool16_t, vuint64m4_t, vuint64m4_t, vuint16m1_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vrgatherei16_vv)))
vuint64m8_t vrgatherei16_vv_u64m8(vuint64m8_t, vuint16m2_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vrgatherei16_vv_m)))
vuint64m8_t vrgatherei16_vv_u64m8_m(vbool8_t, vuint64m8_t, vuint64m8_t, vuint16m2_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vcompress_vm)))
vint64m1_t vcompress_vm_i64m1(vbool64_t, vint64m1_t, vint64m1_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vcompress_vm)))
vint64m2_t vcompress_vm_i64m2(vbool32_t, vint64m2_t, vint64m2_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vcompress_vm)))
vint64m4_t vcompress_vm_i64m4(vbool16_t, vint64m4_t, vint64m4_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vcompress_vm)))
vint64m8_t vcompress_vm_i64m8(vbool8_t, vint64m8_t, vint64m8_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vsuxei8_v)))
void vsuxei8_v_u64m1(uint64_t *, vuint8mf8_t, vuint64m1_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vsuxei8_v_m)))
void vsuxei8_v_u64m1_m(vbool64_t, uint64_t *, vuint8mf8_t, vuint64m1_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vsuxei8_v)))
void vsuxei8_v_u64m2(uint64_t *, vuint8mf4_t, vuint64m2_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vsuxei8_v_m)))
void vsuxei8_v_u64m2_m(vbool32_t, uint64_t *, vuint8mf4_t, vuint64m2_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vsuxei8_v)))
void vsuxei8_v_u64m4(uint64_t *, vuint8mf2_t, vuint64m4_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vsuxei8_v_m)))
void vsuxei8_v_u64m4_m(vbool16_t, uint64_t *, vuint8mf2_t, vuint64m4_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vsuxei8_v)))
void vsuxei8_v_u64m8(uint64_t *, vuint8m1_t, vuint64m8_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vsuxei8_v_m)))
void vsuxei8_v_u64m8_m(vbool8_t, uint64_t *, vuint8m1_t, vuint64m8_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vcompress_vm)))
vuint64m1_t vcompress_vm_u64m1(vbool64_t, vuint64m1_t, vuint64m1_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vcompress_vm)))
vuint64m2_t vcompress_vm_u64m2(vbool32_t, vuint64m2_t, vuint64m2_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vcompress_vm)))
vuint64m4_t vcompress_vm_u64m4(vbool16_t, vuint64m4_t, vuint64m4_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vcompress_vm)))
vuint64m8_t vcompress_vm_u64m8(vbool8_t, vuint64m8_t, vuint64m8_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vget_v)))
vint64m1_t vget_v_i64m2_i64m1(vint64m2_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vget_v)))
vint64m1_t vget_v_i64m4_i64m1(vint64m4_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vget_v)))
vint64m1_t vget_v_i64m8_i64m1(vint64m8_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vget_v)))
vuint64m1_t vget_v_u64m2_u64m1(vuint64m2_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vget_v)))
vuint64m1_t vget_v_u64m4_u64m1(vuint64m4_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vget_v)))
vuint64m1_t vget_v_u64m8_u64m1(vuint64m8_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vget_v)))
vint64m2_t vget_v_i64m4_i64m2(vint64m4_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vget_v)))
vint64m2_t vget_v_i64m8_i64m2(vint64m8_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vget_v)))
vuint64m2_t vget_v_u64m4_u64m2(vuint64m4_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vget_v)))
vuint64m2_t vget_v_u64m8_u64m2(vuint64m8_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vget_v)))
vint64m4_t vget_v_i64m8_i64m4(vint64m8_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vget_v)))
vuint64m4_t vget_v_u64m8_u64m4(vuint64m8_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vset_v)))
vint64m2_t vset_v_i64m1_i64m2(vint64m2_t, size_t, vint64m1_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vset_v)))
vuint64m2_t vset_v_u64m1_u64m2(vuint64m2_t, size_t, vuint64m1_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vset_v)))
vint64m4_t vset_v_i64m1_i64m4(vint64m4_t, size_t, vint64m1_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vset_v)))
vint64m4_t vset_v_i64m2_i64m4(vint64m4_t, size_t, vint64m2_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vsuxei16_v)))
void vsuxei16_v_i64m1(int64_t *, vuint16mf4_t, vint64m1_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vsuxei16_v_m)))
void vsuxei16_v_i64m1_m(vbool64_t, int64_t *, vuint16mf4_t, vint64m1_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vsuxei16_v)))
void vsuxei16_v_i64m2(int64_t *, vuint16mf2_t, vint64m2_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vsuxei16_v_m)))
void vsuxei16_v_i64m2_m(vbool32_t, int64_t *, vuint16mf2_t, vint64m2_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vsuxei16_v)))
void vsuxei16_v_i64m4(int64_t *, vuint16m1_t, vint64m4_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vsuxei16_v_m)))
void vsuxei16_v_i64m4_m(vbool16_t, int64_t *, vuint16m1_t, vint64m4_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vsuxei16_v)))
void vsuxei16_v_i64m8(int64_t *, vuint16m2_t, vint64m8_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vsuxei16_v_m)))
void vsuxei16_v_i64m8_m(vbool8_t, int64_t *, vuint16m2_t, vint64m8_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vset_v)))
vuint64m4_t vset_v_u64m1_u64m4(vuint64m4_t, size_t, vuint64m1_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vset_v)))
vuint64m4_t vset_v_u64m2_u64m4(vuint64m4_t, size_t, vuint64m2_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vset_v)))
vint64m8_t vset_v_i64m1_i64m8(vint64m8_t, size_t, vint64m1_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vset_v)))
vint64m8_t vset_v_i64m2_i64m8(vint64m8_t, size_t, vint64m2_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vset_v)))
vint64m8_t vset_v_i64m4_i64m8(vint64m8_t, size_t, vint64m4_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vset_v)))
vuint64m8_t vset_v_u64m1_u64m8(vuint64m8_t, size_t, vuint64m1_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vset_v)))
vuint64m8_t vset_v_u64m2_u64m8(vuint64m8_t, size_t, vuint64m2_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vset_v)))
vuint64m8_t vset_v_u64m4_u64m8(vuint64m8_t, size_t, vuint64m4_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vsuxei16_v)))
void vsuxei16_v_u64m1(uint64_t *, vuint16mf4_t, vuint64m1_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vsuxei16_v_m)))
void vsuxei16_v_u64m1_m(vbool64_t, uint64_t *, vuint16mf4_t, vuint64m1_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vsuxei16_v)))
void vsuxei16_v_u64m2(uint64_t *, vuint16mf2_t, vuint64m2_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vsuxei16_v_m)))
void vsuxei16_v_u64m2_m(vbool32_t, uint64_t *, vuint16mf2_t, vuint64m2_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vsuxei16_v)))
void vsuxei16_v_u64m4(uint64_t *, vuint16m1_t, vuint64m4_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vsuxei16_v_m)))
void vsuxei16_v_u64m4_m(vbool16_t, uint64_t *, vuint16m1_t, vuint64m4_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vsuxei16_v)))
void vsuxei16_v_u64m8(uint64_t *, vuint16m2_t, vuint64m8_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vsuxei16_v_m)))
void vsuxei16_v_u64m8_m(vbool8_t, uint64_t *, vuint16m2_t, vuint64m8_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vsuxei32_v)))
void vsuxei32_v_i64m1(int64_t *, vuint32mf2_t, vint64m1_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vsuxei32_v_m)))
void vsuxei32_v_i64m1_m(vbool64_t, int64_t *, vuint32mf2_t, vint64m1_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vsuxei32_v)))
void vsuxei32_v_i64m2(int64_t *, vuint32m1_t, vint64m2_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vsuxei32_v_m)))
void vsuxei32_v_i64m2_m(vbool32_t, int64_t *, vuint32m1_t, vint64m2_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vsuxei32_v)))
void vsuxei32_v_i64m4(int64_t *, vuint32m2_t, vint64m4_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vsuxei32_v_m)))
void vsuxei32_v_i64m4_m(vbool16_t, int64_t *, vuint32m2_t, vint64m4_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vsuxei32_v)))
void vsuxei32_v_i64m8(int64_t *, vuint32m4_t, vint64m8_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vsuxei32_v_m)))
void vsuxei32_v_i64m8_m(vbool8_t, int64_t *, vuint32m4_t, vint64m8_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vsuxei32_v)))
void vsuxei32_v_u64m1(uint64_t *, vuint32mf2_t, vuint64m1_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vsuxei32_v_m)))
void vsuxei32_v_u64m1_m(vbool64_t, uint64_t *, vuint32mf2_t, vuint64m1_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vsuxei32_v)))
void vsuxei32_v_u64m2(uint64_t *, vuint32m1_t, vuint64m2_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vsuxei32_v_m)))
void vsuxei32_v_u64m2_m(vbool32_t, uint64_t *, vuint32m1_t, vuint64m2_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vsuxei32_v)))
void vsuxei32_v_u64m4(uint64_t *, vuint32m2_t, vuint64m4_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vsuxei32_v_m)))
void vsuxei32_v_u64m4_m(vbool16_t, uint64_t *, vuint32m2_t, vuint64m4_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vsuxei32_v)))
void vsuxei32_v_u64m8(uint64_t *, vuint32m4_t, vuint64m8_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vsuxei32_v_m)))
void vsuxei32_v_u64m8_m(vbool8_t, uint64_t *, vuint32m4_t, vuint64m8_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vsoxei8_v)))
void vsoxei8_v_i64m1(int64_t *, vuint8mf8_t, vint64m1_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vsoxei8_v_m)))
void vsoxei8_v_i64m1_m(vbool64_t, int64_t *, vuint8mf8_t, vint64m1_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vsoxei8_v)))
void vsoxei8_v_i64m2(int64_t *, vuint8mf4_t, vint64m2_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vsoxei8_v_m)))
void vsoxei8_v_i64m2_m(vbool32_t, int64_t *, vuint8mf4_t, vint64m2_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vsoxei8_v)))
void vsoxei8_v_i64m4(int64_t *, vuint8mf2_t, vint64m4_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vsoxei8_v_m)))
void vsoxei8_v_i64m4_m(vbool16_t, int64_t *, vuint8mf2_t, vint64m4_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vsoxei8_v)))
void vsoxei8_v_i64m8(int64_t *, vuint8m1_t, vint64m8_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vsoxei8_v_m)))
void vsoxei8_v_i64m8_m(vbool8_t, int64_t *, vuint8m1_t, vint64m8_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vsoxei8_v)))
void vsoxei8_v_u64m1(uint64_t *, vuint8mf8_t, vuint64m1_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vsoxei8_v_m)))
void vsoxei8_v_u64m1_m(vbool64_t, uint64_t *, vuint8mf8_t, vuint64m1_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vsoxei8_v)))
void vsoxei8_v_u64m2(uint64_t *, vuint8mf4_t, vuint64m2_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vsoxei8_v_m)))
void vsoxei8_v_u64m2_m(vbool32_t, uint64_t *, vuint8mf4_t, vuint64m2_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vsoxei8_v)))
void vsoxei8_v_u64m4(uint64_t *, vuint8mf2_t, vuint64m4_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vsoxei8_v_m)))
void vsoxei8_v_u64m4_m(vbool16_t, uint64_t *, vuint8mf2_t, vuint64m4_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vsoxei8_v)))
void vsoxei8_v_u64m8(uint64_t *, vuint8m1_t, vuint64m8_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vsoxei8_v_m)))
void vsoxei8_v_u64m8_m(vbool8_t, uint64_t *, vuint8m1_t, vuint64m8_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vsoxei16_v)))
void vsoxei16_v_i64m1(int64_t *, vuint16mf4_t, vint64m1_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vsoxei16_v_m)))
void vsoxei16_v_i64m1_m(vbool64_t, int64_t *, vuint16mf4_t, vint64m1_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vsoxei16_v)))
void vsoxei16_v_i64m2(int64_t *, vuint16mf2_t, vint64m2_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vsoxei16_v_m)))
void vsoxei16_v_i64m2_m(vbool32_t, int64_t *, vuint16mf2_t, vint64m2_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vsoxei16_v)))
void vsoxei16_v_i64m4(int64_t *, vuint16m1_t, vint64m4_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vsoxei16_v_m)))
void vsoxei16_v_i64m4_m(vbool16_t, int64_t *, vuint16m1_t, vint64m4_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vsoxei16_v)))
void vsoxei16_v_i64m8(int64_t *, vuint16m2_t, vint64m8_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vsoxei16_v_m)))
void vsoxei16_v_i64m8_m(vbool8_t, int64_t *, vuint16m2_t, vint64m8_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vsoxei16_v)))
void vsoxei16_v_u64m1(uint64_t *, vuint16mf4_t, vuint64m1_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vsoxei16_v_m)))
void vsoxei16_v_u64m1_m(vbool64_t, uint64_t *, vuint16mf4_t, vuint64m1_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vsoxei16_v)))
void vsoxei16_v_u64m2(uint64_t *, vuint16mf2_t, vuint64m2_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vsoxei16_v_m)))
void vsoxei16_v_u64m2_m(vbool32_t, uint64_t *, vuint16mf2_t, vuint64m2_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vsoxei16_v)))
void vsoxei16_v_u64m4(uint64_t *, vuint16m1_t, vuint64m4_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vsoxei16_v_m)))
void vsoxei16_v_u64m4_m(vbool16_t, uint64_t *, vuint16m1_t, vuint64m4_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vsoxei16_v)))
void vsoxei16_v_u64m8(uint64_t *, vuint16m2_t, vuint64m8_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vsoxei16_v_m)))
void vsoxei16_v_u64m8_m(vbool8_t, uint64_t *, vuint16m2_t, vuint64m8_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vsoxei32_v)))
void vsoxei32_v_i64m1(int64_t *, vuint32mf2_t, vint64m1_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vsoxei32_v_m)))
void vsoxei32_v_i64m1_m(vbool64_t, int64_t *, vuint32mf2_t, vint64m1_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vsoxei32_v)))
void vsoxei32_v_i64m2(int64_t *, vuint32m1_t, vint64m2_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vsoxei32_v_m)))
void vsoxei32_v_i64m2_m(vbool32_t, int64_t *, vuint32m1_t, vint64m2_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vsoxei32_v)))
void vsoxei32_v_i64m4(int64_t *, vuint32m2_t, vint64m4_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vsoxei32_v_m)))
void vsoxei32_v_i64m4_m(vbool16_t, int64_t *, vuint32m2_t, vint64m4_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vsoxei32_v)))
void vsoxei32_v_i64m8(int64_t *, vuint32m4_t, vint64m8_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vsoxei32_v_m)))
void vsoxei32_v_i64m8_m(vbool8_t, int64_t *, vuint32m4_t, vint64m8_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vsoxei32_v)))
void vsoxei32_v_u64m1(uint64_t *, vuint32mf2_t, vuint64m1_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vsoxei32_v_m)))
void vsoxei32_v_u64m1_m(vbool64_t, uint64_t *, vuint32mf2_t, vuint64m1_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vsoxei32_v)))
void vsoxei32_v_u64m2(uint64_t *, vuint32m1_t, vuint64m2_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vsoxei32_v_m)))
void vsoxei32_v_u64m2_m(vbool32_t, uint64_t *, vuint32m1_t, vuint64m2_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vsoxei32_v)))
void vsoxei32_v_u64m4(uint64_t *, vuint32m2_t, vuint64m4_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vsoxei32_v_m)))
void vsoxei32_v_u64m4_m(vbool16_t, uint64_t *, vuint32m2_t, vuint64m4_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vsoxei32_v)))
void vsoxei32_v_u64m8(uint64_t *, vuint32m4_t, vuint64m8_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vsoxei32_v_m)))
void vsoxei32_v_u64m8_m(vbool8_t, uint64_t *, vuint32m4_t, vuint64m8_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vle64ff_v)))
vint64m1_t vle64ff_v_i64m1(const int64_t *, size_t *, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vle64ff_v_m)))
vint64m1_t vle64ff_v_i64m1_m(vbool64_t, vint64m1_t, const int64_t *, size_t *, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vle64ff_v)))
vint64m2_t vle64ff_v_i64m2(const int64_t *, size_t *, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vle64ff_v_m)))
vint64m2_t vle64ff_v_i64m2_m(vbool32_t, vint64m2_t, const int64_t *, size_t *, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vle64ff_v)))
vint64m4_t vle64ff_v_i64m4(const int64_t *, size_t *, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vle64ff_v_m)))
vint64m4_t vle64ff_v_i64m4_m(vbool16_t, vint64m4_t, const int64_t *, size_t *, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vle64ff_v)))
vint64m8_t vle64ff_v_i64m8(const int64_t *, size_t *, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vle64ff_v_m)))
vint64m8_t vle64ff_v_i64m8_m(vbool8_t, vint64m8_t, const int64_t *, size_t *, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vle64ff_v)))
vuint64m1_t vle64ff_v_u64m1(const uint64_t *, size_t *, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vle64ff_v_m)))
vuint64m1_t vle64ff_v_u64m1_m(vbool64_t, vuint64m1_t, const uint64_t *, size_t *, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vle64ff_v)))
vuint64m2_t vle64ff_v_u64m2(const uint64_t *, size_t *, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vle64ff_v_m)))
vuint64m2_t vle64ff_v_u64m2_m(vbool32_t, vuint64m2_t, const uint64_t *, size_t *, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vle64ff_v)))
vuint64m4_t vle64ff_v_u64m4(const uint64_t *, size_t *, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vle64ff_v_m)))
vuint64m4_t vle64ff_v_u64m4_m(vbool16_t, vuint64m4_t, const uint64_t *, size_t *, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vle64ff_v)))
vuint64m8_t vle64ff_v_u64m8(const uint64_t *, size_t *, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vle64ff_v_m)))
vuint64m8_t vle64ff_v_u64m8_m(vbool8_t, vuint64m8_t, const uint64_t *, size_t *, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vlseg2e64_v)))
void vlseg2e64_v_i64m1(vint64m1_t *, vint64m1_t *, const int64_t *, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vlseg2e64_v_m)))
void vlseg2e64_v_i64m1_m(vint64m1_t *, vint64m1_t *, vbool64_t, vint64m1_t, vint64m1_t, const int64_t *, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vlseg2e64_v)))
void vlseg2e64_v_i64m2(vint64m2_t *, vint64m2_t *, const int64_t *, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vlseg2e64_v_m)))
void vlseg2e64_v_i64m2_m(vint64m2_t *, vint64m2_t *, vbool32_t, vint64m2_t, vint64m2_t, const int64_t *, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vlseg2e64_v)))
void vlseg2e64_v_i64m4(vint64m4_t *, vint64m4_t *, const int64_t *, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vlseg2e64_v_m)))
void vlseg2e64_v_i64m4_m(vint64m4_t *, vint64m4_t *, vbool16_t, vint64m4_t, vint64m4_t, const int64_t *, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vlseg2e64_v)))
void vlseg2e64_v_u64m1(vuint64m1_t *, vuint64m1_t *, const uint64_t *, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vlseg2e64_v_m)))
void vlseg2e64_v_u64m1_m(vuint64m1_t *, vuint64m1_t *, vbool64_t, vuint64m1_t, vuint64m1_t, const uint64_t *, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vlseg2e64_v)))
void vlseg2e64_v_u64m2(vuint64m2_t *, vuint64m2_t *, const uint64_t *, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vlseg2e64_v_m)))
void vlseg2e64_v_u64m2_m(vuint64m2_t *, vuint64m2_t *, vbool32_t, vuint64m2_t, vuint64m2_t, const uint64_t *, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vlseg2e64_v)))
void vlseg2e64_v_u64m4(vuint64m4_t *, vuint64m4_t *, const uint64_t *, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vlseg2e64_v_m)))
void vlseg2e64_v_u64m4_m(vuint64m4_t *, vuint64m4_t *, vbool16_t, vuint64m4_t, vuint64m4_t, const uint64_t *, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vlseg3e64_v)))
void vlseg3e64_v_i64m1(vint64m1_t *, vint64m1_t *, vint64m1_t *, const int64_t *, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vlseg3e64_v_m)))
void vlseg3e64_v_i64m1_m(vint64m1_t *, vint64m1_t *, vint64m1_t *, vbool64_t, vint64m1_t, vint64m1_t, vint64m1_t, const int64_t *, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vlseg3e64_v)))
void vlseg3e64_v_i64m2(vint64m2_t *, vint64m2_t *, vint64m2_t *, const int64_t *, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vlseg3e64_v_m)))
void vlseg3e64_v_i64m2_m(vint64m2_t *, vint64m2_t *, vint64m2_t *, vbool32_t, vint64m2_t, vint64m2_t, vint64m2_t, const int64_t *, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vlseg3e64_v)))
void vlseg3e64_v_u64m1(vuint64m1_t *, vuint64m1_t *, vuint64m1_t *, const uint64_t *, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vlseg3e64_v_m)))
void vlseg3e64_v_u64m1_m(vuint64m1_t *, vuint64m1_t *, vuint64m1_t *, vbool64_t, vuint64m1_t, vuint64m1_t, vuint64m1_t, const uint64_t *, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vlseg3e64_v)))
void vlseg3e64_v_u64m2(vuint64m2_t *, vuint64m2_t *, vuint64m2_t *, const uint64_t *, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vlseg3e64_v_m)))
void vlseg3e64_v_u64m2_m(vuint64m2_t *, vuint64m2_t *, vuint64m2_t *, vbool32_t, vuint64m2_t, vuint64m2_t, vuint64m2_t, const uint64_t *, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vlseg4e64_v)))
void vlseg4e64_v_i64m1(vint64m1_t *, vint64m1_t *, vint64m1_t *, vint64m1_t *, const int64_t *, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vlseg4e64_v_m)))
void vlseg4e64_v_i64m1_m(vint64m1_t *, vint64m1_t *, vint64m1_t *, vint64m1_t *, vbool64_t, vint64m1_t, vint64m1_t, vint64m1_t, vint64m1_t, const int64_t *, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vlseg4e64_v)))
void vlseg4e64_v_i64m2(vint64m2_t *, vint64m2_t *, vint64m2_t *, vint64m2_t *, const int64_t *, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vlseg4e64_v_m)))
void vlseg4e64_v_i64m2_m(vint64m2_t *, vint64m2_t *, vint64m2_t *, vint64m2_t *, vbool32_t, vint64m2_t, vint64m2_t, vint64m2_t, vint64m2_t, const int64_t *, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vlseg4e64_v)))
void vlseg4e64_v_u64m1(vuint64m1_t *, vuint64m1_t *, vuint64m1_t *, vuint64m1_t *, const uint64_t *, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vlseg4e64_v_m)))
void vlseg4e64_v_u64m1_m(vuint64m1_t *, vuint64m1_t *, vuint64m1_t *, vuint64m1_t *, vbool64_t, vuint64m1_t, vuint64m1_t, vuint64m1_t, vuint64m1_t, const uint64_t *, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vlseg4e64_v)))
void vlseg4e64_v_u64m2(vuint64m2_t *, vuint64m2_t *, vuint64m2_t *, vuint64m2_t *, const uint64_t *, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vlseg4e64_v_m)))
void vlseg4e64_v_u64m2_m(vuint64m2_t *, vuint64m2_t *, vuint64m2_t *, vuint64m2_t *, vbool32_t, vuint64m2_t, vuint64m2_t, vuint64m2_t, vuint64m2_t, const uint64_t *, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vlseg5e64_v)))
void vlseg5e64_v_i64m1(vint64m1_t *, vint64m1_t *, vint64m1_t *, vint64m1_t *, vint64m1_t *, const int64_t *, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vlseg5e64_v_m)))
void vlseg5e64_v_i64m1_m(vint64m1_t *, vint64m1_t *, vint64m1_t *, vint64m1_t *, vint64m1_t *, vbool64_t, vint64m1_t, vint64m1_t, vint64m1_t, vint64m1_t, vint64m1_t, const int64_t *, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vlseg5e64_v)))
void vlseg5e64_v_u64m1(vuint64m1_t *, vuint64m1_t *, vuint64m1_t *, vuint64m1_t *, vuint64m1_t *, const uint64_t *, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vlseg5e64_v_m)))
void vlseg5e64_v_u64m1_m(vuint64m1_t *, vuint64m1_t *, vuint64m1_t *, vuint64m1_t *, vuint64m1_t *, vbool64_t, vuint64m1_t, vuint64m1_t, vuint64m1_t, vuint64m1_t, vuint64m1_t, const uint64_t *, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vlseg6e64_v)))
void vlseg6e64_v_i64m1(vint64m1_t *, vint64m1_t *, vint64m1_t *, vint64m1_t *, vint64m1_t *, vint64m1_t *, const int64_t *, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vlseg6e64_v_m)))
void vlseg6e64_v_i64m1_m(vint64m1_t *, vint64m1_t *, vint64m1_t *, vint64m1_t *, vint64m1_t *, vint64m1_t *, vbool64_t, vint64m1_t, vint64m1_t, vint64m1_t, vint64m1_t, vint64m1_t, vint64m1_t, const int64_t *, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vlseg6e64_v)))
void vlseg6e64_v_u64m1(vuint64m1_t *, vuint64m1_t *, vuint64m1_t *, vuint64m1_t *, vuint64m1_t *, vuint64m1_t *, const uint64_t *, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vlseg6e64_v_m)))
void vlseg6e64_v_u64m1_m(vuint64m1_t *, vuint64m1_t *, vuint64m1_t *, vuint64m1_t *, vuint64m1_t *, vuint64m1_t *, vbool64_t, vuint64m1_t, vuint64m1_t, vuint64m1_t, vuint64m1_t, vuint64m1_t, vuint64m1_t, const uint64_t *, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vlseg7e64_v)))
void vlseg7e64_v_i64m1(vint64m1_t *, vint64m1_t *, vint64m1_t *, vint64m1_t *, vint64m1_t *, vint64m1_t *, vint64m1_t *, const int64_t *, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vlseg7e64_v_m)))
void vlseg7e64_v_i64m1_m(vint64m1_t *, vint64m1_t *, vint64m1_t *, vint64m1_t *, vint64m1_t *, vint64m1_t *, vint64m1_t *, vbool64_t, vint64m1_t, vint64m1_t, vint64m1_t, vint64m1_t, vint64m1_t, vint64m1_t, vint64m1_t, const int64_t *, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vlseg7e64_v)))
void vlseg7e64_v_u64m1(vuint64m1_t *, vuint64m1_t *, vuint64m1_t *, vuint64m1_t *, vuint64m1_t *, vuint64m1_t *, vuint64m1_t *, const uint64_t *, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vlseg7e64_v_m)))
void vlseg7e64_v_u64m1_m(vuint64m1_t *, vuint64m1_t *, vuint64m1_t *, vuint64m1_t *, vuint64m1_t *, vuint64m1_t *, vuint64m1_t *, vbool64_t, vuint64m1_t, vuint64m1_t, vuint64m1_t, vuint64m1_t, vuint64m1_t, vuint64m1_t, vuint64m1_t, const uint64_t *, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vlseg8e64_v)))
void vlseg8e64_v_i64m1(vint64m1_t *, vint64m1_t *, vint64m1_t *, vint64m1_t *, vint64m1_t *, vint64m1_t *, vint64m1_t *, vint64m1_t *, const int64_t *, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vlseg8e64_v_m)))
void vlseg8e64_v_i64m1_m(vint64m1_t *, vint64m1_t *, vint64m1_t *, vint64m1_t *, vint64m1_t *, vint64m1_t *, vint64m1_t *, vint64m1_t *, vbool64_t, vint64m1_t, vint64m1_t, vint64m1_t, vint64m1_t, vint64m1_t, vint64m1_t, vint64m1_t, vint64m1_t, const int64_t *, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vlseg8e64_v)))
void vlseg8e64_v_u64m1(vuint64m1_t *, vuint64m1_t *, vuint64m1_t *, vuint64m1_t *, vuint64m1_t *, vuint64m1_t *, vuint64m1_t *, vuint64m1_t *, const uint64_t *, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vlseg8e64_v_m)))
void vlseg8e64_v_u64m1_m(vuint64m1_t *, vuint64m1_t *, vuint64m1_t *, vuint64m1_t *, vuint64m1_t *, vuint64m1_t *, vuint64m1_t *, vuint64m1_t *, vbool64_t, vuint64m1_t, vuint64m1_t, vuint64m1_t, vuint64m1_t, vuint64m1_t, vuint64m1_t, vuint64m1_t, vuint64m1_t, const uint64_t *, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vlseg2e64ff_v)))
void vlseg2e64ff_v_i64m1(vint64m1_t *, vint64m1_t *, const int64_t *, size_t *, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vlseg2e64ff_v_m)))
void vlseg2e64ff_v_i64m1_m(vint64m1_t *, vint64m1_t *, vbool64_t, vint64m1_t, vint64m1_t, const int64_t *, size_t *, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vlseg2e64ff_v)))
void vlseg2e64ff_v_i64m2(vint64m2_t *, vint64m2_t *, const int64_t *, size_t *, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vlseg2e64ff_v_m)))
void vlseg2e64ff_v_i64m2_m(vint64m2_t *, vint64m2_t *, vbool32_t, vint64m2_t, vint64m2_t, const int64_t *, size_t *, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vlseg2e64ff_v)))
void vlseg2e64ff_v_i64m4(vint64m4_t *, vint64m4_t *, const int64_t *, size_t *, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vlseg2e64ff_v_m)))
void vlseg2e64ff_v_i64m4_m(vint64m4_t *, vint64m4_t *, vbool16_t, vint64m4_t, vint64m4_t, const int64_t *, size_t *, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vlseg2e64ff_v)))
void vlseg2e64ff_v_u64m1(vuint64m1_t *, vuint64m1_t *, const uint64_t *, size_t *, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vlseg2e64ff_v_m)))
void vlseg2e64ff_v_u64m1_m(vuint64m1_t *, vuint64m1_t *, vbool64_t, vuint64m1_t, vuint64m1_t, const uint64_t *, size_t *, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vlseg2e64ff_v)))
void vlseg2e64ff_v_u64m2(vuint64m2_t *, vuint64m2_t *, const uint64_t *, size_t *, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vlseg2e64ff_v_m)))
void vlseg2e64ff_v_u64m2_m(vuint64m2_t *, vuint64m2_t *, vbool32_t, vuint64m2_t, vuint64m2_t, const uint64_t *, size_t *, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vlseg2e64ff_v)))
void vlseg2e64ff_v_u64m4(vuint64m4_t *, vuint64m4_t *, const uint64_t *, size_t *, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vlseg2e64ff_v_m)))
void vlseg2e64ff_v_u64m4_m(vuint64m4_t *, vuint64m4_t *, vbool16_t, vuint64m4_t, vuint64m4_t, const uint64_t *, size_t *, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vlseg3e64ff_v)))
void vlseg3e64ff_v_i64m1(vint64m1_t *, vint64m1_t *, vint64m1_t *, const int64_t *, size_t *, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vlseg3e64ff_v_m)))
void vlseg3e64ff_v_i64m1_m(vint64m1_t *, vint64m1_t *, vint64m1_t *, vbool64_t, vint64m1_t, vint64m1_t, vint64m1_t, const int64_t *, size_t *, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vlseg3e64ff_v)))
void vlseg3e64ff_v_i64m2(vint64m2_t *, vint64m2_t *, vint64m2_t *, const int64_t *, size_t *, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vlseg3e64ff_v_m)))
void vlseg3e64ff_v_i64m2_m(vint64m2_t *, vint64m2_t *, vint64m2_t *, vbool32_t, vint64m2_t, vint64m2_t, vint64m2_t, const int64_t *, size_t *, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vlseg3e64ff_v)))
void vlseg3e64ff_v_u64m1(vuint64m1_t *, vuint64m1_t *, vuint64m1_t *, const uint64_t *, size_t *, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vlseg3e64ff_v_m)))
void vlseg3e64ff_v_u64m1_m(vuint64m1_t *, vuint64m1_t *, vuint64m1_t *, vbool64_t, vuint64m1_t, vuint64m1_t, vuint64m1_t, const uint64_t *, size_t *, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vlseg3e64ff_v)))
void vlseg3e64ff_v_u64m2(vuint64m2_t *, vuint64m2_t *, vuint64m2_t *, const uint64_t *, size_t *, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vlseg3e64ff_v_m)))
void vlseg3e64ff_v_u64m2_m(vuint64m2_t *, vuint64m2_t *, vuint64m2_t *, vbool32_t, vuint64m2_t, vuint64m2_t, vuint64m2_t, const uint64_t *, size_t *, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vlseg4e64ff_v)))
void vlseg4e64ff_v_i64m1(vint64m1_t *, vint64m1_t *, vint64m1_t *, vint64m1_t *, const int64_t *, size_t *, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vlseg4e64ff_v_m)))
void vlseg4e64ff_v_i64m1_m(vint64m1_t *, vint64m1_t *, vint64m1_t *, vint64m1_t *, vbool64_t, vint64m1_t, vint64m1_t, vint64m1_t, vint64m1_t, const int64_t *, size_t *, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vlseg4e64ff_v)))
void vlseg4e64ff_v_i64m2(vint64m2_t *, vint64m2_t *, vint64m2_t *, vint64m2_t *, const int64_t *, size_t *, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vlseg4e64ff_v_m)))
void vlseg4e64ff_v_i64m2_m(vint64m2_t *, vint64m2_t *, vint64m2_t *, vint64m2_t *, vbool32_t, vint64m2_t, vint64m2_t, vint64m2_t, vint64m2_t, const int64_t *, size_t *, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vlseg4e64ff_v)))
void vlseg4e64ff_v_u64m1(vuint64m1_t *, vuint64m1_t *, vuint64m1_t *, vuint64m1_t *, const uint64_t *, size_t *, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vlseg4e64ff_v_m)))
void vlseg4e64ff_v_u64m1_m(vuint64m1_t *, vuint64m1_t *, vuint64m1_t *, vuint64m1_t *, vbool64_t, vuint64m1_t, vuint64m1_t, vuint64m1_t, vuint64m1_t, const uint64_t *, size_t *, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vlseg4e64ff_v)))
void vlseg4e64ff_v_u64m2(vuint64m2_t *, vuint64m2_t *, vuint64m2_t *, vuint64m2_t *, const uint64_t *, size_t *, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vlseg4e64ff_v_m)))
void vlseg4e64ff_v_u64m2_m(vuint64m2_t *, vuint64m2_t *, vuint64m2_t *, vuint64m2_t *, vbool32_t, vuint64m2_t, vuint64m2_t, vuint64m2_t, vuint64m2_t, const uint64_t *, size_t *, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vlseg5e64ff_v)))
void vlseg5e64ff_v_i64m1(vint64m1_t *, vint64m1_t *, vint64m1_t *, vint64m1_t *, vint64m1_t *, const int64_t *, size_t *, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vlseg5e64ff_v_m)))
void vlseg5e64ff_v_i64m1_m(vint64m1_t *, vint64m1_t *, vint64m1_t *, vint64m1_t *, vint64m1_t *, vbool64_t, vint64m1_t, vint64m1_t, vint64m1_t, vint64m1_t, vint64m1_t, const int64_t *, size_t *, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vlseg5e64ff_v)))
void vlseg5e64ff_v_u64m1(vuint64m1_t *, vuint64m1_t *, vuint64m1_t *, vuint64m1_t *, vuint64m1_t *, const uint64_t *, size_t *, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vlseg5e64ff_v_m)))
void vlseg5e64ff_v_u64m1_m(vuint64m1_t *, vuint64m1_t *, vuint64m1_t *, vuint64m1_t *, vuint64m1_t *, vbool64_t, vuint64m1_t, vuint64m1_t, vuint64m1_t, vuint64m1_t, vuint64m1_t, const uint64_t *, size_t *, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vlseg6e64ff_v)))
void vlseg6e64ff_v_i64m1(vint64m1_t *, vint64m1_t *, vint64m1_t *, vint64m1_t *, vint64m1_t *, vint64m1_t *, const int64_t *, size_t *, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vlseg6e64ff_v_m)))
void vlseg6e64ff_v_i64m1_m(vint64m1_t *, vint64m1_t *, vint64m1_t *, vint64m1_t *, vint64m1_t *, vint64m1_t *, vbool64_t, vint64m1_t, vint64m1_t, vint64m1_t, vint64m1_t, vint64m1_t, vint64m1_t, const int64_t *, size_t *, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vlseg6e64ff_v)))
void vlseg6e64ff_v_u64m1(vuint64m1_t *, vuint64m1_t *, vuint64m1_t *, vuint64m1_t *, vuint64m1_t *, vuint64m1_t *, const uint64_t *, size_t *, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vlseg6e64ff_v_m)))
void vlseg6e64ff_v_u64m1_m(vuint64m1_t *, vuint64m1_t *, vuint64m1_t *, vuint64m1_t *, vuint64m1_t *, vuint64m1_t *, vbool64_t, vuint64m1_t, vuint64m1_t, vuint64m1_t, vuint64m1_t, vuint64m1_t, vuint64m1_t, const uint64_t *, size_t *, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vlseg7e64ff_v)))
void vlseg7e64ff_v_i64m1(vint64m1_t *, vint64m1_t *, vint64m1_t *, vint64m1_t *, vint64m1_t *, vint64m1_t *, vint64m1_t *, const int64_t *, size_t *, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vlseg7e64ff_v_m)))
void vlseg7e64ff_v_i64m1_m(vint64m1_t *, vint64m1_t *, vint64m1_t *, vint64m1_t *, vint64m1_t *, vint64m1_t *, vint64m1_t *, vbool64_t, vint64m1_t, vint64m1_t, vint64m1_t, vint64m1_t, vint64m1_t, vint64m1_t, vint64m1_t, const int64_t *, size_t *, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vlseg7e64ff_v)))
void vlseg7e64ff_v_u64m1(vuint64m1_t *, vuint64m1_t *, vuint64m1_t *, vuint64m1_t *, vuint64m1_t *, vuint64m1_t *, vuint64m1_t *, const uint64_t *, size_t *, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vlseg7e64ff_v_m)))
void vlseg7e64ff_v_u64m1_m(vuint64m1_t *, vuint64m1_t *, vuint64m1_t *, vuint64m1_t *, vuint64m1_t *, vuint64m1_t *, vuint64m1_t *, vbool64_t, vuint64m1_t, vuint64m1_t, vuint64m1_t, vuint64m1_t, vuint64m1_t, vuint64m1_t, vuint64m1_t, const uint64_t *, size_t *, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vlseg8e64ff_v)))
void vlseg8e64ff_v_i64m1(vint64m1_t *, vint64m1_t *, vint64m1_t *, vint64m1_t *, vint64m1_t *, vint64m1_t *, vint64m1_t *, vint64m1_t *, const int64_t *, size_t *, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vlseg8e64ff_v_m)))
void vlseg8e64ff_v_i64m1_m(vint64m1_t *, vint64m1_t *, vint64m1_t *, vint64m1_t *, vint64m1_t *, vint64m1_t *, vint64m1_t *, vint64m1_t *, vbool64_t, vint64m1_t, vint64m1_t, vint64m1_t, vint64m1_t, vint64m1_t, vint64m1_t, vint64m1_t, vint64m1_t, const int64_t *, size_t *, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vlseg8e64ff_v)))
void vlseg8e64ff_v_u64m1(vuint64m1_t *, vuint64m1_t *, vuint64m1_t *, vuint64m1_t *, vuint64m1_t *, vuint64m1_t *, vuint64m1_t *, vuint64m1_t *, const uint64_t *, size_t *, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vlseg8e64ff_v_m)))
void vlseg8e64ff_v_u64m1_m(vuint64m1_t *, vuint64m1_t *, vuint64m1_t *, vuint64m1_t *, vuint64m1_t *, vuint64m1_t *, vuint64m1_t *, vuint64m1_t *, vbool64_t, vuint64m1_t, vuint64m1_t, vuint64m1_t, vuint64m1_t, vuint64m1_t, vuint64m1_t, vuint64m1_t, vuint64m1_t, const uint64_t *, size_t *, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vlsseg2e64_v)))
void vlsseg2e64_v_i64m1(vint64m1_t *, vint64m1_t *, const int64_t *, ptrdiff_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vlsseg2e64_v_m)))
void vlsseg2e64_v_i64m1_m(vint64m1_t *, vint64m1_t *, vbool64_t, vint64m1_t, vint64m1_t, const int64_t *, ptrdiff_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vlsseg2e64_v)))
void vlsseg2e64_v_i64m2(vint64m2_t *, vint64m2_t *, const int64_t *, ptrdiff_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vlsseg2e64_v_m)))
void vlsseg2e64_v_i64m2_m(vint64m2_t *, vint64m2_t *, vbool32_t, vint64m2_t, vint64m2_t, const int64_t *, ptrdiff_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vlsseg2e64_v)))
void vlsseg2e64_v_i64m4(vint64m4_t *, vint64m4_t *, const int64_t *, ptrdiff_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vlsseg2e64_v_m)))
void vlsseg2e64_v_i64m4_m(vint64m4_t *, vint64m4_t *, vbool16_t, vint64m4_t, vint64m4_t, const int64_t *, ptrdiff_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vlsseg2e64_v)))
void vlsseg2e64_v_u64m1(vuint64m1_t *, vuint64m1_t *, const uint64_t *, ptrdiff_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vlsseg2e64_v_m)))
void vlsseg2e64_v_u64m1_m(vuint64m1_t *, vuint64m1_t *, vbool64_t, vuint64m1_t, vuint64m1_t, const uint64_t *, ptrdiff_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vlsseg2e64_v)))
void vlsseg2e64_v_u64m2(vuint64m2_t *, vuint64m2_t *, const uint64_t *, ptrdiff_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vlsseg2e64_v_m)))
void vlsseg2e64_v_u64m2_m(vuint64m2_t *, vuint64m2_t *, vbool32_t, vuint64m2_t, vuint64m2_t, const uint64_t *, ptrdiff_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vlsseg2e64_v)))
void vlsseg2e64_v_u64m4(vuint64m4_t *, vuint64m4_t *, const uint64_t *, ptrdiff_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vlsseg2e64_v_m)))
void vlsseg2e64_v_u64m4_m(vuint64m4_t *, vuint64m4_t *, vbool16_t, vuint64m4_t, vuint64m4_t, const uint64_t *, ptrdiff_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vlsseg3e64_v)))
void vlsseg3e64_v_i64m1(vint64m1_t *, vint64m1_t *, vint64m1_t *, const int64_t *, ptrdiff_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vlsseg3e64_v_m)))
void vlsseg3e64_v_i64m1_m(vint64m1_t *, vint64m1_t *, vint64m1_t *, vbool64_t, vint64m1_t, vint64m1_t, vint64m1_t, const int64_t *, ptrdiff_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vlsseg3e64_v)))
void vlsseg3e64_v_i64m2(vint64m2_t *, vint64m2_t *, vint64m2_t *, const int64_t *, ptrdiff_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vlsseg3e64_v_m)))
void vlsseg3e64_v_i64m2_m(vint64m2_t *, vint64m2_t *, vint64m2_t *, vbool32_t, vint64m2_t, vint64m2_t, vint64m2_t, const int64_t *, ptrdiff_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vlsseg3e64_v)))
void vlsseg3e64_v_u64m1(vuint64m1_t *, vuint64m1_t *, vuint64m1_t *, const uint64_t *, ptrdiff_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vlsseg3e64_v_m)))
void vlsseg3e64_v_u64m1_m(vuint64m1_t *, vuint64m1_t *, vuint64m1_t *, vbool64_t, vuint64m1_t, vuint64m1_t, vuint64m1_t, const uint64_t *, ptrdiff_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vlsseg3e64_v)))
void vlsseg3e64_v_u64m2(vuint64m2_t *, vuint64m2_t *, vuint64m2_t *, const uint64_t *, ptrdiff_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vlsseg3e64_v_m)))
void vlsseg3e64_v_u64m2_m(vuint64m2_t *, vuint64m2_t *, vuint64m2_t *, vbool32_t, vuint64m2_t, vuint64m2_t, vuint64m2_t, const uint64_t *, ptrdiff_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vlsseg4e64_v)))
void vlsseg4e64_v_i64m1(vint64m1_t *, vint64m1_t *, vint64m1_t *, vint64m1_t *, const int64_t *, ptrdiff_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vlsseg4e64_v_m)))
void vlsseg4e64_v_i64m1_m(vint64m1_t *, vint64m1_t *, vint64m1_t *, vint64m1_t *, vbool64_t, vint64m1_t, vint64m1_t, vint64m1_t, vint64m1_t, const int64_t *, ptrdiff_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vlsseg4e64_v)))
void vlsseg4e64_v_i64m2(vint64m2_t *, vint64m2_t *, vint64m2_t *, vint64m2_t *, const int64_t *, ptrdiff_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vlsseg4e64_v_m)))
void vlsseg4e64_v_i64m2_m(vint64m2_t *, vint64m2_t *, vint64m2_t *, vint64m2_t *, vbool32_t, vint64m2_t, vint64m2_t, vint64m2_t, vint64m2_t, const int64_t *, ptrdiff_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vlsseg4e64_v)))
void vlsseg4e64_v_u64m1(vuint64m1_t *, vuint64m1_t *, vuint64m1_t *, vuint64m1_t *, const uint64_t *, ptrdiff_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vlsseg4e64_v_m)))
void vlsseg4e64_v_u64m1_m(vuint64m1_t *, vuint64m1_t *, vuint64m1_t *, vuint64m1_t *, vbool64_t, vuint64m1_t, vuint64m1_t, vuint64m1_t, vuint64m1_t, const uint64_t *, ptrdiff_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vlsseg4e64_v)))
void vlsseg4e64_v_u64m2(vuint64m2_t *, vuint64m2_t *, vuint64m2_t *, vuint64m2_t *, const uint64_t *, ptrdiff_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vlsseg4e64_v_m)))
void vlsseg4e64_v_u64m2_m(vuint64m2_t *, vuint64m2_t *, vuint64m2_t *, vuint64m2_t *, vbool32_t, vuint64m2_t, vuint64m2_t, vuint64m2_t, vuint64m2_t, const uint64_t *, ptrdiff_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vlsseg5e64_v)))
void vlsseg5e64_v_i64m1(vint64m1_t *, vint64m1_t *, vint64m1_t *, vint64m1_t *, vint64m1_t *, const int64_t *, ptrdiff_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vlsseg5e64_v_m)))
void vlsseg5e64_v_i64m1_m(vint64m1_t *, vint64m1_t *, vint64m1_t *, vint64m1_t *, vint64m1_t *, vbool64_t, vint64m1_t, vint64m1_t, vint64m1_t, vint64m1_t, vint64m1_t, const int64_t *, ptrdiff_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vlsseg5e64_v)))
void vlsseg5e64_v_u64m1(vuint64m1_t *, vuint64m1_t *, vuint64m1_t *, vuint64m1_t *, vuint64m1_t *, const uint64_t *, ptrdiff_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vlsseg5e64_v_m)))
void vlsseg5e64_v_u64m1_m(vuint64m1_t *, vuint64m1_t *, vuint64m1_t *, vuint64m1_t *, vuint64m1_t *, vbool64_t, vuint64m1_t, vuint64m1_t, vuint64m1_t, vuint64m1_t, vuint64m1_t, const uint64_t *, ptrdiff_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vlsseg6e64_v)))
void vlsseg6e64_v_i64m1(vint64m1_t *, vint64m1_t *, vint64m1_t *, vint64m1_t *, vint64m1_t *, vint64m1_t *, const int64_t *, ptrdiff_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vlsseg6e64_v_m)))
void vlsseg6e64_v_i64m1_m(vint64m1_t *, vint64m1_t *, vint64m1_t *, vint64m1_t *, vint64m1_t *, vint64m1_t *, vbool64_t, vint64m1_t, vint64m1_t, vint64m1_t, vint64m1_t, vint64m1_t, vint64m1_t, const int64_t *, ptrdiff_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vlsseg6e64_v)))
void vlsseg6e64_v_u64m1(vuint64m1_t *, vuint64m1_t *, vuint64m1_t *, vuint64m1_t *, vuint64m1_t *, vuint64m1_t *, const uint64_t *, ptrdiff_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vlsseg6e64_v_m)))
void vlsseg6e64_v_u64m1_m(vuint64m1_t *, vuint64m1_t *, vuint64m1_t *, vuint64m1_t *, vuint64m1_t *, vuint64m1_t *, vbool64_t, vuint64m1_t, vuint64m1_t, vuint64m1_t, vuint64m1_t, vuint64m1_t, vuint64m1_t, const uint64_t *, ptrdiff_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vlsseg7e64_v)))
void vlsseg7e64_v_i64m1(vint64m1_t *, vint64m1_t *, vint64m1_t *, vint64m1_t *, vint64m1_t *, vint64m1_t *, vint64m1_t *, const int64_t *, ptrdiff_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vlsseg7e64_v_m)))
void vlsseg7e64_v_i64m1_m(vint64m1_t *, vint64m1_t *, vint64m1_t *, vint64m1_t *, vint64m1_t *, vint64m1_t *, vint64m1_t *, vbool64_t, vint64m1_t, vint64m1_t, vint64m1_t, vint64m1_t, vint64m1_t, vint64m1_t, vint64m1_t, const int64_t *, ptrdiff_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vlsseg7e64_v)))
void vlsseg7e64_v_u64m1(vuint64m1_t *, vuint64m1_t *, vuint64m1_t *, vuint64m1_t *, vuint64m1_t *, vuint64m1_t *, vuint64m1_t *, const uint64_t *, ptrdiff_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vlsseg7e64_v_m)))
void vlsseg7e64_v_u64m1_m(vuint64m1_t *, vuint64m1_t *, vuint64m1_t *, vuint64m1_t *, vuint64m1_t *, vuint64m1_t *, vuint64m1_t *, vbool64_t, vuint64m1_t, vuint64m1_t, vuint64m1_t, vuint64m1_t, vuint64m1_t, vuint64m1_t, vuint64m1_t, const uint64_t *, ptrdiff_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vlsseg8e64_v)))
void vlsseg8e64_v_i64m1(vint64m1_t *, vint64m1_t *, vint64m1_t *, vint64m1_t *, vint64m1_t *, vint64m1_t *, vint64m1_t *, vint64m1_t *, const int64_t *, ptrdiff_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vlsseg8e64_v_m)))
void vlsseg8e64_v_i64m1_m(vint64m1_t *, vint64m1_t *, vint64m1_t *, vint64m1_t *, vint64m1_t *, vint64m1_t *, vint64m1_t *, vint64m1_t *, vbool64_t, vint64m1_t, vint64m1_t, vint64m1_t, vint64m1_t, vint64m1_t, vint64m1_t, vint64m1_t, vint64m1_t, const int64_t *, ptrdiff_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vlsseg8e64_v)))
void vlsseg8e64_v_u64m1(vuint64m1_t *, vuint64m1_t *, vuint64m1_t *, vuint64m1_t *, vuint64m1_t *, vuint64m1_t *, vuint64m1_t *, vuint64m1_t *, const uint64_t *, ptrdiff_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vlsseg8e64_v_m)))
void vlsseg8e64_v_u64m1_m(vuint64m1_t *, vuint64m1_t *, vuint64m1_t *, vuint64m1_t *, vuint64m1_t *, vuint64m1_t *, vuint64m1_t *, vuint64m1_t *, vbool64_t, vuint64m1_t, vuint64m1_t, vuint64m1_t, vuint64m1_t, vuint64m1_t, vuint64m1_t, vuint64m1_t, vuint64m1_t, const uint64_t *, ptrdiff_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vluxseg2ei64_v)))
void vluxseg2ei64_v_i8m1(vint8m1_t *, vint8m1_t *, const int8_t *, vuint64m8_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vluxseg2ei64_v_m)))
void vluxseg2ei64_v_i8m1_m(vint8m1_t *, vint8m1_t *, vbool8_t, vint8m1_t, vint8m1_t, const int8_t *, vuint64m8_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vluxseg2ei64_v)))
void vluxseg2ei64_v_i8mf2(vint8mf2_t *, vint8mf2_t *, const int8_t *, vuint64m4_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vluxseg2ei64_v_m)))
void vluxseg2ei64_v_i8mf2_m(vint8mf2_t *, vint8mf2_t *, vbool16_t, vint8mf2_t, vint8mf2_t, const int8_t *, vuint64m4_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vluxseg2ei64_v)))
void vluxseg2ei64_v_i8mf4(vint8mf4_t *, vint8mf4_t *, const int8_t *, vuint64m2_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vluxseg2ei64_v_m)))
void vluxseg2ei64_v_i8mf4_m(vint8mf4_t *, vint8mf4_t *, vbool32_t, vint8mf4_t, vint8mf4_t, const int8_t *, vuint64m2_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vluxseg2ei64_v)))
void vluxseg2ei64_v_i8mf8(vint8mf8_t *, vint8mf8_t *, const int8_t *, vuint64m1_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vluxseg2ei64_v_m)))
void vluxseg2ei64_v_i8mf8_m(vint8mf8_t *, vint8mf8_t *, vbool64_t, vint8mf8_t, vint8mf8_t, const int8_t *, vuint64m1_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vluxseg2ei64_v)))
void vluxseg2ei64_v_u8m1(vuint8m1_t *, vuint8m1_t *, const uint8_t *, vuint64m8_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vluxseg2ei64_v_m)))
void vluxseg2ei64_v_u8m1_m(vuint8m1_t *, vuint8m1_t *, vbool8_t, vuint8m1_t, vuint8m1_t, const uint8_t *, vuint64m8_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vluxseg2ei64_v)))
void vluxseg2ei64_v_u8mf2(vuint8mf2_t *, vuint8mf2_t *, const uint8_t *, vuint64m4_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vluxseg2ei64_v_m)))
void vluxseg2ei64_v_u8mf2_m(vuint8mf2_t *, vuint8mf2_t *, vbool16_t, vuint8mf2_t, vuint8mf2_t, const uint8_t *, vuint64m4_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vluxseg2ei64_v)))
void vluxseg2ei64_v_u8mf4(vuint8mf4_t *, vuint8mf4_t *, const uint8_t *, vuint64m2_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vluxseg2ei64_v_m)))
void vluxseg2ei64_v_u8mf4_m(vuint8mf4_t *, vuint8mf4_t *, vbool32_t, vuint8mf4_t, vuint8mf4_t, const uint8_t *, vuint64m2_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vluxseg2ei64_v)))
void vluxseg2ei64_v_u8mf8(vuint8mf8_t *, vuint8mf8_t *, const uint8_t *, vuint64m1_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vluxseg2ei64_v_m)))
void vluxseg2ei64_v_u8mf8_m(vuint8mf8_t *, vuint8mf8_t *, vbool64_t, vuint8mf8_t, vuint8mf8_t, const uint8_t *, vuint64m1_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vluxseg3ei64_v)))
void vluxseg3ei64_v_i8m1(vint8m1_t *, vint8m1_t *, vint8m1_t *, const int8_t *, vuint64m8_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vluxseg3ei64_v_m)))
void vluxseg3ei64_v_i8m1_m(vint8m1_t *, vint8m1_t *, vint8m1_t *, vbool8_t, vint8m1_t, vint8m1_t, vint8m1_t, const int8_t *, vuint64m8_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vluxseg3ei64_v)))
void vluxseg3ei64_v_i8mf2(vint8mf2_t *, vint8mf2_t *, vint8mf2_t *, const int8_t *, vuint64m4_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vluxseg3ei64_v_m)))
void vluxseg3ei64_v_i8mf2_m(vint8mf2_t *, vint8mf2_t *, vint8mf2_t *, vbool16_t, vint8mf2_t, vint8mf2_t, vint8mf2_t, const int8_t *, vuint64m4_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vluxseg3ei64_v)))
void vluxseg3ei64_v_i8mf4(vint8mf4_t *, vint8mf4_t *, vint8mf4_t *, const int8_t *, vuint64m2_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vluxseg3ei64_v_m)))
void vluxseg3ei64_v_i8mf4_m(vint8mf4_t *, vint8mf4_t *, vint8mf4_t *, vbool32_t, vint8mf4_t, vint8mf4_t, vint8mf4_t, const int8_t *, vuint64m2_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vluxseg3ei64_v)))
void vluxseg3ei64_v_i8mf8(vint8mf8_t *, vint8mf8_t *, vint8mf8_t *, const int8_t *, vuint64m1_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vluxseg3ei64_v_m)))
void vluxseg3ei64_v_i8mf8_m(vint8mf8_t *, vint8mf8_t *, vint8mf8_t *, vbool64_t, vint8mf8_t, vint8mf8_t, vint8mf8_t, const int8_t *, vuint64m1_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vluxseg3ei64_v)))
void vluxseg3ei64_v_u8m1(vuint8m1_t *, vuint8m1_t *, vuint8m1_t *, const uint8_t *, vuint64m8_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vluxseg3ei64_v_m)))
void vluxseg3ei64_v_u8m1_m(vuint8m1_t *, vuint8m1_t *, vuint8m1_t *, vbool8_t, vuint8m1_t, vuint8m1_t, vuint8m1_t, const uint8_t *, vuint64m8_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vluxseg3ei64_v)))
void vluxseg3ei64_v_u8mf2(vuint8mf2_t *, vuint8mf2_t *, vuint8mf2_t *, const uint8_t *, vuint64m4_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vluxseg3ei64_v_m)))
void vluxseg3ei64_v_u8mf2_m(vuint8mf2_t *, vuint8mf2_t *, vuint8mf2_t *, vbool16_t, vuint8mf2_t, vuint8mf2_t, vuint8mf2_t, const uint8_t *, vuint64m4_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vluxseg3ei64_v)))
void vluxseg3ei64_v_u8mf4(vuint8mf4_t *, vuint8mf4_t *, vuint8mf4_t *, const uint8_t *, vuint64m2_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vluxseg3ei64_v_m)))
void vluxseg3ei64_v_u8mf4_m(vuint8mf4_t *, vuint8mf4_t *, vuint8mf4_t *, vbool32_t, vuint8mf4_t, vuint8mf4_t, vuint8mf4_t, const uint8_t *, vuint64m2_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vluxseg3ei64_v)))
void vluxseg3ei64_v_u8mf8(vuint8mf8_t *, vuint8mf8_t *, vuint8mf8_t *, const uint8_t *, vuint64m1_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vluxseg3ei64_v_m)))
void vluxseg3ei64_v_u8mf8_m(vuint8mf8_t *, vuint8mf8_t *, vuint8mf8_t *, vbool64_t, vuint8mf8_t, vuint8mf8_t, vuint8mf8_t, const uint8_t *, vuint64m1_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vluxseg4ei64_v)))
void vluxseg4ei64_v_i8m1(vint8m1_t *, vint8m1_t *, vint8m1_t *, vint8m1_t *, const int8_t *, vuint64m8_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vluxseg4ei64_v_m)))
void vluxseg4ei64_v_i8m1_m(vint8m1_t *, vint8m1_t *, vint8m1_t *, vint8m1_t *, vbool8_t, vint8m1_t, vint8m1_t, vint8m1_t, vint8m1_t, const int8_t *, vuint64m8_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vluxseg4ei64_v)))
void vluxseg4ei64_v_i8mf2(vint8mf2_t *, vint8mf2_t *, vint8mf2_t *, vint8mf2_t *, const int8_t *, vuint64m4_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vluxseg4ei64_v_m)))
void vluxseg4ei64_v_i8mf2_m(vint8mf2_t *, vint8mf2_t *, vint8mf2_t *, vint8mf2_t *, vbool16_t, vint8mf2_t, vint8mf2_t, vint8mf2_t, vint8mf2_t, const int8_t *, vuint64m4_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vluxseg4ei64_v)))
void vluxseg4ei64_v_i8mf4(vint8mf4_t *, vint8mf4_t *, vint8mf4_t *, vint8mf4_t *, const int8_t *, vuint64m2_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vluxseg4ei64_v_m)))
void vluxseg4ei64_v_i8mf4_m(vint8mf4_t *, vint8mf4_t *, vint8mf4_t *, vint8mf4_t *, vbool32_t, vint8mf4_t, vint8mf4_t, vint8mf4_t, vint8mf4_t, const int8_t *, vuint64m2_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vluxseg4ei64_v)))
void vluxseg4ei64_v_i8mf8(vint8mf8_t *, vint8mf8_t *, vint8mf8_t *, vint8mf8_t *, const int8_t *, vuint64m1_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vluxseg4ei64_v_m)))
void vluxseg4ei64_v_i8mf8_m(vint8mf8_t *, vint8mf8_t *, vint8mf8_t *, vint8mf8_t *, vbool64_t, vint8mf8_t, vint8mf8_t, vint8mf8_t, vint8mf8_t, const int8_t *, vuint64m1_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vluxseg4ei64_v)))
void vluxseg4ei64_v_u8m1(vuint8m1_t *, vuint8m1_t *, vuint8m1_t *, vuint8m1_t *, const uint8_t *, vuint64m8_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vluxseg4ei64_v_m)))
void vluxseg4ei64_v_u8m1_m(vuint8m1_t *, vuint8m1_t *, vuint8m1_t *, vuint8m1_t *, vbool8_t, vuint8m1_t, vuint8m1_t, vuint8m1_t, vuint8m1_t, const uint8_t *, vuint64m8_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vluxseg4ei64_v)))
void vluxseg4ei64_v_u8mf2(vuint8mf2_t *, vuint8mf2_t *, vuint8mf2_t *, vuint8mf2_t *, const uint8_t *, vuint64m4_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vluxseg4ei64_v_m)))
void vluxseg4ei64_v_u8mf2_m(vuint8mf2_t *, vuint8mf2_t *, vuint8mf2_t *, vuint8mf2_t *, vbool16_t, vuint8mf2_t, vuint8mf2_t, vuint8mf2_t, vuint8mf2_t, const uint8_t *, vuint64m4_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vluxseg4ei64_v)))
void vluxseg4ei64_v_u8mf4(vuint8mf4_t *, vuint8mf4_t *, vuint8mf4_t *, vuint8mf4_t *, const uint8_t *, vuint64m2_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vluxseg4ei64_v_m)))
void vluxseg4ei64_v_u8mf4_m(vuint8mf4_t *, vuint8mf4_t *, vuint8mf4_t *, vuint8mf4_t *, vbool32_t, vuint8mf4_t, vuint8mf4_t, vuint8mf4_t, vuint8mf4_t, const uint8_t *, vuint64m2_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vluxseg4ei64_v)))
void vluxseg4ei64_v_u8mf8(vuint8mf8_t *, vuint8mf8_t *, vuint8mf8_t *, vuint8mf8_t *, const uint8_t *, vuint64m1_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vluxseg4ei64_v_m)))
void vluxseg4ei64_v_u8mf8_m(vuint8mf8_t *, vuint8mf8_t *, vuint8mf8_t *, vuint8mf8_t *, vbool64_t, vuint8mf8_t, vuint8mf8_t, vuint8mf8_t, vuint8mf8_t, const uint8_t *, vuint64m1_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vluxseg5ei64_v)))
void vluxseg5ei64_v_i8m1(vint8m1_t *, vint8m1_t *, vint8m1_t *, vint8m1_t *, vint8m1_t *, const int8_t *, vuint64m8_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vluxseg5ei64_v_m)))
void vluxseg5ei64_v_i8m1_m(vint8m1_t *, vint8m1_t *, vint8m1_t *, vint8m1_t *, vint8m1_t *, vbool8_t, vint8m1_t, vint8m1_t, vint8m1_t, vint8m1_t, vint8m1_t, const int8_t *, vuint64m8_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vluxseg5ei64_v)))
void vluxseg5ei64_v_i8mf2(vint8mf2_t *, vint8mf2_t *, vint8mf2_t *, vint8mf2_t *, vint8mf2_t *, const int8_t *, vuint64m4_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vluxseg5ei64_v_m)))
void vluxseg5ei64_v_i8mf2_m(vint8mf2_t *, vint8mf2_t *, vint8mf2_t *, vint8mf2_t *, vint8mf2_t *, vbool16_t, vint8mf2_t, vint8mf2_t, vint8mf2_t, vint8mf2_t, vint8mf2_t, const int8_t *, vuint64m4_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vluxseg5ei64_v)))
void vluxseg5ei64_v_i8mf4(vint8mf4_t *, vint8mf4_t *, vint8mf4_t *, vint8mf4_t *, vint8mf4_t *, const int8_t *, vuint64m2_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vluxseg5ei64_v_m)))
void vluxseg5ei64_v_i8mf4_m(vint8mf4_t *, vint8mf4_t *, vint8mf4_t *, vint8mf4_t *, vint8mf4_t *, vbool32_t, vint8mf4_t, vint8mf4_t, vint8mf4_t, vint8mf4_t, vint8mf4_t, const int8_t *, vuint64m2_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vluxseg5ei64_v)))
void vluxseg5ei64_v_i8mf8(vint8mf8_t *, vint8mf8_t *, vint8mf8_t *, vint8mf8_t *, vint8mf8_t *, const int8_t *, vuint64m1_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vluxseg5ei64_v_m)))
void vluxseg5ei64_v_i8mf8_m(vint8mf8_t *, vint8mf8_t *, vint8mf8_t *, vint8mf8_t *, vint8mf8_t *, vbool64_t, vint8mf8_t, vint8mf8_t, vint8mf8_t, vint8mf8_t, vint8mf8_t, const int8_t *, vuint64m1_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vluxseg5ei64_v)))
void vluxseg5ei64_v_u8m1(vuint8m1_t *, vuint8m1_t *, vuint8m1_t *, vuint8m1_t *, vuint8m1_t *, const uint8_t *, vuint64m8_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vluxseg5ei64_v_m)))
void vluxseg5ei64_v_u8m1_m(vuint8m1_t *, vuint8m1_t *, vuint8m1_t *, vuint8m1_t *, vuint8m1_t *, vbool8_t, vuint8m1_t, vuint8m1_t, vuint8m1_t, vuint8m1_t, vuint8m1_t, const uint8_t *, vuint64m8_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vluxseg5ei64_v)))
void vluxseg5ei64_v_u8mf2(vuint8mf2_t *, vuint8mf2_t *, vuint8mf2_t *, vuint8mf2_t *, vuint8mf2_t *, const uint8_t *, vuint64m4_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vluxseg5ei64_v_m)))
void vluxseg5ei64_v_u8mf2_m(vuint8mf2_t *, vuint8mf2_t *, vuint8mf2_t *, vuint8mf2_t *, vuint8mf2_t *, vbool16_t, vuint8mf2_t, vuint8mf2_t, vuint8mf2_t, vuint8mf2_t, vuint8mf2_t, const uint8_t *, vuint64m4_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vluxseg5ei64_v)))
void vluxseg5ei64_v_u8mf4(vuint8mf4_t *, vuint8mf4_t *, vuint8mf4_t *, vuint8mf4_t *, vuint8mf4_t *, const uint8_t *, vuint64m2_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vluxseg5ei64_v_m)))
void vluxseg5ei64_v_u8mf4_m(vuint8mf4_t *, vuint8mf4_t *, vuint8mf4_t *, vuint8mf4_t *, vuint8mf4_t *, vbool32_t, vuint8mf4_t, vuint8mf4_t, vuint8mf4_t, vuint8mf4_t, vuint8mf4_t, const uint8_t *, vuint64m2_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vluxseg5ei64_v)))
void vluxseg5ei64_v_u8mf8(vuint8mf8_t *, vuint8mf8_t *, vuint8mf8_t *, vuint8mf8_t *, vuint8mf8_t *, const uint8_t *, vuint64m1_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vluxseg5ei64_v_m)))
void vluxseg5ei64_v_u8mf8_m(vuint8mf8_t *, vuint8mf8_t *, vuint8mf8_t *, vuint8mf8_t *, vuint8mf8_t *, vbool64_t, vuint8mf8_t, vuint8mf8_t, vuint8mf8_t, vuint8mf8_t, vuint8mf8_t, const uint8_t *, vuint64m1_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vluxseg6ei64_v)))
void vluxseg6ei64_v_i8m1(vint8m1_t *, vint8m1_t *, vint8m1_t *, vint8m1_t *, vint8m1_t *, vint8m1_t *, const int8_t *, vuint64m8_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vluxseg6ei64_v_m)))
void vluxseg6ei64_v_i8m1_m(vint8m1_t *, vint8m1_t *, vint8m1_t *, vint8m1_t *, vint8m1_t *, vint8m1_t *, vbool8_t, vint8m1_t, vint8m1_t, vint8m1_t, vint8m1_t, vint8m1_t, vint8m1_t, const int8_t *, vuint64m8_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vluxseg6ei64_v)))
void vluxseg6ei64_v_i8mf2(vint8mf2_t *, vint8mf2_t *, vint8mf2_t *, vint8mf2_t *, vint8mf2_t *, vint8mf2_t *, const int8_t *, vuint64m4_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vluxseg6ei64_v_m)))
void vluxseg6ei64_v_i8mf2_m(vint8mf2_t *, vint8mf2_t *, vint8mf2_t *, vint8mf2_t *, vint8mf2_t *, vint8mf2_t *, vbool16_t, vint8mf2_t, vint8mf2_t, vint8mf2_t, vint8mf2_t, vint8mf2_t, vint8mf2_t, const int8_t *, vuint64m4_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vluxseg6ei64_v)))
void vluxseg6ei64_v_i8mf4(vint8mf4_t *, vint8mf4_t *, vint8mf4_t *, vint8mf4_t *, vint8mf4_t *, vint8mf4_t *, const int8_t *, vuint64m2_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vluxseg6ei64_v_m)))
void vluxseg6ei64_v_i8mf4_m(vint8mf4_t *, vint8mf4_t *, vint8mf4_t *, vint8mf4_t *, vint8mf4_t *, vint8mf4_t *, vbool32_t, vint8mf4_t, vint8mf4_t, vint8mf4_t, vint8mf4_t, vint8mf4_t, vint8mf4_t, const int8_t *, vuint64m2_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vluxseg6ei64_v)))
void vluxseg6ei64_v_i8mf8(vint8mf8_t *, vint8mf8_t *, vint8mf8_t *, vint8mf8_t *, vint8mf8_t *, vint8mf8_t *, const int8_t *, vuint64m1_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vluxseg6ei64_v_m)))
void vluxseg6ei64_v_i8mf8_m(vint8mf8_t *, vint8mf8_t *, vint8mf8_t *, vint8mf8_t *, vint8mf8_t *, vint8mf8_t *, vbool64_t, vint8mf8_t, vint8mf8_t, vint8mf8_t, vint8mf8_t, vint8mf8_t, vint8mf8_t, const int8_t *, vuint64m1_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vluxseg6ei64_v)))
void vluxseg6ei64_v_u8m1(vuint8m1_t *, vuint8m1_t *, vuint8m1_t *, vuint8m1_t *, vuint8m1_t *, vuint8m1_t *, const uint8_t *, vuint64m8_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vluxseg6ei64_v_m)))
void vluxseg6ei64_v_u8m1_m(vuint8m1_t *, vuint8m1_t *, vuint8m1_t *, vuint8m1_t *, vuint8m1_t *, vuint8m1_t *, vbool8_t, vuint8m1_t, vuint8m1_t, vuint8m1_t, vuint8m1_t, vuint8m1_t, vuint8m1_t, const uint8_t *, vuint64m8_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vluxseg6ei64_v)))
void vluxseg6ei64_v_u8mf2(vuint8mf2_t *, vuint8mf2_t *, vuint8mf2_t *, vuint8mf2_t *, vuint8mf2_t *, vuint8mf2_t *, const uint8_t *, vuint64m4_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vluxseg6ei64_v_m)))
void vluxseg6ei64_v_u8mf2_m(vuint8mf2_t *, vuint8mf2_t *, vuint8mf2_t *, vuint8mf2_t *, vuint8mf2_t *, vuint8mf2_t *, vbool16_t, vuint8mf2_t, vuint8mf2_t, vuint8mf2_t, vuint8mf2_t, vuint8mf2_t, vuint8mf2_t, const uint8_t *, vuint64m4_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vluxseg6ei64_v)))
void vluxseg6ei64_v_u8mf4(vuint8mf4_t *, vuint8mf4_t *, vuint8mf4_t *, vuint8mf4_t *, vuint8mf4_t *, vuint8mf4_t *, const uint8_t *, vuint64m2_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vluxseg6ei64_v_m)))
void vluxseg6ei64_v_u8mf4_m(vuint8mf4_t *, vuint8mf4_t *, vuint8mf4_t *, vuint8mf4_t *, vuint8mf4_t *, vuint8mf4_t *, vbool32_t, vuint8mf4_t, vuint8mf4_t, vuint8mf4_t, vuint8mf4_t, vuint8mf4_t, vuint8mf4_t, const uint8_t *, vuint64m2_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vluxseg6ei64_v)))
void vluxseg6ei64_v_u8mf8(vuint8mf8_t *, vuint8mf8_t *, vuint8mf8_t *, vuint8mf8_t *, vuint8mf8_t *, vuint8mf8_t *, const uint8_t *, vuint64m1_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vluxseg6ei64_v_m)))
void vluxseg6ei64_v_u8mf8_m(vuint8mf8_t *, vuint8mf8_t *, vuint8mf8_t *, vuint8mf8_t *, vuint8mf8_t *, vuint8mf8_t *, vbool64_t, vuint8mf8_t, vuint8mf8_t, vuint8mf8_t, vuint8mf8_t, vuint8mf8_t, vuint8mf8_t, const uint8_t *, vuint64m1_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vluxseg7ei64_v)))
void vluxseg7ei64_v_i8m1(vint8m1_t *, vint8m1_t *, vint8m1_t *, vint8m1_t *, vint8m1_t *, vint8m1_t *, vint8m1_t *, const int8_t *, vuint64m8_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vluxseg7ei64_v_m)))
void vluxseg7ei64_v_i8m1_m(vint8m1_t *, vint8m1_t *, vint8m1_t *, vint8m1_t *, vint8m1_t *, vint8m1_t *, vint8m1_t *, vbool8_t, vint8m1_t, vint8m1_t, vint8m1_t, vint8m1_t, vint8m1_t, vint8m1_t, vint8m1_t, const int8_t *, vuint64m8_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vluxseg7ei64_v)))
void vluxseg7ei64_v_i8mf2(vint8mf2_t *, vint8mf2_t *, vint8mf2_t *, vint8mf2_t *, vint8mf2_t *, vint8mf2_t *, vint8mf2_t *, const int8_t *, vuint64m4_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vluxseg7ei64_v_m)))
void vluxseg7ei64_v_i8mf2_m(vint8mf2_t *, vint8mf2_t *, vint8mf2_t *, vint8mf2_t *, vint8mf2_t *, vint8mf2_t *, vint8mf2_t *, vbool16_t, vint8mf2_t, vint8mf2_t, vint8mf2_t, vint8mf2_t, vint8mf2_t, vint8mf2_t, vint8mf2_t, const int8_t *, vuint64m4_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vluxseg7ei64_v)))
void vluxseg7ei64_v_i8mf4(vint8mf4_t *, vint8mf4_t *, vint8mf4_t *, vint8mf4_t *, vint8mf4_t *, vint8mf4_t *, vint8mf4_t *, const int8_t *, vuint64m2_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vluxseg7ei64_v_m)))
void vluxseg7ei64_v_i8mf4_m(vint8mf4_t *, vint8mf4_t *, vint8mf4_t *, vint8mf4_t *, vint8mf4_t *, vint8mf4_t *, vint8mf4_t *, vbool32_t, vint8mf4_t, vint8mf4_t, vint8mf4_t, vint8mf4_t, vint8mf4_t, vint8mf4_t, vint8mf4_t, const int8_t *, vuint64m2_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vluxseg7ei64_v)))
void vluxseg7ei64_v_i8mf8(vint8mf8_t *, vint8mf8_t *, vint8mf8_t *, vint8mf8_t *, vint8mf8_t *, vint8mf8_t *, vint8mf8_t *, const int8_t *, vuint64m1_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vluxseg7ei64_v_m)))
void vluxseg7ei64_v_i8mf8_m(vint8mf8_t *, vint8mf8_t *, vint8mf8_t *, vint8mf8_t *, vint8mf8_t *, vint8mf8_t *, vint8mf8_t *, vbool64_t, vint8mf8_t, vint8mf8_t, vint8mf8_t, vint8mf8_t, vint8mf8_t, vint8mf8_t, vint8mf8_t, const int8_t *, vuint64m1_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vluxseg7ei64_v)))
void vluxseg7ei64_v_u8m1(vuint8m1_t *, vuint8m1_t *, vuint8m1_t *, vuint8m1_t *, vuint8m1_t *, vuint8m1_t *, vuint8m1_t *, const uint8_t *, vuint64m8_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vluxseg7ei64_v_m)))
void vluxseg7ei64_v_u8m1_m(vuint8m1_t *, vuint8m1_t *, vuint8m1_t *, vuint8m1_t *, vuint8m1_t *, vuint8m1_t *, vuint8m1_t *, vbool8_t, vuint8m1_t, vuint8m1_t, vuint8m1_t, vuint8m1_t, vuint8m1_t, vuint8m1_t, vuint8m1_t, const uint8_t *, vuint64m8_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vluxseg7ei64_v)))
void vluxseg7ei64_v_u8mf2(vuint8mf2_t *, vuint8mf2_t *, vuint8mf2_t *, vuint8mf2_t *, vuint8mf2_t *, vuint8mf2_t *, vuint8mf2_t *, const uint8_t *, vuint64m4_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vluxseg7ei64_v_m)))
void vluxseg7ei64_v_u8mf2_m(vuint8mf2_t *, vuint8mf2_t *, vuint8mf2_t *, vuint8mf2_t *, vuint8mf2_t *, vuint8mf2_t *, vuint8mf2_t *, vbool16_t, vuint8mf2_t, vuint8mf2_t, vuint8mf2_t, vuint8mf2_t, vuint8mf2_t, vuint8mf2_t, vuint8mf2_t, const uint8_t *, vuint64m4_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vluxseg7ei64_v)))
void vluxseg7ei64_v_u8mf4(vuint8mf4_t *, vuint8mf4_t *, vuint8mf4_t *, vuint8mf4_t *, vuint8mf4_t *, vuint8mf4_t *, vuint8mf4_t *, const uint8_t *, vuint64m2_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vluxseg7ei64_v_m)))
void vluxseg7ei64_v_u8mf4_m(vuint8mf4_t *, vuint8mf4_t *, vuint8mf4_t *, vuint8mf4_t *, vuint8mf4_t *, vuint8mf4_t *, vuint8mf4_t *, vbool32_t, vuint8mf4_t, vuint8mf4_t, vuint8mf4_t, vuint8mf4_t, vuint8mf4_t, vuint8mf4_t, vuint8mf4_t, const uint8_t *, vuint64m2_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vluxseg7ei64_v)))
void vluxseg7ei64_v_u8mf8(vuint8mf8_t *, vuint8mf8_t *, vuint8mf8_t *, vuint8mf8_t *, vuint8mf8_t *, vuint8mf8_t *, vuint8mf8_t *, const uint8_t *, vuint64m1_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vluxseg7ei64_v_m)))
void vluxseg7ei64_v_u8mf8_m(vuint8mf8_t *, vuint8mf8_t *, vuint8mf8_t *, vuint8mf8_t *, vuint8mf8_t *, vuint8mf8_t *, vuint8mf8_t *, vbool64_t, vuint8mf8_t, vuint8mf8_t, vuint8mf8_t, vuint8mf8_t, vuint8mf8_t, vuint8mf8_t, vuint8mf8_t, const uint8_t *, vuint64m1_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vluxseg8ei64_v)))
void vluxseg8ei64_v_i8m1(vint8m1_t *, vint8m1_t *, vint8m1_t *, vint8m1_t *, vint8m1_t *, vint8m1_t *, vint8m1_t *, vint8m1_t *, const int8_t *, vuint64m8_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vluxseg8ei64_v_m)))
void vluxseg8ei64_v_i8m1_m(vint8m1_t *, vint8m1_t *, vint8m1_t *, vint8m1_t *, vint8m1_t *, vint8m1_t *, vint8m1_t *, vint8m1_t *, vbool8_t, vint8m1_t, vint8m1_t, vint8m1_t, vint8m1_t, vint8m1_t, vint8m1_t, vint8m1_t, vint8m1_t, const int8_t *, vuint64m8_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vluxseg8ei64_v)))
void vluxseg8ei64_v_i8mf2(vint8mf2_t *, vint8mf2_t *, vint8mf2_t *, vint8mf2_t *, vint8mf2_t *, vint8mf2_t *, vint8mf2_t *, vint8mf2_t *, const int8_t *, vuint64m4_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vluxseg8ei64_v_m)))
void vluxseg8ei64_v_i8mf2_m(vint8mf2_t *, vint8mf2_t *, vint8mf2_t *, vint8mf2_t *, vint8mf2_t *, vint8mf2_t *, vint8mf2_t *, vint8mf2_t *, vbool16_t, vint8mf2_t, vint8mf2_t, vint8mf2_t, vint8mf2_t, vint8mf2_t, vint8mf2_t, vint8mf2_t, vint8mf2_t, const int8_t *, vuint64m4_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vluxseg8ei64_v)))
void vluxseg8ei64_v_i8mf4(vint8mf4_t *, vint8mf4_t *, vint8mf4_t *, vint8mf4_t *, vint8mf4_t *, vint8mf4_t *, vint8mf4_t *, vint8mf4_t *, const int8_t *, vuint64m2_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vluxseg8ei64_v_m)))
void vluxseg8ei64_v_i8mf4_m(vint8mf4_t *, vint8mf4_t *, vint8mf4_t *, vint8mf4_t *, vint8mf4_t *, vint8mf4_t *, vint8mf4_t *, vint8mf4_t *, vbool32_t, vint8mf4_t, vint8mf4_t, vint8mf4_t, vint8mf4_t, vint8mf4_t, vint8mf4_t, vint8mf4_t, vint8mf4_t, const int8_t *, vuint64m2_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vluxseg8ei64_v)))
void vluxseg8ei64_v_i8mf8(vint8mf8_t *, vint8mf8_t *, vint8mf8_t *, vint8mf8_t *, vint8mf8_t *, vint8mf8_t *, vint8mf8_t *, vint8mf8_t *, const int8_t *, vuint64m1_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vluxseg8ei64_v_m)))
void vluxseg8ei64_v_i8mf8_m(vint8mf8_t *, vint8mf8_t *, vint8mf8_t *, vint8mf8_t *, vint8mf8_t *, vint8mf8_t *, vint8mf8_t *, vint8mf8_t *, vbool64_t, vint8mf8_t, vint8mf8_t, vint8mf8_t, vint8mf8_t, vint8mf8_t, vint8mf8_t, vint8mf8_t, vint8mf8_t, const int8_t *, vuint64m1_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vluxseg8ei64_v)))
void vluxseg8ei64_v_u8m1(vuint8m1_t *, vuint8m1_t *, vuint8m1_t *, vuint8m1_t *, vuint8m1_t *, vuint8m1_t *, vuint8m1_t *, vuint8m1_t *, const uint8_t *, vuint64m8_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vluxseg8ei64_v_m)))
void vluxseg8ei64_v_u8m1_m(vuint8m1_t *, vuint8m1_t *, vuint8m1_t *, vuint8m1_t *, vuint8m1_t *, vuint8m1_t *, vuint8m1_t *, vuint8m1_t *, vbool8_t, vuint8m1_t, vuint8m1_t, vuint8m1_t, vuint8m1_t, vuint8m1_t, vuint8m1_t, vuint8m1_t, vuint8m1_t, const uint8_t *, vuint64m8_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vluxseg8ei64_v)))
void vluxseg8ei64_v_u8mf2(vuint8mf2_t *, vuint8mf2_t *, vuint8mf2_t *, vuint8mf2_t *, vuint8mf2_t *, vuint8mf2_t *, vuint8mf2_t *, vuint8mf2_t *, const uint8_t *, vuint64m4_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vluxseg8ei64_v_m)))
void vluxseg8ei64_v_u8mf2_m(vuint8mf2_t *, vuint8mf2_t *, vuint8mf2_t *, vuint8mf2_t *, vuint8mf2_t *, vuint8mf2_t *, vuint8mf2_t *, vuint8mf2_t *, vbool16_t, vuint8mf2_t, vuint8mf2_t, vuint8mf2_t, vuint8mf2_t, vuint8mf2_t, vuint8mf2_t, vuint8mf2_t, vuint8mf2_t, const uint8_t *, vuint64m4_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vluxseg8ei64_v)))
void vluxseg8ei64_v_u8mf4(vuint8mf4_t *, vuint8mf4_t *, vuint8mf4_t *, vuint8mf4_t *, vuint8mf4_t *, vuint8mf4_t *, vuint8mf4_t *, vuint8mf4_t *, const uint8_t *, vuint64m2_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vluxseg8ei64_v_m)))
void vluxseg8ei64_v_u8mf4_m(vuint8mf4_t *, vuint8mf4_t *, vuint8mf4_t *, vuint8mf4_t *, vuint8mf4_t *, vuint8mf4_t *, vuint8mf4_t *, vuint8mf4_t *, vbool32_t, vuint8mf4_t, vuint8mf4_t, vuint8mf4_t, vuint8mf4_t, vuint8mf4_t, vuint8mf4_t, vuint8mf4_t, vuint8mf4_t, const uint8_t *, vuint64m2_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vluxseg8ei64_v)))
void vluxseg8ei64_v_u8mf8(vuint8mf8_t *, vuint8mf8_t *, vuint8mf8_t *, vuint8mf8_t *, vuint8mf8_t *, vuint8mf8_t *, vuint8mf8_t *, vuint8mf8_t *, const uint8_t *, vuint64m1_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vluxseg8ei64_v_m)))
void vluxseg8ei64_v_u8mf8_m(vuint8mf8_t *, vuint8mf8_t *, vuint8mf8_t *, vuint8mf8_t *, vuint8mf8_t *, vuint8mf8_t *, vuint8mf8_t *, vuint8mf8_t *, vbool64_t, vuint8mf8_t, vuint8mf8_t, vuint8mf8_t, vuint8mf8_t, vuint8mf8_t, vuint8mf8_t, vuint8mf8_t, vuint8mf8_t, const uint8_t *, vuint64m1_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vluxseg2ei64_v)))
void vluxseg2ei64_v_i16m1(vint16m1_t *, vint16m1_t *, const int16_t *, vuint64m4_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vluxseg2ei64_v_m)))
void vluxseg2ei64_v_i16m1_m(vint16m1_t *, vint16m1_t *, vbool16_t, vint16m1_t, vint16m1_t, const int16_t *, vuint64m4_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vluxseg2ei64_v)))
void vluxseg2ei64_v_i16m2(vint16m2_t *, vint16m2_t *, const int16_t *, vuint64m8_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vluxseg2ei64_v_m)))
void vluxseg2ei64_v_i16m2_m(vint16m2_t *, vint16m2_t *, vbool8_t, vint16m2_t, vint16m2_t, const int16_t *, vuint64m8_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vluxseg2ei64_v)))
void vluxseg2ei64_v_i16mf2(vint16mf2_t *, vint16mf2_t *, const int16_t *, vuint64m2_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vluxseg2ei64_v_m)))
void vluxseg2ei64_v_i16mf2_m(vint16mf2_t *, vint16mf2_t *, vbool32_t, vint16mf2_t, vint16mf2_t, const int16_t *, vuint64m2_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vluxseg2ei64_v)))
void vluxseg2ei64_v_i16mf4(vint16mf4_t *, vint16mf4_t *, const int16_t *, vuint64m1_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vluxseg2ei64_v_m)))
void vluxseg2ei64_v_i16mf4_m(vint16mf4_t *, vint16mf4_t *, vbool64_t, vint16mf4_t, vint16mf4_t, const int16_t *, vuint64m1_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vluxseg2ei64_v)))
void vluxseg2ei64_v_u16m1(vuint16m1_t *, vuint16m1_t *, const uint16_t *, vuint64m4_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vluxseg2ei64_v_m)))
void vluxseg2ei64_v_u16m1_m(vuint16m1_t *, vuint16m1_t *, vbool16_t, vuint16m1_t, vuint16m1_t, const uint16_t *, vuint64m4_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vluxseg2ei64_v)))
void vluxseg2ei64_v_u16m2(vuint16m2_t *, vuint16m2_t *, const uint16_t *, vuint64m8_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vluxseg2ei64_v_m)))
void vluxseg2ei64_v_u16m2_m(vuint16m2_t *, vuint16m2_t *, vbool8_t, vuint16m2_t, vuint16m2_t, const uint16_t *, vuint64m8_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vluxseg2ei64_v)))
void vluxseg2ei64_v_u16mf2(vuint16mf2_t *, vuint16mf2_t *, const uint16_t *, vuint64m2_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vluxseg2ei64_v_m)))
void vluxseg2ei64_v_u16mf2_m(vuint16mf2_t *, vuint16mf2_t *, vbool32_t, vuint16mf2_t, vuint16mf2_t, const uint16_t *, vuint64m2_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vluxseg2ei64_v)))
void vluxseg2ei64_v_u16mf4(vuint16mf4_t *, vuint16mf4_t *, const uint16_t *, vuint64m1_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vluxseg2ei64_v_m)))
void vluxseg2ei64_v_u16mf4_m(vuint16mf4_t *, vuint16mf4_t *, vbool64_t, vuint16mf4_t, vuint16mf4_t, const uint16_t *, vuint64m1_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vluxseg3ei64_v)))
void vluxseg3ei64_v_i16m1(vint16m1_t *, vint16m1_t *, vint16m1_t *, const int16_t *, vuint64m4_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vluxseg3ei64_v_m)))
void vluxseg3ei64_v_i16m1_m(vint16m1_t *, vint16m1_t *, vint16m1_t *, vbool16_t, vint16m1_t, vint16m1_t, vint16m1_t, const int16_t *, vuint64m4_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vluxseg3ei64_v)))
void vluxseg3ei64_v_i16m2(vint16m2_t *, vint16m2_t *, vint16m2_t *, const int16_t *, vuint64m8_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vluxseg3ei64_v_m)))
void vluxseg3ei64_v_i16m2_m(vint16m2_t *, vint16m2_t *, vint16m2_t *, vbool8_t, vint16m2_t, vint16m2_t, vint16m2_t, const int16_t *, vuint64m8_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vluxseg3ei64_v)))
void vluxseg3ei64_v_i16mf2(vint16mf2_t *, vint16mf2_t *, vint16mf2_t *, const int16_t *, vuint64m2_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vluxseg3ei64_v_m)))
void vluxseg3ei64_v_i16mf2_m(vint16mf2_t *, vint16mf2_t *, vint16mf2_t *, vbool32_t, vint16mf2_t, vint16mf2_t, vint16mf2_t, const int16_t *, vuint64m2_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vluxseg3ei64_v)))
void vluxseg3ei64_v_i16mf4(vint16mf4_t *, vint16mf4_t *, vint16mf4_t *, const int16_t *, vuint64m1_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vluxseg3ei64_v_m)))
void vluxseg3ei64_v_i16mf4_m(vint16mf4_t *, vint16mf4_t *, vint16mf4_t *, vbool64_t, vint16mf4_t, vint16mf4_t, vint16mf4_t, const int16_t *, vuint64m1_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vluxseg3ei64_v)))
void vluxseg3ei64_v_u16m1(vuint16m1_t *, vuint16m1_t *, vuint16m1_t *, const uint16_t *, vuint64m4_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vluxseg3ei64_v_m)))
void vluxseg3ei64_v_u16m1_m(vuint16m1_t *, vuint16m1_t *, vuint16m1_t *, vbool16_t, vuint16m1_t, vuint16m1_t, vuint16m1_t, const uint16_t *, vuint64m4_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vluxseg3ei64_v)))
void vluxseg3ei64_v_u16m2(vuint16m2_t *, vuint16m2_t *, vuint16m2_t *, const uint16_t *, vuint64m8_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vluxseg3ei64_v_m)))
void vluxseg3ei64_v_u16m2_m(vuint16m2_t *, vuint16m2_t *, vuint16m2_t *, vbool8_t, vuint16m2_t, vuint16m2_t, vuint16m2_t, const uint16_t *, vuint64m8_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vluxseg3ei64_v)))
void vluxseg3ei64_v_u16mf2(vuint16mf2_t *, vuint16mf2_t *, vuint16mf2_t *, const uint16_t *, vuint64m2_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vluxseg3ei64_v_m)))
void vluxseg3ei64_v_u16mf2_m(vuint16mf2_t *, vuint16mf2_t *, vuint16mf2_t *, vbool32_t, vuint16mf2_t, vuint16mf2_t, vuint16mf2_t, const uint16_t *, vuint64m2_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vluxseg3ei64_v)))
void vluxseg3ei64_v_u16mf4(vuint16mf4_t *, vuint16mf4_t *, vuint16mf4_t *, const uint16_t *, vuint64m1_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vluxseg3ei64_v_m)))
void vluxseg3ei64_v_u16mf4_m(vuint16mf4_t *, vuint16mf4_t *, vuint16mf4_t *, vbool64_t, vuint16mf4_t, vuint16mf4_t, vuint16mf4_t, const uint16_t *, vuint64m1_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vluxseg4ei64_v)))
void vluxseg4ei64_v_i16m1(vint16m1_t *, vint16m1_t *, vint16m1_t *, vint16m1_t *, const int16_t *, vuint64m4_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vluxseg4ei64_v_m)))
void vluxseg4ei64_v_i16m1_m(vint16m1_t *, vint16m1_t *, vint16m1_t *, vint16m1_t *, vbool16_t, vint16m1_t, vint16m1_t, vint16m1_t, vint16m1_t, const int16_t *, vuint64m4_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vluxseg4ei64_v)))
void vluxseg4ei64_v_i16m2(vint16m2_t *, vint16m2_t *, vint16m2_t *, vint16m2_t *, const int16_t *, vuint64m8_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vluxseg4ei64_v_m)))
void vluxseg4ei64_v_i16m2_m(vint16m2_t *, vint16m2_t *, vint16m2_t *, vint16m2_t *, vbool8_t, vint16m2_t, vint16m2_t, vint16m2_t, vint16m2_t, const int16_t *, vuint64m8_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vluxseg4ei64_v)))
void vluxseg4ei64_v_i16mf2(vint16mf2_t *, vint16mf2_t *, vint16mf2_t *, vint16mf2_t *, const int16_t *, vuint64m2_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vluxseg4ei64_v_m)))
void vluxseg4ei64_v_i16mf2_m(vint16mf2_t *, vint16mf2_t *, vint16mf2_t *, vint16mf2_t *, vbool32_t, vint16mf2_t, vint16mf2_t, vint16mf2_t, vint16mf2_t, const int16_t *, vuint64m2_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vluxseg4ei64_v)))
void vluxseg4ei64_v_i16mf4(vint16mf4_t *, vint16mf4_t *, vint16mf4_t *, vint16mf4_t *, const int16_t *, vuint64m1_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vluxseg4ei64_v_m)))
void vluxseg4ei64_v_i16mf4_m(vint16mf4_t *, vint16mf4_t *, vint16mf4_t *, vint16mf4_t *, vbool64_t, vint16mf4_t, vint16mf4_t, vint16mf4_t, vint16mf4_t, const int16_t *, vuint64m1_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vluxseg4ei64_v)))
void vluxseg4ei64_v_u16m1(vuint16m1_t *, vuint16m1_t *, vuint16m1_t *, vuint16m1_t *, const uint16_t *, vuint64m4_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vluxseg4ei64_v_m)))
void vluxseg4ei64_v_u16m1_m(vuint16m1_t *, vuint16m1_t *, vuint16m1_t *, vuint16m1_t *, vbool16_t, vuint16m1_t, vuint16m1_t, vuint16m1_t, vuint16m1_t, const uint16_t *, vuint64m4_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vluxseg4ei64_v)))
void vluxseg4ei64_v_u16m2(vuint16m2_t *, vuint16m2_t *, vuint16m2_t *, vuint16m2_t *, const uint16_t *, vuint64m8_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vluxseg4ei64_v_m)))
void vluxseg4ei64_v_u16m2_m(vuint16m2_t *, vuint16m2_t *, vuint16m2_t *, vuint16m2_t *, vbool8_t, vuint16m2_t, vuint16m2_t, vuint16m2_t, vuint16m2_t, const uint16_t *, vuint64m8_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vluxseg4ei64_v)))
void vluxseg4ei64_v_u16mf2(vuint16mf2_t *, vuint16mf2_t *, vuint16mf2_t *, vuint16mf2_t *, const uint16_t *, vuint64m2_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vluxseg4ei64_v_m)))
void vluxseg4ei64_v_u16mf2_m(vuint16mf2_t *, vuint16mf2_t *, vuint16mf2_t *, vuint16mf2_t *, vbool32_t, vuint16mf2_t, vuint16mf2_t, vuint16mf2_t, vuint16mf2_t, const uint16_t *, vuint64m2_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vluxseg4ei64_v)))
void vluxseg4ei64_v_u16mf4(vuint16mf4_t *, vuint16mf4_t *, vuint16mf4_t *, vuint16mf4_t *, const uint16_t *, vuint64m1_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vluxseg4ei64_v_m)))
void vluxseg4ei64_v_u16mf4_m(vuint16mf4_t *, vuint16mf4_t *, vuint16mf4_t *, vuint16mf4_t *, vbool64_t, vuint16mf4_t, vuint16mf4_t, vuint16mf4_t, vuint16mf4_t, const uint16_t *, vuint64m1_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vluxseg5ei64_v)))
void vluxseg5ei64_v_i16m1(vint16m1_t *, vint16m1_t *, vint16m1_t *, vint16m1_t *, vint16m1_t *, const int16_t *, vuint64m4_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vluxseg5ei64_v_m)))
void vluxseg5ei64_v_i16m1_m(vint16m1_t *, vint16m1_t *, vint16m1_t *, vint16m1_t *, vint16m1_t *, vbool16_t, vint16m1_t, vint16m1_t, vint16m1_t, vint16m1_t, vint16m1_t, const int16_t *, vuint64m4_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vluxseg5ei64_v)))
void vluxseg5ei64_v_i16mf2(vint16mf2_t *, vint16mf2_t *, vint16mf2_t *, vint16mf2_t *, vint16mf2_t *, const int16_t *, vuint64m2_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vluxseg5ei64_v_m)))
void vluxseg5ei64_v_i16mf2_m(vint16mf2_t *, vint16mf2_t *, vint16mf2_t *, vint16mf2_t *, vint16mf2_t *, vbool32_t, vint16mf2_t, vint16mf2_t, vint16mf2_t, vint16mf2_t, vint16mf2_t, const int16_t *, vuint64m2_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vluxseg5ei64_v)))
void vluxseg5ei64_v_i16mf4(vint16mf4_t *, vint16mf4_t *, vint16mf4_t *, vint16mf4_t *, vint16mf4_t *, const int16_t *, vuint64m1_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vluxseg5ei64_v_m)))
void vluxseg5ei64_v_i16mf4_m(vint16mf4_t *, vint16mf4_t *, vint16mf4_t *, vint16mf4_t *, vint16mf4_t *, vbool64_t, vint16mf4_t, vint16mf4_t, vint16mf4_t, vint16mf4_t, vint16mf4_t, const int16_t *, vuint64m1_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vluxseg5ei64_v)))
void vluxseg5ei64_v_u16m1(vuint16m1_t *, vuint16m1_t *, vuint16m1_t *, vuint16m1_t *, vuint16m1_t *, const uint16_t *, vuint64m4_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vluxseg5ei64_v_m)))
void vluxseg5ei64_v_u16m1_m(vuint16m1_t *, vuint16m1_t *, vuint16m1_t *, vuint16m1_t *, vuint16m1_t *, vbool16_t, vuint16m1_t, vuint16m1_t, vuint16m1_t, vuint16m1_t, vuint16m1_t, const uint16_t *, vuint64m4_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vluxseg5ei64_v)))
void vluxseg5ei64_v_u16mf2(vuint16mf2_t *, vuint16mf2_t *, vuint16mf2_t *, vuint16mf2_t *, vuint16mf2_t *, const uint16_t *, vuint64m2_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vluxseg5ei64_v_m)))
void vluxseg5ei64_v_u16mf2_m(vuint16mf2_t *, vuint16mf2_t *, vuint16mf2_t *, vuint16mf2_t *, vuint16mf2_t *, vbool32_t, vuint16mf2_t, vuint16mf2_t, vuint16mf2_t, vuint16mf2_t, vuint16mf2_t, const uint16_t *, vuint64m2_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vluxseg5ei64_v)))
void vluxseg5ei64_v_u16mf4(vuint16mf4_t *, vuint16mf4_t *, vuint16mf4_t *, vuint16mf4_t *, vuint16mf4_t *, const uint16_t *, vuint64m1_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vluxseg5ei64_v_m)))
void vluxseg5ei64_v_u16mf4_m(vuint16mf4_t *, vuint16mf4_t *, vuint16mf4_t *, vuint16mf4_t *, vuint16mf4_t *, vbool64_t, vuint16mf4_t, vuint16mf4_t, vuint16mf4_t, vuint16mf4_t, vuint16mf4_t, const uint16_t *, vuint64m1_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vluxseg6ei64_v)))
void vluxseg6ei64_v_i16m1(vint16m1_t *, vint16m1_t *, vint16m1_t *, vint16m1_t *, vint16m1_t *, vint16m1_t *, const int16_t *, vuint64m4_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vluxseg6ei64_v_m)))
void vluxseg6ei64_v_i16m1_m(vint16m1_t *, vint16m1_t *, vint16m1_t *, vint16m1_t *, vint16m1_t *, vint16m1_t *, vbool16_t, vint16m1_t, vint16m1_t, vint16m1_t, vint16m1_t, vint16m1_t, vint16m1_t, const int16_t *, vuint64m4_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vluxseg6ei64_v)))
void vluxseg6ei64_v_i16mf2(vint16mf2_t *, vint16mf2_t *, vint16mf2_t *, vint16mf2_t *, vint16mf2_t *, vint16mf2_t *, const int16_t *, vuint64m2_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vluxseg6ei64_v_m)))
void vluxseg6ei64_v_i16mf2_m(vint16mf2_t *, vint16mf2_t *, vint16mf2_t *, vint16mf2_t *, vint16mf2_t *, vint16mf2_t *, vbool32_t, vint16mf2_t, vint16mf2_t, vint16mf2_t, vint16mf2_t, vint16mf2_t, vint16mf2_t, const int16_t *, vuint64m2_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vluxseg6ei64_v)))
void vluxseg6ei64_v_i16mf4(vint16mf4_t *, vint16mf4_t *, vint16mf4_t *, vint16mf4_t *, vint16mf4_t *, vint16mf4_t *, const int16_t *, vuint64m1_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vluxseg6ei64_v_m)))
void vluxseg6ei64_v_i16mf4_m(vint16mf4_t *, vint16mf4_t *, vint16mf4_t *, vint16mf4_t *, vint16mf4_t *, vint16mf4_t *, vbool64_t, vint16mf4_t, vint16mf4_t, vint16mf4_t, vint16mf4_t, vint16mf4_t, vint16mf4_t, const int16_t *, vuint64m1_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vluxseg6ei64_v)))
void vluxseg6ei64_v_u16m1(vuint16m1_t *, vuint16m1_t *, vuint16m1_t *, vuint16m1_t *, vuint16m1_t *, vuint16m1_t *, const uint16_t *, vuint64m4_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vluxseg6ei64_v_m)))
void vluxseg6ei64_v_u16m1_m(vuint16m1_t *, vuint16m1_t *, vuint16m1_t *, vuint16m1_t *, vuint16m1_t *, vuint16m1_t *, vbool16_t, vuint16m1_t, vuint16m1_t, vuint16m1_t, vuint16m1_t, vuint16m1_t, vuint16m1_t, const uint16_t *, vuint64m4_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vluxseg6ei64_v)))
void vluxseg6ei64_v_u16mf2(vuint16mf2_t *, vuint16mf2_t *, vuint16mf2_t *, vuint16mf2_t *, vuint16mf2_t *, vuint16mf2_t *, const uint16_t *, vuint64m2_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vluxseg6ei64_v_m)))
void vluxseg6ei64_v_u16mf2_m(vuint16mf2_t *, vuint16mf2_t *, vuint16mf2_t *, vuint16mf2_t *, vuint16mf2_t *, vuint16mf2_t *, vbool32_t, vuint16mf2_t, vuint16mf2_t, vuint16mf2_t, vuint16mf2_t, vuint16mf2_t, vuint16mf2_t, const uint16_t *, vuint64m2_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vluxseg6ei64_v)))
void vluxseg6ei64_v_u16mf4(vuint16mf4_t *, vuint16mf4_t *, vuint16mf4_t *, vuint16mf4_t *, vuint16mf4_t *, vuint16mf4_t *, const uint16_t *, vuint64m1_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vluxseg6ei64_v_m)))
void vluxseg6ei64_v_u16mf4_m(vuint16mf4_t *, vuint16mf4_t *, vuint16mf4_t *, vuint16mf4_t *, vuint16mf4_t *, vuint16mf4_t *, vbool64_t, vuint16mf4_t, vuint16mf4_t, vuint16mf4_t, vuint16mf4_t, vuint16mf4_t, vuint16mf4_t, const uint16_t *, vuint64m1_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vluxseg7ei64_v)))
void vluxseg7ei64_v_i16m1(vint16m1_t *, vint16m1_t *, vint16m1_t *, vint16m1_t *, vint16m1_t *, vint16m1_t *, vint16m1_t *, const int16_t *, vuint64m4_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vluxseg7ei64_v_m)))
void vluxseg7ei64_v_i16m1_m(vint16m1_t *, vint16m1_t *, vint16m1_t *, vint16m1_t *, vint16m1_t *, vint16m1_t *, vint16m1_t *, vbool16_t, vint16m1_t, vint16m1_t, vint16m1_t, vint16m1_t, vint16m1_t, vint16m1_t, vint16m1_t, const int16_t *, vuint64m4_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vluxseg7ei64_v)))
void vluxseg7ei64_v_i16mf2(vint16mf2_t *, vint16mf2_t *, vint16mf2_t *, vint16mf2_t *, vint16mf2_t *, vint16mf2_t *, vint16mf2_t *, const int16_t *, vuint64m2_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vluxseg7ei64_v_m)))
void vluxseg7ei64_v_i16mf2_m(vint16mf2_t *, vint16mf2_t *, vint16mf2_t *, vint16mf2_t *, vint16mf2_t *, vint16mf2_t *, vint16mf2_t *, vbool32_t, vint16mf2_t, vint16mf2_t, vint16mf2_t, vint16mf2_t, vint16mf2_t, vint16mf2_t, vint16mf2_t, const int16_t *, vuint64m2_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vluxseg7ei64_v)))
void vluxseg7ei64_v_i16mf4(vint16mf4_t *, vint16mf4_t *, vint16mf4_t *, vint16mf4_t *, vint16mf4_t *, vint16mf4_t *, vint16mf4_t *, const int16_t *, vuint64m1_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vluxseg7ei64_v_m)))
void vluxseg7ei64_v_i16mf4_m(vint16mf4_t *, vint16mf4_t *, vint16mf4_t *, vint16mf4_t *, vint16mf4_t *, vint16mf4_t *, vint16mf4_t *, vbool64_t, vint16mf4_t, vint16mf4_t, vint16mf4_t, vint16mf4_t, vint16mf4_t, vint16mf4_t, vint16mf4_t, const int16_t *, vuint64m1_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vluxseg7ei64_v)))
void vluxseg7ei64_v_u16m1(vuint16m1_t *, vuint16m1_t *, vuint16m1_t *, vuint16m1_t *, vuint16m1_t *, vuint16m1_t *, vuint16m1_t *, const uint16_t *, vuint64m4_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vluxseg7ei64_v_m)))
void vluxseg7ei64_v_u16m1_m(vuint16m1_t *, vuint16m1_t *, vuint16m1_t *, vuint16m1_t *, vuint16m1_t *, vuint16m1_t *, vuint16m1_t *, vbool16_t, vuint16m1_t, vuint16m1_t, vuint16m1_t, vuint16m1_t, vuint16m1_t, vuint16m1_t, vuint16m1_t, const uint16_t *, vuint64m4_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vluxseg7ei64_v)))
void vluxseg7ei64_v_u16mf2(vuint16mf2_t *, vuint16mf2_t *, vuint16mf2_t *, vuint16mf2_t *, vuint16mf2_t *, vuint16mf2_t *, vuint16mf2_t *, const uint16_t *, vuint64m2_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vluxseg7ei64_v_m)))
void vluxseg7ei64_v_u16mf2_m(vuint16mf2_t *, vuint16mf2_t *, vuint16mf2_t *, vuint16mf2_t *, vuint16mf2_t *, vuint16mf2_t *, vuint16mf2_t *, vbool32_t, vuint16mf2_t, vuint16mf2_t, vuint16mf2_t, vuint16mf2_t, vuint16mf2_t, vuint16mf2_t, vuint16mf2_t, const uint16_t *, vuint64m2_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vluxseg7ei64_v)))
void vluxseg7ei64_v_u16mf4(vuint16mf4_t *, vuint16mf4_t *, vuint16mf4_t *, vuint16mf4_t *, vuint16mf4_t *, vuint16mf4_t *, vuint16mf4_t *, const uint16_t *, vuint64m1_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vluxseg7ei64_v_m)))
void vluxseg7ei64_v_u16mf4_m(vuint16mf4_t *, vuint16mf4_t *, vuint16mf4_t *, vuint16mf4_t *, vuint16mf4_t *, vuint16mf4_t *, vuint16mf4_t *, vbool64_t, vuint16mf4_t, vuint16mf4_t, vuint16mf4_t, vuint16mf4_t, vuint16mf4_t, vuint16mf4_t, vuint16mf4_t, const uint16_t *, vuint64m1_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vluxseg8ei64_v)))
void vluxseg8ei64_v_i16m1(vint16m1_t *, vint16m1_t *, vint16m1_t *, vint16m1_t *, vint16m1_t *, vint16m1_t *, vint16m1_t *, vint16m1_t *, const int16_t *, vuint64m4_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vluxseg8ei64_v_m)))
void vluxseg8ei64_v_i16m1_m(vint16m1_t *, vint16m1_t *, vint16m1_t *, vint16m1_t *, vint16m1_t *, vint16m1_t *, vint16m1_t *, vint16m1_t *, vbool16_t, vint16m1_t, vint16m1_t, vint16m1_t, vint16m1_t, vint16m1_t, vint16m1_t, vint16m1_t, vint16m1_t, const int16_t *, vuint64m4_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vluxseg8ei64_v)))
void vluxseg8ei64_v_i16mf2(vint16mf2_t *, vint16mf2_t *, vint16mf2_t *, vint16mf2_t *, vint16mf2_t *, vint16mf2_t *, vint16mf2_t *, vint16mf2_t *, const int16_t *, vuint64m2_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vluxseg8ei64_v_m)))
void vluxseg8ei64_v_i16mf2_m(vint16mf2_t *, vint16mf2_t *, vint16mf2_t *, vint16mf2_t *, vint16mf2_t *, vint16mf2_t *, vint16mf2_t *, vint16mf2_t *, vbool32_t, vint16mf2_t, vint16mf2_t, vint16mf2_t, vint16mf2_t, vint16mf2_t, vint16mf2_t, vint16mf2_t, vint16mf2_t, const int16_t *, vuint64m2_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vluxseg8ei64_v)))
void vluxseg8ei64_v_i16mf4(vint16mf4_t *, vint16mf4_t *, vint16mf4_t *, vint16mf4_t *, vint16mf4_t *, vint16mf4_t *, vint16mf4_t *, vint16mf4_t *, const int16_t *, vuint64m1_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vluxseg8ei64_v_m)))
void vluxseg8ei64_v_i16mf4_m(vint16mf4_t *, vint16mf4_t *, vint16mf4_t *, vint16mf4_t *, vint16mf4_t *, vint16mf4_t *, vint16mf4_t *, vint16mf4_t *, vbool64_t, vint16mf4_t, vint16mf4_t, vint16mf4_t, vint16mf4_t, vint16mf4_t, vint16mf4_t, vint16mf4_t, vint16mf4_t, const int16_t *, vuint64m1_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vluxseg8ei64_v)))
void vluxseg8ei64_v_u16m1(vuint16m1_t *, vuint16m1_t *, vuint16m1_t *, vuint16m1_t *, vuint16m1_t *, vuint16m1_t *, vuint16m1_t *, vuint16m1_t *, const uint16_t *, vuint64m4_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vluxseg8ei64_v_m)))
void vluxseg8ei64_v_u16m1_m(vuint16m1_t *, vuint16m1_t *, vuint16m1_t *, vuint16m1_t *, vuint16m1_t *, vuint16m1_t *, vuint16m1_t *, vuint16m1_t *, vbool16_t, vuint16m1_t, vuint16m1_t, vuint16m1_t, vuint16m1_t, vuint16m1_t, vuint16m1_t, vuint16m1_t, vuint16m1_t, const uint16_t *, vuint64m4_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vluxseg8ei64_v)))
void vluxseg8ei64_v_u16mf2(vuint16mf2_t *, vuint16mf2_t *, vuint16mf2_t *, vuint16mf2_t *, vuint16mf2_t *, vuint16mf2_t *, vuint16mf2_t *, vuint16mf2_t *, const uint16_t *, vuint64m2_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vluxseg8ei64_v_m)))
void vluxseg8ei64_v_u16mf2_m(vuint16mf2_t *, vuint16mf2_t *, vuint16mf2_t *, vuint16mf2_t *, vuint16mf2_t *, vuint16mf2_t *, vuint16mf2_t *, vuint16mf2_t *, vbool32_t, vuint16mf2_t, vuint16mf2_t, vuint16mf2_t, vuint16mf2_t, vuint16mf2_t, vuint16mf2_t, vuint16mf2_t, vuint16mf2_t, const uint16_t *, vuint64m2_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vluxseg8ei64_v)))
void vluxseg8ei64_v_u16mf4(vuint16mf4_t *, vuint16mf4_t *, vuint16mf4_t *, vuint16mf4_t *, vuint16mf4_t *, vuint16mf4_t *, vuint16mf4_t *, vuint16mf4_t *, const uint16_t *, vuint64m1_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vluxseg8ei64_v_m)))
void vluxseg8ei64_v_u16mf4_m(vuint16mf4_t *, vuint16mf4_t *, vuint16mf4_t *, vuint16mf4_t *, vuint16mf4_t *, vuint16mf4_t *, vuint16mf4_t *, vuint16mf4_t *, vbool64_t, vuint16mf4_t, vuint16mf4_t, vuint16mf4_t, vuint16mf4_t, vuint16mf4_t, vuint16mf4_t, vuint16mf4_t, vuint16mf4_t, const uint16_t *, vuint64m1_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vluxseg2ei64_v)))
void vluxseg2ei64_v_i32m1(vint32m1_t *, vint32m1_t *, const int32_t *, vuint64m2_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vluxseg2ei64_v_m)))
void vluxseg2ei64_v_i32m1_m(vint32m1_t *, vint32m1_t *, vbool32_t, vint32m1_t, vint32m1_t, const int32_t *, vuint64m2_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vluxseg2ei64_v)))
void vluxseg2ei64_v_i32m2(vint32m2_t *, vint32m2_t *, const int32_t *, vuint64m4_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vluxseg2ei64_v_m)))
void vluxseg2ei64_v_i32m2_m(vint32m2_t *, vint32m2_t *, vbool16_t, vint32m2_t, vint32m2_t, const int32_t *, vuint64m4_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vluxseg2ei64_v)))
void vluxseg2ei64_v_i32m4(vint32m4_t *, vint32m4_t *, const int32_t *, vuint64m8_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vluxseg2ei64_v_m)))
void vluxseg2ei64_v_i32m4_m(vint32m4_t *, vint32m4_t *, vbool8_t, vint32m4_t, vint32m4_t, const int32_t *, vuint64m8_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vluxseg2ei64_v)))
void vluxseg2ei64_v_i32mf2(vint32mf2_t *, vint32mf2_t *, const int32_t *, vuint64m1_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vluxseg2ei64_v_m)))
void vluxseg2ei64_v_i32mf2_m(vint32mf2_t *, vint32mf2_t *, vbool64_t, vint32mf2_t, vint32mf2_t, const int32_t *, vuint64m1_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vluxseg2ei64_v)))
void vluxseg2ei64_v_u32m1(vuint32m1_t *, vuint32m1_t *, const uint32_t *, vuint64m2_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vluxseg2ei64_v_m)))
void vluxseg2ei64_v_u32m1_m(vuint32m1_t *, vuint32m1_t *, vbool32_t, vuint32m1_t, vuint32m1_t, const uint32_t *, vuint64m2_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vluxseg2ei64_v)))
void vluxseg2ei64_v_u32m2(vuint32m2_t *, vuint32m2_t *, const uint32_t *, vuint64m4_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vluxseg2ei64_v_m)))
void vluxseg2ei64_v_u32m2_m(vuint32m2_t *, vuint32m2_t *, vbool16_t, vuint32m2_t, vuint32m2_t, const uint32_t *, vuint64m4_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vluxseg2ei64_v)))
void vluxseg2ei64_v_u32m4(vuint32m4_t *, vuint32m4_t *, const uint32_t *, vuint64m8_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vluxseg2ei64_v_m)))
void vluxseg2ei64_v_u32m4_m(vuint32m4_t *, vuint32m4_t *, vbool8_t, vuint32m4_t, vuint32m4_t, const uint32_t *, vuint64m8_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vluxseg2ei64_v)))
void vluxseg2ei64_v_u32mf2(vuint32mf2_t *, vuint32mf2_t *, const uint32_t *, vuint64m1_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vluxseg2ei64_v_m)))
void vluxseg2ei64_v_u32mf2_m(vuint32mf2_t *, vuint32mf2_t *, vbool64_t, vuint32mf2_t, vuint32mf2_t, const uint32_t *, vuint64m1_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vluxseg3ei64_v)))
void vluxseg3ei64_v_i32m1(vint32m1_t *, vint32m1_t *, vint32m1_t *, const int32_t *, vuint64m2_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vluxseg3ei64_v_m)))
void vluxseg3ei64_v_i32m1_m(vint32m1_t *, vint32m1_t *, vint32m1_t *, vbool32_t, vint32m1_t, vint32m1_t, vint32m1_t, const int32_t *, vuint64m2_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vluxseg3ei64_v)))
void vluxseg3ei64_v_i32m2(vint32m2_t *, vint32m2_t *, vint32m2_t *, const int32_t *, vuint64m4_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vluxseg3ei64_v_m)))
void vluxseg3ei64_v_i32m2_m(vint32m2_t *, vint32m2_t *, vint32m2_t *, vbool16_t, vint32m2_t, vint32m2_t, vint32m2_t, const int32_t *, vuint64m4_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vluxseg3ei64_v)))
void vluxseg3ei64_v_i32mf2(vint32mf2_t *, vint32mf2_t *, vint32mf2_t *, const int32_t *, vuint64m1_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vluxseg3ei64_v_m)))
void vluxseg3ei64_v_i32mf2_m(vint32mf2_t *, vint32mf2_t *, vint32mf2_t *, vbool64_t, vint32mf2_t, vint32mf2_t, vint32mf2_t, const int32_t *, vuint64m1_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vluxseg3ei64_v)))
void vluxseg3ei64_v_u32m1(vuint32m1_t *, vuint32m1_t *, vuint32m1_t *, const uint32_t *, vuint64m2_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vluxseg3ei64_v_m)))
void vluxseg3ei64_v_u32m1_m(vuint32m1_t *, vuint32m1_t *, vuint32m1_t *, vbool32_t, vuint32m1_t, vuint32m1_t, vuint32m1_t, const uint32_t *, vuint64m2_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vluxseg3ei64_v)))
void vluxseg3ei64_v_u32m2(vuint32m2_t *, vuint32m2_t *, vuint32m2_t *, const uint32_t *, vuint64m4_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vluxseg3ei64_v_m)))
void vluxseg3ei64_v_u32m2_m(vuint32m2_t *, vuint32m2_t *, vuint32m2_t *, vbool16_t, vuint32m2_t, vuint32m2_t, vuint32m2_t, const uint32_t *, vuint64m4_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vluxseg3ei64_v)))
void vluxseg3ei64_v_u32mf2(vuint32mf2_t *, vuint32mf2_t *, vuint32mf2_t *, const uint32_t *, vuint64m1_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vluxseg3ei64_v_m)))
void vluxseg3ei64_v_u32mf2_m(vuint32mf2_t *, vuint32mf2_t *, vuint32mf2_t *, vbool64_t, vuint32mf2_t, vuint32mf2_t, vuint32mf2_t, const uint32_t *, vuint64m1_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vluxseg4ei64_v)))
void vluxseg4ei64_v_i32m1(vint32m1_t *, vint32m1_t *, vint32m1_t *, vint32m1_t *, const int32_t *, vuint64m2_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vluxseg4ei64_v_m)))
void vluxseg4ei64_v_i32m1_m(vint32m1_t *, vint32m1_t *, vint32m1_t *, vint32m1_t *, vbool32_t, vint32m1_t, vint32m1_t, vint32m1_t, vint32m1_t, const int32_t *, vuint64m2_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vluxseg4ei64_v)))
void vluxseg4ei64_v_i32m2(vint32m2_t *, vint32m2_t *, vint32m2_t *, vint32m2_t *, const int32_t *, vuint64m4_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vluxseg4ei64_v_m)))
void vluxseg4ei64_v_i32m2_m(vint32m2_t *, vint32m2_t *, vint32m2_t *, vint32m2_t *, vbool16_t, vint32m2_t, vint32m2_t, vint32m2_t, vint32m2_t, const int32_t *, vuint64m4_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vluxseg4ei64_v)))
void vluxseg4ei64_v_i32mf2(vint32mf2_t *, vint32mf2_t *, vint32mf2_t *, vint32mf2_t *, const int32_t *, vuint64m1_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vluxseg4ei64_v_m)))
void vluxseg4ei64_v_i32mf2_m(vint32mf2_t *, vint32mf2_t *, vint32mf2_t *, vint32mf2_t *, vbool64_t, vint32mf2_t, vint32mf2_t, vint32mf2_t, vint32mf2_t, const int32_t *, vuint64m1_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vluxseg4ei64_v)))
void vluxseg4ei64_v_u32m1(vuint32m1_t *, vuint32m1_t *, vuint32m1_t *, vuint32m1_t *, const uint32_t *, vuint64m2_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vluxseg4ei64_v_m)))
void vluxseg4ei64_v_u32m1_m(vuint32m1_t *, vuint32m1_t *, vuint32m1_t *, vuint32m1_t *, vbool32_t, vuint32m1_t, vuint32m1_t, vuint32m1_t, vuint32m1_t, const uint32_t *, vuint64m2_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vluxseg4ei64_v)))
void vluxseg4ei64_v_u32m2(vuint32m2_t *, vuint32m2_t *, vuint32m2_t *, vuint32m2_t *, const uint32_t *, vuint64m4_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vluxseg4ei64_v_m)))
void vluxseg4ei64_v_u32m2_m(vuint32m2_t *, vuint32m2_t *, vuint32m2_t *, vuint32m2_t *, vbool16_t, vuint32m2_t, vuint32m2_t, vuint32m2_t, vuint32m2_t, const uint32_t *, vuint64m4_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vluxseg4ei64_v)))
void vluxseg4ei64_v_u32mf2(vuint32mf2_t *, vuint32mf2_t *, vuint32mf2_t *, vuint32mf2_t *, const uint32_t *, vuint64m1_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vluxseg4ei64_v_m)))
void vluxseg4ei64_v_u32mf2_m(vuint32mf2_t *, vuint32mf2_t *, vuint32mf2_t *, vuint32mf2_t *, vbool64_t, vuint32mf2_t, vuint32mf2_t, vuint32mf2_t, vuint32mf2_t, const uint32_t *, vuint64m1_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vluxseg5ei64_v)))
void vluxseg5ei64_v_i32m1(vint32m1_t *, vint32m1_t *, vint32m1_t *, vint32m1_t *, vint32m1_t *, const int32_t *, vuint64m2_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vluxseg5ei64_v_m)))
void vluxseg5ei64_v_i32m1_m(vint32m1_t *, vint32m1_t *, vint32m1_t *, vint32m1_t *, vint32m1_t *, vbool32_t, vint32m1_t, vint32m1_t, vint32m1_t, vint32m1_t, vint32m1_t, const int32_t *, vuint64m2_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vluxseg5ei64_v)))
void vluxseg5ei64_v_i32mf2(vint32mf2_t *, vint32mf2_t *, vint32mf2_t *, vint32mf2_t *, vint32mf2_t *, const int32_t *, vuint64m1_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vluxseg5ei64_v_m)))
void vluxseg5ei64_v_i32mf2_m(vint32mf2_t *, vint32mf2_t *, vint32mf2_t *, vint32mf2_t *, vint32mf2_t *, vbool64_t, vint32mf2_t, vint32mf2_t, vint32mf2_t, vint32mf2_t, vint32mf2_t, const int32_t *, vuint64m1_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vluxseg5ei64_v)))
void vluxseg5ei64_v_u32m1(vuint32m1_t *, vuint32m1_t *, vuint32m1_t *, vuint32m1_t *, vuint32m1_t *, const uint32_t *, vuint64m2_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vluxseg5ei64_v_m)))
void vluxseg5ei64_v_u32m1_m(vuint32m1_t *, vuint32m1_t *, vuint32m1_t *, vuint32m1_t *, vuint32m1_t *, vbool32_t, vuint32m1_t, vuint32m1_t, vuint32m1_t, vuint32m1_t, vuint32m1_t, const uint32_t *, vuint64m2_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vluxseg5ei64_v)))
void vluxseg5ei64_v_u32mf2(vuint32mf2_t *, vuint32mf2_t *, vuint32mf2_t *, vuint32mf2_t *, vuint32mf2_t *, const uint32_t *, vuint64m1_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vluxseg5ei64_v_m)))
void vluxseg5ei64_v_u32mf2_m(vuint32mf2_t *, vuint32mf2_t *, vuint32mf2_t *, vuint32mf2_t *, vuint32mf2_t *, vbool64_t, vuint32mf2_t, vuint32mf2_t, vuint32mf2_t, vuint32mf2_t, vuint32mf2_t, const uint32_t *, vuint64m1_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vluxseg6ei64_v)))
void vluxseg6ei64_v_i32m1(vint32m1_t *, vint32m1_t *, vint32m1_t *, vint32m1_t *, vint32m1_t *, vint32m1_t *, const int32_t *, vuint64m2_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vluxseg6ei64_v_m)))
void vluxseg6ei64_v_i32m1_m(vint32m1_t *, vint32m1_t *, vint32m1_t *, vint32m1_t *, vint32m1_t *, vint32m1_t *, vbool32_t, vint32m1_t, vint32m1_t, vint32m1_t, vint32m1_t, vint32m1_t, vint32m1_t, const int32_t *, vuint64m2_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vluxseg6ei64_v)))
void vluxseg6ei64_v_i32mf2(vint32mf2_t *, vint32mf2_t *, vint32mf2_t *, vint32mf2_t *, vint32mf2_t *, vint32mf2_t *, const int32_t *, vuint64m1_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vluxseg6ei64_v_m)))
void vluxseg6ei64_v_i32mf2_m(vint32mf2_t *, vint32mf2_t *, vint32mf2_t *, vint32mf2_t *, vint32mf2_t *, vint32mf2_t *, vbool64_t, vint32mf2_t, vint32mf2_t, vint32mf2_t, vint32mf2_t, vint32mf2_t, vint32mf2_t, const int32_t *, vuint64m1_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vluxseg6ei64_v)))
void vluxseg6ei64_v_u32m1(vuint32m1_t *, vuint32m1_t *, vuint32m1_t *, vuint32m1_t *, vuint32m1_t *, vuint32m1_t *, const uint32_t *, vuint64m2_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vluxseg6ei64_v_m)))
void vluxseg6ei64_v_u32m1_m(vuint32m1_t *, vuint32m1_t *, vuint32m1_t *, vuint32m1_t *, vuint32m1_t *, vuint32m1_t *, vbool32_t, vuint32m1_t, vuint32m1_t, vuint32m1_t, vuint32m1_t, vuint32m1_t, vuint32m1_t, const uint32_t *, vuint64m2_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vluxseg6ei64_v)))
void vluxseg6ei64_v_u32mf2(vuint32mf2_t *, vuint32mf2_t *, vuint32mf2_t *, vuint32mf2_t *, vuint32mf2_t *, vuint32mf2_t *, const uint32_t *, vuint64m1_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vluxseg6ei64_v_m)))
void vluxseg6ei64_v_u32mf2_m(vuint32mf2_t *, vuint32mf2_t *, vuint32mf2_t *, vuint32mf2_t *, vuint32mf2_t *, vuint32mf2_t *, vbool64_t, vuint32mf2_t, vuint32mf2_t, vuint32mf2_t, vuint32mf2_t, vuint32mf2_t, vuint32mf2_t, const uint32_t *, vuint64m1_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vluxseg7ei64_v)))
void vluxseg7ei64_v_i32m1(vint32m1_t *, vint32m1_t *, vint32m1_t *, vint32m1_t *, vint32m1_t *, vint32m1_t *, vint32m1_t *, const int32_t *, vuint64m2_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vluxseg7ei64_v_m)))
void vluxseg7ei64_v_i32m1_m(vint32m1_t *, vint32m1_t *, vint32m1_t *, vint32m1_t *, vint32m1_t *, vint32m1_t *, vint32m1_t *, vbool32_t, vint32m1_t, vint32m1_t, vint32m1_t, vint32m1_t, vint32m1_t, vint32m1_t, vint32m1_t, const int32_t *, vuint64m2_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vluxseg7ei64_v)))
void vluxseg7ei64_v_i32mf2(vint32mf2_t *, vint32mf2_t *, vint32mf2_t *, vint32mf2_t *, vint32mf2_t *, vint32mf2_t *, vint32mf2_t *, const int32_t *, vuint64m1_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vluxseg7ei64_v_m)))
void vluxseg7ei64_v_i32mf2_m(vint32mf2_t *, vint32mf2_t *, vint32mf2_t *, vint32mf2_t *, vint32mf2_t *, vint32mf2_t *, vint32mf2_t *, vbool64_t, vint32mf2_t, vint32mf2_t, vint32mf2_t, vint32mf2_t, vint32mf2_t, vint32mf2_t, vint32mf2_t, const int32_t *, vuint64m1_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vluxseg7ei64_v)))
void vluxseg7ei64_v_u32m1(vuint32m1_t *, vuint32m1_t *, vuint32m1_t *, vuint32m1_t *, vuint32m1_t *, vuint32m1_t *, vuint32m1_t *, const uint32_t *, vuint64m2_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vluxseg7ei64_v_m)))
void vluxseg7ei64_v_u32m1_m(vuint32m1_t *, vuint32m1_t *, vuint32m1_t *, vuint32m1_t *, vuint32m1_t *, vuint32m1_t *, vuint32m1_t *, vbool32_t, vuint32m1_t, vuint32m1_t, vuint32m1_t, vuint32m1_t, vuint32m1_t, vuint32m1_t, vuint32m1_t, const uint32_t *, vuint64m2_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vluxseg7ei64_v)))
void vluxseg7ei64_v_u32mf2(vuint32mf2_t *, vuint32mf2_t *, vuint32mf2_t *, vuint32mf2_t *, vuint32mf2_t *, vuint32mf2_t *, vuint32mf2_t *, const uint32_t *, vuint64m1_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vluxseg7ei64_v_m)))
void vluxseg7ei64_v_u32mf2_m(vuint32mf2_t *, vuint32mf2_t *, vuint32mf2_t *, vuint32mf2_t *, vuint32mf2_t *, vuint32mf2_t *, vuint32mf2_t *, vbool64_t, vuint32mf2_t, vuint32mf2_t, vuint32mf2_t, vuint32mf2_t, vuint32mf2_t, vuint32mf2_t, vuint32mf2_t, const uint32_t *, vuint64m1_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vluxseg8ei64_v)))
void vluxseg8ei64_v_i32m1(vint32m1_t *, vint32m1_t *, vint32m1_t *, vint32m1_t *, vint32m1_t *, vint32m1_t *, vint32m1_t *, vint32m1_t *, const int32_t *, vuint64m2_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vluxseg8ei64_v_m)))
void vluxseg8ei64_v_i32m1_m(vint32m1_t *, vint32m1_t *, vint32m1_t *, vint32m1_t *, vint32m1_t *, vint32m1_t *, vint32m1_t *, vint32m1_t *, vbool32_t, vint32m1_t, vint32m1_t, vint32m1_t, vint32m1_t, vint32m1_t, vint32m1_t, vint32m1_t, vint32m1_t, const int32_t *, vuint64m2_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vluxseg8ei64_v)))
void vluxseg8ei64_v_i32mf2(vint32mf2_t *, vint32mf2_t *, vint32mf2_t *, vint32mf2_t *, vint32mf2_t *, vint32mf2_t *, vint32mf2_t *, vint32mf2_t *, const int32_t *, vuint64m1_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vluxseg8ei64_v_m)))
void vluxseg8ei64_v_i32mf2_m(vint32mf2_t *, vint32mf2_t *, vint32mf2_t *, vint32mf2_t *, vint32mf2_t *, vint32mf2_t *, vint32mf2_t *, vint32mf2_t *, vbool64_t, vint32mf2_t, vint32mf2_t, vint32mf2_t, vint32mf2_t, vint32mf2_t, vint32mf2_t, vint32mf2_t, vint32mf2_t, const int32_t *, vuint64m1_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vluxseg8ei64_v)))
void vluxseg8ei64_v_u32m1(vuint32m1_t *, vuint32m1_t *, vuint32m1_t *, vuint32m1_t *, vuint32m1_t *, vuint32m1_t *, vuint32m1_t *, vuint32m1_t *, const uint32_t *, vuint64m2_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vluxseg8ei64_v_m)))
void vluxseg8ei64_v_u32m1_m(vuint32m1_t *, vuint32m1_t *, vuint32m1_t *, vuint32m1_t *, vuint32m1_t *, vuint32m1_t *, vuint32m1_t *, vuint32m1_t *, vbool32_t, vuint32m1_t, vuint32m1_t, vuint32m1_t, vuint32m1_t, vuint32m1_t, vuint32m1_t, vuint32m1_t, vuint32m1_t, const uint32_t *, vuint64m2_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vluxseg8ei64_v)))
void vluxseg8ei64_v_u32mf2(vuint32mf2_t *, vuint32mf2_t *, vuint32mf2_t *, vuint32mf2_t *, vuint32mf2_t *, vuint32mf2_t *, vuint32mf2_t *, vuint32mf2_t *, const uint32_t *, vuint64m1_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vluxseg8ei64_v_m)))
void vluxseg8ei64_v_u32mf2_m(vuint32mf2_t *, vuint32mf2_t *, vuint32mf2_t *, vuint32mf2_t *, vuint32mf2_t *, vuint32mf2_t *, vuint32mf2_t *, vuint32mf2_t *, vbool64_t, vuint32mf2_t, vuint32mf2_t, vuint32mf2_t, vuint32mf2_t, vuint32mf2_t, vuint32mf2_t, vuint32mf2_t, vuint32mf2_t, const uint32_t *, vuint64m1_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vluxseg2ei8_v)))
void vluxseg2ei8_v_i64m1(vint64m1_t *, vint64m1_t *, const int64_t *, vuint8mf8_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vluxseg2ei8_v_m)))
void vluxseg2ei8_v_i64m1_m(vint64m1_t *, vint64m1_t *, vbool64_t, vint64m1_t, vint64m1_t, const int64_t *, vuint8mf8_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vluxseg2ei8_v)))
void vluxseg2ei8_v_i64m2(vint64m2_t *, vint64m2_t *, const int64_t *, vuint8mf4_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vluxseg2ei8_v_m)))
void vluxseg2ei8_v_i64m2_m(vint64m2_t *, vint64m2_t *, vbool32_t, vint64m2_t, vint64m2_t, const int64_t *, vuint8mf4_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vluxseg2ei8_v)))
void vluxseg2ei8_v_i64m4(vint64m4_t *, vint64m4_t *, const int64_t *, vuint8mf2_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vluxseg2ei8_v_m)))
void vluxseg2ei8_v_i64m4_m(vint64m4_t *, vint64m4_t *, vbool16_t, vint64m4_t, vint64m4_t, const int64_t *, vuint8mf2_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vluxseg2ei8_v)))
void vluxseg2ei8_v_u64m1(vuint64m1_t *, vuint64m1_t *, const uint64_t *, vuint8mf8_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vluxseg2ei8_v_m)))
void vluxseg2ei8_v_u64m1_m(vuint64m1_t *, vuint64m1_t *, vbool64_t, vuint64m1_t, vuint64m1_t, const uint64_t *, vuint8mf8_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vluxseg2ei8_v)))
void vluxseg2ei8_v_u64m2(vuint64m2_t *, vuint64m2_t *, const uint64_t *, vuint8mf4_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vluxseg2ei8_v_m)))
void vluxseg2ei8_v_u64m2_m(vuint64m2_t *, vuint64m2_t *, vbool32_t, vuint64m2_t, vuint64m2_t, const uint64_t *, vuint8mf4_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vluxseg2ei8_v)))
void vluxseg2ei8_v_u64m4(vuint64m4_t *, vuint64m4_t *, const uint64_t *, vuint8mf2_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vluxseg2ei8_v_m)))
void vluxseg2ei8_v_u64m4_m(vuint64m4_t *, vuint64m4_t *, vbool16_t, vuint64m4_t, vuint64m4_t, const uint64_t *, vuint8mf2_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vluxseg3ei8_v)))
void vluxseg3ei8_v_i64m1(vint64m1_t *, vint64m1_t *, vint64m1_t *, const int64_t *, vuint8mf8_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vluxseg3ei8_v_m)))
void vluxseg3ei8_v_i64m1_m(vint64m1_t *, vint64m1_t *, vint64m1_t *, vbool64_t, vint64m1_t, vint64m1_t, vint64m1_t, const int64_t *, vuint8mf8_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vluxseg3ei8_v)))
void vluxseg3ei8_v_i64m2(vint64m2_t *, vint64m2_t *, vint64m2_t *, const int64_t *, vuint8mf4_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vluxseg3ei8_v_m)))
void vluxseg3ei8_v_i64m2_m(vint64m2_t *, vint64m2_t *, vint64m2_t *, vbool32_t, vint64m2_t, vint64m2_t, vint64m2_t, const int64_t *, vuint8mf4_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vluxseg3ei8_v)))
void vluxseg3ei8_v_u64m1(vuint64m1_t *, vuint64m1_t *, vuint64m1_t *, const uint64_t *, vuint8mf8_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vluxseg3ei8_v_m)))
void vluxseg3ei8_v_u64m1_m(vuint64m1_t *, vuint64m1_t *, vuint64m1_t *, vbool64_t, vuint64m1_t, vuint64m1_t, vuint64m1_t, const uint64_t *, vuint8mf8_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vluxseg3ei8_v)))
void vluxseg3ei8_v_u64m2(vuint64m2_t *, vuint64m2_t *, vuint64m2_t *, const uint64_t *, vuint8mf4_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vluxseg3ei8_v_m)))
void vluxseg3ei8_v_u64m2_m(vuint64m2_t *, vuint64m2_t *, vuint64m2_t *, vbool32_t, vuint64m2_t, vuint64m2_t, vuint64m2_t, const uint64_t *, vuint8mf4_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vluxseg4ei8_v)))
void vluxseg4ei8_v_i64m1(vint64m1_t *, vint64m1_t *, vint64m1_t *, vint64m1_t *, const int64_t *, vuint8mf8_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vluxseg4ei8_v_m)))
void vluxseg4ei8_v_i64m1_m(vint64m1_t *, vint64m1_t *, vint64m1_t *, vint64m1_t *, vbool64_t, vint64m1_t, vint64m1_t, vint64m1_t, vint64m1_t, const int64_t *, vuint8mf8_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vluxseg4ei8_v)))
void vluxseg4ei8_v_i64m2(vint64m2_t *, vint64m2_t *, vint64m2_t *, vint64m2_t *, const int64_t *, vuint8mf4_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vluxseg4ei8_v_m)))
void vluxseg4ei8_v_i64m2_m(vint64m2_t *, vint64m2_t *, vint64m2_t *, vint64m2_t *, vbool32_t, vint64m2_t, vint64m2_t, vint64m2_t, vint64m2_t, const int64_t *, vuint8mf4_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vluxseg4ei8_v)))
void vluxseg4ei8_v_u64m1(vuint64m1_t *, vuint64m1_t *, vuint64m1_t *, vuint64m1_t *, const uint64_t *, vuint8mf8_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vluxseg4ei8_v_m)))
void vluxseg4ei8_v_u64m1_m(vuint64m1_t *, vuint64m1_t *, vuint64m1_t *, vuint64m1_t *, vbool64_t, vuint64m1_t, vuint64m1_t, vuint64m1_t, vuint64m1_t, const uint64_t *, vuint8mf8_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vluxseg4ei8_v)))
void vluxseg4ei8_v_u64m2(vuint64m2_t *, vuint64m2_t *, vuint64m2_t *, vuint64m2_t *, const uint64_t *, vuint8mf4_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vluxseg4ei8_v_m)))
void vluxseg4ei8_v_u64m2_m(vuint64m2_t *, vuint64m2_t *, vuint64m2_t *, vuint64m2_t *, vbool32_t, vuint64m2_t, vuint64m2_t, vuint64m2_t, vuint64m2_t, const uint64_t *, vuint8mf4_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vluxseg5ei8_v)))
void vluxseg5ei8_v_i64m1(vint64m1_t *, vint64m1_t *, vint64m1_t *, vint64m1_t *, vint64m1_t *, const int64_t *, vuint8mf8_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vluxseg5ei8_v_m)))
void vluxseg5ei8_v_i64m1_m(vint64m1_t *, vint64m1_t *, vint64m1_t *, vint64m1_t *, vint64m1_t *, vbool64_t, vint64m1_t, vint64m1_t, vint64m1_t, vint64m1_t, vint64m1_t, const int64_t *, vuint8mf8_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vluxseg5ei8_v)))
void vluxseg5ei8_v_u64m1(vuint64m1_t *, vuint64m1_t *, vuint64m1_t *, vuint64m1_t *, vuint64m1_t *, const uint64_t *, vuint8mf8_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vluxseg5ei8_v_m)))
void vluxseg5ei8_v_u64m1_m(vuint64m1_t *, vuint64m1_t *, vuint64m1_t *, vuint64m1_t *, vuint64m1_t *, vbool64_t, vuint64m1_t, vuint64m1_t, vuint64m1_t, vuint64m1_t, vuint64m1_t, const uint64_t *, vuint8mf8_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vluxseg6ei8_v)))
void vluxseg6ei8_v_i64m1(vint64m1_t *, vint64m1_t *, vint64m1_t *, vint64m1_t *, vint64m1_t *, vint64m1_t *, const int64_t *, vuint8mf8_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vluxseg6ei8_v_m)))
void vluxseg6ei8_v_i64m1_m(vint64m1_t *, vint64m1_t *, vint64m1_t *, vint64m1_t *, vint64m1_t *, vint64m1_t *, vbool64_t, vint64m1_t, vint64m1_t, vint64m1_t, vint64m1_t, vint64m1_t, vint64m1_t, const int64_t *, vuint8mf8_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vluxseg6ei8_v)))
void vluxseg6ei8_v_u64m1(vuint64m1_t *, vuint64m1_t *, vuint64m1_t *, vuint64m1_t *, vuint64m1_t *, vuint64m1_t *, const uint64_t *, vuint8mf8_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vluxseg6ei8_v_m)))
void vluxseg6ei8_v_u64m1_m(vuint64m1_t *, vuint64m1_t *, vuint64m1_t *, vuint64m1_t *, vuint64m1_t *, vuint64m1_t *, vbool64_t, vuint64m1_t, vuint64m1_t, vuint64m1_t, vuint64m1_t, vuint64m1_t, vuint64m1_t, const uint64_t *, vuint8mf8_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vluxseg7ei8_v)))
void vluxseg7ei8_v_i64m1(vint64m1_t *, vint64m1_t *, vint64m1_t *, vint64m1_t *, vint64m1_t *, vint64m1_t *, vint64m1_t *, const int64_t *, vuint8mf8_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vluxseg7ei8_v_m)))
void vluxseg7ei8_v_i64m1_m(vint64m1_t *, vint64m1_t *, vint64m1_t *, vint64m1_t *, vint64m1_t *, vint64m1_t *, vint64m1_t *, vbool64_t, vint64m1_t, vint64m1_t, vint64m1_t, vint64m1_t, vint64m1_t, vint64m1_t, vint64m1_t, const int64_t *, vuint8mf8_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vneg_v)))
vint64m1_t vneg_v_i64m1(vint64m1_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vneg_v_m)))
vint64m1_t vneg_v_i64m1_m(vbool64_t, vint64m1_t, vint64m1_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vneg_v)))
vint64m2_t vneg_v_i64m2(vint64m2_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vneg_v_m)))
vint64m2_t vneg_v_i64m2_m(vbool32_t, vint64m2_t, vint64m2_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vneg_v)))
vint64m4_t vneg_v_i64m4(vint64m4_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vneg_v_m)))
vint64m4_t vneg_v_i64m4_m(vbool16_t, vint64m4_t, vint64m4_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vneg_v)))
vint64m8_t vneg_v_i64m8(vint64m8_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vneg_v_m)))
vint64m8_t vneg_v_i64m8_m(vbool8_t, vint64m8_t, vint64m8_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vluxseg7ei8_v)))
void vluxseg7ei8_v_u64m1(vuint64m1_t *, vuint64m1_t *, vuint64m1_t *, vuint64m1_t *, vuint64m1_t *, vuint64m1_t *, vuint64m1_t *, const uint64_t *, vuint8mf8_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vluxseg7ei8_v_m)))
void vluxseg7ei8_v_u64m1_m(vuint64m1_t *, vuint64m1_t *, vuint64m1_t *, vuint64m1_t *, vuint64m1_t *, vuint64m1_t *, vuint64m1_t *, vbool64_t, vuint64m1_t, vuint64m1_t, vuint64m1_t, vuint64m1_t, vuint64m1_t, vuint64m1_t, vuint64m1_t, const uint64_t *, vuint8mf8_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vluxseg8ei8_v)))
void vluxseg8ei8_v_i64m1(vint64m1_t *, vint64m1_t *, vint64m1_t *, vint64m1_t *, vint64m1_t *, vint64m1_t *, vint64m1_t *, vint64m1_t *, const int64_t *, vuint8mf8_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vluxseg8ei8_v_m)))
void vluxseg8ei8_v_i64m1_m(vint64m1_t *, vint64m1_t *, vint64m1_t *, vint64m1_t *, vint64m1_t *, vint64m1_t *, vint64m1_t *, vint64m1_t *, vbool64_t, vint64m1_t, vint64m1_t, vint64m1_t, vint64m1_t, vint64m1_t, vint64m1_t, vint64m1_t, vint64m1_t, const int64_t *, vuint8mf8_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vluxseg8ei8_v)))
void vluxseg8ei8_v_u64m1(vuint64m1_t *, vuint64m1_t *, vuint64m1_t *, vuint64m1_t *, vuint64m1_t *, vuint64m1_t *, vuint64m1_t *, vuint64m1_t *, const uint64_t *, vuint8mf8_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vluxseg8ei8_v_m)))
void vluxseg8ei8_v_u64m1_m(vuint64m1_t *, vuint64m1_t *, vuint64m1_t *, vuint64m1_t *, vuint64m1_t *, vuint64m1_t *, vuint64m1_t *, vuint64m1_t *, vbool64_t, vuint64m1_t, vuint64m1_t, vuint64m1_t, vuint64m1_t, vuint64m1_t, vuint64m1_t, vuint64m1_t, vuint64m1_t, const uint64_t *, vuint8mf8_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vluxseg2ei16_v)))
void vluxseg2ei16_v_i64m1(vint64m1_t *, vint64m1_t *, const int64_t *, vuint16mf4_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vluxseg2ei16_v_m)))
void vluxseg2ei16_v_i64m1_m(vint64m1_t *, vint64m1_t *, vbool64_t, vint64m1_t, vint64m1_t, const int64_t *, vuint16mf4_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vluxseg2ei16_v)))
void vluxseg2ei16_v_i64m2(vint64m2_t *, vint64m2_t *, const int64_t *, vuint16mf2_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vluxseg2ei16_v_m)))
void vluxseg2ei16_v_i64m2_m(vint64m2_t *, vint64m2_t *, vbool32_t, vint64m2_t, vint64m2_t, const int64_t *, vuint16mf2_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vluxseg2ei16_v)))
void vluxseg2ei16_v_i64m4(vint64m4_t *, vint64m4_t *, const int64_t *, vuint16m1_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vluxseg2ei16_v_m)))
void vluxseg2ei16_v_i64m4_m(vint64m4_t *, vint64m4_t *, vbool16_t, vint64m4_t, vint64m4_t, const int64_t *, vuint16m1_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vluxseg2ei16_v)))
void vluxseg2ei16_v_u64m1(vuint64m1_t *, vuint64m1_t *, const uint64_t *, vuint16mf4_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vluxseg2ei16_v_m)))
void vluxseg2ei16_v_u64m1_m(vuint64m1_t *, vuint64m1_t *, vbool64_t, vuint64m1_t, vuint64m1_t, const uint64_t *, vuint16mf4_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vluxseg2ei16_v)))
void vluxseg2ei16_v_u64m2(vuint64m2_t *, vuint64m2_t *, const uint64_t *, vuint16mf2_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vluxseg2ei16_v_m)))
void vluxseg2ei16_v_u64m2_m(vuint64m2_t *, vuint64m2_t *, vbool32_t, vuint64m2_t, vuint64m2_t, const uint64_t *, vuint16mf2_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vluxseg2ei16_v)))
void vluxseg2ei16_v_u64m4(vuint64m4_t *, vuint64m4_t *, const uint64_t *, vuint16m1_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vluxseg2ei16_v_m)))
void vluxseg2ei16_v_u64m4_m(vuint64m4_t *, vuint64m4_t *, vbool16_t, vuint64m4_t, vuint64m4_t, const uint64_t *, vuint16m1_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vluxseg3ei16_v)))
void vluxseg3ei16_v_i64m1(vint64m1_t *, vint64m1_t *, vint64m1_t *, const int64_t *, vuint16mf4_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vluxseg3ei16_v_m)))
void vluxseg3ei16_v_i64m1_m(vint64m1_t *, vint64m1_t *, vint64m1_t *, vbool64_t, vint64m1_t, vint64m1_t, vint64m1_t, const int64_t *, vuint16mf4_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vluxseg3ei16_v)))
void vluxseg3ei16_v_i64m2(vint64m2_t *, vint64m2_t *, vint64m2_t *, const int64_t *, vuint16mf2_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vluxseg3ei16_v_m)))
void vluxseg3ei16_v_i64m2_m(vint64m2_t *, vint64m2_t *, vint64m2_t *, vbool32_t, vint64m2_t, vint64m2_t, vint64m2_t, const int64_t *, vuint16mf2_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vluxseg3ei16_v)))
void vluxseg3ei16_v_u64m1(vuint64m1_t *, vuint64m1_t *, vuint64m1_t *, const uint64_t *, vuint16mf4_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vluxseg3ei16_v_m)))
void vluxseg3ei16_v_u64m1_m(vuint64m1_t *, vuint64m1_t *, vuint64m1_t *, vbool64_t, vuint64m1_t, vuint64m1_t, vuint64m1_t, const uint64_t *, vuint16mf4_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vluxseg3ei16_v)))
void vluxseg3ei16_v_u64m2(vuint64m2_t *, vuint64m2_t *, vuint64m2_t *, const uint64_t *, vuint16mf2_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vluxseg3ei16_v_m)))
void vluxseg3ei16_v_u64m2_m(vuint64m2_t *, vuint64m2_t *, vuint64m2_t *, vbool32_t, vuint64m2_t, vuint64m2_t, vuint64m2_t, const uint64_t *, vuint16mf2_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vluxseg4ei16_v)))
void vluxseg4ei16_v_i64m1(vint64m1_t *, vint64m1_t *, vint64m1_t *, vint64m1_t *, const int64_t *, vuint16mf4_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vluxseg4ei16_v_m)))
void vluxseg4ei16_v_i64m1_m(vint64m1_t *, vint64m1_t *, vint64m1_t *, vint64m1_t *, vbool64_t, vint64m1_t, vint64m1_t, vint64m1_t, vint64m1_t, const int64_t *, vuint16mf4_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vluxseg4ei16_v)))
void vluxseg4ei16_v_i64m2(vint64m2_t *, vint64m2_t *, vint64m2_t *, vint64m2_t *, const int64_t *, vuint16mf2_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vluxseg4ei16_v_m)))
void vluxseg4ei16_v_i64m2_m(vint64m2_t *, vint64m2_t *, vint64m2_t *, vint64m2_t *, vbool32_t, vint64m2_t, vint64m2_t, vint64m2_t, vint64m2_t, const int64_t *, vuint16mf2_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vluxseg4ei16_v)))
void vluxseg4ei16_v_u64m1(vuint64m1_t *, vuint64m1_t *, vuint64m1_t *, vuint64m1_t *, const uint64_t *, vuint16mf4_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vluxseg4ei16_v_m)))
void vluxseg4ei16_v_u64m1_m(vuint64m1_t *, vuint64m1_t *, vuint64m1_t *, vuint64m1_t *, vbool64_t, vuint64m1_t, vuint64m1_t, vuint64m1_t, vuint64m1_t, const uint64_t *, vuint16mf4_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vluxseg4ei16_v)))
void vluxseg4ei16_v_u64m2(vuint64m2_t *, vuint64m2_t *, vuint64m2_t *, vuint64m2_t *, const uint64_t *, vuint16mf2_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vluxseg4ei16_v_m)))
void vluxseg4ei16_v_u64m2_m(vuint64m2_t *, vuint64m2_t *, vuint64m2_t *, vuint64m2_t *, vbool32_t, vuint64m2_t, vuint64m2_t, vuint64m2_t, vuint64m2_t, const uint64_t *, vuint16mf2_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vluxseg5ei16_v)))
void vluxseg5ei16_v_i64m1(vint64m1_t *, vint64m1_t *, vint64m1_t *, vint64m1_t *, vint64m1_t *, const int64_t *, vuint16mf4_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vluxseg5ei16_v_m)))
void vluxseg5ei16_v_i64m1_m(vint64m1_t *, vint64m1_t *, vint64m1_t *, vint64m1_t *, vint64m1_t *, vbool64_t, vint64m1_t, vint64m1_t, vint64m1_t, vint64m1_t, vint64m1_t, const int64_t *, vuint16mf4_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vnot_v)))
vint64m1_t vnot_v_i64m1(vint64m1_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vnot_v_m)))
vint64m1_t vnot_v_i64m1_m(vbool64_t, vint64m1_t, vint64m1_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vnot_v)))
vint64m2_t vnot_v_i64m2(vint64m2_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vnot_v_m)))
vint64m2_t vnot_v_i64m2_m(vbool32_t, vint64m2_t, vint64m2_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vnot_v)))
vint64m4_t vnot_v_i64m4(vint64m4_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vnot_v_m)))
vint64m4_t vnot_v_i64m4_m(vbool16_t, vint64m4_t, vint64m4_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vnot_v)))
vint64m8_t vnot_v_i64m8(vint64m8_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vnot_v_m)))
vint64m8_t vnot_v_i64m8_m(vbool8_t, vint64m8_t, vint64m8_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vluxseg5ei16_v)))
void vluxseg5ei16_v_u64m1(vuint64m1_t *, vuint64m1_t *, vuint64m1_t *, vuint64m1_t *, vuint64m1_t *, const uint64_t *, vuint16mf4_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vluxseg5ei16_v_m)))
void vluxseg5ei16_v_u64m1_m(vuint64m1_t *, vuint64m1_t *, vuint64m1_t *, vuint64m1_t *, vuint64m1_t *, vbool64_t, vuint64m1_t, vuint64m1_t, vuint64m1_t, vuint64m1_t, vuint64m1_t, const uint64_t *, vuint16mf4_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vluxseg6ei16_v)))
void vluxseg6ei16_v_i64m1(vint64m1_t *, vint64m1_t *, vint64m1_t *, vint64m1_t *, vint64m1_t *, vint64m1_t *, const int64_t *, vuint16mf4_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vluxseg6ei16_v_m)))
void vluxseg6ei16_v_i64m1_m(vint64m1_t *, vint64m1_t *, vint64m1_t *, vint64m1_t *, vint64m1_t *, vint64m1_t *, vbool64_t, vint64m1_t, vint64m1_t, vint64m1_t, vint64m1_t, vint64m1_t, vint64m1_t, const int64_t *, vuint16mf4_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vluxseg6ei16_v)))
void vluxseg6ei16_v_u64m1(vuint64m1_t *, vuint64m1_t *, vuint64m1_t *, vuint64m1_t *, vuint64m1_t *, vuint64m1_t *, const uint64_t *, vuint16mf4_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vluxseg6ei16_v_m)))
void vluxseg6ei16_v_u64m1_m(vuint64m1_t *, vuint64m1_t *, vuint64m1_t *, vuint64m1_t *, vuint64m1_t *, vuint64m1_t *, vbool64_t, vuint64m1_t, vuint64m1_t, vuint64m1_t, vuint64m1_t, vuint64m1_t, vuint64m1_t, const uint64_t *, vuint16mf4_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vluxseg7ei16_v)))
void vluxseg7ei16_v_i64m1(vint64m1_t *, vint64m1_t *, vint64m1_t *, vint64m1_t *, vint64m1_t *, vint64m1_t *, vint64m1_t *, const int64_t *, vuint16mf4_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vluxseg7ei16_v_m)))
void vluxseg7ei16_v_i64m1_m(vint64m1_t *, vint64m1_t *, vint64m1_t *, vint64m1_t *, vint64m1_t *, vint64m1_t *, vint64m1_t *, vbool64_t, vint64m1_t, vint64m1_t, vint64m1_t, vint64m1_t, vint64m1_t, vint64m1_t, vint64m1_t, const int64_t *, vuint16mf4_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vluxseg7ei16_v)))
void vluxseg7ei16_v_u64m1(vuint64m1_t *, vuint64m1_t *, vuint64m1_t *, vuint64m1_t *, vuint64m1_t *, vuint64m1_t *, vuint64m1_t *, const uint64_t *, vuint16mf4_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vluxseg7ei16_v_m)))
void vluxseg7ei16_v_u64m1_m(vuint64m1_t *, vuint64m1_t *, vuint64m1_t *, vuint64m1_t *, vuint64m1_t *, vuint64m1_t *, vuint64m1_t *, vbool64_t, vuint64m1_t, vuint64m1_t, vuint64m1_t, vuint64m1_t, vuint64m1_t, vuint64m1_t, vuint64m1_t, const uint64_t *, vuint16mf4_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vluxseg8ei16_v)))
void vluxseg8ei16_v_i64m1(vint64m1_t *, vint64m1_t *, vint64m1_t *, vint64m1_t *, vint64m1_t *, vint64m1_t *, vint64m1_t *, vint64m1_t *, const int64_t *, vuint16mf4_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vluxseg8ei16_v_m)))
void vluxseg8ei16_v_i64m1_m(vint64m1_t *, vint64m1_t *, vint64m1_t *, vint64m1_t *, vint64m1_t *, vint64m1_t *, vint64m1_t *, vint64m1_t *, vbool64_t, vint64m1_t, vint64m1_t, vint64m1_t, vint64m1_t, vint64m1_t, vint64m1_t, vint64m1_t, vint64m1_t, const int64_t *, vuint16mf4_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vluxseg8ei16_v)))
void vluxseg8ei16_v_u64m1(vuint64m1_t *, vuint64m1_t *, vuint64m1_t *, vuint64m1_t *, vuint64m1_t *, vuint64m1_t *, vuint64m1_t *, vuint64m1_t *, const uint64_t *, vuint16mf4_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vluxseg8ei16_v_m)))
void vluxseg8ei16_v_u64m1_m(vuint64m1_t *, vuint64m1_t *, vuint64m1_t *, vuint64m1_t *, vuint64m1_t *, vuint64m1_t *, vuint64m1_t *, vuint64m1_t *, vbool64_t, vuint64m1_t, vuint64m1_t, vuint64m1_t, vuint64m1_t, vuint64m1_t, vuint64m1_t, vuint64m1_t, vuint64m1_t, const uint64_t *, vuint16mf4_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vluxseg2ei32_v)))
void vluxseg2ei32_v_i64m1(vint64m1_t *, vint64m1_t *, const int64_t *, vuint32mf2_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vluxseg2ei32_v_m)))
void vluxseg2ei32_v_i64m1_m(vint64m1_t *, vint64m1_t *, vbool64_t, vint64m1_t, vint64m1_t, const int64_t *, vuint32mf2_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vluxseg2ei32_v)))
void vluxseg2ei32_v_i64m2(vint64m2_t *, vint64m2_t *, const int64_t *, vuint32m1_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vluxseg2ei32_v_m)))
void vluxseg2ei32_v_i64m2_m(vint64m2_t *, vint64m2_t *, vbool32_t, vint64m2_t, vint64m2_t, const int64_t *, vuint32m1_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vluxseg2ei32_v)))
void vluxseg2ei32_v_i64m4(vint64m4_t *, vint64m4_t *, const int64_t *, vuint32m2_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vluxseg2ei32_v_m)))
void vluxseg2ei32_v_i64m4_m(vint64m4_t *, vint64m4_t *, vbool16_t, vint64m4_t, vint64m4_t, const int64_t *, vuint32m2_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vluxseg2ei32_v)))
void vluxseg2ei32_v_u64m1(vuint64m1_t *, vuint64m1_t *, const uint64_t *, vuint32mf2_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vluxseg2ei32_v_m)))
void vluxseg2ei32_v_u64m1_m(vuint64m1_t *, vuint64m1_t *, vbool64_t, vuint64m1_t, vuint64m1_t, const uint64_t *, vuint32mf2_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vluxseg2ei32_v)))
void vluxseg2ei32_v_u64m2(vuint64m2_t *, vuint64m2_t *, const uint64_t *, vuint32m1_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vluxseg2ei32_v_m)))
void vluxseg2ei32_v_u64m2_m(vuint64m2_t *, vuint64m2_t *, vbool32_t, vuint64m2_t, vuint64m2_t, const uint64_t *, vuint32m1_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vluxseg2ei32_v)))
void vluxseg2ei32_v_u64m4(vuint64m4_t *, vuint64m4_t *, const uint64_t *, vuint32m2_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vluxseg2ei32_v_m)))
void vluxseg2ei32_v_u64m4_m(vuint64m4_t *, vuint64m4_t *, vbool16_t, vuint64m4_t, vuint64m4_t, const uint64_t *, vuint32m2_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vluxseg3ei32_v)))
void vluxseg3ei32_v_i64m1(vint64m1_t *, vint64m1_t *, vint64m1_t *, const int64_t *, vuint32mf2_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vluxseg3ei32_v_m)))
void vluxseg3ei32_v_i64m1_m(vint64m1_t *, vint64m1_t *, vint64m1_t *, vbool64_t, vint64m1_t, vint64m1_t, vint64m1_t, const int64_t *, vuint32mf2_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vluxseg3ei32_v)))
void vluxseg3ei32_v_i64m2(vint64m2_t *, vint64m2_t *, vint64m2_t *, const int64_t *, vuint32m1_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vluxseg3ei32_v_m)))
void vluxseg3ei32_v_i64m2_m(vint64m2_t *, vint64m2_t *, vint64m2_t *, vbool32_t, vint64m2_t, vint64m2_t, vint64m2_t, const int64_t *, vuint32m1_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vnot_v)))
vuint64m1_t vnot_v_u64m1(vuint64m1_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vnot_v_m)))
vuint64m1_t vnot_v_u64m1_m(vbool64_t, vuint64m1_t, vuint64m1_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vnot_v)))
vuint64m2_t vnot_v_u64m2(vuint64m2_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vnot_v_m)))
vuint64m2_t vnot_v_u64m2_m(vbool32_t, vuint64m2_t, vuint64m2_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vnot_v)))
vuint64m4_t vnot_v_u64m4(vuint64m4_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vnot_v_m)))
vuint64m4_t vnot_v_u64m4_m(vbool16_t, vuint64m4_t, vuint64m4_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vnot_v)))
vuint64m8_t vnot_v_u64m8(vuint64m8_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vnot_v_m)))
vuint64m8_t vnot_v_u64m8_m(vbool8_t, vuint64m8_t, vuint64m8_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vluxseg3ei32_v)))
void vluxseg3ei32_v_u64m1(vuint64m1_t *, vuint64m1_t *, vuint64m1_t *, const uint64_t *, vuint32mf2_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vluxseg3ei32_v_m)))
void vluxseg3ei32_v_u64m1_m(vuint64m1_t *, vuint64m1_t *, vuint64m1_t *, vbool64_t, vuint64m1_t, vuint64m1_t, vuint64m1_t, const uint64_t *, vuint32mf2_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vluxseg3ei32_v)))
void vluxseg3ei32_v_u64m2(vuint64m2_t *, vuint64m2_t *, vuint64m2_t *, const uint64_t *, vuint32m1_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vluxseg3ei32_v_m)))
void vluxseg3ei32_v_u64m2_m(vuint64m2_t *, vuint64m2_t *, vuint64m2_t *, vbool32_t, vuint64m2_t, vuint64m2_t, vuint64m2_t, const uint64_t *, vuint32m1_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vluxseg4ei32_v)))
void vluxseg4ei32_v_i64m1(vint64m1_t *, vint64m1_t *, vint64m1_t *, vint64m1_t *, const int64_t *, vuint32mf2_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vluxseg4ei32_v_m)))
void vluxseg4ei32_v_i64m1_m(vint64m1_t *, vint64m1_t *, vint64m1_t *, vint64m1_t *, vbool64_t, vint64m1_t, vint64m1_t, vint64m1_t, vint64m1_t, const int64_t *, vuint32mf2_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vluxseg4ei32_v)))
void vluxseg4ei32_v_i64m2(vint64m2_t *, vint64m2_t *, vint64m2_t *, vint64m2_t *, const int64_t *, vuint32m1_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vluxseg4ei32_v_m)))
void vluxseg4ei32_v_i64m2_m(vint64m2_t *, vint64m2_t *, vint64m2_t *, vint64m2_t *, vbool32_t, vint64m2_t, vint64m2_t, vint64m2_t, vint64m2_t, const int64_t *, vuint32m1_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vluxseg4ei32_v)))
void vluxseg4ei32_v_u64m1(vuint64m1_t *, vuint64m1_t *, vuint64m1_t *, vuint64m1_t *, const uint64_t *, vuint32mf2_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vluxseg4ei32_v_m)))
void vluxseg4ei32_v_u64m1_m(vuint64m1_t *, vuint64m1_t *, vuint64m1_t *, vuint64m1_t *, vbool64_t, vuint64m1_t, vuint64m1_t, vuint64m1_t, vuint64m1_t, const uint64_t *, vuint32mf2_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vluxseg4ei32_v)))
void vluxseg4ei32_v_u64m2(vuint64m2_t *, vuint64m2_t *, vuint64m2_t *, vuint64m2_t *, const uint64_t *, vuint32m1_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vluxseg4ei32_v_m)))
void vluxseg4ei32_v_u64m2_m(vuint64m2_t *, vuint64m2_t *, vuint64m2_t *, vuint64m2_t *, vbool32_t, vuint64m2_t, vuint64m2_t, vuint64m2_t, vuint64m2_t, const uint64_t *, vuint32m1_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vluxseg5ei32_v)))
void vluxseg5ei32_v_i64m1(vint64m1_t *, vint64m1_t *, vint64m1_t *, vint64m1_t *, vint64m1_t *, const int64_t *, vuint32mf2_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vluxseg5ei32_v_m)))
void vluxseg5ei32_v_i64m1_m(vint64m1_t *, vint64m1_t *, vint64m1_t *, vint64m1_t *, vint64m1_t *, vbool64_t, vint64m1_t, vint64m1_t, vint64m1_t, vint64m1_t, vint64m1_t, const int64_t *, vuint32mf2_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vluxseg5ei32_v)))
void vluxseg5ei32_v_u64m1(vuint64m1_t *, vuint64m1_t *, vuint64m1_t *, vuint64m1_t *, vuint64m1_t *, const uint64_t *, vuint32mf2_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vluxseg5ei32_v_m)))
void vluxseg5ei32_v_u64m1_m(vuint64m1_t *, vuint64m1_t *, vuint64m1_t *, vuint64m1_t *, vuint64m1_t *, vbool64_t, vuint64m1_t, vuint64m1_t, vuint64m1_t, vuint64m1_t, vuint64m1_t, const uint64_t *, vuint32mf2_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vluxseg6ei32_v)))
void vluxseg6ei32_v_i64m1(vint64m1_t *, vint64m1_t *, vint64m1_t *, vint64m1_t *, vint64m1_t *, vint64m1_t *, const int64_t *, vuint32mf2_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vluxseg6ei32_v_m)))
void vluxseg6ei32_v_i64m1_m(vint64m1_t *, vint64m1_t *, vint64m1_t *, vint64m1_t *, vint64m1_t *, vint64m1_t *, vbool64_t, vint64m1_t, vint64m1_t, vint64m1_t, vint64m1_t, vint64m1_t, vint64m1_t, const int64_t *, vuint32mf2_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vluxseg6ei32_v)))
void vluxseg6ei32_v_u64m1(vuint64m1_t *, vuint64m1_t *, vuint64m1_t *, vuint64m1_t *, vuint64m1_t *, vuint64m1_t *, const uint64_t *, vuint32mf2_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vluxseg6ei32_v_m)))
void vluxseg6ei32_v_u64m1_m(vuint64m1_t *, vuint64m1_t *, vuint64m1_t *, vuint64m1_t *, vuint64m1_t *, vuint64m1_t *, vbool64_t, vuint64m1_t, vuint64m1_t, vuint64m1_t, vuint64m1_t, vuint64m1_t, vuint64m1_t, const uint64_t *, vuint32mf2_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vluxseg7ei32_v)))
void vluxseg7ei32_v_i64m1(vint64m1_t *, vint64m1_t *, vint64m1_t *, vint64m1_t *, vint64m1_t *, vint64m1_t *, vint64m1_t *, const int64_t *, vuint32mf2_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vluxseg7ei32_v_m)))
void vluxseg7ei32_v_i64m1_m(vint64m1_t *, vint64m1_t *, vint64m1_t *, vint64m1_t *, vint64m1_t *, vint64m1_t *, vint64m1_t *, vbool64_t, vint64m1_t, vint64m1_t, vint64m1_t, vint64m1_t, vint64m1_t, vint64m1_t, vint64m1_t, const int64_t *, vuint32mf2_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vluxseg7ei32_v)))
void vluxseg7ei32_v_u64m1(vuint64m1_t *, vuint64m1_t *, vuint64m1_t *, vuint64m1_t *, vuint64m1_t *, vuint64m1_t *, vuint64m1_t *, const uint64_t *, vuint32mf2_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vluxseg7ei32_v_m)))
void vluxseg7ei32_v_u64m1_m(vuint64m1_t *, vuint64m1_t *, vuint64m1_t *, vuint64m1_t *, vuint64m1_t *, vuint64m1_t *, vuint64m1_t *, vbool64_t, vuint64m1_t, vuint64m1_t, vuint64m1_t, vuint64m1_t, vuint64m1_t, vuint64m1_t, vuint64m1_t, const uint64_t *, vuint32mf2_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vluxseg8ei32_v)))
void vluxseg8ei32_v_i64m1(vint64m1_t *, vint64m1_t *, vint64m1_t *, vint64m1_t *, vint64m1_t *, vint64m1_t *, vint64m1_t *, vint64m1_t *, const int64_t *, vuint32mf2_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vluxseg8ei32_v_m)))
void vluxseg8ei32_v_i64m1_m(vint64m1_t *, vint64m1_t *, vint64m1_t *, vint64m1_t *, vint64m1_t *, vint64m1_t *, vint64m1_t *, vint64m1_t *, vbool64_t, vint64m1_t, vint64m1_t, vint64m1_t, vint64m1_t, vint64m1_t, vint64m1_t, vint64m1_t, vint64m1_t, const int64_t *, vuint32mf2_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vluxseg8ei32_v)))
void vluxseg8ei32_v_u64m1(vuint64m1_t *, vuint64m1_t *, vuint64m1_t *, vuint64m1_t *, vuint64m1_t *, vuint64m1_t *, vuint64m1_t *, vuint64m1_t *, const uint64_t *, vuint32mf2_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vluxseg8ei32_v_m)))
void vluxseg8ei32_v_u64m1_m(vuint64m1_t *, vuint64m1_t *, vuint64m1_t *, vuint64m1_t *, vuint64m1_t *, vuint64m1_t *, vuint64m1_t *, vuint64m1_t *, vbool64_t, vuint64m1_t, vuint64m1_t, vuint64m1_t, vuint64m1_t, vuint64m1_t, vuint64m1_t, vuint64m1_t, vuint64m1_t, const uint64_t *, vuint32mf2_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vluxseg2ei64_v)))
void vluxseg2ei64_v_i64m1(vint64m1_t *, vint64m1_t *, const int64_t *, vuint64m1_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vluxseg2ei64_v_m)))
void vluxseg2ei64_v_i64m1_m(vint64m1_t *, vint64m1_t *, vbool64_t, vint64m1_t, vint64m1_t, const int64_t *, vuint64m1_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vluxseg2ei64_v)))
void vluxseg2ei64_v_i64m2(vint64m2_t *, vint64m2_t *, const int64_t *, vuint64m2_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vluxseg2ei64_v_m)))
void vluxseg2ei64_v_i64m2_m(vint64m2_t *, vint64m2_t *, vbool32_t, vint64m2_t, vint64m2_t, const int64_t *, vuint64m2_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vluxseg2ei64_v)))
void vluxseg2ei64_v_i64m4(vint64m4_t *, vint64m4_t *, const int64_t *, vuint64m4_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vluxseg2ei64_v_m)))
void vluxseg2ei64_v_i64m4_m(vint64m4_t *, vint64m4_t *, vbool16_t, vint64m4_t, vint64m4_t, const int64_t *, vuint64m4_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vluxseg2ei64_v)))
void vluxseg2ei64_v_u64m1(vuint64m1_t *, vuint64m1_t *, const uint64_t *, vuint64m1_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vluxseg2ei64_v_m)))
void vluxseg2ei64_v_u64m1_m(vuint64m1_t *, vuint64m1_t *, vbool64_t, vuint64m1_t, vuint64m1_t, const uint64_t *, vuint64m1_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vluxseg2ei64_v)))
void vluxseg2ei64_v_u64m2(vuint64m2_t *, vuint64m2_t *, const uint64_t *, vuint64m2_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vluxseg2ei64_v_m)))
void vluxseg2ei64_v_u64m2_m(vuint64m2_t *, vuint64m2_t *, vbool32_t, vuint64m2_t, vuint64m2_t, const uint64_t *, vuint64m2_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vluxseg2ei64_v)))
void vluxseg2ei64_v_u64m4(vuint64m4_t *, vuint64m4_t *, const uint64_t *, vuint64m4_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vluxseg2ei64_v_m)))
void vluxseg2ei64_v_u64m4_m(vuint64m4_t *, vuint64m4_t *, vbool16_t, vuint64m4_t, vuint64m4_t, const uint64_t *, vuint64m4_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vluxseg3ei64_v)))
void vluxseg3ei64_v_i64m1(vint64m1_t *, vint64m1_t *, vint64m1_t *, const int64_t *, vuint64m1_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vluxseg3ei64_v_m)))
void vluxseg3ei64_v_i64m1_m(vint64m1_t *, vint64m1_t *, vint64m1_t *, vbool64_t, vint64m1_t, vint64m1_t, vint64m1_t, const int64_t *, vuint64m1_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vluxseg3ei64_v)))
void vluxseg3ei64_v_i64m2(vint64m2_t *, vint64m2_t *, vint64m2_t *, const int64_t *, vuint64m2_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vluxseg3ei64_v_m)))
void vluxseg3ei64_v_i64m2_m(vint64m2_t *, vint64m2_t *, vint64m2_t *, vbool32_t, vint64m2_t, vint64m2_t, vint64m2_t, const int64_t *, vuint64m2_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vluxseg3ei64_v)))
void vluxseg3ei64_v_u64m1(vuint64m1_t *, vuint64m1_t *, vuint64m1_t *, const uint64_t *, vuint64m1_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vluxseg3ei64_v_m)))
void vluxseg3ei64_v_u64m1_m(vuint64m1_t *, vuint64m1_t *, vuint64m1_t *, vbool64_t, vuint64m1_t, vuint64m1_t, vuint64m1_t, const uint64_t *, vuint64m1_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vluxseg3ei64_v)))
void vluxseg3ei64_v_u64m2(vuint64m2_t *, vuint64m2_t *, vuint64m2_t *, const uint64_t *, vuint64m2_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vluxseg3ei64_v_m)))
void vluxseg3ei64_v_u64m2_m(vuint64m2_t *, vuint64m2_t *, vuint64m2_t *, vbool32_t, vuint64m2_t, vuint64m2_t, vuint64m2_t, const uint64_t *, vuint64m2_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vluxseg4ei64_v)))
void vluxseg4ei64_v_i64m1(vint64m1_t *, vint64m1_t *, vint64m1_t *, vint64m1_t *, const int64_t *, vuint64m1_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vluxseg4ei64_v_m)))
void vluxseg4ei64_v_i64m1_m(vint64m1_t *, vint64m1_t *, vint64m1_t *, vint64m1_t *, vbool64_t, vint64m1_t, vint64m1_t, vint64m1_t, vint64m1_t, const int64_t *, vuint64m1_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vluxseg4ei64_v)))
void vluxseg4ei64_v_i64m2(vint64m2_t *, vint64m2_t *, vint64m2_t *, vint64m2_t *, const int64_t *, vuint64m2_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vluxseg4ei64_v_m)))
void vluxseg4ei64_v_i64m2_m(vint64m2_t *, vint64m2_t *, vint64m2_t *, vint64m2_t *, vbool32_t, vint64m2_t, vint64m2_t, vint64m2_t, vint64m2_t, const int64_t *, vuint64m2_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vluxseg4ei64_v)))
void vluxseg4ei64_v_u64m1(vuint64m1_t *, vuint64m1_t *, vuint64m1_t *, vuint64m1_t *, const uint64_t *, vuint64m1_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vluxseg4ei64_v_m)))
void vluxseg4ei64_v_u64m1_m(vuint64m1_t *, vuint64m1_t *, vuint64m1_t *, vuint64m1_t *, vbool64_t, vuint64m1_t, vuint64m1_t, vuint64m1_t, vuint64m1_t, const uint64_t *, vuint64m1_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vluxseg4ei64_v)))
void vluxseg4ei64_v_u64m2(vuint64m2_t *, vuint64m2_t *, vuint64m2_t *, vuint64m2_t *, const uint64_t *, vuint64m2_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vluxseg4ei64_v_m)))
void vluxseg4ei64_v_u64m2_m(vuint64m2_t *, vuint64m2_t *, vuint64m2_t *, vuint64m2_t *, vbool32_t, vuint64m2_t, vuint64m2_t, vuint64m2_t, vuint64m2_t, const uint64_t *, vuint64m2_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vluxseg5ei64_v)))
void vluxseg5ei64_v_i64m1(vint64m1_t *, vint64m1_t *, vint64m1_t *, vint64m1_t *, vint64m1_t *, const int64_t *, vuint64m1_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vluxseg5ei64_v_m)))
void vluxseg5ei64_v_i64m1_m(vint64m1_t *, vint64m1_t *, vint64m1_t *, vint64m1_t *, vint64m1_t *, vbool64_t, vint64m1_t, vint64m1_t, vint64m1_t, vint64m1_t, vint64m1_t, const int64_t *, vuint64m1_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vluxseg5ei64_v)))
void vluxseg5ei64_v_u64m1(vuint64m1_t *, vuint64m1_t *, vuint64m1_t *, vuint64m1_t *, vuint64m1_t *, const uint64_t *, vuint64m1_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vluxseg5ei64_v_m)))
void vluxseg5ei64_v_u64m1_m(vuint64m1_t *, vuint64m1_t *, vuint64m1_t *, vuint64m1_t *, vuint64m1_t *, vbool64_t, vuint64m1_t, vuint64m1_t, vuint64m1_t, vuint64m1_t, vuint64m1_t, const uint64_t *, vuint64m1_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vluxseg6ei64_v)))
void vluxseg6ei64_v_i64m1(vint64m1_t *, vint64m1_t *, vint64m1_t *, vint64m1_t *, vint64m1_t *, vint64m1_t *, const int64_t *, vuint64m1_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vluxseg6ei64_v_m)))
void vluxseg6ei64_v_i64m1_m(vint64m1_t *, vint64m1_t *, vint64m1_t *, vint64m1_t *, vint64m1_t *, vint64m1_t *, vbool64_t, vint64m1_t, vint64m1_t, vint64m1_t, vint64m1_t, vint64m1_t, vint64m1_t, const int64_t *, vuint64m1_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vluxseg6ei64_v)))
void vluxseg6ei64_v_u64m1(vuint64m1_t *, vuint64m1_t *, vuint64m1_t *, vuint64m1_t *, vuint64m1_t *, vuint64m1_t *, const uint64_t *, vuint64m1_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vluxseg6ei64_v_m)))
void vluxseg6ei64_v_u64m1_m(vuint64m1_t *, vuint64m1_t *, vuint64m1_t *, vuint64m1_t *, vuint64m1_t *, vuint64m1_t *, vbool64_t, vuint64m1_t, vuint64m1_t, vuint64m1_t, vuint64m1_t, vuint64m1_t, vuint64m1_t, const uint64_t *, vuint64m1_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vluxseg7ei64_v)))
void vluxseg7ei64_v_i64m1(vint64m1_t *, vint64m1_t *, vint64m1_t *, vint64m1_t *, vint64m1_t *, vint64m1_t *, vint64m1_t *, const int64_t *, vuint64m1_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vluxseg7ei64_v_m)))
void vluxseg7ei64_v_i64m1_m(vint64m1_t *, vint64m1_t *, vint64m1_t *, vint64m1_t *, vint64m1_t *, vint64m1_t *, vint64m1_t *, vbool64_t, vint64m1_t, vint64m1_t, vint64m1_t, vint64m1_t, vint64m1_t, vint64m1_t, vint64m1_t, const int64_t *, vuint64m1_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vluxseg7ei64_v)))
void vluxseg7ei64_v_u64m1(vuint64m1_t *, vuint64m1_t *, vuint64m1_t *, vuint64m1_t *, vuint64m1_t *, vuint64m1_t *, vuint64m1_t *, const uint64_t *, vuint64m1_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vluxseg7ei64_v_m)))
void vluxseg7ei64_v_u64m1_m(vuint64m1_t *, vuint64m1_t *, vuint64m1_t *, vuint64m1_t *, vuint64m1_t *, vuint64m1_t *, vuint64m1_t *, vbool64_t, vuint64m1_t, vuint64m1_t, vuint64m1_t, vuint64m1_t, vuint64m1_t, vuint64m1_t, vuint64m1_t, const uint64_t *, vuint64m1_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vluxseg8ei64_v)))
void vluxseg8ei64_v_i64m1(vint64m1_t *, vint64m1_t *, vint64m1_t *, vint64m1_t *, vint64m1_t *, vint64m1_t *, vint64m1_t *, vint64m1_t *, const int64_t *, vuint64m1_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vluxseg8ei64_v_m)))
void vluxseg8ei64_v_i64m1_m(vint64m1_t *, vint64m1_t *, vint64m1_t *, vint64m1_t *, vint64m1_t *, vint64m1_t *, vint64m1_t *, vint64m1_t *, vbool64_t, vint64m1_t, vint64m1_t, vint64m1_t, vint64m1_t, vint64m1_t, vint64m1_t, vint64m1_t, vint64m1_t, const int64_t *, vuint64m1_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vluxseg8ei64_v)))
void vluxseg8ei64_v_u64m1(vuint64m1_t *, vuint64m1_t *, vuint64m1_t *, vuint64m1_t *, vuint64m1_t *, vuint64m1_t *, vuint64m1_t *, vuint64m1_t *, const uint64_t *, vuint64m1_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vluxseg8ei64_v_m)))
void vluxseg8ei64_v_u64m1_m(vuint64m1_t *, vuint64m1_t *, vuint64m1_t *, vuint64m1_t *, vuint64m1_t *, vuint64m1_t *, vuint64m1_t *, vuint64m1_t *, vbool64_t, vuint64m1_t, vuint64m1_t, vuint64m1_t, vuint64m1_t, vuint64m1_t, vuint64m1_t, vuint64m1_t, vuint64m1_t, const uint64_t *, vuint64m1_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vwcvtu_x_x_v)))
vuint64m2_t vwcvtu_x_x_v_u64m2(vuint32m1_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vwcvtu_x_x_v_m)))
vuint64m2_t vwcvtu_x_x_v_u64m2_m(vbool32_t, vuint64m2_t, vuint32m1_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vwcvtu_x_x_v)))
vuint64m4_t vwcvtu_x_x_v_u64m4(vuint32m2_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vwcvtu_x_x_v_m)))
vuint64m4_t vwcvtu_x_x_v_u64m4_m(vbool16_t, vuint64m4_t, vuint32m2_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vwcvtu_x_x_v)))
vuint64m8_t vwcvtu_x_x_v_u64m8(vuint32m4_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vwcvtu_x_x_v_m)))
vuint64m8_t vwcvtu_x_x_v_u64m8_m(vbool8_t, vuint64m8_t, vuint32m4_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vwcvtu_x_x_v)))
vuint64m1_t vwcvtu_x_x_v_u64m1(vuint32mf2_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vwcvtu_x_x_v_m)))
vuint64m1_t vwcvtu_x_x_v_u64m1_m(vbool64_t, vuint64m1_t, vuint32mf2_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vncvt_x_x_w)))
vint32m1_t vncvt_x_x_w_i32m1(vint64m2_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vncvt_x_x_w_m)))
vint32m1_t vncvt_x_x_w_i32m1_m(vbool32_t, vint32m1_t, vint64m2_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vncvt_x_x_w)))
vint32m2_t vncvt_x_x_w_i32m2(vint64m4_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vncvt_x_x_w_m)))
vint32m2_t vncvt_x_x_w_i32m2_m(vbool16_t, vint32m2_t, vint64m4_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vncvt_x_x_w)))
vint32m4_t vncvt_x_x_w_i32m4(vint64m8_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vncvt_x_x_w_m)))
vint32m4_t vncvt_x_x_w_i32m4_m(vbool8_t, vint32m4_t, vint64m8_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vncvt_x_x_w)))
vint32mf2_t vncvt_x_x_w_i32mf2(vint64m1_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vncvt_x_x_w_m)))
vint32mf2_t vncvt_x_x_w_i32mf2_m(vbool64_t, vint32mf2_t, vint64m1_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vle64_v)))
vint64m1_t vle64_v_i64m1(const int64_t *, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vle64_v_m)))
vint64m1_t vle64_v_i64m1_m(vbool64_t, vint64m1_t, const int64_t *, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vle64_v)))
vint64m2_t vle64_v_i64m2(const int64_t *, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vle64_v_m)))
vint64m2_t vle64_v_i64m2_m(vbool32_t, vint64m2_t, const int64_t *, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vle64_v)))
vint64m4_t vle64_v_i64m4(const int64_t *, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vle64_v_m)))
vint64m4_t vle64_v_i64m4_m(vbool16_t, vint64m4_t, const int64_t *, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vle64_v)))
vint64m8_t vle64_v_i64m8(const int64_t *, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vle64_v_m)))
vint64m8_t vle64_v_i64m8_m(vbool8_t, vint64m8_t, const int64_t *, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vle64_v)))
vuint64m1_t vle64_v_u64m1(const uint64_t *, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vle64_v_m)))
vuint64m1_t vle64_v_u64m1_m(vbool64_t, vuint64m1_t, const uint64_t *, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vle64_v)))
vuint64m2_t vle64_v_u64m2(const uint64_t *, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vle64_v_m)))
vuint64m2_t vle64_v_u64m2_m(vbool32_t, vuint64m2_t, const uint64_t *, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vle64_v)))
vuint64m4_t vle64_v_u64m4(const uint64_t *, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vle64_v_m)))
vuint64m4_t vle64_v_u64m4_m(vbool16_t, vuint64m4_t, const uint64_t *, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vle64_v)))
vuint64m8_t vle64_v_u64m8(const uint64_t *, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vle64_v_m)))
vuint64m8_t vle64_v_u64m8_m(vbool8_t, vuint64m8_t, const uint64_t *, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vloxseg2ei64_v)))
void vloxseg2ei64_v_i8m1(vint8m1_t *, vint8m1_t *, const int8_t *, vuint64m8_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vloxseg2ei64_v_m)))
void vloxseg2ei64_v_i8m1_m(vint8m1_t *, vint8m1_t *, vbool8_t, vint8m1_t, vint8m1_t, const int8_t *, vuint64m8_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vloxseg2ei64_v)))
void vloxseg2ei64_v_i8mf2(vint8mf2_t *, vint8mf2_t *, const int8_t *, vuint64m4_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vloxseg2ei64_v_m)))
void vloxseg2ei64_v_i8mf2_m(vint8mf2_t *, vint8mf2_t *, vbool16_t, vint8mf2_t, vint8mf2_t, const int8_t *, vuint64m4_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vloxseg2ei64_v)))
void vloxseg2ei64_v_i8mf4(vint8mf4_t *, vint8mf4_t *, const int8_t *, vuint64m2_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vloxseg2ei64_v_m)))
void vloxseg2ei64_v_i8mf4_m(vint8mf4_t *, vint8mf4_t *, vbool32_t, vint8mf4_t, vint8mf4_t, const int8_t *, vuint64m2_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vloxseg2ei64_v)))
void vloxseg2ei64_v_i8mf8(vint8mf8_t *, vint8mf8_t *, const int8_t *, vuint64m1_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vloxseg2ei64_v_m)))
void vloxseg2ei64_v_i8mf8_m(vint8mf8_t *, vint8mf8_t *, vbool64_t, vint8mf8_t, vint8mf8_t, const int8_t *, vuint64m1_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vloxseg2ei64_v)))
void vloxseg2ei64_v_u8m1(vuint8m1_t *, vuint8m1_t *, const uint8_t *, vuint64m8_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vloxseg2ei64_v_m)))
void vloxseg2ei64_v_u8m1_m(vuint8m1_t *, vuint8m1_t *, vbool8_t, vuint8m1_t, vuint8m1_t, const uint8_t *, vuint64m8_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vloxseg2ei64_v)))
void vloxseg2ei64_v_u8mf2(vuint8mf2_t *, vuint8mf2_t *, const uint8_t *, vuint64m4_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vloxseg2ei64_v_m)))
void vloxseg2ei64_v_u8mf2_m(vuint8mf2_t *, vuint8mf2_t *, vbool16_t, vuint8mf2_t, vuint8mf2_t, const uint8_t *, vuint64m4_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vloxseg2ei64_v)))
void vloxseg2ei64_v_u8mf4(vuint8mf4_t *, vuint8mf4_t *, const uint8_t *, vuint64m2_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vloxseg2ei64_v_m)))
void vloxseg2ei64_v_u8mf4_m(vuint8mf4_t *, vuint8mf4_t *, vbool32_t, vuint8mf4_t, vuint8mf4_t, const uint8_t *, vuint64m2_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vloxseg2ei64_v)))
void vloxseg2ei64_v_u8mf8(vuint8mf8_t *, vuint8mf8_t *, const uint8_t *, vuint64m1_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vloxseg2ei64_v_m)))
void vloxseg2ei64_v_u8mf8_m(vuint8mf8_t *, vuint8mf8_t *, vbool64_t, vuint8mf8_t, vuint8mf8_t, const uint8_t *, vuint64m1_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vloxseg3ei64_v)))
void vloxseg3ei64_v_i8m1(vint8m1_t *, vint8m1_t *, vint8m1_t *, const int8_t *, vuint64m8_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vloxseg3ei64_v_m)))
void vloxseg3ei64_v_i8m1_m(vint8m1_t *, vint8m1_t *, vint8m1_t *, vbool8_t, vint8m1_t, vint8m1_t, vint8m1_t, const int8_t *, vuint64m8_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vloxseg3ei64_v)))
void vloxseg3ei64_v_i8mf2(vint8mf2_t *, vint8mf2_t *, vint8mf2_t *, const int8_t *, vuint64m4_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vloxseg3ei64_v_m)))
void vloxseg3ei64_v_i8mf2_m(vint8mf2_t *, vint8mf2_t *, vint8mf2_t *, vbool16_t, vint8mf2_t, vint8mf2_t, vint8mf2_t, const int8_t *, vuint64m4_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vloxseg3ei64_v)))
void vloxseg3ei64_v_i8mf4(vint8mf4_t *, vint8mf4_t *, vint8mf4_t *, const int8_t *, vuint64m2_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vloxseg3ei64_v_m)))
void vloxseg3ei64_v_i8mf4_m(vint8mf4_t *, vint8mf4_t *, vint8mf4_t *, vbool32_t, vint8mf4_t, vint8mf4_t, vint8mf4_t, const int8_t *, vuint64m2_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vloxseg3ei64_v)))
void vloxseg3ei64_v_i8mf8(vint8mf8_t *, vint8mf8_t *, vint8mf8_t *, const int8_t *, vuint64m1_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vloxseg3ei64_v_m)))
void vloxseg3ei64_v_i8mf8_m(vint8mf8_t *, vint8mf8_t *, vint8mf8_t *, vbool64_t, vint8mf8_t, vint8mf8_t, vint8mf8_t, const int8_t *, vuint64m1_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vloxseg3ei64_v)))
void vloxseg3ei64_v_u8m1(vuint8m1_t *, vuint8m1_t *, vuint8m1_t *, const uint8_t *, vuint64m8_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vloxseg3ei64_v_m)))
void vloxseg3ei64_v_u8m1_m(vuint8m1_t *, vuint8m1_t *, vuint8m1_t *, vbool8_t, vuint8m1_t, vuint8m1_t, vuint8m1_t, const uint8_t *, vuint64m8_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vloxseg3ei64_v)))
void vloxseg3ei64_v_u8mf2(vuint8mf2_t *, vuint8mf2_t *, vuint8mf2_t *, const uint8_t *, vuint64m4_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vloxseg3ei64_v_m)))
void vloxseg3ei64_v_u8mf2_m(vuint8mf2_t *, vuint8mf2_t *, vuint8mf2_t *, vbool16_t, vuint8mf2_t, vuint8mf2_t, vuint8mf2_t, const uint8_t *, vuint64m4_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vloxseg3ei64_v)))
void vloxseg3ei64_v_u8mf4(vuint8mf4_t *, vuint8mf4_t *, vuint8mf4_t *, const uint8_t *, vuint64m2_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vloxseg3ei64_v_m)))
void vloxseg3ei64_v_u8mf4_m(vuint8mf4_t *, vuint8mf4_t *, vuint8mf4_t *, vbool32_t, vuint8mf4_t, vuint8mf4_t, vuint8mf4_t, const uint8_t *, vuint64m2_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vloxseg3ei64_v)))
void vloxseg3ei64_v_u8mf8(vuint8mf8_t *, vuint8mf8_t *, vuint8mf8_t *, const uint8_t *, vuint64m1_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vloxseg3ei64_v_m)))
void vloxseg3ei64_v_u8mf8_m(vuint8mf8_t *, vuint8mf8_t *, vuint8mf8_t *, vbool64_t, vuint8mf8_t, vuint8mf8_t, vuint8mf8_t, const uint8_t *, vuint64m1_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vloxseg4ei64_v)))
void vloxseg4ei64_v_i8m1(vint8m1_t *, vint8m1_t *, vint8m1_t *, vint8m1_t *, const int8_t *, vuint64m8_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vloxseg4ei64_v_m)))
void vloxseg4ei64_v_i8m1_m(vint8m1_t *, vint8m1_t *, vint8m1_t *, vint8m1_t *, vbool8_t, vint8m1_t, vint8m1_t, vint8m1_t, vint8m1_t, const int8_t *, vuint64m8_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vloxseg4ei64_v)))
void vloxseg4ei64_v_i8mf2(vint8mf2_t *, vint8mf2_t *, vint8mf2_t *, vint8mf2_t *, const int8_t *, vuint64m4_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vloxseg4ei64_v_m)))
void vloxseg4ei64_v_i8mf2_m(vint8mf2_t *, vint8mf2_t *, vint8mf2_t *, vint8mf2_t *, vbool16_t, vint8mf2_t, vint8mf2_t, vint8mf2_t, vint8mf2_t, const int8_t *, vuint64m4_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vloxseg4ei64_v)))
void vloxseg4ei64_v_i8mf4(vint8mf4_t *, vint8mf4_t *, vint8mf4_t *, vint8mf4_t *, const int8_t *, vuint64m2_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vloxseg4ei64_v_m)))
void vloxseg4ei64_v_i8mf4_m(vint8mf4_t *, vint8mf4_t *, vint8mf4_t *, vint8mf4_t *, vbool32_t, vint8mf4_t, vint8mf4_t, vint8mf4_t, vint8mf4_t, const int8_t *, vuint64m2_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vloxseg4ei64_v)))
void vloxseg4ei64_v_i8mf8(vint8mf8_t *, vint8mf8_t *, vint8mf8_t *, vint8mf8_t *, const int8_t *, vuint64m1_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vloxseg4ei64_v_m)))
void vloxseg4ei64_v_i8mf8_m(vint8mf8_t *, vint8mf8_t *, vint8mf8_t *, vint8mf8_t *, vbool64_t, vint8mf8_t, vint8mf8_t, vint8mf8_t, vint8mf8_t, const int8_t *, vuint64m1_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vloxseg4ei64_v)))
void vloxseg4ei64_v_u8m1(vuint8m1_t *, vuint8m1_t *, vuint8m1_t *, vuint8m1_t *, const uint8_t *, vuint64m8_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vloxseg4ei64_v_m)))
void vloxseg4ei64_v_u8m1_m(vuint8m1_t *, vuint8m1_t *, vuint8m1_t *, vuint8m1_t *, vbool8_t, vuint8m1_t, vuint8m1_t, vuint8m1_t, vuint8m1_t, const uint8_t *, vuint64m8_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vloxseg4ei64_v)))
void vloxseg4ei64_v_u8mf2(vuint8mf2_t *, vuint8mf2_t *, vuint8mf2_t *, vuint8mf2_t *, const uint8_t *, vuint64m4_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vloxseg4ei64_v_m)))
void vloxseg4ei64_v_u8mf2_m(vuint8mf2_t *, vuint8mf2_t *, vuint8mf2_t *, vuint8mf2_t *, vbool16_t, vuint8mf2_t, vuint8mf2_t, vuint8mf2_t, vuint8mf2_t, const uint8_t *, vuint64m4_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vloxseg4ei64_v)))
void vloxseg4ei64_v_u8mf4(vuint8mf4_t *, vuint8mf4_t *, vuint8mf4_t *, vuint8mf4_t *, const uint8_t *, vuint64m2_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vloxseg4ei64_v_m)))
void vloxseg4ei64_v_u8mf4_m(vuint8mf4_t *, vuint8mf4_t *, vuint8mf4_t *, vuint8mf4_t *, vbool32_t, vuint8mf4_t, vuint8mf4_t, vuint8mf4_t, vuint8mf4_t, const uint8_t *, vuint64m2_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vloxseg4ei64_v)))
void vloxseg4ei64_v_u8mf8(vuint8mf8_t *, vuint8mf8_t *, vuint8mf8_t *, vuint8mf8_t *, const uint8_t *, vuint64m1_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vloxseg4ei64_v_m)))
void vloxseg4ei64_v_u8mf8_m(vuint8mf8_t *, vuint8mf8_t *, vuint8mf8_t *, vuint8mf8_t *, vbool64_t, vuint8mf8_t, vuint8mf8_t, vuint8mf8_t, vuint8mf8_t, const uint8_t *, vuint64m1_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vloxseg5ei64_v)))
void vloxseg5ei64_v_i8m1(vint8m1_t *, vint8m1_t *, vint8m1_t *, vint8m1_t *, vint8m1_t *, const int8_t *, vuint64m8_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vloxseg5ei64_v_m)))
void vloxseg5ei64_v_i8m1_m(vint8m1_t *, vint8m1_t *, vint8m1_t *, vint8m1_t *, vint8m1_t *, vbool8_t, vint8m1_t, vint8m1_t, vint8m1_t, vint8m1_t, vint8m1_t, const int8_t *, vuint64m8_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vloxseg5ei64_v)))
void vloxseg5ei64_v_i8mf2(vint8mf2_t *, vint8mf2_t *, vint8mf2_t *, vint8mf2_t *, vint8mf2_t *, const int8_t *, vuint64m4_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vloxseg5ei64_v_m)))
void vloxseg5ei64_v_i8mf2_m(vint8mf2_t *, vint8mf2_t *, vint8mf2_t *, vint8mf2_t *, vint8mf2_t *, vbool16_t, vint8mf2_t, vint8mf2_t, vint8mf2_t, vint8mf2_t, vint8mf2_t, const int8_t *, vuint64m4_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vloxseg5ei64_v)))
void vloxseg5ei64_v_i8mf4(vint8mf4_t *, vint8mf4_t *, vint8mf4_t *, vint8mf4_t *, vint8mf4_t *, const int8_t *, vuint64m2_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vloxseg5ei64_v_m)))
void vloxseg5ei64_v_i8mf4_m(vint8mf4_t *, vint8mf4_t *, vint8mf4_t *, vint8mf4_t *, vint8mf4_t *, vbool32_t, vint8mf4_t, vint8mf4_t, vint8mf4_t, vint8mf4_t, vint8mf4_t, const int8_t *, vuint64m2_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vloxseg5ei64_v)))
void vloxseg5ei64_v_i8mf8(vint8mf8_t *, vint8mf8_t *, vint8mf8_t *, vint8mf8_t *, vint8mf8_t *, const int8_t *, vuint64m1_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vloxseg5ei64_v_m)))
void vloxseg5ei64_v_i8mf8_m(vint8mf8_t *, vint8mf8_t *, vint8mf8_t *, vint8mf8_t *, vint8mf8_t *, vbool64_t, vint8mf8_t, vint8mf8_t, vint8mf8_t, vint8mf8_t, vint8mf8_t, const int8_t *, vuint64m1_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vloxseg5ei64_v)))
void vloxseg5ei64_v_u8m1(vuint8m1_t *, vuint8m1_t *, vuint8m1_t *, vuint8m1_t *, vuint8m1_t *, const uint8_t *, vuint64m8_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vloxseg5ei64_v_m)))
void vloxseg5ei64_v_u8m1_m(vuint8m1_t *, vuint8m1_t *, vuint8m1_t *, vuint8m1_t *, vuint8m1_t *, vbool8_t, vuint8m1_t, vuint8m1_t, vuint8m1_t, vuint8m1_t, vuint8m1_t, const uint8_t *, vuint64m8_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vloxseg5ei64_v)))
void vloxseg5ei64_v_u8mf2(vuint8mf2_t *, vuint8mf2_t *, vuint8mf2_t *, vuint8mf2_t *, vuint8mf2_t *, const uint8_t *, vuint64m4_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vloxseg5ei64_v_m)))
void vloxseg5ei64_v_u8mf2_m(vuint8mf2_t *, vuint8mf2_t *, vuint8mf2_t *, vuint8mf2_t *, vuint8mf2_t *, vbool16_t, vuint8mf2_t, vuint8mf2_t, vuint8mf2_t, vuint8mf2_t, vuint8mf2_t, const uint8_t *, vuint64m4_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vloxseg5ei64_v)))
void vloxseg5ei64_v_u8mf4(vuint8mf4_t *, vuint8mf4_t *, vuint8mf4_t *, vuint8mf4_t *, vuint8mf4_t *, const uint8_t *, vuint64m2_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vloxseg5ei64_v_m)))
void vloxseg5ei64_v_u8mf4_m(vuint8mf4_t *, vuint8mf4_t *, vuint8mf4_t *, vuint8mf4_t *, vuint8mf4_t *, vbool32_t, vuint8mf4_t, vuint8mf4_t, vuint8mf4_t, vuint8mf4_t, vuint8mf4_t, const uint8_t *, vuint64m2_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vloxseg5ei64_v)))
void vloxseg5ei64_v_u8mf8(vuint8mf8_t *, vuint8mf8_t *, vuint8mf8_t *, vuint8mf8_t *, vuint8mf8_t *, const uint8_t *, vuint64m1_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vloxseg5ei64_v_m)))
void vloxseg5ei64_v_u8mf8_m(vuint8mf8_t *, vuint8mf8_t *, vuint8mf8_t *, vuint8mf8_t *, vuint8mf8_t *, vbool64_t, vuint8mf8_t, vuint8mf8_t, vuint8mf8_t, vuint8mf8_t, vuint8mf8_t, const uint8_t *, vuint64m1_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vloxseg6ei64_v)))
void vloxseg6ei64_v_i8m1(vint8m1_t *, vint8m1_t *, vint8m1_t *, vint8m1_t *, vint8m1_t *, vint8m1_t *, const int8_t *, vuint64m8_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vloxseg6ei64_v_m)))
void vloxseg6ei64_v_i8m1_m(vint8m1_t *, vint8m1_t *, vint8m1_t *, vint8m1_t *, vint8m1_t *, vint8m1_t *, vbool8_t, vint8m1_t, vint8m1_t, vint8m1_t, vint8m1_t, vint8m1_t, vint8m1_t, const int8_t *, vuint64m8_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vloxseg6ei64_v)))
void vloxseg6ei64_v_i8mf2(vint8mf2_t *, vint8mf2_t *, vint8mf2_t *, vint8mf2_t *, vint8mf2_t *, vint8mf2_t *, const int8_t *, vuint64m4_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vloxseg6ei64_v_m)))
void vloxseg6ei64_v_i8mf2_m(vint8mf2_t *, vint8mf2_t *, vint8mf2_t *, vint8mf2_t *, vint8mf2_t *, vint8mf2_t *, vbool16_t, vint8mf2_t, vint8mf2_t, vint8mf2_t, vint8mf2_t, vint8mf2_t, vint8mf2_t, const int8_t *, vuint64m4_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vloxseg6ei64_v)))
void vloxseg6ei64_v_i8mf4(vint8mf4_t *, vint8mf4_t *, vint8mf4_t *, vint8mf4_t *, vint8mf4_t *, vint8mf4_t *, const int8_t *, vuint64m2_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vloxseg6ei64_v_m)))
void vloxseg6ei64_v_i8mf4_m(vint8mf4_t *, vint8mf4_t *, vint8mf4_t *, vint8mf4_t *, vint8mf4_t *, vint8mf4_t *, vbool32_t, vint8mf4_t, vint8mf4_t, vint8mf4_t, vint8mf4_t, vint8mf4_t, vint8mf4_t, const int8_t *, vuint64m2_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vloxseg6ei64_v)))
void vloxseg6ei64_v_i8mf8(vint8mf8_t *, vint8mf8_t *, vint8mf8_t *, vint8mf8_t *, vint8mf8_t *, vint8mf8_t *, const int8_t *, vuint64m1_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vloxseg6ei64_v_m)))
void vloxseg6ei64_v_i8mf8_m(vint8mf8_t *, vint8mf8_t *, vint8mf8_t *, vint8mf8_t *, vint8mf8_t *, vint8mf8_t *, vbool64_t, vint8mf8_t, vint8mf8_t, vint8mf8_t, vint8mf8_t, vint8mf8_t, vint8mf8_t, const int8_t *, vuint64m1_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vloxseg6ei64_v)))
void vloxseg6ei64_v_u8m1(vuint8m1_t *, vuint8m1_t *, vuint8m1_t *, vuint8m1_t *, vuint8m1_t *, vuint8m1_t *, const uint8_t *, vuint64m8_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vloxseg6ei64_v_m)))
void vloxseg6ei64_v_u8m1_m(vuint8m1_t *, vuint8m1_t *, vuint8m1_t *, vuint8m1_t *, vuint8m1_t *, vuint8m1_t *, vbool8_t, vuint8m1_t, vuint8m1_t, vuint8m1_t, vuint8m1_t, vuint8m1_t, vuint8m1_t, const uint8_t *, vuint64m8_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vloxseg6ei64_v)))
void vloxseg6ei64_v_u8mf2(vuint8mf2_t *, vuint8mf2_t *, vuint8mf2_t *, vuint8mf2_t *, vuint8mf2_t *, vuint8mf2_t *, const uint8_t *, vuint64m4_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vloxseg6ei64_v_m)))
void vloxseg6ei64_v_u8mf2_m(vuint8mf2_t *, vuint8mf2_t *, vuint8mf2_t *, vuint8mf2_t *, vuint8mf2_t *, vuint8mf2_t *, vbool16_t, vuint8mf2_t, vuint8mf2_t, vuint8mf2_t, vuint8mf2_t, vuint8mf2_t, vuint8mf2_t, const uint8_t *, vuint64m4_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vloxseg6ei64_v)))
void vloxseg6ei64_v_u8mf4(vuint8mf4_t *, vuint8mf4_t *, vuint8mf4_t *, vuint8mf4_t *, vuint8mf4_t *, vuint8mf4_t *, const uint8_t *, vuint64m2_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vloxseg6ei64_v_m)))
void vloxseg6ei64_v_u8mf4_m(vuint8mf4_t *, vuint8mf4_t *, vuint8mf4_t *, vuint8mf4_t *, vuint8mf4_t *, vuint8mf4_t *, vbool32_t, vuint8mf4_t, vuint8mf4_t, vuint8mf4_t, vuint8mf4_t, vuint8mf4_t, vuint8mf4_t, const uint8_t *, vuint64m2_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vloxseg6ei64_v)))
void vloxseg6ei64_v_u8mf8(vuint8mf8_t *, vuint8mf8_t *, vuint8mf8_t *, vuint8mf8_t *, vuint8mf8_t *, vuint8mf8_t *, const uint8_t *, vuint64m1_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vloxseg6ei64_v_m)))
void vloxseg6ei64_v_u8mf8_m(vuint8mf8_t *, vuint8mf8_t *, vuint8mf8_t *, vuint8mf8_t *, vuint8mf8_t *, vuint8mf8_t *, vbool64_t, vuint8mf8_t, vuint8mf8_t, vuint8mf8_t, vuint8mf8_t, vuint8mf8_t, vuint8mf8_t, const uint8_t *, vuint64m1_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vloxseg7ei64_v)))
void vloxseg7ei64_v_i8m1(vint8m1_t *, vint8m1_t *, vint8m1_t *, vint8m1_t *, vint8m1_t *, vint8m1_t *, vint8m1_t *, const int8_t *, vuint64m8_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vloxseg7ei64_v_m)))
void vloxseg7ei64_v_i8m1_m(vint8m1_t *, vint8m1_t *, vint8m1_t *, vint8m1_t *, vint8m1_t *, vint8m1_t *, vint8m1_t *, vbool8_t, vint8m1_t, vint8m1_t, vint8m1_t, vint8m1_t, vint8m1_t, vint8m1_t, vint8m1_t, const int8_t *, vuint64m8_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vloxseg7ei64_v)))
void vloxseg7ei64_v_i8mf2(vint8mf2_t *, vint8mf2_t *, vint8mf2_t *, vint8mf2_t *, vint8mf2_t *, vint8mf2_t *, vint8mf2_t *, const int8_t *, vuint64m4_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vloxseg7ei64_v_m)))
void vloxseg7ei64_v_i8mf2_m(vint8mf2_t *, vint8mf2_t *, vint8mf2_t *, vint8mf2_t *, vint8mf2_t *, vint8mf2_t *, vint8mf2_t *, vbool16_t, vint8mf2_t, vint8mf2_t, vint8mf2_t, vint8mf2_t, vint8mf2_t, vint8mf2_t, vint8mf2_t, const int8_t *, vuint64m4_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vloxseg7ei64_v)))
void vloxseg7ei64_v_i8mf4(vint8mf4_t *, vint8mf4_t *, vint8mf4_t *, vint8mf4_t *, vint8mf4_t *, vint8mf4_t *, vint8mf4_t *, const int8_t *, vuint64m2_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vloxseg7ei64_v_m)))
void vloxseg7ei64_v_i8mf4_m(vint8mf4_t *, vint8mf4_t *, vint8mf4_t *, vint8mf4_t *, vint8mf4_t *, vint8mf4_t *, vint8mf4_t *, vbool32_t, vint8mf4_t, vint8mf4_t, vint8mf4_t, vint8mf4_t, vint8mf4_t, vint8mf4_t, vint8mf4_t, const int8_t *, vuint64m2_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vloxseg7ei64_v)))
void vloxseg7ei64_v_i8mf8(vint8mf8_t *, vint8mf8_t *, vint8mf8_t *, vint8mf8_t *, vint8mf8_t *, vint8mf8_t *, vint8mf8_t *, const int8_t *, vuint64m1_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vloxseg7ei64_v_m)))
void vloxseg7ei64_v_i8mf8_m(vint8mf8_t *, vint8mf8_t *, vint8mf8_t *, vint8mf8_t *, vint8mf8_t *, vint8mf8_t *, vint8mf8_t *, vbool64_t, vint8mf8_t, vint8mf8_t, vint8mf8_t, vint8mf8_t, vint8mf8_t, vint8mf8_t, vint8mf8_t, const int8_t *, vuint64m1_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vloxseg7ei64_v)))
void vloxseg7ei64_v_u8m1(vuint8m1_t *, vuint8m1_t *, vuint8m1_t *, vuint8m1_t *, vuint8m1_t *, vuint8m1_t *, vuint8m1_t *, const uint8_t *, vuint64m8_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vloxseg7ei64_v_m)))
void vloxseg7ei64_v_u8m1_m(vuint8m1_t *, vuint8m1_t *, vuint8m1_t *, vuint8m1_t *, vuint8m1_t *, vuint8m1_t *, vuint8m1_t *, vbool8_t, vuint8m1_t, vuint8m1_t, vuint8m1_t, vuint8m1_t, vuint8m1_t, vuint8m1_t, vuint8m1_t, const uint8_t *, vuint64m8_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vloxseg7ei64_v)))
void vloxseg7ei64_v_u8mf2(vuint8mf2_t *, vuint8mf2_t *, vuint8mf2_t *, vuint8mf2_t *, vuint8mf2_t *, vuint8mf2_t *, vuint8mf2_t *, const uint8_t *, vuint64m4_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vloxseg7ei64_v_m)))
void vloxseg7ei64_v_u8mf2_m(vuint8mf2_t *, vuint8mf2_t *, vuint8mf2_t *, vuint8mf2_t *, vuint8mf2_t *, vuint8mf2_t *, vuint8mf2_t *, vbool16_t, vuint8mf2_t, vuint8mf2_t, vuint8mf2_t, vuint8mf2_t, vuint8mf2_t, vuint8mf2_t, vuint8mf2_t, const uint8_t *, vuint64m4_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vloxseg7ei64_v)))
void vloxseg7ei64_v_u8mf4(vuint8mf4_t *, vuint8mf4_t *, vuint8mf4_t *, vuint8mf4_t *, vuint8mf4_t *, vuint8mf4_t *, vuint8mf4_t *, const uint8_t *, vuint64m2_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vloxseg7ei64_v_m)))
void vloxseg7ei64_v_u8mf4_m(vuint8mf4_t *, vuint8mf4_t *, vuint8mf4_t *, vuint8mf4_t *, vuint8mf4_t *, vuint8mf4_t *, vuint8mf4_t *, vbool32_t, vuint8mf4_t, vuint8mf4_t, vuint8mf4_t, vuint8mf4_t, vuint8mf4_t, vuint8mf4_t, vuint8mf4_t, const uint8_t *, vuint64m2_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vloxseg7ei64_v)))
void vloxseg7ei64_v_u8mf8(vuint8mf8_t *, vuint8mf8_t *, vuint8mf8_t *, vuint8mf8_t *, vuint8mf8_t *, vuint8mf8_t *, vuint8mf8_t *, const uint8_t *, vuint64m1_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vloxseg7ei64_v_m)))
void vloxseg7ei64_v_u8mf8_m(vuint8mf8_t *, vuint8mf8_t *, vuint8mf8_t *, vuint8mf8_t *, vuint8mf8_t *, vuint8mf8_t *, vuint8mf8_t *, vbool64_t, vuint8mf8_t, vuint8mf8_t, vuint8mf8_t, vuint8mf8_t, vuint8mf8_t, vuint8mf8_t, vuint8mf8_t, const uint8_t *, vuint64m1_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vloxseg8ei64_v)))
void vloxseg8ei64_v_i8m1(vint8m1_t *, vint8m1_t *, vint8m1_t *, vint8m1_t *, vint8m1_t *, vint8m1_t *, vint8m1_t *, vint8m1_t *, const int8_t *, vuint64m8_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vloxseg8ei64_v_m)))
void vloxseg8ei64_v_i8m1_m(vint8m1_t *, vint8m1_t *, vint8m1_t *, vint8m1_t *, vint8m1_t *, vint8m1_t *, vint8m1_t *, vint8m1_t *, vbool8_t, vint8m1_t, vint8m1_t, vint8m1_t, vint8m1_t, vint8m1_t, vint8m1_t, vint8m1_t, vint8m1_t, const int8_t *, vuint64m8_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vloxseg8ei64_v)))
void vloxseg8ei64_v_i8mf2(vint8mf2_t *, vint8mf2_t *, vint8mf2_t *, vint8mf2_t *, vint8mf2_t *, vint8mf2_t *, vint8mf2_t *, vint8mf2_t *, const int8_t *, vuint64m4_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vloxseg8ei64_v_m)))
void vloxseg8ei64_v_i8mf2_m(vint8mf2_t *, vint8mf2_t *, vint8mf2_t *, vint8mf2_t *, vint8mf2_t *, vint8mf2_t *, vint8mf2_t *, vint8mf2_t *, vbool16_t, vint8mf2_t, vint8mf2_t, vint8mf2_t, vint8mf2_t, vint8mf2_t, vint8mf2_t, vint8mf2_t, vint8mf2_t, const int8_t *, vuint64m4_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vloxseg8ei64_v)))
void vloxseg8ei64_v_i8mf4(vint8mf4_t *, vint8mf4_t *, vint8mf4_t *, vint8mf4_t *, vint8mf4_t *, vint8mf4_t *, vint8mf4_t *, vint8mf4_t *, const int8_t *, vuint64m2_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vloxseg8ei64_v_m)))
void vloxseg8ei64_v_i8mf4_m(vint8mf4_t *, vint8mf4_t *, vint8mf4_t *, vint8mf4_t *, vint8mf4_t *, vint8mf4_t *, vint8mf4_t *, vint8mf4_t *, vbool32_t, vint8mf4_t, vint8mf4_t, vint8mf4_t, vint8mf4_t, vint8mf4_t, vint8mf4_t, vint8mf4_t, vint8mf4_t, const int8_t *, vuint64m2_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vloxseg8ei64_v)))
void vloxseg8ei64_v_i8mf8(vint8mf8_t *, vint8mf8_t *, vint8mf8_t *, vint8mf8_t *, vint8mf8_t *, vint8mf8_t *, vint8mf8_t *, vint8mf8_t *, const int8_t *, vuint64m1_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vloxseg8ei64_v_m)))
void vloxseg8ei64_v_i8mf8_m(vint8mf8_t *, vint8mf8_t *, vint8mf8_t *, vint8mf8_t *, vint8mf8_t *, vint8mf8_t *, vint8mf8_t *, vint8mf8_t *, vbool64_t, vint8mf8_t, vint8mf8_t, vint8mf8_t, vint8mf8_t, vint8mf8_t, vint8mf8_t, vint8mf8_t, vint8mf8_t, const int8_t *, vuint64m1_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vloxseg8ei64_v)))
void vloxseg8ei64_v_u8m1(vuint8m1_t *, vuint8m1_t *, vuint8m1_t *, vuint8m1_t *, vuint8m1_t *, vuint8m1_t *, vuint8m1_t *, vuint8m1_t *, const uint8_t *, vuint64m8_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vloxseg8ei64_v_m)))
void vloxseg8ei64_v_u8m1_m(vuint8m1_t *, vuint8m1_t *, vuint8m1_t *, vuint8m1_t *, vuint8m1_t *, vuint8m1_t *, vuint8m1_t *, vuint8m1_t *, vbool8_t, vuint8m1_t, vuint8m1_t, vuint8m1_t, vuint8m1_t, vuint8m1_t, vuint8m1_t, vuint8m1_t, vuint8m1_t, const uint8_t *, vuint64m8_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vloxseg8ei64_v)))
void vloxseg8ei64_v_u8mf2(vuint8mf2_t *, vuint8mf2_t *, vuint8mf2_t *, vuint8mf2_t *, vuint8mf2_t *, vuint8mf2_t *, vuint8mf2_t *, vuint8mf2_t *, const uint8_t *, vuint64m4_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vloxseg8ei64_v_m)))
void vloxseg8ei64_v_u8mf2_m(vuint8mf2_t *, vuint8mf2_t *, vuint8mf2_t *, vuint8mf2_t *, vuint8mf2_t *, vuint8mf2_t *, vuint8mf2_t *, vuint8mf2_t *, vbool16_t, vuint8mf2_t, vuint8mf2_t, vuint8mf2_t, vuint8mf2_t, vuint8mf2_t, vuint8mf2_t, vuint8mf2_t, vuint8mf2_t, const uint8_t *, vuint64m4_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vloxseg8ei64_v)))
void vloxseg8ei64_v_u8mf4(vuint8mf4_t *, vuint8mf4_t *, vuint8mf4_t *, vuint8mf4_t *, vuint8mf4_t *, vuint8mf4_t *, vuint8mf4_t *, vuint8mf4_t *, const uint8_t *, vuint64m2_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vloxseg8ei64_v_m)))
void vloxseg8ei64_v_u8mf4_m(vuint8mf4_t *, vuint8mf4_t *, vuint8mf4_t *, vuint8mf4_t *, vuint8mf4_t *, vuint8mf4_t *, vuint8mf4_t *, vuint8mf4_t *, vbool32_t, vuint8mf4_t, vuint8mf4_t, vuint8mf4_t, vuint8mf4_t, vuint8mf4_t, vuint8mf4_t, vuint8mf4_t, vuint8mf4_t, const uint8_t *, vuint64m2_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vloxseg8ei64_v)))
void vloxseg8ei64_v_u8mf8(vuint8mf8_t *, vuint8mf8_t *, vuint8mf8_t *, vuint8mf8_t *, vuint8mf8_t *, vuint8mf8_t *, vuint8mf8_t *, vuint8mf8_t *, const uint8_t *, vuint64m1_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vloxseg8ei64_v_m)))
void vloxseg8ei64_v_u8mf8_m(vuint8mf8_t *, vuint8mf8_t *, vuint8mf8_t *, vuint8mf8_t *, vuint8mf8_t *, vuint8mf8_t *, vuint8mf8_t *, vuint8mf8_t *, vbool64_t, vuint8mf8_t, vuint8mf8_t, vuint8mf8_t, vuint8mf8_t, vuint8mf8_t, vuint8mf8_t, vuint8mf8_t, vuint8mf8_t, const uint8_t *, vuint64m1_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vse64_v)))
void vse64_v_i64m1(int64_t *, vint64m1_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vse64_v_m)))
void vse64_v_i64m1_m(vbool64_t, int64_t *, vint64m1_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vse64_v)))
void vse64_v_i64m2(int64_t *, vint64m2_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vse64_v_m)))
void vse64_v_i64m2_m(vbool32_t, int64_t *, vint64m2_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vse64_v)))
void vse64_v_i64m4(int64_t *, vint64m4_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vse64_v_m)))
void vse64_v_i64m4_m(vbool16_t, int64_t *, vint64m4_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vse64_v)))
void vse64_v_i64m8(int64_t *, vint64m8_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vse64_v_m)))
void vse64_v_i64m8_m(vbool8_t, int64_t *, vint64m8_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vloxseg2ei64_v)))
void vloxseg2ei64_v_i16m1(vint16m1_t *, vint16m1_t *, const int16_t *, vuint64m4_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vloxseg2ei64_v_m)))
void vloxseg2ei64_v_i16m1_m(vint16m1_t *, vint16m1_t *, vbool16_t, vint16m1_t, vint16m1_t, const int16_t *, vuint64m4_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vloxseg2ei64_v)))
void vloxseg2ei64_v_i16m2(vint16m2_t *, vint16m2_t *, const int16_t *, vuint64m8_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vloxseg2ei64_v_m)))
void vloxseg2ei64_v_i16m2_m(vint16m2_t *, vint16m2_t *, vbool8_t, vint16m2_t, vint16m2_t, const int16_t *, vuint64m8_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vloxseg2ei64_v)))
void vloxseg2ei64_v_i16mf2(vint16mf2_t *, vint16mf2_t *, const int16_t *, vuint64m2_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vloxseg2ei64_v_m)))
void vloxseg2ei64_v_i16mf2_m(vint16mf2_t *, vint16mf2_t *, vbool32_t, vint16mf2_t, vint16mf2_t, const int16_t *, vuint64m2_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vloxseg2ei64_v)))
void vloxseg2ei64_v_i16mf4(vint16mf4_t *, vint16mf4_t *, const int16_t *, vuint64m1_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vloxseg2ei64_v_m)))
void vloxseg2ei64_v_i16mf4_m(vint16mf4_t *, vint16mf4_t *, vbool64_t, vint16mf4_t, vint16mf4_t, const int16_t *, vuint64m1_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vloxseg2ei64_v)))
void vloxseg2ei64_v_u16m1(vuint16m1_t *, vuint16m1_t *, const uint16_t *, vuint64m4_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vloxseg2ei64_v_m)))
void vloxseg2ei64_v_u16m1_m(vuint16m1_t *, vuint16m1_t *, vbool16_t, vuint16m1_t, vuint16m1_t, const uint16_t *, vuint64m4_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vloxseg2ei64_v)))
void vloxseg2ei64_v_u16m2(vuint16m2_t *, vuint16m2_t *, const uint16_t *, vuint64m8_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vloxseg2ei64_v_m)))
void vloxseg2ei64_v_u16m2_m(vuint16m2_t *, vuint16m2_t *, vbool8_t, vuint16m2_t, vuint16m2_t, const uint16_t *, vuint64m8_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vloxseg2ei64_v)))
void vloxseg2ei64_v_u16mf2(vuint16mf2_t *, vuint16mf2_t *, const uint16_t *, vuint64m2_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vloxseg2ei64_v_m)))
void vloxseg2ei64_v_u16mf2_m(vuint16mf2_t *, vuint16mf2_t *, vbool32_t, vuint16mf2_t, vuint16mf2_t, const uint16_t *, vuint64m2_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vloxseg2ei64_v)))
void vloxseg2ei64_v_u16mf4(vuint16mf4_t *, vuint16mf4_t *, const uint16_t *, vuint64m1_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vloxseg2ei64_v_m)))
void vloxseg2ei64_v_u16mf4_m(vuint16mf4_t *, vuint16mf4_t *, vbool64_t, vuint16mf4_t, vuint16mf4_t, const uint16_t *, vuint64m1_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vse64_v)))
void vse64_v_u64m1(uint64_t *, vuint64m1_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vse64_v_m)))
void vse64_v_u64m1_m(vbool64_t, uint64_t *, vuint64m1_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vse64_v)))
void vse64_v_u64m2(uint64_t *, vuint64m2_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vse64_v_m)))
void vse64_v_u64m2_m(vbool32_t, uint64_t *, vuint64m2_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vse64_v)))
void vse64_v_u64m4(uint64_t *, vuint64m4_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vse64_v_m)))
void vse64_v_u64m4_m(vbool16_t, uint64_t *, vuint64m4_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vse64_v)))
void vse64_v_u64m8(uint64_t *, vuint64m8_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vse64_v_m)))
void vse64_v_u64m8_m(vbool8_t, uint64_t *, vuint64m8_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vloxseg3ei64_v)))
void vloxseg3ei64_v_i16m1(vint16m1_t *, vint16m1_t *, vint16m1_t *, const int16_t *, vuint64m4_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vloxseg3ei64_v_m)))
void vloxseg3ei64_v_i16m1_m(vint16m1_t *, vint16m1_t *, vint16m1_t *, vbool16_t, vint16m1_t, vint16m1_t, vint16m1_t, const int16_t *, vuint64m4_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vloxseg3ei64_v)))
void vloxseg3ei64_v_i16m2(vint16m2_t *, vint16m2_t *, vint16m2_t *, const int16_t *, vuint64m8_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vloxseg3ei64_v_m)))
void vloxseg3ei64_v_i16m2_m(vint16m2_t *, vint16m2_t *, vint16m2_t *, vbool8_t, vint16m2_t, vint16m2_t, vint16m2_t, const int16_t *, vuint64m8_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vloxseg3ei64_v)))
void vloxseg3ei64_v_i16mf2(vint16mf2_t *, vint16mf2_t *, vint16mf2_t *, const int16_t *, vuint64m2_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vloxseg3ei64_v_m)))
void vloxseg3ei64_v_i16mf2_m(vint16mf2_t *, vint16mf2_t *, vint16mf2_t *, vbool32_t, vint16mf2_t, vint16mf2_t, vint16mf2_t, const int16_t *, vuint64m2_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vloxseg3ei64_v)))
void vloxseg3ei64_v_i16mf4(vint16mf4_t *, vint16mf4_t *, vint16mf4_t *, const int16_t *, vuint64m1_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vloxseg3ei64_v_m)))
void vloxseg3ei64_v_i16mf4_m(vint16mf4_t *, vint16mf4_t *, vint16mf4_t *, vbool64_t, vint16mf4_t, vint16mf4_t, vint16mf4_t, const int16_t *, vuint64m1_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vloxseg3ei64_v)))
void vloxseg3ei64_v_u16m1(vuint16m1_t *, vuint16m1_t *, vuint16m1_t *, const uint16_t *, vuint64m4_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vloxseg3ei64_v_m)))
void vloxseg3ei64_v_u16m1_m(vuint16m1_t *, vuint16m1_t *, vuint16m1_t *, vbool16_t, vuint16m1_t, vuint16m1_t, vuint16m1_t, const uint16_t *, vuint64m4_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vloxseg3ei64_v)))
void vloxseg3ei64_v_u16m2(vuint16m2_t *, vuint16m2_t *, vuint16m2_t *, const uint16_t *, vuint64m8_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vloxseg3ei64_v_m)))
void vloxseg3ei64_v_u16m2_m(vuint16m2_t *, vuint16m2_t *, vuint16m2_t *, vbool8_t, vuint16m2_t, vuint16m2_t, vuint16m2_t, const uint16_t *, vuint64m8_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vloxseg3ei64_v)))
void vloxseg3ei64_v_u16mf2(vuint16mf2_t *, vuint16mf2_t *, vuint16mf2_t *, const uint16_t *, vuint64m2_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vloxseg3ei64_v_m)))
void vloxseg3ei64_v_u16mf2_m(vuint16mf2_t *, vuint16mf2_t *, vuint16mf2_t *, vbool32_t, vuint16mf2_t, vuint16mf2_t, vuint16mf2_t, const uint16_t *, vuint64m2_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vloxseg3ei64_v)))
void vloxseg3ei64_v_u16mf4(vuint16mf4_t *, vuint16mf4_t *, vuint16mf4_t *, const uint16_t *, vuint64m1_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vloxseg3ei64_v_m)))
void vloxseg3ei64_v_u16mf4_m(vuint16mf4_t *, vuint16mf4_t *, vuint16mf4_t *, vbool64_t, vuint16mf4_t, vuint16mf4_t, vuint16mf4_t, const uint16_t *, vuint64m1_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vloxseg4ei64_v)))
void vloxseg4ei64_v_i16m1(vint16m1_t *, vint16m1_t *, vint16m1_t *, vint16m1_t *, const int16_t *, vuint64m4_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vloxseg4ei64_v_m)))
void vloxseg4ei64_v_i16m1_m(vint16m1_t *, vint16m1_t *, vint16m1_t *, vint16m1_t *, vbool16_t, vint16m1_t, vint16m1_t, vint16m1_t, vint16m1_t, const int16_t *, vuint64m4_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vloxseg4ei64_v)))
void vloxseg4ei64_v_i16m2(vint16m2_t *, vint16m2_t *, vint16m2_t *, vint16m2_t *, const int16_t *, vuint64m8_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vloxseg4ei64_v_m)))
void vloxseg4ei64_v_i16m2_m(vint16m2_t *, vint16m2_t *, vint16m2_t *, vint16m2_t *, vbool8_t, vint16m2_t, vint16m2_t, vint16m2_t, vint16m2_t, const int16_t *, vuint64m8_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vloxseg4ei64_v)))
void vloxseg4ei64_v_i16mf2(vint16mf2_t *, vint16mf2_t *, vint16mf2_t *, vint16mf2_t *, const int16_t *, vuint64m2_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vloxseg4ei64_v_m)))
void vloxseg4ei64_v_i16mf2_m(vint16mf2_t *, vint16mf2_t *, vint16mf2_t *, vint16mf2_t *, vbool32_t, vint16mf2_t, vint16mf2_t, vint16mf2_t, vint16mf2_t, const int16_t *, vuint64m2_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vloxseg4ei64_v)))
void vloxseg4ei64_v_i16mf4(vint16mf4_t *, vint16mf4_t *, vint16mf4_t *, vint16mf4_t *, const int16_t *, vuint64m1_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vloxseg4ei64_v_m)))
void vloxseg4ei64_v_i16mf4_m(vint16mf4_t *, vint16mf4_t *, vint16mf4_t *, vint16mf4_t *, vbool64_t, vint16mf4_t, vint16mf4_t, vint16mf4_t, vint16mf4_t, const int16_t *, vuint64m1_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vloxseg4ei64_v)))
void vloxseg4ei64_v_u16m1(vuint16m1_t *, vuint16m1_t *, vuint16m1_t *, vuint16m1_t *, const uint16_t *, vuint64m4_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vloxseg4ei64_v_m)))
void vloxseg4ei64_v_u16m1_m(vuint16m1_t *, vuint16m1_t *, vuint16m1_t *, vuint16m1_t *, vbool16_t, vuint16m1_t, vuint16m1_t, vuint16m1_t, vuint16m1_t, const uint16_t *, vuint64m4_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vloxseg4ei64_v)))
void vloxseg4ei64_v_u16m2(vuint16m2_t *, vuint16m2_t *, vuint16m2_t *, vuint16m2_t *, const uint16_t *, vuint64m8_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vloxseg4ei64_v_m)))
void vloxseg4ei64_v_u16m2_m(vuint16m2_t *, vuint16m2_t *, vuint16m2_t *, vuint16m2_t *, vbool8_t, vuint16m2_t, vuint16m2_t, vuint16m2_t, vuint16m2_t, const uint16_t *, vuint64m8_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vloxseg4ei64_v)))
void vloxseg4ei64_v_u16mf2(vuint16mf2_t *, vuint16mf2_t *, vuint16mf2_t *, vuint16mf2_t *, const uint16_t *, vuint64m2_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vloxseg4ei64_v_m)))
void vloxseg4ei64_v_u16mf2_m(vuint16mf2_t *, vuint16mf2_t *, vuint16mf2_t *, vuint16mf2_t *, vbool32_t, vuint16mf2_t, vuint16mf2_t, vuint16mf2_t, vuint16mf2_t, const uint16_t *, vuint64m2_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vloxseg4ei64_v)))
void vloxseg4ei64_v_u16mf4(vuint16mf4_t *, vuint16mf4_t *, vuint16mf4_t *, vuint16mf4_t *, const uint16_t *, vuint64m1_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vloxseg4ei64_v_m)))
void vloxseg4ei64_v_u16mf4_m(vuint16mf4_t *, vuint16mf4_t *, vuint16mf4_t *, vuint16mf4_t *, vbool64_t, vuint16mf4_t, vuint16mf4_t, vuint16mf4_t, vuint16mf4_t, const uint16_t *, vuint64m1_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vloxseg5ei64_v)))
void vloxseg5ei64_v_i16m1(vint16m1_t *, vint16m1_t *, vint16m1_t *, vint16m1_t *, vint16m1_t *, const int16_t *, vuint64m4_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vloxseg5ei64_v_m)))
void vloxseg5ei64_v_i16m1_m(vint16m1_t *, vint16m1_t *, vint16m1_t *, vint16m1_t *, vint16m1_t *, vbool16_t, vint16m1_t, vint16m1_t, vint16m1_t, vint16m1_t, vint16m1_t, const int16_t *, vuint64m4_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vloxseg5ei64_v)))
void vloxseg5ei64_v_i16mf2(vint16mf2_t *, vint16mf2_t *, vint16mf2_t *, vint16mf2_t *, vint16mf2_t *, const int16_t *, vuint64m2_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vloxseg5ei64_v_m)))
void vloxseg5ei64_v_i16mf2_m(vint16mf2_t *, vint16mf2_t *, vint16mf2_t *, vint16mf2_t *, vint16mf2_t *, vbool32_t, vint16mf2_t, vint16mf2_t, vint16mf2_t, vint16mf2_t, vint16mf2_t, const int16_t *, vuint64m2_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vloxseg5ei64_v)))
void vloxseg5ei64_v_i16mf4(vint16mf4_t *, vint16mf4_t *, vint16mf4_t *, vint16mf4_t *, vint16mf4_t *, const int16_t *, vuint64m1_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vloxseg5ei64_v_m)))
void vloxseg5ei64_v_i16mf4_m(vint16mf4_t *, vint16mf4_t *, vint16mf4_t *, vint16mf4_t *, vint16mf4_t *, vbool64_t, vint16mf4_t, vint16mf4_t, vint16mf4_t, vint16mf4_t, vint16mf4_t, const int16_t *, vuint64m1_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vloxseg5ei64_v)))
void vloxseg5ei64_v_u16m1(vuint16m1_t *, vuint16m1_t *, vuint16m1_t *, vuint16m1_t *, vuint16m1_t *, const uint16_t *, vuint64m4_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vloxseg5ei64_v_m)))
void vloxseg5ei64_v_u16m1_m(vuint16m1_t *, vuint16m1_t *, vuint16m1_t *, vuint16m1_t *, vuint16m1_t *, vbool16_t, vuint16m1_t, vuint16m1_t, vuint16m1_t, vuint16m1_t, vuint16m1_t, const uint16_t *, vuint64m4_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vloxseg5ei64_v)))
void vloxseg5ei64_v_u16mf2(vuint16mf2_t *, vuint16mf2_t *, vuint16mf2_t *, vuint16mf2_t *, vuint16mf2_t *, const uint16_t *, vuint64m2_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vloxseg5ei64_v_m)))
void vloxseg5ei64_v_u16mf2_m(vuint16mf2_t *, vuint16mf2_t *, vuint16mf2_t *, vuint16mf2_t *, vuint16mf2_t *, vbool32_t, vuint16mf2_t, vuint16mf2_t, vuint16mf2_t, vuint16mf2_t, vuint16mf2_t, const uint16_t *, vuint64m2_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vloxseg5ei64_v)))
void vloxseg5ei64_v_u16mf4(vuint16mf4_t *, vuint16mf4_t *, vuint16mf4_t *, vuint16mf4_t *, vuint16mf4_t *, const uint16_t *, vuint64m1_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vloxseg5ei64_v_m)))
void vloxseg5ei64_v_u16mf4_m(vuint16mf4_t *, vuint16mf4_t *, vuint16mf4_t *, vuint16mf4_t *, vuint16mf4_t *, vbool64_t, vuint16mf4_t, vuint16mf4_t, vuint16mf4_t, vuint16mf4_t, vuint16mf4_t, const uint16_t *, vuint64m1_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vloxseg6ei64_v)))
void vloxseg6ei64_v_i16m1(vint16m1_t *, vint16m1_t *, vint16m1_t *, vint16m1_t *, vint16m1_t *, vint16m1_t *, const int16_t *, vuint64m4_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vloxseg6ei64_v_m)))
void vloxseg6ei64_v_i16m1_m(vint16m1_t *, vint16m1_t *, vint16m1_t *, vint16m1_t *, vint16m1_t *, vint16m1_t *, vbool16_t, vint16m1_t, vint16m1_t, vint16m1_t, vint16m1_t, vint16m1_t, vint16m1_t, const int16_t *, vuint64m4_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vloxseg6ei64_v)))
void vloxseg6ei64_v_i16mf2(vint16mf2_t *, vint16mf2_t *, vint16mf2_t *, vint16mf2_t *, vint16mf2_t *, vint16mf2_t *, const int16_t *, vuint64m2_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vloxseg6ei64_v_m)))
void vloxseg6ei64_v_i16mf2_m(vint16mf2_t *, vint16mf2_t *, vint16mf2_t *, vint16mf2_t *, vint16mf2_t *, vint16mf2_t *, vbool32_t, vint16mf2_t, vint16mf2_t, vint16mf2_t, vint16mf2_t, vint16mf2_t, vint16mf2_t, const int16_t *, vuint64m2_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vloxseg6ei64_v)))
void vloxseg6ei64_v_i16mf4(vint16mf4_t *, vint16mf4_t *, vint16mf4_t *, vint16mf4_t *, vint16mf4_t *, vint16mf4_t *, const int16_t *, vuint64m1_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vloxseg6ei64_v_m)))
void vloxseg6ei64_v_i16mf4_m(vint16mf4_t *, vint16mf4_t *, vint16mf4_t *, vint16mf4_t *, vint16mf4_t *, vint16mf4_t *, vbool64_t, vint16mf4_t, vint16mf4_t, vint16mf4_t, vint16mf4_t, vint16mf4_t, vint16mf4_t, const int16_t *, vuint64m1_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vloxseg6ei64_v)))
void vloxseg6ei64_v_u16m1(vuint16m1_t *, vuint16m1_t *, vuint16m1_t *, vuint16m1_t *, vuint16m1_t *, vuint16m1_t *, const uint16_t *, vuint64m4_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vloxseg6ei64_v_m)))
void vloxseg6ei64_v_u16m1_m(vuint16m1_t *, vuint16m1_t *, vuint16m1_t *, vuint16m1_t *, vuint16m1_t *, vuint16m1_t *, vbool16_t, vuint16m1_t, vuint16m1_t, vuint16m1_t, vuint16m1_t, vuint16m1_t, vuint16m1_t, const uint16_t *, vuint64m4_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vloxseg6ei64_v)))
void vloxseg6ei64_v_u16mf2(vuint16mf2_t *, vuint16mf2_t *, vuint16mf2_t *, vuint16mf2_t *, vuint16mf2_t *, vuint16mf2_t *, const uint16_t *, vuint64m2_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vloxseg6ei64_v_m)))
void vloxseg6ei64_v_u16mf2_m(vuint16mf2_t *, vuint16mf2_t *, vuint16mf2_t *, vuint16mf2_t *, vuint16mf2_t *, vuint16mf2_t *, vbool32_t, vuint16mf2_t, vuint16mf2_t, vuint16mf2_t, vuint16mf2_t, vuint16mf2_t, vuint16mf2_t, const uint16_t *, vuint64m2_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vloxseg6ei64_v)))
void vloxseg6ei64_v_u16mf4(vuint16mf4_t *, vuint16mf4_t *, vuint16mf4_t *, vuint16mf4_t *, vuint16mf4_t *, vuint16mf4_t *, const uint16_t *, vuint64m1_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vloxseg6ei64_v_m)))
void vloxseg6ei64_v_u16mf4_m(vuint16mf4_t *, vuint16mf4_t *, vuint16mf4_t *, vuint16mf4_t *, vuint16mf4_t *, vuint16mf4_t *, vbool64_t, vuint16mf4_t, vuint16mf4_t, vuint16mf4_t, vuint16mf4_t, vuint16mf4_t, vuint16mf4_t, const uint16_t *, vuint64m1_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vloxseg7ei64_v)))
void vloxseg7ei64_v_i16m1(vint16m1_t *, vint16m1_t *, vint16m1_t *, vint16m1_t *, vint16m1_t *, vint16m1_t *, vint16m1_t *, const int16_t *, vuint64m4_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vloxseg7ei64_v_m)))
void vloxseg7ei64_v_i16m1_m(vint16m1_t *, vint16m1_t *, vint16m1_t *, vint16m1_t *, vint16m1_t *, vint16m1_t *, vint16m1_t *, vbool16_t, vint16m1_t, vint16m1_t, vint16m1_t, vint16m1_t, vint16m1_t, vint16m1_t, vint16m1_t, const int16_t *, vuint64m4_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vloxseg7ei64_v)))
void vloxseg7ei64_v_i16mf2(vint16mf2_t *, vint16mf2_t *, vint16mf2_t *, vint16mf2_t *, vint16mf2_t *, vint16mf2_t *, vint16mf2_t *, const int16_t *, vuint64m2_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vloxseg7ei64_v_m)))
void vloxseg7ei64_v_i16mf2_m(vint16mf2_t *, vint16mf2_t *, vint16mf2_t *, vint16mf2_t *, vint16mf2_t *, vint16mf2_t *, vint16mf2_t *, vbool32_t, vint16mf2_t, vint16mf2_t, vint16mf2_t, vint16mf2_t, vint16mf2_t, vint16mf2_t, vint16mf2_t, const int16_t *, vuint64m2_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vloxseg7ei64_v)))
void vloxseg7ei64_v_i16mf4(vint16mf4_t *, vint16mf4_t *, vint16mf4_t *, vint16mf4_t *, vint16mf4_t *, vint16mf4_t *, vint16mf4_t *, const int16_t *, vuint64m1_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vloxseg7ei64_v_m)))
void vloxseg7ei64_v_i16mf4_m(vint16mf4_t *, vint16mf4_t *, vint16mf4_t *, vint16mf4_t *, vint16mf4_t *, vint16mf4_t *, vint16mf4_t *, vbool64_t, vint16mf4_t, vint16mf4_t, vint16mf4_t, vint16mf4_t, vint16mf4_t, vint16mf4_t, vint16mf4_t, const int16_t *, vuint64m1_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vloxseg7ei64_v)))
void vloxseg7ei64_v_u16m1(vuint16m1_t *, vuint16m1_t *, vuint16m1_t *, vuint16m1_t *, vuint16m1_t *, vuint16m1_t *, vuint16m1_t *, const uint16_t *, vuint64m4_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vloxseg7ei64_v_m)))
void vloxseg7ei64_v_u16m1_m(vuint16m1_t *, vuint16m1_t *, vuint16m1_t *, vuint16m1_t *, vuint16m1_t *, vuint16m1_t *, vuint16m1_t *, vbool16_t, vuint16m1_t, vuint16m1_t, vuint16m1_t, vuint16m1_t, vuint16m1_t, vuint16m1_t, vuint16m1_t, const uint16_t *, vuint64m4_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vloxseg7ei64_v)))
void vloxseg7ei64_v_u16mf2(vuint16mf2_t *, vuint16mf2_t *, vuint16mf2_t *, vuint16mf2_t *, vuint16mf2_t *, vuint16mf2_t *, vuint16mf2_t *, const uint16_t *, vuint64m2_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vloxseg7ei64_v_m)))
void vloxseg7ei64_v_u16mf2_m(vuint16mf2_t *, vuint16mf2_t *, vuint16mf2_t *, vuint16mf2_t *, vuint16mf2_t *, vuint16mf2_t *, vuint16mf2_t *, vbool32_t, vuint16mf2_t, vuint16mf2_t, vuint16mf2_t, vuint16mf2_t, vuint16mf2_t, vuint16mf2_t, vuint16mf2_t, const uint16_t *, vuint64m2_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vloxseg7ei64_v)))
void vloxseg7ei64_v_u16mf4(vuint16mf4_t *, vuint16mf4_t *, vuint16mf4_t *, vuint16mf4_t *, vuint16mf4_t *, vuint16mf4_t *, vuint16mf4_t *, const uint16_t *, vuint64m1_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vloxseg7ei64_v_m)))
void vloxseg7ei64_v_u16mf4_m(vuint16mf4_t *, vuint16mf4_t *, vuint16mf4_t *, vuint16mf4_t *, vuint16mf4_t *, vuint16mf4_t *, vuint16mf4_t *, vbool64_t, vuint16mf4_t, vuint16mf4_t, vuint16mf4_t, vuint16mf4_t, vuint16mf4_t, vuint16mf4_t, vuint16mf4_t, const uint16_t *, vuint64m1_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vloxseg8ei64_v)))
void vloxseg8ei64_v_i16m1(vint16m1_t *, vint16m1_t *, vint16m1_t *, vint16m1_t *, vint16m1_t *, vint16m1_t *, vint16m1_t *, vint16m1_t *, const int16_t *, vuint64m4_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vloxseg8ei64_v_m)))
void vloxseg8ei64_v_i16m1_m(vint16m1_t *, vint16m1_t *, vint16m1_t *, vint16m1_t *, vint16m1_t *, vint16m1_t *, vint16m1_t *, vint16m1_t *, vbool16_t, vint16m1_t, vint16m1_t, vint16m1_t, vint16m1_t, vint16m1_t, vint16m1_t, vint16m1_t, vint16m1_t, const int16_t *, vuint64m4_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vloxseg8ei64_v)))
void vloxseg8ei64_v_i16mf2(vint16mf2_t *, vint16mf2_t *, vint16mf2_t *, vint16mf2_t *, vint16mf2_t *, vint16mf2_t *, vint16mf2_t *, vint16mf2_t *, const int16_t *, vuint64m2_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vloxseg8ei64_v_m)))
void vloxseg8ei64_v_i16mf2_m(vint16mf2_t *, vint16mf2_t *, vint16mf2_t *, vint16mf2_t *, vint16mf2_t *, vint16mf2_t *, vint16mf2_t *, vint16mf2_t *, vbool32_t, vint16mf2_t, vint16mf2_t, vint16mf2_t, vint16mf2_t, vint16mf2_t, vint16mf2_t, vint16mf2_t, vint16mf2_t, const int16_t *, vuint64m2_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vloxseg8ei64_v)))
void vloxseg8ei64_v_i16mf4(vint16mf4_t *, vint16mf4_t *, vint16mf4_t *, vint16mf4_t *, vint16mf4_t *, vint16mf4_t *, vint16mf4_t *, vint16mf4_t *, const int16_t *, vuint64m1_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vloxseg8ei64_v_m)))
void vloxseg8ei64_v_i16mf4_m(vint16mf4_t *, vint16mf4_t *, vint16mf4_t *, vint16mf4_t *, vint16mf4_t *, vint16mf4_t *, vint16mf4_t *, vint16mf4_t *, vbool64_t, vint16mf4_t, vint16mf4_t, vint16mf4_t, vint16mf4_t, vint16mf4_t, vint16mf4_t, vint16mf4_t, vint16mf4_t, const int16_t *, vuint64m1_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vloxseg8ei64_v)))
void vloxseg8ei64_v_u16m1(vuint16m1_t *, vuint16m1_t *, vuint16m1_t *, vuint16m1_t *, vuint16m1_t *, vuint16m1_t *, vuint16m1_t *, vuint16m1_t *, const uint16_t *, vuint64m4_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vloxseg8ei64_v_m)))
void vloxseg8ei64_v_u16m1_m(vuint16m1_t *, vuint16m1_t *, vuint16m1_t *, vuint16m1_t *, vuint16m1_t *, vuint16m1_t *, vuint16m1_t *, vuint16m1_t *, vbool16_t, vuint16m1_t, vuint16m1_t, vuint16m1_t, vuint16m1_t, vuint16m1_t, vuint16m1_t, vuint16m1_t, vuint16m1_t, const uint16_t *, vuint64m4_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vloxseg8ei64_v)))
void vloxseg8ei64_v_u16mf2(vuint16mf2_t *, vuint16mf2_t *, vuint16mf2_t *, vuint16mf2_t *, vuint16mf2_t *, vuint16mf2_t *, vuint16mf2_t *, vuint16mf2_t *, const uint16_t *, vuint64m2_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vloxseg8ei64_v_m)))
void vloxseg8ei64_v_u16mf2_m(vuint16mf2_t *, vuint16mf2_t *, vuint16mf2_t *, vuint16mf2_t *, vuint16mf2_t *, vuint16mf2_t *, vuint16mf2_t *, vuint16mf2_t *, vbool32_t, vuint16mf2_t, vuint16mf2_t, vuint16mf2_t, vuint16mf2_t, vuint16mf2_t, vuint16mf2_t, vuint16mf2_t, vuint16mf2_t, const uint16_t *, vuint64m2_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vloxseg8ei64_v)))
void vloxseg8ei64_v_u16mf4(vuint16mf4_t *, vuint16mf4_t *, vuint16mf4_t *, vuint16mf4_t *, vuint16mf4_t *, vuint16mf4_t *, vuint16mf4_t *, vuint16mf4_t *, const uint16_t *, vuint64m1_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vloxseg8ei64_v_m)))
void vloxseg8ei64_v_u16mf4_m(vuint16mf4_t *, vuint16mf4_t *, vuint16mf4_t *, vuint16mf4_t *, vuint16mf4_t *, vuint16mf4_t *, vuint16mf4_t *, vuint16mf4_t *, vbool64_t, vuint16mf4_t, vuint16mf4_t, vuint16mf4_t, vuint16mf4_t, vuint16mf4_t, vuint16mf4_t, vuint16mf4_t, vuint16mf4_t, const uint16_t *, vuint64m1_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vloxseg2ei64_v)))
void vloxseg2ei64_v_i32m1(vint32m1_t *, vint32m1_t *, const int32_t *, vuint64m2_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vloxseg2ei64_v_m)))
void vloxseg2ei64_v_i32m1_m(vint32m1_t *, vint32m1_t *, vbool32_t, vint32m1_t, vint32m1_t, const int32_t *, vuint64m2_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vloxseg2ei64_v)))
void vloxseg2ei64_v_i32m2(vint32m2_t *, vint32m2_t *, const int32_t *, vuint64m4_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vloxseg2ei64_v_m)))
void vloxseg2ei64_v_i32m2_m(vint32m2_t *, vint32m2_t *, vbool16_t, vint32m2_t, vint32m2_t, const int32_t *, vuint64m4_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vloxseg2ei64_v)))
void vloxseg2ei64_v_i32m4(vint32m4_t *, vint32m4_t *, const int32_t *, vuint64m8_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vloxseg2ei64_v_m)))
void vloxseg2ei64_v_i32m4_m(vint32m4_t *, vint32m4_t *, vbool8_t, vint32m4_t, vint32m4_t, const int32_t *, vuint64m8_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vloxseg2ei64_v)))
void vloxseg2ei64_v_i32mf2(vint32mf2_t *, vint32mf2_t *, const int32_t *, vuint64m1_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vloxseg2ei64_v_m)))
void vloxseg2ei64_v_i32mf2_m(vint32mf2_t *, vint32mf2_t *, vbool64_t, vint32mf2_t, vint32mf2_t, const int32_t *, vuint64m1_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vloxseg2ei64_v)))
void vloxseg2ei64_v_u32m1(vuint32m1_t *, vuint32m1_t *, const uint32_t *, vuint64m2_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vloxseg2ei64_v_m)))
void vloxseg2ei64_v_u32m1_m(vuint32m1_t *, vuint32m1_t *, vbool32_t, vuint32m1_t, vuint32m1_t, const uint32_t *, vuint64m2_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vloxseg2ei64_v)))
void vloxseg2ei64_v_u32m2(vuint32m2_t *, vuint32m2_t *, const uint32_t *, vuint64m4_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vloxseg2ei64_v_m)))
void vloxseg2ei64_v_u32m2_m(vuint32m2_t *, vuint32m2_t *, vbool16_t, vuint32m2_t, vuint32m2_t, const uint32_t *, vuint64m4_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vloxseg2ei64_v)))
void vloxseg2ei64_v_u32m4(vuint32m4_t *, vuint32m4_t *, const uint32_t *, vuint64m8_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vloxseg2ei64_v_m)))
void vloxseg2ei64_v_u32m4_m(vuint32m4_t *, vuint32m4_t *, vbool8_t, vuint32m4_t, vuint32m4_t, const uint32_t *, vuint64m8_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vloxseg2ei64_v)))
void vloxseg2ei64_v_u32mf2(vuint32mf2_t *, vuint32mf2_t *, const uint32_t *, vuint64m1_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vloxseg2ei64_v_m)))
void vloxseg2ei64_v_u32mf2_m(vuint32mf2_t *, vuint32mf2_t *, vbool64_t, vuint32mf2_t, vuint32mf2_t, const uint32_t *, vuint64m1_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vloxseg3ei64_v)))
void vloxseg3ei64_v_i32m1(vint32m1_t *, vint32m1_t *, vint32m1_t *, const int32_t *, vuint64m2_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vloxseg3ei64_v_m)))
void vloxseg3ei64_v_i32m1_m(vint32m1_t *, vint32m1_t *, vint32m1_t *, vbool32_t, vint32m1_t, vint32m1_t, vint32m1_t, const int32_t *, vuint64m2_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vloxseg3ei64_v)))
void vloxseg3ei64_v_i32m2(vint32m2_t *, vint32m2_t *, vint32m2_t *, const int32_t *, vuint64m4_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vloxseg3ei64_v_m)))
void vloxseg3ei64_v_i32m2_m(vint32m2_t *, vint32m2_t *, vint32m2_t *, vbool16_t, vint32m2_t, vint32m2_t, vint32m2_t, const int32_t *, vuint64m4_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vloxseg3ei64_v)))
void vloxseg3ei64_v_i32mf2(vint32mf2_t *, vint32mf2_t *, vint32mf2_t *, const int32_t *, vuint64m1_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vloxseg3ei64_v_m)))
void vloxseg3ei64_v_i32mf2_m(vint32mf2_t *, vint32mf2_t *, vint32mf2_t *, vbool64_t, vint32mf2_t, vint32mf2_t, vint32mf2_t, const int32_t *, vuint64m1_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vloxseg3ei64_v)))
void vloxseg3ei64_v_u32m1(vuint32m1_t *, vuint32m1_t *, vuint32m1_t *, const uint32_t *, vuint64m2_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vloxseg3ei64_v_m)))
void vloxseg3ei64_v_u32m1_m(vuint32m1_t *, vuint32m1_t *, vuint32m1_t *, vbool32_t, vuint32m1_t, vuint32m1_t, vuint32m1_t, const uint32_t *, vuint64m2_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vloxseg3ei64_v)))
void vloxseg3ei64_v_u32m2(vuint32m2_t *, vuint32m2_t *, vuint32m2_t *, const uint32_t *, vuint64m4_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vloxseg3ei64_v_m)))
void vloxseg3ei64_v_u32m2_m(vuint32m2_t *, vuint32m2_t *, vuint32m2_t *, vbool16_t, vuint32m2_t, vuint32m2_t, vuint32m2_t, const uint32_t *, vuint64m4_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vloxseg3ei64_v)))
void vloxseg3ei64_v_u32mf2(vuint32mf2_t *, vuint32mf2_t *, vuint32mf2_t *, const uint32_t *, vuint64m1_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vloxseg3ei64_v_m)))
void vloxseg3ei64_v_u32mf2_m(vuint32mf2_t *, vuint32mf2_t *, vuint32mf2_t *, vbool64_t, vuint32mf2_t, vuint32mf2_t, vuint32mf2_t, const uint32_t *, vuint64m1_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vloxseg4ei64_v)))
void vloxseg4ei64_v_i32m1(vint32m1_t *, vint32m1_t *, vint32m1_t *, vint32m1_t *, const int32_t *, vuint64m2_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vloxseg4ei64_v_m)))
void vloxseg4ei64_v_i32m1_m(vint32m1_t *, vint32m1_t *, vint32m1_t *, vint32m1_t *, vbool32_t, vint32m1_t, vint32m1_t, vint32m1_t, vint32m1_t, const int32_t *, vuint64m2_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vloxseg4ei64_v)))
void vloxseg4ei64_v_i32m2(vint32m2_t *, vint32m2_t *, vint32m2_t *, vint32m2_t *, const int32_t *, vuint64m4_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vloxseg4ei64_v_m)))
void vloxseg4ei64_v_i32m2_m(vint32m2_t *, vint32m2_t *, vint32m2_t *, vint32m2_t *, vbool16_t, vint32m2_t, vint32m2_t, vint32m2_t, vint32m2_t, const int32_t *, vuint64m4_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vloxseg4ei64_v)))
void vloxseg4ei64_v_i32mf2(vint32mf2_t *, vint32mf2_t *, vint32mf2_t *, vint32mf2_t *, const int32_t *, vuint64m1_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vloxseg4ei64_v_m)))
void vloxseg4ei64_v_i32mf2_m(vint32mf2_t *, vint32mf2_t *, vint32mf2_t *, vint32mf2_t *, vbool64_t, vint32mf2_t, vint32mf2_t, vint32mf2_t, vint32mf2_t, const int32_t *, vuint64m1_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vloxseg4ei64_v)))
void vloxseg4ei64_v_u32m1(vuint32m1_t *, vuint32m1_t *, vuint32m1_t *, vuint32m1_t *, const uint32_t *, vuint64m2_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vloxseg4ei64_v_m)))
void vloxseg4ei64_v_u32m1_m(vuint32m1_t *, vuint32m1_t *, vuint32m1_t *, vuint32m1_t *, vbool32_t, vuint32m1_t, vuint32m1_t, vuint32m1_t, vuint32m1_t, const uint32_t *, vuint64m2_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vloxseg4ei64_v)))
void vloxseg4ei64_v_u32m2(vuint32m2_t *, vuint32m2_t *, vuint32m2_t *, vuint32m2_t *, const uint32_t *, vuint64m4_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vloxseg4ei64_v_m)))
void vloxseg4ei64_v_u32m2_m(vuint32m2_t *, vuint32m2_t *, vuint32m2_t *, vuint32m2_t *, vbool16_t, vuint32m2_t, vuint32m2_t, vuint32m2_t, vuint32m2_t, const uint32_t *, vuint64m4_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vloxseg4ei64_v)))
void vloxseg4ei64_v_u32mf2(vuint32mf2_t *, vuint32mf2_t *, vuint32mf2_t *, vuint32mf2_t *, const uint32_t *, vuint64m1_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vloxseg4ei64_v_m)))
void vloxseg4ei64_v_u32mf2_m(vuint32mf2_t *, vuint32mf2_t *, vuint32mf2_t *, vuint32mf2_t *, vbool64_t, vuint32mf2_t, vuint32mf2_t, vuint32mf2_t, vuint32mf2_t, const uint32_t *, vuint64m1_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vloxseg5ei64_v)))
void vloxseg5ei64_v_i32m1(vint32m1_t *, vint32m1_t *, vint32m1_t *, vint32m1_t *, vint32m1_t *, const int32_t *, vuint64m2_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vloxseg5ei64_v_m)))
void vloxseg5ei64_v_i32m1_m(vint32m1_t *, vint32m1_t *, vint32m1_t *, vint32m1_t *, vint32m1_t *, vbool32_t, vint32m1_t, vint32m1_t, vint32m1_t, vint32m1_t, vint32m1_t, const int32_t *, vuint64m2_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vloxseg5ei64_v)))
void vloxseg5ei64_v_i32mf2(vint32mf2_t *, vint32mf2_t *, vint32mf2_t *, vint32mf2_t *, vint32mf2_t *, const int32_t *, vuint64m1_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vloxseg5ei64_v_m)))
void vloxseg5ei64_v_i32mf2_m(vint32mf2_t *, vint32mf2_t *, vint32mf2_t *, vint32mf2_t *, vint32mf2_t *, vbool64_t, vint32mf2_t, vint32mf2_t, vint32mf2_t, vint32mf2_t, vint32mf2_t, const int32_t *, vuint64m1_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vloxseg5ei64_v)))
void vloxseg5ei64_v_u32m1(vuint32m1_t *, vuint32m1_t *, vuint32m1_t *, vuint32m1_t *, vuint32m1_t *, const uint32_t *, vuint64m2_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vloxseg5ei64_v_m)))
void vloxseg5ei64_v_u32m1_m(vuint32m1_t *, vuint32m1_t *, vuint32m1_t *, vuint32m1_t *, vuint32m1_t *, vbool32_t, vuint32m1_t, vuint32m1_t, vuint32m1_t, vuint32m1_t, vuint32m1_t, const uint32_t *, vuint64m2_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vloxseg5ei64_v)))
void vloxseg5ei64_v_u32mf2(vuint32mf2_t *, vuint32mf2_t *, vuint32mf2_t *, vuint32mf2_t *, vuint32mf2_t *, const uint32_t *, vuint64m1_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vloxseg5ei64_v_m)))
void vloxseg5ei64_v_u32mf2_m(vuint32mf2_t *, vuint32mf2_t *, vuint32mf2_t *, vuint32mf2_t *, vuint32mf2_t *, vbool64_t, vuint32mf2_t, vuint32mf2_t, vuint32mf2_t, vuint32mf2_t, vuint32mf2_t, const uint32_t *, vuint64m1_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vloxseg6ei64_v)))
void vloxseg6ei64_v_i32m1(vint32m1_t *, vint32m1_t *, vint32m1_t *, vint32m1_t *, vint32m1_t *, vint32m1_t *, const int32_t *, vuint64m2_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vloxseg6ei64_v_m)))
void vloxseg6ei64_v_i32m1_m(vint32m1_t *, vint32m1_t *, vint32m1_t *, vint32m1_t *, vint32m1_t *, vint32m1_t *, vbool32_t, vint32m1_t, vint32m1_t, vint32m1_t, vint32m1_t, vint32m1_t, vint32m1_t, const int32_t *, vuint64m2_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vloxseg6ei64_v)))
void vloxseg6ei64_v_i32mf2(vint32mf2_t *, vint32mf2_t *, vint32mf2_t *, vint32mf2_t *, vint32mf2_t *, vint32mf2_t *, const int32_t *, vuint64m1_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vloxseg6ei64_v_m)))
void vloxseg6ei64_v_i32mf2_m(vint32mf2_t *, vint32mf2_t *, vint32mf2_t *, vint32mf2_t *, vint32mf2_t *, vint32mf2_t *, vbool64_t, vint32mf2_t, vint32mf2_t, vint32mf2_t, vint32mf2_t, vint32mf2_t, vint32mf2_t, const int32_t *, vuint64m1_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vloxseg6ei64_v)))
void vloxseg6ei64_v_u32m1(vuint32m1_t *, vuint32m1_t *, vuint32m1_t *, vuint32m1_t *, vuint32m1_t *, vuint32m1_t *, const uint32_t *, vuint64m2_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vloxseg6ei64_v_m)))
void vloxseg6ei64_v_u32m1_m(vuint32m1_t *, vuint32m1_t *, vuint32m1_t *, vuint32m1_t *, vuint32m1_t *, vuint32m1_t *, vbool32_t, vuint32m1_t, vuint32m1_t, vuint32m1_t, vuint32m1_t, vuint32m1_t, vuint32m1_t, const uint32_t *, vuint64m2_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vloxseg6ei64_v)))
void vloxseg6ei64_v_u32mf2(vuint32mf2_t *, vuint32mf2_t *, vuint32mf2_t *, vuint32mf2_t *, vuint32mf2_t *, vuint32mf2_t *, const uint32_t *, vuint64m1_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vloxseg6ei64_v_m)))
void vloxseg6ei64_v_u32mf2_m(vuint32mf2_t *, vuint32mf2_t *, vuint32mf2_t *, vuint32mf2_t *, vuint32mf2_t *, vuint32mf2_t *, vbool64_t, vuint32mf2_t, vuint32mf2_t, vuint32mf2_t, vuint32mf2_t, vuint32mf2_t, vuint32mf2_t, const uint32_t *, vuint64m1_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vloxseg7ei64_v)))
void vloxseg7ei64_v_i32m1(vint32m1_t *, vint32m1_t *, vint32m1_t *, vint32m1_t *, vint32m1_t *, vint32m1_t *, vint32m1_t *, const int32_t *, vuint64m2_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vloxseg7ei64_v_m)))
void vloxseg7ei64_v_i32m1_m(vint32m1_t *, vint32m1_t *, vint32m1_t *, vint32m1_t *, vint32m1_t *, vint32m1_t *, vint32m1_t *, vbool32_t, vint32m1_t, vint32m1_t, vint32m1_t, vint32m1_t, vint32m1_t, vint32m1_t, vint32m1_t, const int32_t *, vuint64m2_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vloxseg7ei64_v)))
void vloxseg7ei64_v_i32mf2(vint32mf2_t *, vint32mf2_t *, vint32mf2_t *, vint32mf2_t *, vint32mf2_t *, vint32mf2_t *, vint32mf2_t *, const int32_t *, vuint64m1_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vloxseg7ei64_v_m)))
void vloxseg7ei64_v_i32mf2_m(vint32mf2_t *, vint32mf2_t *, vint32mf2_t *, vint32mf2_t *, vint32mf2_t *, vint32mf2_t *, vint32mf2_t *, vbool64_t, vint32mf2_t, vint32mf2_t, vint32mf2_t, vint32mf2_t, vint32mf2_t, vint32mf2_t, vint32mf2_t, const int32_t *, vuint64m1_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vloxseg7ei64_v)))
void vloxseg7ei64_v_u32m1(vuint32m1_t *, vuint32m1_t *, vuint32m1_t *, vuint32m1_t *, vuint32m1_t *, vuint32m1_t *, vuint32m1_t *, const uint32_t *, vuint64m2_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vloxseg7ei64_v_m)))
void vloxseg7ei64_v_u32m1_m(vuint32m1_t *, vuint32m1_t *, vuint32m1_t *, vuint32m1_t *, vuint32m1_t *, vuint32m1_t *, vuint32m1_t *, vbool32_t, vuint32m1_t, vuint32m1_t, vuint32m1_t, vuint32m1_t, vuint32m1_t, vuint32m1_t, vuint32m1_t, const uint32_t *, vuint64m2_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vloxseg7ei64_v)))
void vloxseg7ei64_v_u32mf2(vuint32mf2_t *, vuint32mf2_t *, vuint32mf2_t *, vuint32mf2_t *, vuint32mf2_t *, vuint32mf2_t *, vuint32mf2_t *, const uint32_t *, vuint64m1_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vloxseg7ei64_v_m)))
void vloxseg7ei64_v_u32mf2_m(vuint32mf2_t *, vuint32mf2_t *, vuint32mf2_t *, vuint32mf2_t *, vuint32mf2_t *, vuint32mf2_t *, vuint32mf2_t *, vbool64_t, vuint32mf2_t, vuint32mf2_t, vuint32mf2_t, vuint32mf2_t, vuint32mf2_t, vuint32mf2_t, vuint32mf2_t, const uint32_t *, vuint64m1_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vloxseg8ei64_v)))
void vloxseg8ei64_v_i32m1(vint32m1_t *, vint32m1_t *, vint32m1_t *, vint32m1_t *, vint32m1_t *, vint32m1_t *, vint32m1_t *, vint32m1_t *, const int32_t *, vuint64m2_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vloxseg8ei64_v_m)))
void vloxseg8ei64_v_i32m1_m(vint32m1_t *, vint32m1_t *, vint32m1_t *, vint32m1_t *, vint32m1_t *, vint32m1_t *, vint32m1_t *, vint32m1_t *, vbool32_t, vint32m1_t, vint32m1_t, vint32m1_t, vint32m1_t, vint32m1_t, vint32m1_t, vint32m1_t, vint32m1_t, const int32_t *, vuint64m2_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vloxseg8ei64_v)))
void vloxseg8ei64_v_i32mf2(vint32mf2_t *, vint32mf2_t *, vint32mf2_t *, vint32mf2_t *, vint32mf2_t *, vint32mf2_t *, vint32mf2_t *, vint32mf2_t *, const int32_t *, vuint64m1_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vloxseg8ei64_v_m)))
void vloxseg8ei64_v_i32mf2_m(vint32mf2_t *, vint32mf2_t *, vint32mf2_t *, vint32mf2_t *, vint32mf2_t *, vint32mf2_t *, vint32mf2_t *, vint32mf2_t *, vbool64_t, vint32mf2_t, vint32mf2_t, vint32mf2_t, vint32mf2_t, vint32mf2_t, vint32mf2_t, vint32mf2_t, vint32mf2_t, const int32_t *, vuint64m1_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vloxseg8ei64_v)))
void vloxseg8ei64_v_u32m1(vuint32m1_t *, vuint32m1_t *, vuint32m1_t *, vuint32m1_t *, vuint32m1_t *, vuint32m1_t *, vuint32m1_t *, vuint32m1_t *, const uint32_t *, vuint64m2_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vloxseg8ei64_v_m)))
void vloxseg8ei64_v_u32m1_m(vuint32m1_t *, vuint32m1_t *, vuint32m1_t *, vuint32m1_t *, vuint32m1_t *, vuint32m1_t *, vuint32m1_t *, vuint32m1_t *, vbool32_t, vuint32m1_t, vuint32m1_t, vuint32m1_t, vuint32m1_t, vuint32m1_t, vuint32m1_t, vuint32m1_t, vuint32m1_t, const uint32_t *, vuint64m2_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vloxseg8ei64_v)))
void vloxseg8ei64_v_u32mf2(vuint32mf2_t *, vuint32mf2_t *, vuint32mf2_t *, vuint32mf2_t *, vuint32mf2_t *, vuint32mf2_t *, vuint32mf2_t *, vuint32mf2_t *, const uint32_t *, vuint64m1_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vloxseg8ei64_v_m)))
void vloxseg8ei64_v_u32mf2_m(vuint32mf2_t *, vuint32mf2_t *, vuint32mf2_t *, vuint32mf2_t *, vuint32mf2_t *, vuint32mf2_t *, vuint32mf2_t *, vuint32mf2_t *, vbool64_t, vuint32mf2_t, vuint32mf2_t, vuint32mf2_t, vuint32mf2_t, vuint32mf2_t, vuint32mf2_t, vuint32mf2_t, vuint32mf2_t, const uint32_t *, vuint64m1_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vloxseg2ei8_v)))
void vloxseg2ei8_v_i64m1(vint64m1_t *, vint64m1_t *, const int64_t *, vuint8mf8_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vloxseg2ei8_v_m)))
void vloxseg2ei8_v_i64m1_m(vint64m1_t *, vint64m1_t *, vbool64_t, vint64m1_t, vint64m1_t, const int64_t *, vuint8mf8_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vloxseg2ei8_v)))
void vloxseg2ei8_v_i64m2(vint64m2_t *, vint64m2_t *, const int64_t *, vuint8mf4_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vloxseg2ei8_v_m)))
void vloxseg2ei8_v_i64m2_m(vint64m2_t *, vint64m2_t *, vbool32_t, vint64m2_t, vint64m2_t, const int64_t *, vuint8mf4_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vloxseg2ei8_v)))
void vloxseg2ei8_v_i64m4(vint64m4_t *, vint64m4_t *, const int64_t *, vuint8mf2_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vloxseg2ei8_v_m)))
void vloxseg2ei8_v_i64m4_m(vint64m4_t *, vint64m4_t *, vbool16_t, vint64m4_t, vint64m4_t, const int64_t *, vuint8mf2_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vloxseg2ei8_v)))
void vloxseg2ei8_v_u64m1(vuint64m1_t *, vuint64m1_t *, const uint64_t *, vuint8mf8_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vloxseg2ei8_v_m)))
void vloxseg2ei8_v_u64m1_m(vuint64m1_t *, vuint64m1_t *, vbool64_t, vuint64m1_t, vuint64m1_t, const uint64_t *, vuint8mf8_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vloxseg2ei8_v)))
void vloxseg2ei8_v_u64m2(vuint64m2_t *, vuint64m2_t *, const uint64_t *, vuint8mf4_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vloxseg2ei8_v_m)))
void vloxseg2ei8_v_u64m2_m(vuint64m2_t *, vuint64m2_t *, vbool32_t, vuint64m2_t, vuint64m2_t, const uint64_t *, vuint8mf4_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vloxseg2ei8_v)))
void vloxseg2ei8_v_u64m4(vuint64m4_t *, vuint64m4_t *, const uint64_t *, vuint8mf2_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vloxseg2ei8_v_m)))
void vloxseg2ei8_v_u64m4_m(vuint64m4_t *, vuint64m4_t *, vbool16_t, vuint64m4_t, vuint64m4_t, const uint64_t *, vuint8mf2_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vlmul_ext_v)))
vint64m2_t vlmul_ext_v_i64m1_i64m2(vint64m1_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vlmul_ext_v)))
vint64m4_t vlmul_ext_v_i64m1_i64m4(vint64m1_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vlmul_ext_v)))
vint64m4_t vlmul_ext_v_i64m2_i64m4(vint64m2_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vlmul_ext_v)))
vint64m8_t vlmul_ext_v_i64m1_i64m8(vint64m1_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vlmul_ext_v)))
vint64m8_t vlmul_ext_v_i64m2_i64m8(vint64m2_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vlmul_ext_v)))
vint64m8_t vlmul_ext_v_i64m4_i64m8(vint64m4_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vlmul_ext_v)))
vuint64m2_t vlmul_ext_v_u64m1_u64m2(vuint64m1_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vlmul_ext_v)))
vuint64m4_t vlmul_ext_v_u64m1_u64m4(vuint64m1_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vlmul_ext_v)))
vuint64m4_t vlmul_ext_v_u64m2_u64m4(vuint64m2_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vlmul_ext_v)))
vuint64m8_t vlmul_ext_v_u64m1_u64m8(vuint64m1_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vlmul_ext_v)))
vuint64m8_t vlmul_ext_v_u64m2_u64m8(vuint64m2_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vlmul_ext_v)))
vuint64m8_t vlmul_ext_v_u64m4_u64m8(vuint64m4_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vlmul_trunc_v)))
vint64m1_t vlmul_trunc_v_i64m2_i64m1(vint64m2_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vlmul_trunc_v)))
vint64m1_t vlmul_trunc_v_i64m4_i64m1(vint64m4_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vlmul_trunc_v)))
vint64m1_t vlmul_trunc_v_i64m8_i64m1(vint64m8_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vlmul_trunc_v)))
vint64m2_t vlmul_trunc_v_i64m4_i64m2(vint64m4_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vlmul_trunc_v)))
vint64m2_t vlmul_trunc_v_i64m8_i64m2(vint64m8_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vlmul_trunc_v)))
vint64m4_t vlmul_trunc_v_i64m8_i64m4(vint64m8_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vlmul_trunc_v)))
vuint64m1_t vlmul_trunc_v_u64m2_u64m1(vuint64m2_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vlmul_trunc_v)))
vuint64m1_t vlmul_trunc_v_u64m4_u64m1(vuint64m4_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vlmul_trunc_v)))
vuint64m1_t vlmul_trunc_v_u64m8_u64m1(vuint64m8_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vlmul_trunc_v)))
vuint64m2_t vlmul_trunc_v_u64m4_u64m2(vuint64m4_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vlmul_trunc_v)))
vuint64m2_t vlmul_trunc_v_u64m8_u64m2(vuint64m8_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vlmul_trunc_v)))
vuint64m4_t vlmul_trunc_v_u64m8_u64m4(vuint64m8_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vreinterpret_v)))
vint16m1_t vreinterpret_v_i64m1_i16m1(vint64m1_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vreinterpret_v)))
vint16m2_t vreinterpret_v_i64m2_i16m2(vint64m2_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vreinterpret_v)))
vint16m4_t vreinterpret_v_i64m4_i16m4(vint64m4_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vreinterpret_v)))
vint16m8_t vreinterpret_v_i64m8_i16m8(vint64m8_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vreinterpret_v)))
vint32m1_t vreinterpret_v_i64m1_i32m1(vint64m1_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vreinterpret_v)))
vint32m2_t vreinterpret_v_i64m2_i32m2(vint64m2_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vreinterpret_v)))
vint32m4_t vreinterpret_v_i64m4_i32m4(vint64m4_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vreinterpret_v)))
vint32m8_t vreinterpret_v_i64m8_i32m8(vint64m8_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vreinterpret_v)))
vint64m1_t vreinterpret_v_i8m1_i64m1(vint8m1_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vreinterpret_v)))
vint64m2_t vreinterpret_v_i8m2_i64m2(vint8m2_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vreinterpret_v)))
vint64m4_t vreinterpret_v_i8m4_i64m4(vint8m4_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vreinterpret_v)))
vint64m8_t vreinterpret_v_i8m8_i64m8(vint8m8_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vreinterpret_v)))
vint64m1_t vreinterpret_v_i16m1_i64m1(vint16m1_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vreinterpret_v)))
vint64m2_t vreinterpret_v_i16m2_i64m2(vint16m2_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vreinterpret_v)))
vint64m4_t vreinterpret_v_i16m4_i64m4(vint16m4_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vreinterpret_v)))
vint64m8_t vreinterpret_v_i16m8_i64m8(vint16m8_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vreinterpret_v)))
vint64m1_t vreinterpret_v_i32m1_i64m1(vint32m1_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vreinterpret_v)))
vint64m2_t vreinterpret_v_i32m2_i64m2(vint32m2_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vreinterpret_v)))
vint64m4_t vreinterpret_v_i32m4_i64m4(vint32m4_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vreinterpret_v)))
vint64m8_t vreinterpret_v_i32m8_i64m8(vint32m8_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vreinterpret_v)))
vint8m1_t vreinterpret_v_i64m1_i8m1(vint64m1_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vreinterpret_v)))
vint8m2_t vreinterpret_v_i64m2_i8m2(vint64m2_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vreinterpret_v)))
vint8m4_t vreinterpret_v_i64m4_i8m4(vint64m4_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vreinterpret_v)))
vint8m8_t vreinterpret_v_i64m8_i8m8(vint64m8_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vreinterpret_v)))
vint64m1_t vreinterpret_v_u64m1_i64m1(vuint64m1_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vreinterpret_v)))
vint64m2_t vreinterpret_v_u64m2_i64m2(vuint64m2_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vreinterpret_v)))
vint64m4_t vreinterpret_v_u64m4_i64m4(vuint64m4_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vreinterpret_v)))
vint64m8_t vreinterpret_v_u64m8_i64m8(vuint64m8_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vreinterpret_v)))
vuint16m1_t vreinterpret_v_u64m1_u16m1(vuint64m1_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vreinterpret_v)))
vuint16m2_t vreinterpret_v_u64m2_u16m2(vuint64m2_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vreinterpret_v)))
vuint16m4_t vreinterpret_v_u64m4_u16m4(vuint64m4_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vreinterpret_v)))
vuint16m8_t vreinterpret_v_u64m8_u16m8(vuint64m8_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vreinterpret_v)))
vuint32m1_t vreinterpret_v_u64m1_u32m1(vuint64m1_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vreinterpret_v)))
vuint32m2_t vreinterpret_v_u64m2_u32m2(vuint64m2_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vreinterpret_v)))
vuint32m4_t vreinterpret_v_u64m4_u32m4(vuint64m4_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vreinterpret_v)))
vuint32m8_t vreinterpret_v_u64m8_u32m8(vuint64m8_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vreinterpret_v)))
vuint64m1_t vreinterpret_v_u8m1_u64m1(vuint8m1_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vreinterpret_v)))
vuint64m2_t vreinterpret_v_u8m2_u64m2(vuint8m2_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vreinterpret_v)))
vuint64m4_t vreinterpret_v_u8m4_u64m4(vuint8m4_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vreinterpret_v)))
vuint64m8_t vreinterpret_v_u8m8_u64m8(vuint8m8_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vreinterpret_v)))
vuint64m1_t vreinterpret_v_u16m1_u64m1(vuint16m1_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vreinterpret_v)))
vuint64m2_t vreinterpret_v_u16m2_u64m2(vuint16m2_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vreinterpret_v)))
vuint64m4_t vreinterpret_v_u16m4_u64m4(vuint16m4_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vreinterpret_v)))
vuint64m8_t vreinterpret_v_u16m8_u64m8(vuint16m8_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vreinterpret_v)))
vuint64m1_t vreinterpret_v_u32m1_u64m1(vuint32m1_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vreinterpret_v)))
vuint64m2_t vreinterpret_v_u32m2_u64m2(vuint32m2_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vreinterpret_v)))
vuint64m4_t vreinterpret_v_u32m4_u64m4(vuint32m4_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vreinterpret_v)))
vuint64m8_t vreinterpret_v_u32m8_u64m8(vuint32m8_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vreinterpret_v)))
vuint8m1_t vreinterpret_v_u64m1_u8m1(vuint64m1_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vreinterpret_v)))
vuint8m2_t vreinterpret_v_u64m2_u8m2(vuint64m2_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vreinterpret_v)))
vuint8m4_t vreinterpret_v_u64m4_u8m4(vuint64m4_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vreinterpret_v)))
vuint8m8_t vreinterpret_v_u64m8_u8m8(vuint64m8_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vreinterpret_v)))
vuint64m1_t vreinterpret_v_i64m1_u64m1(vint64m1_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vreinterpret_v)))
vuint64m2_t vreinterpret_v_i64m2_u64m2(vint64m2_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vreinterpret_v)))
vuint64m4_t vreinterpret_v_i64m4_u64m4(vint64m4_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vreinterpret_v)))
vuint64m8_t vreinterpret_v_i64m8_u64m8(vint64m8_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vsext_vf2)))
vint64m1_t vsext_vf2_i64m1(vint32mf2_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vsext_vf2_m)))
vint64m1_t vsext_vf2_i64m1_m(vbool64_t, vint64m1_t, vint32mf2_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vsext_vf2)))
vint64m2_t vsext_vf2_i64m2(vint32m1_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vsext_vf2_m)))
vint64m2_t vsext_vf2_i64m2_m(vbool32_t, vint64m2_t, vint32m1_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vsext_vf2)))
vint64m4_t vsext_vf2_i64m4(vint32m2_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vsext_vf2_m)))
vint64m4_t vsext_vf2_i64m4_m(vbool16_t, vint64m4_t, vint32m2_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vsext_vf2)))
vint64m8_t vsext_vf2_i64m8(vint32m4_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vsext_vf2_m)))
vint64m8_t vsext_vf2_i64m8_m(vbool8_t, vint64m8_t, vint32m4_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vsext_vf4)))
vint64m1_t vsext_vf4_i64m1(vint16mf4_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vsext_vf4_m)))
vint64m1_t vsext_vf4_i64m1_m(vbool64_t, vint64m1_t, vint16mf4_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vsext_vf4)))
vint64m2_t vsext_vf4_i64m2(vint16mf2_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vsext_vf4_m)))
vint64m2_t vsext_vf4_i64m2_m(vbool32_t, vint64m2_t, vint16mf2_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vsext_vf4)))
vint64m4_t vsext_vf4_i64m4(vint16m1_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vsext_vf4_m)))
vint64m4_t vsext_vf4_i64m4_m(vbool16_t, vint64m4_t, vint16m1_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vsext_vf4)))
vint64m8_t vsext_vf4_i64m8(vint16m2_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vsext_vf4_m)))
vint64m8_t vsext_vf4_i64m8_m(vbool8_t, vint64m8_t, vint16m2_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vsext_vf8)))
vint64m1_t vsext_vf8_i64m1(vint8mf8_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vsext_vf8_m)))
vint64m1_t vsext_vf8_i64m1_m(vbool64_t, vint64m1_t, vint8mf8_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vsext_vf8)))
vint64m2_t vsext_vf8_i64m2(vint8mf4_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vsext_vf8_m)))
vint64m2_t vsext_vf8_i64m2_m(vbool32_t, vint64m2_t, vint8mf4_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vsext_vf8)))
vint64m4_t vsext_vf8_i64m4(vint8mf2_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vsext_vf8_m)))
vint64m4_t vsext_vf8_i64m4_m(vbool16_t, vint64m4_t, vint8mf2_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vsext_vf8)))
vint64m8_t vsext_vf8_i64m8(vint8m1_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vsext_vf8_m)))
vint64m8_t vsext_vf8_i64m8_m(vbool8_t, vint64m8_t, vint8m1_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vundefined)))
vint64m1_t vundefined_i64m1();
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vundefined)))
vint64m2_t vundefined_i64m2();
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vundefined)))
vint64m4_t vundefined_i64m4();
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vundefined)))
vint64m8_t vundefined_i64m8();
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vundefined)))
vuint64m1_t vundefined_u64m1();
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vundefined)))
vuint64m2_t vundefined_u64m2();
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vundefined)))
vuint64m4_t vundefined_u64m4();
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vundefined)))
vuint64m8_t vundefined_u64m8();
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vzext_vf2)))
vuint64m1_t vzext_vf2_u64m1(vuint32mf2_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vzext_vf2_m)))
vuint64m1_t vzext_vf2_u64m1_m(vbool64_t, vuint64m1_t, vuint32mf2_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vzext_vf2)))
vuint64m2_t vzext_vf2_u64m2(vuint32m1_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vzext_vf2_m)))
vuint64m2_t vzext_vf2_u64m2_m(vbool32_t, vuint64m2_t, vuint32m1_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vzext_vf2)))
vuint64m4_t vzext_vf2_u64m4(vuint32m2_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vzext_vf2_m)))
vuint64m4_t vzext_vf2_u64m4_m(vbool16_t, vuint64m4_t, vuint32m2_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vzext_vf2)))
vuint64m8_t vzext_vf2_u64m8(vuint32m4_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vzext_vf2_m)))
vuint64m8_t vzext_vf2_u64m8_m(vbool8_t, vuint64m8_t, vuint32m4_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vzext_vf4)))
vuint64m1_t vzext_vf4_u64m1(vuint16mf4_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vzext_vf4_m)))
vuint64m1_t vzext_vf4_u64m1_m(vbool64_t, vuint64m1_t, vuint16mf4_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vzext_vf4)))
vuint64m2_t vzext_vf4_u64m2(vuint16mf2_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vzext_vf4_m)))
vuint64m2_t vzext_vf4_u64m2_m(vbool32_t, vuint64m2_t, vuint16mf2_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vzext_vf4)))
vuint64m4_t vzext_vf4_u64m4(vuint16m1_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vzext_vf4_m)))
vuint64m4_t vzext_vf4_u64m4_m(vbool16_t, vuint64m4_t, vuint16m1_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vzext_vf4)))
vuint64m8_t vzext_vf4_u64m8(vuint16m2_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vzext_vf4_m)))
vuint64m8_t vzext_vf4_u64m8_m(vbool8_t, vuint64m8_t, vuint16m2_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vzext_vf8)))
vuint64m1_t vzext_vf8_u64m1(vuint8mf8_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vzext_vf8_m)))
vuint64m1_t vzext_vf8_u64m1_m(vbool64_t, vuint64m1_t, vuint8mf8_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vzext_vf8)))
vuint64m2_t vzext_vf8_u64m2(vuint8mf4_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vzext_vf8_m)))
vuint64m2_t vzext_vf8_u64m2_m(vbool32_t, vuint64m2_t, vuint8mf4_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vzext_vf8)))
vuint64m4_t vzext_vf8_u64m4(vuint8mf2_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vzext_vf8_m)))
vuint64m4_t vzext_vf8_u64m4_m(vbool16_t, vuint64m4_t, vuint8mf2_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vzext_vf8)))
vuint64m8_t vzext_vf8_u64m8(vuint8m1_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vzext_vf8_m)))
vuint64m8_t vzext_vf8_u64m8_m(vbool8_t, vuint64m8_t, vuint8m1_t, size_t);
#endif

#if defined(__riscv_v) && (__riscv_v_elen >= 64)
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vmulh_vv)))
vint64m1_t vmulh_vv_i64m1(vint64m1_t, vint64m1_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vmulh_vv_m)))
vint64m1_t vmulh_vv_i64m1_m(vbool64_t, vint64m1_t, vint64m1_t, vint64m1_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vmulh_vv)))
vint64m2_t vmulh_vv_i64m2(vint64m2_t, vint64m2_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vmulh_vv_m)))
vint64m2_t vmulh_vv_i64m2_m(vbool32_t, vint64m2_t, vint64m2_t, vint64m2_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vmulh_vv)))
vint64m4_t vmulh_vv_i64m4(vint64m4_t, vint64m4_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vmulh_vv_m)))
vint64m4_t vmulh_vv_i64m4_m(vbool16_t, vint64m4_t, vint64m4_t, vint64m4_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vmulh_vv)))
vint64m8_t vmulh_vv_i64m8(vint64m8_t, vint64m8_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vmulh_vv_m)))
vint64m8_t vmulh_vv_i64m8_m(vbool8_t, vint64m8_t, vint64m8_t, vint64m8_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vmulh_vx)))
vint64m1_t vmulh_vx_i64m1(vint64m1_t, int64_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vmulh_vx_m)))
vint64m1_t vmulh_vx_i64m1_m(vbool64_t, vint64m1_t, vint64m1_t, int64_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vmulh_vx)))
vint64m2_t vmulh_vx_i64m2(vint64m2_t, int64_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vmulh_vx_m)))
vint64m2_t vmulh_vx_i64m2_m(vbool32_t, vint64m2_t, vint64m2_t, int64_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vmulh_vx)))
vint64m4_t vmulh_vx_i64m4(vint64m4_t, int64_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vmulh_vx_m)))
vint64m4_t vmulh_vx_i64m4_m(vbool16_t, vint64m4_t, vint64m4_t, int64_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vmulh_vx)))
vint64m8_t vmulh_vx_i64m8(vint64m8_t, int64_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vmulh_vx_m)))
vint64m8_t vmulh_vx_i64m8_m(vbool8_t, vint64m8_t, vint64m8_t, int64_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vmulhu_vv)))
vuint64m1_t vmulhu_vv_u64m1(vuint64m1_t, vuint64m1_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vmulhu_vv_m)))
vuint64m1_t vmulhu_vv_u64m1_m(vbool64_t, vuint64m1_t, vuint64m1_t, vuint64m1_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vmulhu_vv)))
vuint64m2_t vmulhu_vv_u64m2(vuint64m2_t, vuint64m2_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vmulhu_vv_m)))
vuint64m2_t vmulhu_vv_u64m2_m(vbool32_t, vuint64m2_t, vuint64m2_t, vuint64m2_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vmulhu_vv)))
vuint64m4_t vmulhu_vv_u64m4(vuint64m4_t, vuint64m4_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vmulhu_vv_m)))
vuint64m4_t vmulhu_vv_u64m4_m(vbool16_t, vuint64m4_t, vuint64m4_t, vuint64m4_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vmulhu_vv)))
vuint64m8_t vmulhu_vv_u64m8(vuint64m8_t, vuint64m8_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vmulhu_vv_m)))
vuint64m8_t vmulhu_vv_u64m8_m(vbool8_t, vuint64m8_t, vuint64m8_t, vuint64m8_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vmulhu_vx)))
vuint64m1_t vmulhu_vx_u64m1(vuint64m1_t, uint64_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vmulhu_vx_m)))
vuint64m1_t vmulhu_vx_u64m1_m(vbool64_t, vuint64m1_t, vuint64m1_t, uint64_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vmulhu_vx)))
vuint64m2_t vmulhu_vx_u64m2(vuint64m2_t, uint64_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vmulhu_vx_m)))
vuint64m2_t vmulhu_vx_u64m2_m(vbool32_t, vuint64m2_t, vuint64m2_t, uint64_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vmulhu_vx)))
vuint64m4_t vmulhu_vx_u64m4(vuint64m4_t, uint64_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vmulhu_vx_m)))
vuint64m4_t vmulhu_vx_u64m4_m(vbool16_t, vuint64m4_t, vuint64m4_t, uint64_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vmulhu_vx)))
vuint64m8_t vmulhu_vx_u64m8(vuint64m8_t, uint64_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vmulhu_vx_m)))
vuint64m8_t vmulhu_vx_u64m8_m(vbool8_t, vuint64m8_t, vuint64m8_t, uint64_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vmulhsu_vv)))
vint64m1_t vmulhsu_vv_i64m1(vint64m1_t, vuint64m1_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vmulhsu_vv_m)))
vint64m1_t vmulhsu_vv_i64m1_m(vbool64_t, vint64m1_t, vint64m1_t, vuint64m1_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vmulhsu_vv)))
vint64m2_t vmulhsu_vv_i64m2(vint64m2_t, vuint64m2_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vmulhsu_vv_m)))
vint64m2_t vmulhsu_vv_i64m2_m(vbool32_t, vint64m2_t, vint64m2_t, vuint64m2_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vmulhsu_vv)))
vint64m4_t vmulhsu_vv_i64m4(vint64m4_t, vuint64m4_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vmulhsu_vv_m)))
vint64m4_t vmulhsu_vv_i64m4_m(vbool16_t, vint64m4_t, vint64m4_t, vuint64m4_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vmulhsu_vv)))
vint64m8_t vmulhsu_vv_i64m8(vint64m8_t, vuint64m8_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vmulhsu_vv_m)))
vint64m8_t vmulhsu_vv_i64m8_m(vbool8_t, vint64m8_t, vint64m8_t, vuint64m8_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vmulhsu_vx)))
vint64m1_t vmulhsu_vx_i64m1(vint64m1_t, uint64_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vmulhsu_vx_m)))
vint64m1_t vmulhsu_vx_i64m1_m(vbool64_t, vint64m1_t, vint64m1_t, uint64_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vmulhsu_vx)))
vint64m2_t vmulhsu_vx_i64m2(vint64m2_t, uint64_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vmulhsu_vx_m)))
vint64m2_t vmulhsu_vx_i64m2_m(vbool32_t, vint64m2_t, vint64m2_t, uint64_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vmulhsu_vx)))
vint64m4_t vmulhsu_vx_i64m4(vint64m4_t, uint64_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vmulhsu_vx_m)))
vint64m4_t vmulhsu_vx_i64m4_m(vbool16_t, vint64m4_t, vint64m4_t, uint64_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vmulhsu_vx)))
vint64m8_t vmulhsu_vx_i64m8(vint64m8_t, uint64_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vmulhsu_vx_m)))
vint64m8_t vmulhsu_vx_i64m8_m(vbool8_t, vint64m8_t, vint64m8_t, uint64_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vsmul_vv)))
vint64m1_t vsmul_vv_i64m1(vint64m1_t, vint64m1_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vsmul_vv_m)))
vint64m1_t vsmul_vv_i64m1_m(vbool64_t, vint64m1_t, vint64m1_t, vint64m1_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vsmul_vv)))
vint64m2_t vsmul_vv_i64m2(vint64m2_t, vint64m2_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vsmul_vv_m)))
vint64m2_t vsmul_vv_i64m2_m(vbool32_t, vint64m2_t, vint64m2_t, vint64m2_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vsmul_vv)))
vint64m4_t vsmul_vv_i64m4(vint64m4_t, vint64m4_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vsmul_vv_m)))
vint64m4_t vsmul_vv_i64m4_m(vbool16_t, vint64m4_t, vint64m4_t, vint64m4_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vsmul_vv)))
vint64m8_t vsmul_vv_i64m8(vint64m8_t, vint64m8_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vsmul_vv_m)))
vint64m8_t vsmul_vv_i64m8_m(vbool8_t, vint64m8_t, vint64m8_t, vint64m8_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vsmul_vx)))
vint64m1_t vsmul_vx_i64m1(vint64m1_t, int64_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vsmul_vx_m)))
vint64m1_t vsmul_vx_i64m1_m(vbool64_t, vint64m1_t, vint64m1_t, int64_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vsmul_vx)))
vint64m2_t vsmul_vx_i64m2(vint64m2_t, int64_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vsmul_vx_m)))
vint64m2_t vsmul_vx_i64m2_m(vbool32_t, vint64m2_t, vint64m2_t, int64_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vsmul_vx)))
vint64m4_t vsmul_vx_i64m4(vint64m4_t, int64_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vsmul_vx_m)))
vint64m4_t vsmul_vx_i64m4_m(vbool16_t, vint64m4_t, vint64m4_t, int64_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vsmul_vx)))
vint64m8_t vsmul_vx_i64m8(vint64m8_t, int64_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vsmul_vx_m)))
vint64m8_t vsmul_vx_i64m8_m(vbool8_t, vint64m8_t, vint64m8_t, int64_t, size_t);
#endif

#if defined(__riscv_zfh) && (__riscv_v_elen >= 64)
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vloxseg2ei64_v)))
void vloxseg2ei64_v_f16m1(vfloat16m1_t *, vfloat16m1_t *, const _Float16 *, vuint64m4_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vloxseg2ei64_v_m)))
void vloxseg2ei64_v_f16m1_m(vfloat16m1_t *, vfloat16m1_t *, vbool16_t, vfloat16m1_t, vfloat16m1_t, const _Float16 *, vuint64m4_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vloxseg2ei64_v)))
void vloxseg2ei64_v_f16m2(vfloat16m2_t *, vfloat16m2_t *, const _Float16 *, vuint64m8_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vloxseg2ei64_v_m)))
void vloxseg2ei64_v_f16m2_m(vfloat16m2_t *, vfloat16m2_t *, vbool8_t, vfloat16m2_t, vfloat16m2_t, const _Float16 *, vuint64m8_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vloxseg2ei64_v)))
void vloxseg2ei64_v_f16mf2(vfloat16mf2_t *, vfloat16mf2_t *, const _Float16 *, vuint64m2_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vloxseg2ei64_v_m)))
void vloxseg2ei64_v_f16mf2_m(vfloat16mf2_t *, vfloat16mf2_t *, vbool32_t, vfloat16mf2_t, vfloat16mf2_t, const _Float16 *, vuint64m2_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vloxseg2ei64_v)))
void vloxseg2ei64_v_f16mf4(vfloat16mf4_t *, vfloat16mf4_t *, const _Float16 *, vuint64m1_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vloxseg2ei64_v_m)))
void vloxseg2ei64_v_f16mf4_m(vfloat16mf4_t *, vfloat16mf4_t *, vbool64_t, vfloat16mf4_t, vfloat16mf4_t, const _Float16 *, vuint64m1_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vloxseg3ei64_v)))
void vloxseg3ei64_v_f16m1(vfloat16m1_t *, vfloat16m1_t *, vfloat16m1_t *, const _Float16 *, vuint64m4_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vloxseg3ei64_v_m)))
void vloxseg3ei64_v_f16m1_m(vfloat16m1_t *, vfloat16m1_t *, vfloat16m1_t *, vbool16_t, vfloat16m1_t, vfloat16m1_t, vfloat16m1_t, const _Float16 *, vuint64m4_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vloxseg3ei64_v)))
void vloxseg3ei64_v_f16m2(vfloat16m2_t *, vfloat16m2_t *, vfloat16m2_t *, const _Float16 *, vuint64m8_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vloxseg3ei64_v_m)))
void vloxseg3ei64_v_f16m2_m(vfloat16m2_t *, vfloat16m2_t *, vfloat16m2_t *, vbool8_t, vfloat16m2_t, vfloat16m2_t, vfloat16m2_t, const _Float16 *, vuint64m8_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vloxseg3ei64_v)))
void vloxseg3ei64_v_f16mf2(vfloat16mf2_t *, vfloat16mf2_t *, vfloat16mf2_t *, const _Float16 *, vuint64m2_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vloxseg3ei64_v_m)))
void vloxseg3ei64_v_f16mf2_m(vfloat16mf2_t *, vfloat16mf2_t *, vfloat16mf2_t *, vbool32_t, vfloat16mf2_t, vfloat16mf2_t, vfloat16mf2_t, const _Float16 *, vuint64m2_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vloxseg3ei64_v)))
void vloxseg3ei64_v_f16mf4(vfloat16mf4_t *, vfloat16mf4_t *, vfloat16mf4_t *, const _Float16 *, vuint64m1_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vloxseg3ei64_v_m)))
void vloxseg3ei64_v_f16mf4_m(vfloat16mf4_t *, vfloat16mf4_t *, vfloat16mf4_t *, vbool64_t, vfloat16mf4_t, vfloat16mf4_t, vfloat16mf4_t, const _Float16 *, vuint64m1_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vloxseg4ei64_v)))
void vloxseg4ei64_v_f16m1(vfloat16m1_t *, vfloat16m1_t *, vfloat16m1_t *, vfloat16m1_t *, const _Float16 *, vuint64m4_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vloxseg4ei64_v_m)))
void vloxseg4ei64_v_f16m1_m(vfloat16m1_t *, vfloat16m1_t *, vfloat16m1_t *, vfloat16m1_t *, vbool16_t, vfloat16m1_t, vfloat16m1_t, vfloat16m1_t, vfloat16m1_t, const _Float16 *, vuint64m4_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vloxseg4ei64_v)))
void vloxseg4ei64_v_f16m2(vfloat16m2_t *, vfloat16m2_t *, vfloat16m2_t *, vfloat16m2_t *, const _Float16 *, vuint64m8_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vloxseg4ei64_v_m)))
void vloxseg4ei64_v_f16m2_m(vfloat16m2_t *, vfloat16m2_t *, vfloat16m2_t *, vfloat16m2_t *, vbool8_t, vfloat16m2_t, vfloat16m2_t, vfloat16m2_t, vfloat16m2_t, const _Float16 *, vuint64m8_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vloxseg4ei64_v)))
void vloxseg4ei64_v_f16mf2(vfloat16mf2_t *, vfloat16mf2_t *, vfloat16mf2_t *, vfloat16mf2_t *, const _Float16 *, vuint64m2_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vloxseg4ei64_v_m)))
void vloxseg4ei64_v_f16mf2_m(vfloat16mf2_t *, vfloat16mf2_t *, vfloat16mf2_t *, vfloat16mf2_t *, vbool32_t, vfloat16mf2_t, vfloat16mf2_t, vfloat16mf2_t, vfloat16mf2_t, const _Float16 *, vuint64m2_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vloxseg4ei64_v)))
void vloxseg4ei64_v_f16mf4(vfloat16mf4_t *, vfloat16mf4_t *, vfloat16mf4_t *, vfloat16mf4_t *, const _Float16 *, vuint64m1_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vloxseg4ei64_v_m)))
void vloxseg4ei64_v_f16mf4_m(vfloat16mf4_t *, vfloat16mf4_t *, vfloat16mf4_t *, vfloat16mf4_t *, vbool64_t, vfloat16mf4_t, vfloat16mf4_t, vfloat16mf4_t, vfloat16mf4_t, const _Float16 *, vuint64m1_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vloxseg5ei64_v)))
void vloxseg5ei64_v_f16m1(vfloat16m1_t *, vfloat16m1_t *, vfloat16m1_t *, vfloat16m1_t *, vfloat16m1_t *, const _Float16 *, vuint64m4_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vloxseg5ei64_v_m)))
void vloxseg5ei64_v_f16m1_m(vfloat16m1_t *, vfloat16m1_t *, vfloat16m1_t *, vfloat16m1_t *, vfloat16m1_t *, vbool16_t, vfloat16m1_t, vfloat16m1_t, vfloat16m1_t, vfloat16m1_t, vfloat16m1_t, const _Float16 *, vuint64m4_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vloxseg5ei64_v)))
void vloxseg5ei64_v_f16mf2(vfloat16mf2_t *, vfloat16mf2_t *, vfloat16mf2_t *, vfloat16mf2_t *, vfloat16mf2_t *, const _Float16 *, vuint64m2_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vloxseg5ei64_v_m)))
void vloxseg5ei64_v_f16mf2_m(vfloat16mf2_t *, vfloat16mf2_t *, vfloat16mf2_t *, vfloat16mf2_t *, vfloat16mf2_t *, vbool32_t, vfloat16mf2_t, vfloat16mf2_t, vfloat16mf2_t, vfloat16mf2_t, vfloat16mf2_t, const _Float16 *, vuint64m2_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vloxseg5ei64_v)))
void vloxseg5ei64_v_f16mf4(vfloat16mf4_t *, vfloat16mf4_t *, vfloat16mf4_t *, vfloat16mf4_t *, vfloat16mf4_t *, const _Float16 *, vuint64m1_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vloxseg5ei64_v_m)))
void vloxseg5ei64_v_f16mf4_m(vfloat16mf4_t *, vfloat16mf4_t *, vfloat16mf4_t *, vfloat16mf4_t *, vfloat16mf4_t *, vbool64_t, vfloat16mf4_t, vfloat16mf4_t, vfloat16mf4_t, vfloat16mf4_t, vfloat16mf4_t, const _Float16 *, vuint64m1_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vloxseg6ei64_v)))
void vloxseg6ei64_v_f16m1(vfloat16m1_t *, vfloat16m1_t *, vfloat16m1_t *, vfloat16m1_t *, vfloat16m1_t *, vfloat16m1_t *, const _Float16 *, vuint64m4_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vloxseg6ei64_v_m)))
void vloxseg6ei64_v_f16m1_m(vfloat16m1_t *, vfloat16m1_t *, vfloat16m1_t *, vfloat16m1_t *, vfloat16m1_t *, vfloat16m1_t *, vbool16_t, vfloat16m1_t, vfloat16m1_t, vfloat16m1_t, vfloat16m1_t, vfloat16m1_t, vfloat16m1_t, const _Float16 *, vuint64m4_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vloxseg6ei64_v)))
void vloxseg6ei64_v_f16mf2(vfloat16mf2_t *, vfloat16mf2_t *, vfloat16mf2_t *, vfloat16mf2_t *, vfloat16mf2_t *, vfloat16mf2_t *, const _Float16 *, vuint64m2_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vloxseg6ei64_v_m)))
void vloxseg6ei64_v_f16mf2_m(vfloat16mf2_t *, vfloat16mf2_t *, vfloat16mf2_t *, vfloat16mf2_t *, vfloat16mf2_t *, vfloat16mf2_t *, vbool32_t, vfloat16mf2_t, vfloat16mf2_t, vfloat16mf2_t, vfloat16mf2_t, vfloat16mf2_t, vfloat16mf2_t, const _Float16 *, vuint64m2_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vloxseg6ei64_v)))
void vloxseg6ei64_v_f16mf4(vfloat16mf4_t *, vfloat16mf4_t *, vfloat16mf4_t *, vfloat16mf4_t *, vfloat16mf4_t *, vfloat16mf4_t *, const _Float16 *, vuint64m1_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vloxseg6ei64_v_m)))
void vloxseg6ei64_v_f16mf4_m(vfloat16mf4_t *, vfloat16mf4_t *, vfloat16mf4_t *, vfloat16mf4_t *, vfloat16mf4_t *, vfloat16mf4_t *, vbool64_t, vfloat16mf4_t, vfloat16mf4_t, vfloat16mf4_t, vfloat16mf4_t, vfloat16mf4_t, vfloat16mf4_t, const _Float16 *, vuint64m1_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vloxseg7ei64_v)))
void vloxseg7ei64_v_f16m1(vfloat16m1_t *, vfloat16m1_t *, vfloat16m1_t *, vfloat16m1_t *, vfloat16m1_t *, vfloat16m1_t *, vfloat16m1_t *, const _Float16 *, vuint64m4_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vloxseg7ei64_v_m)))
void vloxseg7ei64_v_f16m1_m(vfloat16m1_t *, vfloat16m1_t *, vfloat16m1_t *, vfloat16m1_t *, vfloat16m1_t *, vfloat16m1_t *, vfloat16m1_t *, vbool16_t, vfloat16m1_t, vfloat16m1_t, vfloat16m1_t, vfloat16m1_t, vfloat16m1_t, vfloat16m1_t, vfloat16m1_t, const _Float16 *, vuint64m4_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vloxseg7ei64_v)))
void vloxseg7ei64_v_f16mf2(vfloat16mf2_t *, vfloat16mf2_t *, vfloat16mf2_t *, vfloat16mf2_t *, vfloat16mf2_t *, vfloat16mf2_t *, vfloat16mf2_t *, const _Float16 *, vuint64m2_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vloxseg7ei64_v_m)))
void vloxseg7ei64_v_f16mf2_m(vfloat16mf2_t *, vfloat16mf2_t *, vfloat16mf2_t *, vfloat16mf2_t *, vfloat16mf2_t *, vfloat16mf2_t *, vfloat16mf2_t *, vbool32_t, vfloat16mf2_t, vfloat16mf2_t, vfloat16mf2_t, vfloat16mf2_t, vfloat16mf2_t, vfloat16mf2_t, vfloat16mf2_t, const _Float16 *, vuint64m2_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vloxseg7ei64_v)))
void vloxseg7ei64_v_f16mf4(vfloat16mf4_t *, vfloat16mf4_t *, vfloat16mf4_t *, vfloat16mf4_t *, vfloat16mf4_t *, vfloat16mf4_t *, vfloat16mf4_t *, const _Float16 *, vuint64m1_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vloxseg7ei64_v_m)))
void vloxseg7ei64_v_f16mf4_m(vfloat16mf4_t *, vfloat16mf4_t *, vfloat16mf4_t *, vfloat16mf4_t *, vfloat16mf4_t *, vfloat16mf4_t *, vfloat16mf4_t *, vbool64_t, vfloat16mf4_t, vfloat16mf4_t, vfloat16mf4_t, vfloat16mf4_t, vfloat16mf4_t, vfloat16mf4_t, vfloat16mf4_t, const _Float16 *, vuint64m1_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vloxseg8ei64_v)))
void vloxseg8ei64_v_f16m1(vfloat16m1_t *, vfloat16m1_t *, vfloat16m1_t *, vfloat16m1_t *, vfloat16m1_t *, vfloat16m1_t *, vfloat16m1_t *, vfloat16m1_t *, const _Float16 *, vuint64m4_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vloxseg8ei64_v_m)))
void vloxseg8ei64_v_f16m1_m(vfloat16m1_t *, vfloat16m1_t *, vfloat16m1_t *, vfloat16m1_t *, vfloat16m1_t *, vfloat16m1_t *, vfloat16m1_t *, vfloat16m1_t *, vbool16_t, vfloat16m1_t, vfloat16m1_t, vfloat16m1_t, vfloat16m1_t, vfloat16m1_t, vfloat16m1_t, vfloat16m1_t, vfloat16m1_t, const _Float16 *, vuint64m4_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vloxseg8ei64_v)))
void vloxseg8ei64_v_f16mf2(vfloat16mf2_t *, vfloat16mf2_t *, vfloat16mf2_t *, vfloat16mf2_t *, vfloat16mf2_t *, vfloat16mf2_t *, vfloat16mf2_t *, vfloat16mf2_t *, const _Float16 *, vuint64m2_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vloxseg8ei64_v_m)))
void vloxseg8ei64_v_f16mf2_m(vfloat16mf2_t *, vfloat16mf2_t *, vfloat16mf2_t *, vfloat16mf2_t *, vfloat16mf2_t *, vfloat16mf2_t *, vfloat16mf2_t *, vfloat16mf2_t *, vbool32_t, vfloat16mf2_t, vfloat16mf2_t, vfloat16mf2_t, vfloat16mf2_t, vfloat16mf2_t, vfloat16mf2_t, vfloat16mf2_t, vfloat16mf2_t, const _Float16 *, vuint64m2_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vloxseg8ei64_v)))
void vloxseg8ei64_v_f16mf4(vfloat16mf4_t *, vfloat16mf4_t *, vfloat16mf4_t *, vfloat16mf4_t *, vfloat16mf4_t *, vfloat16mf4_t *, vfloat16mf4_t *, vfloat16mf4_t *, const _Float16 *, vuint64m1_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vloxseg8ei64_v_m)))
void vloxseg8ei64_v_f16mf4_m(vfloat16mf4_t *, vfloat16mf4_t *, vfloat16mf4_t *, vfloat16mf4_t *, vfloat16mf4_t *, vfloat16mf4_t *, vfloat16mf4_t *, vfloat16mf4_t *, vbool64_t, vfloat16mf4_t, vfloat16mf4_t, vfloat16mf4_t, vfloat16mf4_t, vfloat16mf4_t, vfloat16mf4_t, vfloat16mf4_t, vfloat16mf4_t, const _Float16 *, vuint64m1_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vsuxseg2ei64_v)))
void vsuxseg2ei64_v_f16m1(_Float16 *, vuint64m4_t, vfloat16m1_t, vfloat16m1_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vsuxseg2ei64_v_m)))
void vsuxseg2ei64_v_f16m1_m(vbool16_t, _Float16 *, vuint64m4_t, vfloat16m1_t, vfloat16m1_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vsuxseg2ei64_v)))
void vsuxseg2ei64_v_f16m2(_Float16 *, vuint64m8_t, vfloat16m2_t, vfloat16m2_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vsuxseg2ei64_v_m)))
void vsuxseg2ei64_v_f16m2_m(vbool8_t, _Float16 *, vuint64m8_t, vfloat16m2_t, vfloat16m2_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vsuxseg2ei64_v)))
void vsuxseg2ei64_v_f16mf2(_Float16 *, vuint64m2_t, vfloat16mf2_t, vfloat16mf2_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vsuxseg2ei64_v_m)))
void vsuxseg2ei64_v_f16mf2_m(vbool32_t, _Float16 *, vuint64m2_t, vfloat16mf2_t, vfloat16mf2_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vsuxseg2ei64_v)))
void vsuxseg2ei64_v_f16mf4(_Float16 *, vuint64m1_t, vfloat16mf4_t, vfloat16mf4_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vsuxseg2ei64_v_m)))
void vsuxseg2ei64_v_f16mf4_m(vbool64_t, _Float16 *, vuint64m1_t, vfloat16mf4_t, vfloat16mf4_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vsuxseg3ei64_v)))
void vsuxseg3ei64_v_f16m1(_Float16 *, vuint64m4_t, vfloat16m1_t, vfloat16m1_t, vfloat16m1_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vsuxseg3ei64_v_m)))
void vsuxseg3ei64_v_f16m1_m(vbool16_t, _Float16 *, vuint64m4_t, vfloat16m1_t, vfloat16m1_t, vfloat16m1_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vsuxseg3ei64_v)))
void vsuxseg3ei64_v_f16m2(_Float16 *, vuint64m8_t, vfloat16m2_t, vfloat16m2_t, vfloat16m2_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vsuxseg3ei64_v_m)))
void vsuxseg3ei64_v_f16m2_m(vbool8_t, _Float16 *, vuint64m8_t, vfloat16m2_t, vfloat16m2_t, vfloat16m2_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vsuxseg3ei64_v)))
void vsuxseg3ei64_v_f16mf2(_Float16 *, vuint64m2_t, vfloat16mf2_t, vfloat16mf2_t, vfloat16mf2_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vsuxseg3ei64_v_m)))
void vsuxseg3ei64_v_f16mf2_m(vbool32_t, _Float16 *, vuint64m2_t, vfloat16mf2_t, vfloat16mf2_t, vfloat16mf2_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vsuxseg3ei64_v)))
void vsuxseg3ei64_v_f16mf4(_Float16 *, vuint64m1_t, vfloat16mf4_t, vfloat16mf4_t, vfloat16mf4_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vsuxseg3ei64_v_m)))
void vsuxseg3ei64_v_f16mf4_m(vbool64_t, _Float16 *, vuint64m1_t, vfloat16mf4_t, vfloat16mf4_t, vfloat16mf4_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vsuxseg4ei64_v)))
void vsuxseg4ei64_v_f16m1(_Float16 *, vuint64m4_t, vfloat16m1_t, vfloat16m1_t, vfloat16m1_t, vfloat16m1_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vsuxseg4ei64_v_m)))
void vsuxseg4ei64_v_f16m1_m(vbool16_t, _Float16 *, vuint64m4_t, vfloat16m1_t, vfloat16m1_t, vfloat16m1_t, vfloat16m1_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vsuxseg4ei64_v)))
void vsuxseg4ei64_v_f16m2(_Float16 *, vuint64m8_t, vfloat16m2_t, vfloat16m2_t, vfloat16m2_t, vfloat16m2_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vsuxseg4ei64_v_m)))
void vsuxseg4ei64_v_f16m2_m(vbool8_t, _Float16 *, vuint64m8_t, vfloat16m2_t, vfloat16m2_t, vfloat16m2_t, vfloat16m2_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vsuxseg4ei64_v)))
void vsuxseg4ei64_v_f16mf2(_Float16 *, vuint64m2_t, vfloat16mf2_t, vfloat16mf2_t, vfloat16mf2_t, vfloat16mf2_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vsuxseg4ei64_v_m)))
void vsuxseg4ei64_v_f16mf2_m(vbool32_t, _Float16 *, vuint64m2_t, vfloat16mf2_t, vfloat16mf2_t, vfloat16mf2_t, vfloat16mf2_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vsuxseg4ei64_v)))
void vsuxseg4ei64_v_f16mf4(_Float16 *, vuint64m1_t, vfloat16mf4_t, vfloat16mf4_t, vfloat16mf4_t, vfloat16mf4_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vsuxseg4ei64_v_m)))
void vsuxseg4ei64_v_f16mf4_m(vbool64_t, _Float16 *, vuint64m1_t, vfloat16mf4_t, vfloat16mf4_t, vfloat16mf4_t, vfloat16mf4_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vsuxseg5ei64_v)))
void vsuxseg5ei64_v_f16m1(_Float16 *, vuint64m4_t, vfloat16m1_t, vfloat16m1_t, vfloat16m1_t, vfloat16m1_t, vfloat16m1_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vsuxseg5ei64_v_m)))
void vsuxseg5ei64_v_f16m1_m(vbool16_t, _Float16 *, vuint64m4_t, vfloat16m1_t, vfloat16m1_t, vfloat16m1_t, vfloat16m1_t, vfloat16m1_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vsuxseg5ei64_v)))
void vsuxseg5ei64_v_f16mf2(_Float16 *, vuint64m2_t, vfloat16mf2_t, vfloat16mf2_t, vfloat16mf2_t, vfloat16mf2_t, vfloat16mf2_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vsuxseg5ei64_v_m)))
void vsuxseg5ei64_v_f16mf2_m(vbool32_t, _Float16 *, vuint64m2_t, vfloat16mf2_t, vfloat16mf2_t, vfloat16mf2_t, vfloat16mf2_t, vfloat16mf2_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vsuxseg5ei64_v)))
void vsuxseg5ei64_v_f16mf4(_Float16 *, vuint64m1_t, vfloat16mf4_t, vfloat16mf4_t, vfloat16mf4_t, vfloat16mf4_t, vfloat16mf4_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vsuxseg5ei64_v_m)))
void vsuxseg5ei64_v_f16mf4_m(vbool64_t, _Float16 *, vuint64m1_t, vfloat16mf4_t, vfloat16mf4_t, vfloat16mf4_t, vfloat16mf4_t, vfloat16mf4_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vsuxseg6ei64_v)))
void vsuxseg6ei64_v_f16m1(_Float16 *, vuint64m4_t, vfloat16m1_t, vfloat16m1_t, vfloat16m1_t, vfloat16m1_t, vfloat16m1_t, vfloat16m1_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vsuxseg6ei64_v_m)))
void vsuxseg6ei64_v_f16m1_m(vbool16_t, _Float16 *, vuint64m4_t, vfloat16m1_t, vfloat16m1_t, vfloat16m1_t, vfloat16m1_t, vfloat16m1_t, vfloat16m1_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vsuxseg6ei64_v)))
void vsuxseg6ei64_v_f16mf2(_Float16 *, vuint64m2_t, vfloat16mf2_t, vfloat16mf2_t, vfloat16mf2_t, vfloat16mf2_t, vfloat16mf2_t, vfloat16mf2_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vsuxseg6ei64_v_m)))
void vsuxseg6ei64_v_f16mf2_m(vbool32_t, _Float16 *, vuint64m2_t, vfloat16mf2_t, vfloat16mf2_t, vfloat16mf2_t, vfloat16mf2_t, vfloat16mf2_t, vfloat16mf2_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vsuxseg6ei64_v)))
void vsuxseg6ei64_v_f16mf4(_Float16 *, vuint64m1_t, vfloat16mf4_t, vfloat16mf4_t, vfloat16mf4_t, vfloat16mf4_t, vfloat16mf4_t, vfloat16mf4_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vsuxseg6ei64_v_m)))
void vsuxseg6ei64_v_f16mf4_m(vbool64_t, _Float16 *, vuint64m1_t, vfloat16mf4_t, vfloat16mf4_t, vfloat16mf4_t, vfloat16mf4_t, vfloat16mf4_t, vfloat16mf4_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vsuxseg7ei64_v)))
void vsuxseg7ei64_v_f16m1(_Float16 *, vuint64m4_t, vfloat16m1_t, vfloat16m1_t, vfloat16m1_t, vfloat16m1_t, vfloat16m1_t, vfloat16m1_t, vfloat16m1_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vsuxseg7ei64_v_m)))
void vsuxseg7ei64_v_f16m1_m(vbool16_t, _Float16 *, vuint64m4_t, vfloat16m1_t, vfloat16m1_t, vfloat16m1_t, vfloat16m1_t, vfloat16m1_t, vfloat16m1_t, vfloat16m1_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vsuxseg7ei64_v)))
void vsuxseg7ei64_v_f16mf2(_Float16 *, vuint64m2_t, vfloat16mf2_t, vfloat16mf2_t, vfloat16mf2_t, vfloat16mf2_t, vfloat16mf2_t, vfloat16mf2_t, vfloat16mf2_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vsuxseg7ei64_v_m)))
void vsuxseg7ei64_v_f16mf2_m(vbool32_t, _Float16 *, vuint64m2_t, vfloat16mf2_t, vfloat16mf2_t, vfloat16mf2_t, vfloat16mf2_t, vfloat16mf2_t, vfloat16mf2_t, vfloat16mf2_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vsuxseg7ei64_v)))
void vsuxseg7ei64_v_f16mf4(_Float16 *, vuint64m1_t, vfloat16mf4_t, vfloat16mf4_t, vfloat16mf4_t, vfloat16mf4_t, vfloat16mf4_t, vfloat16mf4_t, vfloat16mf4_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vsuxseg7ei64_v_m)))
void vsuxseg7ei64_v_f16mf4_m(vbool64_t, _Float16 *, vuint64m1_t, vfloat16mf4_t, vfloat16mf4_t, vfloat16mf4_t, vfloat16mf4_t, vfloat16mf4_t, vfloat16mf4_t, vfloat16mf4_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vsuxseg8ei64_v)))
void vsuxseg8ei64_v_f16m1(_Float16 *, vuint64m4_t, vfloat16m1_t, vfloat16m1_t, vfloat16m1_t, vfloat16m1_t, vfloat16m1_t, vfloat16m1_t, vfloat16m1_t, vfloat16m1_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vsuxseg8ei64_v_m)))
void vsuxseg8ei64_v_f16m1_m(vbool16_t, _Float16 *, vuint64m4_t, vfloat16m1_t, vfloat16m1_t, vfloat16m1_t, vfloat16m1_t, vfloat16m1_t, vfloat16m1_t, vfloat16m1_t, vfloat16m1_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vsuxseg8ei64_v)))
void vsuxseg8ei64_v_f16mf2(_Float16 *, vuint64m2_t, vfloat16mf2_t, vfloat16mf2_t, vfloat16mf2_t, vfloat16mf2_t, vfloat16mf2_t, vfloat16mf2_t, vfloat16mf2_t, vfloat16mf2_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vsuxseg8ei64_v_m)))
void vsuxseg8ei64_v_f16mf2_m(vbool32_t, _Float16 *, vuint64m2_t, vfloat16mf2_t, vfloat16mf2_t, vfloat16mf2_t, vfloat16mf2_t, vfloat16mf2_t, vfloat16mf2_t, vfloat16mf2_t, vfloat16mf2_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vsuxseg8ei64_v)))
void vsuxseg8ei64_v_f16mf4(_Float16 *, vuint64m1_t, vfloat16mf4_t, vfloat16mf4_t, vfloat16mf4_t, vfloat16mf4_t, vfloat16mf4_t, vfloat16mf4_t, vfloat16mf4_t, vfloat16mf4_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vsuxseg8ei64_v_m)))
void vsuxseg8ei64_v_f16mf4_m(vbool64_t, _Float16 *, vuint64m1_t, vfloat16mf4_t, vfloat16mf4_t, vfloat16mf4_t, vfloat16mf4_t, vfloat16mf4_t, vfloat16mf4_t, vfloat16mf4_t, vfloat16mf4_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vsoxseg2ei64_v)))
void vsoxseg2ei64_v_f16m1(_Float16 *, vuint64m4_t, vfloat16m1_t, vfloat16m1_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vsoxseg2ei64_v_m)))
void vsoxseg2ei64_v_f16m1_m(vbool16_t, _Float16 *, vuint64m4_t, vfloat16m1_t, vfloat16m1_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vsoxseg2ei64_v)))
void vsoxseg2ei64_v_f16m2(_Float16 *, vuint64m8_t, vfloat16m2_t, vfloat16m2_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vsoxseg2ei64_v_m)))
void vsoxseg2ei64_v_f16m2_m(vbool8_t, _Float16 *, vuint64m8_t, vfloat16m2_t, vfloat16m2_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vsoxseg2ei64_v)))
void vsoxseg2ei64_v_f16mf2(_Float16 *, vuint64m2_t, vfloat16mf2_t, vfloat16mf2_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vsoxseg2ei64_v_m)))
void vsoxseg2ei64_v_f16mf2_m(vbool32_t, _Float16 *, vuint64m2_t, vfloat16mf2_t, vfloat16mf2_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vsoxseg2ei64_v)))
void vsoxseg2ei64_v_f16mf4(_Float16 *, vuint64m1_t, vfloat16mf4_t, vfloat16mf4_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vsoxseg2ei64_v_m)))
void vsoxseg2ei64_v_f16mf4_m(vbool64_t, _Float16 *, vuint64m1_t, vfloat16mf4_t, vfloat16mf4_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vsoxseg3ei64_v)))
void vsoxseg3ei64_v_f16m1(_Float16 *, vuint64m4_t, vfloat16m1_t, vfloat16m1_t, vfloat16m1_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vsoxseg3ei64_v_m)))
void vsoxseg3ei64_v_f16m1_m(vbool16_t, _Float16 *, vuint64m4_t, vfloat16m1_t, vfloat16m1_t, vfloat16m1_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vsoxseg3ei64_v)))
void vsoxseg3ei64_v_f16m2(_Float16 *, vuint64m8_t, vfloat16m2_t, vfloat16m2_t, vfloat16m2_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vsoxseg3ei64_v_m)))
void vsoxseg3ei64_v_f16m2_m(vbool8_t, _Float16 *, vuint64m8_t, vfloat16m2_t, vfloat16m2_t, vfloat16m2_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vsoxseg3ei64_v)))
void vsoxseg3ei64_v_f16mf2(_Float16 *, vuint64m2_t, vfloat16mf2_t, vfloat16mf2_t, vfloat16mf2_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vsoxseg3ei64_v_m)))
void vsoxseg3ei64_v_f16mf2_m(vbool32_t, _Float16 *, vuint64m2_t, vfloat16mf2_t, vfloat16mf2_t, vfloat16mf2_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vsoxseg3ei64_v)))
void vsoxseg3ei64_v_f16mf4(_Float16 *, vuint64m1_t, vfloat16mf4_t, vfloat16mf4_t, vfloat16mf4_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vsoxseg3ei64_v_m)))
void vsoxseg3ei64_v_f16mf4_m(vbool64_t, _Float16 *, vuint64m1_t, vfloat16mf4_t, vfloat16mf4_t, vfloat16mf4_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vsoxseg4ei64_v)))
void vsoxseg4ei64_v_f16m1(_Float16 *, vuint64m4_t, vfloat16m1_t, vfloat16m1_t, vfloat16m1_t, vfloat16m1_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vsoxseg4ei64_v_m)))
void vsoxseg4ei64_v_f16m1_m(vbool16_t, _Float16 *, vuint64m4_t, vfloat16m1_t, vfloat16m1_t, vfloat16m1_t, vfloat16m1_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vsoxseg4ei64_v)))
void vsoxseg4ei64_v_f16m2(_Float16 *, vuint64m8_t, vfloat16m2_t, vfloat16m2_t, vfloat16m2_t, vfloat16m2_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vsoxseg4ei64_v_m)))
void vsoxseg4ei64_v_f16m2_m(vbool8_t, _Float16 *, vuint64m8_t, vfloat16m2_t, vfloat16m2_t, vfloat16m2_t, vfloat16m2_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vsoxseg4ei64_v)))
void vsoxseg4ei64_v_f16mf2(_Float16 *, vuint64m2_t, vfloat16mf2_t, vfloat16mf2_t, vfloat16mf2_t, vfloat16mf2_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vsoxseg4ei64_v_m)))
void vsoxseg4ei64_v_f16mf2_m(vbool32_t, _Float16 *, vuint64m2_t, vfloat16mf2_t, vfloat16mf2_t, vfloat16mf2_t, vfloat16mf2_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vsoxseg4ei64_v)))
void vsoxseg4ei64_v_f16mf4(_Float16 *, vuint64m1_t, vfloat16mf4_t, vfloat16mf4_t, vfloat16mf4_t, vfloat16mf4_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vsoxseg4ei64_v_m)))
void vsoxseg4ei64_v_f16mf4_m(vbool64_t, _Float16 *, vuint64m1_t, vfloat16mf4_t, vfloat16mf4_t, vfloat16mf4_t, vfloat16mf4_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vsoxseg5ei64_v)))
void vsoxseg5ei64_v_f16m1(_Float16 *, vuint64m4_t, vfloat16m1_t, vfloat16m1_t, vfloat16m1_t, vfloat16m1_t, vfloat16m1_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vsoxseg5ei64_v_m)))
void vsoxseg5ei64_v_f16m1_m(vbool16_t, _Float16 *, vuint64m4_t, vfloat16m1_t, vfloat16m1_t, vfloat16m1_t, vfloat16m1_t, vfloat16m1_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vsoxseg5ei64_v)))
void vsoxseg5ei64_v_f16mf2(_Float16 *, vuint64m2_t, vfloat16mf2_t, vfloat16mf2_t, vfloat16mf2_t, vfloat16mf2_t, vfloat16mf2_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vsoxseg5ei64_v_m)))
void vsoxseg5ei64_v_f16mf2_m(vbool32_t, _Float16 *, vuint64m2_t, vfloat16mf2_t, vfloat16mf2_t, vfloat16mf2_t, vfloat16mf2_t, vfloat16mf2_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vsoxseg5ei64_v)))
void vsoxseg5ei64_v_f16mf4(_Float16 *, vuint64m1_t, vfloat16mf4_t, vfloat16mf4_t, vfloat16mf4_t, vfloat16mf4_t, vfloat16mf4_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vsoxseg5ei64_v_m)))
void vsoxseg5ei64_v_f16mf4_m(vbool64_t, _Float16 *, vuint64m1_t, vfloat16mf4_t, vfloat16mf4_t, vfloat16mf4_t, vfloat16mf4_t, vfloat16mf4_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vsoxseg6ei64_v)))
void vsoxseg6ei64_v_f16m1(_Float16 *, vuint64m4_t, vfloat16m1_t, vfloat16m1_t, vfloat16m1_t, vfloat16m1_t, vfloat16m1_t, vfloat16m1_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vsoxseg6ei64_v_m)))
void vsoxseg6ei64_v_f16m1_m(vbool16_t, _Float16 *, vuint64m4_t, vfloat16m1_t, vfloat16m1_t, vfloat16m1_t, vfloat16m1_t, vfloat16m1_t, vfloat16m1_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vsoxseg6ei64_v)))
void vsoxseg6ei64_v_f16mf2(_Float16 *, vuint64m2_t, vfloat16mf2_t, vfloat16mf2_t, vfloat16mf2_t, vfloat16mf2_t, vfloat16mf2_t, vfloat16mf2_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vsoxseg6ei64_v_m)))
void vsoxseg6ei64_v_f16mf2_m(vbool32_t, _Float16 *, vuint64m2_t, vfloat16mf2_t, vfloat16mf2_t, vfloat16mf2_t, vfloat16mf2_t, vfloat16mf2_t, vfloat16mf2_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vsoxseg6ei64_v)))
void vsoxseg6ei64_v_f16mf4(_Float16 *, vuint64m1_t, vfloat16mf4_t, vfloat16mf4_t, vfloat16mf4_t, vfloat16mf4_t, vfloat16mf4_t, vfloat16mf4_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vsoxseg6ei64_v_m)))
void vsoxseg6ei64_v_f16mf4_m(vbool64_t, _Float16 *, vuint64m1_t, vfloat16mf4_t, vfloat16mf4_t, vfloat16mf4_t, vfloat16mf4_t, vfloat16mf4_t, vfloat16mf4_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vsoxseg7ei64_v)))
void vsoxseg7ei64_v_f16m1(_Float16 *, vuint64m4_t, vfloat16m1_t, vfloat16m1_t, vfloat16m1_t, vfloat16m1_t, vfloat16m1_t, vfloat16m1_t, vfloat16m1_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vsoxseg7ei64_v_m)))
void vsoxseg7ei64_v_f16m1_m(vbool16_t, _Float16 *, vuint64m4_t, vfloat16m1_t, vfloat16m1_t, vfloat16m1_t, vfloat16m1_t, vfloat16m1_t, vfloat16m1_t, vfloat16m1_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vsoxseg7ei64_v)))
void vsoxseg7ei64_v_f16mf2(_Float16 *, vuint64m2_t, vfloat16mf2_t, vfloat16mf2_t, vfloat16mf2_t, vfloat16mf2_t, vfloat16mf2_t, vfloat16mf2_t, vfloat16mf2_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vsoxseg7ei64_v_m)))
void vsoxseg7ei64_v_f16mf2_m(vbool32_t, _Float16 *, vuint64m2_t, vfloat16mf2_t, vfloat16mf2_t, vfloat16mf2_t, vfloat16mf2_t, vfloat16mf2_t, vfloat16mf2_t, vfloat16mf2_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vsoxseg7ei64_v)))
void vsoxseg7ei64_v_f16mf4(_Float16 *, vuint64m1_t, vfloat16mf4_t, vfloat16mf4_t, vfloat16mf4_t, vfloat16mf4_t, vfloat16mf4_t, vfloat16mf4_t, vfloat16mf4_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vsoxseg7ei64_v_m)))
void vsoxseg7ei64_v_f16mf4_m(vbool64_t, _Float16 *, vuint64m1_t, vfloat16mf4_t, vfloat16mf4_t, vfloat16mf4_t, vfloat16mf4_t, vfloat16mf4_t, vfloat16mf4_t, vfloat16mf4_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vsoxseg8ei64_v)))
void vsoxseg8ei64_v_f16m1(_Float16 *, vuint64m4_t, vfloat16m1_t, vfloat16m1_t, vfloat16m1_t, vfloat16m1_t, vfloat16m1_t, vfloat16m1_t, vfloat16m1_t, vfloat16m1_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vsoxseg8ei64_v_m)))
void vsoxseg8ei64_v_f16m1_m(vbool16_t, _Float16 *, vuint64m4_t, vfloat16m1_t, vfloat16m1_t, vfloat16m1_t, vfloat16m1_t, vfloat16m1_t, vfloat16m1_t, vfloat16m1_t, vfloat16m1_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vsoxseg8ei64_v)))
void vsoxseg8ei64_v_f16mf2(_Float16 *, vuint64m2_t, vfloat16mf2_t, vfloat16mf2_t, vfloat16mf2_t, vfloat16mf2_t, vfloat16mf2_t, vfloat16mf2_t, vfloat16mf2_t, vfloat16mf2_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vsoxseg8ei64_v_m)))
void vsoxseg8ei64_v_f16mf2_m(vbool32_t, _Float16 *, vuint64m2_t, vfloat16mf2_t, vfloat16mf2_t, vfloat16mf2_t, vfloat16mf2_t, vfloat16mf2_t, vfloat16mf2_t, vfloat16mf2_t, vfloat16mf2_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vsoxseg8ei64_v)))
void vsoxseg8ei64_v_f16mf4(_Float16 *, vuint64m1_t, vfloat16mf4_t, vfloat16mf4_t, vfloat16mf4_t, vfloat16mf4_t, vfloat16mf4_t, vfloat16mf4_t, vfloat16mf4_t, vfloat16mf4_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vsoxseg8ei64_v_m)))
void vsoxseg8ei64_v_f16mf4_m(vbool64_t, _Float16 *, vuint64m1_t, vfloat16mf4_t, vfloat16mf4_t, vfloat16mf4_t, vfloat16mf4_t, vfloat16mf4_t, vfloat16mf4_t, vfloat16mf4_t, vfloat16mf4_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vluxseg2ei64_v)))
void vluxseg2ei64_v_f16m1(vfloat16m1_t *, vfloat16m1_t *, const _Float16 *, vuint64m4_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vluxseg2ei64_v_m)))
void vluxseg2ei64_v_f16m1_m(vfloat16m1_t *, vfloat16m1_t *, vbool16_t, vfloat16m1_t, vfloat16m1_t, const _Float16 *, vuint64m4_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vluxseg2ei64_v)))
void vluxseg2ei64_v_f16m2(vfloat16m2_t *, vfloat16m2_t *, const _Float16 *, vuint64m8_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vluxseg2ei64_v_m)))
void vluxseg2ei64_v_f16m2_m(vfloat16m2_t *, vfloat16m2_t *, vbool8_t, vfloat16m2_t, vfloat16m2_t, const _Float16 *, vuint64m8_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vluxseg2ei64_v)))
void vluxseg2ei64_v_f16mf2(vfloat16mf2_t *, vfloat16mf2_t *, const _Float16 *, vuint64m2_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vluxseg2ei64_v_m)))
void vluxseg2ei64_v_f16mf2_m(vfloat16mf2_t *, vfloat16mf2_t *, vbool32_t, vfloat16mf2_t, vfloat16mf2_t, const _Float16 *, vuint64m2_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vluxseg2ei64_v)))
void vluxseg2ei64_v_f16mf4(vfloat16mf4_t *, vfloat16mf4_t *, const _Float16 *, vuint64m1_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vluxseg2ei64_v_m)))
void vluxseg2ei64_v_f16mf4_m(vfloat16mf4_t *, vfloat16mf4_t *, vbool64_t, vfloat16mf4_t, vfloat16mf4_t, const _Float16 *, vuint64m1_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vluxseg3ei64_v)))
void vluxseg3ei64_v_f16m1(vfloat16m1_t *, vfloat16m1_t *, vfloat16m1_t *, const _Float16 *, vuint64m4_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vluxseg3ei64_v_m)))
void vluxseg3ei64_v_f16m1_m(vfloat16m1_t *, vfloat16m1_t *, vfloat16m1_t *, vbool16_t, vfloat16m1_t, vfloat16m1_t, vfloat16m1_t, const _Float16 *, vuint64m4_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vluxseg3ei64_v)))
void vluxseg3ei64_v_f16m2(vfloat16m2_t *, vfloat16m2_t *, vfloat16m2_t *, const _Float16 *, vuint64m8_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vluxseg3ei64_v_m)))
void vluxseg3ei64_v_f16m2_m(vfloat16m2_t *, vfloat16m2_t *, vfloat16m2_t *, vbool8_t, vfloat16m2_t, vfloat16m2_t, vfloat16m2_t, const _Float16 *, vuint64m8_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vluxseg3ei64_v)))
void vluxseg3ei64_v_f16mf2(vfloat16mf2_t *, vfloat16mf2_t *, vfloat16mf2_t *, const _Float16 *, vuint64m2_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vluxseg3ei64_v_m)))
void vluxseg3ei64_v_f16mf2_m(vfloat16mf2_t *, vfloat16mf2_t *, vfloat16mf2_t *, vbool32_t, vfloat16mf2_t, vfloat16mf2_t, vfloat16mf2_t, const _Float16 *, vuint64m2_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vluxseg3ei64_v)))
void vluxseg3ei64_v_f16mf4(vfloat16mf4_t *, vfloat16mf4_t *, vfloat16mf4_t *, const _Float16 *, vuint64m1_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vluxseg3ei64_v_m)))
void vluxseg3ei64_v_f16mf4_m(vfloat16mf4_t *, vfloat16mf4_t *, vfloat16mf4_t *, vbool64_t, vfloat16mf4_t, vfloat16mf4_t, vfloat16mf4_t, const _Float16 *, vuint64m1_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vluxseg4ei64_v)))
void vluxseg4ei64_v_f16m1(vfloat16m1_t *, vfloat16m1_t *, vfloat16m1_t *, vfloat16m1_t *, const _Float16 *, vuint64m4_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vluxseg4ei64_v_m)))
void vluxseg4ei64_v_f16m1_m(vfloat16m1_t *, vfloat16m1_t *, vfloat16m1_t *, vfloat16m1_t *, vbool16_t, vfloat16m1_t, vfloat16m1_t, vfloat16m1_t, vfloat16m1_t, const _Float16 *, vuint64m4_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vluxseg4ei64_v)))
void vluxseg4ei64_v_f16m2(vfloat16m2_t *, vfloat16m2_t *, vfloat16m2_t *, vfloat16m2_t *, const _Float16 *, vuint64m8_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vluxseg4ei64_v_m)))
void vluxseg4ei64_v_f16m2_m(vfloat16m2_t *, vfloat16m2_t *, vfloat16m2_t *, vfloat16m2_t *, vbool8_t, vfloat16m2_t, vfloat16m2_t, vfloat16m2_t, vfloat16m2_t, const _Float16 *, vuint64m8_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vluxseg4ei64_v)))
void vluxseg4ei64_v_f16mf2(vfloat16mf2_t *, vfloat16mf2_t *, vfloat16mf2_t *, vfloat16mf2_t *, const _Float16 *, vuint64m2_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vluxseg4ei64_v_m)))
void vluxseg4ei64_v_f16mf2_m(vfloat16mf2_t *, vfloat16mf2_t *, vfloat16mf2_t *, vfloat16mf2_t *, vbool32_t, vfloat16mf2_t, vfloat16mf2_t, vfloat16mf2_t, vfloat16mf2_t, const _Float16 *, vuint64m2_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vluxseg4ei64_v)))
void vluxseg4ei64_v_f16mf4(vfloat16mf4_t *, vfloat16mf4_t *, vfloat16mf4_t *, vfloat16mf4_t *, const _Float16 *, vuint64m1_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vluxseg4ei64_v_m)))
void vluxseg4ei64_v_f16mf4_m(vfloat16mf4_t *, vfloat16mf4_t *, vfloat16mf4_t *, vfloat16mf4_t *, vbool64_t, vfloat16mf4_t, vfloat16mf4_t, vfloat16mf4_t, vfloat16mf4_t, const _Float16 *, vuint64m1_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vluxseg5ei64_v)))
void vluxseg5ei64_v_f16m1(vfloat16m1_t *, vfloat16m1_t *, vfloat16m1_t *, vfloat16m1_t *, vfloat16m1_t *, const _Float16 *, vuint64m4_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vluxseg5ei64_v_m)))
void vluxseg5ei64_v_f16m1_m(vfloat16m1_t *, vfloat16m1_t *, vfloat16m1_t *, vfloat16m1_t *, vfloat16m1_t *, vbool16_t, vfloat16m1_t, vfloat16m1_t, vfloat16m1_t, vfloat16m1_t, vfloat16m1_t, const _Float16 *, vuint64m4_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vluxseg5ei64_v)))
void vluxseg5ei64_v_f16mf2(vfloat16mf2_t *, vfloat16mf2_t *, vfloat16mf2_t *, vfloat16mf2_t *, vfloat16mf2_t *, const _Float16 *, vuint64m2_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vluxseg5ei64_v_m)))
void vluxseg5ei64_v_f16mf2_m(vfloat16mf2_t *, vfloat16mf2_t *, vfloat16mf2_t *, vfloat16mf2_t *, vfloat16mf2_t *, vbool32_t, vfloat16mf2_t, vfloat16mf2_t, vfloat16mf2_t, vfloat16mf2_t, vfloat16mf2_t, const _Float16 *, vuint64m2_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vluxseg5ei64_v)))
void vluxseg5ei64_v_f16mf4(vfloat16mf4_t *, vfloat16mf4_t *, vfloat16mf4_t *, vfloat16mf4_t *, vfloat16mf4_t *, const _Float16 *, vuint64m1_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vluxseg5ei64_v_m)))
void vluxseg5ei64_v_f16mf4_m(vfloat16mf4_t *, vfloat16mf4_t *, vfloat16mf4_t *, vfloat16mf4_t *, vfloat16mf4_t *, vbool64_t, vfloat16mf4_t, vfloat16mf4_t, vfloat16mf4_t, vfloat16mf4_t, vfloat16mf4_t, const _Float16 *, vuint64m1_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vluxseg6ei64_v)))
void vluxseg6ei64_v_f16m1(vfloat16m1_t *, vfloat16m1_t *, vfloat16m1_t *, vfloat16m1_t *, vfloat16m1_t *, vfloat16m1_t *, const _Float16 *, vuint64m4_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vluxseg6ei64_v_m)))
void vluxseg6ei64_v_f16m1_m(vfloat16m1_t *, vfloat16m1_t *, vfloat16m1_t *, vfloat16m1_t *, vfloat16m1_t *, vfloat16m1_t *, vbool16_t, vfloat16m1_t, vfloat16m1_t, vfloat16m1_t, vfloat16m1_t, vfloat16m1_t, vfloat16m1_t, const _Float16 *, vuint64m4_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vluxseg6ei64_v)))
void vluxseg6ei64_v_f16mf2(vfloat16mf2_t *, vfloat16mf2_t *, vfloat16mf2_t *, vfloat16mf2_t *, vfloat16mf2_t *, vfloat16mf2_t *, const _Float16 *, vuint64m2_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vluxseg6ei64_v_m)))
void vluxseg6ei64_v_f16mf2_m(vfloat16mf2_t *, vfloat16mf2_t *, vfloat16mf2_t *, vfloat16mf2_t *, vfloat16mf2_t *, vfloat16mf2_t *, vbool32_t, vfloat16mf2_t, vfloat16mf2_t, vfloat16mf2_t, vfloat16mf2_t, vfloat16mf2_t, vfloat16mf2_t, const _Float16 *, vuint64m2_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vluxseg6ei64_v)))
void vluxseg6ei64_v_f16mf4(vfloat16mf4_t *, vfloat16mf4_t *, vfloat16mf4_t *, vfloat16mf4_t *, vfloat16mf4_t *, vfloat16mf4_t *, const _Float16 *, vuint64m1_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vluxseg6ei64_v_m)))
void vluxseg6ei64_v_f16mf4_m(vfloat16mf4_t *, vfloat16mf4_t *, vfloat16mf4_t *, vfloat16mf4_t *, vfloat16mf4_t *, vfloat16mf4_t *, vbool64_t, vfloat16mf4_t, vfloat16mf4_t, vfloat16mf4_t, vfloat16mf4_t, vfloat16mf4_t, vfloat16mf4_t, const _Float16 *, vuint64m1_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vluxseg7ei64_v)))
void vluxseg7ei64_v_f16m1(vfloat16m1_t *, vfloat16m1_t *, vfloat16m1_t *, vfloat16m1_t *, vfloat16m1_t *, vfloat16m1_t *, vfloat16m1_t *, const _Float16 *, vuint64m4_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vluxseg7ei64_v_m)))
void vluxseg7ei64_v_f16m1_m(vfloat16m1_t *, vfloat16m1_t *, vfloat16m1_t *, vfloat16m1_t *, vfloat16m1_t *, vfloat16m1_t *, vfloat16m1_t *, vbool16_t, vfloat16m1_t, vfloat16m1_t, vfloat16m1_t, vfloat16m1_t, vfloat16m1_t, vfloat16m1_t, vfloat16m1_t, const _Float16 *, vuint64m4_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vluxseg7ei64_v)))
void vluxseg7ei64_v_f16mf2(vfloat16mf2_t *, vfloat16mf2_t *, vfloat16mf2_t *, vfloat16mf2_t *, vfloat16mf2_t *, vfloat16mf2_t *, vfloat16mf2_t *, const _Float16 *, vuint64m2_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vluxseg7ei64_v_m)))
void vluxseg7ei64_v_f16mf2_m(vfloat16mf2_t *, vfloat16mf2_t *, vfloat16mf2_t *, vfloat16mf2_t *, vfloat16mf2_t *, vfloat16mf2_t *, vfloat16mf2_t *, vbool32_t, vfloat16mf2_t, vfloat16mf2_t, vfloat16mf2_t, vfloat16mf2_t, vfloat16mf2_t, vfloat16mf2_t, vfloat16mf2_t, const _Float16 *, vuint64m2_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vluxseg7ei64_v)))
void vluxseg7ei64_v_f16mf4(vfloat16mf4_t *, vfloat16mf4_t *, vfloat16mf4_t *, vfloat16mf4_t *, vfloat16mf4_t *, vfloat16mf4_t *, vfloat16mf4_t *, const _Float16 *, vuint64m1_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vluxseg7ei64_v_m)))
void vluxseg7ei64_v_f16mf4_m(vfloat16mf4_t *, vfloat16mf4_t *, vfloat16mf4_t *, vfloat16mf4_t *, vfloat16mf4_t *, vfloat16mf4_t *, vfloat16mf4_t *, vbool64_t, vfloat16mf4_t, vfloat16mf4_t, vfloat16mf4_t, vfloat16mf4_t, vfloat16mf4_t, vfloat16mf4_t, vfloat16mf4_t, const _Float16 *, vuint64m1_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vluxseg8ei64_v)))
void vluxseg8ei64_v_f16m1(vfloat16m1_t *, vfloat16m1_t *, vfloat16m1_t *, vfloat16m1_t *, vfloat16m1_t *, vfloat16m1_t *, vfloat16m1_t *, vfloat16m1_t *, const _Float16 *, vuint64m4_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vluxseg8ei64_v_m)))
void vluxseg8ei64_v_f16m1_m(vfloat16m1_t *, vfloat16m1_t *, vfloat16m1_t *, vfloat16m1_t *, vfloat16m1_t *, vfloat16m1_t *, vfloat16m1_t *, vfloat16m1_t *, vbool16_t, vfloat16m1_t, vfloat16m1_t, vfloat16m1_t, vfloat16m1_t, vfloat16m1_t, vfloat16m1_t, vfloat16m1_t, vfloat16m1_t, const _Float16 *, vuint64m4_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vluxseg8ei64_v)))
void vluxseg8ei64_v_f16mf2(vfloat16mf2_t *, vfloat16mf2_t *, vfloat16mf2_t *, vfloat16mf2_t *, vfloat16mf2_t *, vfloat16mf2_t *, vfloat16mf2_t *, vfloat16mf2_t *, const _Float16 *, vuint64m2_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vluxseg8ei64_v_m)))
void vluxseg8ei64_v_f16mf2_m(vfloat16mf2_t *, vfloat16mf2_t *, vfloat16mf2_t *, vfloat16mf2_t *, vfloat16mf2_t *, vfloat16mf2_t *, vfloat16mf2_t *, vfloat16mf2_t *, vbool32_t, vfloat16mf2_t, vfloat16mf2_t, vfloat16mf2_t, vfloat16mf2_t, vfloat16mf2_t, vfloat16mf2_t, vfloat16mf2_t, vfloat16mf2_t, const _Float16 *, vuint64m2_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vluxseg8ei64_v)))
void vluxseg8ei64_v_f16mf4(vfloat16mf4_t *, vfloat16mf4_t *, vfloat16mf4_t *, vfloat16mf4_t *, vfloat16mf4_t *, vfloat16mf4_t *, vfloat16mf4_t *, vfloat16mf4_t *, const _Float16 *, vuint64m1_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vluxseg8ei64_v_m)))
void vluxseg8ei64_v_f16mf4_m(vfloat16mf4_t *, vfloat16mf4_t *, vfloat16mf4_t *, vfloat16mf4_t *, vfloat16mf4_t *, vfloat16mf4_t *, vfloat16mf4_t *, vfloat16mf4_t *, vbool64_t, vfloat16mf4_t, vfloat16mf4_t, vfloat16mf4_t, vfloat16mf4_t, vfloat16mf4_t, vfloat16mf4_t, vfloat16mf4_t, vfloat16mf4_t, const _Float16 *, vuint64m1_t, size_t);
#endif

#if (__riscv_xlen == 64) && (__riscv_v_elen >= 64)
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vluxei64_v)))
vint8m1_t vluxei64_v_i8m1(const int8_t *, vuint64m8_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vluxei64_v_m)))
vint8m1_t vluxei64_v_i8m1_m(vbool8_t, vint8m1_t, const int8_t *, vuint64m8_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vluxei64_v)))
vint8mf2_t vluxei64_v_i8mf2(const int8_t *, vuint64m4_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vluxei64_v_m)))
vint8mf2_t vluxei64_v_i8mf2_m(vbool16_t, vint8mf2_t, const int8_t *, vuint64m4_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vluxei64_v)))
vint8mf4_t vluxei64_v_i8mf4(const int8_t *, vuint64m2_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vluxei64_v_m)))
vint8mf4_t vluxei64_v_i8mf4_m(vbool32_t, vint8mf4_t, const int8_t *, vuint64m2_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vluxei64_v)))
vint8mf8_t vluxei64_v_i8mf8(const int8_t *, vuint64m1_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vluxei64_v_m)))
vint8mf8_t vluxei64_v_i8mf8_m(vbool64_t, vint8mf8_t, const int8_t *, vuint64m1_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vluxei64_v)))
vuint8m1_t vluxei64_v_u8m1(const uint8_t *, vuint64m8_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vluxei64_v_m)))
vuint8m1_t vluxei64_v_u8m1_m(vbool8_t, vuint8m1_t, const uint8_t *, vuint64m8_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vluxei64_v)))
vuint8mf2_t vluxei64_v_u8mf2(const uint8_t *, vuint64m4_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vluxei64_v_m)))
vuint8mf2_t vluxei64_v_u8mf2_m(vbool16_t, vuint8mf2_t, const uint8_t *, vuint64m4_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vluxei64_v)))
vuint8mf4_t vluxei64_v_u8mf4(const uint8_t *, vuint64m2_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vluxei64_v_m)))
vuint8mf4_t vluxei64_v_u8mf4_m(vbool32_t, vuint8mf4_t, const uint8_t *, vuint64m2_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vluxei64_v)))
vuint8mf8_t vluxei64_v_u8mf8(const uint8_t *, vuint64m1_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vluxei64_v_m)))
vuint8mf8_t vluxei64_v_u8mf8_m(vbool64_t, vuint8mf8_t, const uint8_t *, vuint64m1_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vluxei64_v)))
vint16m1_t vluxei64_v_i16m1(const int16_t *, vuint64m4_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vluxei64_v_m)))
vint16m1_t vluxei64_v_i16m1_m(vbool16_t, vint16m1_t, const int16_t *, vuint64m4_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vluxei64_v)))
vint16m2_t vluxei64_v_i16m2(const int16_t *, vuint64m8_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vluxei64_v_m)))
vint16m2_t vluxei64_v_i16m2_m(vbool8_t, vint16m2_t, const int16_t *, vuint64m8_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vluxei64_v)))
vint16mf2_t vluxei64_v_i16mf2(const int16_t *, vuint64m2_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vluxei64_v_m)))
vint16mf2_t vluxei64_v_i16mf2_m(vbool32_t, vint16mf2_t, const int16_t *, vuint64m2_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vluxei64_v)))
vint16mf4_t vluxei64_v_i16mf4(const int16_t *, vuint64m1_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vluxei64_v_m)))
vint16mf4_t vluxei64_v_i16mf4_m(vbool64_t, vint16mf4_t, const int16_t *, vuint64m1_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vluxei64_v)))
vuint16m1_t vluxei64_v_u16m1(const uint16_t *, vuint64m4_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vluxei64_v_m)))
vuint16m1_t vluxei64_v_u16m1_m(vbool16_t, vuint16m1_t, const uint16_t *, vuint64m4_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vluxei64_v)))
vuint16m2_t vluxei64_v_u16m2(const uint16_t *, vuint64m8_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vluxei64_v_m)))
vuint16m2_t vluxei64_v_u16m2_m(vbool8_t, vuint16m2_t, const uint16_t *, vuint64m8_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vluxei64_v)))
vuint16mf2_t vluxei64_v_u16mf2(const uint16_t *, vuint64m2_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vluxei64_v_m)))
vuint16mf2_t vluxei64_v_u16mf2_m(vbool32_t, vuint16mf2_t, const uint16_t *, vuint64m2_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vluxei64_v)))
vuint16mf4_t vluxei64_v_u16mf4(const uint16_t *, vuint64m1_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vluxei64_v_m)))
vuint16mf4_t vluxei64_v_u16mf4_m(vbool64_t, vuint16mf4_t, const uint16_t *, vuint64m1_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vluxei64_v)))
vint32m1_t vluxei64_v_i32m1(const int32_t *, vuint64m2_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vluxei64_v_m)))
vint32m1_t vluxei64_v_i32m1_m(vbool32_t, vint32m1_t, const int32_t *, vuint64m2_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vluxei64_v)))
vint32m2_t vluxei64_v_i32m2(const int32_t *, vuint64m4_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vluxei64_v_m)))
vint32m2_t vluxei64_v_i32m2_m(vbool16_t, vint32m2_t, const int32_t *, vuint64m4_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vluxei64_v)))
vint32m4_t vluxei64_v_i32m4(const int32_t *, vuint64m8_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vluxei64_v_m)))
vint32m4_t vluxei64_v_i32m4_m(vbool8_t, vint32m4_t, const int32_t *, vuint64m8_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vluxei64_v)))
vint32mf2_t vluxei64_v_i32mf2(const int32_t *, vuint64m1_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vluxei64_v_m)))
vint32mf2_t vluxei64_v_i32mf2_m(vbool64_t, vint32mf2_t, const int32_t *, vuint64m1_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vluxei64_v)))
vuint32m1_t vluxei64_v_u32m1(const uint32_t *, vuint64m2_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vluxei64_v_m)))
vuint32m1_t vluxei64_v_u32m1_m(vbool32_t, vuint32m1_t, const uint32_t *, vuint64m2_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vluxei64_v)))
vuint32m2_t vluxei64_v_u32m2(const uint32_t *, vuint64m4_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vluxei64_v_m)))
vuint32m2_t vluxei64_v_u32m2_m(vbool16_t, vuint32m2_t, const uint32_t *, vuint64m4_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vluxei64_v)))
vuint32m4_t vluxei64_v_u32m4(const uint32_t *, vuint64m8_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vluxei64_v_m)))
vuint32m4_t vluxei64_v_u32m4_m(vbool8_t, vuint32m4_t, const uint32_t *, vuint64m8_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vluxei64_v)))
vuint32mf2_t vluxei64_v_u32mf2(const uint32_t *, vuint64m1_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vluxei64_v_m)))
vuint32mf2_t vluxei64_v_u32mf2_m(vbool64_t, vuint32mf2_t, const uint32_t *, vuint64m1_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vluxei64_v)))
vint64m1_t vluxei64_v_i64m1(const int64_t *, vuint64m1_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vluxei64_v_m)))
vint64m1_t vluxei64_v_i64m1_m(vbool64_t, vint64m1_t, const int64_t *, vuint64m1_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vluxei64_v)))
vint64m2_t vluxei64_v_i64m2(const int64_t *, vuint64m2_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vluxei64_v_m)))
vint64m2_t vluxei64_v_i64m2_m(vbool32_t, vint64m2_t, const int64_t *, vuint64m2_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vluxei64_v)))
vint64m4_t vluxei64_v_i64m4(const int64_t *, vuint64m4_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vluxei64_v_m)))
vint64m4_t vluxei64_v_i64m4_m(vbool16_t, vint64m4_t, const int64_t *, vuint64m4_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vluxei64_v)))
vint64m8_t vluxei64_v_i64m8(const int64_t *, vuint64m8_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vluxei64_v_m)))
vint64m8_t vluxei64_v_i64m8_m(vbool8_t, vint64m8_t, const int64_t *, vuint64m8_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vluxei64_v)))
vuint64m1_t vluxei64_v_u64m1(const uint64_t *, vuint64m1_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vluxei64_v_m)))
vuint64m1_t vluxei64_v_u64m1_m(vbool64_t, vuint64m1_t, const uint64_t *, vuint64m1_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vluxei64_v)))
vuint64m2_t vluxei64_v_u64m2(const uint64_t *, vuint64m2_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vluxei64_v_m)))
vuint64m2_t vluxei64_v_u64m2_m(vbool32_t, vuint64m2_t, const uint64_t *, vuint64m2_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vluxei64_v)))
vuint64m4_t vluxei64_v_u64m4(const uint64_t *, vuint64m4_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vluxei64_v_m)))
vuint64m4_t vluxei64_v_u64m4_m(vbool16_t, vuint64m4_t, const uint64_t *, vuint64m4_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vluxei64_v)))
vuint64m8_t vluxei64_v_u64m8(const uint64_t *, vuint64m8_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vluxei64_v_m)))
vuint64m8_t vluxei64_v_u64m8_m(vbool8_t, vuint64m8_t, const uint64_t *, vuint64m8_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vloxei64_v)))
vint8m1_t vloxei64_v_i8m1(const int8_t *, vuint64m8_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vloxei64_v_m)))
vint8m1_t vloxei64_v_i8m1_m(vbool8_t, vint8m1_t, const int8_t *, vuint64m8_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vloxei64_v)))
vint8mf2_t vloxei64_v_i8mf2(const int8_t *, vuint64m4_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vloxei64_v_m)))
vint8mf2_t vloxei64_v_i8mf2_m(vbool16_t, vint8mf2_t, const int8_t *, vuint64m4_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vloxei64_v)))
vint8mf4_t vloxei64_v_i8mf4(const int8_t *, vuint64m2_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vloxei64_v_m)))
vint8mf4_t vloxei64_v_i8mf4_m(vbool32_t, vint8mf4_t, const int8_t *, vuint64m2_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vloxei64_v)))
vint8mf8_t vloxei64_v_i8mf8(const int8_t *, vuint64m1_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vloxei64_v_m)))
vint8mf8_t vloxei64_v_i8mf8_m(vbool64_t, vint8mf8_t, const int8_t *, vuint64m1_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vloxei64_v)))
vuint8m1_t vloxei64_v_u8m1(const uint8_t *, vuint64m8_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vloxei64_v_m)))
vuint8m1_t vloxei64_v_u8m1_m(vbool8_t, vuint8m1_t, const uint8_t *, vuint64m8_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vloxei64_v)))
vuint8mf2_t vloxei64_v_u8mf2(const uint8_t *, vuint64m4_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vloxei64_v_m)))
vuint8mf2_t vloxei64_v_u8mf2_m(vbool16_t, vuint8mf2_t, const uint8_t *, vuint64m4_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vloxei64_v)))
vuint8mf4_t vloxei64_v_u8mf4(const uint8_t *, vuint64m2_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vloxei64_v_m)))
vuint8mf4_t vloxei64_v_u8mf4_m(vbool32_t, vuint8mf4_t, const uint8_t *, vuint64m2_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vloxei64_v)))
vuint8mf8_t vloxei64_v_u8mf8(const uint8_t *, vuint64m1_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vloxei64_v_m)))
vuint8mf8_t vloxei64_v_u8mf8_m(vbool64_t, vuint8mf8_t, const uint8_t *, vuint64m1_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vloxei64_v)))
vint16m1_t vloxei64_v_i16m1(const int16_t *, vuint64m4_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vloxei64_v_m)))
vint16m1_t vloxei64_v_i16m1_m(vbool16_t, vint16m1_t, const int16_t *, vuint64m4_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vloxei64_v)))
vint16m2_t vloxei64_v_i16m2(const int16_t *, vuint64m8_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vloxei64_v_m)))
vint16m2_t vloxei64_v_i16m2_m(vbool8_t, vint16m2_t, const int16_t *, vuint64m8_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vloxei64_v)))
vint16mf2_t vloxei64_v_i16mf2(const int16_t *, vuint64m2_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vloxei64_v_m)))
vint16mf2_t vloxei64_v_i16mf2_m(vbool32_t, vint16mf2_t, const int16_t *, vuint64m2_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vloxei64_v)))
vint16mf4_t vloxei64_v_i16mf4(const int16_t *, vuint64m1_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vloxei64_v_m)))
vint16mf4_t vloxei64_v_i16mf4_m(vbool64_t, vint16mf4_t, const int16_t *, vuint64m1_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vloxei64_v)))
vuint16m1_t vloxei64_v_u16m1(const uint16_t *, vuint64m4_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vloxei64_v_m)))
vuint16m1_t vloxei64_v_u16m1_m(vbool16_t, vuint16m1_t, const uint16_t *, vuint64m4_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vloxei64_v)))
vuint16m2_t vloxei64_v_u16m2(const uint16_t *, vuint64m8_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vloxei64_v_m)))
vuint16m2_t vloxei64_v_u16m2_m(vbool8_t, vuint16m2_t, const uint16_t *, vuint64m8_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vloxei64_v)))
vuint16mf2_t vloxei64_v_u16mf2(const uint16_t *, vuint64m2_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vloxei64_v_m)))
vuint16mf2_t vloxei64_v_u16mf2_m(vbool32_t, vuint16mf2_t, const uint16_t *, vuint64m2_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vloxei64_v)))
vuint16mf4_t vloxei64_v_u16mf4(const uint16_t *, vuint64m1_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vloxei64_v_m)))
vuint16mf4_t vloxei64_v_u16mf4_m(vbool64_t, vuint16mf4_t, const uint16_t *, vuint64m1_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vloxei64_v)))
vint32m1_t vloxei64_v_i32m1(const int32_t *, vuint64m2_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vloxei64_v_m)))
vint32m1_t vloxei64_v_i32m1_m(vbool32_t, vint32m1_t, const int32_t *, vuint64m2_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vloxei64_v)))
vint32m2_t vloxei64_v_i32m2(const int32_t *, vuint64m4_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vloxei64_v_m)))
vint32m2_t vloxei64_v_i32m2_m(vbool16_t, vint32m2_t, const int32_t *, vuint64m4_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vloxei64_v)))
vint32m4_t vloxei64_v_i32m4(const int32_t *, vuint64m8_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vloxei64_v_m)))
vint32m4_t vloxei64_v_i32m4_m(vbool8_t, vint32m4_t, const int32_t *, vuint64m8_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vloxei64_v)))
vint32mf2_t vloxei64_v_i32mf2(const int32_t *, vuint64m1_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vloxei64_v_m)))
vint32mf2_t vloxei64_v_i32mf2_m(vbool64_t, vint32mf2_t, const int32_t *, vuint64m1_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vloxei64_v)))
vuint32m1_t vloxei64_v_u32m1(const uint32_t *, vuint64m2_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vloxei64_v_m)))
vuint32m1_t vloxei64_v_u32m1_m(vbool32_t, vuint32m1_t, const uint32_t *, vuint64m2_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vloxei64_v)))
vuint32m2_t vloxei64_v_u32m2(const uint32_t *, vuint64m4_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vloxei64_v_m)))
vuint32m2_t vloxei64_v_u32m2_m(vbool16_t, vuint32m2_t, const uint32_t *, vuint64m4_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vloxei64_v)))
vuint32m4_t vloxei64_v_u32m4(const uint32_t *, vuint64m8_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vloxei64_v_m)))
vuint32m4_t vloxei64_v_u32m4_m(vbool8_t, vuint32m4_t, const uint32_t *, vuint64m8_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vloxei64_v)))
vuint32mf2_t vloxei64_v_u32mf2(const uint32_t *, vuint64m1_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vloxei64_v_m)))
vuint32mf2_t vloxei64_v_u32mf2_m(vbool64_t, vuint32mf2_t, const uint32_t *, vuint64m1_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vloxei64_v)))
vint64m1_t vloxei64_v_i64m1(const int64_t *, vuint64m1_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vloxei64_v_m)))
vint64m1_t vloxei64_v_i64m1_m(vbool64_t, vint64m1_t, const int64_t *, vuint64m1_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vloxei64_v)))
vint64m2_t vloxei64_v_i64m2(const int64_t *, vuint64m2_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vloxei64_v_m)))
vint64m2_t vloxei64_v_i64m2_m(vbool32_t, vint64m2_t, const int64_t *, vuint64m2_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vloxei64_v)))
vint64m4_t vloxei64_v_i64m4(const int64_t *, vuint64m4_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vloxei64_v_m)))
vint64m4_t vloxei64_v_i64m4_m(vbool16_t, vint64m4_t, const int64_t *, vuint64m4_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vloxei64_v)))
vint64m8_t vloxei64_v_i64m8(const int64_t *, vuint64m8_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vloxei64_v_m)))
vint64m8_t vloxei64_v_i64m8_m(vbool8_t, vint64m8_t, const int64_t *, vuint64m8_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vloxei64_v)))
vuint64m1_t vloxei64_v_u64m1(const uint64_t *, vuint64m1_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vloxei64_v_m)))
vuint64m1_t vloxei64_v_u64m1_m(vbool64_t, vuint64m1_t, const uint64_t *, vuint64m1_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vloxei64_v)))
vuint64m2_t vloxei64_v_u64m2(const uint64_t *, vuint64m2_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vloxei64_v_m)))
vuint64m2_t vloxei64_v_u64m2_m(vbool32_t, vuint64m2_t, const uint64_t *, vuint64m2_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vloxei64_v)))
vuint64m4_t vloxei64_v_u64m4(const uint64_t *, vuint64m4_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vloxei64_v_m)))
vuint64m4_t vloxei64_v_u64m4_m(vbool16_t, vuint64m4_t, const uint64_t *, vuint64m4_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vloxei64_v)))
vuint64m8_t vloxei64_v_u64m8(const uint64_t *, vuint64m8_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vloxei64_v_m)))
vuint64m8_t vloxei64_v_u64m8_m(vbool8_t, vuint64m8_t, const uint64_t *, vuint64m8_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vsuxei64_v)))
void vsuxei64_v_i16m1(int16_t *, vuint64m4_t, vint16m1_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vsuxei64_v_m)))
void vsuxei64_v_i16m1_m(vbool16_t, int16_t *, vuint64m4_t, vint16m1_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vsuxei64_v)))
void vsuxei64_v_i16m2(int16_t *, vuint64m8_t, vint16m2_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vsuxei64_v_m)))
void vsuxei64_v_i16m2_m(vbool8_t, int16_t *, vuint64m8_t, vint16m2_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vsuxei64_v)))
void vsuxei64_v_i16mf2(int16_t *, vuint64m2_t, vint16mf2_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vsuxei64_v_m)))
void vsuxei64_v_i16mf2_m(vbool32_t, int16_t *, vuint64m2_t, vint16mf2_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vsuxei64_v)))
void vsuxei64_v_i16mf4(int16_t *, vuint64m1_t, vint16mf4_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vsuxei64_v_m)))
void vsuxei64_v_i16mf4_m(vbool64_t, int16_t *, vuint64m1_t, vint16mf4_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vsuxei64_v)))
void vsuxei64_v_u16m1(uint16_t *, vuint64m4_t, vuint16m1_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vsuxei64_v_m)))
void vsuxei64_v_u16m1_m(vbool16_t, uint16_t *, vuint64m4_t, vuint16m1_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vsuxei64_v)))
void vsuxei64_v_u16m2(uint16_t *, vuint64m8_t, vuint16m2_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vsuxei64_v_m)))
void vsuxei64_v_u16m2_m(vbool8_t, uint16_t *, vuint64m8_t, vuint16m2_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vsuxei64_v)))
void vsuxei64_v_u16mf2(uint16_t *, vuint64m2_t, vuint16mf2_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vsuxei64_v_m)))
void vsuxei64_v_u16mf2_m(vbool32_t, uint16_t *, vuint64m2_t, vuint16mf2_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vsuxei64_v)))
void vsuxei64_v_u16mf4(uint16_t *, vuint64m1_t, vuint16mf4_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vsuxei64_v_m)))
void vsuxei64_v_u16mf4_m(vbool64_t, uint16_t *, vuint64m1_t, vuint16mf4_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vsuxei64_v)))
void vsuxei64_v_i32m1(int32_t *, vuint64m2_t, vint32m1_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vsuxei64_v_m)))
void vsuxei64_v_i32m1_m(vbool32_t, int32_t *, vuint64m2_t, vint32m1_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vsuxei64_v)))
void vsuxei64_v_i32m2(int32_t *, vuint64m4_t, vint32m2_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vsuxei64_v_m)))
void vsuxei64_v_i32m2_m(vbool16_t, int32_t *, vuint64m4_t, vint32m2_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vsuxei64_v)))
void vsuxei64_v_i32m4(int32_t *, vuint64m8_t, vint32m4_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vsuxei64_v_m)))
void vsuxei64_v_i32m4_m(vbool8_t, int32_t *, vuint64m8_t, vint32m4_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vsuxei64_v)))
void vsuxei64_v_i32mf2(int32_t *, vuint64m1_t, vint32mf2_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vsuxei64_v_m)))
void vsuxei64_v_i32mf2_m(vbool64_t, int32_t *, vuint64m1_t, vint32mf2_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vsuxei64_v)))
void vsuxei64_v_u32m1(uint32_t *, vuint64m2_t, vuint32m1_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vsuxei64_v_m)))
void vsuxei64_v_u32m1_m(vbool32_t, uint32_t *, vuint64m2_t, vuint32m1_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vsuxei64_v)))
void vsuxei64_v_u32m2(uint32_t *, vuint64m4_t, vuint32m2_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vsuxei64_v_m)))
void vsuxei64_v_u32m2_m(vbool16_t, uint32_t *, vuint64m4_t, vuint32m2_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vsuxei64_v)))
void vsuxei64_v_u32m4(uint32_t *, vuint64m8_t, vuint32m4_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vsuxei64_v_m)))
void vsuxei64_v_u32m4_m(vbool8_t, uint32_t *, vuint64m8_t, vuint32m4_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vsuxei64_v)))
void vsuxei64_v_u32mf2(uint32_t *, vuint64m1_t, vuint32mf2_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vsuxei64_v_m)))
void vsuxei64_v_u32mf2_m(vbool64_t, uint32_t *, vuint64m1_t, vuint32mf2_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vsuxei64_v)))
void vsuxei64_v_i64m1(int64_t *, vuint64m1_t, vint64m1_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vsuxei64_v_m)))
void vsuxei64_v_i64m1_m(vbool64_t, int64_t *, vuint64m1_t, vint64m1_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vsuxei64_v)))
void vsuxei64_v_i64m2(int64_t *, vuint64m2_t, vint64m2_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vsuxei64_v_m)))
void vsuxei64_v_i64m2_m(vbool32_t, int64_t *, vuint64m2_t, vint64m2_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vsuxei64_v)))
void vsuxei64_v_i64m4(int64_t *, vuint64m4_t, vint64m4_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vsuxei64_v_m)))
void vsuxei64_v_i64m4_m(vbool16_t, int64_t *, vuint64m4_t, vint64m4_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vsuxei64_v)))
void vsuxei64_v_i64m8(int64_t *, vuint64m8_t, vint64m8_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vsuxei64_v_m)))
void vsuxei64_v_i64m8_m(vbool8_t, int64_t *, vuint64m8_t, vint64m8_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vsuxei64_v)))
void vsuxei64_v_u64m1(uint64_t *, vuint64m1_t, vuint64m1_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vsuxei64_v_m)))
void vsuxei64_v_u64m1_m(vbool64_t, uint64_t *, vuint64m1_t, vuint64m1_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vsuxei64_v)))
void vsuxei64_v_u64m2(uint64_t *, vuint64m2_t, vuint64m2_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vsuxei64_v_m)))
void vsuxei64_v_u64m2_m(vbool32_t, uint64_t *, vuint64m2_t, vuint64m2_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vsuxei64_v)))
void vsuxei64_v_u64m4(uint64_t *, vuint64m4_t, vuint64m4_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vsuxei64_v_m)))
void vsuxei64_v_u64m4_m(vbool16_t, uint64_t *, vuint64m4_t, vuint64m4_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vsuxei64_v)))
void vsuxei64_v_u64m8(uint64_t *, vuint64m8_t, vuint64m8_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vsuxei64_v_m)))
void vsuxei64_v_u64m8_m(vbool8_t, uint64_t *, vuint64m8_t, vuint64m8_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vsoxei64_v)))
void vsoxei64_v_i8m1(int8_t *, vuint64m8_t, vint8m1_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vsoxei64_v_m)))
void vsoxei64_v_i8m1_m(vbool8_t, int8_t *, vuint64m8_t, vint8m1_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vsoxei64_v)))
void vsoxei64_v_i8mf2(int8_t *, vuint64m4_t, vint8mf2_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vsoxei64_v_m)))
void vsoxei64_v_i8mf2_m(vbool16_t, int8_t *, vuint64m4_t, vint8mf2_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vsoxei64_v)))
void vsoxei64_v_i8mf4(int8_t *, vuint64m2_t, vint8mf4_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vsoxei64_v_m)))
void vsoxei64_v_i8mf4_m(vbool32_t, int8_t *, vuint64m2_t, vint8mf4_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vsoxei64_v)))
void vsoxei64_v_i8mf8(int8_t *, vuint64m1_t, vint8mf8_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vsoxei64_v_m)))
void vsoxei64_v_i8mf8_m(vbool64_t, int8_t *, vuint64m1_t, vint8mf8_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vsoxei64_v)))
void vsoxei64_v_u8m1(uint8_t *, vuint64m8_t, vuint8m1_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vsoxei64_v_m)))
void vsoxei64_v_u8m1_m(vbool8_t, uint8_t *, vuint64m8_t, vuint8m1_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vsoxei64_v)))
void vsoxei64_v_u8mf2(uint8_t *, vuint64m4_t, vuint8mf2_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vsoxei64_v_m)))
void vsoxei64_v_u8mf2_m(vbool16_t, uint8_t *, vuint64m4_t, vuint8mf2_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vsoxei64_v)))
void vsoxei64_v_u8mf4(uint8_t *, vuint64m2_t, vuint8mf4_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vsoxei64_v_m)))
void vsoxei64_v_u8mf4_m(vbool32_t, uint8_t *, vuint64m2_t, vuint8mf4_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vsoxei64_v)))
void vsoxei64_v_u8mf8(uint8_t *, vuint64m1_t, vuint8mf8_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vsoxei64_v_m)))
void vsoxei64_v_u8mf8_m(vbool64_t, uint8_t *, vuint64m1_t, vuint8mf8_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vsoxei64_v)))
void vsoxei64_v_i16m1(int16_t *, vuint64m4_t, vint16m1_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vsoxei64_v_m)))
void vsoxei64_v_i16m1_m(vbool16_t, int16_t *, vuint64m4_t, vint16m1_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vsoxei64_v)))
void vsoxei64_v_i16m2(int16_t *, vuint64m8_t, vint16m2_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vsoxei64_v_m)))
void vsoxei64_v_i16m2_m(vbool8_t, int16_t *, vuint64m8_t, vint16m2_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vsoxei64_v)))
void vsoxei64_v_i16mf2(int16_t *, vuint64m2_t, vint16mf2_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vsoxei64_v_m)))
void vsoxei64_v_i16mf2_m(vbool32_t, int16_t *, vuint64m2_t, vint16mf2_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vsoxei64_v)))
void vsoxei64_v_i16mf4(int16_t *, vuint64m1_t, vint16mf4_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vsoxei64_v_m)))
void vsoxei64_v_i16mf4_m(vbool64_t, int16_t *, vuint64m1_t, vint16mf4_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vsoxei64_v)))
void vsoxei64_v_u16m1(uint16_t *, vuint64m4_t, vuint16m1_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vsoxei64_v_m)))
void vsoxei64_v_u16m1_m(vbool16_t, uint16_t *, vuint64m4_t, vuint16m1_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vsoxei64_v)))
void vsoxei64_v_u16m2(uint16_t *, vuint64m8_t, vuint16m2_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vsoxei64_v_m)))
void vsoxei64_v_u16m2_m(vbool8_t, uint16_t *, vuint64m8_t, vuint16m2_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vsoxei64_v)))
void vsoxei64_v_u16mf2(uint16_t *, vuint64m2_t, vuint16mf2_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vsoxei64_v_m)))
void vsoxei64_v_u16mf2_m(vbool32_t, uint16_t *, vuint64m2_t, vuint16mf2_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vsoxei64_v)))
void vsoxei64_v_u16mf4(uint16_t *, vuint64m1_t, vuint16mf4_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vsoxei64_v_m)))
void vsoxei64_v_u16mf4_m(vbool64_t, uint16_t *, vuint64m1_t, vuint16mf4_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vsuxei64_v)))
void vsuxei64_v_i8m1(int8_t *, vuint64m8_t, vint8m1_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vsuxei64_v_m)))
void vsuxei64_v_i8m1_m(vbool8_t, int8_t *, vuint64m8_t, vint8m1_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vsuxei64_v)))
void vsuxei64_v_i8mf2(int8_t *, vuint64m4_t, vint8mf2_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vsuxei64_v_m)))
void vsuxei64_v_i8mf2_m(vbool16_t, int8_t *, vuint64m4_t, vint8mf2_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vsuxei64_v)))
void vsuxei64_v_i8mf4(int8_t *, vuint64m2_t, vint8mf4_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vsuxei64_v_m)))
void vsuxei64_v_i8mf4_m(vbool32_t, int8_t *, vuint64m2_t, vint8mf4_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vsuxei64_v)))
void vsuxei64_v_i8mf8(int8_t *, vuint64m1_t, vint8mf8_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vsuxei64_v_m)))
void vsuxei64_v_i8mf8_m(vbool64_t, int8_t *, vuint64m1_t, vint8mf8_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vsoxei64_v)))
void vsoxei64_v_i32m1(int32_t *, vuint64m2_t, vint32m1_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vsoxei64_v_m)))
void vsoxei64_v_i32m1_m(vbool32_t, int32_t *, vuint64m2_t, vint32m1_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vsoxei64_v)))
void vsoxei64_v_i32m2(int32_t *, vuint64m4_t, vint32m2_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vsoxei64_v_m)))
void vsoxei64_v_i32m2_m(vbool16_t, int32_t *, vuint64m4_t, vint32m2_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vsoxei64_v)))
void vsoxei64_v_i32m4(int32_t *, vuint64m8_t, vint32m4_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vsoxei64_v_m)))
void vsoxei64_v_i32m4_m(vbool8_t, int32_t *, vuint64m8_t, vint32m4_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vsoxei64_v)))
void vsoxei64_v_i32mf2(int32_t *, vuint64m1_t, vint32mf2_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vsoxei64_v_m)))
void vsoxei64_v_i32mf2_m(vbool64_t, int32_t *, vuint64m1_t, vint32mf2_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vsoxei64_v)))
void vsoxei64_v_u32m1(uint32_t *, vuint64m2_t, vuint32m1_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vsoxei64_v_m)))
void vsoxei64_v_u32m1_m(vbool32_t, uint32_t *, vuint64m2_t, vuint32m1_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vsoxei64_v)))
void vsoxei64_v_u32m2(uint32_t *, vuint64m4_t, vuint32m2_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vsoxei64_v_m)))
void vsoxei64_v_u32m2_m(vbool16_t, uint32_t *, vuint64m4_t, vuint32m2_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vsoxei64_v)))
void vsoxei64_v_u32m4(uint32_t *, vuint64m8_t, vuint32m4_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vsoxei64_v_m)))
void vsoxei64_v_u32m4_m(vbool8_t, uint32_t *, vuint64m8_t, vuint32m4_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vsoxei64_v)))
void vsoxei64_v_u32mf2(uint32_t *, vuint64m1_t, vuint32mf2_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vsoxei64_v_m)))
void vsoxei64_v_u32mf2_m(vbool64_t, uint32_t *, vuint64m1_t, vuint32mf2_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vsuxei64_v)))
void vsuxei64_v_u8m1(uint8_t *, vuint64m8_t, vuint8m1_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vsuxei64_v_m)))
void vsuxei64_v_u8m1_m(vbool8_t, uint8_t *, vuint64m8_t, vuint8m1_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vsuxei64_v)))
void vsuxei64_v_u8mf2(uint8_t *, vuint64m4_t, vuint8mf2_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vsuxei64_v_m)))
void vsuxei64_v_u8mf2_m(vbool16_t, uint8_t *, vuint64m4_t, vuint8mf2_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vsuxei64_v)))
void vsuxei64_v_u8mf4(uint8_t *, vuint64m2_t, vuint8mf4_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vsuxei64_v_m)))
void vsuxei64_v_u8mf4_m(vbool32_t, uint8_t *, vuint64m2_t, vuint8mf4_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vsuxei64_v)))
void vsuxei64_v_u8mf8(uint8_t *, vuint64m1_t, vuint8mf8_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vsuxei64_v_m)))
void vsuxei64_v_u8mf8_m(vbool64_t, uint8_t *, vuint64m1_t, vuint8mf8_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vsoxei64_v)))
void vsoxei64_v_i64m1(int64_t *, vuint64m1_t, vint64m1_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vsoxei64_v_m)))
void vsoxei64_v_i64m1_m(vbool64_t, int64_t *, vuint64m1_t, vint64m1_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vsoxei64_v)))
void vsoxei64_v_i64m2(int64_t *, vuint64m2_t, vint64m2_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vsoxei64_v_m)))
void vsoxei64_v_i64m2_m(vbool32_t, int64_t *, vuint64m2_t, vint64m2_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vsoxei64_v)))
void vsoxei64_v_i64m4(int64_t *, vuint64m4_t, vint64m4_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vsoxei64_v_m)))
void vsoxei64_v_i64m4_m(vbool16_t, int64_t *, vuint64m4_t, vint64m4_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vsoxei64_v)))
void vsoxei64_v_i64m8(int64_t *, vuint64m8_t, vint64m8_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vsoxei64_v_m)))
void vsoxei64_v_i64m8_m(vbool8_t, int64_t *, vuint64m8_t, vint64m8_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vsoxei64_v)))
void vsoxei64_v_u64m1(uint64_t *, vuint64m1_t, vuint64m1_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vsoxei64_v_m)))
void vsoxei64_v_u64m1_m(vbool64_t, uint64_t *, vuint64m1_t, vuint64m1_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vsoxei64_v)))
void vsoxei64_v_u64m2(uint64_t *, vuint64m2_t, vuint64m2_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vsoxei64_v_m)))
void vsoxei64_v_u64m2_m(vbool32_t, uint64_t *, vuint64m2_t, vuint64m2_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vsoxei64_v)))
void vsoxei64_v_u64m4(uint64_t *, vuint64m4_t, vuint64m4_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vsoxei64_v_m)))
void vsoxei64_v_u64m4_m(vbool16_t, uint64_t *, vuint64m4_t, vuint64m4_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vsoxei64_v)))
void vsoxei64_v_u64m8(uint64_t *, vuint64m8_t, vuint64m8_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vsoxei64_v_m)))
void vsoxei64_v_u64m8_m(vbool8_t, uint64_t *, vuint64m8_t, vuint64m8_t, size_t);
#endif

#if defined(__riscv_zfh) && (__riscv_xlen == 64) && (__riscv_v_elen >= 64)
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vluxei64_v)))
vfloat16m1_t vluxei64_v_f16m1(const _Float16 *, vuint64m4_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vluxei64_v_m)))
vfloat16m1_t vluxei64_v_f16m1_m(vbool16_t, vfloat16m1_t, const _Float16 *, vuint64m4_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vluxei64_v)))
vfloat16m2_t vluxei64_v_f16m2(const _Float16 *, vuint64m8_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vluxei64_v_m)))
vfloat16m2_t vluxei64_v_f16m2_m(vbool8_t, vfloat16m2_t, const _Float16 *, vuint64m8_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vluxei64_v)))
vfloat16mf2_t vluxei64_v_f16mf2(const _Float16 *, vuint64m2_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vluxei64_v_m)))
vfloat16mf2_t vluxei64_v_f16mf2_m(vbool32_t, vfloat16mf2_t, const _Float16 *, vuint64m2_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vluxei64_v)))
vfloat16mf4_t vluxei64_v_f16mf4(const _Float16 *, vuint64m1_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vluxei64_v_m)))
vfloat16mf4_t vluxei64_v_f16mf4_m(vbool64_t, vfloat16mf4_t, const _Float16 *, vuint64m1_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vloxei64_v)))
vfloat16m1_t vloxei64_v_f16m1(const _Float16 *, vuint64m4_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vloxei64_v_m)))
vfloat16m1_t vloxei64_v_f16m1_m(vbool16_t, vfloat16m1_t, const _Float16 *, vuint64m4_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vloxei64_v)))
vfloat16m2_t vloxei64_v_f16m2(const _Float16 *, vuint64m8_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vloxei64_v_m)))
vfloat16m2_t vloxei64_v_f16m2_m(vbool8_t, vfloat16m2_t, const _Float16 *, vuint64m8_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vloxei64_v)))
vfloat16mf2_t vloxei64_v_f16mf2(const _Float16 *, vuint64m2_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vloxei64_v_m)))
vfloat16mf2_t vloxei64_v_f16mf2_m(vbool32_t, vfloat16mf2_t, const _Float16 *, vuint64m2_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vloxei64_v)))
vfloat16mf4_t vloxei64_v_f16mf4(const _Float16 *, vuint64m1_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vloxei64_v_m)))
vfloat16mf4_t vloxei64_v_f16mf4_m(vbool64_t, vfloat16mf4_t, const _Float16 *, vuint64m1_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vsuxei64_v)))
void vsuxei64_v_f16m1(_Float16 *, vuint64m4_t, vfloat16m1_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vsuxei64_v_m)))
void vsuxei64_v_f16m1_m(vbool16_t, _Float16 *, vuint64m4_t, vfloat16m1_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vsuxei64_v)))
void vsuxei64_v_f16m2(_Float16 *, vuint64m8_t, vfloat16m2_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vsuxei64_v_m)))
void vsuxei64_v_f16m2_m(vbool8_t, _Float16 *, vuint64m8_t, vfloat16m2_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vsuxei64_v)))
void vsuxei64_v_f16mf2(_Float16 *, vuint64m2_t, vfloat16mf2_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vsuxei64_v_m)))
void vsuxei64_v_f16mf2_m(vbool32_t, _Float16 *, vuint64m2_t, vfloat16mf2_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vsuxei64_v)))
void vsuxei64_v_f16mf4(_Float16 *, vuint64m1_t, vfloat16mf4_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vsuxei64_v_m)))
void vsuxei64_v_f16mf4_m(vbool64_t, _Float16 *, vuint64m1_t, vfloat16mf4_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vsoxei64_v)))
void vsoxei64_v_f16m1(_Float16 *, vuint64m4_t, vfloat16m1_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vsoxei64_v_m)))
void vsoxei64_v_f16m1_m(vbool16_t, _Float16 *, vuint64m4_t, vfloat16m1_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vsoxei64_v)))
void vsoxei64_v_f16m2(_Float16 *, vuint64m8_t, vfloat16m2_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vsoxei64_v_m)))
void vsoxei64_v_f16m2_m(vbool8_t, _Float16 *, vuint64m8_t, vfloat16m2_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vsoxei64_v)))
void vsoxei64_v_f16mf2(_Float16 *, vuint64m2_t, vfloat16mf2_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vsoxei64_v_m)))
void vsoxei64_v_f16mf2_m(vbool32_t, _Float16 *, vuint64m2_t, vfloat16mf2_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vsoxei64_v)))
void vsoxei64_v_f16mf4(_Float16 *, vuint64m1_t, vfloat16mf4_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vsoxei64_v_m)))
void vsoxei64_v_f16mf4_m(vbool64_t, _Float16 *, vuint64m1_t, vfloat16mf4_t, size_t);
#endif

#if (__riscv_v_elen_fp >= 32)
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vlse32_v)))
vfloat32m1_t vlse32_v_f32m1(const float *, ptrdiff_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vlse32_v_m)))
vfloat32m1_t vlse32_v_f32m1_m(vbool32_t, vfloat32m1_t, const float *, ptrdiff_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vlse32_v)))
vfloat32m2_t vlse32_v_f32m2(const float *, ptrdiff_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vlse32_v_m)))
vfloat32m2_t vlse32_v_f32m2_m(vbool16_t, vfloat32m2_t, const float *, ptrdiff_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vlse32_v)))
vfloat32m4_t vlse32_v_f32m4(const float *, ptrdiff_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vlse32_v_m)))
vfloat32m4_t vlse32_v_f32m4_m(vbool8_t, vfloat32m4_t, const float *, ptrdiff_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vlse32_v)))
vfloat32m8_t vlse32_v_f32m8(const float *, ptrdiff_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vlse32_v_m)))
vfloat32m8_t vlse32_v_f32m8_m(vbool4_t, vfloat32m8_t, const float *, ptrdiff_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vlse32_v)))
vfloat32mf2_t vlse32_v_f32mf2(const float *, ptrdiff_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vlse32_v_m)))
vfloat32mf2_t vlse32_v_f32mf2_m(vbool64_t, vfloat32mf2_t, const float *, ptrdiff_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vloxseg2ei8_v)))
void vloxseg2ei8_v_f32m1(vfloat32m1_t *, vfloat32m1_t *, const float *, vuint8mf4_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vloxseg2ei8_v_m)))
void vloxseg2ei8_v_f32m1_m(vfloat32m1_t *, vfloat32m1_t *, vbool32_t, vfloat32m1_t, vfloat32m1_t, const float *, vuint8mf4_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vloxseg2ei8_v)))
void vloxseg2ei8_v_f32m2(vfloat32m2_t *, vfloat32m2_t *, const float *, vuint8mf2_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vloxseg2ei8_v_m)))
void vloxseg2ei8_v_f32m2_m(vfloat32m2_t *, vfloat32m2_t *, vbool16_t, vfloat32m2_t, vfloat32m2_t, const float *, vuint8mf2_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vloxseg2ei8_v)))
void vloxseg2ei8_v_f32m4(vfloat32m4_t *, vfloat32m4_t *, const float *, vuint8m1_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vloxseg2ei8_v_m)))
void vloxseg2ei8_v_f32m4_m(vfloat32m4_t *, vfloat32m4_t *, vbool8_t, vfloat32m4_t, vfloat32m4_t, const float *, vuint8m1_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vloxseg2ei8_v)))
void vloxseg2ei8_v_f32mf2(vfloat32mf2_t *, vfloat32mf2_t *, const float *, vuint8mf8_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vloxseg2ei8_v_m)))
void vloxseg2ei8_v_f32mf2_m(vfloat32mf2_t *, vfloat32mf2_t *, vbool64_t, vfloat32mf2_t, vfloat32mf2_t, const float *, vuint8mf8_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vloxseg3ei8_v)))
void vloxseg3ei8_v_f32m1(vfloat32m1_t *, vfloat32m1_t *, vfloat32m1_t *, const float *, vuint8mf4_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vloxseg3ei8_v_m)))
void vloxseg3ei8_v_f32m1_m(vfloat32m1_t *, vfloat32m1_t *, vfloat32m1_t *, vbool32_t, vfloat32m1_t, vfloat32m1_t, vfloat32m1_t, const float *, vuint8mf4_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vloxseg3ei8_v)))
void vloxseg3ei8_v_f32m2(vfloat32m2_t *, vfloat32m2_t *, vfloat32m2_t *, const float *, vuint8mf2_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vloxseg3ei8_v_m)))
void vloxseg3ei8_v_f32m2_m(vfloat32m2_t *, vfloat32m2_t *, vfloat32m2_t *, vbool16_t, vfloat32m2_t, vfloat32m2_t, vfloat32m2_t, const float *, vuint8mf2_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vloxseg3ei8_v)))
void vloxseg3ei8_v_f32mf2(vfloat32mf2_t *, vfloat32mf2_t *, vfloat32mf2_t *, const float *, vuint8mf8_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vloxseg3ei8_v_m)))
void vloxseg3ei8_v_f32mf2_m(vfloat32mf2_t *, vfloat32mf2_t *, vfloat32mf2_t *, vbool64_t, vfloat32mf2_t, vfloat32mf2_t, vfloat32mf2_t, const float *, vuint8mf8_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vloxseg4ei8_v)))
void vloxseg4ei8_v_f32m1(vfloat32m1_t *, vfloat32m1_t *, vfloat32m1_t *, vfloat32m1_t *, const float *, vuint8mf4_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vloxseg4ei8_v_m)))
void vloxseg4ei8_v_f32m1_m(vfloat32m1_t *, vfloat32m1_t *, vfloat32m1_t *, vfloat32m1_t *, vbool32_t, vfloat32m1_t, vfloat32m1_t, vfloat32m1_t, vfloat32m1_t, const float *, vuint8mf4_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vloxseg4ei8_v)))
void vloxseg4ei8_v_f32m2(vfloat32m2_t *, vfloat32m2_t *, vfloat32m2_t *, vfloat32m2_t *, const float *, vuint8mf2_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vloxseg4ei8_v_m)))
void vloxseg4ei8_v_f32m2_m(vfloat32m2_t *, vfloat32m2_t *, vfloat32m2_t *, vfloat32m2_t *, vbool16_t, vfloat32m2_t, vfloat32m2_t, vfloat32m2_t, vfloat32m2_t, const float *, vuint8mf2_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vloxseg4ei8_v)))
void vloxseg4ei8_v_f32mf2(vfloat32mf2_t *, vfloat32mf2_t *, vfloat32mf2_t *, vfloat32mf2_t *, const float *, vuint8mf8_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vloxseg4ei8_v_m)))
void vloxseg4ei8_v_f32mf2_m(vfloat32mf2_t *, vfloat32mf2_t *, vfloat32mf2_t *, vfloat32mf2_t *, vbool64_t, vfloat32mf2_t, vfloat32mf2_t, vfloat32mf2_t, vfloat32mf2_t, const float *, vuint8mf8_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vloxseg5ei8_v)))
void vloxseg5ei8_v_f32m1(vfloat32m1_t *, vfloat32m1_t *, vfloat32m1_t *, vfloat32m1_t *, vfloat32m1_t *, const float *, vuint8mf4_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vloxseg5ei8_v_m)))
void vloxseg5ei8_v_f32m1_m(vfloat32m1_t *, vfloat32m1_t *, vfloat32m1_t *, vfloat32m1_t *, vfloat32m1_t *, vbool32_t, vfloat32m1_t, vfloat32m1_t, vfloat32m1_t, vfloat32m1_t, vfloat32m1_t, const float *, vuint8mf4_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vloxseg5ei8_v)))
void vloxseg5ei8_v_f32mf2(vfloat32mf2_t *, vfloat32mf2_t *, vfloat32mf2_t *, vfloat32mf2_t *, vfloat32mf2_t *, const float *, vuint8mf8_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vloxseg5ei8_v_m)))
void vloxseg5ei8_v_f32mf2_m(vfloat32mf2_t *, vfloat32mf2_t *, vfloat32mf2_t *, vfloat32mf2_t *, vfloat32mf2_t *, vbool64_t, vfloat32mf2_t, vfloat32mf2_t, vfloat32mf2_t, vfloat32mf2_t, vfloat32mf2_t, const float *, vuint8mf8_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vloxseg6ei8_v)))
void vloxseg6ei8_v_f32m1(vfloat32m1_t *, vfloat32m1_t *, vfloat32m1_t *, vfloat32m1_t *, vfloat32m1_t *, vfloat32m1_t *, const float *, vuint8mf4_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vloxseg6ei8_v_m)))
void vloxseg6ei8_v_f32m1_m(vfloat32m1_t *, vfloat32m1_t *, vfloat32m1_t *, vfloat32m1_t *, vfloat32m1_t *, vfloat32m1_t *, vbool32_t, vfloat32m1_t, vfloat32m1_t, vfloat32m1_t, vfloat32m1_t, vfloat32m1_t, vfloat32m1_t, const float *, vuint8mf4_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vloxseg6ei8_v)))
void vloxseg6ei8_v_f32mf2(vfloat32mf2_t *, vfloat32mf2_t *, vfloat32mf2_t *, vfloat32mf2_t *, vfloat32mf2_t *, vfloat32mf2_t *, const float *, vuint8mf8_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vloxseg6ei8_v_m)))
void vloxseg6ei8_v_f32mf2_m(vfloat32mf2_t *, vfloat32mf2_t *, vfloat32mf2_t *, vfloat32mf2_t *, vfloat32mf2_t *, vfloat32mf2_t *, vbool64_t, vfloat32mf2_t, vfloat32mf2_t, vfloat32mf2_t, vfloat32mf2_t, vfloat32mf2_t, vfloat32mf2_t, const float *, vuint8mf8_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vloxseg7ei8_v)))
void vloxseg7ei8_v_f32m1(vfloat32m1_t *, vfloat32m1_t *, vfloat32m1_t *, vfloat32m1_t *, vfloat32m1_t *, vfloat32m1_t *, vfloat32m1_t *, const float *, vuint8mf4_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vloxseg7ei8_v_m)))
void vloxseg7ei8_v_f32m1_m(vfloat32m1_t *, vfloat32m1_t *, vfloat32m1_t *, vfloat32m1_t *, vfloat32m1_t *, vfloat32m1_t *, vfloat32m1_t *, vbool32_t, vfloat32m1_t, vfloat32m1_t, vfloat32m1_t, vfloat32m1_t, vfloat32m1_t, vfloat32m1_t, vfloat32m1_t, const float *, vuint8mf4_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vloxseg7ei8_v)))
void vloxseg7ei8_v_f32mf2(vfloat32mf2_t *, vfloat32mf2_t *, vfloat32mf2_t *, vfloat32mf2_t *, vfloat32mf2_t *, vfloat32mf2_t *, vfloat32mf2_t *, const float *, vuint8mf8_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vloxseg7ei8_v_m)))
void vloxseg7ei8_v_f32mf2_m(vfloat32mf2_t *, vfloat32mf2_t *, vfloat32mf2_t *, vfloat32mf2_t *, vfloat32mf2_t *, vfloat32mf2_t *, vfloat32mf2_t *, vbool64_t, vfloat32mf2_t, vfloat32mf2_t, vfloat32mf2_t, vfloat32mf2_t, vfloat32mf2_t, vfloat32mf2_t, vfloat32mf2_t, const float *, vuint8mf8_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vloxseg8ei8_v)))
void vloxseg8ei8_v_f32m1(vfloat32m1_t *, vfloat32m1_t *, vfloat32m1_t *, vfloat32m1_t *, vfloat32m1_t *, vfloat32m1_t *, vfloat32m1_t *, vfloat32m1_t *, const float *, vuint8mf4_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vloxseg8ei8_v_m)))
void vloxseg8ei8_v_f32m1_m(vfloat32m1_t *, vfloat32m1_t *, vfloat32m1_t *, vfloat32m1_t *, vfloat32m1_t *, vfloat32m1_t *, vfloat32m1_t *, vfloat32m1_t *, vbool32_t, vfloat32m1_t, vfloat32m1_t, vfloat32m1_t, vfloat32m1_t, vfloat32m1_t, vfloat32m1_t, vfloat32m1_t, vfloat32m1_t, const float *, vuint8mf4_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vloxseg8ei8_v)))
void vloxseg8ei8_v_f32mf2(vfloat32mf2_t *, vfloat32mf2_t *, vfloat32mf2_t *, vfloat32mf2_t *, vfloat32mf2_t *, vfloat32mf2_t *, vfloat32mf2_t *, vfloat32mf2_t *, const float *, vuint8mf8_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vloxseg8ei8_v_m)))
void vloxseg8ei8_v_f32mf2_m(vfloat32mf2_t *, vfloat32mf2_t *, vfloat32mf2_t *, vfloat32mf2_t *, vfloat32mf2_t *, vfloat32mf2_t *, vfloat32mf2_t *, vfloat32mf2_t *, vbool64_t, vfloat32mf2_t, vfloat32mf2_t, vfloat32mf2_t, vfloat32mf2_t, vfloat32mf2_t, vfloat32mf2_t, vfloat32mf2_t, vfloat32mf2_t, const float *, vuint8mf8_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vloxseg2ei16_v)))
void vloxseg2ei16_v_f32m1(vfloat32m1_t *, vfloat32m1_t *, const float *, vuint16mf2_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vloxseg2ei16_v_m)))
void vloxseg2ei16_v_f32m1_m(vfloat32m1_t *, vfloat32m1_t *, vbool32_t, vfloat32m1_t, vfloat32m1_t, const float *, vuint16mf2_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vloxseg2ei16_v)))
void vloxseg2ei16_v_f32m2(vfloat32m2_t *, vfloat32m2_t *, const float *, vuint16m1_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vloxseg2ei16_v_m)))
void vloxseg2ei16_v_f32m2_m(vfloat32m2_t *, vfloat32m2_t *, vbool16_t, vfloat32m2_t, vfloat32m2_t, const float *, vuint16m1_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vloxseg2ei16_v)))
void vloxseg2ei16_v_f32m4(vfloat32m4_t *, vfloat32m4_t *, const float *, vuint16m2_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vloxseg2ei16_v_m)))
void vloxseg2ei16_v_f32m4_m(vfloat32m4_t *, vfloat32m4_t *, vbool8_t, vfloat32m4_t, vfloat32m4_t, const float *, vuint16m2_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vloxseg2ei16_v)))
void vloxseg2ei16_v_f32mf2(vfloat32mf2_t *, vfloat32mf2_t *, const float *, vuint16mf4_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vloxseg2ei16_v_m)))
void vloxseg2ei16_v_f32mf2_m(vfloat32mf2_t *, vfloat32mf2_t *, vbool64_t, vfloat32mf2_t, vfloat32mf2_t, const float *, vuint16mf4_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vsse32_v)))
void vsse32_v_f32m1(float *, ptrdiff_t, vfloat32m1_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vsse32_v_m)))
void vsse32_v_f32m1_m(vbool32_t, float *, ptrdiff_t, vfloat32m1_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vsse32_v)))
void vsse32_v_f32m2(float *, ptrdiff_t, vfloat32m2_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vsse32_v_m)))
void vsse32_v_f32m2_m(vbool16_t, float *, ptrdiff_t, vfloat32m2_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vsse32_v)))
void vsse32_v_f32m4(float *, ptrdiff_t, vfloat32m4_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vsse32_v_m)))
void vsse32_v_f32m4_m(vbool8_t, float *, ptrdiff_t, vfloat32m4_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vsse32_v)))
void vsse32_v_f32m8(float *, ptrdiff_t, vfloat32m8_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vsse32_v_m)))
void vsse32_v_f32m8_m(vbool4_t, float *, ptrdiff_t, vfloat32m8_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vsse32_v)))
void vsse32_v_f32mf2(float *, ptrdiff_t, vfloat32mf2_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vsse32_v_m)))
void vsse32_v_f32mf2_m(vbool64_t, float *, ptrdiff_t, vfloat32mf2_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vloxseg3ei16_v)))
void vloxseg3ei16_v_f32m1(vfloat32m1_t *, vfloat32m1_t *, vfloat32m1_t *, const float *, vuint16mf2_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vloxseg3ei16_v_m)))
void vloxseg3ei16_v_f32m1_m(vfloat32m1_t *, vfloat32m1_t *, vfloat32m1_t *, vbool32_t, vfloat32m1_t, vfloat32m1_t, vfloat32m1_t, const float *, vuint16mf2_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vloxseg3ei16_v)))
void vloxseg3ei16_v_f32m2(vfloat32m2_t *, vfloat32m2_t *, vfloat32m2_t *, const float *, vuint16m1_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vloxseg3ei16_v_m)))
void vloxseg3ei16_v_f32m2_m(vfloat32m2_t *, vfloat32m2_t *, vfloat32m2_t *, vbool16_t, vfloat32m2_t, vfloat32m2_t, vfloat32m2_t, const float *, vuint16m1_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vloxseg3ei16_v)))
void vloxseg3ei16_v_f32mf2(vfloat32mf2_t *, vfloat32mf2_t *, vfloat32mf2_t *, const float *, vuint16mf4_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vloxseg3ei16_v_m)))
void vloxseg3ei16_v_f32mf2_m(vfloat32mf2_t *, vfloat32mf2_t *, vfloat32mf2_t *, vbool64_t, vfloat32mf2_t, vfloat32mf2_t, vfloat32mf2_t, const float *, vuint16mf4_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vloxseg4ei16_v)))
void vloxseg4ei16_v_f32m1(vfloat32m1_t *, vfloat32m1_t *, vfloat32m1_t *, vfloat32m1_t *, const float *, vuint16mf2_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vloxseg4ei16_v_m)))
void vloxseg4ei16_v_f32m1_m(vfloat32m1_t *, vfloat32m1_t *, vfloat32m1_t *, vfloat32m1_t *, vbool32_t, vfloat32m1_t, vfloat32m1_t, vfloat32m1_t, vfloat32m1_t, const float *, vuint16mf2_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vloxseg4ei16_v)))
void vloxseg4ei16_v_f32m2(vfloat32m2_t *, vfloat32m2_t *, vfloat32m2_t *, vfloat32m2_t *, const float *, vuint16m1_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vloxseg4ei16_v_m)))
void vloxseg4ei16_v_f32m2_m(vfloat32m2_t *, vfloat32m2_t *, vfloat32m2_t *, vfloat32m2_t *, vbool16_t, vfloat32m2_t, vfloat32m2_t, vfloat32m2_t, vfloat32m2_t, const float *, vuint16m1_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vloxseg4ei16_v)))
void vloxseg4ei16_v_f32mf2(vfloat32mf2_t *, vfloat32mf2_t *, vfloat32mf2_t *, vfloat32mf2_t *, const float *, vuint16mf4_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vloxseg4ei16_v_m)))
void vloxseg4ei16_v_f32mf2_m(vfloat32mf2_t *, vfloat32mf2_t *, vfloat32mf2_t *, vfloat32mf2_t *, vbool64_t, vfloat32mf2_t, vfloat32mf2_t, vfloat32mf2_t, vfloat32mf2_t, const float *, vuint16mf4_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vloxseg5ei16_v)))
void vloxseg5ei16_v_f32m1(vfloat32m1_t *, vfloat32m1_t *, vfloat32m1_t *, vfloat32m1_t *, vfloat32m1_t *, const float *, vuint16mf2_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vloxseg5ei16_v_m)))
void vloxseg5ei16_v_f32m1_m(vfloat32m1_t *, vfloat32m1_t *, vfloat32m1_t *, vfloat32m1_t *, vfloat32m1_t *, vbool32_t, vfloat32m1_t, vfloat32m1_t, vfloat32m1_t, vfloat32m1_t, vfloat32m1_t, const float *, vuint16mf2_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vloxseg5ei16_v)))
void vloxseg5ei16_v_f32mf2(vfloat32mf2_t *, vfloat32mf2_t *, vfloat32mf2_t *, vfloat32mf2_t *, vfloat32mf2_t *, const float *, vuint16mf4_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vloxseg5ei16_v_m)))
void vloxseg5ei16_v_f32mf2_m(vfloat32mf2_t *, vfloat32mf2_t *, vfloat32mf2_t *, vfloat32mf2_t *, vfloat32mf2_t *, vbool64_t, vfloat32mf2_t, vfloat32mf2_t, vfloat32mf2_t, vfloat32mf2_t, vfloat32mf2_t, const float *, vuint16mf4_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vloxseg6ei16_v)))
void vloxseg6ei16_v_f32m1(vfloat32m1_t *, vfloat32m1_t *, vfloat32m1_t *, vfloat32m1_t *, vfloat32m1_t *, vfloat32m1_t *, const float *, vuint16mf2_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vloxseg6ei16_v_m)))
void vloxseg6ei16_v_f32m1_m(vfloat32m1_t *, vfloat32m1_t *, vfloat32m1_t *, vfloat32m1_t *, vfloat32m1_t *, vfloat32m1_t *, vbool32_t, vfloat32m1_t, vfloat32m1_t, vfloat32m1_t, vfloat32m1_t, vfloat32m1_t, vfloat32m1_t, const float *, vuint16mf2_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vloxseg6ei16_v)))
void vloxseg6ei16_v_f32mf2(vfloat32mf2_t *, vfloat32mf2_t *, vfloat32mf2_t *, vfloat32mf2_t *, vfloat32mf2_t *, vfloat32mf2_t *, const float *, vuint16mf4_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vloxseg6ei16_v_m)))
void vloxseg6ei16_v_f32mf2_m(vfloat32mf2_t *, vfloat32mf2_t *, vfloat32mf2_t *, vfloat32mf2_t *, vfloat32mf2_t *, vfloat32mf2_t *, vbool64_t, vfloat32mf2_t, vfloat32mf2_t, vfloat32mf2_t, vfloat32mf2_t, vfloat32mf2_t, vfloat32mf2_t, const float *, vuint16mf4_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vloxseg7ei16_v)))
void vloxseg7ei16_v_f32m1(vfloat32m1_t *, vfloat32m1_t *, vfloat32m1_t *, vfloat32m1_t *, vfloat32m1_t *, vfloat32m1_t *, vfloat32m1_t *, const float *, vuint16mf2_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vloxseg7ei16_v_m)))
void vloxseg7ei16_v_f32m1_m(vfloat32m1_t *, vfloat32m1_t *, vfloat32m1_t *, vfloat32m1_t *, vfloat32m1_t *, vfloat32m1_t *, vfloat32m1_t *, vbool32_t, vfloat32m1_t, vfloat32m1_t, vfloat32m1_t, vfloat32m1_t, vfloat32m1_t, vfloat32m1_t, vfloat32m1_t, const float *, vuint16mf2_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vloxseg7ei16_v)))
void vloxseg7ei16_v_f32mf2(vfloat32mf2_t *, vfloat32mf2_t *, vfloat32mf2_t *, vfloat32mf2_t *, vfloat32mf2_t *, vfloat32mf2_t *, vfloat32mf2_t *, const float *, vuint16mf4_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vloxseg7ei16_v_m)))
void vloxseg7ei16_v_f32mf2_m(vfloat32mf2_t *, vfloat32mf2_t *, vfloat32mf2_t *, vfloat32mf2_t *, vfloat32mf2_t *, vfloat32mf2_t *, vfloat32mf2_t *, vbool64_t, vfloat32mf2_t, vfloat32mf2_t, vfloat32mf2_t, vfloat32mf2_t, vfloat32mf2_t, vfloat32mf2_t, vfloat32mf2_t, const float *, vuint16mf4_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vloxseg8ei16_v)))
void vloxseg8ei16_v_f32m1(vfloat32m1_t *, vfloat32m1_t *, vfloat32m1_t *, vfloat32m1_t *, vfloat32m1_t *, vfloat32m1_t *, vfloat32m1_t *, vfloat32m1_t *, const float *, vuint16mf2_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vloxseg8ei16_v_m)))
void vloxseg8ei16_v_f32m1_m(vfloat32m1_t *, vfloat32m1_t *, vfloat32m1_t *, vfloat32m1_t *, vfloat32m1_t *, vfloat32m1_t *, vfloat32m1_t *, vfloat32m1_t *, vbool32_t, vfloat32m1_t, vfloat32m1_t, vfloat32m1_t, vfloat32m1_t, vfloat32m1_t, vfloat32m1_t, vfloat32m1_t, vfloat32m1_t, const float *, vuint16mf2_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vloxseg8ei16_v)))
void vloxseg8ei16_v_f32mf2(vfloat32mf2_t *, vfloat32mf2_t *, vfloat32mf2_t *, vfloat32mf2_t *, vfloat32mf2_t *, vfloat32mf2_t *, vfloat32mf2_t *, vfloat32mf2_t *, const float *, vuint16mf4_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vloxseg8ei16_v_m)))
void vloxseg8ei16_v_f32mf2_m(vfloat32mf2_t *, vfloat32mf2_t *, vfloat32mf2_t *, vfloat32mf2_t *, vfloat32mf2_t *, vfloat32mf2_t *, vfloat32mf2_t *, vfloat32mf2_t *, vbool64_t, vfloat32mf2_t, vfloat32mf2_t, vfloat32mf2_t, vfloat32mf2_t, vfloat32mf2_t, vfloat32mf2_t, vfloat32mf2_t, vfloat32mf2_t, const float *, vuint16mf4_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vloxseg2ei32_v)))
void vloxseg2ei32_v_f32m1(vfloat32m1_t *, vfloat32m1_t *, const float *, vuint32m1_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vloxseg2ei32_v_m)))
void vloxseg2ei32_v_f32m1_m(vfloat32m1_t *, vfloat32m1_t *, vbool32_t, vfloat32m1_t, vfloat32m1_t, const float *, vuint32m1_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vloxseg2ei32_v)))
void vloxseg2ei32_v_f32m2(vfloat32m2_t *, vfloat32m2_t *, const float *, vuint32m2_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vloxseg2ei32_v_m)))
void vloxseg2ei32_v_f32m2_m(vfloat32m2_t *, vfloat32m2_t *, vbool16_t, vfloat32m2_t, vfloat32m2_t, const float *, vuint32m2_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vloxseg2ei32_v)))
void vloxseg2ei32_v_f32m4(vfloat32m4_t *, vfloat32m4_t *, const float *, vuint32m4_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vloxseg2ei32_v_m)))
void vloxseg2ei32_v_f32m4_m(vfloat32m4_t *, vfloat32m4_t *, vbool8_t, vfloat32m4_t, vfloat32m4_t, const float *, vuint32m4_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vloxseg2ei32_v)))
void vloxseg2ei32_v_f32mf2(vfloat32mf2_t *, vfloat32mf2_t *, const float *, vuint32mf2_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vloxseg2ei32_v_m)))
void vloxseg2ei32_v_f32mf2_m(vfloat32mf2_t *, vfloat32mf2_t *, vbool64_t, vfloat32mf2_t, vfloat32mf2_t, const float *, vuint32mf2_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vloxseg3ei32_v)))
void vloxseg3ei32_v_f32m1(vfloat32m1_t *, vfloat32m1_t *, vfloat32m1_t *, const float *, vuint32m1_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vloxseg3ei32_v_m)))
void vloxseg3ei32_v_f32m1_m(vfloat32m1_t *, vfloat32m1_t *, vfloat32m1_t *, vbool32_t, vfloat32m1_t, vfloat32m1_t, vfloat32m1_t, const float *, vuint32m1_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vloxseg3ei32_v)))
void vloxseg3ei32_v_f32m2(vfloat32m2_t *, vfloat32m2_t *, vfloat32m2_t *, const float *, vuint32m2_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vloxseg3ei32_v_m)))
void vloxseg3ei32_v_f32m2_m(vfloat32m2_t *, vfloat32m2_t *, vfloat32m2_t *, vbool16_t, vfloat32m2_t, vfloat32m2_t, vfloat32m2_t, const float *, vuint32m2_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vloxseg3ei32_v)))
void vloxseg3ei32_v_f32mf2(vfloat32mf2_t *, vfloat32mf2_t *, vfloat32mf2_t *, const float *, vuint32mf2_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vloxseg3ei32_v_m)))
void vloxseg3ei32_v_f32mf2_m(vfloat32mf2_t *, vfloat32mf2_t *, vfloat32mf2_t *, vbool64_t, vfloat32mf2_t, vfloat32mf2_t, vfloat32mf2_t, const float *, vuint32mf2_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vloxseg4ei32_v)))
void vloxseg4ei32_v_f32m1(vfloat32m1_t *, vfloat32m1_t *, vfloat32m1_t *, vfloat32m1_t *, const float *, vuint32m1_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vloxseg4ei32_v_m)))
void vloxseg4ei32_v_f32m1_m(vfloat32m1_t *, vfloat32m1_t *, vfloat32m1_t *, vfloat32m1_t *, vbool32_t, vfloat32m1_t, vfloat32m1_t, vfloat32m1_t, vfloat32m1_t, const float *, vuint32m1_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vloxseg4ei32_v)))
void vloxseg4ei32_v_f32m2(vfloat32m2_t *, vfloat32m2_t *, vfloat32m2_t *, vfloat32m2_t *, const float *, vuint32m2_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vloxseg4ei32_v_m)))
void vloxseg4ei32_v_f32m2_m(vfloat32m2_t *, vfloat32m2_t *, vfloat32m2_t *, vfloat32m2_t *, vbool16_t, vfloat32m2_t, vfloat32m2_t, vfloat32m2_t, vfloat32m2_t, const float *, vuint32m2_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vloxseg4ei32_v)))
void vloxseg4ei32_v_f32mf2(vfloat32mf2_t *, vfloat32mf2_t *, vfloat32mf2_t *, vfloat32mf2_t *, const float *, vuint32mf2_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vloxseg4ei32_v_m)))
void vloxseg4ei32_v_f32mf2_m(vfloat32mf2_t *, vfloat32mf2_t *, vfloat32mf2_t *, vfloat32mf2_t *, vbool64_t, vfloat32mf2_t, vfloat32mf2_t, vfloat32mf2_t, vfloat32mf2_t, const float *, vuint32mf2_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vloxseg5ei32_v)))
void vloxseg5ei32_v_f32m1(vfloat32m1_t *, vfloat32m1_t *, vfloat32m1_t *, vfloat32m1_t *, vfloat32m1_t *, const float *, vuint32m1_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vloxseg5ei32_v_m)))
void vloxseg5ei32_v_f32m1_m(vfloat32m1_t *, vfloat32m1_t *, vfloat32m1_t *, vfloat32m1_t *, vfloat32m1_t *, vbool32_t, vfloat32m1_t, vfloat32m1_t, vfloat32m1_t, vfloat32m1_t, vfloat32m1_t, const float *, vuint32m1_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vloxseg5ei32_v)))
void vloxseg5ei32_v_f32mf2(vfloat32mf2_t *, vfloat32mf2_t *, vfloat32mf2_t *, vfloat32mf2_t *, vfloat32mf2_t *, const float *, vuint32mf2_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vloxseg5ei32_v_m)))
void vloxseg5ei32_v_f32mf2_m(vfloat32mf2_t *, vfloat32mf2_t *, vfloat32mf2_t *, vfloat32mf2_t *, vfloat32mf2_t *, vbool64_t, vfloat32mf2_t, vfloat32mf2_t, vfloat32mf2_t, vfloat32mf2_t, vfloat32mf2_t, const float *, vuint32mf2_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vloxseg6ei32_v)))
void vloxseg6ei32_v_f32m1(vfloat32m1_t *, vfloat32m1_t *, vfloat32m1_t *, vfloat32m1_t *, vfloat32m1_t *, vfloat32m1_t *, const float *, vuint32m1_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vloxseg6ei32_v_m)))
void vloxseg6ei32_v_f32m1_m(vfloat32m1_t *, vfloat32m1_t *, vfloat32m1_t *, vfloat32m1_t *, vfloat32m1_t *, vfloat32m1_t *, vbool32_t, vfloat32m1_t, vfloat32m1_t, vfloat32m1_t, vfloat32m1_t, vfloat32m1_t, vfloat32m1_t, const float *, vuint32m1_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vloxseg6ei32_v)))
void vloxseg6ei32_v_f32mf2(vfloat32mf2_t *, vfloat32mf2_t *, vfloat32mf2_t *, vfloat32mf2_t *, vfloat32mf2_t *, vfloat32mf2_t *, const float *, vuint32mf2_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vloxseg6ei32_v_m)))
void vloxseg6ei32_v_f32mf2_m(vfloat32mf2_t *, vfloat32mf2_t *, vfloat32mf2_t *, vfloat32mf2_t *, vfloat32mf2_t *, vfloat32mf2_t *, vbool64_t, vfloat32mf2_t, vfloat32mf2_t, vfloat32mf2_t, vfloat32mf2_t, vfloat32mf2_t, vfloat32mf2_t, const float *, vuint32mf2_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vloxseg7ei32_v)))
void vloxseg7ei32_v_f32m1(vfloat32m1_t *, vfloat32m1_t *, vfloat32m1_t *, vfloat32m1_t *, vfloat32m1_t *, vfloat32m1_t *, vfloat32m1_t *, const float *, vuint32m1_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vloxseg7ei32_v_m)))
void vloxseg7ei32_v_f32m1_m(vfloat32m1_t *, vfloat32m1_t *, vfloat32m1_t *, vfloat32m1_t *, vfloat32m1_t *, vfloat32m1_t *, vfloat32m1_t *, vbool32_t, vfloat32m1_t, vfloat32m1_t, vfloat32m1_t, vfloat32m1_t, vfloat32m1_t, vfloat32m1_t, vfloat32m1_t, const float *, vuint32m1_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vloxseg7ei32_v)))
void vloxseg7ei32_v_f32mf2(vfloat32mf2_t *, vfloat32mf2_t *, vfloat32mf2_t *, vfloat32mf2_t *, vfloat32mf2_t *, vfloat32mf2_t *, vfloat32mf2_t *, const float *, vuint32mf2_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vloxseg7ei32_v_m)))
void vloxseg7ei32_v_f32mf2_m(vfloat32mf2_t *, vfloat32mf2_t *, vfloat32mf2_t *, vfloat32mf2_t *, vfloat32mf2_t *, vfloat32mf2_t *, vfloat32mf2_t *, vbool64_t, vfloat32mf2_t, vfloat32mf2_t, vfloat32mf2_t, vfloat32mf2_t, vfloat32mf2_t, vfloat32mf2_t, vfloat32mf2_t, const float *, vuint32mf2_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vloxseg8ei32_v)))
void vloxseg8ei32_v_f32m1(vfloat32m1_t *, vfloat32m1_t *, vfloat32m1_t *, vfloat32m1_t *, vfloat32m1_t *, vfloat32m1_t *, vfloat32m1_t *, vfloat32m1_t *, const float *, vuint32m1_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vloxseg8ei32_v_m)))
void vloxseg8ei32_v_f32m1_m(vfloat32m1_t *, vfloat32m1_t *, vfloat32m1_t *, vfloat32m1_t *, vfloat32m1_t *, vfloat32m1_t *, vfloat32m1_t *, vfloat32m1_t *, vbool32_t, vfloat32m1_t, vfloat32m1_t, vfloat32m1_t, vfloat32m1_t, vfloat32m1_t, vfloat32m1_t, vfloat32m1_t, vfloat32m1_t, const float *, vuint32m1_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vloxseg8ei32_v)))
void vloxseg8ei32_v_f32mf2(vfloat32mf2_t *, vfloat32mf2_t *, vfloat32mf2_t *, vfloat32mf2_t *, vfloat32mf2_t *, vfloat32mf2_t *, vfloat32mf2_t *, vfloat32mf2_t *, const float *, vuint32mf2_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vloxseg8ei32_v_m)))
void vloxseg8ei32_v_f32mf2_m(vfloat32mf2_t *, vfloat32mf2_t *, vfloat32mf2_t *, vfloat32mf2_t *, vfloat32mf2_t *, vfloat32mf2_t *, vfloat32mf2_t *, vfloat32mf2_t *, vbool64_t, vfloat32mf2_t, vfloat32mf2_t, vfloat32mf2_t, vfloat32mf2_t, vfloat32mf2_t, vfloat32mf2_t, vfloat32mf2_t, vfloat32mf2_t, const float *, vuint32mf2_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vsseg2e32_v)))
void vsseg2e32_v_f32m1(float *, vfloat32m1_t, vfloat32m1_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vsseg2e32_v_m)))
void vsseg2e32_v_f32m1_m(vbool32_t, float *, vfloat32m1_t, vfloat32m1_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vsseg2e32_v)))
void vsseg2e32_v_f32m2(float *, vfloat32m2_t, vfloat32m2_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vsseg2e32_v_m)))
void vsseg2e32_v_f32m2_m(vbool16_t, float *, vfloat32m2_t, vfloat32m2_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vsseg2e32_v)))
void vsseg2e32_v_f32m4(float *, vfloat32m4_t, vfloat32m4_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vsseg2e32_v_m)))
void vsseg2e32_v_f32m4_m(vbool8_t, float *, vfloat32m4_t, vfloat32m4_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vsseg2e32_v)))
void vsseg2e32_v_f32mf2(float *, vfloat32mf2_t, vfloat32mf2_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vsseg2e32_v_m)))
void vsseg2e32_v_f32mf2_m(vbool64_t, float *, vfloat32mf2_t, vfloat32mf2_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vsseg3e32_v)))
void vsseg3e32_v_f32m1(float *, vfloat32m1_t, vfloat32m1_t, vfloat32m1_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vsseg3e32_v_m)))
void vsseg3e32_v_f32m1_m(vbool32_t, float *, vfloat32m1_t, vfloat32m1_t, vfloat32m1_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vsseg3e32_v)))
void vsseg3e32_v_f32m2(float *, vfloat32m2_t, vfloat32m2_t, vfloat32m2_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vsseg3e32_v_m)))
void vsseg3e32_v_f32m2_m(vbool16_t, float *, vfloat32m2_t, vfloat32m2_t, vfloat32m2_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vsseg3e32_v)))
void vsseg3e32_v_f32mf2(float *, vfloat32mf2_t, vfloat32mf2_t, vfloat32mf2_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vsseg3e32_v_m)))
void vsseg3e32_v_f32mf2_m(vbool64_t, float *, vfloat32mf2_t, vfloat32mf2_t, vfloat32mf2_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vsseg4e32_v)))
void vsseg4e32_v_f32m1(float *, vfloat32m1_t, vfloat32m1_t, vfloat32m1_t, vfloat32m1_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vsseg4e32_v_m)))
void vsseg4e32_v_f32m1_m(vbool32_t, float *, vfloat32m1_t, vfloat32m1_t, vfloat32m1_t, vfloat32m1_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vsseg4e32_v)))
void vsseg4e32_v_f32m2(float *, vfloat32m2_t, vfloat32m2_t, vfloat32m2_t, vfloat32m2_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vsseg4e32_v_m)))
void vsseg4e32_v_f32m2_m(vbool16_t, float *, vfloat32m2_t, vfloat32m2_t, vfloat32m2_t, vfloat32m2_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vsseg4e32_v)))
void vsseg4e32_v_f32mf2(float *, vfloat32mf2_t, vfloat32mf2_t, vfloat32mf2_t, vfloat32mf2_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vsseg4e32_v_m)))
void vsseg4e32_v_f32mf2_m(vbool64_t, float *, vfloat32mf2_t, vfloat32mf2_t, vfloat32mf2_t, vfloat32mf2_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vsseg5e32_v)))
void vsseg5e32_v_f32m1(float *, vfloat32m1_t, vfloat32m1_t, vfloat32m1_t, vfloat32m1_t, vfloat32m1_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vsseg5e32_v_m)))
void vsseg5e32_v_f32m1_m(vbool32_t, float *, vfloat32m1_t, vfloat32m1_t, vfloat32m1_t, vfloat32m1_t, vfloat32m1_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vsseg5e32_v)))
void vsseg5e32_v_f32mf2(float *, vfloat32mf2_t, vfloat32mf2_t, vfloat32mf2_t, vfloat32mf2_t, vfloat32mf2_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vsseg5e32_v_m)))
void vsseg5e32_v_f32mf2_m(vbool64_t, float *, vfloat32mf2_t, vfloat32mf2_t, vfloat32mf2_t, vfloat32mf2_t, vfloat32mf2_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vsseg6e32_v)))
void vsseg6e32_v_f32m1(float *, vfloat32m1_t, vfloat32m1_t, vfloat32m1_t, vfloat32m1_t, vfloat32m1_t, vfloat32m1_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vsseg6e32_v_m)))
void vsseg6e32_v_f32m1_m(vbool32_t, float *, vfloat32m1_t, vfloat32m1_t, vfloat32m1_t, vfloat32m1_t, vfloat32m1_t, vfloat32m1_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vsseg6e32_v)))
void vsseg6e32_v_f32mf2(float *, vfloat32mf2_t, vfloat32mf2_t, vfloat32mf2_t, vfloat32mf2_t, vfloat32mf2_t, vfloat32mf2_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vsseg6e32_v_m)))
void vsseg6e32_v_f32mf2_m(vbool64_t, float *, vfloat32mf2_t, vfloat32mf2_t, vfloat32mf2_t, vfloat32mf2_t, vfloat32mf2_t, vfloat32mf2_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vsseg7e32_v)))
void vsseg7e32_v_f32m1(float *, vfloat32m1_t, vfloat32m1_t, vfloat32m1_t, vfloat32m1_t, vfloat32m1_t, vfloat32m1_t, vfloat32m1_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vsseg7e32_v_m)))
void vsseg7e32_v_f32m1_m(vbool32_t, float *, vfloat32m1_t, vfloat32m1_t, vfloat32m1_t, vfloat32m1_t, vfloat32m1_t, vfloat32m1_t, vfloat32m1_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vsseg7e32_v)))
void vsseg7e32_v_f32mf2(float *, vfloat32mf2_t, vfloat32mf2_t, vfloat32mf2_t, vfloat32mf2_t, vfloat32mf2_t, vfloat32mf2_t, vfloat32mf2_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vsseg7e32_v_m)))
void vsseg7e32_v_f32mf2_m(vbool64_t, float *, vfloat32mf2_t, vfloat32mf2_t, vfloat32mf2_t, vfloat32mf2_t, vfloat32mf2_t, vfloat32mf2_t, vfloat32mf2_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vsseg8e32_v)))
void vsseg8e32_v_f32m1(float *, vfloat32m1_t, vfloat32m1_t, vfloat32m1_t, vfloat32m1_t, vfloat32m1_t, vfloat32m1_t, vfloat32m1_t, vfloat32m1_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vsseg8e32_v_m)))
void vsseg8e32_v_f32m1_m(vbool32_t, float *, vfloat32m1_t, vfloat32m1_t, vfloat32m1_t, vfloat32m1_t, vfloat32m1_t, vfloat32m1_t, vfloat32m1_t, vfloat32m1_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vsseg8e32_v)))
void vsseg8e32_v_f32mf2(float *, vfloat32mf2_t, vfloat32mf2_t, vfloat32mf2_t, vfloat32mf2_t, vfloat32mf2_t, vfloat32mf2_t, vfloat32mf2_t, vfloat32mf2_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vsseg8e32_v_m)))
void vsseg8e32_v_f32mf2_m(vbool64_t, float *, vfloat32mf2_t, vfloat32mf2_t, vfloat32mf2_t, vfloat32mf2_t, vfloat32mf2_t, vfloat32mf2_t, vfloat32mf2_t, vfloat32mf2_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vssseg2e32_v)))
void vssseg2e32_v_f32m1(float *, ptrdiff_t, vfloat32m1_t, vfloat32m1_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vssseg2e32_v_m)))
void vssseg2e32_v_f32m1_m(vbool32_t, float *, ptrdiff_t, vfloat32m1_t, vfloat32m1_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vssseg2e32_v)))
void vssseg2e32_v_f32m2(float *, ptrdiff_t, vfloat32m2_t, vfloat32m2_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vssseg2e32_v_m)))
void vssseg2e32_v_f32m2_m(vbool16_t, float *, ptrdiff_t, vfloat32m2_t, vfloat32m2_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vssseg2e32_v)))
void vssseg2e32_v_f32m4(float *, ptrdiff_t, vfloat32m4_t, vfloat32m4_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vssseg2e32_v_m)))
void vssseg2e32_v_f32m4_m(vbool8_t, float *, ptrdiff_t, vfloat32m4_t, vfloat32m4_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vssseg2e32_v)))
void vssseg2e32_v_f32mf2(float *, ptrdiff_t, vfloat32mf2_t, vfloat32mf2_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vssseg2e32_v_m)))
void vssseg2e32_v_f32mf2_m(vbool64_t, float *, ptrdiff_t, vfloat32mf2_t, vfloat32mf2_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vssseg3e32_v)))
void vssseg3e32_v_f32m1(float *, ptrdiff_t, vfloat32m1_t, vfloat32m1_t, vfloat32m1_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vssseg3e32_v_m)))
void vssseg3e32_v_f32m1_m(vbool32_t, float *, ptrdiff_t, vfloat32m1_t, vfloat32m1_t, vfloat32m1_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vssseg3e32_v)))
void vssseg3e32_v_f32m2(float *, ptrdiff_t, vfloat32m2_t, vfloat32m2_t, vfloat32m2_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vssseg3e32_v_m)))
void vssseg3e32_v_f32m2_m(vbool16_t, float *, ptrdiff_t, vfloat32m2_t, vfloat32m2_t, vfloat32m2_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vssseg3e32_v)))
void vssseg3e32_v_f32mf2(float *, ptrdiff_t, vfloat32mf2_t, vfloat32mf2_t, vfloat32mf2_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vssseg3e32_v_m)))
void vssseg3e32_v_f32mf2_m(vbool64_t, float *, ptrdiff_t, vfloat32mf2_t, vfloat32mf2_t, vfloat32mf2_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vssseg4e32_v)))
void vssseg4e32_v_f32m1(float *, ptrdiff_t, vfloat32m1_t, vfloat32m1_t, vfloat32m1_t, vfloat32m1_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vssseg4e32_v_m)))
void vssseg4e32_v_f32m1_m(vbool32_t, float *, ptrdiff_t, vfloat32m1_t, vfloat32m1_t, vfloat32m1_t, vfloat32m1_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vssseg4e32_v)))
void vssseg4e32_v_f32m2(float *, ptrdiff_t, vfloat32m2_t, vfloat32m2_t, vfloat32m2_t, vfloat32m2_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vssseg4e32_v_m)))
void vssseg4e32_v_f32m2_m(vbool16_t, float *, ptrdiff_t, vfloat32m2_t, vfloat32m2_t, vfloat32m2_t, vfloat32m2_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vssseg4e32_v)))
void vssseg4e32_v_f32mf2(float *, ptrdiff_t, vfloat32mf2_t, vfloat32mf2_t, vfloat32mf2_t, vfloat32mf2_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vssseg4e32_v_m)))
void vssseg4e32_v_f32mf2_m(vbool64_t, float *, ptrdiff_t, vfloat32mf2_t, vfloat32mf2_t, vfloat32mf2_t, vfloat32mf2_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vssseg5e32_v)))
void vssseg5e32_v_f32m1(float *, ptrdiff_t, vfloat32m1_t, vfloat32m1_t, vfloat32m1_t, vfloat32m1_t, vfloat32m1_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vssseg5e32_v_m)))
void vssseg5e32_v_f32m1_m(vbool32_t, float *, ptrdiff_t, vfloat32m1_t, vfloat32m1_t, vfloat32m1_t, vfloat32m1_t, vfloat32m1_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vssseg5e32_v)))
void vssseg5e32_v_f32mf2(float *, ptrdiff_t, vfloat32mf2_t, vfloat32mf2_t, vfloat32mf2_t, vfloat32mf2_t, vfloat32mf2_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vssseg5e32_v_m)))
void vssseg5e32_v_f32mf2_m(vbool64_t, float *, ptrdiff_t, vfloat32mf2_t, vfloat32mf2_t, vfloat32mf2_t, vfloat32mf2_t, vfloat32mf2_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vssseg6e32_v)))
void vssseg6e32_v_f32m1(float *, ptrdiff_t, vfloat32m1_t, vfloat32m1_t, vfloat32m1_t, vfloat32m1_t, vfloat32m1_t, vfloat32m1_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vssseg6e32_v_m)))
void vssseg6e32_v_f32m1_m(vbool32_t, float *, ptrdiff_t, vfloat32m1_t, vfloat32m1_t, vfloat32m1_t, vfloat32m1_t, vfloat32m1_t, vfloat32m1_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vssseg6e32_v)))
void vssseg6e32_v_f32mf2(float *, ptrdiff_t, vfloat32mf2_t, vfloat32mf2_t, vfloat32mf2_t, vfloat32mf2_t, vfloat32mf2_t, vfloat32mf2_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vssseg6e32_v_m)))
void vssseg6e32_v_f32mf2_m(vbool64_t, float *, ptrdiff_t, vfloat32mf2_t, vfloat32mf2_t, vfloat32mf2_t, vfloat32mf2_t, vfloat32mf2_t, vfloat32mf2_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vssseg7e32_v)))
void vssseg7e32_v_f32m1(float *, ptrdiff_t, vfloat32m1_t, vfloat32m1_t, vfloat32m1_t, vfloat32m1_t, vfloat32m1_t, vfloat32m1_t, vfloat32m1_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vssseg7e32_v_m)))
void vssseg7e32_v_f32m1_m(vbool32_t, float *, ptrdiff_t, vfloat32m1_t, vfloat32m1_t, vfloat32m1_t, vfloat32m1_t, vfloat32m1_t, vfloat32m1_t, vfloat32m1_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vssseg7e32_v)))
void vssseg7e32_v_f32mf2(float *, ptrdiff_t, vfloat32mf2_t, vfloat32mf2_t, vfloat32mf2_t, vfloat32mf2_t, vfloat32mf2_t, vfloat32mf2_t, vfloat32mf2_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vssseg7e32_v_m)))
void vssseg7e32_v_f32mf2_m(vbool64_t, float *, ptrdiff_t, vfloat32mf2_t, vfloat32mf2_t, vfloat32mf2_t, vfloat32mf2_t, vfloat32mf2_t, vfloat32mf2_t, vfloat32mf2_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vssseg8e32_v)))
void vssseg8e32_v_f32m1(float *, ptrdiff_t, vfloat32m1_t, vfloat32m1_t, vfloat32m1_t, vfloat32m1_t, vfloat32m1_t, vfloat32m1_t, vfloat32m1_t, vfloat32m1_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vssseg8e32_v_m)))
void vssseg8e32_v_f32m1_m(vbool32_t, float *, ptrdiff_t, vfloat32m1_t, vfloat32m1_t, vfloat32m1_t, vfloat32m1_t, vfloat32m1_t, vfloat32m1_t, vfloat32m1_t, vfloat32m1_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vssseg8e32_v)))
void vssseg8e32_v_f32mf2(float *, ptrdiff_t, vfloat32mf2_t, vfloat32mf2_t, vfloat32mf2_t, vfloat32mf2_t, vfloat32mf2_t, vfloat32mf2_t, vfloat32mf2_t, vfloat32mf2_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vssseg8e32_v_m)))
void vssseg8e32_v_f32mf2_m(vbool64_t, float *, ptrdiff_t, vfloat32mf2_t, vfloat32mf2_t, vfloat32mf2_t, vfloat32mf2_t, vfloat32mf2_t, vfloat32mf2_t, vfloat32mf2_t, vfloat32mf2_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vluxei8_v)))
vfloat32m1_t vluxei8_v_f32m1(const float *, vuint8mf4_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vluxei8_v_m)))
vfloat32m1_t vluxei8_v_f32m1_m(vbool32_t, vfloat32m1_t, const float *, vuint8mf4_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vluxei8_v)))
vfloat32m2_t vluxei8_v_f32m2(const float *, vuint8mf2_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vluxei8_v_m)))
vfloat32m2_t vluxei8_v_f32m2_m(vbool16_t, vfloat32m2_t, const float *, vuint8mf2_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vluxei8_v)))
vfloat32m4_t vluxei8_v_f32m4(const float *, vuint8m1_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vluxei8_v_m)))
vfloat32m4_t vluxei8_v_f32m4_m(vbool8_t, vfloat32m4_t, const float *, vuint8m1_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vluxei8_v)))
vfloat32m8_t vluxei8_v_f32m8(const float *, vuint8m2_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vluxei8_v_m)))
vfloat32m8_t vluxei8_v_f32m8_m(vbool4_t, vfloat32m8_t, const float *, vuint8m2_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vluxei8_v)))
vfloat32mf2_t vluxei8_v_f32mf2(const float *, vuint8mf8_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vluxei8_v_m)))
vfloat32mf2_t vluxei8_v_f32mf2_m(vbool64_t, vfloat32mf2_t, const float *, vuint8mf8_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vluxei16_v)))
vfloat32m1_t vluxei16_v_f32m1(const float *, vuint16mf2_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vluxei16_v_m)))
vfloat32m1_t vluxei16_v_f32m1_m(vbool32_t, vfloat32m1_t, const float *, vuint16mf2_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vluxei16_v)))
vfloat32m2_t vluxei16_v_f32m2(const float *, vuint16m1_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vluxei16_v_m)))
vfloat32m2_t vluxei16_v_f32m2_m(vbool16_t, vfloat32m2_t, const float *, vuint16m1_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vluxei16_v)))
vfloat32m4_t vluxei16_v_f32m4(const float *, vuint16m2_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vluxei16_v_m)))
vfloat32m4_t vluxei16_v_f32m4_m(vbool8_t, vfloat32m4_t, const float *, vuint16m2_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vluxei16_v)))
vfloat32m8_t vluxei16_v_f32m8(const float *, vuint16m4_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vluxei16_v_m)))
vfloat32m8_t vluxei16_v_f32m8_m(vbool4_t, vfloat32m8_t, const float *, vuint16m4_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vluxei16_v)))
vfloat32mf2_t vluxei16_v_f32mf2(const float *, vuint16mf4_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vluxei16_v_m)))
vfloat32mf2_t vluxei16_v_f32mf2_m(vbool64_t, vfloat32mf2_t, const float *, vuint16mf4_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vluxei32_v)))
vfloat32m1_t vluxei32_v_f32m1(const float *, vuint32m1_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vluxei32_v_m)))
vfloat32m1_t vluxei32_v_f32m1_m(vbool32_t, vfloat32m1_t, const float *, vuint32m1_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vluxei32_v)))
vfloat32m2_t vluxei32_v_f32m2(const float *, vuint32m2_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vluxei32_v_m)))
vfloat32m2_t vluxei32_v_f32m2_m(vbool16_t, vfloat32m2_t, const float *, vuint32m2_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vluxei32_v)))
vfloat32m4_t vluxei32_v_f32m4(const float *, vuint32m4_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vluxei32_v_m)))
vfloat32m4_t vluxei32_v_f32m4_m(vbool8_t, vfloat32m4_t, const float *, vuint32m4_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vluxei32_v)))
vfloat32m8_t vluxei32_v_f32m8(const float *, vuint32m8_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vluxei32_v_m)))
vfloat32m8_t vluxei32_v_f32m8_m(vbool4_t, vfloat32m8_t, const float *, vuint32m8_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vluxei32_v)))
vfloat32mf2_t vluxei32_v_f32mf2(const float *, vuint32mf2_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vluxei32_v_m)))
vfloat32mf2_t vluxei32_v_f32mf2_m(vbool64_t, vfloat32mf2_t, const float *, vuint32mf2_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vsuxseg2ei8_v)))
void vsuxseg2ei8_v_f32m1(float *, vuint8mf4_t, vfloat32m1_t, vfloat32m1_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vsuxseg2ei8_v_m)))
void vsuxseg2ei8_v_f32m1_m(vbool32_t, float *, vuint8mf4_t, vfloat32m1_t, vfloat32m1_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vsuxseg2ei8_v)))
void vsuxseg2ei8_v_f32m2(float *, vuint8mf2_t, vfloat32m2_t, vfloat32m2_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vsuxseg2ei8_v_m)))
void vsuxseg2ei8_v_f32m2_m(vbool16_t, float *, vuint8mf2_t, vfloat32m2_t, vfloat32m2_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vsuxseg2ei8_v)))
void vsuxseg2ei8_v_f32m4(float *, vuint8m1_t, vfloat32m4_t, vfloat32m4_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vsuxseg2ei8_v_m)))
void vsuxseg2ei8_v_f32m4_m(vbool8_t, float *, vuint8m1_t, vfloat32m4_t, vfloat32m4_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vsuxseg2ei8_v)))
void vsuxseg2ei8_v_f32mf2(float *, vuint8mf8_t, vfloat32mf2_t, vfloat32mf2_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vsuxseg2ei8_v_m)))
void vsuxseg2ei8_v_f32mf2_m(vbool64_t, float *, vuint8mf8_t, vfloat32mf2_t, vfloat32mf2_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vsuxseg3ei8_v)))
void vsuxseg3ei8_v_f32m1(float *, vuint8mf4_t, vfloat32m1_t, vfloat32m1_t, vfloat32m1_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vsuxseg3ei8_v_m)))
void vsuxseg3ei8_v_f32m1_m(vbool32_t, float *, vuint8mf4_t, vfloat32m1_t, vfloat32m1_t, vfloat32m1_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vsuxseg3ei8_v)))
void vsuxseg3ei8_v_f32m2(float *, vuint8mf2_t, vfloat32m2_t, vfloat32m2_t, vfloat32m2_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vsuxseg3ei8_v_m)))
void vsuxseg3ei8_v_f32m2_m(vbool16_t, float *, vuint8mf2_t, vfloat32m2_t, vfloat32m2_t, vfloat32m2_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vsuxseg3ei8_v)))
void vsuxseg3ei8_v_f32mf2(float *, vuint8mf8_t, vfloat32mf2_t, vfloat32mf2_t, vfloat32mf2_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vsuxseg3ei8_v_m)))
void vsuxseg3ei8_v_f32mf2_m(vbool64_t, float *, vuint8mf8_t, vfloat32mf2_t, vfloat32mf2_t, vfloat32mf2_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vsuxseg4ei8_v)))
void vsuxseg4ei8_v_f32m1(float *, vuint8mf4_t, vfloat32m1_t, vfloat32m1_t, vfloat32m1_t, vfloat32m1_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vsuxseg4ei8_v_m)))
void vsuxseg4ei8_v_f32m1_m(vbool32_t, float *, vuint8mf4_t, vfloat32m1_t, vfloat32m1_t, vfloat32m1_t, vfloat32m1_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vsuxseg4ei8_v)))
void vsuxseg4ei8_v_f32m2(float *, vuint8mf2_t, vfloat32m2_t, vfloat32m2_t, vfloat32m2_t, vfloat32m2_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vsuxseg4ei8_v_m)))
void vsuxseg4ei8_v_f32m2_m(vbool16_t, float *, vuint8mf2_t, vfloat32m2_t, vfloat32m2_t, vfloat32m2_t, vfloat32m2_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vsuxseg4ei8_v)))
void vsuxseg4ei8_v_f32mf2(float *, vuint8mf8_t, vfloat32mf2_t, vfloat32mf2_t, vfloat32mf2_t, vfloat32mf2_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vsuxseg4ei8_v_m)))
void vsuxseg4ei8_v_f32mf2_m(vbool64_t, float *, vuint8mf8_t, vfloat32mf2_t, vfloat32mf2_t, vfloat32mf2_t, vfloat32mf2_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vsuxseg5ei8_v)))
void vsuxseg5ei8_v_f32m1(float *, vuint8mf4_t, vfloat32m1_t, vfloat32m1_t, vfloat32m1_t, vfloat32m1_t, vfloat32m1_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vsuxseg5ei8_v_m)))
void vsuxseg5ei8_v_f32m1_m(vbool32_t, float *, vuint8mf4_t, vfloat32m1_t, vfloat32m1_t, vfloat32m1_t, vfloat32m1_t, vfloat32m1_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vsuxseg5ei8_v)))
void vsuxseg5ei8_v_f32mf2(float *, vuint8mf8_t, vfloat32mf2_t, vfloat32mf2_t, vfloat32mf2_t, vfloat32mf2_t, vfloat32mf2_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vsuxseg5ei8_v_m)))
void vsuxseg5ei8_v_f32mf2_m(vbool64_t, float *, vuint8mf8_t, vfloat32mf2_t, vfloat32mf2_t, vfloat32mf2_t, vfloat32mf2_t, vfloat32mf2_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vsuxseg6ei8_v)))
void vsuxseg6ei8_v_f32m1(float *, vuint8mf4_t, vfloat32m1_t, vfloat32m1_t, vfloat32m1_t, vfloat32m1_t, vfloat32m1_t, vfloat32m1_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vsuxseg6ei8_v_m)))
void vsuxseg6ei8_v_f32m1_m(vbool32_t, float *, vuint8mf4_t, vfloat32m1_t, vfloat32m1_t, vfloat32m1_t, vfloat32m1_t, vfloat32m1_t, vfloat32m1_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vsuxseg6ei8_v)))
void vsuxseg6ei8_v_f32mf2(float *, vuint8mf8_t, vfloat32mf2_t, vfloat32mf2_t, vfloat32mf2_t, vfloat32mf2_t, vfloat32mf2_t, vfloat32mf2_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vsuxseg6ei8_v_m)))
void vsuxseg6ei8_v_f32mf2_m(vbool64_t, float *, vuint8mf8_t, vfloat32mf2_t, vfloat32mf2_t, vfloat32mf2_t, vfloat32mf2_t, vfloat32mf2_t, vfloat32mf2_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vsuxseg7ei8_v)))
void vsuxseg7ei8_v_f32m1(float *, vuint8mf4_t, vfloat32m1_t, vfloat32m1_t, vfloat32m1_t, vfloat32m1_t, vfloat32m1_t, vfloat32m1_t, vfloat32m1_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vsuxseg7ei8_v_m)))
void vsuxseg7ei8_v_f32m1_m(vbool32_t, float *, vuint8mf4_t, vfloat32m1_t, vfloat32m1_t, vfloat32m1_t, vfloat32m1_t, vfloat32m1_t, vfloat32m1_t, vfloat32m1_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vsuxseg7ei8_v)))
void vsuxseg7ei8_v_f32mf2(float *, vuint8mf8_t, vfloat32mf2_t, vfloat32mf2_t, vfloat32mf2_t, vfloat32mf2_t, vfloat32mf2_t, vfloat32mf2_t, vfloat32mf2_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vsuxseg7ei8_v_m)))
void vsuxseg7ei8_v_f32mf2_m(vbool64_t, float *, vuint8mf8_t, vfloat32mf2_t, vfloat32mf2_t, vfloat32mf2_t, vfloat32mf2_t, vfloat32mf2_t, vfloat32mf2_t, vfloat32mf2_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vsuxseg8ei8_v)))
void vsuxseg8ei8_v_f32m1(float *, vuint8mf4_t, vfloat32m1_t, vfloat32m1_t, vfloat32m1_t, vfloat32m1_t, vfloat32m1_t, vfloat32m1_t, vfloat32m1_t, vfloat32m1_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vsuxseg8ei8_v_m)))
void vsuxseg8ei8_v_f32m1_m(vbool32_t, float *, vuint8mf4_t, vfloat32m1_t, vfloat32m1_t, vfloat32m1_t, vfloat32m1_t, vfloat32m1_t, vfloat32m1_t, vfloat32m1_t, vfloat32m1_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vsuxseg8ei8_v)))
void vsuxseg8ei8_v_f32mf2(float *, vuint8mf8_t, vfloat32mf2_t, vfloat32mf2_t, vfloat32mf2_t, vfloat32mf2_t, vfloat32mf2_t, vfloat32mf2_t, vfloat32mf2_t, vfloat32mf2_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vsuxseg8ei8_v_m)))
void vsuxseg8ei8_v_f32mf2_m(vbool64_t, float *, vuint8mf8_t, vfloat32mf2_t, vfloat32mf2_t, vfloat32mf2_t, vfloat32mf2_t, vfloat32mf2_t, vfloat32mf2_t, vfloat32mf2_t, vfloat32mf2_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vsuxseg2ei16_v)))
void vsuxseg2ei16_v_f32m1(float *, vuint16mf2_t, vfloat32m1_t, vfloat32m1_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vsuxseg2ei16_v_m)))
void vsuxseg2ei16_v_f32m1_m(vbool32_t, float *, vuint16mf2_t, vfloat32m1_t, vfloat32m1_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vsuxseg2ei16_v)))
void vsuxseg2ei16_v_f32m2(float *, vuint16m1_t, vfloat32m2_t, vfloat32m2_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vsuxseg2ei16_v_m)))
void vsuxseg2ei16_v_f32m2_m(vbool16_t, float *, vuint16m1_t, vfloat32m2_t, vfloat32m2_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vsuxseg2ei16_v)))
void vsuxseg2ei16_v_f32m4(float *, vuint16m2_t, vfloat32m4_t, vfloat32m4_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vsuxseg2ei16_v_m)))
void vsuxseg2ei16_v_f32m4_m(vbool8_t, float *, vuint16m2_t, vfloat32m4_t, vfloat32m4_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vsuxseg2ei16_v)))
void vsuxseg2ei16_v_f32mf2(float *, vuint16mf4_t, vfloat32mf2_t, vfloat32mf2_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vsuxseg2ei16_v_m)))
void vsuxseg2ei16_v_f32mf2_m(vbool64_t, float *, vuint16mf4_t, vfloat32mf2_t, vfloat32mf2_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vsuxseg3ei16_v)))
void vsuxseg3ei16_v_f32m1(float *, vuint16mf2_t, vfloat32m1_t, vfloat32m1_t, vfloat32m1_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vsuxseg3ei16_v_m)))
void vsuxseg3ei16_v_f32m1_m(vbool32_t, float *, vuint16mf2_t, vfloat32m1_t, vfloat32m1_t, vfloat32m1_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vsuxseg3ei16_v)))
void vsuxseg3ei16_v_f32m2(float *, vuint16m1_t, vfloat32m2_t, vfloat32m2_t, vfloat32m2_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vsuxseg3ei16_v_m)))
void vsuxseg3ei16_v_f32m2_m(vbool16_t, float *, vuint16m1_t, vfloat32m2_t, vfloat32m2_t, vfloat32m2_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vsuxseg3ei16_v)))
void vsuxseg3ei16_v_f32mf2(float *, vuint16mf4_t, vfloat32mf2_t, vfloat32mf2_t, vfloat32mf2_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vsuxseg3ei16_v_m)))
void vsuxseg3ei16_v_f32mf2_m(vbool64_t, float *, vuint16mf4_t, vfloat32mf2_t, vfloat32mf2_t, vfloat32mf2_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vsuxseg4ei16_v)))
void vsuxseg4ei16_v_f32m1(float *, vuint16mf2_t, vfloat32m1_t, vfloat32m1_t, vfloat32m1_t, vfloat32m1_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vsuxseg4ei16_v_m)))
void vsuxseg4ei16_v_f32m1_m(vbool32_t, float *, vuint16mf2_t, vfloat32m1_t, vfloat32m1_t, vfloat32m1_t, vfloat32m1_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vsuxseg4ei16_v)))
void vsuxseg4ei16_v_f32m2(float *, vuint16m1_t, vfloat32m2_t, vfloat32m2_t, vfloat32m2_t, vfloat32m2_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vsuxseg4ei16_v_m)))
void vsuxseg4ei16_v_f32m2_m(vbool16_t, float *, vuint16m1_t, vfloat32m2_t, vfloat32m2_t, vfloat32m2_t, vfloat32m2_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vsuxseg4ei16_v)))
void vsuxseg4ei16_v_f32mf2(float *, vuint16mf4_t, vfloat32mf2_t, vfloat32mf2_t, vfloat32mf2_t, vfloat32mf2_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vsuxseg4ei16_v_m)))
void vsuxseg4ei16_v_f32mf2_m(vbool64_t, float *, vuint16mf4_t, vfloat32mf2_t, vfloat32mf2_t, vfloat32mf2_t, vfloat32mf2_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vsuxseg5ei16_v)))
void vsuxseg5ei16_v_f32m1(float *, vuint16mf2_t, vfloat32m1_t, vfloat32m1_t, vfloat32m1_t, vfloat32m1_t, vfloat32m1_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vsuxseg5ei16_v_m)))
void vsuxseg5ei16_v_f32m1_m(vbool32_t, float *, vuint16mf2_t, vfloat32m1_t, vfloat32m1_t, vfloat32m1_t, vfloat32m1_t, vfloat32m1_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vsuxseg5ei16_v)))
void vsuxseg5ei16_v_f32mf2(float *, vuint16mf4_t, vfloat32mf2_t, vfloat32mf2_t, vfloat32mf2_t, vfloat32mf2_t, vfloat32mf2_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vsuxseg5ei16_v_m)))
void vsuxseg5ei16_v_f32mf2_m(vbool64_t, float *, vuint16mf4_t, vfloat32mf2_t, vfloat32mf2_t, vfloat32mf2_t, vfloat32mf2_t, vfloat32mf2_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vsuxseg6ei16_v)))
void vsuxseg6ei16_v_f32m1(float *, vuint16mf2_t, vfloat32m1_t, vfloat32m1_t, vfloat32m1_t, vfloat32m1_t, vfloat32m1_t, vfloat32m1_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vsuxseg6ei16_v_m)))
void vsuxseg6ei16_v_f32m1_m(vbool32_t, float *, vuint16mf2_t, vfloat32m1_t, vfloat32m1_t, vfloat32m1_t, vfloat32m1_t, vfloat32m1_t, vfloat32m1_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vsuxseg6ei16_v)))
void vsuxseg6ei16_v_f32mf2(float *, vuint16mf4_t, vfloat32mf2_t, vfloat32mf2_t, vfloat32mf2_t, vfloat32mf2_t, vfloat32mf2_t, vfloat32mf2_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vsuxseg6ei16_v_m)))
void vsuxseg6ei16_v_f32mf2_m(vbool64_t, float *, vuint16mf4_t, vfloat32mf2_t, vfloat32mf2_t, vfloat32mf2_t, vfloat32mf2_t, vfloat32mf2_t, vfloat32mf2_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vsuxseg7ei16_v)))
void vsuxseg7ei16_v_f32m1(float *, vuint16mf2_t, vfloat32m1_t, vfloat32m1_t, vfloat32m1_t, vfloat32m1_t, vfloat32m1_t, vfloat32m1_t, vfloat32m1_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vsuxseg7ei16_v_m)))
void vsuxseg7ei16_v_f32m1_m(vbool32_t, float *, vuint16mf2_t, vfloat32m1_t, vfloat32m1_t, vfloat32m1_t, vfloat32m1_t, vfloat32m1_t, vfloat32m1_t, vfloat32m1_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vsuxseg7ei16_v)))
void vsuxseg7ei16_v_f32mf2(float *, vuint16mf4_t, vfloat32mf2_t, vfloat32mf2_t, vfloat32mf2_t, vfloat32mf2_t, vfloat32mf2_t, vfloat32mf2_t, vfloat32mf2_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vsuxseg7ei16_v_m)))
void vsuxseg7ei16_v_f32mf2_m(vbool64_t, float *, vuint16mf4_t, vfloat32mf2_t, vfloat32mf2_t, vfloat32mf2_t, vfloat32mf2_t, vfloat32mf2_t, vfloat32mf2_t, vfloat32mf2_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vsuxseg8ei16_v)))
void vsuxseg8ei16_v_f32m1(float *, vuint16mf2_t, vfloat32m1_t, vfloat32m1_t, vfloat32m1_t, vfloat32m1_t, vfloat32m1_t, vfloat32m1_t, vfloat32m1_t, vfloat32m1_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vsuxseg8ei16_v_m)))
void vsuxseg8ei16_v_f32m1_m(vbool32_t, float *, vuint16mf2_t, vfloat32m1_t, vfloat32m1_t, vfloat32m1_t, vfloat32m1_t, vfloat32m1_t, vfloat32m1_t, vfloat32m1_t, vfloat32m1_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vsuxseg8ei16_v)))
void vsuxseg8ei16_v_f32mf2(float *, vuint16mf4_t, vfloat32mf2_t, vfloat32mf2_t, vfloat32mf2_t, vfloat32mf2_t, vfloat32mf2_t, vfloat32mf2_t, vfloat32mf2_t, vfloat32mf2_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vsuxseg8ei16_v_m)))
void vsuxseg8ei16_v_f32mf2_m(vbool64_t, float *, vuint16mf4_t, vfloat32mf2_t, vfloat32mf2_t, vfloat32mf2_t, vfloat32mf2_t, vfloat32mf2_t, vfloat32mf2_t, vfloat32mf2_t, vfloat32mf2_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vsuxseg2ei32_v)))
void vsuxseg2ei32_v_f32m1(float *, vuint32m1_t, vfloat32m1_t, vfloat32m1_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vsuxseg2ei32_v_m)))
void vsuxseg2ei32_v_f32m1_m(vbool32_t, float *, vuint32m1_t, vfloat32m1_t, vfloat32m1_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vsuxseg2ei32_v)))
void vsuxseg2ei32_v_f32m2(float *, vuint32m2_t, vfloat32m2_t, vfloat32m2_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vsuxseg2ei32_v_m)))
void vsuxseg2ei32_v_f32m2_m(vbool16_t, float *, vuint32m2_t, vfloat32m2_t, vfloat32m2_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vsuxseg2ei32_v)))
void vsuxseg2ei32_v_f32m4(float *, vuint32m4_t, vfloat32m4_t, vfloat32m4_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vsuxseg2ei32_v_m)))
void vsuxseg2ei32_v_f32m4_m(vbool8_t, float *, vuint32m4_t, vfloat32m4_t, vfloat32m4_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vsuxseg2ei32_v)))
void vsuxseg2ei32_v_f32mf2(float *, vuint32mf2_t, vfloat32mf2_t, vfloat32mf2_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vsuxseg2ei32_v_m)))
void vsuxseg2ei32_v_f32mf2_m(vbool64_t, float *, vuint32mf2_t, vfloat32mf2_t, vfloat32mf2_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vsuxseg3ei32_v)))
void vsuxseg3ei32_v_f32m1(float *, vuint32m1_t, vfloat32m1_t, vfloat32m1_t, vfloat32m1_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vsuxseg3ei32_v_m)))
void vsuxseg3ei32_v_f32m1_m(vbool32_t, float *, vuint32m1_t, vfloat32m1_t, vfloat32m1_t, vfloat32m1_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vsuxseg3ei32_v)))
void vsuxseg3ei32_v_f32m2(float *, vuint32m2_t, vfloat32m2_t, vfloat32m2_t, vfloat32m2_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vsuxseg3ei32_v_m)))
void vsuxseg3ei32_v_f32m2_m(vbool16_t, float *, vuint32m2_t, vfloat32m2_t, vfloat32m2_t, vfloat32m2_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vsuxseg3ei32_v)))
void vsuxseg3ei32_v_f32mf2(float *, vuint32mf2_t, vfloat32mf2_t, vfloat32mf2_t, vfloat32mf2_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vsuxseg3ei32_v_m)))
void vsuxseg3ei32_v_f32mf2_m(vbool64_t, float *, vuint32mf2_t, vfloat32mf2_t, vfloat32mf2_t, vfloat32mf2_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vsuxseg4ei32_v)))
void vsuxseg4ei32_v_f32m1(float *, vuint32m1_t, vfloat32m1_t, vfloat32m1_t, vfloat32m1_t, vfloat32m1_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vsuxseg4ei32_v_m)))
void vsuxseg4ei32_v_f32m1_m(vbool32_t, float *, vuint32m1_t, vfloat32m1_t, vfloat32m1_t, vfloat32m1_t, vfloat32m1_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vsuxseg4ei32_v)))
void vsuxseg4ei32_v_f32m2(float *, vuint32m2_t, vfloat32m2_t, vfloat32m2_t, vfloat32m2_t, vfloat32m2_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vsuxseg4ei32_v_m)))
void vsuxseg4ei32_v_f32m2_m(vbool16_t, float *, vuint32m2_t, vfloat32m2_t, vfloat32m2_t, vfloat32m2_t, vfloat32m2_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vsuxseg4ei32_v)))
void vsuxseg4ei32_v_f32mf2(float *, vuint32mf2_t, vfloat32mf2_t, vfloat32mf2_t, vfloat32mf2_t, vfloat32mf2_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vsuxseg4ei32_v_m)))
void vsuxseg4ei32_v_f32mf2_m(vbool64_t, float *, vuint32mf2_t, vfloat32mf2_t, vfloat32mf2_t, vfloat32mf2_t, vfloat32mf2_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vsuxseg5ei32_v)))
void vsuxseg5ei32_v_f32m1(float *, vuint32m1_t, vfloat32m1_t, vfloat32m1_t, vfloat32m1_t, vfloat32m1_t, vfloat32m1_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vsuxseg5ei32_v_m)))
void vsuxseg5ei32_v_f32m1_m(vbool32_t, float *, vuint32m1_t, vfloat32m1_t, vfloat32m1_t, vfloat32m1_t, vfloat32m1_t, vfloat32m1_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vsuxseg5ei32_v)))
void vsuxseg5ei32_v_f32mf2(float *, vuint32mf2_t, vfloat32mf2_t, vfloat32mf2_t, vfloat32mf2_t, vfloat32mf2_t, vfloat32mf2_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vsuxseg5ei32_v_m)))
void vsuxseg5ei32_v_f32mf2_m(vbool64_t, float *, vuint32mf2_t, vfloat32mf2_t, vfloat32mf2_t, vfloat32mf2_t, vfloat32mf2_t, vfloat32mf2_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vsuxseg6ei32_v)))
void vsuxseg6ei32_v_f32m1(float *, vuint32m1_t, vfloat32m1_t, vfloat32m1_t, vfloat32m1_t, vfloat32m1_t, vfloat32m1_t, vfloat32m1_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vsuxseg6ei32_v_m)))
void vsuxseg6ei32_v_f32m1_m(vbool32_t, float *, vuint32m1_t, vfloat32m1_t, vfloat32m1_t, vfloat32m1_t, vfloat32m1_t, vfloat32m1_t, vfloat32m1_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vsuxseg6ei32_v)))
void vsuxseg6ei32_v_f32mf2(float *, vuint32mf2_t, vfloat32mf2_t, vfloat32mf2_t, vfloat32mf2_t, vfloat32mf2_t, vfloat32mf2_t, vfloat32mf2_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vsuxseg6ei32_v_m)))
void vsuxseg6ei32_v_f32mf2_m(vbool64_t, float *, vuint32mf2_t, vfloat32mf2_t, vfloat32mf2_t, vfloat32mf2_t, vfloat32mf2_t, vfloat32mf2_t, vfloat32mf2_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vsuxseg7ei32_v)))
void vsuxseg7ei32_v_f32m1(float *, vuint32m1_t, vfloat32m1_t, vfloat32m1_t, vfloat32m1_t, vfloat32m1_t, vfloat32m1_t, vfloat32m1_t, vfloat32m1_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vsuxseg7ei32_v_m)))
void vsuxseg7ei32_v_f32m1_m(vbool32_t, float *, vuint32m1_t, vfloat32m1_t, vfloat32m1_t, vfloat32m1_t, vfloat32m1_t, vfloat32m1_t, vfloat32m1_t, vfloat32m1_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vsuxseg7ei32_v)))
void vsuxseg7ei32_v_f32mf2(float *, vuint32mf2_t, vfloat32mf2_t, vfloat32mf2_t, vfloat32mf2_t, vfloat32mf2_t, vfloat32mf2_t, vfloat32mf2_t, vfloat32mf2_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vsuxseg7ei32_v_m)))
void vsuxseg7ei32_v_f32mf2_m(vbool64_t, float *, vuint32mf2_t, vfloat32mf2_t, vfloat32mf2_t, vfloat32mf2_t, vfloat32mf2_t, vfloat32mf2_t, vfloat32mf2_t, vfloat32mf2_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vsuxseg8ei32_v)))
void vsuxseg8ei32_v_f32m1(float *, vuint32m1_t, vfloat32m1_t, vfloat32m1_t, vfloat32m1_t, vfloat32m1_t, vfloat32m1_t, vfloat32m1_t, vfloat32m1_t, vfloat32m1_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vsuxseg8ei32_v_m)))
void vsuxseg8ei32_v_f32m1_m(vbool32_t, float *, vuint32m1_t, vfloat32m1_t, vfloat32m1_t, vfloat32m1_t, vfloat32m1_t, vfloat32m1_t, vfloat32m1_t, vfloat32m1_t, vfloat32m1_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vsuxseg8ei32_v)))
void vsuxseg8ei32_v_f32mf2(float *, vuint32mf2_t, vfloat32mf2_t, vfloat32mf2_t, vfloat32mf2_t, vfloat32mf2_t, vfloat32mf2_t, vfloat32mf2_t, vfloat32mf2_t, vfloat32mf2_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vsuxseg8ei32_v_m)))
void vsuxseg8ei32_v_f32mf2_m(vbool64_t, float *, vuint32mf2_t, vfloat32mf2_t, vfloat32mf2_t, vfloat32mf2_t, vfloat32mf2_t, vfloat32mf2_t, vfloat32mf2_t, vfloat32mf2_t, vfloat32mf2_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vsoxseg2ei8_v)))
void vsoxseg2ei8_v_f32m1(float *, vuint8mf4_t, vfloat32m1_t, vfloat32m1_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vsoxseg2ei8_v_m)))
void vsoxseg2ei8_v_f32m1_m(vbool32_t, float *, vuint8mf4_t, vfloat32m1_t, vfloat32m1_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vsoxseg2ei8_v)))
void vsoxseg2ei8_v_f32m2(float *, vuint8mf2_t, vfloat32m2_t, vfloat32m2_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vsoxseg2ei8_v_m)))
void vsoxseg2ei8_v_f32m2_m(vbool16_t, float *, vuint8mf2_t, vfloat32m2_t, vfloat32m2_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vsoxseg2ei8_v)))
void vsoxseg2ei8_v_f32m4(float *, vuint8m1_t, vfloat32m4_t, vfloat32m4_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vsoxseg2ei8_v_m)))
void vsoxseg2ei8_v_f32m4_m(vbool8_t, float *, vuint8m1_t, vfloat32m4_t, vfloat32m4_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vsoxseg2ei8_v)))
void vsoxseg2ei8_v_f32mf2(float *, vuint8mf8_t, vfloat32mf2_t, vfloat32mf2_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vsoxseg2ei8_v_m)))
void vsoxseg2ei8_v_f32mf2_m(vbool64_t, float *, vuint8mf8_t, vfloat32mf2_t, vfloat32mf2_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vsoxseg3ei8_v)))
void vsoxseg3ei8_v_f32m1(float *, vuint8mf4_t, vfloat32m1_t, vfloat32m1_t, vfloat32m1_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vsoxseg3ei8_v_m)))
void vsoxseg3ei8_v_f32m1_m(vbool32_t, float *, vuint8mf4_t, vfloat32m1_t, vfloat32m1_t, vfloat32m1_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vsoxseg3ei8_v)))
void vsoxseg3ei8_v_f32m2(float *, vuint8mf2_t, vfloat32m2_t, vfloat32m2_t, vfloat32m2_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vsoxseg3ei8_v_m)))
void vsoxseg3ei8_v_f32m2_m(vbool16_t, float *, vuint8mf2_t, vfloat32m2_t, vfloat32m2_t, vfloat32m2_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vsoxseg3ei8_v)))
void vsoxseg3ei8_v_f32mf2(float *, vuint8mf8_t, vfloat32mf2_t, vfloat32mf2_t, vfloat32mf2_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vsoxseg3ei8_v_m)))
void vsoxseg3ei8_v_f32mf2_m(vbool64_t, float *, vuint8mf8_t, vfloat32mf2_t, vfloat32mf2_t, vfloat32mf2_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vsoxseg4ei8_v)))
void vsoxseg4ei8_v_f32m1(float *, vuint8mf4_t, vfloat32m1_t, vfloat32m1_t, vfloat32m1_t, vfloat32m1_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vsoxseg4ei8_v_m)))
void vsoxseg4ei8_v_f32m1_m(vbool32_t, float *, vuint8mf4_t, vfloat32m1_t, vfloat32m1_t, vfloat32m1_t, vfloat32m1_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vsoxseg4ei8_v)))
void vsoxseg4ei8_v_f32m2(float *, vuint8mf2_t, vfloat32m2_t, vfloat32m2_t, vfloat32m2_t, vfloat32m2_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vsoxseg4ei8_v_m)))
void vsoxseg4ei8_v_f32m2_m(vbool16_t, float *, vuint8mf2_t, vfloat32m2_t, vfloat32m2_t, vfloat32m2_t, vfloat32m2_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vsoxseg4ei8_v)))
void vsoxseg4ei8_v_f32mf2(float *, vuint8mf8_t, vfloat32mf2_t, vfloat32mf2_t, vfloat32mf2_t, vfloat32mf2_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vsoxseg4ei8_v_m)))
void vsoxseg4ei8_v_f32mf2_m(vbool64_t, float *, vuint8mf8_t, vfloat32mf2_t, vfloat32mf2_t, vfloat32mf2_t, vfloat32mf2_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vsoxseg5ei8_v)))
void vsoxseg5ei8_v_f32m1(float *, vuint8mf4_t, vfloat32m1_t, vfloat32m1_t, vfloat32m1_t, vfloat32m1_t, vfloat32m1_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vsoxseg5ei8_v_m)))
void vsoxseg5ei8_v_f32m1_m(vbool32_t, float *, vuint8mf4_t, vfloat32m1_t, vfloat32m1_t, vfloat32m1_t, vfloat32m1_t, vfloat32m1_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vsoxseg5ei8_v)))
void vsoxseg5ei8_v_f32mf2(float *, vuint8mf8_t, vfloat32mf2_t, vfloat32mf2_t, vfloat32mf2_t, vfloat32mf2_t, vfloat32mf2_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vsoxseg5ei8_v_m)))
void vsoxseg5ei8_v_f32mf2_m(vbool64_t, float *, vuint8mf8_t, vfloat32mf2_t, vfloat32mf2_t, vfloat32mf2_t, vfloat32mf2_t, vfloat32mf2_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vsoxseg6ei8_v)))
void vsoxseg6ei8_v_f32m1(float *, vuint8mf4_t, vfloat32m1_t, vfloat32m1_t, vfloat32m1_t, vfloat32m1_t, vfloat32m1_t, vfloat32m1_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vsoxseg6ei8_v_m)))
void vsoxseg6ei8_v_f32m1_m(vbool32_t, float *, vuint8mf4_t, vfloat32m1_t, vfloat32m1_t, vfloat32m1_t, vfloat32m1_t, vfloat32m1_t, vfloat32m1_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vsoxseg6ei8_v)))
void vsoxseg6ei8_v_f32mf2(float *, vuint8mf8_t, vfloat32mf2_t, vfloat32mf2_t, vfloat32mf2_t, vfloat32mf2_t, vfloat32mf2_t, vfloat32mf2_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vsoxseg6ei8_v_m)))
void vsoxseg6ei8_v_f32mf2_m(vbool64_t, float *, vuint8mf8_t, vfloat32mf2_t, vfloat32mf2_t, vfloat32mf2_t, vfloat32mf2_t, vfloat32mf2_t, vfloat32mf2_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vsoxseg7ei8_v)))
void vsoxseg7ei8_v_f32m1(float *, vuint8mf4_t, vfloat32m1_t, vfloat32m1_t, vfloat32m1_t, vfloat32m1_t, vfloat32m1_t, vfloat32m1_t, vfloat32m1_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vsoxseg7ei8_v_m)))
void vsoxseg7ei8_v_f32m1_m(vbool32_t, float *, vuint8mf4_t, vfloat32m1_t, vfloat32m1_t, vfloat32m1_t, vfloat32m1_t, vfloat32m1_t, vfloat32m1_t, vfloat32m1_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vsoxseg7ei8_v)))
void vsoxseg7ei8_v_f32mf2(float *, vuint8mf8_t, vfloat32mf2_t, vfloat32mf2_t, vfloat32mf2_t, vfloat32mf2_t, vfloat32mf2_t, vfloat32mf2_t, vfloat32mf2_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vsoxseg7ei8_v_m)))
void vsoxseg7ei8_v_f32mf2_m(vbool64_t, float *, vuint8mf8_t, vfloat32mf2_t, vfloat32mf2_t, vfloat32mf2_t, vfloat32mf2_t, vfloat32mf2_t, vfloat32mf2_t, vfloat32mf2_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vsoxseg8ei8_v)))
void vsoxseg8ei8_v_f32m1(float *, vuint8mf4_t, vfloat32m1_t, vfloat32m1_t, vfloat32m1_t, vfloat32m1_t, vfloat32m1_t, vfloat32m1_t, vfloat32m1_t, vfloat32m1_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vsoxseg8ei8_v_m)))
void vsoxseg8ei8_v_f32m1_m(vbool32_t, float *, vuint8mf4_t, vfloat32m1_t, vfloat32m1_t, vfloat32m1_t, vfloat32m1_t, vfloat32m1_t, vfloat32m1_t, vfloat32m1_t, vfloat32m1_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vsoxseg8ei8_v)))
void vsoxseg8ei8_v_f32mf2(float *, vuint8mf8_t, vfloat32mf2_t, vfloat32mf2_t, vfloat32mf2_t, vfloat32mf2_t, vfloat32mf2_t, vfloat32mf2_t, vfloat32mf2_t, vfloat32mf2_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vsoxseg8ei8_v_m)))
void vsoxseg8ei8_v_f32mf2_m(vbool64_t, float *, vuint8mf8_t, vfloat32mf2_t, vfloat32mf2_t, vfloat32mf2_t, vfloat32mf2_t, vfloat32mf2_t, vfloat32mf2_t, vfloat32mf2_t, vfloat32mf2_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vsoxseg2ei16_v)))
void vsoxseg2ei16_v_f32m1(float *, vuint16mf2_t, vfloat32m1_t, vfloat32m1_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vsoxseg2ei16_v_m)))
void vsoxseg2ei16_v_f32m1_m(vbool32_t, float *, vuint16mf2_t, vfloat32m1_t, vfloat32m1_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vsoxseg2ei16_v)))
void vsoxseg2ei16_v_f32m2(float *, vuint16m1_t, vfloat32m2_t, vfloat32m2_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vsoxseg2ei16_v_m)))
void vsoxseg2ei16_v_f32m2_m(vbool16_t, float *, vuint16m1_t, vfloat32m2_t, vfloat32m2_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vsoxseg2ei16_v)))
void vsoxseg2ei16_v_f32m4(float *, vuint16m2_t, vfloat32m4_t, vfloat32m4_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vsoxseg2ei16_v_m)))
void vsoxseg2ei16_v_f32m4_m(vbool8_t, float *, vuint16m2_t, vfloat32m4_t, vfloat32m4_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vsoxseg2ei16_v)))
void vsoxseg2ei16_v_f32mf2(float *, vuint16mf4_t, vfloat32mf2_t, vfloat32mf2_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vsoxseg2ei16_v_m)))
void vsoxseg2ei16_v_f32mf2_m(vbool64_t, float *, vuint16mf4_t, vfloat32mf2_t, vfloat32mf2_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vsoxseg3ei16_v)))
void vsoxseg3ei16_v_f32m1(float *, vuint16mf2_t, vfloat32m1_t, vfloat32m1_t, vfloat32m1_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vsoxseg3ei16_v_m)))
void vsoxseg3ei16_v_f32m1_m(vbool32_t, float *, vuint16mf2_t, vfloat32m1_t, vfloat32m1_t, vfloat32m1_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vsoxseg3ei16_v)))
void vsoxseg3ei16_v_f32m2(float *, vuint16m1_t, vfloat32m2_t, vfloat32m2_t, vfloat32m2_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vsoxseg3ei16_v_m)))
void vsoxseg3ei16_v_f32m2_m(vbool16_t, float *, vuint16m1_t, vfloat32m2_t, vfloat32m2_t, vfloat32m2_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vsoxseg3ei16_v)))
void vsoxseg3ei16_v_f32mf2(float *, vuint16mf4_t, vfloat32mf2_t, vfloat32mf2_t, vfloat32mf2_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vsoxseg3ei16_v_m)))
void vsoxseg3ei16_v_f32mf2_m(vbool64_t, float *, vuint16mf4_t, vfloat32mf2_t, vfloat32mf2_t, vfloat32mf2_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vsoxseg4ei16_v)))
void vsoxseg4ei16_v_f32m1(float *, vuint16mf2_t, vfloat32m1_t, vfloat32m1_t, vfloat32m1_t, vfloat32m1_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vsoxseg4ei16_v_m)))
void vsoxseg4ei16_v_f32m1_m(vbool32_t, float *, vuint16mf2_t, vfloat32m1_t, vfloat32m1_t, vfloat32m1_t, vfloat32m1_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vsoxseg4ei16_v)))
void vsoxseg4ei16_v_f32m2(float *, vuint16m1_t, vfloat32m2_t, vfloat32m2_t, vfloat32m2_t, vfloat32m2_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vsoxseg4ei16_v_m)))
void vsoxseg4ei16_v_f32m2_m(vbool16_t, float *, vuint16m1_t, vfloat32m2_t, vfloat32m2_t, vfloat32m2_t, vfloat32m2_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vsoxseg4ei16_v)))
void vsoxseg4ei16_v_f32mf2(float *, vuint16mf4_t, vfloat32mf2_t, vfloat32mf2_t, vfloat32mf2_t, vfloat32mf2_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vsoxseg4ei16_v_m)))
void vsoxseg4ei16_v_f32mf2_m(vbool64_t, float *, vuint16mf4_t, vfloat32mf2_t, vfloat32mf2_t, vfloat32mf2_t, vfloat32mf2_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vsoxseg5ei16_v)))
void vsoxseg5ei16_v_f32m1(float *, vuint16mf2_t, vfloat32m1_t, vfloat32m1_t, vfloat32m1_t, vfloat32m1_t, vfloat32m1_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vsoxseg5ei16_v_m)))
void vsoxseg5ei16_v_f32m1_m(vbool32_t, float *, vuint16mf2_t, vfloat32m1_t, vfloat32m1_t, vfloat32m1_t, vfloat32m1_t, vfloat32m1_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vsoxseg5ei16_v)))
void vsoxseg5ei16_v_f32mf2(float *, vuint16mf4_t, vfloat32mf2_t, vfloat32mf2_t, vfloat32mf2_t, vfloat32mf2_t, vfloat32mf2_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vsoxseg5ei16_v_m)))
void vsoxseg5ei16_v_f32mf2_m(vbool64_t, float *, vuint16mf4_t, vfloat32mf2_t, vfloat32mf2_t, vfloat32mf2_t, vfloat32mf2_t, vfloat32mf2_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vsoxseg6ei16_v)))
void vsoxseg6ei16_v_f32m1(float *, vuint16mf2_t, vfloat32m1_t, vfloat32m1_t, vfloat32m1_t, vfloat32m1_t, vfloat32m1_t, vfloat32m1_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vsoxseg6ei16_v_m)))
void vsoxseg6ei16_v_f32m1_m(vbool32_t, float *, vuint16mf2_t, vfloat32m1_t, vfloat32m1_t, vfloat32m1_t, vfloat32m1_t, vfloat32m1_t, vfloat32m1_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vsoxseg6ei16_v)))
void vsoxseg6ei16_v_f32mf2(float *, vuint16mf4_t, vfloat32mf2_t, vfloat32mf2_t, vfloat32mf2_t, vfloat32mf2_t, vfloat32mf2_t, vfloat32mf2_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vsoxseg6ei16_v_m)))
void vsoxseg6ei16_v_f32mf2_m(vbool64_t, float *, vuint16mf4_t, vfloat32mf2_t, vfloat32mf2_t, vfloat32mf2_t, vfloat32mf2_t, vfloat32mf2_t, vfloat32mf2_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vsoxseg7ei16_v)))
void vsoxseg7ei16_v_f32m1(float *, vuint16mf2_t, vfloat32m1_t, vfloat32m1_t, vfloat32m1_t, vfloat32m1_t, vfloat32m1_t, vfloat32m1_t, vfloat32m1_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vsoxseg7ei16_v_m)))
void vsoxseg7ei16_v_f32m1_m(vbool32_t, float *, vuint16mf2_t, vfloat32m1_t, vfloat32m1_t, vfloat32m1_t, vfloat32m1_t, vfloat32m1_t, vfloat32m1_t, vfloat32m1_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vsoxseg7ei16_v)))
void vsoxseg7ei16_v_f32mf2(float *, vuint16mf4_t, vfloat32mf2_t, vfloat32mf2_t, vfloat32mf2_t, vfloat32mf2_t, vfloat32mf2_t, vfloat32mf2_t, vfloat32mf2_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vsoxseg7ei16_v_m)))
void vsoxseg7ei16_v_f32mf2_m(vbool64_t, float *, vuint16mf4_t, vfloat32mf2_t, vfloat32mf2_t, vfloat32mf2_t, vfloat32mf2_t, vfloat32mf2_t, vfloat32mf2_t, vfloat32mf2_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vsoxseg8ei16_v)))
void vsoxseg8ei16_v_f32m1(float *, vuint16mf2_t, vfloat32m1_t, vfloat32m1_t, vfloat32m1_t, vfloat32m1_t, vfloat32m1_t, vfloat32m1_t, vfloat32m1_t, vfloat32m1_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vsoxseg8ei16_v_m)))
void vsoxseg8ei16_v_f32m1_m(vbool32_t, float *, vuint16mf2_t, vfloat32m1_t, vfloat32m1_t, vfloat32m1_t, vfloat32m1_t, vfloat32m1_t, vfloat32m1_t, vfloat32m1_t, vfloat32m1_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vsoxseg8ei16_v)))
void vsoxseg8ei16_v_f32mf2(float *, vuint16mf4_t, vfloat32mf2_t, vfloat32mf2_t, vfloat32mf2_t, vfloat32mf2_t, vfloat32mf2_t, vfloat32mf2_t, vfloat32mf2_t, vfloat32mf2_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vsoxseg8ei16_v_m)))
void vsoxseg8ei16_v_f32mf2_m(vbool64_t, float *, vuint16mf4_t, vfloat32mf2_t, vfloat32mf2_t, vfloat32mf2_t, vfloat32mf2_t, vfloat32mf2_t, vfloat32mf2_t, vfloat32mf2_t, vfloat32mf2_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vsoxseg2ei32_v)))
void vsoxseg2ei32_v_f32m1(float *, vuint32m1_t, vfloat32m1_t, vfloat32m1_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vsoxseg2ei32_v_m)))
void vsoxseg2ei32_v_f32m1_m(vbool32_t, float *, vuint32m1_t, vfloat32m1_t, vfloat32m1_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vsoxseg2ei32_v)))
void vsoxseg2ei32_v_f32m2(float *, vuint32m2_t, vfloat32m2_t, vfloat32m2_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vsoxseg2ei32_v_m)))
void vsoxseg2ei32_v_f32m2_m(vbool16_t, float *, vuint32m2_t, vfloat32m2_t, vfloat32m2_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vsoxseg2ei32_v)))
void vsoxseg2ei32_v_f32m4(float *, vuint32m4_t, vfloat32m4_t, vfloat32m4_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vsoxseg2ei32_v_m)))
void vsoxseg2ei32_v_f32m4_m(vbool8_t, float *, vuint32m4_t, vfloat32m4_t, vfloat32m4_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vsoxseg2ei32_v)))
void vsoxseg2ei32_v_f32mf2(float *, vuint32mf2_t, vfloat32mf2_t, vfloat32mf2_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vsoxseg2ei32_v_m)))
void vsoxseg2ei32_v_f32mf2_m(vbool64_t, float *, vuint32mf2_t, vfloat32mf2_t, vfloat32mf2_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vsoxseg3ei32_v)))
void vsoxseg3ei32_v_f32m1(float *, vuint32m1_t, vfloat32m1_t, vfloat32m1_t, vfloat32m1_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vsoxseg3ei32_v_m)))
void vsoxseg3ei32_v_f32m1_m(vbool32_t, float *, vuint32m1_t, vfloat32m1_t, vfloat32m1_t, vfloat32m1_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vsoxseg3ei32_v)))
void vsoxseg3ei32_v_f32m2(float *, vuint32m2_t, vfloat32m2_t, vfloat32m2_t, vfloat32m2_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vsoxseg3ei32_v_m)))
void vsoxseg3ei32_v_f32m2_m(vbool16_t, float *, vuint32m2_t, vfloat32m2_t, vfloat32m2_t, vfloat32m2_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vsoxseg3ei32_v)))
void vsoxseg3ei32_v_f32mf2(float *, vuint32mf2_t, vfloat32mf2_t, vfloat32mf2_t, vfloat32mf2_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vsoxseg3ei32_v_m)))
void vsoxseg3ei32_v_f32mf2_m(vbool64_t, float *, vuint32mf2_t, vfloat32mf2_t, vfloat32mf2_t, vfloat32mf2_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vsoxseg4ei32_v)))
void vsoxseg4ei32_v_f32m1(float *, vuint32m1_t, vfloat32m1_t, vfloat32m1_t, vfloat32m1_t, vfloat32m1_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vsoxseg4ei32_v_m)))
void vsoxseg4ei32_v_f32m1_m(vbool32_t, float *, vuint32m1_t, vfloat32m1_t, vfloat32m1_t, vfloat32m1_t, vfloat32m1_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vsoxseg4ei32_v)))
void vsoxseg4ei32_v_f32m2(float *, vuint32m2_t, vfloat32m2_t, vfloat32m2_t, vfloat32m2_t, vfloat32m2_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vsoxseg4ei32_v_m)))
void vsoxseg4ei32_v_f32m2_m(vbool16_t, float *, vuint32m2_t, vfloat32m2_t, vfloat32m2_t, vfloat32m2_t, vfloat32m2_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vsoxseg4ei32_v)))
void vsoxseg4ei32_v_f32mf2(float *, vuint32mf2_t, vfloat32mf2_t, vfloat32mf2_t, vfloat32mf2_t, vfloat32mf2_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vsoxseg4ei32_v_m)))
void vsoxseg4ei32_v_f32mf2_m(vbool64_t, float *, vuint32mf2_t, vfloat32mf2_t, vfloat32mf2_t, vfloat32mf2_t, vfloat32mf2_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vsoxseg5ei32_v)))
void vsoxseg5ei32_v_f32m1(float *, vuint32m1_t, vfloat32m1_t, vfloat32m1_t, vfloat32m1_t, vfloat32m1_t, vfloat32m1_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vsoxseg5ei32_v_m)))
void vsoxseg5ei32_v_f32m1_m(vbool32_t, float *, vuint32m1_t, vfloat32m1_t, vfloat32m1_t, vfloat32m1_t, vfloat32m1_t, vfloat32m1_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vsoxseg5ei32_v)))
void vsoxseg5ei32_v_f32mf2(float *, vuint32mf2_t, vfloat32mf2_t, vfloat32mf2_t, vfloat32mf2_t, vfloat32mf2_t, vfloat32mf2_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vsoxseg5ei32_v_m)))
void vsoxseg5ei32_v_f32mf2_m(vbool64_t, float *, vuint32mf2_t, vfloat32mf2_t, vfloat32mf2_t, vfloat32mf2_t, vfloat32mf2_t, vfloat32mf2_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vsoxseg6ei32_v)))
void vsoxseg6ei32_v_f32m1(float *, vuint32m1_t, vfloat32m1_t, vfloat32m1_t, vfloat32m1_t, vfloat32m1_t, vfloat32m1_t, vfloat32m1_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vsoxseg6ei32_v_m)))
void vsoxseg6ei32_v_f32m1_m(vbool32_t, float *, vuint32m1_t, vfloat32m1_t, vfloat32m1_t, vfloat32m1_t, vfloat32m1_t, vfloat32m1_t, vfloat32m1_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vsoxseg6ei32_v)))
void vsoxseg6ei32_v_f32mf2(float *, vuint32mf2_t, vfloat32mf2_t, vfloat32mf2_t, vfloat32mf2_t, vfloat32mf2_t, vfloat32mf2_t, vfloat32mf2_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vsoxseg6ei32_v_m)))
void vsoxseg6ei32_v_f32mf2_m(vbool64_t, float *, vuint32mf2_t, vfloat32mf2_t, vfloat32mf2_t, vfloat32mf2_t, vfloat32mf2_t, vfloat32mf2_t, vfloat32mf2_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vsoxseg7ei32_v)))
void vsoxseg7ei32_v_f32m1(float *, vuint32m1_t, vfloat32m1_t, vfloat32m1_t, vfloat32m1_t, vfloat32m1_t, vfloat32m1_t, vfloat32m1_t, vfloat32m1_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vsoxseg7ei32_v_m)))
void vsoxseg7ei32_v_f32m1_m(vbool32_t, float *, vuint32m1_t, vfloat32m1_t, vfloat32m1_t, vfloat32m1_t, vfloat32m1_t, vfloat32m1_t, vfloat32m1_t, vfloat32m1_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vsoxseg7ei32_v)))
void vsoxseg7ei32_v_f32mf2(float *, vuint32mf2_t, vfloat32mf2_t, vfloat32mf2_t, vfloat32mf2_t, vfloat32mf2_t, vfloat32mf2_t, vfloat32mf2_t, vfloat32mf2_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vsoxseg7ei32_v_m)))
void vsoxseg7ei32_v_f32mf2_m(vbool64_t, float *, vuint32mf2_t, vfloat32mf2_t, vfloat32mf2_t, vfloat32mf2_t, vfloat32mf2_t, vfloat32mf2_t, vfloat32mf2_t, vfloat32mf2_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vsoxseg8ei32_v)))
void vsoxseg8ei32_v_f32m1(float *, vuint32m1_t, vfloat32m1_t, vfloat32m1_t, vfloat32m1_t, vfloat32m1_t, vfloat32m1_t, vfloat32m1_t, vfloat32m1_t, vfloat32m1_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vsoxseg8ei32_v_m)))
void vsoxseg8ei32_v_f32m1_m(vbool32_t, float *, vuint32m1_t, vfloat32m1_t, vfloat32m1_t, vfloat32m1_t, vfloat32m1_t, vfloat32m1_t, vfloat32m1_t, vfloat32m1_t, vfloat32m1_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vsoxseg8ei32_v)))
void vsoxseg8ei32_v_f32mf2(float *, vuint32mf2_t, vfloat32mf2_t, vfloat32mf2_t, vfloat32mf2_t, vfloat32mf2_t, vfloat32mf2_t, vfloat32mf2_t, vfloat32mf2_t, vfloat32mf2_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vsoxseg8ei32_v_m)))
void vsoxseg8ei32_v_f32mf2_m(vbool64_t, float *, vuint32mf2_t, vfloat32mf2_t, vfloat32mf2_t, vfloat32mf2_t, vfloat32mf2_t, vfloat32mf2_t, vfloat32mf2_t, vfloat32mf2_t, vfloat32mf2_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vloxei8_v)))
vfloat32m1_t vloxei8_v_f32m1(const float *, vuint8mf4_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vloxei8_v_m)))
vfloat32m1_t vloxei8_v_f32m1_m(vbool32_t, vfloat32m1_t, const float *, vuint8mf4_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vloxei8_v)))
vfloat32m2_t vloxei8_v_f32m2(const float *, vuint8mf2_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vloxei8_v_m)))
vfloat32m2_t vloxei8_v_f32m2_m(vbool16_t, vfloat32m2_t, const float *, vuint8mf2_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vloxei8_v)))
vfloat32m4_t vloxei8_v_f32m4(const float *, vuint8m1_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vloxei8_v_m)))
vfloat32m4_t vloxei8_v_f32m4_m(vbool8_t, vfloat32m4_t, const float *, vuint8m1_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vloxei8_v)))
vfloat32m8_t vloxei8_v_f32m8(const float *, vuint8m2_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vloxei8_v_m)))
vfloat32m8_t vloxei8_v_f32m8_m(vbool4_t, vfloat32m8_t, const float *, vuint8m2_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vloxei8_v)))
vfloat32mf2_t vloxei8_v_f32mf2(const float *, vuint8mf8_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vloxei8_v_m)))
vfloat32mf2_t vloxei8_v_f32mf2_m(vbool64_t, vfloat32mf2_t, const float *, vuint8mf8_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vloxei16_v)))
vfloat32m1_t vloxei16_v_f32m1(const float *, vuint16mf2_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vloxei16_v_m)))
vfloat32m1_t vloxei16_v_f32m1_m(vbool32_t, vfloat32m1_t, const float *, vuint16mf2_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vloxei16_v)))
vfloat32m2_t vloxei16_v_f32m2(const float *, vuint16m1_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vloxei16_v_m)))
vfloat32m2_t vloxei16_v_f32m2_m(vbool16_t, vfloat32m2_t, const float *, vuint16m1_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vloxei16_v)))
vfloat32m4_t vloxei16_v_f32m4(const float *, vuint16m2_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vloxei16_v_m)))
vfloat32m4_t vloxei16_v_f32m4_m(vbool8_t, vfloat32m4_t, const float *, vuint16m2_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vloxei16_v)))
vfloat32m8_t vloxei16_v_f32m8(const float *, vuint16m4_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vloxei16_v_m)))
vfloat32m8_t vloxei16_v_f32m8_m(vbool4_t, vfloat32m8_t, const float *, vuint16m4_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vloxei16_v)))
vfloat32mf2_t vloxei16_v_f32mf2(const float *, vuint16mf4_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vloxei16_v_m)))
vfloat32mf2_t vloxei16_v_f32mf2_m(vbool64_t, vfloat32mf2_t, const float *, vuint16mf4_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vloxei32_v)))
vfloat32m1_t vloxei32_v_f32m1(const float *, vuint32m1_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vloxei32_v_m)))
vfloat32m1_t vloxei32_v_f32m1_m(vbool32_t, vfloat32m1_t, const float *, vuint32m1_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vloxei32_v)))
vfloat32m2_t vloxei32_v_f32m2(const float *, vuint32m2_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vloxei32_v_m)))
vfloat32m2_t vloxei32_v_f32m2_m(vbool16_t, vfloat32m2_t, const float *, vuint32m2_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vloxei32_v)))
vfloat32m4_t vloxei32_v_f32m4(const float *, vuint32m4_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vloxei32_v_m)))
vfloat32m4_t vloxei32_v_f32m4_m(vbool8_t, vfloat32m4_t, const float *, vuint32m4_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vloxei32_v)))
vfloat32m8_t vloxei32_v_f32m8(const float *, vuint32m8_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vloxei32_v_m)))
vfloat32m8_t vloxei32_v_f32m8_m(vbool4_t, vfloat32m8_t, const float *, vuint32m8_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vloxei32_v)))
vfloat32mf2_t vloxei32_v_f32mf2(const float *, vuint32mf2_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vloxei32_v_m)))
vfloat32mf2_t vloxei32_v_f32mf2_m(vbool64_t, vfloat32mf2_t, const float *, vuint32mf2_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vmv_v_v)))
vfloat32m1_t vmv_v_v_f32m1(vfloat32m1_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vmv_v_v)))
vfloat32m2_t vmv_v_v_f32m2(vfloat32m2_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vmv_v_v)))
vfloat32m4_t vmv_v_v_f32m4(vfloat32m4_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vmv_v_v)))
vfloat32m8_t vmv_v_v_f32m8(vfloat32m8_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vmv_v_v)))
vfloat32mf2_t vmv_v_v_f32mf2(vfloat32mf2_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vfadd_vv)))
vfloat32m1_t vfadd_vv_f32m1(vfloat32m1_t, vfloat32m1_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vfadd_vv_m)))
vfloat32m1_t vfadd_vv_f32m1_m(vbool32_t, vfloat32m1_t, vfloat32m1_t, vfloat32m1_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vfadd_vv)))
vfloat32m2_t vfadd_vv_f32m2(vfloat32m2_t, vfloat32m2_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vfadd_vv_m)))
vfloat32m2_t vfadd_vv_f32m2_m(vbool16_t, vfloat32m2_t, vfloat32m2_t, vfloat32m2_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vfadd_vv)))
vfloat32m4_t vfadd_vv_f32m4(vfloat32m4_t, vfloat32m4_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vfadd_vv_m)))
vfloat32m4_t vfadd_vv_f32m4_m(vbool8_t, vfloat32m4_t, vfloat32m4_t, vfloat32m4_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vfadd_vv)))
vfloat32m8_t vfadd_vv_f32m8(vfloat32m8_t, vfloat32m8_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vfadd_vv_m)))
vfloat32m8_t vfadd_vv_f32m8_m(vbool4_t, vfloat32m8_t, vfloat32m8_t, vfloat32m8_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vfadd_vv)))
vfloat32mf2_t vfadd_vv_f32mf2(vfloat32mf2_t, vfloat32mf2_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vfadd_vv_m)))
vfloat32mf2_t vfadd_vv_f32mf2_m(vbool64_t, vfloat32mf2_t, vfloat32mf2_t, vfloat32mf2_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vfadd_vf)))
vfloat32m1_t vfadd_vf_f32m1(vfloat32m1_t, float, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vfadd_vf_m)))
vfloat32m1_t vfadd_vf_f32m1_m(vbool32_t, vfloat32m1_t, vfloat32m1_t, float, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vfadd_vf)))
vfloat32m2_t vfadd_vf_f32m2(vfloat32m2_t, float, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vfadd_vf_m)))
vfloat32m2_t vfadd_vf_f32m2_m(vbool16_t, vfloat32m2_t, vfloat32m2_t, float, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vfadd_vf)))
vfloat32m4_t vfadd_vf_f32m4(vfloat32m4_t, float, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vfadd_vf_m)))
vfloat32m4_t vfadd_vf_f32m4_m(vbool8_t, vfloat32m4_t, vfloat32m4_t, float, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vfadd_vf)))
vfloat32m8_t vfadd_vf_f32m8(vfloat32m8_t, float, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vfadd_vf_m)))
vfloat32m8_t vfadd_vf_f32m8_m(vbool4_t, vfloat32m8_t, vfloat32m8_t, float, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vfadd_vf)))
vfloat32mf2_t vfadd_vf_f32mf2(vfloat32mf2_t, float, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vfadd_vf_m)))
vfloat32mf2_t vfadd_vf_f32mf2_m(vbool64_t, vfloat32mf2_t, vfloat32mf2_t, float, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vfsub_vv)))
vfloat32m1_t vfsub_vv_f32m1(vfloat32m1_t, vfloat32m1_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vfsub_vv_m)))
vfloat32m1_t vfsub_vv_f32m1_m(vbool32_t, vfloat32m1_t, vfloat32m1_t, vfloat32m1_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vfsub_vv)))
vfloat32m2_t vfsub_vv_f32m2(vfloat32m2_t, vfloat32m2_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vfsub_vv_m)))
vfloat32m2_t vfsub_vv_f32m2_m(vbool16_t, vfloat32m2_t, vfloat32m2_t, vfloat32m2_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vfsub_vv)))
vfloat32m4_t vfsub_vv_f32m4(vfloat32m4_t, vfloat32m4_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vfsub_vv_m)))
vfloat32m4_t vfsub_vv_f32m4_m(vbool8_t, vfloat32m4_t, vfloat32m4_t, vfloat32m4_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vfsub_vv)))
vfloat32m8_t vfsub_vv_f32m8(vfloat32m8_t, vfloat32m8_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vfsub_vv_m)))
vfloat32m8_t vfsub_vv_f32m8_m(vbool4_t, vfloat32m8_t, vfloat32m8_t, vfloat32m8_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vfsub_vv)))
vfloat32mf2_t vfsub_vv_f32mf2(vfloat32mf2_t, vfloat32mf2_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vfsub_vv_m)))
vfloat32mf2_t vfsub_vv_f32mf2_m(vbool64_t, vfloat32mf2_t, vfloat32mf2_t, vfloat32mf2_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vfsub_vf)))
vfloat32m1_t vfsub_vf_f32m1(vfloat32m1_t, float, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vfsub_vf_m)))
vfloat32m1_t vfsub_vf_f32m1_m(vbool32_t, vfloat32m1_t, vfloat32m1_t, float, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vfsub_vf)))
vfloat32m2_t vfsub_vf_f32m2(vfloat32m2_t, float, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vfsub_vf_m)))
vfloat32m2_t vfsub_vf_f32m2_m(vbool16_t, vfloat32m2_t, vfloat32m2_t, float, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vfsub_vf)))
vfloat32m4_t vfsub_vf_f32m4(vfloat32m4_t, float, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vfsub_vf_m)))
vfloat32m4_t vfsub_vf_f32m4_m(vbool8_t, vfloat32m4_t, vfloat32m4_t, float, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vfsub_vf)))
vfloat32m8_t vfsub_vf_f32m8(vfloat32m8_t, float, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vfsub_vf_m)))
vfloat32m8_t vfsub_vf_f32m8_m(vbool4_t, vfloat32m8_t, vfloat32m8_t, float, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vfsub_vf)))
vfloat32mf2_t vfsub_vf_f32mf2(vfloat32mf2_t, float, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vfsub_vf_m)))
vfloat32mf2_t vfsub_vf_f32mf2_m(vbool64_t, vfloat32mf2_t, vfloat32mf2_t, float, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vfrsub_vf)))
vfloat32m1_t vfrsub_vf_f32m1(vfloat32m1_t, float, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vfrsub_vf_m)))
vfloat32m1_t vfrsub_vf_f32m1_m(vbool32_t, vfloat32m1_t, vfloat32m1_t, float, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vfrsub_vf)))
vfloat32m2_t vfrsub_vf_f32m2(vfloat32m2_t, float, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vfrsub_vf_m)))
vfloat32m2_t vfrsub_vf_f32m2_m(vbool16_t, vfloat32m2_t, vfloat32m2_t, float, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vfrsub_vf)))
vfloat32m4_t vfrsub_vf_f32m4(vfloat32m4_t, float, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vfrsub_vf_m)))
vfloat32m4_t vfrsub_vf_f32m4_m(vbool8_t, vfloat32m4_t, vfloat32m4_t, float, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vfrsub_vf)))
vfloat32m8_t vfrsub_vf_f32m8(vfloat32m8_t, float, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vfrsub_vf_m)))
vfloat32m8_t vfrsub_vf_f32m8_m(vbool4_t, vfloat32m8_t, vfloat32m8_t, float, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vfrsub_vf)))
vfloat32mf2_t vfrsub_vf_f32mf2(vfloat32mf2_t, float, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vfrsub_vf_m)))
vfloat32mf2_t vfrsub_vf_f32mf2_m(vbool64_t, vfloat32mf2_t, vfloat32mf2_t, float, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vfmul_vv)))
vfloat32m1_t vfmul_vv_f32m1(vfloat32m1_t, vfloat32m1_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vfmul_vv_m)))
vfloat32m1_t vfmul_vv_f32m1_m(vbool32_t, vfloat32m1_t, vfloat32m1_t, vfloat32m1_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vfmul_vv)))
vfloat32m2_t vfmul_vv_f32m2(vfloat32m2_t, vfloat32m2_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vfmul_vv_m)))
vfloat32m2_t vfmul_vv_f32m2_m(vbool16_t, vfloat32m2_t, vfloat32m2_t, vfloat32m2_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vfmul_vv)))
vfloat32m4_t vfmul_vv_f32m4(vfloat32m4_t, vfloat32m4_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vfmul_vv_m)))
vfloat32m4_t vfmul_vv_f32m4_m(vbool8_t, vfloat32m4_t, vfloat32m4_t, vfloat32m4_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vfmul_vv)))
vfloat32m8_t vfmul_vv_f32m8(vfloat32m8_t, vfloat32m8_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vfmul_vv_m)))
vfloat32m8_t vfmul_vv_f32m8_m(vbool4_t, vfloat32m8_t, vfloat32m8_t, vfloat32m8_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vfmul_vv)))
vfloat32mf2_t vfmul_vv_f32mf2(vfloat32mf2_t, vfloat32mf2_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vfmul_vv_m)))
vfloat32mf2_t vfmul_vv_f32mf2_m(vbool64_t, vfloat32mf2_t, vfloat32mf2_t, vfloat32mf2_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vfmul_vf)))
vfloat32m1_t vfmul_vf_f32m1(vfloat32m1_t, float, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vfmul_vf_m)))
vfloat32m1_t vfmul_vf_f32m1_m(vbool32_t, vfloat32m1_t, vfloat32m1_t, float, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vfmul_vf)))
vfloat32m2_t vfmul_vf_f32m2(vfloat32m2_t, float, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vfmul_vf_m)))
vfloat32m2_t vfmul_vf_f32m2_m(vbool16_t, vfloat32m2_t, vfloat32m2_t, float, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vfmul_vf)))
vfloat32m4_t vfmul_vf_f32m4(vfloat32m4_t, float, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vfmul_vf_m)))
vfloat32m4_t vfmul_vf_f32m4_m(vbool8_t, vfloat32m4_t, vfloat32m4_t, float, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vfmul_vf)))
vfloat32m8_t vfmul_vf_f32m8(vfloat32m8_t, float, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vfmul_vf_m)))
vfloat32m8_t vfmul_vf_f32m8_m(vbool4_t, vfloat32m8_t, vfloat32m8_t, float, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vfmul_vf)))
vfloat32mf2_t vfmul_vf_f32mf2(vfloat32mf2_t, float, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vfmul_vf_m)))
vfloat32mf2_t vfmul_vf_f32mf2_m(vbool64_t, vfloat32mf2_t, vfloat32mf2_t, float, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vfdiv_vv)))
vfloat32m1_t vfdiv_vv_f32m1(vfloat32m1_t, vfloat32m1_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vfdiv_vv_m)))
vfloat32m1_t vfdiv_vv_f32m1_m(vbool32_t, vfloat32m1_t, vfloat32m1_t, vfloat32m1_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vfdiv_vv)))
vfloat32m2_t vfdiv_vv_f32m2(vfloat32m2_t, vfloat32m2_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vfdiv_vv_m)))
vfloat32m2_t vfdiv_vv_f32m2_m(vbool16_t, vfloat32m2_t, vfloat32m2_t, vfloat32m2_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vfdiv_vv)))
vfloat32m4_t vfdiv_vv_f32m4(vfloat32m4_t, vfloat32m4_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vfdiv_vv_m)))
vfloat32m4_t vfdiv_vv_f32m4_m(vbool8_t, vfloat32m4_t, vfloat32m4_t, vfloat32m4_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vfdiv_vv)))
vfloat32m8_t vfdiv_vv_f32m8(vfloat32m8_t, vfloat32m8_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vfdiv_vv_m)))
vfloat32m8_t vfdiv_vv_f32m8_m(vbool4_t, vfloat32m8_t, vfloat32m8_t, vfloat32m8_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vfdiv_vv)))
vfloat32mf2_t vfdiv_vv_f32mf2(vfloat32mf2_t, vfloat32mf2_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vfdiv_vv_m)))
vfloat32mf2_t vfdiv_vv_f32mf2_m(vbool64_t, vfloat32mf2_t, vfloat32mf2_t, vfloat32mf2_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vfdiv_vf)))
vfloat32m1_t vfdiv_vf_f32m1(vfloat32m1_t, float, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vfdiv_vf_m)))
vfloat32m1_t vfdiv_vf_f32m1_m(vbool32_t, vfloat32m1_t, vfloat32m1_t, float, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vfdiv_vf)))
vfloat32m2_t vfdiv_vf_f32m2(vfloat32m2_t, float, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vfdiv_vf_m)))
vfloat32m2_t vfdiv_vf_f32m2_m(vbool16_t, vfloat32m2_t, vfloat32m2_t, float, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vfdiv_vf)))
vfloat32m4_t vfdiv_vf_f32m4(vfloat32m4_t, float, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vfdiv_vf_m)))
vfloat32m4_t vfdiv_vf_f32m4_m(vbool8_t, vfloat32m4_t, vfloat32m4_t, float, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vfdiv_vf)))
vfloat32m8_t vfdiv_vf_f32m8(vfloat32m8_t, float, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vfdiv_vf_m)))
vfloat32m8_t vfdiv_vf_f32m8_m(vbool4_t, vfloat32m8_t, vfloat32m8_t, float, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vfdiv_vf)))
vfloat32mf2_t vfdiv_vf_f32mf2(vfloat32mf2_t, float, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vfdiv_vf_m)))
vfloat32mf2_t vfdiv_vf_f32mf2_m(vbool64_t, vfloat32mf2_t, vfloat32mf2_t, float, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vfrdiv_vf)))
vfloat32m1_t vfrdiv_vf_f32m1(vfloat32m1_t, float, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vfrdiv_vf_m)))
vfloat32m1_t vfrdiv_vf_f32m1_m(vbool32_t, vfloat32m1_t, vfloat32m1_t, float, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vfrdiv_vf)))
vfloat32m2_t vfrdiv_vf_f32m2(vfloat32m2_t, float, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vfrdiv_vf_m)))
vfloat32m2_t vfrdiv_vf_f32m2_m(vbool16_t, vfloat32m2_t, vfloat32m2_t, float, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vfrdiv_vf)))
vfloat32m4_t vfrdiv_vf_f32m4(vfloat32m4_t, float, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vfrdiv_vf_m)))
vfloat32m4_t vfrdiv_vf_f32m4_m(vbool8_t, vfloat32m4_t, vfloat32m4_t, float, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vfrdiv_vf)))
vfloat32m8_t vfrdiv_vf_f32m8(vfloat32m8_t, float, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vfrdiv_vf_m)))
vfloat32m8_t vfrdiv_vf_f32m8_m(vbool4_t, vfloat32m8_t, vfloat32m8_t, float, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vfrdiv_vf)))
vfloat32mf2_t vfrdiv_vf_f32mf2(vfloat32mf2_t, float, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vfrdiv_vf_m)))
vfloat32mf2_t vfrdiv_vf_f32mf2_m(vbool64_t, vfloat32mf2_t, vfloat32mf2_t, float, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vfmacc_vv)))
vfloat32m1_t vfmacc_vv_f32m1(vfloat32m1_t, vfloat32m1_t, vfloat32m1_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vfmacc_vv_m)))
vfloat32m1_t vfmacc_vv_f32m1_m(vbool32_t, vfloat32m1_t, vfloat32m1_t, vfloat32m1_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vfmacc_vv)))
vfloat32m2_t vfmacc_vv_f32m2(vfloat32m2_t, vfloat32m2_t, vfloat32m2_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vfmacc_vv_m)))
vfloat32m2_t vfmacc_vv_f32m2_m(vbool16_t, vfloat32m2_t, vfloat32m2_t, vfloat32m2_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vfmacc_vv)))
vfloat32m4_t vfmacc_vv_f32m4(vfloat32m4_t, vfloat32m4_t, vfloat32m4_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vfmacc_vv_m)))
vfloat32m4_t vfmacc_vv_f32m4_m(vbool8_t, vfloat32m4_t, vfloat32m4_t, vfloat32m4_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vfmacc_vv)))
vfloat32m8_t vfmacc_vv_f32m8(vfloat32m8_t, vfloat32m8_t, vfloat32m8_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vfmacc_vv_m)))
vfloat32m8_t vfmacc_vv_f32m8_m(vbool4_t, vfloat32m8_t, vfloat32m8_t, vfloat32m8_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vfmacc_vv)))
vfloat32mf2_t vfmacc_vv_f32mf2(vfloat32mf2_t, vfloat32mf2_t, vfloat32mf2_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vfmacc_vv_m)))
vfloat32mf2_t vfmacc_vv_f32mf2_m(vbool64_t, vfloat32mf2_t, vfloat32mf2_t, vfloat32mf2_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vfmacc_vf)))
vfloat32m1_t vfmacc_vf_f32m1(vfloat32m1_t, float, vfloat32m1_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vfmacc_vf_m)))
vfloat32m1_t vfmacc_vf_f32m1_m(vbool32_t, vfloat32m1_t, float, vfloat32m1_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vfmacc_vf)))
vfloat32m2_t vfmacc_vf_f32m2(vfloat32m2_t, float, vfloat32m2_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vfmacc_vf_m)))
vfloat32m2_t vfmacc_vf_f32m2_m(vbool16_t, vfloat32m2_t, float, vfloat32m2_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vfmacc_vf)))
vfloat32m4_t vfmacc_vf_f32m4(vfloat32m4_t, float, vfloat32m4_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vfmacc_vf_m)))
vfloat32m4_t vfmacc_vf_f32m4_m(vbool8_t, vfloat32m4_t, float, vfloat32m4_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vfmacc_vf)))
vfloat32m8_t vfmacc_vf_f32m8(vfloat32m8_t, float, vfloat32m8_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vfmacc_vf_m)))
vfloat32m8_t vfmacc_vf_f32m8_m(vbool4_t, vfloat32m8_t, float, vfloat32m8_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vfmacc_vf)))
vfloat32mf2_t vfmacc_vf_f32mf2(vfloat32mf2_t, float, vfloat32mf2_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vfmacc_vf_m)))
vfloat32mf2_t vfmacc_vf_f32mf2_m(vbool64_t, vfloat32mf2_t, float, vfloat32mf2_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vfnmacc_vv)))
vfloat32m1_t vfnmacc_vv_f32m1(vfloat32m1_t, vfloat32m1_t, vfloat32m1_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vfnmacc_vv_m)))
vfloat32m1_t vfnmacc_vv_f32m1_m(vbool32_t, vfloat32m1_t, vfloat32m1_t, vfloat32m1_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vfnmacc_vv)))
vfloat32m2_t vfnmacc_vv_f32m2(vfloat32m2_t, vfloat32m2_t, vfloat32m2_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vfnmacc_vv_m)))
vfloat32m2_t vfnmacc_vv_f32m2_m(vbool16_t, vfloat32m2_t, vfloat32m2_t, vfloat32m2_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vfnmacc_vv)))
vfloat32m4_t vfnmacc_vv_f32m4(vfloat32m4_t, vfloat32m4_t, vfloat32m4_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vfnmacc_vv_m)))
vfloat32m4_t vfnmacc_vv_f32m4_m(vbool8_t, vfloat32m4_t, vfloat32m4_t, vfloat32m4_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vfnmacc_vv)))
vfloat32m8_t vfnmacc_vv_f32m8(vfloat32m8_t, vfloat32m8_t, vfloat32m8_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vfnmacc_vv_m)))
vfloat32m8_t vfnmacc_vv_f32m8_m(vbool4_t, vfloat32m8_t, vfloat32m8_t, vfloat32m8_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vfnmacc_vv)))
vfloat32mf2_t vfnmacc_vv_f32mf2(vfloat32mf2_t, vfloat32mf2_t, vfloat32mf2_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vfnmacc_vv_m)))
vfloat32mf2_t vfnmacc_vv_f32mf2_m(vbool64_t, vfloat32mf2_t, vfloat32mf2_t, vfloat32mf2_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vfnmacc_vf)))
vfloat32m1_t vfnmacc_vf_f32m1(vfloat32m1_t, float, vfloat32m1_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vfnmacc_vf_m)))
vfloat32m1_t vfnmacc_vf_f32m1_m(vbool32_t, vfloat32m1_t, float, vfloat32m1_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vfnmacc_vf)))
vfloat32m2_t vfnmacc_vf_f32m2(vfloat32m2_t, float, vfloat32m2_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vfnmacc_vf_m)))
vfloat32m2_t vfnmacc_vf_f32m2_m(vbool16_t, vfloat32m2_t, float, vfloat32m2_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vfnmacc_vf)))
vfloat32m4_t vfnmacc_vf_f32m4(vfloat32m4_t, float, vfloat32m4_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vfnmacc_vf_m)))
vfloat32m4_t vfnmacc_vf_f32m4_m(vbool8_t, vfloat32m4_t, float, vfloat32m4_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vfnmacc_vf)))
vfloat32m8_t vfnmacc_vf_f32m8(vfloat32m8_t, float, vfloat32m8_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vfnmacc_vf_m)))
vfloat32m8_t vfnmacc_vf_f32m8_m(vbool4_t, vfloat32m8_t, float, vfloat32m8_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vfnmacc_vf)))
vfloat32mf2_t vfnmacc_vf_f32mf2(vfloat32mf2_t, float, vfloat32mf2_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vfnmacc_vf_m)))
vfloat32mf2_t vfnmacc_vf_f32mf2_m(vbool64_t, vfloat32mf2_t, float, vfloat32mf2_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vfmsac_vv)))
vfloat32m1_t vfmsac_vv_f32m1(vfloat32m1_t, vfloat32m1_t, vfloat32m1_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vfmsac_vv_m)))
vfloat32m1_t vfmsac_vv_f32m1_m(vbool32_t, vfloat32m1_t, vfloat32m1_t, vfloat32m1_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vfmsac_vv)))
vfloat32m2_t vfmsac_vv_f32m2(vfloat32m2_t, vfloat32m2_t, vfloat32m2_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vfmsac_vv_m)))
vfloat32m2_t vfmsac_vv_f32m2_m(vbool16_t, vfloat32m2_t, vfloat32m2_t, vfloat32m2_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vfmsac_vv)))
vfloat32m4_t vfmsac_vv_f32m4(vfloat32m4_t, vfloat32m4_t, vfloat32m4_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vfmsac_vv_m)))
vfloat32m4_t vfmsac_vv_f32m4_m(vbool8_t, vfloat32m4_t, vfloat32m4_t, vfloat32m4_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vfmsac_vv)))
vfloat32m8_t vfmsac_vv_f32m8(vfloat32m8_t, vfloat32m8_t, vfloat32m8_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vfmsac_vv_m)))
vfloat32m8_t vfmsac_vv_f32m8_m(vbool4_t, vfloat32m8_t, vfloat32m8_t, vfloat32m8_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vfmsac_vv)))
vfloat32mf2_t vfmsac_vv_f32mf2(vfloat32mf2_t, vfloat32mf2_t, vfloat32mf2_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vfmsac_vv_m)))
vfloat32mf2_t vfmsac_vv_f32mf2_m(vbool64_t, vfloat32mf2_t, vfloat32mf2_t, vfloat32mf2_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vfmsac_vf)))
vfloat32m1_t vfmsac_vf_f32m1(vfloat32m1_t, float, vfloat32m1_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vfmsac_vf_m)))
vfloat32m1_t vfmsac_vf_f32m1_m(vbool32_t, vfloat32m1_t, float, vfloat32m1_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vfmsac_vf)))
vfloat32m2_t vfmsac_vf_f32m2(vfloat32m2_t, float, vfloat32m2_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vfmsac_vf_m)))
vfloat32m2_t vfmsac_vf_f32m2_m(vbool16_t, vfloat32m2_t, float, vfloat32m2_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vfmsac_vf)))
vfloat32m4_t vfmsac_vf_f32m4(vfloat32m4_t, float, vfloat32m4_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vfmsac_vf_m)))
vfloat32m4_t vfmsac_vf_f32m4_m(vbool8_t, vfloat32m4_t, float, vfloat32m4_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vfmsac_vf)))
vfloat32m8_t vfmsac_vf_f32m8(vfloat32m8_t, float, vfloat32m8_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vfmsac_vf_m)))
vfloat32m8_t vfmsac_vf_f32m8_m(vbool4_t, vfloat32m8_t, float, vfloat32m8_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vfmsac_vf)))
vfloat32mf2_t vfmsac_vf_f32mf2(vfloat32mf2_t, float, vfloat32mf2_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vfmsac_vf_m)))
vfloat32mf2_t vfmsac_vf_f32mf2_m(vbool64_t, vfloat32mf2_t, float, vfloat32mf2_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vfnmsac_vv)))
vfloat32m1_t vfnmsac_vv_f32m1(vfloat32m1_t, vfloat32m1_t, vfloat32m1_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vfnmsac_vv_m)))
vfloat32m1_t vfnmsac_vv_f32m1_m(vbool32_t, vfloat32m1_t, vfloat32m1_t, vfloat32m1_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vfnmsac_vv)))
vfloat32m2_t vfnmsac_vv_f32m2(vfloat32m2_t, vfloat32m2_t, vfloat32m2_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vfnmsac_vv_m)))
vfloat32m2_t vfnmsac_vv_f32m2_m(vbool16_t, vfloat32m2_t, vfloat32m2_t, vfloat32m2_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vfnmsac_vv)))
vfloat32m4_t vfnmsac_vv_f32m4(vfloat32m4_t, vfloat32m4_t, vfloat32m4_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vfnmsac_vv_m)))
vfloat32m4_t vfnmsac_vv_f32m4_m(vbool8_t, vfloat32m4_t, vfloat32m4_t, vfloat32m4_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vfnmsac_vv)))
vfloat32m8_t vfnmsac_vv_f32m8(vfloat32m8_t, vfloat32m8_t, vfloat32m8_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vfnmsac_vv_m)))
vfloat32m8_t vfnmsac_vv_f32m8_m(vbool4_t, vfloat32m8_t, vfloat32m8_t, vfloat32m8_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vfnmsac_vv)))
vfloat32mf2_t vfnmsac_vv_f32mf2(vfloat32mf2_t, vfloat32mf2_t, vfloat32mf2_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vfnmsac_vv_m)))
vfloat32mf2_t vfnmsac_vv_f32mf2_m(vbool64_t, vfloat32mf2_t, vfloat32mf2_t, vfloat32mf2_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vfnmsac_vf)))
vfloat32m1_t vfnmsac_vf_f32m1(vfloat32m1_t, float, vfloat32m1_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vfnmsac_vf_m)))
vfloat32m1_t vfnmsac_vf_f32m1_m(vbool32_t, vfloat32m1_t, float, vfloat32m1_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vfnmsac_vf)))
vfloat32m2_t vfnmsac_vf_f32m2(vfloat32m2_t, float, vfloat32m2_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vfnmsac_vf_m)))
vfloat32m2_t vfnmsac_vf_f32m2_m(vbool16_t, vfloat32m2_t, float, vfloat32m2_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vfnmsac_vf)))
vfloat32m4_t vfnmsac_vf_f32m4(vfloat32m4_t, float, vfloat32m4_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vfnmsac_vf_m)))
vfloat32m4_t vfnmsac_vf_f32m4_m(vbool8_t, vfloat32m4_t, float, vfloat32m4_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vfnmsac_vf)))
vfloat32m8_t vfnmsac_vf_f32m8(vfloat32m8_t, float, vfloat32m8_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vfnmsac_vf_m)))
vfloat32m8_t vfnmsac_vf_f32m8_m(vbool4_t, vfloat32m8_t, float, vfloat32m8_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vfnmsac_vf)))
vfloat32mf2_t vfnmsac_vf_f32mf2(vfloat32mf2_t, float, vfloat32mf2_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vfnmsac_vf_m)))
vfloat32mf2_t vfnmsac_vf_f32mf2_m(vbool64_t, vfloat32mf2_t, float, vfloat32mf2_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vfmadd_vv)))
vfloat32m1_t vfmadd_vv_f32m1(vfloat32m1_t, vfloat32m1_t, vfloat32m1_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vfmadd_vv_m)))
vfloat32m1_t vfmadd_vv_f32m1_m(vbool32_t, vfloat32m1_t, vfloat32m1_t, vfloat32m1_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vfmadd_vv)))
vfloat32m2_t vfmadd_vv_f32m2(vfloat32m2_t, vfloat32m2_t, vfloat32m2_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vfmadd_vv_m)))
vfloat32m2_t vfmadd_vv_f32m2_m(vbool16_t, vfloat32m2_t, vfloat32m2_t, vfloat32m2_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vfmadd_vv)))
vfloat32m4_t vfmadd_vv_f32m4(vfloat32m4_t, vfloat32m4_t, vfloat32m4_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vfmadd_vv_m)))
vfloat32m4_t vfmadd_vv_f32m4_m(vbool8_t, vfloat32m4_t, vfloat32m4_t, vfloat32m4_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vfmadd_vv)))
vfloat32m8_t vfmadd_vv_f32m8(vfloat32m8_t, vfloat32m8_t, vfloat32m8_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vfmadd_vv_m)))
vfloat32m8_t vfmadd_vv_f32m8_m(vbool4_t, vfloat32m8_t, vfloat32m8_t, vfloat32m8_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vfmadd_vv)))
vfloat32mf2_t vfmadd_vv_f32mf2(vfloat32mf2_t, vfloat32mf2_t, vfloat32mf2_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vfmadd_vv_m)))
vfloat32mf2_t vfmadd_vv_f32mf2_m(vbool64_t, vfloat32mf2_t, vfloat32mf2_t, vfloat32mf2_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vfmadd_vf)))
vfloat32m1_t vfmadd_vf_f32m1(vfloat32m1_t, float, vfloat32m1_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vfmadd_vf_m)))
vfloat32m1_t vfmadd_vf_f32m1_m(vbool32_t, vfloat32m1_t, float, vfloat32m1_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vfmadd_vf)))
vfloat32m2_t vfmadd_vf_f32m2(vfloat32m2_t, float, vfloat32m2_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vfmadd_vf_m)))
vfloat32m2_t vfmadd_vf_f32m2_m(vbool16_t, vfloat32m2_t, float, vfloat32m2_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vfmadd_vf)))
vfloat32m4_t vfmadd_vf_f32m4(vfloat32m4_t, float, vfloat32m4_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vfmadd_vf_m)))
vfloat32m4_t vfmadd_vf_f32m4_m(vbool8_t, vfloat32m4_t, float, vfloat32m4_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vfmadd_vf)))
vfloat32m8_t vfmadd_vf_f32m8(vfloat32m8_t, float, vfloat32m8_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vfmadd_vf_m)))
vfloat32m8_t vfmadd_vf_f32m8_m(vbool4_t, vfloat32m8_t, float, vfloat32m8_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vfmadd_vf)))
vfloat32mf2_t vfmadd_vf_f32mf2(vfloat32mf2_t, float, vfloat32mf2_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vfmadd_vf_m)))
vfloat32mf2_t vfmadd_vf_f32mf2_m(vbool64_t, vfloat32mf2_t, float, vfloat32mf2_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vfnmadd_vv)))
vfloat32m1_t vfnmadd_vv_f32m1(vfloat32m1_t, vfloat32m1_t, vfloat32m1_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vfnmadd_vv_m)))
vfloat32m1_t vfnmadd_vv_f32m1_m(vbool32_t, vfloat32m1_t, vfloat32m1_t, vfloat32m1_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vfnmadd_vv)))
vfloat32m2_t vfnmadd_vv_f32m2(vfloat32m2_t, vfloat32m2_t, vfloat32m2_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vfnmadd_vv_m)))
vfloat32m2_t vfnmadd_vv_f32m2_m(vbool16_t, vfloat32m2_t, vfloat32m2_t, vfloat32m2_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vfnmadd_vv)))
vfloat32m4_t vfnmadd_vv_f32m4(vfloat32m4_t, vfloat32m4_t, vfloat32m4_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vfnmadd_vv_m)))
vfloat32m4_t vfnmadd_vv_f32m4_m(vbool8_t, vfloat32m4_t, vfloat32m4_t, vfloat32m4_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vfnmadd_vv)))
vfloat32m8_t vfnmadd_vv_f32m8(vfloat32m8_t, vfloat32m8_t, vfloat32m8_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vfnmadd_vv_m)))
vfloat32m8_t vfnmadd_vv_f32m8_m(vbool4_t, vfloat32m8_t, vfloat32m8_t, vfloat32m8_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vfnmadd_vv)))
vfloat32mf2_t vfnmadd_vv_f32mf2(vfloat32mf2_t, vfloat32mf2_t, vfloat32mf2_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vfnmadd_vv_m)))
vfloat32mf2_t vfnmadd_vv_f32mf2_m(vbool64_t, vfloat32mf2_t, vfloat32mf2_t, vfloat32mf2_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vfnmadd_vf)))
vfloat32m1_t vfnmadd_vf_f32m1(vfloat32m1_t, float, vfloat32m1_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vfnmadd_vf_m)))
vfloat32m1_t vfnmadd_vf_f32m1_m(vbool32_t, vfloat32m1_t, float, vfloat32m1_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vfnmadd_vf)))
vfloat32m2_t vfnmadd_vf_f32m2(vfloat32m2_t, float, vfloat32m2_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vfnmadd_vf_m)))
vfloat32m2_t vfnmadd_vf_f32m2_m(vbool16_t, vfloat32m2_t, float, vfloat32m2_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vfnmadd_vf)))
vfloat32m4_t vfnmadd_vf_f32m4(vfloat32m4_t, float, vfloat32m4_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vfnmadd_vf_m)))
vfloat32m4_t vfnmadd_vf_f32m4_m(vbool8_t, vfloat32m4_t, float, vfloat32m4_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vfnmadd_vf)))
vfloat32m8_t vfnmadd_vf_f32m8(vfloat32m8_t, float, vfloat32m8_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vfnmadd_vf_m)))
vfloat32m8_t vfnmadd_vf_f32m8_m(vbool4_t, vfloat32m8_t, float, vfloat32m8_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vfnmadd_vf)))
vfloat32mf2_t vfnmadd_vf_f32mf2(vfloat32mf2_t, float, vfloat32mf2_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vfnmadd_vf_m)))
vfloat32mf2_t vfnmadd_vf_f32mf2_m(vbool64_t, vfloat32mf2_t, float, vfloat32mf2_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vfmsub_vv)))
vfloat32m1_t vfmsub_vv_f32m1(vfloat32m1_t, vfloat32m1_t, vfloat32m1_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vfmsub_vv_m)))
vfloat32m1_t vfmsub_vv_f32m1_m(vbool32_t, vfloat32m1_t, vfloat32m1_t, vfloat32m1_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vfmsub_vv)))
vfloat32m2_t vfmsub_vv_f32m2(vfloat32m2_t, vfloat32m2_t, vfloat32m2_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vfmsub_vv_m)))
vfloat32m2_t vfmsub_vv_f32m2_m(vbool16_t, vfloat32m2_t, vfloat32m2_t, vfloat32m2_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vfmsub_vv)))
vfloat32m4_t vfmsub_vv_f32m4(vfloat32m4_t, vfloat32m4_t, vfloat32m4_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vfmsub_vv_m)))
vfloat32m4_t vfmsub_vv_f32m4_m(vbool8_t, vfloat32m4_t, vfloat32m4_t, vfloat32m4_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vfmsub_vv)))
vfloat32m8_t vfmsub_vv_f32m8(vfloat32m8_t, vfloat32m8_t, vfloat32m8_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vfmsub_vv_m)))
vfloat32m8_t vfmsub_vv_f32m8_m(vbool4_t, vfloat32m8_t, vfloat32m8_t, vfloat32m8_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vfmsub_vv)))
vfloat32mf2_t vfmsub_vv_f32mf2(vfloat32mf2_t, vfloat32mf2_t, vfloat32mf2_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vfmsub_vv_m)))
vfloat32mf2_t vfmsub_vv_f32mf2_m(vbool64_t, vfloat32mf2_t, vfloat32mf2_t, vfloat32mf2_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vfmsub_vf)))
vfloat32m1_t vfmsub_vf_f32m1(vfloat32m1_t, float, vfloat32m1_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vfmsub_vf_m)))
vfloat32m1_t vfmsub_vf_f32m1_m(vbool32_t, vfloat32m1_t, float, vfloat32m1_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vfmsub_vf)))
vfloat32m2_t vfmsub_vf_f32m2(vfloat32m2_t, float, vfloat32m2_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vfmsub_vf_m)))
vfloat32m2_t vfmsub_vf_f32m2_m(vbool16_t, vfloat32m2_t, float, vfloat32m2_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vfmsub_vf)))
vfloat32m4_t vfmsub_vf_f32m4(vfloat32m4_t, float, vfloat32m4_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vfmsub_vf_m)))
vfloat32m4_t vfmsub_vf_f32m4_m(vbool8_t, vfloat32m4_t, float, vfloat32m4_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vfmsub_vf)))
vfloat32m8_t vfmsub_vf_f32m8(vfloat32m8_t, float, vfloat32m8_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vfmsub_vf_m)))
vfloat32m8_t vfmsub_vf_f32m8_m(vbool4_t, vfloat32m8_t, float, vfloat32m8_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vfmsub_vf)))
vfloat32mf2_t vfmsub_vf_f32mf2(vfloat32mf2_t, float, vfloat32mf2_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vfmsub_vf_m)))
vfloat32mf2_t vfmsub_vf_f32mf2_m(vbool64_t, vfloat32mf2_t, float, vfloat32mf2_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vfnmsub_vv)))
vfloat32m1_t vfnmsub_vv_f32m1(vfloat32m1_t, vfloat32m1_t, vfloat32m1_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vfnmsub_vv_m)))
vfloat32m1_t vfnmsub_vv_f32m1_m(vbool32_t, vfloat32m1_t, vfloat32m1_t, vfloat32m1_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vfnmsub_vv)))
vfloat32m2_t vfnmsub_vv_f32m2(vfloat32m2_t, vfloat32m2_t, vfloat32m2_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vfnmsub_vv_m)))
vfloat32m2_t vfnmsub_vv_f32m2_m(vbool16_t, vfloat32m2_t, vfloat32m2_t, vfloat32m2_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vfnmsub_vv)))
vfloat32m4_t vfnmsub_vv_f32m4(vfloat32m4_t, vfloat32m4_t, vfloat32m4_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vfnmsub_vv_m)))
vfloat32m4_t vfnmsub_vv_f32m4_m(vbool8_t, vfloat32m4_t, vfloat32m4_t, vfloat32m4_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vfnmsub_vv)))
vfloat32m8_t vfnmsub_vv_f32m8(vfloat32m8_t, vfloat32m8_t, vfloat32m8_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vfnmsub_vv_m)))
vfloat32m8_t vfnmsub_vv_f32m8_m(vbool4_t, vfloat32m8_t, vfloat32m8_t, vfloat32m8_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vfnmsub_vv)))
vfloat32mf2_t vfnmsub_vv_f32mf2(vfloat32mf2_t, vfloat32mf2_t, vfloat32mf2_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vfnmsub_vv_m)))
vfloat32mf2_t vfnmsub_vv_f32mf2_m(vbool64_t, vfloat32mf2_t, vfloat32mf2_t, vfloat32mf2_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vfnmsub_vf)))
vfloat32m1_t vfnmsub_vf_f32m1(vfloat32m1_t, float, vfloat32m1_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vfnmsub_vf_m)))
vfloat32m1_t vfnmsub_vf_f32m1_m(vbool32_t, vfloat32m1_t, float, vfloat32m1_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vfnmsub_vf)))
vfloat32m2_t vfnmsub_vf_f32m2(vfloat32m2_t, float, vfloat32m2_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vfnmsub_vf_m)))
vfloat32m2_t vfnmsub_vf_f32m2_m(vbool16_t, vfloat32m2_t, float, vfloat32m2_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vfnmsub_vf)))
vfloat32m4_t vfnmsub_vf_f32m4(vfloat32m4_t, float, vfloat32m4_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vfnmsub_vf_m)))
vfloat32m4_t vfnmsub_vf_f32m4_m(vbool8_t, vfloat32m4_t, float, vfloat32m4_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vfnmsub_vf)))
vfloat32m8_t vfnmsub_vf_f32m8(vfloat32m8_t, float, vfloat32m8_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vfnmsub_vf_m)))
vfloat32m8_t vfnmsub_vf_f32m8_m(vbool4_t, vfloat32m8_t, float, vfloat32m8_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vfnmsub_vf)))
vfloat32mf2_t vfnmsub_vf_f32mf2(vfloat32mf2_t, float, vfloat32mf2_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vfnmsub_vf_m)))
vfloat32mf2_t vfnmsub_vf_f32mf2_m(vbool64_t, vfloat32mf2_t, float, vfloat32mf2_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vfmin_vv)))
vfloat32m1_t vfmin_vv_f32m1(vfloat32m1_t, vfloat32m1_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vfmin_vv_m)))
vfloat32m1_t vfmin_vv_f32m1_m(vbool32_t, vfloat32m1_t, vfloat32m1_t, vfloat32m1_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vfmin_vv)))
vfloat32m2_t vfmin_vv_f32m2(vfloat32m2_t, vfloat32m2_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vfmin_vv_m)))
vfloat32m2_t vfmin_vv_f32m2_m(vbool16_t, vfloat32m2_t, vfloat32m2_t, vfloat32m2_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vfmin_vv)))
vfloat32m4_t vfmin_vv_f32m4(vfloat32m4_t, vfloat32m4_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vfmin_vv_m)))
vfloat32m4_t vfmin_vv_f32m4_m(vbool8_t, vfloat32m4_t, vfloat32m4_t, vfloat32m4_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vfmin_vv)))
vfloat32m8_t vfmin_vv_f32m8(vfloat32m8_t, vfloat32m8_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vfmin_vv_m)))
vfloat32m8_t vfmin_vv_f32m8_m(vbool4_t, vfloat32m8_t, vfloat32m8_t, vfloat32m8_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vfmin_vv)))
vfloat32mf2_t vfmin_vv_f32mf2(vfloat32mf2_t, vfloat32mf2_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vfmin_vv_m)))
vfloat32mf2_t vfmin_vv_f32mf2_m(vbool64_t, vfloat32mf2_t, vfloat32mf2_t, vfloat32mf2_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vfmin_vf)))
vfloat32m1_t vfmin_vf_f32m1(vfloat32m1_t, float, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vfmin_vf_m)))
vfloat32m1_t vfmin_vf_f32m1_m(vbool32_t, vfloat32m1_t, vfloat32m1_t, float, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vfmin_vf)))
vfloat32m2_t vfmin_vf_f32m2(vfloat32m2_t, float, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vfmin_vf_m)))
vfloat32m2_t vfmin_vf_f32m2_m(vbool16_t, vfloat32m2_t, vfloat32m2_t, float, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vfmin_vf)))
vfloat32m4_t vfmin_vf_f32m4(vfloat32m4_t, float, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vfmin_vf_m)))
vfloat32m4_t vfmin_vf_f32m4_m(vbool8_t, vfloat32m4_t, vfloat32m4_t, float, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vfmin_vf)))
vfloat32m8_t vfmin_vf_f32m8(vfloat32m8_t, float, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vfmin_vf_m)))
vfloat32m8_t vfmin_vf_f32m8_m(vbool4_t, vfloat32m8_t, vfloat32m8_t, float, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vfmin_vf)))
vfloat32mf2_t vfmin_vf_f32mf2(vfloat32mf2_t, float, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vfmin_vf_m)))
vfloat32mf2_t vfmin_vf_f32mf2_m(vbool64_t, vfloat32mf2_t, vfloat32mf2_t, float, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vfmax_vv)))
vfloat32m1_t vfmax_vv_f32m1(vfloat32m1_t, vfloat32m1_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vfmax_vv_m)))
vfloat32m1_t vfmax_vv_f32m1_m(vbool32_t, vfloat32m1_t, vfloat32m1_t, vfloat32m1_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vfmax_vv)))
vfloat32m2_t vfmax_vv_f32m2(vfloat32m2_t, vfloat32m2_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vfmax_vv_m)))
vfloat32m2_t vfmax_vv_f32m2_m(vbool16_t, vfloat32m2_t, vfloat32m2_t, vfloat32m2_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vfmax_vv)))
vfloat32m4_t vfmax_vv_f32m4(vfloat32m4_t, vfloat32m4_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vfmax_vv_m)))
vfloat32m4_t vfmax_vv_f32m4_m(vbool8_t, vfloat32m4_t, vfloat32m4_t, vfloat32m4_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vfmax_vv)))
vfloat32m8_t vfmax_vv_f32m8(vfloat32m8_t, vfloat32m8_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vfmax_vv_m)))
vfloat32m8_t vfmax_vv_f32m8_m(vbool4_t, vfloat32m8_t, vfloat32m8_t, vfloat32m8_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vfmax_vv)))
vfloat32mf2_t vfmax_vv_f32mf2(vfloat32mf2_t, vfloat32mf2_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vfmax_vv_m)))
vfloat32mf2_t vfmax_vv_f32mf2_m(vbool64_t, vfloat32mf2_t, vfloat32mf2_t, vfloat32mf2_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vfmax_vf)))
vfloat32m1_t vfmax_vf_f32m1(vfloat32m1_t, float, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vfmax_vf_m)))
vfloat32m1_t vfmax_vf_f32m1_m(vbool32_t, vfloat32m1_t, vfloat32m1_t, float, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vfmax_vf)))
vfloat32m2_t vfmax_vf_f32m2(vfloat32m2_t, float, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vfmax_vf_m)))
vfloat32m2_t vfmax_vf_f32m2_m(vbool16_t, vfloat32m2_t, vfloat32m2_t, float, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vfmax_vf)))
vfloat32m4_t vfmax_vf_f32m4(vfloat32m4_t, float, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vfmax_vf_m)))
vfloat32m4_t vfmax_vf_f32m4_m(vbool8_t, vfloat32m4_t, vfloat32m4_t, float, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vfmax_vf)))
vfloat32m8_t vfmax_vf_f32m8(vfloat32m8_t, float, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vfmax_vf_m)))
vfloat32m8_t vfmax_vf_f32m8_m(vbool4_t, vfloat32m8_t, vfloat32m8_t, float, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vfmax_vf)))
vfloat32mf2_t vfmax_vf_f32mf2(vfloat32mf2_t, float, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vfmax_vf_m)))
vfloat32mf2_t vfmax_vf_f32mf2_m(vbool64_t, vfloat32mf2_t, vfloat32mf2_t, float, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vfsgnj_vv)))
vfloat32m1_t vfsgnj_vv_f32m1(vfloat32m1_t, vfloat32m1_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vfsgnj_vv_m)))
vfloat32m1_t vfsgnj_vv_f32m1_m(vbool32_t, vfloat32m1_t, vfloat32m1_t, vfloat32m1_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vfsgnj_vv)))
vfloat32m2_t vfsgnj_vv_f32m2(vfloat32m2_t, vfloat32m2_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vfsgnj_vv_m)))
vfloat32m2_t vfsgnj_vv_f32m2_m(vbool16_t, vfloat32m2_t, vfloat32m2_t, vfloat32m2_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vfsgnj_vv)))
vfloat32m4_t vfsgnj_vv_f32m4(vfloat32m4_t, vfloat32m4_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vfsgnj_vv_m)))
vfloat32m4_t vfsgnj_vv_f32m4_m(vbool8_t, vfloat32m4_t, vfloat32m4_t, vfloat32m4_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vfsgnj_vv)))
vfloat32m8_t vfsgnj_vv_f32m8(vfloat32m8_t, vfloat32m8_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vfsgnj_vv_m)))
vfloat32m8_t vfsgnj_vv_f32m8_m(vbool4_t, vfloat32m8_t, vfloat32m8_t, vfloat32m8_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vfsgnj_vv)))
vfloat32mf2_t vfsgnj_vv_f32mf2(vfloat32mf2_t, vfloat32mf2_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vfsgnj_vv_m)))
vfloat32mf2_t vfsgnj_vv_f32mf2_m(vbool64_t, vfloat32mf2_t, vfloat32mf2_t, vfloat32mf2_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vfsgnj_vf)))
vfloat32m1_t vfsgnj_vf_f32m1(vfloat32m1_t, float, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vfsgnj_vf_m)))
vfloat32m1_t vfsgnj_vf_f32m1_m(vbool32_t, vfloat32m1_t, vfloat32m1_t, float, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vfsgnj_vf)))
vfloat32m2_t vfsgnj_vf_f32m2(vfloat32m2_t, float, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vfsgnj_vf_m)))
vfloat32m2_t vfsgnj_vf_f32m2_m(vbool16_t, vfloat32m2_t, vfloat32m2_t, float, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vfsgnj_vf)))
vfloat32m4_t vfsgnj_vf_f32m4(vfloat32m4_t, float, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vfsgnj_vf_m)))
vfloat32m4_t vfsgnj_vf_f32m4_m(vbool8_t, vfloat32m4_t, vfloat32m4_t, float, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vfsgnj_vf)))
vfloat32m8_t vfsgnj_vf_f32m8(vfloat32m8_t, float, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vfsgnj_vf_m)))
vfloat32m8_t vfsgnj_vf_f32m8_m(vbool4_t, vfloat32m8_t, vfloat32m8_t, float, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vfsgnj_vf)))
vfloat32mf2_t vfsgnj_vf_f32mf2(vfloat32mf2_t, float, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vfsgnj_vf_m)))
vfloat32mf2_t vfsgnj_vf_f32mf2_m(vbool64_t, vfloat32mf2_t, vfloat32mf2_t, float, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vfsgnjn_vv)))
vfloat32m1_t vfsgnjn_vv_f32m1(vfloat32m1_t, vfloat32m1_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vfsgnjn_vv_m)))
vfloat32m1_t vfsgnjn_vv_f32m1_m(vbool32_t, vfloat32m1_t, vfloat32m1_t, vfloat32m1_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vfsgnjn_vv)))
vfloat32m2_t vfsgnjn_vv_f32m2(vfloat32m2_t, vfloat32m2_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vfsgnjn_vv_m)))
vfloat32m2_t vfsgnjn_vv_f32m2_m(vbool16_t, vfloat32m2_t, vfloat32m2_t, vfloat32m2_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vfsgnjn_vv)))
vfloat32m4_t vfsgnjn_vv_f32m4(vfloat32m4_t, vfloat32m4_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vfsgnjn_vv_m)))
vfloat32m4_t vfsgnjn_vv_f32m4_m(vbool8_t, vfloat32m4_t, vfloat32m4_t, vfloat32m4_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vfsgnjn_vv)))
vfloat32m8_t vfsgnjn_vv_f32m8(vfloat32m8_t, vfloat32m8_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vfsgnjn_vv_m)))
vfloat32m8_t vfsgnjn_vv_f32m8_m(vbool4_t, vfloat32m8_t, vfloat32m8_t, vfloat32m8_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vfsgnjn_vv)))
vfloat32mf2_t vfsgnjn_vv_f32mf2(vfloat32mf2_t, vfloat32mf2_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vfsgnjn_vv_m)))
vfloat32mf2_t vfsgnjn_vv_f32mf2_m(vbool64_t, vfloat32mf2_t, vfloat32mf2_t, vfloat32mf2_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vfsgnjn_vf)))
vfloat32m1_t vfsgnjn_vf_f32m1(vfloat32m1_t, float, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vfsgnjn_vf_m)))
vfloat32m1_t vfsgnjn_vf_f32m1_m(vbool32_t, vfloat32m1_t, vfloat32m1_t, float, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vfsgnjn_vf)))
vfloat32m2_t vfsgnjn_vf_f32m2(vfloat32m2_t, float, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vfsgnjn_vf_m)))
vfloat32m2_t vfsgnjn_vf_f32m2_m(vbool16_t, vfloat32m2_t, vfloat32m2_t, float, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vfsgnjn_vf)))
vfloat32m4_t vfsgnjn_vf_f32m4(vfloat32m4_t, float, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vfsgnjn_vf_m)))
vfloat32m4_t vfsgnjn_vf_f32m4_m(vbool8_t, vfloat32m4_t, vfloat32m4_t, float, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vfsgnjn_vf)))
vfloat32m8_t vfsgnjn_vf_f32m8(vfloat32m8_t, float, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vfsgnjn_vf_m)))
vfloat32m8_t vfsgnjn_vf_f32m8_m(vbool4_t, vfloat32m8_t, vfloat32m8_t, float, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vfsgnjn_vf)))
vfloat32mf2_t vfsgnjn_vf_f32mf2(vfloat32mf2_t, float, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vfsgnjn_vf_m)))
vfloat32mf2_t vfsgnjn_vf_f32mf2_m(vbool64_t, vfloat32mf2_t, vfloat32mf2_t, float, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vfsgnjx_vv)))
vfloat32m1_t vfsgnjx_vv_f32m1(vfloat32m1_t, vfloat32m1_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vfsgnjx_vv_m)))
vfloat32m1_t vfsgnjx_vv_f32m1_m(vbool32_t, vfloat32m1_t, vfloat32m1_t, vfloat32m1_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vfsgnjx_vv)))
vfloat32m2_t vfsgnjx_vv_f32m2(vfloat32m2_t, vfloat32m2_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vfsgnjx_vv_m)))
vfloat32m2_t vfsgnjx_vv_f32m2_m(vbool16_t, vfloat32m2_t, vfloat32m2_t, vfloat32m2_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vfsgnjx_vv)))
vfloat32m4_t vfsgnjx_vv_f32m4(vfloat32m4_t, vfloat32m4_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vfsgnjx_vv_m)))
vfloat32m4_t vfsgnjx_vv_f32m4_m(vbool8_t, vfloat32m4_t, vfloat32m4_t, vfloat32m4_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vfsgnjx_vv)))
vfloat32m8_t vfsgnjx_vv_f32m8(vfloat32m8_t, vfloat32m8_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vfsgnjx_vv_m)))
vfloat32m8_t vfsgnjx_vv_f32m8_m(vbool4_t, vfloat32m8_t, vfloat32m8_t, vfloat32m8_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vfsgnjx_vv)))
vfloat32mf2_t vfsgnjx_vv_f32mf2(vfloat32mf2_t, vfloat32mf2_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vfsgnjx_vv_m)))
vfloat32mf2_t vfsgnjx_vv_f32mf2_m(vbool64_t, vfloat32mf2_t, vfloat32mf2_t, vfloat32mf2_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vfsgnjx_vf)))
vfloat32m1_t vfsgnjx_vf_f32m1(vfloat32m1_t, float, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vfsgnjx_vf_m)))
vfloat32m1_t vfsgnjx_vf_f32m1_m(vbool32_t, vfloat32m1_t, vfloat32m1_t, float, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vfsgnjx_vf)))
vfloat32m2_t vfsgnjx_vf_f32m2(vfloat32m2_t, float, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vfsgnjx_vf_m)))
vfloat32m2_t vfsgnjx_vf_f32m2_m(vbool16_t, vfloat32m2_t, vfloat32m2_t, float, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vfsgnjx_vf)))
vfloat32m4_t vfsgnjx_vf_f32m4(vfloat32m4_t, float, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vfsgnjx_vf_m)))
vfloat32m4_t vfsgnjx_vf_f32m4_m(vbool8_t, vfloat32m4_t, vfloat32m4_t, float, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vfsgnjx_vf)))
vfloat32m8_t vfsgnjx_vf_f32m8(vfloat32m8_t, float, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vfsgnjx_vf_m)))
vfloat32m8_t vfsgnjx_vf_f32m8_m(vbool4_t, vfloat32m8_t, vfloat32m8_t, float, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vfsgnjx_vf)))
vfloat32mf2_t vfsgnjx_vf_f32mf2(vfloat32mf2_t, float, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vfsgnjx_vf_m)))
vfloat32mf2_t vfsgnjx_vf_f32mf2_m(vbool64_t, vfloat32mf2_t, vfloat32mf2_t, float, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vfabs_v)))
vfloat32m1_t vfabs_v_f32m1(vfloat32m1_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vfabs_v_m)))
vfloat32m1_t vfabs_v_f32m1_m(vbool32_t, vfloat32m1_t, vfloat32m1_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vfabs_v)))
vfloat32m2_t vfabs_v_f32m2(vfloat32m2_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vfabs_v_m)))
vfloat32m2_t vfabs_v_f32m2_m(vbool16_t, vfloat32m2_t, vfloat32m2_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vfabs_v)))
vfloat32m4_t vfabs_v_f32m4(vfloat32m4_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vfabs_v_m)))
vfloat32m4_t vfabs_v_f32m4_m(vbool8_t, vfloat32m4_t, vfloat32m4_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vfabs_v)))
vfloat32m8_t vfabs_v_f32m8(vfloat32m8_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vfabs_v_m)))
vfloat32m8_t vfabs_v_f32m8_m(vbool4_t, vfloat32m8_t, vfloat32m8_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vfabs_v)))
vfloat32mf2_t vfabs_v_f32mf2(vfloat32mf2_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vfabs_v_m)))
vfloat32mf2_t vfabs_v_f32mf2_m(vbool64_t, vfloat32mf2_t, vfloat32mf2_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vmfeq_vv)))
vbool32_t vmfeq_vv_f32m1_b32(vfloat32m1_t, vfloat32m1_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vmfeq_vv_m)))
vbool32_t vmfeq_vv_f32m1_b32_m(vbool32_t, vbool32_t, vfloat32m1_t, vfloat32m1_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vmfeq_vv)))
vbool16_t vmfeq_vv_f32m2_b16(vfloat32m2_t, vfloat32m2_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vmfeq_vv_m)))
vbool16_t vmfeq_vv_f32m2_b16_m(vbool16_t, vbool16_t, vfloat32m2_t, vfloat32m2_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vmfeq_vv)))
vbool8_t vmfeq_vv_f32m4_b8(vfloat32m4_t, vfloat32m4_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vmfeq_vv_m)))
vbool8_t vmfeq_vv_f32m4_b8_m(vbool8_t, vbool8_t, vfloat32m4_t, vfloat32m4_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vmfeq_vv)))
vbool4_t vmfeq_vv_f32m8_b4(vfloat32m8_t, vfloat32m8_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vmfeq_vv_m)))
vbool4_t vmfeq_vv_f32m8_b4_m(vbool4_t, vbool4_t, vfloat32m8_t, vfloat32m8_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vmfeq_vv)))
vbool64_t vmfeq_vv_f32mf2_b64(vfloat32mf2_t, vfloat32mf2_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vmfeq_vv_m)))
vbool64_t vmfeq_vv_f32mf2_b64_m(vbool64_t, vbool64_t, vfloat32mf2_t, vfloat32mf2_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vmfeq_vf)))
vbool32_t vmfeq_vf_f32m1_b32(vfloat32m1_t, float, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vmfeq_vf_m)))
vbool32_t vmfeq_vf_f32m1_b32_m(vbool32_t, vbool32_t, vfloat32m1_t, float, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vmfeq_vf)))
vbool16_t vmfeq_vf_f32m2_b16(vfloat32m2_t, float, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vmfeq_vf_m)))
vbool16_t vmfeq_vf_f32m2_b16_m(vbool16_t, vbool16_t, vfloat32m2_t, float, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vmfeq_vf)))
vbool8_t vmfeq_vf_f32m4_b8(vfloat32m4_t, float, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vmfeq_vf_m)))
vbool8_t vmfeq_vf_f32m4_b8_m(vbool8_t, vbool8_t, vfloat32m4_t, float, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vmfeq_vf)))
vbool4_t vmfeq_vf_f32m8_b4(vfloat32m8_t, float, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vmfeq_vf_m)))
vbool4_t vmfeq_vf_f32m8_b4_m(vbool4_t, vbool4_t, vfloat32m8_t, float, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vmfeq_vf)))
vbool64_t vmfeq_vf_f32mf2_b64(vfloat32mf2_t, float, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vmfeq_vf_m)))
vbool64_t vmfeq_vf_f32mf2_b64_m(vbool64_t, vbool64_t, vfloat32mf2_t, float, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vmfne_vv)))
vbool32_t vmfne_vv_f32m1_b32(vfloat32m1_t, vfloat32m1_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vmfne_vv_m)))
vbool32_t vmfne_vv_f32m1_b32_m(vbool32_t, vbool32_t, vfloat32m1_t, vfloat32m1_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vmfne_vv)))
vbool16_t vmfne_vv_f32m2_b16(vfloat32m2_t, vfloat32m2_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vmfne_vv_m)))
vbool16_t vmfne_vv_f32m2_b16_m(vbool16_t, vbool16_t, vfloat32m2_t, vfloat32m2_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vmfne_vv)))
vbool8_t vmfne_vv_f32m4_b8(vfloat32m4_t, vfloat32m4_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vmfne_vv_m)))
vbool8_t vmfne_vv_f32m4_b8_m(vbool8_t, vbool8_t, vfloat32m4_t, vfloat32m4_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vmfne_vv)))
vbool4_t vmfne_vv_f32m8_b4(vfloat32m8_t, vfloat32m8_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vmfne_vv_m)))
vbool4_t vmfne_vv_f32m8_b4_m(vbool4_t, vbool4_t, vfloat32m8_t, vfloat32m8_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vmfne_vv)))
vbool64_t vmfne_vv_f32mf2_b64(vfloat32mf2_t, vfloat32mf2_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vmfne_vv_m)))
vbool64_t vmfne_vv_f32mf2_b64_m(vbool64_t, vbool64_t, vfloat32mf2_t, vfloat32mf2_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vmfne_vf)))
vbool32_t vmfne_vf_f32m1_b32(vfloat32m1_t, float, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vmfne_vf_m)))
vbool32_t vmfne_vf_f32m1_b32_m(vbool32_t, vbool32_t, vfloat32m1_t, float, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vmfne_vf)))
vbool16_t vmfne_vf_f32m2_b16(vfloat32m2_t, float, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vmfne_vf_m)))
vbool16_t vmfne_vf_f32m2_b16_m(vbool16_t, vbool16_t, vfloat32m2_t, float, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vmfne_vf)))
vbool8_t vmfne_vf_f32m4_b8(vfloat32m4_t, float, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vmfne_vf_m)))
vbool8_t vmfne_vf_f32m4_b8_m(vbool8_t, vbool8_t, vfloat32m4_t, float, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vmfne_vf)))
vbool4_t vmfne_vf_f32m8_b4(vfloat32m8_t, float, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vmfne_vf_m)))
vbool4_t vmfne_vf_f32m8_b4_m(vbool4_t, vbool4_t, vfloat32m8_t, float, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vmfne_vf)))
vbool64_t vmfne_vf_f32mf2_b64(vfloat32mf2_t, float, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vmfne_vf_m)))
vbool64_t vmfne_vf_f32mf2_b64_m(vbool64_t, vbool64_t, vfloat32mf2_t, float, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vmflt_vv)))
vbool32_t vmflt_vv_f32m1_b32(vfloat32m1_t, vfloat32m1_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vmflt_vv_m)))
vbool32_t vmflt_vv_f32m1_b32_m(vbool32_t, vbool32_t, vfloat32m1_t, vfloat32m1_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vmflt_vv)))
vbool16_t vmflt_vv_f32m2_b16(vfloat32m2_t, vfloat32m2_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vmflt_vv_m)))
vbool16_t vmflt_vv_f32m2_b16_m(vbool16_t, vbool16_t, vfloat32m2_t, vfloat32m2_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vmflt_vv)))
vbool8_t vmflt_vv_f32m4_b8(vfloat32m4_t, vfloat32m4_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vmflt_vv_m)))
vbool8_t vmflt_vv_f32m4_b8_m(vbool8_t, vbool8_t, vfloat32m4_t, vfloat32m4_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vmflt_vv)))
vbool4_t vmflt_vv_f32m8_b4(vfloat32m8_t, vfloat32m8_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vmflt_vv_m)))
vbool4_t vmflt_vv_f32m8_b4_m(vbool4_t, vbool4_t, vfloat32m8_t, vfloat32m8_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vmflt_vv)))
vbool64_t vmflt_vv_f32mf2_b64(vfloat32mf2_t, vfloat32mf2_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vmflt_vv_m)))
vbool64_t vmflt_vv_f32mf2_b64_m(vbool64_t, vbool64_t, vfloat32mf2_t, vfloat32mf2_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vmflt_vf)))
vbool32_t vmflt_vf_f32m1_b32(vfloat32m1_t, float, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vmflt_vf_m)))
vbool32_t vmflt_vf_f32m1_b32_m(vbool32_t, vbool32_t, vfloat32m1_t, float, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vmflt_vf)))
vbool16_t vmflt_vf_f32m2_b16(vfloat32m2_t, float, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vmflt_vf_m)))
vbool16_t vmflt_vf_f32m2_b16_m(vbool16_t, vbool16_t, vfloat32m2_t, float, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vmflt_vf)))
vbool8_t vmflt_vf_f32m4_b8(vfloat32m4_t, float, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vmflt_vf_m)))
vbool8_t vmflt_vf_f32m4_b8_m(vbool8_t, vbool8_t, vfloat32m4_t, float, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vmflt_vf)))
vbool4_t vmflt_vf_f32m8_b4(vfloat32m8_t, float, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vmflt_vf_m)))
vbool4_t vmflt_vf_f32m8_b4_m(vbool4_t, vbool4_t, vfloat32m8_t, float, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vmflt_vf)))
vbool64_t vmflt_vf_f32mf2_b64(vfloat32mf2_t, float, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vmflt_vf_m)))
vbool64_t vmflt_vf_f32mf2_b64_m(vbool64_t, vbool64_t, vfloat32mf2_t, float, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vmfle_vv)))
vbool32_t vmfle_vv_f32m1_b32(vfloat32m1_t, vfloat32m1_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vmfle_vv_m)))
vbool32_t vmfle_vv_f32m1_b32_m(vbool32_t, vbool32_t, vfloat32m1_t, vfloat32m1_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vmfle_vv)))
vbool16_t vmfle_vv_f32m2_b16(vfloat32m2_t, vfloat32m2_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vmfle_vv_m)))
vbool16_t vmfle_vv_f32m2_b16_m(vbool16_t, vbool16_t, vfloat32m2_t, vfloat32m2_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vmfle_vv)))
vbool8_t vmfle_vv_f32m4_b8(vfloat32m4_t, vfloat32m4_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vmfle_vv_m)))
vbool8_t vmfle_vv_f32m4_b8_m(vbool8_t, vbool8_t, vfloat32m4_t, vfloat32m4_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vmfle_vv)))
vbool4_t vmfle_vv_f32m8_b4(vfloat32m8_t, vfloat32m8_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vmfle_vv_m)))
vbool4_t vmfle_vv_f32m8_b4_m(vbool4_t, vbool4_t, vfloat32m8_t, vfloat32m8_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vmfle_vv)))
vbool64_t vmfle_vv_f32mf2_b64(vfloat32mf2_t, vfloat32mf2_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vmfle_vv_m)))
vbool64_t vmfle_vv_f32mf2_b64_m(vbool64_t, vbool64_t, vfloat32mf2_t, vfloat32mf2_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vmfle_vf)))
vbool32_t vmfle_vf_f32m1_b32(vfloat32m1_t, float, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vmfle_vf_m)))
vbool32_t vmfle_vf_f32m1_b32_m(vbool32_t, vbool32_t, vfloat32m1_t, float, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vmfle_vf)))
vbool16_t vmfle_vf_f32m2_b16(vfloat32m2_t, float, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vmfle_vf_m)))
vbool16_t vmfle_vf_f32m2_b16_m(vbool16_t, vbool16_t, vfloat32m2_t, float, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vmfle_vf)))
vbool8_t vmfle_vf_f32m4_b8(vfloat32m4_t, float, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vmfle_vf_m)))
vbool8_t vmfle_vf_f32m4_b8_m(vbool8_t, vbool8_t, vfloat32m4_t, float, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vmfle_vf)))
vbool4_t vmfle_vf_f32m8_b4(vfloat32m8_t, float, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vmfle_vf_m)))
vbool4_t vmfle_vf_f32m8_b4_m(vbool4_t, vbool4_t, vfloat32m8_t, float, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vmfle_vf)))
vbool64_t vmfle_vf_f32mf2_b64(vfloat32mf2_t, float, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vmfle_vf_m)))
vbool64_t vmfle_vf_f32mf2_b64_m(vbool64_t, vbool64_t, vfloat32mf2_t, float, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vmfgt_vv)))
vbool32_t vmfgt_vv_f32m1_b32(vfloat32m1_t, vfloat32m1_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vmfgt_vv_m)))
vbool32_t vmfgt_vv_f32m1_b32_m(vbool32_t, vbool32_t, vfloat32m1_t, vfloat32m1_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vmfgt_vv)))
vbool16_t vmfgt_vv_f32m2_b16(vfloat32m2_t, vfloat32m2_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vmfgt_vv_m)))
vbool16_t vmfgt_vv_f32m2_b16_m(vbool16_t, vbool16_t, vfloat32m2_t, vfloat32m2_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vmfgt_vv)))
vbool8_t vmfgt_vv_f32m4_b8(vfloat32m4_t, vfloat32m4_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vmfgt_vv_m)))
vbool8_t vmfgt_vv_f32m4_b8_m(vbool8_t, vbool8_t, vfloat32m4_t, vfloat32m4_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vmfgt_vv)))
vbool4_t vmfgt_vv_f32m8_b4(vfloat32m8_t, vfloat32m8_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vmfgt_vv_m)))
vbool4_t vmfgt_vv_f32m8_b4_m(vbool4_t, vbool4_t, vfloat32m8_t, vfloat32m8_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vmfgt_vv)))
vbool64_t vmfgt_vv_f32mf2_b64(vfloat32mf2_t, vfloat32mf2_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vmfgt_vv_m)))
vbool64_t vmfgt_vv_f32mf2_b64_m(vbool64_t, vbool64_t, vfloat32mf2_t, vfloat32mf2_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vmfgt_vf)))
vbool32_t vmfgt_vf_f32m1_b32(vfloat32m1_t, float, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vmfgt_vf_m)))
vbool32_t vmfgt_vf_f32m1_b32_m(vbool32_t, vbool32_t, vfloat32m1_t, float, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vmfgt_vf)))
vbool16_t vmfgt_vf_f32m2_b16(vfloat32m2_t, float, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vmfgt_vf_m)))
vbool16_t vmfgt_vf_f32m2_b16_m(vbool16_t, vbool16_t, vfloat32m2_t, float, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vmfgt_vf)))
vbool8_t vmfgt_vf_f32m4_b8(vfloat32m4_t, float, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vmfgt_vf_m)))
vbool8_t vmfgt_vf_f32m4_b8_m(vbool8_t, vbool8_t, vfloat32m4_t, float, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vmfgt_vf)))
vbool4_t vmfgt_vf_f32m8_b4(vfloat32m8_t, float, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vmfgt_vf_m)))
vbool4_t vmfgt_vf_f32m8_b4_m(vbool4_t, vbool4_t, vfloat32m8_t, float, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vmfgt_vf)))
vbool64_t vmfgt_vf_f32mf2_b64(vfloat32mf2_t, float, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vmfgt_vf_m)))
vbool64_t vmfgt_vf_f32mf2_b64_m(vbool64_t, vbool64_t, vfloat32mf2_t, float, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vmfge_vv)))
vbool32_t vmfge_vv_f32m1_b32(vfloat32m1_t, vfloat32m1_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vmfge_vv_m)))
vbool32_t vmfge_vv_f32m1_b32_m(vbool32_t, vbool32_t, vfloat32m1_t, vfloat32m1_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vmfge_vv)))
vbool16_t vmfge_vv_f32m2_b16(vfloat32m2_t, vfloat32m2_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vmfge_vv_m)))
vbool16_t vmfge_vv_f32m2_b16_m(vbool16_t, vbool16_t, vfloat32m2_t, vfloat32m2_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vmfge_vv)))
vbool8_t vmfge_vv_f32m4_b8(vfloat32m4_t, vfloat32m4_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vmfge_vv_m)))
vbool8_t vmfge_vv_f32m4_b8_m(vbool8_t, vbool8_t, vfloat32m4_t, vfloat32m4_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vmfge_vv)))
vbool4_t vmfge_vv_f32m8_b4(vfloat32m8_t, vfloat32m8_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vmfge_vv_m)))
vbool4_t vmfge_vv_f32m8_b4_m(vbool4_t, vbool4_t, vfloat32m8_t, vfloat32m8_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vmfge_vv)))
vbool64_t vmfge_vv_f32mf2_b64(vfloat32mf2_t, vfloat32mf2_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vmfge_vv_m)))
vbool64_t vmfge_vv_f32mf2_b64_m(vbool64_t, vbool64_t, vfloat32mf2_t, vfloat32mf2_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vmfge_vf)))
vbool32_t vmfge_vf_f32m1_b32(vfloat32m1_t, float, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vmfge_vf_m)))
vbool32_t vmfge_vf_f32m1_b32_m(vbool32_t, vbool32_t, vfloat32m1_t, float, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vmfge_vf)))
vbool16_t vmfge_vf_f32m2_b16(vfloat32m2_t, float, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vmfge_vf_m)))
vbool16_t vmfge_vf_f32m2_b16_m(vbool16_t, vbool16_t, vfloat32m2_t, float, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vmfge_vf)))
vbool8_t vmfge_vf_f32m4_b8(vfloat32m4_t, float, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vmfge_vf_m)))
vbool8_t vmfge_vf_f32m4_b8_m(vbool8_t, vbool8_t, vfloat32m4_t, float, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vmfge_vf)))
vbool4_t vmfge_vf_f32m8_b4(vfloat32m8_t, float, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vmfge_vf_m)))
vbool4_t vmfge_vf_f32m8_b4_m(vbool4_t, vbool4_t, vfloat32m8_t, float, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vmfge_vf)))
vbool64_t vmfge_vf_f32mf2_b64(vfloat32mf2_t, float, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vmfge_vf_m)))
vbool64_t vmfge_vf_f32mf2_b64_m(vbool64_t, vbool64_t, vfloat32mf2_t, float, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vmerge_vvm)))
vfloat32m1_t vmerge_vvm_f32m1(vbool32_t, vfloat32m1_t, vfloat32m1_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vmerge_vvm)))
vfloat32m2_t vmerge_vvm_f32m2(vbool16_t, vfloat32m2_t, vfloat32m2_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vmerge_vvm)))
vfloat32m4_t vmerge_vvm_f32m4(vbool8_t, vfloat32m4_t, vfloat32m4_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vmerge_vvm)))
vfloat32m8_t vmerge_vvm_f32m8(vbool4_t, vfloat32m8_t, vfloat32m8_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vmerge_vvm)))
vfloat32mf2_t vmerge_vvm_f32mf2(vbool64_t, vfloat32mf2_t, vfloat32mf2_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vfmerge_vfm)))
vfloat32m1_t vfmerge_vfm_f32m1(vbool32_t, vfloat32m1_t, float, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vfmerge_vfm)))
vfloat32m2_t vfmerge_vfm_f32m2(vbool16_t, vfloat32m2_t, float, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vfmerge_vfm)))
vfloat32m4_t vfmerge_vfm_f32m4(vbool8_t, vfloat32m4_t, float, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vfmerge_vfm)))
vfloat32m8_t vfmerge_vfm_f32m8(vbool4_t, vfloat32m8_t, float, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vfmerge_vfm)))
vfloat32mf2_t vfmerge_vfm_f32mf2(vbool64_t, vfloat32mf2_t, float, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vfmv_v_f)))
vfloat32m1_t vfmv_v_f_f32m1(float, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vfmv_v_f)))
vfloat32m2_t vfmv_v_f_f32m2(float, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vfmv_v_f)))
vfloat32m4_t vfmv_v_f_f32m4(float, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vfmv_v_f)))
vfloat32m8_t vfmv_v_f_f32m8(float, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vfmv_v_f)))
vfloat32mf2_t vfmv_v_f_f32mf2(float, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vfredmax_vs)))
vfloat32m1_t vfredmax_vs_f32m1_f32m1(vfloat32m1_t, vfloat32m1_t, vfloat32m1_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vfredmax_vs_m)))
vfloat32m1_t vfredmax_vs_f32m1_f32m1_m(vbool32_t, vfloat32m1_t, vfloat32m1_t, vfloat32m1_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vfredmax_vs)))
vfloat32m1_t vfredmax_vs_f32m2_f32m1(vfloat32m1_t, vfloat32m2_t, vfloat32m1_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vfredmax_vs_m)))
vfloat32m1_t vfredmax_vs_f32m2_f32m1_m(vbool16_t, vfloat32m1_t, vfloat32m2_t, vfloat32m1_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vfredmax_vs)))
vfloat32m1_t vfredmax_vs_f32m4_f32m1(vfloat32m1_t, vfloat32m4_t, vfloat32m1_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vfredmax_vs_m)))
vfloat32m1_t vfredmax_vs_f32m4_f32m1_m(vbool8_t, vfloat32m1_t, vfloat32m4_t, vfloat32m1_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vfredmax_vs)))
vfloat32m1_t vfredmax_vs_f32m8_f32m1(vfloat32m1_t, vfloat32m8_t, vfloat32m1_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vfredmax_vs_m)))
vfloat32m1_t vfredmax_vs_f32m8_f32m1_m(vbool4_t, vfloat32m1_t, vfloat32m8_t, vfloat32m1_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vfredmax_vs)))
vfloat32m1_t vfredmax_vs_f32mf2_f32m1(vfloat32m1_t, vfloat32mf2_t, vfloat32m1_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vfredmax_vs_m)))
vfloat32m1_t vfredmax_vs_f32mf2_f32m1_m(vbool64_t, vfloat32m1_t, vfloat32mf2_t, vfloat32m1_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vfredmin_vs)))
vfloat32m1_t vfredmin_vs_f32m1_f32m1(vfloat32m1_t, vfloat32m1_t, vfloat32m1_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vfredmin_vs_m)))
vfloat32m1_t vfredmin_vs_f32m1_f32m1_m(vbool32_t, vfloat32m1_t, vfloat32m1_t, vfloat32m1_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vfredmin_vs)))
vfloat32m1_t vfredmin_vs_f32m2_f32m1(vfloat32m1_t, vfloat32m2_t, vfloat32m1_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vfredmin_vs_m)))
vfloat32m1_t vfredmin_vs_f32m2_f32m1_m(vbool16_t, vfloat32m1_t, vfloat32m2_t, vfloat32m1_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vfredmin_vs)))
vfloat32m1_t vfredmin_vs_f32m4_f32m1(vfloat32m1_t, vfloat32m4_t, vfloat32m1_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vfredmin_vs_m)))
vfloat32m1_t vfredmin_vs_f32m4_f32m1_m(vbool8_t, vfloat32m1_t, vfloat32m4_t, vfloat32m1_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vfredmin_vs)))
vfloat32m1_t vfredmin_vs_f32m8_f32m1(vfloat32m1_t, vfloat32m8_t, vfloat32m1_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vfredmin_vs_m)))
vfloat32m1_t vfredmin_vs_f32m8_f32m1_m(vbool4_t, vfloat32m1_t, vfloat32m8_t, vfloat32m1_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vfredmin_vs)))
vfloat32m1_t vfredmin_vs_f32mf2_f32m1(vfloat32m1_t, vfloat32mf2_t, vfloat32m1_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vfredmin_vs_m)))
vfloat32m1_t vfredmin_vs_f32mf2_f32m1_m(vbool64_t, vfloat32m1_t, vfloat32mf2_t, vfloat32m1_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vfredusum_vs)))
vfloat32m1_t vfredusum_vs_f32m1_f32m1(vfloat32m1_t, vfloat32m1_t, vfloat32m1_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vfredusum_vs_m)))
vfloat32m1_t vfredusum_vs_f32m1_f32m1_m(vbool32_t, vfloat32m1_t, vfloat32m1_t, vfloat32m1_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vfredusum_vs)))
vfloat32m1_t vfredusum_vs_f32m2_f32m1(vfloat32m1_t, vfloat32m2_t, vfloat32m1_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vfredusum_vs_m)))
vfloat32m1_t vfredusum_vs_f32m2_f32m1_m(vbool16_t, vfloat32m1_t, vfloat32m2_t, vfloat32m1_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vfredusum_vs)))
vfloat32m1_t vfredusum_vs_f32m4_f32m1(vfloat32m1_t, vfloat32m4_t, vfloat32m1_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vfredusum_vs_m)))
vfloat32m1_t vfredusum_vs_f32m4_f32m1_m(vbool8_t, vfloat32m1_t, vfloat32m4_t, vfloat32m1_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vfredusum_vs)))
vfloat32m1_t vfredusum_vs_f32m8_f32m1(vfloat32m1_t, vfloat32m8_t, vfloat32m1_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vfredusum_vs_m)))
vfloat32m1_t vfredusum_vs_f32m8_f32m1_m(vbool4_t, vfloat32m1_t, vfloat32m8_t, vfloat32m1_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vfredusum_vs)))
vfloat32m1_t vfredusum_vs_f32mf2_f32m1(vfloat32m1_t, vfloat32mf2_t, vfloat32m1_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vfredusum_vs_m)))
vfloat32m1_t vfredusum_vs_f32mf2_f32m1_m(vbool64_t, vfloat32m1_t, vfloat32mf2_t, vfloat32m1_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vfredosum_vs)))
vfloat32m1_t vfredosum_vs_f32m1_f32m1(vfloat32m1_t, vfloat32m1_t, vfloat32m1_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vfredosum_vs_m)))
vfloat32m1_t vfredosum_vs_f32m1_f32m1_m(vbool32_t, vfloat32m1_t, vfloat32m1_t, vfloat32m1_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vfredosum_vs)))
vfloat32m1_t vfredosum_vs_f32m2_f32m1(vfloat32m1_t, vfloat32m2_t, vfloat32m1_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vfredosum_vs_m)))
vfloat32m1_t vfredosum_vs_f32m2_f32m1_m(vbool16_t, vfloat32m1_t, vfloat32m2_t, vfloat32m1_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vfredosum_vs)))
vfloat32m1_t vfredosum_vs_f32m4_f32m1(vfloat32m1_t, vfloat32m4_t, vfloat32m1_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vfredosum_vs_m)))
vfloat32m1_t vfredosum_vs_f32m4_f32m1_m(vbool8_t, vfloat32m1_t, vfloat32m4_t, vfloat32m1_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vfredosum_vs)))
vfloat32m1_t vfredosum_vs_f32m8_f32m1(vfloat32m1_t, vfloat32m8_t, vfloat32m1_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vfredosum_vs_m)))
vfloat32m1_t vfredosum_vs_f32m8_f32m1_m(vbool4_t, vfloat32m1_t, vfloat32m8_t, vfloat32m1_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vfredosum_vs)))
vfloat32m1_t vfredosum_vs_f32mf2_f32m1(vfloat32m1_t, vfloat32mf2_t, vfloat32m1_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vfredosum_vs_m)))
vfloat32m1_t vfredosum_vs_f32mf2_f32m1_m(vbool64_t, vfloat32m1_t, vfloat32mf2_t, vfloat32m1_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vfmv_f_s)))
float vfmv_f_s_f32m1_f32(vfloat32m1_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vfmv_f_s)))
float vfmv_f_s_f32m2_f32(vfloat32m2_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vfmv_f_s)))
float vfmv_f_s_f32m4_f32(vfloat32m4_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vfmv_f_s)))
float vfmv_f_s_f32m8_f32(vfloat32m8_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vfmv_f_s)))
float vfmv_f_s_f32mf2_f32(vfloat32mf2_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vfmv_s_f)))
vfloat32m1_t vfmv_s_f_f32m1(vfloat32m1_t, float, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vfmv_s_f)))
vfloat32m2_t vfmv_s_f_f32m2(vfloat32m2_t, float, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vfmv_s_f)))
vfloat32m4_t vfmv_s_f_f32m4(vfloat32m4_t, float, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vfmv_s_f)))
vfloat32m8_t vfmv_s_f_f32m8(vfloat32m8_t, float, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vfmv_s_f)))
vfloat32mf2_t vfmv_s_f_f32mf2(vfloat32mf2_t, float, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vslideup_vx)))
vfloat32m1_t vslideup_vx_f32m1(vfloat32m1_t, vfloat32m1_t, size_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vslideup_vx_m)))
vfloat32m1_t vslideup_vx_f32m1_m(vbool32_t, vfloat32m1_t, vfloat32m1_t, size_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vslideup_vx)))
vfloat32m2_t vslideup_vx_f32m2(vfloat32m2_t, vfloat32m2_t, size_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vslideup_vx_m)))
vfloat32m2_t vslideup_vx_f32m2_m(vbool16_t, vfloat32m2_t, vfloat32m2_t, size_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vslideup_vx)))
vfloat32m4_t vslideup_vx_f32m4(vfloat32m4_t, vfloat32m4_t, size_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vslideup_vx_m)))
vfloat32m4_t vslideup_vx_f32m4_m(vbool8_t, vfloat32m4_t, vfloat32m4_t, size_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vslideup_vx)))
vfloat32m8_t vslideup_vx_f32m8(vfloat32m8_t, vfloat32m8_t, size_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vslideup_vx_m)))
vfloat32m8_t vslideup_vx_f32m8_m(vbool4_t, vfloat32m8_t, vfloat32m8_t, size_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vslideup_vx)))
vfloat32mf2_t vslideup_vx_f32mf2(vfloat32mf2_t, vfloat32mf2_t, size_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vslideup_vx_m)))
vfloat32mf2_t vslideup_vx_f32mf2_m(vbool64_t, vfloat32mf2_t, vfloat32mf2_t, size_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vslidedown_vx)))
vfloat32m1_t vslidedown_vx_f32m1(vfloat32m1_t, vfloat32m1_t, size_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vslidedown_vx_m)))
vfloat32m1_t vslidedown_vx_f32m1_m(vbool32_t, vfloat32m1_t, vfloat32m1_t, size_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vslidedown_vx)))
vfloat32m2_t vslidedown_vx_f32m2(vfloat32m2_t, vfloat32m2_t, size_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vslidedown_vx_m)))
vfloat32m2_t vslidedown_vx_f32m2_m(vbool16_t, vfloat32m2_t, vfloat32m2_t, size_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vslidedown_vx)))
vfloat32m4_t vslidedown_vx_f32m4(vfloat32m4_t, vfloat32m4_t, size_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vslidedown_vx_m)))
vfloat32m4_t vslidedown_vx_f32m4_m(vbool8_t, vfloat32m4_t, vfloat32m4_t, size_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vslidedown_vx)))
vfloat32m8_t vslidedown_vx_f32m8(vfloat32m8_t, vfloat32m8_t, size_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vslidedown_vx_m)))
vfloat32m8_t vslidedown_vx_f32m8_m(vbool4_t, vfloat32m8_t, vfloat32m8_t, size_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vslidedown_vx)))
vfloat32mf2_t vslidedown_vx_f32mf2(vfloat32mf2_t, vfloat32mf2_t, size_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vslidedown_vx_m)))
vfloat32mf2_t vslidedown_vx_f32mf2_m(vbool64_t, vfloat32mf2_t, vfloat32mf2_t, size_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vfslide1up_vf)))
vfloat32m1_t vfslide1up_vf_f32m1(vfloat32m1_t, float, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vfslide1up_vf_m)))
vfloat32m1_t vfslide1up_vf_f32m1_m(vbool32_t, vfloat32m1_t, vfloat32m1_t, float, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vfslide1up_vf)))
vfloat32m2_t vfslide1up_vf_f32m2(vfloat32m2_t, float, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vfslide1up_vf_m)))
vfloat32m2_t vfslide1up_vf_f32m2_m(vbool16_t, vfloat32m2_t, vfloat32m2_t, float, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vfslide1up_vf)))
vfloat32m4_t vfslide1up_vf_f32m4(vfloat32m4_t, float, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vfslide1up_vf_m)))
vfloat32m4_t vfslide1up_vf_f32m4_m(vbool8_t, vfloat32m4_t, vfloat32m4_t, float, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vfslide1up_vf)))
vfloat32m8_t vfslide1up_vf_f32m8(vfloat32m8_t, float, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vfslide1up_vf_m)))
vfloat32m8_t vfslide1up_vf_f32m8_m(vbool4_t, vfloat32m8_t, vfloat32m8_t, float, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vfslide1up_vf)))
vfloat32mf2_t vfslide1up_vf_f32mf2(vfloat32mf2_t, float, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vfslide1up_vf_m)))
vfloat32mf2_t vfslide1up_vf_f32mf2_m(vbool64_t, vfloat32mf2_t, vfloat32mf2_t, float, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vfslide1down_vf)))
vfloat32m1_t vfslide1down_vf_f32m1(vfloat32m1_t, float, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vfslide1down_vf_m)))
vfloat32m1_t vfslide1down_vf_f32m1_m(vbool32_t, vfloat32m1_t, vfloat32m1_t, float, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vfslide1down_vf)))
vfloat32m2_t vfslide1down_vf_f32m2(vfloat32m2_t, float, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vfslide1down_vf_m)))
vfloat32m2_t vfslide1down_vf_f32m2_m(vbool16_t, vfloat32m2_t, vfloat32m2_t, float, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vfslide1down_vf)))
vfloat32m4_t vfslide1down_vf_f32m4(vfloat32m4_t, float, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vfslide1down_vf_m)))
vfloat32m4_t vfslide1down_vf_f32m4_m(vbool8_t, vfloat32m4_t, vfloat32m4_t, float, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vfslide1down_vf)))
vfloat32m8_t vfslide1down_vf_f32m8(vfloat32m8_t, float, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vfslide1down_vf_m)))
vfloat32m8_t vfslide1down_vf_f32m8_m(vbool4_t, vfloat32m8_t, vfloat32m8_t, float, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vfslide1down_vf)))
vfloat32mf2_t vfslide1down_vf_f32mf2(vfloat32mf2_t, float, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vfslide1down_vf_m)))
vfloat32mf2_t vfslide1down_vf_f32mf2_m(vbool64_t, vfloat32mf2_t, vfloat32mf2_t, float, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vrgather_vv)))
vfloat32m1_t vrgather_vv_f32m1(vfloat32m1_t, vuint32m1_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vrgather_vv_m)))
vfloat32m1_t vrgather_vv_f32m1_m(vbool32_t, vfloat32m1_t, vfloat32m1_t, vuint32m1_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vrgather_vv)))
vfloat32m2_t vrgather_vv_f32m2(vfloat32m2_t, vuint32m2_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vrgather_vv_m)))
vfloat32m2_t vrgather_vv_f32m2_m(vbool16_t, vfloat32m2_t, vfloat32m2_t, vuint32m2_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vrgather_vv)))
vfloat32m4_t vrgather_vv_f32m4(vfloat32m4_t, vuint32m4_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vrgather_vv_m)))
vfloat32m4_t vrgather_vv_f32m4_m(vbool8_t, vfloat32m4_t, vfloat32m4_t, vuint32m4_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vrgather_vv)))
vfloat32m8_t vrgather_vv_f32m8(vfloat32m8_t, vuint32m8_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vrgather_vv_m)))
vfloat32m8_t vrgather_vv_f32m8_m(vbool4_t, vfloat32m8_t, vfloat32m8_t, vuint32m8_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vrgather_vv)))
vfloat32mf2_t vrgather_vv_f32mf2(vfloat32mf2_t, vuint32mf2_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vrgather_vv_m)))
vfloat32mf2_t vrgather_vv_f32mf2_m(vbool64_t, vfloat32mf2_t, vfloat32mf2_t, vuint32mf2_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vrgather_vx)))
vfloat32m1_t vrgather_vx_f32m1(vfloat32m1_t, size_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vrgather_vx_m)))
vfloat32m1_t vrgather_vx_f32m1_m(vbool32_t, vfloat32m1_t, vfloat32m1_t, size_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vrgather_vx)))
vfloat32m2_t vrgather_vx_f32m2(vfloat32m2_t, size_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vrgather_vx_m)))
vfloat32m2_t vrgather_vx_f32m2_m(vbool16_t, vfloat32m2_t, vfloat32m2_t, size_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vrgather_vx)))
vfloat32m4_t vrgather_vx_f32m4(vfloat32m4_t, size_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vrgather_vx_m)))
vfloat32m4_t vrgather_vx_f32m4_m(vbool8_t, vfloat32m4_t, vfloat32m4_t, size_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vrgather_vx)))
vfloat32m8_t vrgather_vx_f32m8(vfloat32m8_t, size_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vrgather_vx_m)))
vfloat32m8_t vrgather_vx_f32m8_m(vbool4_t, vfloat32m8_t, vfloat32m8_t, size_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vrgather_vx)))
vfloat32mf2_t vrgather_vx_f32mf2(vfloat32mf2_t, size_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vrgather_vx_m)))
vfloat32mf2_t vrgather_vx_f32mf2_m(vbool64_t, vfloat32mf2_t, vfloat32mf2_t, size_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vrgatherei16_vv)))
vfloat32m1_t vrgatherei16_vv_f32m1(vfloat32m1_t, vuint16mf2_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vrgatherei16_vv_m)))
vfloat32m1_t vrgatherei16_vv_f32m1_m(vbool32_t, vfloat32m1_t, vfloat32m1_t, vuint16mf2_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vrgatherei16_vv)))
vfloat32m2_t vrgatherei16_vv_f32m2(vfloat32m2_t, vuint16m1_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vrgatherei16_vv_m)))
vfloat32m2_t vrgatherei16_vv_f32m2_m(vbool16_t, vfloat32m2_t, vfloat32m2_t, vuint16m1_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vrgatherei16_vv)))
vfloat32m4_t vrgatherei16_vv_f32m4(vfloat32m4_t, vuint16m2_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vrgatherei16_vv_m)))
vfloat32m4_t vrgatherei16_vv_f32m4_m(vbool8_t, vfloat32m4_t, vfloat32m4_t, vuint16m2_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vrgatherei16_vv)))
vfloat32m8_t vrgatherei16_vv_f32m8(vfloat32m8_t, vuint16m4_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vrgatherei16_vv_m)))
vfloat32m8_t vrgatherei16_vv_f32m8_m(vbool4_t, vfloat32m8_t, vfloat32m8_t, vuint16m4_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vrgatherei16_vv)))
vfloat32mf2_t vrgatherei16_vv_f32mf2(vfloat32mf2_t, vuint16mf4_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vrgatherei16_vv_m)))
vfloat32mf2_t vrgatherei16_vv_f32mf2_m(vbool64_t, vfloat32mf2_t, vfloat32mf2_t, vuint16mf4_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vcompress_vm)))
vfloat32m1_t vcompress_vm_f32m1(vbool32_t, vfloat32m1_t, vfloat32m1_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vcompress_vm)))
vfloat32m2_t vcompress_vm_f32m2(vbool16_t, vfloat32m2_t, vfloat32m2_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vcompress_vm)))
vfloat32m4_t vcompress_vm_f32m4(vbool8_t, vfloat32m4_t, vfloat32m4_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vcompress_vm)))
vfloat32m8_t vcompress_vm_f32m8(vbool4_t, vfloat32m8_t, vfloat32m8_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vcompress_vm)))
vfloat32mf2_t vcompress_vm_f32mf2(vbool64_t, vfloat32mf2_t, vfloat32mf2_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vget_v)))
vfloat32m1_t vget_v_f32m2_f32m1(vfloat32m2_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vget_v)))
vfloat32m1_t vget_v_f32m4_f32m1(vfloat32m4_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vget_v)))
vfloat32m1_t vget_v_f32m8_f32m1(vfloat32m8_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vget_v)))
vfloat32m2_t vget_v_f32m4_f32m2(vfloat32m4_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vget_v)))
vfloat32m2_t vget_v_f32m8_f32m2(vfloat32m8_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vget_v)))
vfloat32m4_t vget_v_f32m8_f32m4(vfloat32m8_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vset_v)))
vfloat32m2_t vset_v_f32m1_f32m2(vfloat32m2_t, size_t, vfloat32m1_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vset_v)))
vfloat32m4_t vset_v_f32m1_f32m4(vfloat32m4_t, size_t, vfloat32m1_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vset_v)))
vfloat32m4_t vset_v_f32m2_f32m4(vfloat32m4_t, size_t, vfloat32m2_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vset_v)))
vfloat32m8_t vset_v_f32m1_f32m8(vfloat32m8_t, size_t, vfloat32m1_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vset_v)))
vfloat32m8_t vset_v_f32m2_f32m8(vfloat32m8_t, size_t, vfloat32m2_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vset_v)))
vfloat32m8_t vset_v_f32m4_f32m8(vfloat32m8_t, size_t, vfloat32m4_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vsuxei8_v)))
void vsuxei8_v_f32m1(float *, vuint8mf4_t, vfloat32m1_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vsuxei8_v_m)))
void vsuxei8_v_f32m1_m(vbool32_t, float *, vuint8mf4_t, vfloat32m1_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vsuxei8_v)))
void vsuxei8_v_f32m2(float *, vuint8mf2_t, vfloat32m2_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vsuxei8_v_m)))
void vsuxei8_v_f32m2_m(vbool16_t, float *, vuint8mf2_t, vfloat32m2_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vsuxei8_v)))
void vsuxei8_v_f32m4(float *, vuint8m1_t, vfloat32m4_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vsuxei8_v_m)))
void vsuxei8_v_f32m4_m(vbool8_t, float *, vuint8m1_t, vfloat32m4_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vsuxei8_v)))
void vsuxei8_v_f32m8(float *, vuint8m2_t, vfloat32m8_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vsuxei8_v_m)))
void vsuxei8_v_f32m8_m(vbool4_t, float *, vuint8m2_t, vfloat32m8_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vsuxei8_v)))
void vsuxei8_v_f32mf2(float *, vuint8mf8_t, vfloat32mf2_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vsuxei8_v_m)))
void vsuxei8_v_f32mf2_m(vbool64_t, float *, vuint8mf8_t, vfloat32mf2_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vsuxei16_v)))
void vsuxei16_v_f32m1(float *, vuint16mf2_t, vfloat32m1_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vsuxei16_v_m)))
void vsuxei16_v_f32m1_m(vbool32_t, float *, vuint16mf2_t, vfloat32m1_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vsuxei16_v)))
void vsuxei16_v_f32m2(float *, vuint16m1_t, vfloat32m2_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vsuxei16_v_m)))
void vsuxei16_v_f32m2_m(vbool16_t, float *, vuint16m1_t, vfloat32m2_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vsuxei16_v)))
void vsuxei16_v_f32m4(float *, vuint16m2_t, vfloat32m4_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vsuxei16_v_m)))
void vsuxei16_v_f32m4_m(vbool8_t, float *, vuint16m2_t, vfloat32m4_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vsuxei16_v)))
void vsuxei16_v_f32m8(float *, vuint16m4_t, vfloat32m8_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vsuxei16_v_m)))
void vsuxei16_v_f32m8_m(vbool4_t, float *, vuint16m4_t, vfloat32m8_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vsuxei16_v)))
void vsuxei16_v_f32mf2(float *, vuint16mf4_t, vfloat32mf2_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vsuxei16_v_m)))
void vsuxei16_v_f32mf2_m(vbool64_t, float *, vuint16mf4_t, vfloat32mf2_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vsuxei32_v)))
void vsuxei32_v_f32m1(float *, vuint32m1_t, vfloat32m1_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vsuxei32_v_m)))
void vsuxei32_v_f32m1_m(vbool32_t, float *, vuint32m1_t, vfloat32m1_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vsuxei32_v)))
void vsuxei32_v_f32m2(float *, vuint32m2_t, vfloat32m2_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vsuxei32_v_m)))
void vsuxei32_v_f32m2_m(vbool16_t, float *, vuint32m2_t, vfloat32m2_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vsuxei32_v)))
void vsuxei32_v_f32m4(float *, vuint32m4_t, vfloat32m4_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vsuxei32_v_m)))
void vsuxei32_v_f32m4_m(vbool8_t, float *, vuint32m4_t, vfloat32m4_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vsuxei32_v)))
void vsuxei32_v_f32m8(float *, vuint32m8_t, vfloat32m8_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vsuxei32_v_m)))
void vsuxei32_v_f32m8_m(vbool4_t, float *, vuint32m8_t, vfloat32m8_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vsuxei32_v)))
void vsuxei32_v_f32mf2(float *, vuint32mf2_t, vfloat32mf2_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vsuxei32_v_m)))
void vsuxei32_v_f32mf2_m(vbool64_t, float *, vuint32mf2_t, vfloat32mf2_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vsoxei8_v)))
void vsoxei8_v_f32m1(float *, vuint8mf4_t, vfloat32m1_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vsoxei8_v_m)))
void vsoxei8_v_f32m1_m(vbool32_t, float *, vuint8mf4_t, vfloat32m1_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vsoxei8_v)))
void vsoxei8_v_f32m2(float *, vuint8mf2_t, vfloat32m2_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vsoxei8_v_m)))
void vsoxei8_v_f32m2_m(vbool16_t, float *, vuint8mf2_t, vfloat32m2_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vsoxei8_v)))
void vsoxei8_v_f32m4(float *, vuint8m1_t, vfloat32m4_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vsoxei8_v_m)))
void vsoxei8_v_f32m4_m(vbool8_t, float *, vuint8m1_t, vfloat32m4_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vsoxei8_v)))
void vsoxei8_v_f32m8(float *, vuint8m2_t, vfloat32m8_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vsoxei8_v_m)))
void vsoxei8_v_f32m8_m(vbool4_t, float *, vuint8m2_t, vfloat32m8_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vsoxei8_v)))
void vsoxei8_v_f32mf2(float *, vuint8mf8_t, vfloat32mf2_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vsoxei8_v_m)))
void vsoxei8_v_f32mf2_m(vbool64_t, float *, vuint8mf8_t, vfloat32mf2_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vsoxei16_v)))
void vsoxei16_v_f32m1(float *, vuint16mf2_t, vfloat32m1_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vsoxei16_v_m)))
void vsoxei16_v_f32m1_m(vbool32_t, float *, vuint16mf2_t, vfloat32m1_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vsoxei16_v)))
void vsoxei16_v_f32m2(float *, vuint16m1_t, vfloat32m2_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vsoxei16_v_m)))
void vsoxei16_v_f32m2_m(vbool16_t, float *, vuint16m1_t, vfloat32m2_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vsoxei16_v)))
void vsoxei16_v_f32m4(float *, vuint16m2_t, vfloat32m4_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vsoxei16_v_m)))
void vsoxei16_v_f32m4_m(vbool8_t, float *, vuint16m2_t, vfloat32m4_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vsoxei16_v)))
void vsoxei16_v_f32m8(float *, vuint16m4_t, vfloat32m8_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vsoxei16_v_m)))
void vsoxei16_v_f32m8_m(vbool4_t, float *, vuint16m4_t, vfloat32m8_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vsoxei16_v)))
void vsoxei16_v_f32mf2(float *, vuint16mf4_t, vfloat32mf2_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vsoxei16_v_m)))
void vsoxei16_v_f32mf2_m(vbool64_t, float *, vuint16mf4_t, vfloat32mf2_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vsoxei32_v)))
void vsoxei32_v_f32m1(float *, vuint32m1_t, vfloat32m1_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vsoxei32_v_m)))
void vsoxei32_v_f32m1_m(vbool32_t, float *, vuint32m1_t, vfloat32m1_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vsoxei32_v)))
void vsoxei32_v_f32m2(float *, vuint32m2_t, vfloat32m2_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vsoxei32_v_m)))
void vsoxei32_v_f32m2_m(vbool16_t, float *, vuint32m2_t, vfloat32m2_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vsoxei32_v)))
void vsoxei32_v_f32m4(float *, vuint32m4_t, vfloat32m4_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vsoxei32_v_m)))
void vsoxei32_v_f32m4_m(vbool8_t, float *, vuint32m4_t, vfloat32m4_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vsoxei32_v)))
void vsoxei32_v_f32m8(float *, vuint32m8_t, vfloat32m8_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vsoxei32_v_m)))
void vsoxei32_v_f32m8_m(vbool4_t, float *, vuint32m8_t, vfloat32m8_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vsoxei32_v)))
void vsoxei32_v_f32mf2(float *, vuint32mf2_t, vfloat32mf2_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vsoxei32_v_m)))
void vsoxei32_v_f32mf2_m(vbool64_t, float *, vuint32mf2_t, vfloat32mf2_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vle32ff_v)))
vfloat32m1_t vle32ff_v_f32m1(const float *, size_t *, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vle32ff_v_m)))
vfloat32m1_t vle32ff_v_f32m1_m(vbool32_t, vfloat32m1_t, const float *, size_t *, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vle32ff_v)))
vfloat32m2_t vle32ff_v_f32m2(const float *, size_t *, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vle32ff_v_m)))
vfloat32m2_t vle32ff_v_f32m2_m(vbool16_t, vfloat32m2_t, const float *, size_t *, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vle32ff_v)))
vfloat32m4_t vle32ff_v_f32m4(const float *, size_t *, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vle32ff_v_m)))
vfloat32m4_t vle32ff_v_f32m4_m(vbool8_t, vfloat32m4_t, const float *, size_t *, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vle32ff_v)))
vfloat32m8_t vle32ff_v_f32m8(const float *, size_t *, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vle32ff_v_m)))
vfloat32m8_t vle32ff_v_f32m8_m(vbool4_t, vfloat32m8_t, const float *, size_t *, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vle32ff_v)))
vfloat32mf2_t vle32ff_v_f32mf2(const float *, size_t *, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vle32ff_v_m)))
vfloat32mf2_t vle32ff_v_f32mf2_m(vbool64_t, vfloat32mf2_t, const float *, size_t *, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vlseg2e32_v)))
void vlseg2e32_v_f32m1(vfloat32m1_t *, vfloat32m1_t *, const float *, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vlseg2e32_v_m)))
void vlseg2e32_v_f32m1_m(vfloat32m1_t *, vfloat32m1_t *, vbool32_t, vfloat32m1_t, vfloat32m1_t, const float *, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vlseg2e32_v)))
void vlseg2e32_v_f32m2(vfloat32m2_t *, vfloat32m2_t *, const float *, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vlseg2e32_v_m)))
void vlseg2e32_v_f32m2_m(vfloat32m2_t *, vfloat32m2_t *, vbool16_t, vfloat32m2_t, vfloat32m2_t, const float *, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vlseg2e32_v)))
void vlseg2e32_v_f32m4(vfloat32m4_t *, vfloat32m4_t *, const float *, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vlseg2e32_v_m)))
void vlseg2e32_v_f32m4_m(vfloat32m4_t *, vfloat32m4_t *, vbool8_t, vfloat32m4_t, vfloat32m4_t, const float *, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vlseg2e32_v)))
void vlseg2e32_v_f32mf2(vfloat32mf2_t *, vfloat32mf2_t *, const float *, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vlseg2e32_v_m)))
void vlseg2e32_v_f32mf2_m(vfloat32mf2_t *, vfloat32mf2_t *, vbool64_t, vfloat32mf2_t, vfloat32mf2_t, const float *, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vlseg3e32_v)))
void vlseg3e32_v_f32m1(vfloat32m1_t *, vfloat32m1_t *, vfloat32m1_t *, const float *, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vlseg3e32_v_m)))
void vlseg3e32_v_f32m1_m(vfloat32m1_t *, vfloat32m1_t *, vfloat32m1_t *, vbool32_t, vfloat32m1_t, vfloat32m1_t, vfloat32m1_t, const float *, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vlseg3e32_v)))
void vlseg3e32_v_f32m2(vfloat32m2_t *, vfloat32m2_t *, vfloat32m2_t *, const float *, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vlseg3e32_v_m)))
void vlseg3e32_v_f32m2_m(vfloat32m2_t *, vfloat32m2_t *, vfloat32m2_t *, vbool16_t, vfloat32m2_t, vfloat32m2_t, vfloat32m2_t, const float *, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vlseg3e32_v)))
void vlseg3e32_v_f32mf2(vfloat32mf2_t *, vfloat32mf2_t *, vfloat32mf2_t *, const float *, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vlseg3e32_v_m)))
void vlseg3e32_v_f32mf2_m(vfloat32mf2_t *, vfloat32mf2_t *, vfloat32mf2_t *, vbool64_t, vfloat32mf2_t, vfloat32mf2_t, vfloat32mf2_t, const float *, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vlseg4e32_v)))
void vlseg4e32_v_f32m1(vfloat32m1_t *, vfloat32m1_t *, vfloat32m1_t *, vfloat32m1_t *, const float *, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vlseg4e32_v_m)))
void vlseg4e32_v_f32m1_m(vfloat32m1_t *, vfloat32m1_t *, vfloat32m1_t *, vfloat32m1_t *, vbool32_t, vfloat32m1_t, vfloat32m1_t, vfloat32m1_t, vfloat32m1_t, const float *, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vlseg4e32_v)))
void vlseg4e32_v_f32m2(vfloat32m2_t *, vfloat32m2_t *, vfloat32m2_t *, vfloat32m2_t *, const float *, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vlseg4e32_v_m)))
void vlseg4e32_v_f32m2_m(vfloat32m2_t *, vfloat32m2_t *, vfloat32m2_t *, vfloat32m2_t *, vbool16_t, vfloat32m2_t, vfloat32m2_t, vfloat32m2_t, vfloat32m2_t, const float *, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vlseg4e32_v)))
void vlseg4e32_v_f32mf2(vfloat32mf2_t *, vfloat32mf2_t *, vfloat32mf2_t *, vfloat32mf2_t *, const float *, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vlseg4e32_v_m)))
void vlseg4e32_v_f32mf2_m(vfloat32mf2_t *, vfloat32mf2_t *, vfloat32mf2_t *, vfloat32mf2_t *, vbool64_t, vfloat32mf2_t, vfloat32mf2_t, vfloat32mf2_t, vfloat32mf2_t, const float *, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vlseg5e32_v)))
void vlseg5e32_v_f32m1(vfloat32m1_t *, vfloat32m1_t *, vfloat32m1_t *, vfloat32m1_t *, vfloat32m1_t *, const float *, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vlseg5e32_v_m)))
void vlseg5e32_v_f32m1_m(vfloat32m1_t *, vfloat32m1_t *, vfloat32m1_t *, vfloat32m1_t *, vfloat32m1_t *, vbool32_t, vfloat32m1_t, vfloat32m1_t, vfloat32m1_t, vfloat32m1_t, vfloat32m1_t, const float *, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vlseg5e32_v)))
void vlseg5e32_v_f32mf2(vfloat32mf2_t *, vfloat32mf2_t *, vfloat32mf2_t *, vfloat32mf2_t *, vfloat32mf2_t *, const float *, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vlseg5e32_v_m)))
void vlseg5e32_v_f32mf2_m(vfloat32mf2_t *, vfloat32mf2_t *, vfloat32mf2_t *, vfloat32mf2_t *, vfloat32mf2_t *, vbool64_t, vfloat32mf2_t, vfloat32mf2_t, vfloat32mf2_t, vfloat32mf2_t, vfloat32mf2_t, const float *, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vlseg6e32_v)))
void vlseg6e32_v_f32m1(vfloat32m1_t *, vfloat32m1_t *, vfloat32m1_t *, vfloat32m1_t *, vfloat32m1_t *, vfloat32m1_t *, const float *, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vlseg6e32_v_m)))
void vlseg6e32_v_f32m1_m(vfloat32m1_t *, vfloat32m1_t *, vfloat32m1_t *, vfloat32m1_t *, vfloat32m1_t *, vfloat32m1_t *, vbool32_t, vfloat32m1_t, vfloat32m1_t, vfloat32m1_t, vfloat32m1_t, vfloat32m1_t, vfloat32m1_t, const float *, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vlseg6e32_v)))
void vlseg6e32_v_f32mf2(vfloat32mf2_t *, vfloat32mf2_t *, vfloat32mf2_t *, vfloat32mf2_t *, vfloat32mf2_t *, vfloat32mf2_t *, const float *, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vlseg6e32_v_m)))
void vlseg6e32_v_f32mf2_m(vfloat32mf2_t *, vfloat32mf2_t *, vfloat32mf2_t *, vfloat32mf2_t *, vfloat32mf2_t *, vfloat32mf2_t *, vbool64_t, vfloat32mf2_t, vfloat32mf2_t, vfloat32mf2_t, vfloat32mf2_t, vfloat32mf2_t, vfloat32mf2_t, const float *, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vlseg7e32_v)))
void vlseg7e32_v_f32m1(vfloat32m1_t *, vfloat32m1_t *, vfloat32m1_t *, vfloat32m1_t *, vfloat32m1_t *, vfloat32m1_t *, vfloat32m1_t *, const float *, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vlseg7e32_v_m)))
void vlseg7e32_v_f32m1_m(vfloat32m1_t *, vfloat32m1_t *, vfloat32m1_t *, vfloat32m1_t *, vfloat32m1_t *, vfloat32m1_t *, vfloat32m1_t *, vbool32_t, vfloat32m1_t, vfloat32m1_t, vfloat32m1_t, vfloat32m1_t, vfloat32m1_t, vfloat32m1_t, vfloat32m1_t, const float *, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vlseg7e32_v)))
void vlseg7e32_v_f32mf2(vfloat32mf2_t *, vfloat32mf2_t *, vfloat32mf2_t *, vfloat32mf2_t *, vfloat32mf2_t *, vfloat32mf2_t *, vfloat32mf2_t *, const float *, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vlseg7e32_v_m)))
void vlseg7e32_v_f32mf2_m(vfloat32mf2_t *, vfloat32mf2_t *, vfloat32mf2_t *, vfloat32mf2_t *, vfloat32mf2_t *, vfloat32mf2_t *, vfloat32mf2_t *, vbool64_t, vfloat32mf2_t, vfloat32mf2_t, vfloat32mf2_t, vfloat32mf2_t, vfloat32mf2_t, vfloat32mf2_t, vfloat32mf2_t, const float *, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vlseg8e32_v)))
void vlseg8e32_v_f32m1(vfloat32m1_t *, vfloat32m1_t *, vfloat32m1_t *, vfloat32m1_t *, vfloat32m1_t *, vfloat32m1_t *, vfloat32m1_t *, vfloat32m1_t *, const float *, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vlseg8e32_v_m)))
void vlseg8e32_v_f32m1_m(vfloat32m1_t *, vfloat32m1_t *, vfloat32m1_t *, vfloat32m1_t *, vfloat32m1_t *, vfloat32m1_t *, vfloat32m1_t *, vfloat32m1_t *, vbool32_t, vfloat32m1_t, vfloat32m1_t, vfloat32m1_t, vfloat32m1_t, vfloat32m1_t, vfloat32m1_t, vfloat32m1_t, vfloat32m1_t, const float *, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vlseg8e32_v)))
void vlseg8e32_v_f32mf2(vfloat32mf2_t *, vfloat32mf2_t *, vfloat32mf2_t *, vfloat32mf2_t *, vfloat32mf2_t *, vfloat32mf2_t *, vfloat32mf2_t *, vfloat32mf2_t *, const float *, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vlseg8e32_v_m)))
void vlseg8e32_v_f32mf2_m(vfloat32mf2_t *, vfloat32mf2_t *, vfloat32mf2_t *, vfloat32mf2_t *, vfloat32mf2_t *, vfloat32mf2_t *, vfloat32mf2_t *, vfloat32mf2_t *, vbool64_t, vfloat32mf2_t, vfloat32mf2_t, vfloat32mf2_t, vfloat32mf2_t, vfloat32mf2_t, vfloat32mf2_t, vfloat32mf2_t, vfloat32mf2_t, const float *, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vlseg2e32ff_v)))
void vlseg2e32ff_v_f32m1(vfloat32m1_t *, vfloat32m1_t *, const float *, size_t *, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vlseg2e32ff_v_m)))
void vlseg2e32ff_v_f32m1_m(vfloat32m1_t *, vfloat32m1_t *, vbool32_t, vfloat32m1_t, vfloat32m1_t, const float *, size_t *, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vlseg2e32ff_v)))
void vlseg2e32ff_v_f32m2(vfloat32m2_t *, vfloat32m2_t *, const float *, size_t *, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vlseg2e32ff_v_m)))
void vlseg2e32ff_v_f32m2_m(vfloat32m2_t *, vfloat32m2_t *, vbool16_t, vfloat32m2_t, vfloat32m2_t, const float *, size_t *, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vlseg2e32ff_v)))
void vlseg2e32ff_v_f32m4(vfloat32m4_t *, vfloat32m4_t *, const float *, size_t *, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vlseg2e32ff_v_m)))
void vlseg2e32ff_v_f32m4_m(vfloat32m4_t *, vfloat32m4_t *, vbool8_t, vfloat32m4_t, vfloat32m4_t, const float *, size_t *, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vlseg2e32ff_v)))
void vlseg2e32ff_v_f32mf2(vfloat32mf2_t *, vfloat32mf2_t *, const float *, size_t *, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vlseg2e32ff_v_m)))
void vlseg2e32ff_v_f32mf2_m(vfloat32mf2_t *, vfloat32mf2_t *, vbool64_t, vfloat32mf2_t, vfloat32mf2_t, const float *, size_t *, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vlseg3e32ff_v)))
void vlseg3e32ff_v_f32m1(vfloat32m1_t *, vfloat32m1_t *, vfloat32m1_t *, const float *, size_t *, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vlseg3e32ff_v_m)))
void vlseg3e32ff_v_f32m1_m(vfloat32m1_t *, vfloat32m1_t *, vfloat32m1_t *, vbool32_t, vfloat32m1_t, vfloat32m1_t, vfloat32m1_t, const float *, size_t *, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vlseg3e32ff_v)))
void vlseg3e32ff_v_f32m2(vfloat32m2_t *, vfloat32m2_t *, vfloat32m2_t *, const float *, size_t *, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vlseg3e32ff_v_m)))
void vlseg3e32ff_v_f32m2_m(vfloat32m2_t *, vfloat32m2_t *, vfloat32m2_t *, vbool16_t, vfloat32m2_t, vfloat32m2_t, vfloat32m2_t, const float *, size_t *, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vlseg3e32ff_v)))
void vlseg3e32ff_v_f32mf2(vfloat32mf2_t *, vfloat32mf2_t *, vfloat32mf2_t *, const float *, size_t *, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vlseg3e32ff_v_m)))
void vlseg3e32ff_v_f32mf2_m(vfloat32mf2_t *, vfloat32mf2_t *, vfloat32mf2_t *, vbool64_t, vfloat32mf2_t, vfloat32mf2_t, vfloat32mf2_t, const float *, size_t *, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vlseg4e32ff_v)))
void vlseg4e32ff_v_f32m1(vfloat32m1_t *, vfloat32m1_t *, vfloat32m1_t *, vfloat32m1_t *, const float *, size_t *, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vlseg4e32ff_v_m)))
void vlseg4e32ff_v_f32m1_m(vfloat32m1_t *, vfloat32m1_t *, vfloat32m1_t *, vfloat32m1_t *, vbool32_t, vfloat32m1_t, vfloat32m1_t, vfloat32m1_t, vfloat32m1_t, const float *, size_t *, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vlseg4e32ff_v)))
void vlseg4e32ff_v_f32m2(vfloat32m2_t *, vfloat32m2_t *, vfloat32m2_t *, vfloat32m2_t *, const float *, size_t *, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vlseg4e32ff_v_m)))
void vlseg4e32ff_v_f32m2_m(vfloat32m2_t *, vfloat32m2_t *, vfloat32m2_t *, vfloat32m2_t *, vbool16_t, vfloat32m2_t, vfloat32m2_t, vfloat32m2_t, vfloat32m2_t, const float *, size_t *, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vlseg4e32ff_v)))
void vlseg4e32ff_v_f32mf2(vfloat32mf2_t *, vfloat32mf2_t *, vfloat32mf2_t *, vfloat32mf2_t *, const float *, size_t *, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vlseg4e32ff_v_m)))
void vlseg4e32ff_v_f32mf2_m(vfloat32mf2_t *, vfloat32mf2_t *, vfloat32mf2_t *, vfloat32mf2_t *, vbool64_t, vfloat32mf2_t, vfloat32mf2_t, vfloat32mf2_t, vfloat32mf2_t, const float *, size_t *, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vlseg5e32ff_v)))
void vlseg5e32ff_v_f32m1(vfloat32m1_t *, vfloat32m1_t *, vfloat32m1_t *, vfloat32m1_t *, vfloat32m1_t *, const float *, size_t *, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vlseg5e32ff_v_m)))
void vlseg5e32ff_v_f32m1_m(vfloat32m1_t *, vfloat32m1_t *, vfloat32m1_t *, vfloat32m1_t *, vfloat32m1_t *, vbool32_t, vfloat32m1_t, vfloat32m1_t, vfloat32m1_t, vfloat32m1_t, vfloat32m1_t, const float *, size_t *, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vlseg5e32ff_v)))
void vlseg5e32ff_v_f32mf2(vfloat32mf2_t *, vfloat32mf2_t *, vfloat32mf2_t *, vfloat32mf2_t *, vfloat32mf2_t *, const float *, size_t *, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vlseg5e32ff_v_m)))
void vlseg5e32ff_v_f32mf2_m(vfloat32mf2_t *, vfloat32mf2_t *, vfloat32mf2_t *, vfloat32mf2_t *, vfloat32mf2_t *, vbool64_t, vfloat32mf2_t, vfloat32mf2_t, vfloat32mf2_t, vfloat32mf2_t, vfloat32mf2_t, const float *, size_t *, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vlseg6e32ff_v)))
void vlseg6e32ff_v_f32m1(vfloat32m1_t *, vfloat32m1_t *, vfloat32m1_t *, vfloat32m1_t *, vfloat32m1_t *, vfloat32m1_t *, const float *, size_t *, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vlseg6e32ff_v_m)))
void vlseg6e32ff_v_f32m1_m(vfloat32m1_t *, vfloat32m1_t *, vfloat32m1_t *, vfloat32m1_t *, vfloat32m1_t *, vfloat32m1_t *, vbool32_t, vfloat32m1_t, vfloat32m1_t, vfloat32m1_t, vfloat32m1_t, vfloat32m1_t, vfloat32m1_t, const float *, size_t *, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vlseg6e32ff_v)))
void vlseg6e32ff_v_f32mf2(vfloat32mf2_t *, vfloat32mf2_t *, vfloat32mf2_t *, vfloat32mf2_t *, vfloat32mf2_t *, vfloat32mf2_t *, const float *, size_t *, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vlseg6e32ff_v_m)))
void vlseg6e32ff_v_f32mf2_m(vfloat32mf2_t *, vfloat32mf2_t *, vfloat32mf2_t *, vfloat32mf2_t *, vfloat32mf2_t *, vfloat32mf2_t *, vbool64_t, vfloat32mf2_t, vfloat32mf2_t, vfloat32mf2_t, vfloat32mf2_t, vfloat32mf2_t, vfloat32mf2_t, const float *, size_t *, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vlseg7e32ff_v)))
void vlseg7e32ff_v_f32m1(vfloat32m1_t *, vfloat32m1_t *, vfloat32m1_t *, vfloat32m1_t *, vfloat32m1_t *, vfloat32m1_t *, vfloat32m1_t *, const float *, size_t *, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vlseg7e32ff_v_m)))
void vlseg7e32ff_v_f32m1_m(vfloat32m1_t *, vfloat32m1_t *, vfloat32m1_t *, vfloat32m1_t *, vfloat32m1_t *, vfloat32m1_t *, vfloat32m1_t *, vbool32_t, vfloat32m1_t, vfloat32m1_t, vfloat32m1_t, vfloat32m1_t, vfloat32m1_t, vfloat32m1_t, vfloat32m1_t, const float *, size_t *, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vlseg7e32ff_v)))
void vlseg7e32ff_v_f32mf2(vfloat32mf2_t *, vfloat32mf2_t *, vfloat32mf2_t *, vfloat32mf2_t *, vfloat32mf2_t *, vfloat32mf2_t *, vfloat32mf2_t *, const float *, size_t *, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vlseg7e32ff_v_m)))
void vlseg7e32ff_v_f32mf2_m(vfloat32mf2_t *, vfloat32mf2_t *, vfloat32mf2_t *, vfloat32mf2_t *, vfloat32mf2_t *, vfloat32mf2_t *, vfloat32mf2_t *, vbool64_t, vfloat32mf2_t, vfloat32mf2_t, vfloat32mf2_t, vfloat32mf2_t, vfloat32mf2_t, vfloat32mf2_t, vfloat32mf2_t, const float *, size_t *, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vlseg8e32ff_v)))
void vlseg8e32ff_v_f32m1(vfloat32m1_t *, vfloat32m1_t *, vfloat32m1_t *, vfloat32m1_t *, vfloat32m1_t *, vfloat32m1_t *, vfloat32m1_t *, vfloat32m1_t *, const float *, size_t *, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vlseg8e32ff_v_m)))
void vlseg8e32ff_v_f32m1_m(vfloat32m1_t *, vfloat32m1_t *, vfloat32m1_t *, vfloat32m1_t *, vfloat32m1_t *, vfloat32m1_t *, vfloat32m1_t *, vfloat32m1_t *, vbool32_t, vfloat32m1_t, vfloat32m1_t, vfloat32m1_t, vfloat32m1_t, vfloat32m1_t, vfloat32m1_t, vfloat32m1_t, vfloat32m1_t, const float *, size_t *, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vlseg8e32ff_v)))
void vlseg8e32ff_v_f32mf2(vfloat32mf2_t *, vfloat32mf2_t *, vfloat32mf2_t *, vfloat32mf2_t *, vfloat32mf2_t *, vfloat32mf2_t *, vfloat32mf2_t *, vfloat32mf2_t *, const float *, size_t *, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vlseg8e32ff_v_m)))
void vlseg8e32ff_v_f32mf2_m(vfloat32mf2_t *, vfloat32mf2_t *, vfloat32mf2_t *, vfloat32mf2_t *, vfloat32mf2_t *, vfloat32mf2_t *, vfloat32mf2_t *, vfloat32mf2_t *, vbool64_t, vfloat32mf2_t, vfloat32mf2_t, vfloat32mf2_t, vfloat32mf2_t, vfloat32mf2_t, vfloat32mf2_t, vfloat32mf2_t, vfloat32mf2_t, const float *, size_t *, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vlsseg2e32_v)))
void vlsseg2e32_v_f32m1(vfloat32m1_t *, vfloat32m1_t *, const float *, ptrdiff_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vlsseg2e32_v_m)))
void vlsseg2e32_v_f32m1_m(vfloat32m1_t *, vfloat32m1_t *, vbool32_t, vfloat32m1_t, vfloat32m1_t, const float *, ptrdiff_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vlsseg2e32_v)))
void vlsseg2e32_v_f32m2(vfloat32m2_t *, vfloat32m2_t *, const float *, ptrdiff_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vlsseg2e32_v_m)))
void vlsseg2e32_v_f32m2_m(vfloat32m2_t *, vfloat32m2_t *, vbool16_t, vfloat32m2_t, vfloat32m2_t, const float *, ptrdiff_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vlsseg2e32_v)))
void vlsseg2e32_v_f32m4(vfloat32m4_t *, vfloat32m4_t *, const float *, ptrdiff_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vlsseg2e32_v_m)))
void vlsseg2e32_v_f32m4_m(vfloat32m4_t *, vfloat32m4_t *, vbool8_t, vfloat32m4_t, vfloat32m4_t, const float *, ptrdiff_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vlsseg2e32_v)))
void vlsseg2e32_v_f32mf2(vfloat32mf2_t *, vfloat32mf2_t *, const float *, ptrdiff_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vlsseg2e32_v_m)))
void vlsseg2e32_v_f32mf2_m(vfloat32mf2_t *, vfloat32mf2_t *, vbool64_t, vfloat32mf2_t, vfloat32mf2_t, const float *, ptrdiff_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vlsseg3e32_v)))
void vlsseg3e32_v_f32m1(vfloat32m1_t *, vfloat32m1_t *, vfloat32m1_t *, const float *, ptrdiff_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vlsseg3e32_v_m)))
void vlsseg3e32_v_f32m1_m(vfloat32m1_t *, vfloat32m1_t *, vfloat32m1_t *, vbool32_t, vfloat32m1_t, vfloat32m1_t, vfloat32m1_t, const float *, ptrdiff_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vlsseg3e32_v)))
void vlsseg3e32_v_f32m2(vfloat32m2_t *, vfloat32m2_t *, vfloat32m2_t *, const float *, ptrdiff_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vlsseg3e32_v_m)))
void vlsseg3e32_v_f32m2_m(vfloat32m2_t *, vfloat32m2_t *, vfloat32m2_t *, vbool16_t, vfloat32m2_t, vfloat32m2_t, vfloat32m2_t, const float *, ptrdiff_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vlsseg3e32_v)))
void vlsseg3e32_v_f32mf2(vfloat32mf2_t *, vfloat32mf2_t *, vfloat32mf2_t *, const float *, ptrdiff_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vlsseg3e32_v_m)))
void vlsseg3e32_v_f32mf2_m(vfloat32mf2_t *, vfloat32mf2_t *, vfloat32mf2_t *, vbool64_t, vfloat32mf2_t, vfloat32mf2_t, vfloat32mf2_t, const float *, ptrdiff_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vlsseg4e32_v)))
void vlsseg4e32_v_f32m1(vfloat32m1_t *, vfloat32m1_t *, vfloat32m1_t *, vfloat32m1_t *, const float *, ptrdiff_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vlsseg4e32_v_m)))
void vlsseg4e32_v_f32m1_m(vfloat32m1_t *, vfloat32m1_t *, vfloat32m1_t *, vfloat32m1_t *, vbool32_t, vfloat32m1_t, vfloat32m1_t, vfloat32m1_t, vfloat32m1_t, const float *, ptrdiff_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vlsseg4e32_v)))
void vlsseg4e32_v_f32m2(vfloat32m2_t *, vfloat32m2_t *, vfloat32m2_t *, vfloat32m2_t *, const float *, ptrdiff_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vlsseg4e32_v_m)))
void vlsseg4e32_v_f32m2_m(vfloat32m2_t *, vfloat32m2_t *, vfloat32m2_t *, vfloat32m2_t *, vbool16_t, vfloat32m2_t, vfloat32m2_t, vfloat32m2_t, vfloat32m2_t, const float *, ptrdiff_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vlsseg4e32_v)))
void vlsseg4e32_v_f32mf2(vfloat32mf2_t *, vfloat32mf2_t *, vfloat32mf2_t *, vfloat32mf2_t *, const float *, ptrdiff_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vlsseg4e32_v_m)))
void vlsseg4e32_v_f32mf2_m(vfloat32mf2_t *, vfloat32mf2_t *, vfloat32mf2_t *, vfloat32mf2_t *, vbool64_t, vfloat32mf2_t, vfloat32mf2_t, vfloat32mf2_t, vfloat32mf2_t, const float *, ptrdiff_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vlsseg5e32_v)))
void vlsseg5e32_v_f32m1(vfloat32m1_t *, vfloat32m1_t *, vfloat32m1_t *, vfloat32m1_t *, vfloat32m1_t *, const float *, ptrdiff_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vlsseg5e32_v_m)))
void vlsseg5e32_v_f32m1_m(vfloat32m1_t *, vfloat32m1_t *, vfloat32m1_t *, vfloat32m1_t *, vfloat32m1_t *, vbool32_t, vfloat32m1_t, vfloat32m1_t, vfloat32m1_t, vfloat32m1_t, vfloat32m1_t, const float *, ptrdiff_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vlsseg5e32_v)))
void vlsseg5e32_v_f32mf2(vfloat32mf2_t *, vfloat32mf2_t *, vfloat32mf2_t *, vfloat32mf2_t *, vfloat32mf2_t *, const float *, ptrdiff_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vlsseg5e32_v_m)))
void vlsseg5e32_v_f32mf2_m(vfloat32mf2_t *, vfloat32mf2_t *, vfloat32mf2_t *, vfloat32mf2_t *, vfloat32mf2_t *, vbool64_t, vfloat32mf2_t, vfloat32mf2_t, vfloat32mf2_t, vfloat32mf2_t, vfloat32mf2_t, const float *, ptrdiff_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vlsseg6e32_v)))
void vlsseg6e32_v_f32m1(vfloat32m1_t *, vfloat32m1_t *, vfloat32m1_t *, vfloat32m1_t *, vfloat32m1_t *, vfloat32m1_t *, const float *, ptrdiff_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vlsseg6e32_v_m)))
void vlsseg6e32_v_f32m1_m(vfloat32m1_t *, vfloat32m1_t *, vfloat32m1_t *, vfloat32m1_t *, vfloat32m1_t *, vfloat32m1_t *, vbool32_t, vfloat32m1_t, vfloat32m1_t, vfloat32m1_t, vfloat32m1_t, vfloat32m1_t, vfloat32m1_t, const float *, ptrdiff_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vlsseg6e32_v)))
void vlsseg6e32_v_f32mf2(vfloat32mf2_t *, vfloat32mf2_t *, vfloat32mf2_t *, vfloat32mf2_t *, vfloat32mf2_t *, vfloat32mf2_t *, const float *, ptrdiff_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vlsseg6e32_v_m)))
void vlsseg6e32_v_f32mf2_m(vfloat32mf2_t *, vfloat32mf2_t *, vfloat32mf2_t *, vfloat32mf2_t *, vfloat32mf2_t *, vfloat32mf2_t *, vbool64_t, vfloat32mf2_t, vfloat32mf2_t, vfloat32mf2_t, vfloat32mf2_t, vfloat32mf2_t, vfloat32mf2_t, const float *, ptrdiff_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vlsseg7e32_v)))
void vlsseg7e32_v_f32m1(vfloat32m1_t *, vfloat32m1_t *, vfloat32m1_t *, vfloat32m1_t *, vfloat32m1_t *, vfloat32m1_t *, vfloat32m1_t *, const float *, ptrdiff_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vlsseg7e32_v_m)))
void vlsseg7e32_v_f32m1_m(vfloat32m1_t *, vfloat32m1_t *, vfloat32m1_t *, vfloat32m1_t *, vfloat32m1_t *, vfloat32m1_t *, vfloat32m1_t *, vbool32_t, vfloat32m1_t, vfloat32m1_t, vfloat32m1_t, vfloat32m1_t, vfloat32m1_t, vfloat32m1_t, vfloat32m1_t, const float *, ptrdiff_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vlsseg7e32_v)))
void vlsseg7e32_v_f32mf2(vfloat32mf2_t *, vfloat32mf2_t *, vfloat32mf2_t *, vfloat32mf2_t *, vfloat32mf2_t *, vfloat32mf2_t *, vfloat32mf2_t *, const float *, ptrdiff_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vlsseg7e32_v_m)))
void vlsseg7e32_v_f32mf2_m(vfloat32mf2_t *, vfloat32mf2_t *, vfloat32mf2_t *, vfloat32mf2_t *, vfloat32mf2_t *, vfloat32mf2_t *, vfloat32mf2_t *, vbool64_t, vfloat32mf2_t, vfloat32mf2_t, vfloat32mf2_t, vfloat32mf2_t, vfloat32mf2_t, vfloat32mf2_t, vfloat32mf2_t, const float *, ptrdiff_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vlsseg8e32_v)))
void vlsseg8e32_v_f32m1(vfloat32m1_t *, vfloat32m1_t *, vfloat32m1_t *, vfloat32m1_t *, vfloat32m1_t *, vfloat32m1_t *, vfloat32m1_t *, vfloat32m1_t *, const float *, ptrdiff_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vlsseg8e32_v_m)))
void vlsseg8e32_v_f32m1_m(vfloat32m1_t *, vfloat32m1_t *, vfloat32m1_t *, vfloat32m1_t *, vfloat32m1_t *, vfloat32m1_t *, vfloat32m1_t *, vfloat32m1_t *, vbool32_t, vfloat32m1_t, vfloat32m1_t, vfloat32m1_t, vfloat32m1_t, vfloat32m1_t, vfloat32m1_t, vfloat32m1_t, vfloat32m1_t, const float *, ptrdiff_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vlsseg8e32_v)))
void vlsseg8e32_v_f32mf2(vfloat32mf2_t *, vfloat32mf2_t *, vfloat32mf2_t *, vfloat32mf2_t *, vfloat32mf2_t *, vfloat32mf2_t *, vfloat32mf2_t *, vfloat32mf2_t *, const float *, ptrdiff_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vlsseg8e32_v_m)))
void vlsseg8e32_v_f32mf2_m(vfloat32mf2_t *, vfloat32mf2_t *, vfloat32mf2_t *, vfloat32mf2_t *, vfloat32mf2_t *, vfloat32mf2_t *, vfloat32mf2_t *, vfloat32mf2_t *, vbool64_t, vfloat32mf2_t, vfloat32mf2_t, vfloat32mf2_t, vfloat32mf2_t, vfloat32mf2_t, vfloat32mf2_t, vfloat32mf2_t, vfloat32mf2_t, const float *, ptrdiff_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vfneg_v)))
vfloat32m1_t vfneg_v_f32m1(vfloat32m1_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vfneg_v_m)))
vfloat32m1_t vfneg_v_f32m1_m(vbool32_t, vfloat32m1_t, vfloat32m1_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vfneg_v)))
vfloat32m2_t vfneg_v_f32m2(vfloat32m2_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vfneg_v_m)))
vfloat32m2_t vfneg_v_f32m2_m(vbool16_t, vfloat32m2_t, vfloat32m2_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vfneg_v)))
vfloat32m4_t vfneg_v_f32m4(vfloat32m4_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vfneg_v_m)))
vfloat32m4_t vfneg_v_f32m4_m(vbool8_t, vfloat32m4_t, vfloat32m4_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vfneg_v)))
vfloat32m8_t vfneg_v_f32m8(vfloat32m8_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vfneg_v_m)))
vfloat32m8_t vfneg_v_f32m8_m(vbool4_t, vfloat32m8_t, vfloat32m8_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vfneg_v)))
vfloat32mf2_t vfneg_v_f32mf2(vfloat32mf2_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vfneg_v_m)))
vfloat32mf2_t vfneg_v_f32mf2_m(vbool64_t, vfloat32mf2_t, vfloat32mf2_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vluxseg2ei8_v)))
void vluxseg2ei8_v_f32m1(vfloat32m1_t *, vfloat32m1_t *, const float *, vuint8mf4_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vluxseg2ei8_v_m)))
void vluxseg2ei8_v_f32m1_m(vfloat32m1_t *, vfloat32m1_t *, vbool32_t, vfloat32m1_t, vfloat32m1_t, const float *, vuint8mf4_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vluxseg2ei8_v)))
void vluxseg2ei8_v_f32m2(vfloat32m2_t *, vfloat32m2_t *, const float *, vuint8mf2_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vluxseg2ei8_v_m)))
void vluxseg2ei8_v_f32m2_m(vfloat32m2_t *, vfloat32m2_t *, vbool16_t, vfloat32m2_t, vfloat32m2_t, const float *, vuint8mf2_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vluxseg2ei8_v)))
void vluxseg2ei8_v_f32m4(vfloat32m4_t *, vfloat32m4_t *, const float *, vuint8m1_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vluxseg2ei8_v_m)))
void vluxseg2ei8_v_f32m4_m(vfloat32m4_t *, vfloat32m4_t *, vbool8_t, vfloat32m4_t, vfloat32m4_t, const float *, vuint8m1_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vluxseg2ei8_v)))
void vluxseg2ei8_v_f32mf2(vfloat32mf2_t *, vfloat32mf2_t *, const float *, vuint8mf8_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vluxseg2ei8_v_m)))
void vluxseg2ei8_v_f32mf2_m(vfloat32mf2_t *, vfloat32mf2_t *, vbool64_t, vfloat32mf2_t, vfloat32mf2_t, const float *, vuint8mf8_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vluxseg3ei8_v)))
void vluxseg3ei8_v_f32m1(vfloat32m1_t *, vfloat32m1_t *, vfloat32m1_t *, const float *, vuint8mf4_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vluxseg3ei8_v_m)))
void vluxseg3ei8_v_f32m1_m(vfloat32m1_t *, vfloat32m1_t *, vfloat32m1_t *, vbool32_t, vfloat32m1_t, vfloat32m1_t, vfloat32m1_t, const float *, vuint8mf4_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vluxseg3ei8_v)))
void vluxseg3ei8_v_f32m2(vfloat32m2_t *, vfloat32m2_t *, vfloat32m2_t *, const float *, vuint8mf2_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vluxseg3ei8_v_m)))
void vluxseg3ei8_v_f32m2_m(vfloat32m2_t *, vfloat32m2_t *, vfloat32m2_t *, vbool16_t, vfloat32m2_t, vfloat32m2_t, vfloat32m2_t, const float *, vuint8mf2_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vluxseg3ei8_v)))
void vluxseg3ei8_v_f32mf2(vfloat32mf2_t *, vfloat32mf2_t *, vfloat32mf2_t *, const float *, vuint8mf8_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vluxseg3ei8_v_m)))
void vluxseg3ei8_v_f32mf2_m(vfloat32mf2_t *, vfloat32mf2_t *, vfloat32mf2_t *, vbool64_t, vfloat32mf2_t, vfloat32mf2_t, vfloat32mf2_t, const float *, vuint8mf8_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vluxseg4ei8_v)))
void vluxseg4ei8_v_f32m1(vfloat32m1_t *, vfloat32m1_t *, vfloat32m1_t *, vfloat32m1_t *, const float *, vuint8mf4_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vluxseg4ei8_v_m)))
void vluxseg4ei8_v_f32m1_m(vfloat32m1_t *, vfloat32m1_t *, vfloat32m1_t *, vfloat32m1_t *, vbool32_t, vfloat32m1_t, vfloat32m1_t, vfloat32m1_t, vfloat32m1_t, const float *, vuint8mf4_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vluxseg4ei8_v)))
void vluxseg4ei8_v_f32m2(vfloat32m2_t *, vfloat32m2_t *, vfloat32m2_t *, vfloat32m2_t *, const float *, vuint8mf2_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vluxseg4ei8_v_m)))
void vluxseg4ei8_v_f32m2_m(vfloat32m2_t *, vfloat32m2_t *, vfloat32m2_t *, vfloat32m2_t *, vbool16_t, vfloat32m2_t, vfloat32m2_t, vfloat32m2_t, vfloat32m2_t, const float *, vuint8mf2_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vluxseg4ei8_v)))
void vluxseg4ei8_v_f32mf2(vfloat32mf2_t *, vfloat32mf2_t *, vfloat32mf2_t *, vfloat32mf2_t *, const float *, vuint8mf8_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vluxseg4ei8_v_m)))
void vluxseg4ei8_v_f32mf2_m(vfloat32mf2_t *, vfloat32mf2_t *, vfloat32mf2_t *, vfloat32mf2_t *, vbool64_t, vfloat32mf2_t, vfloat32mf2_t, vfloat32mf2_t, vfloat32mf2_t, const float *, vuint8mf8_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vluxseg5ei8_v)))
void vluxseg5ei8_v_f32m1(vfloat32m1_t *, vfloat32m1_t *, vfloat32m1_t *, vfloat32m1_t *, vfloat32m1_t *, const float *, vuint8mf4_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vluxseg5ei8_v_m)))
void vluxseg5ei8_v_f32m1_m(vfloat32m1_t *, vfloat32m1_t *, vfloat32m1_t *, vfloat32m1_t *, vfloat32m1_t *, vbool32_t, vfloat32m1_t, vfloat32m1_t, vfloat32m1_t, vfloat32m1_t, vfloat32m1_t, const float *, vuint8mf4_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vluxseg5ei8_v)))
void vluxseg5ei8_v_f32mf2(vfloat32mf2_t *, vfloat32mf2_t *, vfloat32mf2_t *, vfloat32mf2_t *, vfloat32mf2_t *, const float *, vuint8mf8_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vluxseg5ei8_v_m)))
void vluxseg5ei8_v_f32mf2_m(vfloat32mf2_t *, vfloat32mf2_t *, vfloat32mf2_t *, vfloat32mf2_t *, vfloat32mf2_t *, vbool64_t, vfloat32mf2_t, vfloat32mf2_t, vfloat32mf2_t, vfloat32mf2_t, vfloat32mf2_t, const float *, vuint8mf8_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vluxseg6ei8_v)))
void vluxseg6ei8_v_f32m1(vfloat32m1_t *, vfloat32m1_t *, vfloat32m1_t *, vfloat32m1_t *, vfloat32m1_t *, vfloat32m1_t *, const float *, vuint8mf4_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vluxseg6ei8_v_m)))
void vluxseg6ei8_v_f32m1_m(vfloat32m1_t *, vfloat32m1_t *, vfloat32m1_t *, vfloat32m1_t *, vfloat32m1_t *, vfloat32m1_t *, vbool32_t, vfloat32m1_t, vfloat32m1_t, vfloat32m1_t, vfloat32m1_t, vfloat32m1_t, vfloat32m1_t, const float *, vuint8mf4_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vluxseg6ei8_v)))
void vluxseg6ei8_v_f32mf2(vfloat32mf2_t *, vfloat32mf2_t *, vfloat32mf2_t *, vfloat32mf2_t *, vfloat32mf2_t *, vfloat32mf2_t *, const float *, vuint8mf8_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vluxseg6ei8_v_m)))
void vluxseg6ei8_v_f32mf2_m(vfloat32mf2_t *, vfloat32mf2_t *, vfloat32mf2_t *, vfloat32mf2_t *, vfloat32mf2_t *, vfloat32mf2_t *, vbool64_t, vfloat32mf2_t, vfloat32mf2_t, vfloat32mf2_t, vfloat32mf2_t, vfloat32mf2_t, vfloat32mf2_t, const float *, vuint8mf8_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vluxseg7ei8_v)))
void vluxseg7ei8_v_f32m1(vfloat32m1_t *, vfloat32m1_t *, vfloat32m1_t *, vfloat32m1_t *, vfloat32m1_t *, vfloat32m1_t *, vfloat32m1_t *, const float *, vuint8mf4_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vluxseg7ei8_v_m)))
void vluxseg7ei8_v_f32m1_m(vfloat32m1_t *, vfloat32m1_t *, vfloat32m1_t *, vfloat32m1_t *, vfloat32m1_t *, vfloat32m1_t *, vfloat32m1_t *, vbool32_t, vfloat32m1_t, vfloat32m1_t, vfloat32m1_t, vfloat32m1_t, vfloat32m1_t, vfloat32m1_t, vfloat32m1_t, const float *, vuint8mf4_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vluxseg7ei8_v)))
void vluxseg7ei8_v_f32mf2(vfloat32mf2_t *, vfloat32mf2_t *, vfloat32mf2_t *, vfloat32mf2_t *, vfloat32mf2_t *, vfloat32mf2_t *, vfloat32mf2_t *, const float *, vuint8mf8_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vluxseg7ei8_v_m)))
void vluxseg7ei8_v_f32mf2_m(vfloat32mf2_t *, vfloat32mf2_t *, vfloat32mf2_t *, vfloat32mf2_t *, vfloat32mf2_t *, vfloat32mf2_t *, vfloat32mf2_t *, vbool64_t, vfloat32mf2_t, vfloat32mf2_t, vfloat32mf2_t, vfloat32mf2_t, vfloat32mf2_t, vfloat32mf2_t, vfloat32mf2_t, const float *, vuint8mf8_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vluxseg8ei8_v)))
void vluxseg8ei8_v_f32m1(vfloat32m1_t *, vfloat32m1_t *, vfloat32m1_t *, vfloat32m1_t *, vfloat32m1_t *, vfloat32m1_t *, vfloat32m1_t *, vfloat32m1_t *, const float *, vuint8mf4_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vluxseg8ei8_v_m)))
void vluxseg8ei8_v_f32m1_m(vfloat32m1_t *, vfloat32m1_t *, vfloat32m1_t *, vfloat32m1_t *, vfloat32m1_t *, vfloat32m1_t *, vfloat32m1_t *, vfloat32m1_t *, vbool32_t, vfloat32m1_t, vfloat32m1_t, vfloat32m1_t, vfloat32m1_t, vfloat32m1_t, vfloat32m1_t, vfloat32m1_t, vfloat32m1_t, const float *, vuint8mf4_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vluxseg8ei8_v)))
void vluxseg8ei8_v_f32mf2(vfloat32mf2_t *, vfloat32mf2_t *, vfloat32mf2_t *, vfloat32mf2_t *, vfloat32mf2_t *, vfloat32mf2_t *, vfloat32mf2_t *, vfloat32mf2_t *, const float *, vuint8mf8_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vluxseg8ei8_v_m)))
void vluxseg8ei8_v_f32mf2_m(vfloat32mf2_t *, vfloat32mf2_t *, vfloat32mf2_t *, vfloat32mf2_t *, vfloat32mf2_t *, vfloat32mf2_t *, vfloat32mf2_t *, vfloat32mf2_t *, vbool64_t, vfloat32mf2_t, vfloat32mf2_t, vfloat32mf2_t, vfloat32mf2_t, vfloat32mf2_t, vfloat32mf2_t, vfloat32mf2_t, vfloat32mf2_t, const float *, vuint8mf8_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vluxseg2ei16_v)))
void vluxseg2ei16_v_f32m1(vfloat32m1_t *, vfloat32m1_t *, const float *, vuint16mf2_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vluxseg2ei16_v_m)))
void vluxseg2ei16_v_f32m1_m(vfloat32m1_t *, vfloat32m1_t *, vbool32_t, vfloat32m1_t, vfloat32m1_t, const float *, vuint16mf2_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vluxseg2ei16_v)))
void vluxseg2ei16_v_f32m2(vfloat32m2_t *, vfloat32m2_t *, const float *, vuint16m1_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vluxseg2ei16_v_m)))
void vluxseg2ei16_v_f32m2_m(vfloat32m2_t *, vfloat32m2_t *, vbool16_t, vfloat32m2_t, vfloat32m2_t, const float *, vuint16m1_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vluxseg2ei16_v)))
void vluxseg2ei16_v_f32m4(vfloat32m4_t *, vfloat32m4_t *, const float *, vuint16m2_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vluxseg2ei16_v_m)))
void vluxseg2ei16_v_f32m4_m(vfloat32m4_t *, vfloat32m4_t *, vbool8_t, vfloat32m4_t, vfloat32m4_t, const float *, vuint16m2_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vluxseg2ei16_v)))
void vluxseg2ei16_v_f32mf2(vfloat32mf2_t *, vfloat32mf2_t *, const float *, vuint16mf4_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vluxseg2ei16_v_m)))
void vluxseg2ei16_v_f32mf2_m(vfloat32mf2_t *, vfloat32mf2_t *, vbool64_t, vfloat32mf2_t, vfloat32mf2_t, const float *, vuint16mf4_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vluxseg3ei16_v)))
void vluxseg3ei16_v_f32m1(vfloat32m1_t *, vfloat32m1_t *, vfloat32m1_t *, const float *, vuint16mf2_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vluxseg3ei16_v_m)))
void vluxseg3ei16_v_f32m1_m(vfloat32m1_t *, vfloat32m1_t *, vfloat32m1_t *, vbool32_t, vfloat32m1_t, vfloat32m1_t, vfloat32m1_t, const float *, vuint16mf2_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vluxseg3ei16_v)))
void vluxseg3ei16_v_f32m2(vfloat32m2_t *, vfloat32m2_t *, vfloat32m2_t *, const float *, vuint16m1_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vluxseg3ei16_v_m)))
void vluxseg3ei16_v_f32m2_m(vfloat32m2_t *, vfloat32m2_t *, vfloat32m2_t *, vbool16_t, vfloat32m2_t, vfloat32m2_t, vfloat32m2_t, const float *, vuint16m1_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vluxseg3ei16_v)))
void vluxseg3ei16_v_f32mf2(vfloat32mf2_t *, vfloat32mf2_t *, vfloat32mf2_t *, const float *, vuint16mf4_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vluxseg3ei16_v_m)))
void vluxseg3ei16_v_f32mf2_m(vfloat32mf2_t *, vfloat32mf2_t *, vfloat32mf2_t *, vbool64_t, vfloat32mf2_t, vfloat32mf2_t, vfloat32mf2_t, const float *, vuint16mf4_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vluxseg4ei16_v)))
void vluxseg4ei16_v_f32m1(vfloat32m1_t *, vfloat32m1_t *, vfloat32m1_t *, vfloat32m1_t *, const float *, vuint16mf2_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vluxseg4ei16_v_m)))
void vluxseg4ei16_v_f32m1_m(vfloat32m1_t *, vfloat32m1_t *, vfloat32m1_t *, vfloat32m1_t *, vbool32_t, vfloat32m1_t, vfloat32m1_t, vfloat32m1_t, vfloat32m1_t, const float *, vuint16mf2_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vluxseg4ei16_v)))
void vluxseg4ei16_v_f32m2(vfloat32m2_t *, vfloat32m2_t *, vfloat32m2_t *, vfloat32m2_t *, const float *, vuint16m1_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vluxseg4ei16_v_m)))
void vluxseg4ei16_v_f32m2_m(vfloat32m2_t *, vfloat32m2_t *, vfloat32m2_t *, vfloat32m2_t *, vbool16_t, vfloat32m2_t, vfloat32m2_t, vfloat32m2_t, vfloat32m2_t, const float *, vuint16m1_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vluxseg4ei16_v)))
void vluxseg4ei16_v_f32mf2(vfloat32mf2_t *, vfloat32mf2_t *, vfloat32mf2_t *, vfloat32mf2_t *, const float *, vuint16mf4_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vluxseg4ei16_v_m)))
void vluxseg4ei16_v_f32mf2_m(vfloat32mf2_t *, vfloat32mf2_t *, vfloat32mf2_t *, vfloat32mf2_t *, vbool64_t, vfloat32mf2_t, vfloat32mf2_t, vfloat32mf2_t, vfloat32mf2_t, const float *, vuint16mf4_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vluxseg5ei16_v)))
void vluxseg5ei16_v_f32m1(vfloat32m1_t *, vfloat32m1_t *, vfloat32m1_t *, vfloat32m1_t *, vfloat32m1_t *, const float *, vuint16mf2_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vluxseg5ei16_v_m)))
void vluxseg5ei16_v_f32m1_m(vfloat32m1_t *, vfloat32m1_t *, vfloat32m1_t *, vfloat32m1_t *, vfloat32m1_t *, vbool32_t, vfloat32m1_t, vfloat32m1_t, vfloat32m1_t, vfloat32m1_t, vfloat32m1_t, const float *, vuint16mf2_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vluxseg5ei16_v)))
void vluxseg5ei16_v_f32mf2(vfloat32mf2_t *, vfloat32mf2_t *, vfloat32mf2_t *, vfloat32mf2_t *, vfloat32mf2_t *, const float *, vuint16mf4_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vluxseg5ei16_v_m)))
void vluxseg5ei16_v_f32mf2_m(vfloat32mf2_t *, vfloat32mf2_t *, vfloat32mf2_t *, vfloat32mf2_t *, vfloat32mf2_t *, vbool64_t, vfloat32mf2_t, vfloat32mf2_t, vfloat32mf2_t, vfloat32mf2_t, vfloat32mf2_t, const float *, vuint16mf4_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vluxseg6ei16_v)))
void vluxseg6ei16_v_f32m1(vfloat32m1_t *, vfloat32m1_t *, vfloat32m1_t *, vfloat32m1_t *, vfloat32m1_t *, vfloat32m1_t *, const float *, vuint16mf2_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vluxseg6ei16_v_m)))
void vluxseg6ei16_v_f32m1_m(vfloat32m1_t *, vfloat32m1_t *, vfloat32m1_t *, vfloat32m1_t *, vfloat32m1_t *, vfloat32m1_t *, vbool32_t, vfloat32m1_t, vfloat32m1_t, vfloat32m1_t, vfloat32m1_t, vfloat32m1_t, vfloat32m1_t, const float *, vuint16mf2_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vluxseg6ei16_v)))
void vluxseg6ei16_v_f32mf2(vfloat32mf2_t *, vfloat32mf2_t *, vfloat32mf2_t *, vfloat32mf2_t *, vfloat32mf2_t *, vfloat32mf2_t *, const float *, vuint16mf4_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vluxseg6ei16_v_m)))
void vluxseg6ei16_v_f32mf2_m(vfloat32mf2_t *, vfloat32mf2_t *, vfloat32mf2_t *, vfloat32mf2_t *, vfloat32mf2_t *, vfloat32mf2_t *, vbool64_t, vfloat32mf2_t, vfloat32mf2_t, vfloat32mf2_t, vfloat32mf2_t, vfloat32mf2_t, vfloat32mf2_t, const float *, vuint16mf4_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vluxseg7ei16_v)))
void vluxseg7ei16_v_f32m1(vfloat32m1_t *, vfloat32m1_t *, vfloat32m1_t *, vfloat32m1_t *, vfloat32m1_t *, vfloat32m1_t *, vfloat32m1_t *, const float *, vuint16mf2_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vluxseg7ei16_v_m)))
void vluxseg7ei16_v_f32m1_m(vfloat32m1_t *, vfloat32m1_t *, vfloat32m1_t *, vfloat32m1_t *, vfloat32m1_t *, vfloat32m1_t *, vfloat32m1_t *, vbool32_t, vfloat32m1_t, vfloat32m1_t, vfloat32m1_t, vfloat32m1_t, vfloat32m1_t, vfloat32m1_t, vfloat32m1_t, const float *, vuint16mf2_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vluxseg7ei16_v)))
void vluxseg7ei16_v_f32mf2(vfloat32mf2_t *, vfloat32mf2_t *, vfloat32mf2_t *, vfloat32mf2_t *, vfloat32mf2_t *, vfloat32mf2_t *, vfloat32mf2_t *, const float *, vuint16mf4_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vluxseg7ei16_v_m)))
void vluxseg7ei16_v_f32mf2_m(vfloat32mf2_t *, vfloat32mf2_t *, vfloat32mf2_t *, vfloat32mf2_t *, vfloat32mf2_t *, vfloat32mf2_t *, vfloat32mf2_t *, vbool64_t, vfloat32mf2_t, vfloat32mf2_t, vfloat32mf2_t, vfloat32mf2_t, vfloat32mf2_t, vfloat32mf2_t, vfloat32mf2_t, const float *, vuint16mf4_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vluxseg8ei16_v)))
void vluxseg8ei16_v_f32m1(vfloat32m1_t *, vfloat32m1_t *, vfloat32m1_t *, vfloat32m1_t *, vfloat32m1_t *, vfloat32m1_t *, vfloat32m1_t *, vfloat32m1_t *, const float *, vuint16mf2_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vluxseg8ei16_v_m)))
void vluxseg8ei16_v_f32m1_m(vfloat32m1_t *, vfloat32m1_t *, vfloat32m1_t *, vfloat32m1_t *, vfloat32m1_t *, vfloat32m1_t *, vfloat32m1_t *, vfloat32m1_t *, vbool32_t, vfloat32m1_t, vfloat32m1_t, vfloat32m1_t, vfloat32m1_t, vfloat32m1_t, vfloat32m1_t, vfloat32m1_t, vfloat32m1_t, const float *, vuint16mf2_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vluxseg8ei16_v)))
void vluxseg8ei16_v_f32mf2(vfloat32mf2_t *, vfloat32mf2_t *, vfloat32mf2_t *, vfloat32mf2_t *, vfloat32mf2_t *, vfloat32mf2_t *, vfloat32mf2_t *, vfloat32mf2_t *, const float *, vuint16mf4_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vluxseg8ei16_v_m)))
void vluxseg8ei16_v_f32mf2_m(vfloat32mf2_t *, vfloat32mf2_t *, vfloat32mf2_t *, vfloat32mf2_t *, vfloat32mf2_t *, vfloat32mf2_t *, vfloat32mf2_t *, vfloat32mf2_t *, vbool64_t, vfloat32mf2_t, vfloat32mf2_t, vfloat32mf2_t, vfloat32mf2_t, vfloat32mf2_t, vfloat32mf2_t, vfloat32mf2_t, vfloat32mf2_t, const float *, vuint16mf4_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vluxseg2ei32_v)))
void vluxseg2ei32_v_f32m1(vfloat32m1_t *, vfloat32m1_t *, const float *, vuint32m1_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vluxseg2ei32_v_m)))
void vluxseg2ei32_v_f32m1_m(vfloat32m1_t *, vfloat32m1_t *, vbool32_t, vfloat32m1_t, vfloat32m1_t, const float *, vuint32m1_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vluxseg2ei32_v)))
void vluxseg2ei32_v_f32m2(vfloat32m2_t *, vfloat32m2_t *, const float *, vuint32m2_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vluxseg2ei32_v_m)))
void vluxseg2ei32_v_f32m2_m(vfloat32m2_t *, vfloat32m2_t *, vbool16_t, vfloat32m2_t, vfloat32m2_t, const float *, vuint32m2_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vluxseg2ei32_v)))
void vluxseg2ei32_v_f32m4(vfloat32m4_t *, vfloat32m4_t *, const float *, vuint32m4_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vluxseg2ei32_v_m)))
void vluxseg2ei32_v_f32m4_m(vfloat32m4_t *, vfloat32m4_t *, vbool8_t, vfloat32m4_t, vfloat32m4_t, const float *, vuint32m4_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vluxseg2ei32_v)))
void vluxseg2ei32_v_f32mf2(vfloat32mf2_t *, vfloat32mf2_t *, const float *, vuint32mf2_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vluxseg2ei32_v_m)))
void vluxseg2ei32_v_f32mf2_m(vfloat32mf2_t *, vfloat32mf2_t *, vbool64_t, vfloat32mf2_t, vfloat32mf2_t, const float *, vuint32mf2_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vluxseg3ei32_v)))
void vluxseg3ei32_v_f32m1(vfloat32m1_t *, vfloat32m1_t *, vfloat32m1_t *, const float *, vuint32m1_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vluxseg3ei32_v_m)))
void vluxseg3ei32_v_f32m1_m(vfloat32m1_t *, vfloat32m1_t *, vfloat32m1_t *, vbool32_t, vfloat32m1_t, vfloat32m1_t, vfloat32m1_t, const float *, vuint32m1_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vluxseg3ei32_v)))
void vluxseg3ei32_v_f32m2(vfloat32m2_t *, vfloat32m2_t *, vfloat32m2_t *, const float *, vuint32m2_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vluxseg3ei32_v_m)))
void vluxseg3ei32_v_f32m2_m(vfloat32m2_t *, vfloat32m2_t *, vfloat32m2_t *, vbool16_t, vfloat32m2_t, vfloat32m2_t, vfloat32m2_t, const float *, vuint32m2_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vluxseg3ei32_v)))
void vluxseg3ei32_v_f32mf2(vfloat32mf2_t *, vfloat32mf2_t *, vfloat32mf2_t *, const float *, vuint32mf2_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vluxseg3ei32_v_m)))
void vluxseg3ei32_v_f32mf2_m(vfloat32mf2_t *, vfloat32mf2_t *, vfloat32mf2_t *, vbool64_t, vfloat32mf2_t, vfloat32mf2_t, vfloat32mf2_t, const float *, vuint32mf2_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vluxseg4ei32_v)))
void vluxseg4ei32_v_f32m1(vfloat32m1_t *, vfloat32m1_t *, vfloat32m1_t *, vfloat32m1_t *, const float *, vuint32m1_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vluxseg4ei32_v_m)))
void vluxseg4ei32_v_f32m1_m(vfloat32m1_t *, vfloat32m1_t *, vfloat32m1_t *, vfloat32m1_t *, vbool32_t, vfloat32m1_t, vfloat32m1_t, vfloat32m1_t, vfloat32m1_t, const float *, vuint32m1_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vluxseg4ei32_v)))
void vluxseg4ei32_v_f32m2(vfloat32m2_t *, vfloat32m2_t *, vfloat32m2_t *, vfloat32m2_t *, const float *, vuint32m2_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vluxseg4ei32_v_m)))
void vluxseg4ei32_v_f32m2_m(vfloat32m2_t *, vfloat32m2_t *, vfloat32m2_t *, vfloat32m2_t *, vbool16_t, vfloat32m2_t, vfloat32m2_t, vfloat32m2_t, vfloat32m2_t, const float *, vuint32m2_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vluxseg4ei32_v)))
void vluxseg4ei32_v_f32mf2(vfloat32mf2_t *, vfloat32mf2_t *, vfloat32mf2_t *, vfloat32mf2_t *, const float *, vuint32mf2_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vluxseg4ei32_v_m)))
void vluxseg4ei32_v_f32mf2_m(vfloat32mf2_t *, vfloat32mf2_t *, vfloat32mf2_t *, vfloat32mf2_t *, vbool64_t, vfloat32mf2_t, vfloat32mf2_t, vfloat32mf2_t, vfloat32mf2_t, const float *, vuint32mf2_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vluxseg5ei32_v)))
void vluxseg5ei32_v_f32m1(vfloat32m1_t *, vfloat32m1_t *, vfloat32m1_t *, vfloat32m1_t *, vfloat32m1_t *, const float *, vuint32m1_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vluxseg5ei32_v_m)))
void vluxseg5ei32_v_f32m1_m(vfloat32m1_t *, vfloat32m1_t *, vfloat32m1_t *, vfloat32m1_t *, vfloat32m1_t *, vbool32_t, vfloat32m1_t, vfloat32m1_t, vfloat32m1_t, vfloat32m1_t, vfloat32m1_t, const float *, vuint32m1_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vluxseg5ei32_v)))
void vluxseg5ei32_v_f32mf2(vfloat32mf2_t *, vfloat32mf2_t *, vfloat32mf2_t *, vfloat32mf2_t *, vfloat32mf2_t *, const float *, vuint32mf2_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vluxseg5ei32_v_m)))
void vluxseg5ei32_v_f32mf2_m(vfloat32mf2_t *, vfloat32mf2_t *, vfloat32mf2_t *, vfloat32mf2_t *, vfloat32mf2_t *, vbool64_t, vfloat32mf2_t, vfloat32mf2_t, vfloat32mf2_t, vfloat32mf2_t, vfloat32mf2_t, const float *, vuint32mf2_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vluxseg6ei32_v)))
void vluxseg6ei32_v_f32m1(vfloat32m1_t *, vfloat32m1_t *, vfloat32m1_t *, vfloat32m1_t *, vfloat32m1_t *, vfloat32m1_t *, const float *, vuint32m1_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vluxseg6ei32_v_m)))
void vluxseg6ei32_v_f32m1_m(vfloat32m1_t *, vfloat32m1_t *, vfloat32m1_t *, vfloat32m1_t *, vfloat32m1_t *, vfloat32m1_t *, vbool32_t, vfloat32m1_t, vfloat32m1_t, vfloat32m1_t, vfloat32m1_t, vfloat32m1_t, vfloat32m1_t, const float *, vuint32m1_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vluxseg6ei32_v)))
void vluxseg6ei32_v_f32mf2(vfloat32mf2_t *, vfloat32mf2_t *, vfloat32mf2_t *, vfloat32mf2_t *, vfloat32mf2_t *, vfloat32mf2_t *, const float *, vuint32mf2_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vluxseg6ei32_v_m)))
void vluxseg6ei32_v_f32mf2_m(vfloat32mf2_t *, vfloat32mf2_t *, vfloat32mf2_t *, vfloat32mf2_t *, vfloat32mf2_t *, vfloat32mf2_t *, vbool64_t, vfloat32mf2_t, vfloat32mf2_t, vfloat32mf2_t, vfloat32mf2_t, vfloat32mf2_t, vfloat32mf2_t, const float *, vuint32mf2_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vluxseg7ei32_v)))
void vluxseg7ei32_v_f32m1(vfloat32m1_t *, vfloat32m1_t *, vfloat32m1_t *, vfloat32m1_t *, vfloat32m1_t *, vfloat32m1_t *, vfloat32m1_t *, const float *, vuint32m1_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vluxseg7ei32_v_m)))
void vluxseg7ei32_v_f32m1_m(vfloat32m1_t *, vfloat32m1_t *, vfloat32m1_t *, vfloat32m1_t *, vfloat32m1_t *, vfloat32m1_t *, vfloat32m1_t *, vbool32_t, vfloat32m1_t, vfloat32m1_t, vfloat32m1_t, vfloat32m1_t, vfloat32m1_t, vfloat32m1_t, vfloat32m1_t, const float *, vuint32m1_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vluxseg7ei32_v)))
void vluxseg7ei32_v_f32mf2(vfloat32mf2_t *, vfloat32mf2_t *, vfloat32mf2_t *, vfloat32mf2_t *, vfloat32mf2_t *, vfloat32mf2_t *, vfloat32mf2_t *, const float *, vuint32mf2_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vluxseg7ei32_v_m)))
void vluxseg7ei32_v_f32mf2_m(vfloat32mf2_t *, vfloat32mf2_t *, vfloat32mf2_t *, vfloat32mf2_t *, vfloat32mf2_t *, vfloat32mf2_t *, vfloat32mf2_t *, vbool64_t, vfloat32mf2_t, vfloat32mf2_t, vfloat32mf2_t, vfloat32mf2_t, vfloat32mf2_t, vfloat32mf2_t, vfloat32mf2_t, const float *, vuint32mf2_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vluxseg8ei32_v)))
void vluxseg8ei32_v_f32m1(vfloat32m1_t *, vfloat32m1_t *, vfloat32m1_t *, vfloat32m1_t *, vfloat32m1_t *, vfloat32m1_t *, vfloat32m1_t *, vfloat32m1_t *, const float *, vuint32m1_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vluxseg8ei32_v_m)))
void vluxseg8ei32_v_f32m1_m(vfloat32m1_t *, vfloat32m1_t *, vfloat32m1_t *, vfloat32m1_t *, vfloat32m1_t *, vfloat32m1_t *, vfloat32m1_t *, vfloat32m1_t *, vbool32_t, vfloat32m1_t, vfloat32m1_t, vfloat32m1_t, vfloat32m1_t, vfloat32m1_t, vfloat32m1_t, vfloat32m1_t, vfloat32m1_t, const float *, vuint32m1_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vluxseg8ei32_v)))
void vluxseg8ei32_v_f32mf2(vfloat32mf2_t *, vfloat32mf2_t *, vfloat32mf2_t *, vfloat32mf2_t *, vfloat32mf2_t *, vfloat32mf2_t *, vfloat32mf2_t *, vfloat32mf2_t *, const float *, vuint32mf2_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vluxseg8ei32_v_m)))
void vluxseg8ei32_v_f32mf2_m(vfloat32mf2_t *, vfloat32mf2_t *, vfloat32mf2_t *, vfloat32mf2_t *, vfloat32mf2_t *, vfloat32mf2_t *, vfloat32mf2_t *, vfloat32mf2_t *, vbool64_t, vfloat32mf2_t, vfloat32mf2_t, vfloat32mf2_t, vfloat32mf2_t, vfloat32mf2_t, vfloat32mf2_t, vfloat32mf2_t, vfloat32mf2_t, const float *, vuint32mf2_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vle32_v)))
vfloat32m1_t vle32_v_f32m1(const float *, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vle32_v_m)))
vfloat32m1_t vle32_v_f32m1_m(vbool32_t, vfloat32m1_t, const float *, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vle32_v)))
vfloat32m2_t vle32_v_f32m2(const float *, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vle32_v_m)))
vfloat32m2_t vle32_v_f32m2_m(vbool16_t, vfloat32m2_t, const float *, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vle32_v)))
vfloat32m4_t vle32_v_f32m4(const float *, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vle32_v_m)))
vfloat32m4_t vle32_v_f32m4_m(vbool8_t, vfloat32m4_t, const float *, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vle32_v)))
vfloat32m8_t vle32_v_f32m8(const float *, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vle32_v_m)))
vfloat32m8_t vle32_v_f32m8_m(vbool4_t, vfloat32m8_t, const float *, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vle32_v)))
vfloat32mf2_t vle32_v_f32mf2(const float *, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vle32_v_m)))
vfloat32mf2_t vle32_v_f32mf2_m(vbool64_t, vfloat32mf2_t, const float *, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vse32_v)))
void vse32_v_f32m1(float *, vfloat32m1_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vse32_v_m)))
void vse32_v_f32m1_m(vbool32_t, float *, vfloat32m1_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vse32_v)))
void vse32_v_f32m2(float *, vfloat32m2_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vse32_v_m)))
void vse32_v_f32m2_m(vbool16_t, float *, vfloat32m2_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vse32_v)))
void vse32_v_f32m4(float *, vfloat32m4_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vse32_v_m)))
void vse32_v_f32m4_m(vbool8_t, float *, vfloat32m4_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vse32_v)))
void vse32_v_f32m8(float *, vfloat32m8_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vse32_v_m)))
void vse32_v_f32m8_m(vbool4_t, float *, vfloat32m8_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vse32_v)))
void vse32_v_f32mf2(float *, vfloat32mf2_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vse32_v_m)))
void vse32_v_f32mf2_m(vbool64_t, float *, vfloat32mf2_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vfclass_v)))
vuint32m1_t vfclass_v_u32m1(vfloat32m1_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vfclass_v_m)))
vuint32m1_t vfclass_v_u32m1_m(vbool32_t, vuint32m1_t, vfloat32m1_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vfclass_v)))
vuint32m2_t vfclass_v_u32m2(vfloat32m2_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vfclass_v_m)))
vuint32m2_t vfclass_v_u32m2_m(vbool16_t, vuint32m2_t, vfloat32m2_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vfclass_v)))
vuint32m4_t vfclass_v_u32m4(vfloat32m4_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vfclass_v_m)))
vuint32m4_t vfclass_v_u32m4_m(vbool8_t, vuint32m4_t, vfloat32m4_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vfclass_v)))
vuint32m8_t vfclass_v_u32m8(vfloat32m8_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vfclass_v_m)))
vuint32m8_t vfclass_v_u32m8_m(vbool4_t, vuint32m8_t, vfloat32m8_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vfclass_v)))
vuint32mf2_t vfclass_v_u32mf2(vfloat32mf2_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vfclass_v_m)))
vuint32mf2_t vfclass_v_u32mf2_m(vbool64_t, vuint32mf2_t, vfloat32mf2_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vfcvt_f_x_v)))
vfloat32m1_t vfcvt_f_x_v_f32m1(vint32m1_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vfcvt_f_x_v_m)))
vfloat32m1_t vfcvt_f_x_v_f32m1_m(vbool32_t, vfloat32m1_t, vint32m1_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vfcvt_f_x_v)))
vfloat32m2_t vfcvt_f_x_v_f32m2(vint32m2_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vfcvt_f_x_v_m)))
vfloat32m2_t vfcvt_f_x_v_f32m2_m(vbool16_t, vfloat32m2_t, vint32m2_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vfcvt_f_x_v)))
vfloat32m4_t vfcvt_f_x_v_f32m4(vint32m4_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vfcvt_f_x_v_m)))
vfloat32m4_t vfcvt_f_x_v_f32m4_m(vbool8_t, vfloat32m4_t, vint32m4_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vfcvt_f_x_v)))
vfloat32m8_t vfcvt_f_x_v_f32m8(vint32m8_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vfcvt_f_x_v_m)))
vfloat32m8_t vfcvt_f_x_v_f32m8_m(vbool4_t, vfloat32m8_t, vint32m8_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vfcvt_f_x_v)))
vfloat32mf2_t vfcvt_f_x_v_f32mf2(vint32mf2_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vfcvt_f_x_v_m)))
vfloat32mf2_t vfcvt_f_x_v_f32mf2_m(vbool64_t, vfloat32mf2_t, vint32mf2_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vfcvt_f_xu_v)))
vfloat32m1_t vfcvt_f_xu_v_f32m1(vuint32m1_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vfcvt_f_xu_v_m)))
vfloat32m1_t vfcvt_f_xu_v_f32m1_m(vbool32_t, vfloat32m1_t, vuint32m1_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vfcvt_f_xu_v)))
vfloat32m2_t vfcvt_f_xu_v_f32m2(vuint32m2_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vfcvt_f_xu_v_m)))
vfloat32m2_t vfcvt_f_xu_v_f32m2_m(vbool16_t, vfloat32m2_t, vuint32m2_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vfcvt_f_xu_v)))
vfloat32m4_t vfcvt_f_xu_v_f32m4(vuint32m4_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vfcvt_f_xu_v_m)))
vfloat32m4_t vfcvt_f_xu_v_f32m4_m(vbool8_t, vfloat32m4_t, vuint32m4_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vfcvt_f_xu_v)))
vfloat32m8_t vfcvt_f_xu_v_f32m8(vuint32m8_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vfcvt_f_xu_v_m)))
vfloat32m8_t vfcvt_f_xu_v_f32m8_m(vbool4_t, vfloat32m8_t, vuint32m8_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vfcvt_f_xu_v)))
vfloat32mf2_t vfcvt_f_xu_v_f32mf2(vuint32mf2_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vfcvt_f_xu_v_m)))
vfloat32mf2_t vfcvt_f_xu_v_f32mf2_m(vbool64_t, vfloat32mf2_t, vuint32mf2_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vfcvt_rtz_x_f_v)))
vint32m1_t vfcvt_rtz_x_f_v_i32m1(vfloat32m1_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vfcvt_rtz_x_f_v_m)))
vint32m1_t vfcvt_rtz_x_f_v_i32m1_m(vbool32_t, vint32m1_t, vfloat32m1_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vfcvt_rtz_x_f_v)))
vint32m2_t vfcvt_rtz_x_f_v_i32m2(vfloat32m2_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vfcvt_rtz_x_f_v_m)))
vint32m2_t vfcvt_rtz_x_f_v_i32m2_m(vbool16_t, vint32m2_t, vfloat32m2_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vfcvt_rtz_x_f_v)))
vint32m4_t vfcvt_rtz_x_f_v_i32m4(vfloat32m4_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vfcvt_rtz_x_f_v_m)))
vint32m4_t vfcvt_rtz_x_f_v_i32m4_m(vbool8_t, vint32m4_t, vfloat32m4_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vfcvt_rtz_x_f_v)))
vint32m8_t vfcvt_rtz_x_f_v_i32m8(vfloat32m8_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vfcvt_rtz_x_f_v_m)))
vint32m8_t vfcvt_rtz_x_f_v_i32m8_m(vbool4_t, vint32m8_t, vfloat32m8_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vfcvt_rtz_x_f_v)))
vint32mf2_t vfcvt_rtz_x_f_v_i32mf2(vfloat32mf2_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vfcvt_rtz_x_f_v_m)))
vint32mf2_t vfcvt_rtz_x_f_v_i32mf2_m(vbool64_t, vint32mf2_t, vfloat32mf2_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vfcvt_rtz_xu_f_v)))
vuint32m1_t vfcvt_rtz_xu_f_v_u32m1(vfloat32m1_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vfcvt_rtz_xu_f_v_m)))
vuint32m1_t vfcvt_rtz_xu_f_v_u32m1_m(vbool32_t, vuint32m1_t, vfloat32m1_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vfcvt_rtz_xu_f_v)))
vuint32m2_t vfcvt_rtz_xu_f_v_u32m2(vfloat32m2_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vfcvt_rtz_xu_f_v_m)))
vuint32m2_t vfcvt_rtz_xu_f_v_u32m2_m(vbool16_t, vuint32m2_t, vfloat32m2_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vfcvt_rtz_xu_f_v)))
vuint32m4_t vfcvt_rtz_xu_f_v_u32m4(vfloat32m4_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vfcvt_rtz_xu_f_v_m)))
vuint32m4_t vfcvt_rtz_xu_f_v_u32m4_m(vbool8_t, vuint32m4_t, vfloat32m4_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vfcvt_rtz_xu_f_v)))
vuint32m8_t vfcvt_rtz_xu_f_v_u32m8(vfloat32m8_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vfcvt_rtz_xu_f_v_m)))
vuint32m8_t vfcvt_rtz_xu_f_v_u32m8_m(vbool4_t, vuint32m8_t, vfloat32m8_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vfcvt_rtz_xu_f_v)))
vuint32mf2_t vfcvt_rtz_xu_f_v_u32mf2(vfloat32mf2_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vfcvt_rtz_xu_f_v_m)))
vuint32mf2_t vfcvt_rtz_xu_f_v_u32mf2_m(vbool64_t, vuint32mf2_t, vfloat32mf2_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vfcvt_x_f_v)))
vint32m1_t vfcvt_x_f_v_i32m1(vfloat32m1_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vfcvt_x_f_v_m)))
vint32m1_t vfcvt_x_f_v_i32m1_m(vbool32_t, vint32m1_t, vfloat32m1_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vfcvt_x_f_v)))
vint32m2_t vfcvt_x_f_v_i32m2(vfloat32m2_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vfcvt_x_f_v_m)))
vint32m2_t vfcvt_x_f_v_i32m2_m(vbool16_t, vint32m2_t, vfloat32m2_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vfcvt_x_f_v)))
vint32m4_t vfcvt_x_f_v_i32m4(vfloat32m4_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vfcvt_x_f_v_m)))
vint32m4_t vfcvt_x_f_v_i32m4_m(vbool8_t, vint32m4_t, vfloat32m4_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vfcvt_x_f_v)))
vint32m8_t vfcvt_x_f_v_i32m8(vfloat32m8_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vfcvt_x_f_v_m)))
vint32m8_t vfcvt_x_f_v_i32m8_m(vbool4_t, vint32m8_t, vfloat32m8_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vfcvt_x_f_v)))
vint32mf2_t vfcvt_x_f_v_i32mf2(vfloat32mf2_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vfcvt_x_f_v_m)))
vint32mf2_t vfcvt_x_f_v_i32mf2_m(vbool64_t, vint32mf2_t, vfloat32mf2_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vfcvt_xu_f_v)))
vuint32m1_t vfcvt_xu_f_v_u32m1(vfloat32m1_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vfcvt_xu_f_v_m)))
vuint32m1_t vfcvt_xu_f_v_u32m1_m(vbool32_t, vuint32m1_t, vfloat32m1_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vfcvt_xu_f_v)))
vuint32m2_t vfcvt_xu_f_v_u32m2(vfloat32m2_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vfcvt_xu_f_v_m)))
vuint32m2_t vfcvt_xu_f_v_u32m2_m(vbool16_t, vuint32m2_t, vfloat32m2_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vfcvt_xu_f_v)))
vuint32m4_t vfcvt_xu_f_v_u32m4(vfloat32m4_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vfcvt_xu_f_v_m)))
vuint32m4_t vfcvt_xu_f_v_u32m4_m(vbool8_t, vuint32m4_t, vfloat32m4_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vfcvt_xu_f_v)))
vuint32m8_t vfcvt_xu_f_v_u32m8(vfloat32m8_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vfcvt_xu_f_v_m)))
vuint32m8_t vfcvt_xu_f_v_u32m8_m(vbool4_t, vuint32m8_t, vfloat32m8_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vfcvt_xu_f_v)))
vuint32mf2_t vfcvt_xu_f_v_u32mf2(vfloat32mf2_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vfcvt_xu_f_v_m)))
vuint32mf2_t vfcvt_xu_f_v_u32mf2_m(vbool64_t, vuint32mf2_t, vfloat32mf2_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vfncvt_rtz_x_f_w)))
vint16mf4_t vfncvt_rtz_x_f_w_i16mf4(vfloat32mf2_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vfncvt_rtz_x_f_w_m)))
vint16mf4_t vfncvt_rtz_x_f_w_i16mf4_m(vbool64_t, vint16mf4_t, vfloat32mf2_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vfncvt_rtz_x_f_w)))
vint16mf2_t vfncvt_rtz_x_f_w_i16mf2(vfloat32m1_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vfncvt_rtz_x_f_w_m)))
vint16mf2_t vfncvt_rtz_x_f_w_i16mf2_m(vbool32_t, vint16mf2_t, vfloat32m1_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vfncvt_rtz_x_f_w)))
vint16m1_t vfncvt_rtz_x_f_w_i16m1(vfloat32m2_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vfncvt_rtz_x_f_w_m)))
vint16m1_t vfncvt_rtz_x_f_w_i16m1_m(vbool16_t, vint16m1_t, vfloat32m2_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vfncvt_rtz_x_f_w)))
vint16m2_t vfncvt_rtz_x_f_w_i16m2(vfloat32m4_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vfncvt_rtz_x_f_w_m)))
vint16m2_t vfncvt_rtz_x_f_w_i16m2_m(vbool8_t, vint16m2_t, vfloat32m4_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vfncvt_rtz_x_f_w)))
vint16m4_t vfncvt_rtz_x_f_w_i16m4(vfloat32m8_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vfncvt_rtz_x_f_w_m)))
vint16m4_t vfncvt_rtz_x_f_w_i16m4_m(vbool4_t, vint16m4_t, vfloat32m8_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vfncvt_rtz_xu_f_w)))
vuint16mf4_t vfncvt_rtz_xu_f_w_u16mf4(vfloat32mf2_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vfncvt_rtz_xu_f_w_m)))
vuint16mf4_t vfncvt_rtz_xu_f_w_u16mf4_m(vbool64_t, vuint16mf4_t, vfloat32mf2_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vfncvt_rtz_xu_f_w)))
vuint16mf2_t vfncvt_rtz_xu_f_w_u16mf2(vfloat32m1_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vfncvt_rtz_xu_f_w_m)))
vuint16mf2_t vfncvt_rtz_xu_f_w_u16mf2_m(vbool32_t, vuint16mf2_t, vfloat32m1_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vfncvt_rtz_xu_f_w)))
vuint16m1_t vfncvt_rtz_xu_f_w_u16m1(vfloat32m2_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vfncvt_rtz_xu_f_w_m)))
vuint16m1_t vfncvt_rtz_xu_f_w_u16m1_m(vbool16_t, vuint16m1_t, vfloat32m2_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vfncvt_rtz_xu_f_w)))
vuint16m2_t vfncvt_rtz_xu_f_w_u16m2(vfloat32m4_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vfncvt_rtz_xu_f_w_m)))
vuint16m2_t vfncvt_rtz_xu_f_w_u16m2_m(vbool8_t, vuint16m2_t, vfloat32m4_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vfncvt_rtz_xu_f_w)))
vuint16m4_t vfncvt_rtz_xu_f_w_u16m4(vfloat32m8_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vfncvt_rtz_xu_f_w_m)))
vuint16m4_t vfncvt_rtz_xu_f_w_u16m4_m(vbool4_t, vuint16m4_t, vfloat32m8_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vfncvt_x_f_w)))
vint16mf4_t vfncvt_x_f_w_i16mf4(vfloat32mf2_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vfncvt_x_f_w_m)))
vint16mf4_t vfncvt_x_f_w_i16mf4_m(vbool64_t, vint16mf4_t, vfloat32mf2_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vfncvt_x_f_w)))
vint16mf2_t vfncvt_x_f_w_i16mf2(vfloat32m1_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vfncvt_x_f_w_m)))
vint16mf2_t vfncvt_x_f_w_i16mf2_m(vbool32_t, vint16mf2_t, vfloat32m1_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vfncvt_x_f_w)))
vint16m1_t vfncvt_x_f_w_i16m1(vfloat32m2_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vfncvt_x_f_w_m)))
vint16m1_t vfncvt_x_f_w_i16m1_m(vbool16_t, vint16m1_t, vfloat32m2_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vfncvt_x_f_w)))
vint16m2_t vfncvt_x_f_w_i16m2(vfloat32m4_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vfncvt_x_f_w_m)))
vint16m2_t vfncvt_x_f_w_i16m2_m(vbool8_t, vint16m2_t, vfloat32m4_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vfncvt_x_f_w)))
vint16m4_t vfncvt_x_f_w_i16m4(vfloat32m8_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vfncvt_x_f_w_m)))
vint16m4_t vfncvt_x_f_w_i16m4_m(vbool4_t, vint16m4_t, vfloat32m8_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vfncvt_xu_f_w)))
vuint16mf4_t vfncvt_xu_f_w_u16mf4(vfloat32mf2_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vfncvt_xu_f_w_m)))
vuint16mf4_t vfncvt_xu_f_w_u16mf4_m(vbool64_t, vuint16mf4_t, vfloat32mf2_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vfncvt_xu_f_w)))
vuint16mf2_t vfncvt_xu_f_w_u16mf2(vfloat32m1_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vfncvt_xu_f_w_m)))
vuint16mf2_t vfncvt_xu_f_w_u16mf2_m(vbool32_t, vuint16mf2_t, vfloat32m1_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vfncvt_xu_f_w)))
vuint16m1_t vfncvt_xu_f_w_u16m1(vfloat32m2_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vfncvt_xu_f_w_m)))
vuint16m1_t vfncvt_xu_f_w_u16m1_m(vbool16_t, vuint16m1_t, vfloat32m2_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vfncvt_xu_f_w)))
vuint16m2_t vfncvt_xu_f_w_u16m2(vfloat32m4_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vfncvt_xu_f_w_m)))
vuint16m2_t vfncvt_xu_f_w_u16m2_m(vbool8_t, vuint16m2_t, vfloat32m4_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vfncvt_xu_f_w)))
vuint16m4_t vfncvt_xu_f_w_u16m4(vfloat32m8_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vfncvt_xu_f_w_m)))
vuint16m4_t vfncvt_xu_f_w_u16m4_m(vbool4_t, vuint16m4_t, vfloat32m8_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vfrec7_v)))
vfloat32m1_t vfrec7_v_f32m1(vfloat32m1_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vfrec7_v_m)))
vfloat32m1_t vfrec7_v_f32m1_m(vbool32_t, vfloat32m1_t, vfloat32m1_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vfrec7_v)))
vfloat32m2_t vfrec7_v_f32m2(vfloat32m2_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vfrec7_v_m)))
vfloat32m2_t vfrec7_v_f32m2_m(vbool16_t, vfloat32m2_t, vfloat32m2_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vfrec7_v)))
vfloat32m4_t vfrec7_v_f32m4(vfloat32m4_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vfrec7_v_m)))
vfloat32m4_t vfrec7_v_f32m4_m(vbool8_t, vfloat32m4_t, vfloat32m4_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vfrec7_v)))
vfloat32m8_t vfrec7_v_f32m8(vfloat32m8_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vfrec7_v_m)))
vfloat32m8_t vfrec7_v_f32m8_m(vbool4_t, vfloat32m8_t, vfloat32m8_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vfrec7_v)))
vfloat32mf2_t vfrec7_v_f32mf2(vfloat32mf2_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vfrec7_v_m)))
vfloat32mf2_t vfrec7_v_f32mf2_m(vbool64_t, vfloat32mf2_t, vfloat32mf2_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vfrsqrt7_v)))
vfloat32m1_t vfrsqrt7_v_f32m1(vfloat32m1_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vfrsqrt7_v_m)))
vfloat32m1_t vfrsqrt7_v_f32m1_m(vbool32_t, vfloat32m1_t, vfloat32m1_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vfrsqrt7_v)))
vfloat32m2_t vfrsqrt7_v_f32m2(vfloat32m2_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vfrsqrt7_v_m)))
vfloat32m2_t vfrsqrt7_v_f32m2_m(vbool16_t, vfloat32m2_t, vfloat32m2_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vfrsqrt7_v)))
vfloat32m4_t vfrsqrt7_v_f32m4(vfloat32m4_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vfrsqrt7_v_m)))
vfloat32m4_t vfrsqrt7_v_f32m4_m(vbool8_t, vfloat32m4_t, vfloat32m4_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vfrsqrt7_v)))
vfloat32m8_t vfrsqrt7_v_f32m8(vfloat32m8_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vfrsqrt7_v_m)))
vfloat32m8_t vfrsqrt7_v_f32m8_m(vbool4_t, vfloat32m8_t, vfloat32m8_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vfrsqrt7_v)))
vfloat32mf2_t vfrsqrt7_v_f32mf2(vfloat32mf2_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vfrsqrt7_v_m)))
vfloat32mf2_t vfrsqrt7_v_f32mf2_m(vbool64_t, vfloat32mf2_t, vfloat32mf2_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vfsqrt_v)))
vfloat32m1_t vfsqrt_v_f32m1(vfloat32m1_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vfsqrt_v_m)))
vfloat32m1_t vfsqrt_v_f32m1_m(vbool32_t, vfloat32m1_t, vfloat32m1_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vfsqrt_v)))
vfloat32m2_t vfsqrt_v_f32m2(vfloat32m2_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vfsqrt_v_m)))
vfloat32m2_t vfsqrt_v_f32m2_m(vbool16_t, vfloat32m2_t, vfloat32m2_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vfsqrt_v)))
vfloat32m4_t vfsqrt_v_f32m4(vfloat32m4_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vfsqrt_v_m)))
vfloat32m4_t vfsqrt_v_f32m4_m(vbool8_t, vfloat32m4_t, vfloat32m4_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vfsqrt_v)))
vfloat32m8_t vfsqrt_v_f32m8(vfloat32m8_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vfsqrt_v_m)))
vfloat32m8_t vfsqrt_v_f32m8_m(vbool4_t, vfloat32m8_t, vfloat32m8_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vfsqrt_v)))
vfloat32mf2_t vfsqrt_v_f32mf2(vfloat32mf2_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vfsqrt_v_m)))
vfloat32mf2_t vfsqrt_v_f32mf2_m(vbool64_t, vfloat32mf2_t, vfloat32mf2_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vfwcvt_f_x_v)))
vfloat32mf2_t vfwcvt_f_x_v_f32mf2(vint16mf4_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vfwcvt_f_x_v_m)))
vfloat32mf2_t vfwcvt_f_x_v_f32mf2_m(vbool64_t, vfloat32mf2_t, vint16mf4_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vfwcvt_f_x_v)))
vfloat32m1_t vfwcvt_f_x_v_f32m1(vint16mf2_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vfwcvt_f_x_v_m)))
vfloat32m1_t vfwcvt_f_x_v_f32m1_m(vbool32_t, vfloat32m1_t, vint16mf2_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vfwcvt_f_x_v)))
vfloat32m2_t vfwcvt_f_x_v_f32m2(vint16m1_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vfwcvt_f_x_v_m)))
vfloat32m2_t vfwcvt_f_x_v_f32m2_m(vbool16_t, vfloat32m2_t, vint16m1_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vfwcvt_f_x_v)))
vfloat32m4_t vfwcvt_f_x_v_f32m4(vint16m2_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vfwcvt_f_x_v_m)))
vfloat32m4_t vfwcvt_f_x_v_f32m4_m(vbool8_t, vfloat32m4_t, vint16m2_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vfwcvt_f_x_v)))
vfloat32m8_t vfwcvt_f_x_v_f32m8(vint16m4_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vfwcvt_f_x_v_m)))
vfloat32m8_t vfwcvt_f_x_v_f32m8_m(vbool4_t, vfloat32m8_t, vint16m4_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vfwcvt_f_xu_v)))
vfloat32mf2_t vfwcvt_f_xu_v_f32mf2(vuint16mf4_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vfwcvt_f_xu_v_m)))
vfloat32mf2_t vfwcvt_f_xu_v_f32mf2_m(vbool64_t, vfloat32mf2_t, vuint16mf4_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vfwcvt_f_xu_v)))
vfloat32m1_t vfwcvt_f_xu_v_f32m1(vuint16mf2_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vfwcvt_f_xu_v_m)))
vfloat32m1_t vfwcvt_f_xu_v_f32m1_m(vbool32_t, vfloat32m1_t, vuint16mf2_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vfwcvt_f_xu_v)))
vfloat32m2_t vfwcvt_f_xu_v_f32m2(vuint16m1_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vfwcvt_f_xu_v_m)))
vfloat32m2_t vfwcvt_f_xu_v_f32m2_m(vbool16_t, vfloat32m2_t, vuint16m1_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vfwcvt_f_xu_v)))
vfloat32m4_t vfwcvt_f_xu_v_f32m4(vuint16m2_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vfwcvt_f_xu_v_m)))
vfloat32m4_t vfwcvt_f_xu_v_f32m4_m(vbool8_t, vfloat32m4_t, vuint16m2_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vfwcvt_f_xu_v)))
vfloat32m8_t vfwcvt_f_xu_v_f32m8(vuint16m4_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vfwcvt_f_xu_v_m)))
vfloat32m8_t vfwcvt_f_xu_v_f32m8_m(vbool4_t, vfloat32m8_t, vuint16m4_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vlmul_ext_v)))
vfloat32m1_t vlmul_ext_v_f32mf2_f32m1(vfloat32mf2_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vlmul_ext_v)))
vfloat32m2_t vlmul_ext_v_f32m1_f32m2(vfloat32m1_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vlmul_ext_v)))
vfloat32m2_t vlmul_ext_v_f32mf2_f32m2(vfloat32mf2_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vlmul_ext_v)))
vfloat32m4_t vlmul_ext_v_f32m1_f32m4(vfloat32m1_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vlmul_ext_v)))
vfloat32m4_t vlmul_ext_v_f32m2_f32m4(vfloat32m2_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vlmul_ext_v)))
vfloat32m4_t vlmul_ext_v_f32mf2_f32m4(vfloat32mf2_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vlmul_ext_v)))
vfloat32m8_t vlmul_ext_v_f32m1_f32m8(vfloat32m1_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vlmul_ext_v)))
vfloat32m8_t vlmul_ext_v_f32m2_f32m8(vfloat32m2_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vlmul_ext_v)))
vfloat32m8_t vlmul_ext_v_f32m4_f32m8(vfloat32m4_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vlmul_ext_v)))
vfloat32m8_t vlmul_ext_v_f32mf2_f32m8(vfloat32mf2_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vlmul_trunc_v)))
vfloat32mf2_t vlmul_trunc_v_f32m1_f32mf2(vfloat32m1_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vlmul_trunc_v)))
vfloat32mf2_t vlmul_trunc_v_f32m2_f32mf2(vfloat32m2_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vlmul_trunc_v)))
vfloat32mf2_t vlmul_trunc_v_f32m4_f32mf2(vfloat32m4_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vlmul_trunc_v)))
vfloat32mf2_t vlmul_trunc_v_f32m8_f32mf2(vfloat32m8_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vlmul_trunc_v)))
vfloat32m1_t vlmul_trunc_v_f32m2_f32m1(vfloat32m2_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vlmul_trunc_v)))
vfloat32m1_t vlmul_trunc_v_f32m4_f32m1(vfloat32m4_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vlmul_trunc_v)))
vfloat32m1_t vlmul_trunc_v_f32m8_f32m1(vfloat32m8_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vlmul_trunc_v)))
vfloat32m2_t vlmul_trunc_v_f32m4_f32m2(vfloat32m4_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vlmul_trunc_v)))
vfloat32m2_t vlmul_trunc_v_f32m8_f32m2(vfloat32m8_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vlmul_trunc_v)))
vfloat32m4_t vlmul_trunc_v_f32m8_f32m4(vfloat32m8_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vreinterpret_v)))
vfloat32m1_t vreinterpret_v_i32m1_f32m1(vint32m1_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vreinterpret_v)))
vfloat32m2_t vreinterpret_v_i32m2_f32m2(vint32m2_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vreinterpret_v)))
vfloat32m4_t vreinterpret_v_i32m4_f32m4(vint32m4_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vreinterpret_v)))
vfloat32m8_t vreinterpret_v_i32m8_f32m8(vint32m8_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vreinterpret_v)))
vfloat32mf2_t vreinterpret_v_i32mf2_f32mf2(vint32mf2_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vreinterpret_v)))
vfloat32m1_t vreinterpret_v_u32m1_f32m1(vuint32m1_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vreinterpret_v)))
vfloat32m2_t vreinterpret_v_u32m2_f32m2(vuint32m2_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vreinterpret_v)))
vfloat32m4_t vreinterpret_v_u32m4_f32m4(vuint32m4_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vreinterpret_v)))
vfloat32m8_t vreinterpret_v_u32m8_f32m8(vuint32m8_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vreinterpret_v)))
vfloat32mf2_t vreinterpret_v_u32mf2_f32mf2(vuint32mf2_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vreinterpret_v)))
vint32m1_t vreinterpret_v_f32m1_i32m1(vfloat32m1_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vreinterpret_v)))
vint32m2_t vreinterpret_v_f32m2_i32m2(vfloat32m2_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vreinterpret_v)))
vint32m4_t vreinterpret_v_f32m4_i32m4(vfloat32m4_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vreinterpret_v)))
vint32m8_t vreinterpret_v_f32m8_i32m8(vfloat32m8_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vreinterpret_v)))
vint32mf2_t vreinterpret_v_f32mf2_i32mf2(vfloat32mf2_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vreinterpret_v)))
vuint32m1_t vreinterpret_v_f32m1_u32m1(vfloat32m1_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vreinterpret_v)))
vuint32m2_t vreinterpret_v_f32m2_u32m2(vfloat32m2_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vreinterpret_v)))
vuint32m4_t vreinterpret_v_f32m4_u32m4(vfloat32m4_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vreinterpret_v)))
vuint32m8_t vreinterpret_v_f32m8_u32m8(vfloat32m8_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vreinterpret_v)))
vuint32mf2_t vreinterpret_v_f32mf2_u32mf2(vfloat32mf2_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vundefined)))
vfloat32m1_t vundefined_f32m1();
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vundefined)))
vfloat32m2_t vundefined_f32m2();
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vundefined)))
vfloat32m4_t vundefined_f32m4();
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vundefined)))
vfloat32m8_t vundefined_f32m8();
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vundefined)))
vfloat32mf2_t vundefined_f32mf2();
#endif

#if defined(__riscv_zfh) && (__riscv_v_elen_fp >= 32)
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vfwadd_vv)))
vfloat32mf2_t vfwadd_vv_f32mf2(vfloat16mf4_t, vfloat16mf4_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vfwadd_vv_m)))
vfloat32mf2_t vfwadd_vv_f32mf2_m(vbool64_t, vfloat32mf2_t, vfloat16mf4_t, vfloat16mf4_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vfwadd_vv)))
vfloat32m1_t vfwadd_vv_f32m1(vfloat16mf2_t, vfloat16mf2_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vfwadd_vv_m)))
vfloat32m1_t vfwadd_vv_f32m1_m(vbool32_t, vfloat32m1_t, vfloat16mf2_t, vfloat16mf2_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vfwadd_vv)))
vfloat32m2_t vfwadd_vv_f32m2(vfloat16m1_t, vfloat16m1_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vfwadd_vv_m)))
vfloat32m2_t vfwadd_vv_f32m2_m(vbool16_t, vfloat32m2_t, vfloat16m1_t, vfloat16m1_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vfwadd_vv)))
vfloat32m4_t vfwadd_vv_f32m4(vfloat16m2_t, vfloat16m2_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vfwadd_vv_m)))
vfloat32m4_t vfwadd_vv_f32m4_m(vbool8_t, vfloat32m4_t, vfloat16m2_t, vfloat16m2_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vfwadd_vv)))
vfloat32m8_t vfwadd_vv_f32m8(vfloat16m4_t, vfloat16m4_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vfwadd_vv_m)))
vfloat32m8_t vfwadd_vv_f32m8_m(vbool4_t, vfloat32m8_t, vfloat16m4_t, vfloat16m4_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vfwadd_vf)))
vfloat32mf2_t vfwadd_vf_f32mf2(vfloat16mf4_t, _Float16, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vfwadd_vf_m)))
vfloat32mf2_t vfwadd_vf_f32mf2_m(vbool64_t, vfloat32mf2_t, vfloat16mf4_t, _Float16, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vfwadd_vf)))
vfloat32m1_t vfwadd_vf_f32m1(vfloat16mf2_t, _Float16, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vfwadd_vf_m)))
vfloat32m1_t vfwadd_vf_f32m1_m(vbool32_t, vfloat32m1_t, vfloat16mf2_t, _Float16, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vfwadd_vf)))
vfloat32m2_t vfwadd_vf_f32m2(vfloat16m1_t, _Float16, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vfwadd_vf_m)))
vfloat32m2_t vfwadd_vf_f32m2_m(vbool16_t, vfloat32m2_t, vfloat16m1_t, _Float16, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vfwadd_vf)))
vfloat32m4_t vfwadd_vf_f32m4(vfloat16m2_t, _Float16, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vfwadd_vf_m)))
vfloat32m4_t vfwadd_vf_f32m4_m(vbool8_t, vfloat32m4_t, vfloat16m2_t, _Float16, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vfwadd_vf)))
vfloat32m8_t vfwadd_vf_f32m8(vfloat16m4_t, _Float16, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vfwadd_vf_m)))
vfloat32m8_t vfwadd_vf_f32m8_m(vbool4_t, vfloat32m8_t, vfloat16m4_t, _Float16, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vfwsub_vv)))
vfloat32mf2_t vfwsub_vv_f32mf2(vfloat16mf4_t, vfloat16mf4_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vfwsub_vv_m)))
vfloat32mf2_t vfwsub_vv_f32mf2_m(vbool64_t, vfloat32mf2_t, vfloat16mf4_t, vfloat16mf4_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vfwsub_vv)))
vfloat32m1_t vfwsub_vv_f32m1(vfloat16mf2_t, vfloat16mf2_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vfwsub_vv_m)))
vfloat32m1_t vfwsub_vv_f32m1_m(vbool32_t, vfloat32m1_t, vfloat16mf2_t, vfloat16mf2_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vfwsub_vv)))
vfloat32m2_t vfwsub_vv_f32m2(vfloat16m1_t, vfloat16m1_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vfwsub_vv_m)))
vfloat32m2_t vfwsub_vv_f32m2_m(vbool16_t, vfloat32m2_t, vfloat16m1_t, vfloat16m1_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vfwsub_vv)))
vfloat32m4_t vfwsub_vv_f32m4(vfloat16m2_t, vfloat16m2_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vfwsub_vv_m)))
vfloat32m4_t vfwsub_vv_f32m4_m(vbool8_t, vfloat32m4_t, vfloat16m2_t, vfloat16m2_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vfwsub_vv)))
vfloat32m8_t vfwsub_vv_f32m8(vfloat16m4_t, vfloat16m4_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vfwsub_vv_m)))
vfloat32m8_t vfwsub_vv_f32m8_m(vbool4_t, vfloat32m8_t, vfloat16m4_t, vfloat16m4_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vfwsub_vf)))
vfloat32mf2_t vfwsub_vf_f32mf2(vfloat16mf4_t, _Float16, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vfwsub_vf_m)))
vfloat32mf2_t vfwsub_vf_f32mf2_m(vbool64_t, vfloat32mf2_t, vfloat16mf4_t, _Float16, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vfwsub_vf)))
vfloat32m1_t vfwsub_vf_f32m1(vfloat16mf2_t, _Float16, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vfwsub_vf_m)))
vfloat32m1_t vfwsub_vf_f32m1_m(vbool32_t, vfloat32m1_t, vfloat16mf2_t, _Float16, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vfwsub_vf)))
vfloat32m2_t vfwsub_vf_f32m2(vfloat16m1_t, _Float16, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vfwsub_vf_m)))
vfloat32m2_t vfwsub_vf_f32m2_m(vbool16_t, vfloat32m2_t, vfloat16m1_t, _Float16, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vfwsub_vf)))
vfloat32m4_t vfwsub_vf_f32m4(vfloat16m2_t, _Float16, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vfwsub_vf_m)))
vfloat32m4_t vfwsub_vf_f32m4_m(vbool8_t, vfloat32m4_t, vfloat16m2_t, _Float16, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vfwsub_vf)))
vfloat32m8_t vfwsub_vf_f32m8(vfloat16m4_t, _Float16, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vfwsub_vf_m)))
vfloat32m8_t vfwsub_vf_f32m8_m(vbool4_t, vfloat32m8_t, vfloat16m4_t, _Float16, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vfwadd_wv)))
vfloat32mf2_t vfwadd_wv_f32mf2(vfloat32mf2_t, vfloat16mf4_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vfwadd_wv_m)))
vfloat32mf2_t vfwadd_wv_f32mf2_m(vbool64_t, vfloat32mf2_t, vfloat32mf2_t, vfloat16mf4_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vfwadd_wv)))
vfloat32m1_t vfwadd_wv_f32m1(vfloat32m1_t, vfloat16mf2_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vfwadd_wv_m)))
vfloat32m1_t vfwadd_wv_f32m1_m(vbool32_t, vfloat32m1_t, vfloat32m1_t, vfloat16mf2_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vfwadd_wv)))
vfloat32m2_t vfwadd_wv_f32m2(vfloat32m2_t, vfloat16m1_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vfwadd_wv_m)))
vfloat32m2_t vfwadd_wv_f32m2_m(vbool16_t, vfloat32m2_t, vfloat32m2_t, vfloat16m1_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vfwadd_wv)))
vfloat32m4_t vfwadd_wv_f32m4(vfloat32m4_t, vfloat16m2_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vfwadd_wv_m)))
vfloat32m4_t vfwadd_wv_f32m4_m(vbool8_t, vfloat32m4_t, vfloat32m4_t, vfloat16m2_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vfwadd_wv)))
vfloat32m8_t vfwadd_wv_f32m8(vfloat32m8_t, vfloat16m4_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vfwadd_wv_m)))
vfloat32m8_t vfwadd_wv_f32m8_m(vbool4_t, vfloat32m8_t, vfloat32m8_t, vfloat16m4_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vfwadd_wf)))
vfloat32mf2_t vfwadd_wf_f32mf2(vfloat32mf2_t, _Float16, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vfwadd_wf_m)))
vfloat32mf2_t vfwadd_wf_f32mf2_m(vbool64_t, vfloat32mf2_t, vfloat32mf2_t, _Float16, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vfwadd_wf)))
vfloat32m1_t vfwadd_wf_f32m1(vfloat32m1_t, _Float16, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vfwadd_wf_m)))
vfloat32m1_t vfwadd_wf_f32m1_m(vbool32_t, vfloat32m1_t, vfloat32m1_t, _Float16, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vfwadd_wf)))
vfloat32m2_t vfwadd_wf_f32m2(vfloat32m2_t, _Float16, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vfwadd_wf_m)))
vfloat32m2_t vfwadd_wf_f32m2_m(vbool16_t, vfloat32m2_t, vfloat32m2_t, _Float16, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vfwadd_wf)))
vfloat32m4_t vfwadd_wf_f32m4(vfloat32m4_t, _Float16, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vfwadd_wf_m)))
vfloat32m4_t vfwadd_wf_f32m4_m(vbool8_t, vfloat32m4_t, vfloat32m4_t, _Float16, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vfwadd_wf)))
vfloat32m8_t vfwadd_wf_f32m8(vfloat32m8_t, _Float16, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vfwadd_wf_m)))
vfloat32m8_t vfwadd_wf_f32m8_m(vbool4_t, vfloat32m8_t, vfloat32m8_t, _Float16, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vfwsub_wv)))
vfloat32mf2_t vfwsub_wv_f32mf2(vfloat32mf2_t, vfloat16mf4_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vfwsub_wv_m)))
vfloat32mf2_t vfwsub_wv_f32mf2_m(vbool64_t, vfloat32mf2_t, vfloat32mf2_t, vfloat16mf4_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vfwsub_wv)))
vfloat32m1_t vfwsub_wv_f32m1(vfloat32m1_t, vfloat16mf2_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vfwsub_wv_m)))
vfloat32m1_t vfwsub_wv_f32m1_m(vbool32_t, vfloat32m1_t, vfloat32m1_t, vfloat16mf2_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vfwsub_wv)))
vfloat32m2_t vfwsub_wv_f32m2(vfloat32m2_t, vfloat16m1_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vfwsub_wv_m)))
vfloat32m2_t vfwsub_wv_f32m2_m(vbool16_t, vfloat32m2_t, vfloat32m2_t, vfloat16m1_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vfwsub_wv)))
vfloat32m4_t vfwsub_wv_f32m4(vfloat32m4_t, vfloat16m2_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vfwsub_wv_m)))
vfloat32m4_t vfwsub_wv_f32m4_m(vbool8_t, vfloat32m4_t, vfloat32m4_t, vfloat16m2_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vfwsub_wv)))
vfloat32m8_t vfwsub_wv_f32m8(vfloat32m8_t, vfloat16m4_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vfwsub_wv_m)))
vfloat32m8_t vfwsub_wv_f32m8_m(vbool4_t, vfloat32m8_t, vfloat32m8_t, vfloat16m4_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vfwsub_wf)))
vfloat32mf2_t vfwsub_wf_f32mf2(vfloat32mf2_t, _Float16, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vfwsub_wf_m)))
vfloat32mf2_t vfwsub_wf_f32mf2_m(vbool64_t, vfloat32mf2_t, vfloat32mf2_t, _Float16, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vfwsub_wf)))
vfloat32m1_t vfwsub_wf_f32m1(vfloat32m1_t, _Float16, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vfwsub_wf_m)))
vfloat32m1_t vfwsub_wf_f32m1_m(vbool32_t, vfloat32m1_t, vfloat32m1_t, _Float16, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vfwsub_wf)))
vfloat32m2_t vfwsub_wf_f32m2(vfloat32m2_t, _Float16, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vfwsub_wf_m)))
vfloat32m2_t vfwsub_wf_f32m2_m(vbool16_t, vfloat32m2_t, vfloat32m2_t, _Float16, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vfwsub_wf)))
vfloat32m4_t vfwsub_wf_f32m4(vfloat32m4_t, _Float16, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vfwsub_wf_m)))
vfloat32m4_t vfwsub_wf_f32m4_m(vbool8_t, vfloat32m4_t, vfloat32m4_t, _Float16, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vfwsub_wf)))
vfloat32m8_t vfwsub_wf_f32m8(vfloat32m8_t, _Float16, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vfwsub_wf_m)))
vfloat32m8_t vfwsub_wf_f32m8_m(vbool4_t, vfloat32m8_t, vfloat32m8_t, _Float16, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vfwmul_vv)))
vfloat32mf2_t vfwmul_vv_f32mf2(vfloat16mf4_t, vfloat16mf4_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vfwmul_vv_m)))
vfloat32mf2_t vfwmul_vv_f32mf2_m(vbool64_t, vfloat32mf2_t, vfloat16mf4_t, vfloat16mf4_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vfwmul_vv)))
vfloat32m1_t vfwmul_vv_f32m1(vfloat16mf2_t, vfloat16mf2_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vfwmul_vv_m)))
vfloat32m1_t vfwmul_vv_f32m1_m(vbool32_t, vfloat32m1_t, vfloat16mf2_t, vfloat16mf2_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vfwmul_vv)))
vfloat32m2_t vfwmul_vv_f32m2(vfloat16m1_t, vfloat16m1_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vfwmul_vv_m)))
vfloat32m2_t vfwmul_vv_f32m2_m(vbool16_t, vfloat32m2_t, vfloat16m1_t, vfloat16m1_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vfwmul_vv)))
vfloat32m4_t vfwmul_vv_f32m4(vfloat16m2_t, vfloat16m2_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vfwmul_vv_m)))
vfloat32m4_t vfwmul_vv_f32m4_m(vbool8_t, vfloat32m4_t, vfloat16m2_t, vfloat16m2_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vfwmul_vv)))
vfloat32m8_t vfwmul_vv_f32m8(vfloat16m4_t, vfloat16m4_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vfwmul_vv_m)))
vfloat32m8_t vfwmul_vv_f32m8_m(vbool4_t, vfloat32m8_t, vfloat16m4_t, vfloat16m4_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vfwmul_vf)))
vfloat32mf2_t vfwmul_vf_f32mf2(vfloat16mf4_t, _Float16, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vfwmul_vf_m)))
vfloat32mf2_t vfwmul_vf_f32mf2_m(vbool64_t, vfloat32mf2_t, vfloat16mf4_t, _Float16, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vfwmul_vf)))
vfloat32m1_t vfwmul_vf_f32m1(vfloat16mf2_t, _Float16, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vfwmul_vf_m)))
vfloat32m1_t vfwmul_vf_f32m1_m(vbool32_t, vfloat32m1_t, vfloat16mf2_t, _Float16, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vfwmul_vf)))
vfloat32m2_t vfwmul_vf_f32m2(vfloat16m1_t, _Float16, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vfwmul_vf_m)))
vfloat32m2_t vfwmul_vf_f32m2_m(vbool16_t, vfloat32m2_t, vfloat16m1_t, _Float16, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vfwmul_vf)))
vfloat32m4_t vfwmul_vf_f32m4(vfloat16m2_t, _Float16, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vfwmul_vf_m)))
vfloat32m4_t vfwmul_vf_f32m4_m(vbool8_t, vfloat32m4_t, vfloat16m2_t, _Float16, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vfwmul_vf)))
vfloat32m8_t vfwmul_vf_f32m8(vfloat16m4_t, _Float16, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vfwmul_vf_m)))
vfloat32m8_t vfwmul_vf_f32m8_m(vbool4_t, vfloat32m8_t, vfloat16m4_t, _Float16, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vfwmacc_vv)))
vfloat32mf2_t vfwmacc_vv_f32mf2(vfloat32mf2_t, vfloat16mf4_t, vfloat16mf4_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vfwmacc_vv_m)))
vfloat32mf2_t vfwmacc_vv_f32mf2_m(vbool64_t, vfloat32mf2_t, vfloat16mf4_t, vfloat16mf4_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vfwmacc_vv)))
vfloat32m1_t vfwmacc_vv_f32m1(vfloat32m1_t, vfloat16mf2_t, vfloat16mf2_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vfwmacc_vv_m)))
vfloat32m1_t vfwmacc_vv_f32m1_m(vbool32_t, vfloat32m1_t, vfloat16mf2_t, vfloat16mf2_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vfwmacc_vv)))
vfloat32m2_t vfwmacc_vv_f32m2(vfloat32m2_t, vfloat16m1_t, vfloat16m1_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vfwmacc_vv_m)))
vfloat32m2_t vfwmacc_vv_f32m2_m(vbool16_t, vfloat32m2_t, vfloat16m1_t, vfloat16m1_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vfwmacc_vv)))
vfloat32m4_t vfwmacc_vv_f32m4(vfloat32m4_t, vfloat16m2_t, vfloat16m2_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vfwmacc_vv_m)))
vfloat32m4_t vfwmacc_vv_f32m4_m(vbool8_t, vfloat32m4_t, vfloat16m2_t, vfloat16m2_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vfwmacc_vv)))
vfloat32m8_t vfwmacc_vv_f32m8(vfloat32m8_t, vfloat16m4_t, vfloat16m4_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vfwmacc_vv_m)))
vfloat32m8_t vfwmacc_vv_f32m8_m(vbool4_t, vfloat32m8_t, vfloat16m4_t, vfloat16m4_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vfwmacc_vf)))
vfloat32mf2_t vfwmacc_vf_f32mf2(vfloat32mf2_t, _Float16, vfloat16mf4_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vfwmacc_vf_m)))
vfloat32mf2_t vfwmacc_vf_f32mf2_m(vbool64_t, vfloat32mf2_t, _Float16, vfloat16mf4_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vfwmacc_vf)))
vfloat32m1_t vfwmacc_vf_f32m1(vfloat32m1_t, _Float16, vfloat16mf2_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vfwmacc_vf_m)))
vfloat32m1_t vfwmacc_vf_f32m1_m(vbool32_t, vfloat32m1_t, _Float16, vfloat16mf2_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vfwmacc_vf)))
vfloat32m2_t vfwmacc_vf_f32m2(vfloat32m2_t, _Float16, vfloat16m1_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vfwmacc_vf_m)))
vfloat32m2_t vfwmacc_vf_f32m2_m(vbool16_t, vfloat32m2_t, _Float16, vfloat16m1_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vfwmacc_vf)))
vfloat32m4_t vfwmacc_vf_f32m4(vfloat32m4_t, _Float16, vfloat16m2_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vfwmacc_vf_m)))
vfloat32m4_t vfwmacc_vf_f32m4_m(vbool8_t, vfloat32m4_t, _Float16, vfloat16m2_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vfwmacc_vf)))
vfloat32m8_t vfwmacc_vf_f32m8(vfloat32m8_t, _Float16, vfloat16m4_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vfwmacc_vf_m)))
vfloat32m8_t vfwmacc_vf_f32m8_m(vbool4_t, vfloat32m8_t, _Float16, vfloat16m4_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vfwnmacc_vv)))
vfloat32mf2_t vfwnmacc_vv_f32mf2(vfloat32mf2_t, vfloat16mf4_t, vfloat16mf4_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vfwnmacc_vv_m)))
vfloat32mf2_t vfwnmacc_vv_f32mf2_m(vbool64_t, vfloat32mf2_t, vfloat16mf4_t, vfloat16mf4_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vfwnmacc_vv)))
vfloat32m1_t vfwnmacc_vv_f32m1(vfloat32m1_t, vfloat16mf2_t, vfloat16mf2_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vfwnmacc_vv_m)))
vfloat32m1_t vfwnmacc_vv_f32m1_m(vbool32_t, vfloat32m1_t, vfloat16mf2_t, vfloat16mf2_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vfwnmacc_vv)))
vfloat32m2_t vfwnmacc_vv_f32m2(vfloat32m2_t, vfloat16m1_t, vfloat16m1_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vfwnmacc_vv_m)))
vfloat32m2_t vfwnmacc_vv_f32m2_m(vbool16_t, vfloat32m2_t, vfloat16m1_t, vfloat16m1_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vfwnmacc_vv)))
vfloat32m4_t vfwnmacc_vv_f32m4(vfloat32m4_t, vfloat16m2_t, vfloat16m2_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vfwnmacc_vv_m)))
vfloat32m4_t vfwnmacc_vv_f32m4_m(vbool8_t, vfloat32m4_t, vfloat16m2_t, vfloat16m2_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vfwnmacc_vv)))
vfloat32m8_t vfwnmacc_vv_f32m8(vfloat32m8_t, vfloat16m4_t, vfloat16m4_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vfwnmacc_vv_m)))
vfloat32m8_t vfwnmacc_vv_f32m8_m(vbool4_t, vfloat32m8_t, vfloat16m4_t, vfloat16m4_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vfwnmacc_vf)))
vfloat32mf2_t vfwnmacc_vf_f32mf2(vfloat32mf2_t, _Float16, vfloat16mf4_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vfwnmacc_vf_m)))
vfloat32mf2_t vfwnmacc_vf_f32mf2_m(vbool64_t, vfloat32mf2_t, _Float16, vfloat16mf4_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vfwnmacc_vf)))
vfloat32m1_t vfwnmacc_vf_f32m1(vfloat32m1_t, _Float16, vfloat16mf2_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vfwnmacc_vf_m)))
vfloat32m1_t vfwnmacc_vf_f32m1_m(vbool32_t, vfloat32m1_t, _Float16, vfloat16mf2_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vfwnmacc_vf)))
vfloat32m2_t vfwnmacc_vf_f32m2(vfloat32m2_t, _Float16, vfloat16m1_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vfwnmacc_vf_m)))
vfloat32m2_t vfwnmacc_vf_f32m2_m(vbool16_t, vfloat32m2_t, _Float16, vfloat16m1_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vfwnmacc_vf)))
vfloat32m4_t vfwnmacc_vf_f32m4(vfloat32m4_t, _Float16, vfloat16m2_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vfwnmacc_vf_m)))
vfloat32m4_t vfwnmacc_vf_f32m4_m(vbool8_t, vfloat32m4_t, _Float16, vfloat16m2_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vfwnmacc_vf)))
vfloat32m8_t vfwnmacc_vf_f32m8(vfloat32m8_t, _Float16, vfloat16m4_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vfwnmacc_vf_m)))
vfloat32m8_t vfwnmacc_vf_f32m8_m(vbool4_t, vfloat32m8_t, _Float16, vfloat16m4_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vfwmsac_vv)))
vfloat32mf2_t vfwmsac_vv_f32mf2(vfloat32mf2_t, vfloat16mf4_t, vfloat16mf4_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vfwmsac_vv_m)))
vfloat32mf2_t vfwmsac_vv_f32mf2_m(vbool64_t, vfloat32mf2_t, vfloat16mf4_t, vfloat16mf4_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vfwmsac_vv)))
vfloat32m1_t vfwmsac_vv_f32m1(vfloat32m1_t, vfloat16mf2_t, vfloat16mf2_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vfwmsac_vv_m)))
vfloat32m1_t vfwmsac_vv_f32m1_m(vbool32_t, vfloat32m1_t, vfloat16mf2_t, vfloat16mf2_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vfwmsac_vv)))
vfloat32m2_t vfwmsac_vv_f32m2(vfloat32m2_t, vfloat16m1_t, vfloat16m1_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vfwmsac_vv_m)))
vfloat32m2_t vfwmsac_vv_f32m2_m(vbool16_t, vfloat32m2_t, vfloat16m1_t, vfloat16m1_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vfwmsac_vv)))
vfloat32m4_t vfwmsac_vv_f32m4(vfloat32m4_t, vfloat16m2_t, vfloat16m2_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vfwmsac_vv_m)))
vfloat32m4_t vfwmsac_vv_f32m4_m(vbool8_t, vfloat32m4_t, vfloat16m2_t, vfloat16m2_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vfwmsac_vv)))
vfloat32m8_t vfwmsac_vv_f32m8(vfloat32m8_t, vfloat16m4_t, vfloat16m4_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vfwmsac_vv_m)))
vfloat32m8_t vfwmsac_vv_f32m8_m(vbool4_t, vfloat32m8_t, vfloat16m4_t, vfloat16m4_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vfwmsac_vf)))
vfloat32mf2_t vfwmsac_vf_f32mf2(vfloat32mf2_t, _Float16, vfloat16mf4_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vfwmsac_vf_m)))
vfloat32mf2_t vfwmsac_vf_f32mf2_m(vbool64_t, vfloat32mf2_t, _Float16, vfloat16mf4_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vfwmsac_vf)))
vfloat32m1_t vfwmsac_vf_f32m1(vfloat32m1_t, _Float16, vfloat16mf2_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vfwmsac_vf_m)))
vfloat32m1_t vfwmsac_vf_f32m1_m(vbool32_t, vfloat32m1_t, _Float16, vfloat16mf2_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vfwmsac_vf)))
vfloat32m2_t vfwmsac_vf_f32m2(vfloat32m2_t, _Float16, vfloat16m1_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vfwmsac_vf_m)))
vfloat32m2_t vfwmsac_vf_f32m2_m(vbool16_t, vfloat32m2_t, _Float16, vfloat16m1_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vfwmsac_vf)))
vfloat32m4_t vfwmsac_vf_f32m4(vfloat32m4_t, _Float16, vfloat16m2_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vfwmsac_vf_m)))
vfloat32m4_t vfwmsac_vf_f32m4_m(vbool8_t, vfloat32m4_t, _Float16, vfloat16m2_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vfwmsac_vf)))
vfloat32m8_t vfwmsac_vf_f32m8(vfloat32m8_t, _Float16, vfloat16m4_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vfwmsac_vf_m)))
vfloat32m8_t vfwmsac_vf_f32m8_m(vbool4_t, vfloat32m8_t, _Float16, vfloat16m4_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vfwnmsac_vv)))
vfloat32mf2_t vfwnmsac_vv_f32mf2(vfloat32mf2_t, vfloat16mf4_t, vfloat16mf4_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vfwnmsac_vv_m)))
vfloat32mf2_t vfwnmsac_vv_f32mf2_m(vbool64_t, vfloat32mf2_t, vfloat16mf4_t, vfloat16mf4_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vfwnmsac_vv)))
vfloat32m1_t vfwnmsac_vv_f32m1(vfloat32m1_t, vfloat16mf2_t, vfloat16mf2_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vfwnmsac_vv_m)))
vfloat32m1_t vfwnmsac_vv_f32m1_m(vbool32_t, vfloat32m1_t, vfloat16mf2_t, vfloat16mf2_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vfwnmsac_vv)))
vfloat32m2_t vfwnmsac_vv_f32m2(vfloat32m2_t, vfloat16m1_t, vfloat16m1_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vfwnmsac_vv_m)))
vfloat32m2_t vfwnmsac_vv_f32m2_m(vbool16_t, vfloat32m2_t, vfloat16m1_t, vfloat16m1_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vfwnmsac_vv)))
vfloat32m4_t vfwnmsac_vv_f32m4(vfloat32m4_t, vfloat16m2_t, vfloat16m2_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vfwnmsac_vv_m)))
vfloat32m4_t vfwnmsac_vv_f32m4_m(vbool8_t, vfloat32m4_t, vfloat16m2_t, vfloat16m2_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vfwnmsac_vv)))
vfloat32m8_t vfwnmsac_vv_f32m8(vfloat32m8_t, vfloat16m4_t, vfloat16m4_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vfwnmsac_vv_m)))
vfloat32m8_t vfwnmsac_vv_f32m8_m(vbool4_t, vfloat32m8_t, vfloat16m4_t, vfloat16m4_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vfwnmsac_vf)))
vfloat32mf2_t vfwnmsac_vf_f32mf2(vfloat32mf2_t, _Float16, vfloat16mf4_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vfwnmsac_vf_m)))
vfloat32mf2_t vfwnmsac_vf_f32mf2_m(vbool64_t, vfloat32mf2_t, _Float16, vfloat16mf4_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vfwnmsac_vf)))
vfloat32m1_t vfwnmsac_vf_f32m1(vfloat32m1_t, _Float16, vfloat16mf2_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vfwnmsac_vf_m)))
vfloat32m1_t vfwnmsac_vf_f32m1_m(vbool32_t, vfloat32m1_t, _Float16, vfloat16mf2_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vfwnmsac_vf)))
vfloat32m2_t vfwnmsac_vf_f32m2(vfloat32m2_t, _Float16, vfloat16m1_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vfwnmsac_vf_m)))
vfloat32m2_t vfwnmsac_vf_f32m2_m(vbool16_t, vfloat32m2_t, _Float16, vfloat16m1_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vfwnmsac_vf)))
vfloat32m4_t vfwnmsac_vf_f32m4(vfloat32m4_t, _Float16, vfloat16m2_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vfwnmsac_vf_m)))
vfloat32m4_t vfwnmsac_vf_f32m4_m(vbool8_t, vfloat32m4_t, _Float16, vfloat16m2_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vfwnmsac_vf)))
vfloat32m8_t vfwnmsac_vf_f32m8(vfloat32m8_t, _Float16, vfloat16m4_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vfwnmsac_vf_m)))
vfloat32m8_t vfwnmsac_vf_f32m8_m(vbool4_t, vfloat32m8_t, _Float16, vfloat16m4_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vfwredusum_vs)))
vfloat32m1_t vfwredusum_vs_f16m1_f32m1(vfloat32m1_t, vfloat16m1_t, vfloat32m1_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vfwredusum_vs_m)))
vfloat32m1_t vfwredusum_vs_f16m1_f32m1_m(vbool16_t, vfloat32m1_t, vfloat16m1_t, vfloat32m1_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vfwredusum_vs)))
vfloat32m1_t vfwredusum_vs_f16m2_f32m1(vfloat32m1_t, vfloat16m2_t, vfloat32m1_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vfwredusum_vs_m)))
vfloat32m1_t vfwredusum_vs_f16m2_f32m1_m(vbool8_t, vfloat32m1_t, vfloat16m2_t, vfloat32m1_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vfwredusum_vs)))
vfloat32m1_t vfwredusum_vs_f16m4_f32m1(vfloat32m1_t, vfloat16m4_t, vfloat32m1_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vfwredusum_vs_m)))
vfloat32m1_t vfwredusum_vs_f16m4_f32m1_m(vbool4_t, vfloat32m1_t, vfloat16m4_t, vfloat32m1_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vfwredusum_vs)))
vfloat32m1_t vfwredusum_vs_f16m8_f32m1(vfloat32m1_t, vfloat16m8_t, vfloat32m1_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vfwredusum_vs_m)))
vfloat32m1_t vfwredusum_vs_f16m8_f32m1_m(vbool2_t, vfloat32m1_t, vfloat16m8_t, vfloat32m1_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vfwredusum_vs)))
vfloat32m1_t vfwredusum_vs_f16mf2_f32m1(vfloat32m1_t, vfloat16mf2_t, vfloat32m1_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vfwredusum_vs_m)))
vfloat32m1_t vfwredusum_vs_f16mf2_f32m1_m(vbool32_t, vfloat32m1_t, vfloat16mf2_t, vfloat32m1_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vfwredusum_vs)))
vfloat32m1_t vfwredusum_vs_f16mf4_f32m1(vfloat32m1_t, vfloat16mf4_t, vfloat32m1_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vfwredusum_vs_m)))
vfloat32m1_t vfwredusum_vs_f16mf4_f32m1_m(vbool64_t, vfloat32m1_t, vfloat16mf4_t, vfloat32m1_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vfwredosum_vs)))
vfloat32m1_t vfwredosum_vs_f16m1_f32m1(vfloat32m1_t, vfloat16m1_t, vfloat32m1_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vfwredosum_vs_m)))
vfloat32m1_t vfwredosum_vs_f16m1_f32m1_m(vbool16_t, vfloat32m1_t, vfloat16m1_t, vfloat32m1_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vfwredosum_vs)))
vfloat32m1_t vfwredosum_vs_f16m2_f32m1(vfloat32m1_t, vfloat16m2_t, vfloat32m1_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vfwredosum_vs_m)))
vfloat32m1_t vfwredosum_vs_f16m2_f32m1_m(vbool8_t, vfloat32m1_t, vfloat16m2_t, vfloat32m1_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vfwredosum_vs)))
vfloat32m1_t vfwredosum_vs_f16m4_f32m1(vfloat32m1_t, vfloat16m4_t, vfloat32m1_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vfwredosum_vs_m)))
vfloat32m1_t vfwredosum_vs_f16m4_f32m1_m(vbool4_t, vfloat32m1_t, vfloat16m4_t, vfloat32m1_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vfwredosum_vs)))
vfloat32m1_t vfwredosum_vs_f16m8_f32m1(vfloat32m1_t, vfloat16m8_t, vfloat32m1_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vfwredosum_vs_m)))
vfloat32m1_t vfwredosum_vs_f16m8_f32m1_m(vbool2_t, vfloat32m1_t, vfloat16m8_t, vfloat32m1_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vfwredosum_vs)))
vfloat32m1_t vfwredosum_vs_f16mf2_f32m1(vfloat32m1_t, vfloat16mf2_t, vfloat32m1_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vfwredosum_vs_m)))
vfloat32m1_t vfwredosum_vs_f16mf2_f32m1_m(vbool32_t, vfloat32m1_t, vfloat16mf2_t, vfloat32m1_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vfwredosum_vs)))
vfloat32m1_t vfwredosum_vs_f16mf4_f32m1(vfloat32m1_t, vfloat16mf4_t, vfloat32m1_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vfwredosum_vs_m)))
vfloat32m1_t vfwredosum_vs_f16mf4_f32m1_m(vbool64_t, vfloat32m1_t, vfloat16mf4_t, vfloat32m1_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vfncvt_f_f_w)))
vfloat16mf4_t vfncvt_f_f_w_f16mf4(vfloat32mf2_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vfncvt_f_f_w_m)))
vfloat16mf4_t vfncvt_f_f_w_f16mf4_m(vbool64_t, vfloat16mf4_t, vfloat32mf2_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vfncvt_f_f_w)))
vfloat16mf2_t vfncvt_f_f_w_f16mf2(vfloat32m1_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vfncvt_f_f_w_m)))
vfloat16mf2_t vfncvt_f_f_w_f16mf2_m(vbool32_t, vfloat16mf2_t, vfloat32m1_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vfncvt_f_f_w)))
vfloat16m1_t vfncvt_f_f_w_f16m1(vfloat32m2_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vfncvt_f_f_w_m)))
vfloat16m1_t vfncvt_f_f_w_f16m1_m(vbool16_t, vfloat16m1_t, vfloat32m2_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vfncvt_f_f_w)))
vfloat16m2_t vfncvt_f_f_w_f16m2(vfloat32m4_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vfncvt_f_f_w_m)))
vfloat16m2_t vfncvt_f_f_w_f16m2_m(vbool8_t, vfloat16m2_t, vfloat32m4_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vfncvt_f_f_w)))
vfloat16m4_t vfncvt_f_f_w_f16m4(vfloat32m8_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vfncvt_f_f_w_m)))
vfloat16m4_t vfncvt_f_f_w_f16m4_m(vbool4_t, vfloat16m4_t, vfloat32m8_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vfncvt_rod_f_f_w)))
vfloat16mf4_t vfncvt_rod_f_f_w_f16mf4(vfloat32mf2_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vfncvt_rod_f_f_w_m)))
vfloat16mf4_t vfncvt_rod_f_f_w_f16mf4_m(vbool64_t, vfloat16mf4_t, vfloat32mf2_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vfncvt_rod_f_f_w)))
vfloat16mf2_t vfncvt_rod_f_f_w_f16mf2(vfloat32m1_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vfncvt_rod_f_f_w_m)))
vfloat16mf2_t vfncvt_rod_f_f_w_f16mf2_m(vbool32_t, vfloat16mf2_t, vfloat32m1_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vfncvt_rod_f_f_w)))
vfloat16m1_t vfncvt_rod_f_f_w_f16m1(vfloat32m2_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vfncvt_rod_f_f_w_m)))
vfloat16m1_t vfncvt_rod_f_f_w_f16m1_m(vbool16_t, vfloat16m1_t, vfloat32m2_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vfncvt_rod_f_f_w)))
vfloat16m2_t vfncvt_rod_f_f_w_f16m2(vfloat32m4_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vfncvt_rod_f_f_w_m)))
vfloat16m2_t vfncvt_rod_f_f_w_f16m2_m(vbool8_t, vfloat16m2_t, vfloat32m4_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vfncvt_rod_f_f_w)))
vfloat16m4_t vfncvt_rod_f_f_w_f16m4(vfloat32m8_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vfncvt_rod_f_f_w_m)))
vfloat16m4_t vfncvt_rod_f_f_w_f16m4_m(vbool4_t, vfloat16m4_t, vfloat32m8_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vfwcvt_f_f_v)))
vfloat32mf2_t vfwcvt_f_f_v_f32mf2(vfloat16mf4_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vfwcvt_f_f_v_m)))
vfloat32mf2_t vfwcvt_f_f_v_f32mf2_m(vbool64_t, vfloat32mf2_t, vfloat16mf4_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vfwcvt_f_f_v)))
vfloat32m1_t vfwcvt_f_f_v_f32m1(vfloat16mf2_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vfwcvt_f_f_v_m)))
vfloat32m1_t vfwcvt_f_f_v_f32m1_m(vbool32_t, vfloat32m1_t, vfloat16mf2_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vfwcvt_f_f_v)))
vfloat32m2_t vfwcvt_f_f_v_f32m2(vfloat16m1_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vfwcvt_f_f_v_m)))
vfloat32m2_t vfwcvt_f_f_v_f32m2_m(vbool16_t, vfloat32m2_t, vfloat16m1_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vfwcvt_f_f_v)))
vfloat32m4_t vfwcvt_f_f_v_f32m4(vfloat16m2_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vfwcvt_f_f_v_m)))
vfloat32m4_t vfwcvt_f_f_v_f32m4_m(vbool8_t, vfloat32m4_t, vfloat16m2_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vfwcvt_f_f_v)))
vfloat32m8_t vfwcvt_f_f_v_f32m8(vfloat16m4_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vfwcvt_f_f_v_m)))
vfloat32m8_t vfwcvt_f_f_v_f32m8_m(vbool4_t, vfloat32m8_t, vfloat16m4_t, size_t);
#endif

#if (__riscv_v_elen >= 64) && (__riscv_v_elen_fp >= 32)
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vloxseg2ei64_v)))
void vloxseg2ei64_v_f32m1(vfloat32m1_t *, vfloat32m1_t *, const float *, vuint64m2_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vloxseg2ei64_v_m)))
void vloxseg2ei64_v_f32m1_m(vfloat32m1_t *, vfloat32m1_t *, vbool32_t, vfloat32m1_t, vfloat32m1_t, const float *, vuint64m2_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vloxseg2ei64_v)))
void vloxseg2ei64_v_f32m2(vfloat32m2_t *, vfloat32m2_t *, const float *, vuint64m4_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vloxseg2ei64_v_m)))
void vloxseg2ei64_v_f32m2_m(vfloat32m2_t *, vfloat32m2_t *, vbool16_t, vfloat32m2_t, vfloat32m2_t, const float *, vuint64m4_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vloxseg2ei64_v)))
void vloxseg2ei64_v_f32m4(vfloat32m4_t *, vfloat32m4_t *, const float *, vuint64m8_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vloxseg2ei64_v_m)))
void vloxseg2ei64_v_f32m4_m(vfloat32m4_t *, vfloat32m4_t *, vbool8_t, vfloat32m4_t, vfloat32m4_t, const float *, vuint64m8_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vloxseg2ei64_v)))
void vloxseg2ei64_v_f32mf2(vfloat32mf2_t *, vfloat32mf2_t *, const float *, vuint64m1_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vloxseg2ei64_v_m)))
void vloxseg2ei64_v_f32mf2_m(vfloat32mf2_t *, vfloat32mf2_t *, vbool64_t, vfloat32mf2_t, vfloat32mf2_t, const float *, vuint64m1_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vloxseg3ei64_v)))
void vloxseg3ei64_v_f32m1(vfloat32m1_t *, vfloat32m1_t *, vfloat32m1_t *, const float *, vuint64m2_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vloxseg3ei64_v_m)))
void vloxseg3ei64_v_f32m1_m(vfloat32m1_t *, vfloat32m1_t *, vfloat32m1_t *, vbool32_t, vfloat32m1_t, vfloat32m1_t, vfloat32m1_t, const float *, vuint64m2_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vloxseg3ei64_v)))
void vloxseg3ei64_v_f32m2(vfloat32m2_t *, vfloat32m2_t *, vfloat32m2_t *, const float *, vuint64m4_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vloxseg3ei64_v_m)))
void vloxseg3ei64_v_f32m2_m(vfloat32m2_t *, vfloat32m2_t *, vfloat32m2_t *, vbool16_t, vfloat32m2_t, vfloat32m2_t, vfloat32m2_t, const float *, vuint64m4_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vloxseg3ei64_v)))
void vloxseg3ei64_v_f32mf2(vfloat32mf2_t *, vfloat32mf2_t *, vfloat32mf2_t *, const float *, vuint64m1_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vloxseg3ei64_v_m)))
void vloxseg3ei64_v_f32mf2_m(vfloat32mf2_t *, vfloat32mf2_t *, vfloat32mf2_t *, vbool64_t, vfloat32mf2_t, vfloat32mf2_t, vfloat32mf2_t, const float *, vuint64m1_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vloxseg4ei64_v)))
void vloxseg4ei64_v_f32m1(vfloat32m1_t *, vfloat32m1_t *, vfloat32m1_t *, vfloat32m1_t *, const float *, vuint64m2_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vloxseg4ei64_v_m)))
void vloxseg4ei64_v_f32m1_m(vfloat32m1_t *, vfloat32m1_t *, vfloat32m1_t *, vfloat32m1_t *, vbool32_t, vfloat32m1_t, vfloat32m1_t, vfloat32m1_t, vfloat32m1_t, const float *, vuint64m2_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vloxseg4ei64_v)))
void vloxseg4ei64_v_f32m2(vfloat32m2_t *, vfloat32m2_t *, vfloat32m2_t *, vfloat32m2_t *, const float *, vuint64m4_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vloxseg4ei64_v_m)))
void vloxseg4ei64_v_f32m2_m(vfloat32m2_t *, vfloat32m2_t *, vfloat32m2_t *, vfloat32m2_t *, vbool16_t, vfloat32m2_t, vfloat32m2_t, vfloat32m2_t, vfloat32m2_t, const float *, vuint64m4_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vloxseg4ei64_v)))
void vloxseg4ei64_v_f32mf2(vfloat32mf2_t *, vfloat32mf2_t *, vfloat32mf2_t *, vfloat32mf2_t *, const float *, vuint64m1_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vloxseg4ei64_v_m)))
void vloxseg4ei64_v_f32mf2_m(vfloat32mf2_t *, vfloat32mf2_t *, vfloat32mf2_t *, vfloat32mf2_t *, vbool64_t, vfloat32mf2_t, vfloat32mf2_t, vfloat32mf2_t, vfloat32mf2_t, const float *, vuint64m1_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vloxseg5ei64_v)))
void vloxseg5ei64_v_f32m1(vfloat32m1_t *, vfloat32m1_t *, vfloat32m1_t *, vfloat32m1_t *, vfloat32m1_t *, const float *, vuint64m2_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vloxseg5ei64_v_m)))
void vloxseg5ei64_v_f32m1_m(vfloat32m1_t *, vfloat32m1_t *, vfloat32m1_t *, vfloat32m1_t *, vfloat32m1_t *, vbool32_t, vfloat32m1_t, vfloat32m1_t, vfloat32m1_t, vfloat32m1_t, vfloat32m1_t, const float *, vuint64m2_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vloxseg5ei64_v)))
void vloxseg5ei64_v_f32mf2(vfloat32mf2_t *, vfloat32mf2_t *, vfloat32mf2_t *, vfloat32mf2_t *, vfloat32mf2_t *, const float *, vuint64m1_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vloxseg5ei64_v_m)))
void vloxseg5ei64_v_f32mf2_m(vfloat32mf2_t *, vfloat32mf2_t *, vfloat32mf2_t *, vfloat32mf2_t *, vfloat32mf2_t *, vbool64_t, vfloat32mf2_t, vfloat32mf2_t, vfloat32mf2_t, vfloat32mf2_t, vfloat32mf2_t, const float *, vuint64m1_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vloxseg6ei64_v)))
void vloxseg6ei64_v_f32m1(vfloat32m1_t *, vfloat32m1_t *, vfloat32m1_t *, vfloat32m1_t *, vfloat32m1_t *, vfloat32m1_t *, const float *, vuint64m2_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vloxseg6ei64_v_m)))
void vloxseg6ei64_v_f32m1_m(vfloat32m1_t *, vfloat32m1_t *, vfloat32m1_t *, vfloat32m1_t *, vfloat32m1_t *, vfloat32m1_t *, vbool32_t, vfloat32m1_t, vfloat32m1_t, vfloat32m1_t, vfloat32m1_t, vfloat32m1_t, vfloat32m1_t, const float *, vuint64m2_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vloxseg6ei64_v)))
void vloxseg6ei64_v_f32mf2(vfloat32mf2_t *, vfloat32mf2_t *, vfloat32mf2_t *, vfloat32mf2_t *, vfloat32mf2_t *, vfloat32mf2_t *, const float *, vuint64m1_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vloxseg6ei64_v_m)))
void vloxseg6ei64_v_f32mf2_m(vfloat32mf2_t *, vfloat32mf2_t *, vfloat32mf2_t *, vfloat32mf2_t *, vfloat32mf2_t *, vfloat32mf2_t *, vbool64_t, vfloat32mf2_t, vfloat32mf2_t, vfloat32mf2_t, vfloat32mf2_t, vfloat32mf2_t, vfloat32mf2_t, const float *, vuint64m1_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vloxseg7ei64_v)))
void vloxseg7ei64_v_f32m1(vfloat32m1_t *, vfloat32m1_t *, vfloat32m1_t *, vfloat32m1_t *, vfloat32m1_t *, vfloat32m1_t *, vfloat32m1_t *, const float *, vuint64m2_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vloxseg7ei64_v_m)))
void vloxseg7ei64_v_f32m1_m(vfloat32m1_t *, vfloat32m1_t *, vfloat32m1_t *, vfloat32m1_t *, vfloat32m1_t *, vfloat32m1_t *, vfloat32m1_t *, vbool32_t, vfloat32m1_t, vfloat32m1_t, vfloat32m1_t, vfloat32m1_t, vfloat32m1_t, vfloat32m1_t, vfloat32m1_t, const float *, vuint64m2_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vloxseg7ei64_v)))
void vloxseg7ei64_v_f32mf2(vfloat32mf2_t *, vfloat32mf2_t *, vfloat32mf2_t *, vfloat32mf2_t *, vfloat32mf2_t *, vfloat32mf2_t *, vfloat32mf2_t *, const float *, vuint64m1_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vloxseg7ei64_v_m)))
void vloxseg7ei64_v_f32mf2_m(vfloat32mf2_t *, vfloat32mf2_t *, vfloat32mf2_t *, vfloat32mf2_t *, vfloat32mf2_t *, vfloat32mf2_t *, vfloat32mf2_t *, vbool64_t, vfloat32mf2_t, vfloat32mf2_t, vfloat32mf2_t, vfloat32mf2_t, vfloat32mf2_t, vfloat32mf2_t, vfloat32mf2_t, const float *, vuint64m1_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vloxseg8ei64_v)))
void vloxseg8ei64_v_f32m1(vfloat32m1_t *, vfloat32m1_t *, vfloat32m1_t *, vfloat32m1_t *, vfloat32m1_t *, vfloat32m1_t *, vfloat32m1_t *, vfloat32m1_t *, const float *, vuint64m2_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vloxseg8ei64_v_m)))
void vloxseg8ei64_v_f32m1_m(vfloat32m1_t *, vfloat32m1_t *, vfloat32m1_t *, vfloat32m1_t *, vfloat32m1_t *, vfloat32m1_t *, vfloat32m1_t *, vfloat32m1_t *, vbool32_t, vfloat32m1_t, vfloat32m1_t, vfloat32m1_t, vfloat32m1_t, vfloat32m1_t, vfloat32m1_t, vfloat32m1_t, vfloat32m1_t, const float *, vuint64m2_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vloxseg8ei64_v)))
void vloxseg8ei64_v_f32mf2(vfloat32mf2_t *, vfloat32mf2_t *, vfloat32mf2_t *, vfloat32mf2_t *, vfloat32mf2_t *, vfloat32mf2_t *, vfloat32mf2_t *, vfloat32mf2_t *, const float *, vuint64m1_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vloxseg8ei64_v_m)))
void vloxseg8ei64_v_f32mf2_m(vfloat32mf2_t *, vfloat32mf2_t *, vfloat32mf2_t *, vfloat32mf2_t *, vfloat32mf2_t *, vfloat32mf2_t *, vfloat32mf2_t *, vfloat32mf2_t *, vbool64_t, vfloat32mf2_t, vfloat32mf2_t, vfloat32mf2_t, vfloat32mf2_t, vfloat32mf2_t, vfloat32mf2_t, vfloat32mf2_t, vfloat32mf2_t, const float *, vuint64m1_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vsuxseg2ei64_v)))
void vsuxseg2ei64_v_f32m1(float *, vuint64m2_t, vfloat32m1_t, vfloat32m1_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vsuxseg2ei64_v_m)))
void vsuxseg2ei64_v_f32m1_m(vbool32_t, float *, vuint64m2_t, vfloat32m1_t, vfloat32m1_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vsuxseg2ei64_v)))
void vsuxseg2ei64_v_f32m2(float *, vuint64m4_t, vfloat32m2_t, vfloat32m2_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vsuxseg2ei64_v_m)))
void vsuxseg2ei64_v_f32m2_m(vbool16_t, float *, vuint64m4_t, vfloat32m2_t, vfloat32m2_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vsuxseg2ei64_v)))
void vsuxseg2ei64_v_f32m4(float *, vuint64m8_t, vfloat32m4_t, vfloat32m4_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vsuxseg2ei64_v_m)))
void vsuxseg2ei64_v_f32m4_m(vbool8_t, float *, vuint64m8_t, vfloat32m4_t, vfloat32m4_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vsuxseg2ei64_v)))
void vsuxseg2ei64_v_f32mf2(float *, vuint64m1_t, vfloat32mf2_t, vfloat32mf2_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vsuxseg2ei64_v_m)))
void vsuxseg2ei64_v_f32mf2_m(vbool64_t, float *, vuint64m1_t, vfloat32mf2_t, vfloat32mf2_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vsuxseg3ei64_v)))
void vsuxseg3ei64_v_f32m1(float *, vuint64m2_t, vfloat32m1_t, vfloat32m1_t, vfloat32m1_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vsuxseg3ei64_v_m)))
void vsuxseg3ei64_v_f32m1_m(vbool32_t, float *, vuint64m2_t, vfloat32m1_t, vfloat32m1_t, vfloat32m1_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vsuxseg3ei64_v)))
void vsuxseg3ei64_v_f32m2(float *, vuint64m4_t, vfloat32m2_t, vfloat32m2_t, vfloat32m2_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vsuxseg3ei64_v_m)))
void vsuxseg3ei64_v_f32m2_m(vbool16_t, float *, vuint64m4_t, vfloat32m2_t, vfloat32m2_t, vfloat32m2_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vsuxseg3ei64_v)))
void vsuxseg3ei64_v_f32mf2(float *, vuint64m1_t, vfloat32mf2_t, vfloat32mf2_t, vfloat32mf2_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vsuxseg3ei64_v_m)))
void vsuxseg3ei64_v_f32mf2_m(vbool64_t, float *, vuint64m1_t, vfloat32mf2_t, vfloat32mf2_t, vfloat32mf2_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vsuxseg4ei64_v)))
void vsuxseg4ei64_v_f32m1(float *, vuint64m2_t, vfloat32m1_t, vfloat32m1_t, vfloat32m1_t, vfloat32m1_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vsuxseg4ei64_v_m)))
void vsuxseg4ei64_v_f32m1_m(vbool32_t, float *, vuint64m2_t, vfloat32m1_t, vfloat32m1_t, vfloat32m1_t, vfloat32m1_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vsuxseg4ei64_v)))
void vsuxseg4ei64_v_f32m2(float *, vuint64m4_t, vfloat32m2_t, vfloat32m2_t, vfloat32m2_t, vfloat32m2_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vsuxseg4ei64_v_m)))
void vsuxseg4ei64_v_f32m2_m(vbool16_t, float *, vuint64m4_t, vfloat32m2_t, vfloat32m2_t, vfloat32m2_t, vfloat32m2_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vsuxseg4ei64_v)))
void vsuxseg4ei64_v_f32mf2(float *, vuint64m1_t, vfloat32mf2_t, vfloat32mf2_t, vfloat32mf2_t, vfloat32mf2_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vsuxseg4ei64_v_m)))
void vsuxseg4ei64_v_f32mf2_m(vbool64_t, float *, vuint64m1_t, vfloat32mf2_t, vfloat32mf2_t, vfloat32mf2_t, vfloat32mf2_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vsuxseg5ei64_v)))
void vsuxseg5ei64_v_f32m1(float *, vuint64m2_t, vfloat32m1_t, vfloat32m1_t, vfloat32m1_t, vfloat32m1_t, vfloat32m1_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vsuxseg5ei64_v_m)))
void vsuxseg5ei64_v_f32m1_m(vbool32_t, float *, vuint64m2_t, vfloat32m1_t, vfloat32m1_t, vfloat32m1_t, vfloat32m1_t, vfloat32m1_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vsuxseg5ei64_v)))
void vsuxseg5ei64_v_f32mf2(float *, vuint64m1_t, vfloat32mf2_t, vfloat32mf2_t, vfloat32mf2_t, vfloat32mf2_t, vfloat32mf2_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vsuxseg5ei64_v_m)))
void vsuxseg5ei64_v_f32mf2_m(vbool64_t, float *, vuint64m1_t, vfloat32mf2_t, vfloat32mf2_t, vfloat32mf2_t, vfloat32mf2_t, vfloat32mf2_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vsuxseg6ei64_v)))
void vsuxseg6ei64_v_f32m1(float *, vuint64m2_t, vfloat32m1_t, vfloat32m1_t, vfloat32m1_t, vfloat32m1_t, vfloat32m1_t, vfloat32m1_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vsuxseg6ei64_v_m)))
void vsuxseg6ei64_v_f32m1_m(vbool32_t, float *, vuint64m2_t, vfloat32m1_t, vfloat32m1_t, vfloat32m1_t, vfloat32m1_t, vfloat32m1_t, vfloat32m1_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vsuxseg6ei64_v)))
void vsuxseg6ei64_v_f32mf2(float *, vuint64m1_t, vfloat32mf2_t, vfloat32mf2_t, vfloat32mf2_t, vfloat32mf2_t, vfloat32mf2_t, vfloat32mf2_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vsuxseg6ei64_v_m)))
void vsuxseg6ei64_v_f32mf2_m(vbool64_t, float *, vuint64m1_t, vfloat32mf2_t, vfloat32mf2_t, vfloat32mf2_t, vfloat32mf2_t, vfloat32mf2_t, vfloat32mf2_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vsuxseg7ei64_v)))
void vsuxseg7ei64_v_f32m1(float *, vuint64m2_t, vfloat32m1_t, vfloat32m1_t, vfloat32m1_t, vfloat32m1_t, vfloat32m1_t, vfloat32m1_t, vfloat32m1_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vsuxseg7ei64_v_m)))
void vsuxseg7ei64_v_f32m1_m(vbool32_t, float *, vuint64m2_t, vfloat32m1_t, vfloat32m1_t, vfloat32m1_t, vfloat32m1_t, vfloat32m1_t, vfloat32m1_t, vfloat32m1_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vsuxseg7ei64_v)))
void vsuxseg7ei64_v_f32mf2(float *, vuint64m1_t, vfloat32mf2_t, vfloat32mf2_t, vfloat32mf2_t, vfloat32mf2_t, vfloat32mf2_t, vfloat32mf2_t, vfloat32mf2_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vsuxseg7ei64_v_m)))
void vsuxseg7ei64_v_f32mf2_m(vbool64_t, float *, vuint64m1_t, vfloat32mf2_t, vfloat32mf2_t, vfloat32mf2_t, vfloat32mf2_t, vfloat32mf2_t, vfloat32mf2_t, vfloat32mf2_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vsuxseg8ei64_v)))
void vsuxseg8ei64_v_f32m1(float *, vuint64m2_t, vfloat32m1_t, vfloat32m1_t, vfloat32m1_t, vfloat32m1_t, vfloat32m1_t, vfloat32m1_t, vfloat32m1_t, vfloat32m1_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vsuxseg8ei64_v_m)))
void vsuxseg8ei64_v_f32m1_m(vbool32_t, float *, vuint64m2_t, vfloat32m1_t, vfloat32m1_t, vfloat32m1_t, vfloat32m1_t, vfloat32m1_t, vfloat32m1_t, vfloat32m1_t, vfloat32m1_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vsuxseg8ei64_v)))
void vsuxseg8ei64_v_f32mf2(float *, vuint64m1_t, vfloat32mf2_t, vfloat32mf2_t, vfloat32mf2_t, vfloat32mf2_t, vfloat32mf2_t, vfloat32mf2_t, vfloat32mf2_t, vfloat32mf2_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vsuxseg8ei64_v_m)))
void vsuxseg8ei64_v_f32mf2_m(vbool64_t, float *, vuint64m1_t, vfloat32mf2_t, vfloat32mf2_t, vfloat32mf2_t, vfloat32mf2_t, vfloat32mf2_t, vfloat32mf2_t, vfloat32mf2_t, vfloat32mf2_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vsoxseg2ei64_v)))
void vsoxseg2ei64_v_f32m1(float *, vuint64m2_t, vfloat32m1_t, vfloat32m1_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vsoxseg2ei64_v_m)))
void vsoxseg2ei64_v_f32m1_m(vbool32_t, float *, vuint64m2_t, vfloat32m1_t, vfloat32m1_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vsoxseg2ei64_v)))
void vsoxseg2ei64_v_f32m2(float *, vuint64m4_t, vfloat32m2_t, vfloat32m2_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vsoxseg2ei64_v_m)))
void vsoxseg2ei64_v_f32m2_m(vbool16_t, float *, vuint64m4_t, vfloat32m2_t, vfloat32m2_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vsoxseg2ei64_v)))
void vsoxseg2ei64_v_f32m4(float *, vuint64m8_t, vfloat32m4_t, vfloat32m4_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vsoxseg2ei64_v_m)))
void vsoxseg2ei64_v_f32m4_m(vbool8_t, float *, vuint64m8_t, vfloat32m4_t, vfloat32m4_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vsoxseg2ei64_v)))
void vsoxseg2ei64_v_f32mf2(float *, vuint64m1_t, vfloat32mf2_t, vfloat32mf2_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vsoxseg2ei64_v_m)))
void vsoxseg2ei64_v_f32mf2_m(vbool64_t, float *, vuint64m1_t, vfloat32mf2_t, vfloat32mf2_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vsoxseg3ei64_v)))
void vsoxseg3ei64_v_f32m1(float *, vuint64m2_t, vfloat32m1_t, vfloat32m1_t, vfloat32m1_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vsoxseg3ei64_v_m)))
void vsoxseg3ei64_v_f32m1_m(vbool32_t, float *, vuint64m2_t, vfloat32m1_t, vfloat32m1_t, vfloat32m1_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vsoxseg3ei64_v)))
void vsoxseg3ei64_v_f32m2(float *, vuint64m4_t, vfloat32m2_t, vfloat32m2_t, vfloat32m2_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vsoxseg3ei64_v_m)))
void vsoxseg3ei64_v_f32m2_m(vbool16_t, float *, vuint64m4_t, vfloat32m2_t, vfloat32m2_t, vfloat32m2_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vsoxseg3ei64_v)))
void vsoxseg3ei64_v_f32mf2(float *, vuint64m1_t, vfloat32mf2_t, vfloat32mf2_t, vfloat32mf2_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vsoxseg3ei64_v_m)))
void vsoxseg3ei64_v_f32mf2_m(vbool64_t, float *, vuint64m1_t, vfloat32mf2_t, vfloat32mf2_t, vfloat32mf2_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vsoxseg4ei64_v)))
void vsoxseg4ei64_v_f32m1(float *, vuint64m2_t, vfloat32m1_t, vfloat32m1_t, vfloat32m1_t, vfloat32m1_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vsoxseg4ei64_v_m)))
void vsoxseg4ei64_v_f32m1_m(vbool32_t, float *, vuint64m2_t, vfloat32m1_t, vfloat32m1_t, vfloat32m1_t, vfloat32m1_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vsoxseg4ei64_v)))
void vsoxseg4ei64_v_f32m2(float *, vuint64m4_t, vfloat32m2_t, vfloat32m2_t, vfloat32m2_t, vfloat32m2_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vsoxseg4ei64_v_m)))
void vsoxseg4ei64_v_f32m2_m(vbool16_t, float *, vuint64m4_t, vfloat32m2_t, vfloat32m2_t, vfloat32m2_t, vfloat32m2_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vsoxseg4ei64_v)))
void vsoxseg4ei64_v_f32mf2(float *, vuint64m1_t, vfloat32mf2_t, vfloat32mf2_t, vfloat32mf2_t, vfloat32mf2_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vsoxseg4ei64_v_m)))
void vsoxseg4ei64_v_f32mf2_m(vbool64_t, float *, vuint64m1_t, vfloat32mf2_t, vfloat32mf2_t, vfloat32mf2_t, vfloat32mf2_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vsoxseg5ei64_v)))
void vsoxseg5ei64_v_f32m1(float *, vuint64m2_t, vfloat32m1_t, vfloat32m1_t, vfloat32m1_t, vfloat32m1_t, vfloat32m1_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vsoxseg5ei64_v_m)))
void vsoxseg5ei64_v_f32m1_m(vbool32_t, float *, vuint64m2_t, vfloat32m1_t, vfloat32m1_t, vfloat32m1_t, vfloat32m1_t, vfloat32m1_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vsoxseg5ei64_v)))
void vsoxseg5ei64_v_f32mf2(float *, vuint64m1_t, vfloat32mf2_t, vfloat32mf2_t, vfloat32mf2_t, vfloat32mf2_t, vfloat32mf2_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vsoxseg5ei64_v_m)))
void vsoxseg5ei64_v_f32mf2_m(vbool64_t, float *, vuint64m1_t, vfloat32mf2_t, vfloat32mf2_t, vfloat32mf2_t, vfloat32mf2_t, vfloat32mf2_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vsoxseg6ei64_v)))
void vsoxseg6ei64_v_f32m1(float *, vuint64m2_t, vfloat32m1_t, vfloat32m1_t, vfloat32m1_t, vfloat32m1_t, vfloat32m1_t, vfloat32m1_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vsoxseg6ei64_v_m)))
void vsoxseg6ei64_v_f32m1_m(vbool32_t, float *, vuint64m2_t, vfloat32m1_t, vfloat32m1_t, vfloat32m1_t, vfloat32m1_t, vfloat32m1_t, vfloat32m1_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vsoxseg6ei64_v)))
void vsoxseg6ei64_v_f32mf2(float *, vuint64m1_t, vfloat32mf2_t, vfloat32mf2_t, vfloat32mf2_t, vfloat32mf2_t, vfloat32mf2_t, vfloat32mf2_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vsoxseg6ei64_v_m)))
void vsoxseg6ei64_v_f32mf2_m(vbool64_t, float *, vuint64m1_t, vfloat32mf2_t, vfloat32mf2_t, vfloat32mf2_t, vfloat32mf2_t, vfloat32mf2_t, vfloat32mf2_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vsoxseg7ei64_v)))
void vsoxseg7ei64_v_f32m1(float *, vuint64m2_t, vfloat32m1_t, vfloat32m1_t, vfloat32m1_t, vfloat32m1_t, vfloat32m1_t, vfloat32m1_t, vfloat32m1_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vsoxseg7ei64_v_m)))
void vsoxseg7ei64_v_f32m1_m(vbool32_t, float *, vuint64m2_t, vfloat32m1_t, vfloat32m1_t, vfloat32m1_t, vfloat32m1_t, vfloat32m1_t, vfloat32m1_t, vfloat32m1_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vsoxseg7ei64_v)))
void vsoxseg7ei64_v_f32mf2(float *, vuint64m1_t, vfloat32mf2_t, vfloat32mf2_t, vfloat32mf2_t, vfloat32mf2_t, vfloat32mf2_t, vfloat32mf2_t, vfloat32mf2_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vsoxseg7ei64_v_m)))
void vsoxseg7ei64_v_f32mf2_m(vbool64_t, float *, vuint64m1_t, vfloat32mf2_t, vfloat32mf2_t, vfloat32mf2_t, vfloat32mf2_t, vfloat32mf2_t, vfloat32mf2_t, vfloat32mf2_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vsoxseg8ei64_v)))
void vsoxseg8ei64_v_f32m1(float *, vuint64m2_t, vfloat32m1_t, vfloat32m1_t, vfloat32m1_t, vfloat32m1_t, vfloat32m1_t, vfloat32m1_t, vfloat32m1_t, vfloat32m1_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vsoxseg8ei64_v_m)))
void vsoxseg8ei64_v_f32m1_m(vbool32_t, float *, vuint64m2_t, vfloat32m1_t, vfloat32m1_t, vfloat32m1_t, vfloat32m1_t, vfloat32m1_t, vfloat32m1_t, vfloat32m1_t, vfloat32m1_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vsoxseg8ei64_v)))
void vsoxseg8ei64_v_f32mf2(float *, vuint64m1_t, vfloat32mf2_t, vfloat32mf2_t, vfloat32mf2_t, vfloat32mf2_t, vfloat32mf2_t, vfloat32mf2_t, vfloat32mf2_t, vfloat32mf2_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vsoxseg8ei64_v_m)))
void vsoxseg8ei64_v_f32mf2_m(vbool64_t, float *, vuint64m1_t, vfloat32mf2_t, vfloat32mf2_t, vfloat32mf2_t, vfloat32mf2_t, vfloat32mf2_t, vfloat32mf2_t, vfloat32mf2_t, vfloat32mf2_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vluxseg2ei64_v)))
void vluxseg2ei64_v_f32m1(vfloat32m1_t *, vfloat32m1_t *, const float *, vuint64m2_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vluxseg2ei64_v_m)))
void vluxseg2ei64_v_f32m1_m(vfloat32m1_t *, vfloat32m1_t *, vbool32_t, vfloat32m1_t, vfloat32m1_t, const float *, vuint64m2_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vluxseg2ei64_v)))
void vluxseg2ei64_v_f32m2(vfloat32m2_t *, vfloat32m2_t *, const float *, vuint64m4_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vluxseg2ei64_v_m)))
void vluxseg2ei64_v_f32m2_m(vfloat32m2_t *, vfloat32m2_t *, vbool16_t, vfloat32m2_t, vfloat32m2_t, const float *, vuint64m4_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vluxseg2ei64_v)))
void vluxseg2ei64_v_f32m4(vfloat32m4_t *, vfloat32m4_t *, const float *, vuint64m8_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vluxseg2ei64_v_m)))
void vluxseg2ei64_v_f32m4_m(vfloat32m4_t *, vfloat32m4_t *, vbool8_t, vfloat32m4_t, vfloat32m4_t, const float *, vuint64m8_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vluxseg2ei64_v)))
void vluxseg2ei64_v_f32mf2(vfloat32mf2_t *, vfloat32mf2_t *, const float *, vuint64m1_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vluxseg2ei64_v_m)))
void vluxseg2ei64_v_f32mf2_m(vfloat32mf2_t *, vfloat32mf2_t *, vbool64_t, vfloat32mf2_t, vfloat32mf2_t, const float *, vuint64m1_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vluxseg3ei64_v)))
void vluxseg3ei64_v_f32m1(vfloat32m1_t *, vfloat32m1_t *, vfloat32m1_t *, const float *, vuint64m2_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vluxseg3ei64_v_m)))
void vluxseg3ei64_v_f32m1_m(vfloat32m1_t *, vfloat32m1_t *, vfloat32m1_t *, vbool32_t, vfloat32m1_t, vfloat32m1_t, vfloat32m1_t, const float *, vuint64m2_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vluxseg3ei64_v)))
void vluxseg3ei64_v_f32m2(vfloat32m2_t *, vfloat32m2_t *, vfloat32m2_t *, const float *, vuint64m4_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vluxseg3ei64_v_m)))
void vluxseg3ei64_v_f32m2_m(vfloat32m2_t *, vfloat32m2_t *, vfloat32m2_t *, vbool16_t, vfloat32m2_t, vfloat32m2_t, vfloat32m2_t, const float *, vuint64m4_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vluxseg3ei64_v)))
void vluxseg3ei64_v_f32mf2(vfloat32mf2_t *, vfloat32mf2_t *, vfloat32mf2_t *, const float *, vuint64m1_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vluxseg3ei64_v_m)))
void vluxseg3ei64_v_f32mf2_m(vfloat32mf2_t *, vfloat32mf2_t *, vfloat32mf2_t *, vbool64_t, vfloat32mf2_t, vfloat32mf2_t, vfloat32mf2_t, const float *, vuint64m1_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vluxseg4ei64_v)))
void vluxseg4ei64_v_f32m1(vfloat32m1_t *, vfloat32m1_t *, vfloat32m1_t *, vfloat32m1_t *, const float *, vuint64m2_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vluxseg4ei64_v_m)))
void vluxseg4ei64_v_f32m1_m(vfloat32m1_t *, vfloat32m1_t *, vfloat32m1_t *, vfloat32m1_t *, vbool32_t, vfloat32m1_t, vfloat32m1_t, vfloat32m1_t, vfloat32m1_t, const float *, vuint64m2_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vluxseg4ei64_v)))
void vluxseg4ei64_v_f32m2(vfloat32m2_t *, vfloat32m2_t *, vfloat32m2_t *, vfloat32m2_t *, const float *, vuint64m4_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vluxseg4ei64_v_m)))
void vluxseg4ei64_v_f32m2_m(vfloat32m2_t *, vfloat32m2_t *, vfloat32m2_t *, vfloat32m2_t *, vbool16_t, vfloat32m2_t, vfloat32m2_t, vfloat32m2_t, vfloat32m2_t, const float *, vuint64m4_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vluxseg4ei64_v)))
void vluxseg4ei64_v_f32mf2(vfloat32mf2_t *, vfloat32mf2_t *, vfloat32mf2_t *, vfloat32mf2_t *, const float *, vuint64m1_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vluxseg4ei64_v_m)))
void vluxseg4ei64_v_f32mf2_m(vfloat32mf2_t *, vfloat32mf2_t *, vfloat32mf2_t *, vfloat32mf2_t *, vbool64_t, vfloat32mf2_t, vfloat32mf2_t, vfloat32mf2_t, vfloat32mf2_t, const float *, vuint64m1_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vluxseg5ei64_v)))
void vluxseg5ei64_v_f32m1(vfloat32m1_t *, vfloat32m1_t *, vfloat32m1_t *, vfloat32m1_t *, vfloat32m1_t *, const float *, vuint64m2_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vluxseg5ei64_v_m)))
void vluxseg5ei64_v_f32m1_m(vfloat32m1_t *, vfloat32m1_t *, vfloat32m1_t *, vfloat32m1_t *, vfloat32m1_t *, vbool32_t, vfloat32m1_t, vfloat32m1_t, vfloat32m1_t, vfloat32m1_t, vfloat32m1_t, const float *, vuint64m2_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vluxseg5ei64_v)))
void vluxseg5ei64_v_f32mf2(vfloat32mf2_t *, vfloat32mf2_t *, vfloat32mf2_t *, vfloat32mf2_t *, vfloat32mf2_t *, const float *, vuint64m1_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vluxseg5ei64_v_m)))
void vluxseg5ei64_v_f32mf2_m(vfloat32mf2_t *, vfloat32mf2_t *, vfloat32mf2_t *, vfloat32mf2_t *, vfloat32mf2_t *, vbool64_t, vfloat32mf2_t, vfloat32mf2_t, vfloat32mf2_t, vfloat32mf2_t, vfloat32mf2_t, const float *, vuint64m1_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vluxseg6ei64_v)))
void vluxseg6ei64_v_f32m1(vfloat32m1_t *, vfloat32m1_t *, vfloat32m1_t *, vfloat32m1_t *, vfloat32m1_t *, vfloat32m1_t *, const float *, vuint64m2_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vluxseg6ei64_v_m)))
void vluxseg6ei64_v_f32m1_m(vfloat32m1_t *, vfloat32m1_t *, vfloat32m1_t *, vfloat32m1_t *, vfloat32m1_t *, vfloat32m1_t *, vbool32_t, vfloat32m1_t, vfloat32m1_t, vfloat32m1_t, vfloat32m1_t, vfloat32m1_t, vfloat32m1_t, const float *, vuint64m2_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vluxseg6ei64_v)))
void vluxseg6ei64_v_f32mf2(vfloat32mf2_t *, vfloat32mf2_t *, vfloat32mf2_t *, vfloat32mf2_t *, vfloat32mf2_t *, vfloat32mf2_t *, const float *, vuint64m1_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vluxseg6ei64_v_m)))
void vluxseg6ei64_v_f32mf2_m(vfloat32mf2_t *, vfloat32mf2_t *, vfloat32mf2_t *, vfloat32mf2_t *, vfloat32mf2_t *, vfloat32mf2_t *, vbool64_t, vfloat32mf2_t, vfloat32mf2_t, vfloat32mf2_t, vfloat32mf2_t, vfloat32mf2_t, vfloat32mf2_t, const float *, vuint64m1_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vluxseg7ei64_v)))
void vluxseg7ei64_v_f32m1(vfloat32m1_t *, vfloat32m1_t *, vfloat32m1_t *, vfloat32m1_t *, vfloat32m1_t *, vfloat32m1_t *, vfloat32m1_t *, const float *, vuint64m2_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vluxseg7ei64_v_m)))
void vluxseg7ei64_v_f32m1_m(vfloat32m1_t *, vfloat32m1_t *, vfloat32m1_t *, vfloat32m1_t *, vfloat32m1_t *, vfloat32m1_t *, vfloat32m1_t *, vbool32_t, vfloat32m1_t, vfloat32m1_t, vfloat32m1_t, vfloat32m1_t, vfloat32m1_t, vfloat32m1_t, vfloat32m1_t, const float *, vuint64m2_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vluxseg7ei64_v)))
void vluxseg7ei64_v_f32mf2(vfloat32mf2_t *, vfloat32mf2_t *, vfloat32mf2_t *, vfloat32mf2_t *, vfloat32mf2_t *, vfloat32mf2_t *, vfloat32mf2_t *, const float *, vuint64m1_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vluxseg7ei64_v_m)))
void vluxseg7ei64_v_f32mf2_m(vfloat32mf2_t *, vfloat32mf2_t *, vfloat32mf2_t *, vfloat32mf2_t *, vfloat32mf2_t *, vfloat32mf2_t *, vfloat32mf2_t *, vbool64_t, vfloat32mf2_t, vfloat32mf2_t, vfloat32mf2_t, vfloat32mf2_t, vfloat32mf2_t, vfloat32mf2_t, vfloat32mf2_t, const float *, vuint64m1_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vluxseg8ei64_v)))
void vluxseg8ei64_v_f32m1(vfloat32m1_t *, vfloat32m1_t *, vfloat32m1_t *, vfloat32m1_t *, vfloat32m1_t *, vfloat32m1_t *, vfloat32m1_t *, vfloat32m1_t *, const float *, vuint64m2_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vluxseg8ei64_v_m)))
void vluxseg8ei64_v_f32m1_m(vfloat32m1_t *, vfloat32m1_t *, vfloat32m1_t *, vfloat32m1_t *, vfloat32m1_t *, vfloat32m1_t *, vfloat32m1_t *, vfloat32m1_t *, vbool32_t, vfloat32m1_t, vfloat32m1_t, vfloat32m1_t, vfloat32m1_t, vfloat32m1_t, vfloat32m1_t, vfloat32m1_t, vfloat32m1_t, const float *, vuint64m2_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vluxseg8ei64_v)))
void vluxseg8ei64_v_f32mf2(vfloat32mf2_t *, vfloat32mf2_t *, vfloat32mf2_t *, vfloat32mf2_t *, vfloat32mf2_t *, vfloat32mf2_t *, vfloat32mf2_t *, vfloat32mf2_t *, const float *, vuint64m1_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vluxseg8ei64_v_m)))
void vluxseg8ei64_v_f32mf2_m(vfloat32mf2_t *, vfloat32mf2_t *, vfloat32mf2_t *, vfloat32mf2_t *, vfloat32mf2_t *, vfloat32mf2_t *, vfloat32mf2_t *, vfloat32mf2_t *, vbool64_t, vfloat32mf2_t, vfloat32mf2_t, vfloat32mf2_t, vfloat32mf2_t, vfloat32mf2_t, vfloat32mf2_t, vfloat32mf2_t, vfloat32mf2_t, const float *, vuint64m1_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vfncvt_f_x_w)))
vfloat32mf2_t vfncvt_f_x_w_f32mf2(vint64m1_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vfncvt_f_x_w_m)))
vfloat32mf2_t vfncvt_f_x_w_f32mf2_m(vbool64_t, vfloat32mf2_t, vint64m1_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vfncvt_f_x_w)))
vfloat32m1_t vfncvt_f_x_w_f32m1(vint64m2_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vfncvt_f_x_w_m)))
vfloat32m1_t vfncvt_f_x_w_f32m1_m(vbool32_t, vfloat32m1_t, vint64m2_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vfncvt_f_x_w)))
vfloat32m2_t vfncvt_f_x_w_f32m2(vint64m4_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vfncvt_f_x_w_m)))
vfloat32m2_t vfncvt_f_x_w_f32m2_m(vbool16_t, vfloat32m2_t, vint64m4_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vfncvt_f_x_w)))
vfloat32m4_t vfncvt_f_x_w_f32m4(vint64m8_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vfncvt_f_x_w_m)))
vfloat32m4_t vfncvt_f_x_w_f32m4_m(vbool8_t, vfloat32m4_t, vint64m8_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vfncvt_f_xu_w)))
vfloat32mf2_t vfncvt_f_xu_w_f32mf2(vuint64m1_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vfncvt_f_xu_w_m)))
vfloat32mf2_t vfncvt_f_xu_w_f32mf2_m(vbool64_t, vfloat32mf2_t, vuint64m1_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vfncvt_f_xu_w)))
vfloat32m1_t vfncvt_f_xu_w_f32m1(vuint64m2_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vfncvt_f_xu_w_m)))
vfloat32m1_t vfncvt_f_xu_w_f32m1_m(vbool32_t, vfloat32m1_t, vuint64m2_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vfncvt_f_xu_w)))
vfloat32m2_t vfncvt_f_xu_w_f32m2(vuint64m4_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vfncvt_f_xu_w_m)))
vfloat32m2_t vfncvt_f_xu_w_f32m2_m(vbool16_t, vfloat32m2_t, vuint64m4_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vfncvt_f_xu_w)))
vfloat32m4_t vfncvt_f_xu_w_f32m4(vuint64m8_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vfncvt_f_xu_w_m)))
vfloat32m4_t vfncvt_f_xu_w_f32m4_m(vbool8_t, vfloat32m4_t, vuint64m8_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vfwcvt_rtz_x_f_v)))
vint64m1_t vfwcvt_rtz_x_f_v_i64m1(vfloat32mf2_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vfwcvt_rtz_x_f_v_m)))
vint64m1_t vfwcvt_rtz_x_f_v_i64m1_m(vbool64_t, vint64m1_t, vfloat32mf2_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vfwcvt_rtz_x_f_v)))
vint64m2_t vfwcvt_rtz_x_f_v_i64m2(vfloat32m1_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vfwcvt_rtz_x_f_v_m)))
vint64m2_t vfwcvt_rtz_x_f_v_i64m2_m(vbool32_t, vint64m2_t, vfloat32m1_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vfwcvt_rtz_x_f_v)))
vint64m4_t vfwcvt_rtz_x_f_v_i64m4(vfloat32m2_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vfwcvt_rtz_x_f_v_m)))
vint64m4_t vfwcvt_rtz_x_f_v_i64m4_m(vbool16_t, vint64m4_t, vfloat32m2_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vfwcvt_rtz_x_f_v)))
vint64m8_t vfwcvt_rtz_x_f_v_i64m8(vfloat32m4_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vfwcvt_rtz_x_f_v_m)))
vint64m8_t vfwcvt_rtz_x_f_v_i64m8_m(vbool8_t, vint64m8_t, vfloat32m4_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vfwcvt_rtz_xu_f_v)))
vuint64m1_t vfwcvt_rtz_xu_f_v_u64m1(vfloat32mf2_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vfwcvt_rtz_xu_f_v_m)))
vuint64m1_t vfwcvt_rtz_xu_f_v_u64m1_m(vbool64_t, vuint64m1_t, vfloat32mf2_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vfwcvt_rtz_xu_f_v)))
vuint64m2_t vfwcvt_rtz_xu_f_v_u64m2(vfloat32m1_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vfwcvt_rtz_xu_f_v_m)))
vuint64m2_t vfwcvt_rtz_xu_f_v_u64m2_m(vbool32_t, vuint64m2_t, vfloat32m1_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vfwcvt_rtz_xu_f_v)))
vuint64m4_t vfwcvt_rtz_xu_f_v_u64m4(vfloat32m2_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vfwcvt_rtz_xu_f_v_m)))
vuint64m4_t vfwcvt_rtz_xu_f_v_u64m4_m(vbool16_t, vuint64m4_t, vfloat32m2_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vfwcvt_rtz_xu_f_v)))
vuint64m8_t vfwcvt_rtz_xu_f_v_u64m8(vfloat32m4_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vfwcvt_rtz_xu_f_v_m)))
vuint64m8_t vfwcvt_rtz_xu_f_v_u64m8_m(vbool8_t, vuint64m8_t, vfloat32m4_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vfwcvt_x_f_v)))
vint64m1_t vfwcvt_x_f_v_i64m1(vfloat32mf2_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vfwcvt_x_f_v_m)))
vint64m1_t vfwcvt_x_f_v_i64m1_m(vbool64_t, vint64m1_t, vfloat32mf2_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vfwcvt_x_f_v)))
vint64m2_t vfwcvt_x_f_v_i64m2(vfloat32m1_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vfwcvt_x_f_v_m)))
vint64m2_t vfwcvt_x_f_v_i64m2_m(vbool32_t, vint64m2_t, vfloat32m1_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vfwcvt_x_f_v)))
vint64m4_t vfwcvt_x_f_v_i64m4(vfloat32m2_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vfwcvt_x_f_v_m)))
vint64m4_t vfwcvt_x_f_v_i64m4_m(vbool16_t, vint64m4_t, vfloat32m2_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vfwcvt_x_f_v)))
vint64m8_t vfwcvt_x_f_v_i64m8(vfloat32m4_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vfwcvt_x_f_v_m)))
vint64m8_t vfwcvt_x_f_v_i64m8_m(vbool8_t, vint64m8_t, vfloat32m4_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vfwcvt_xu_f_v)))
vuint64m1_t vfwcvt_xu_f_v_u64m1(vfloat32mf2_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vfwcvt_xu_f_v_m)))
vuint64m1_t vfwcvt_xu_f_v_u64m1_m(vbool64_t, vuint64m1_t, vfloat32mf2_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vfwcvt_xu_f_v)))
vuint64m2_t vfwcvt_xu_f_v_u64m2(vfloat32m1_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vfwcvt_xu_f_v_m)))
vuint64m2_t vfwcvt_xu_f_v_u64m2_m(vbool32_t, vuint64m2_t, vfloat32m1_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vfwcvt_xu_f_v)))
vuint64m4_t vfwcvt_xu_f_v_u64m4(vfloat32m2_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vfwcvt_xu_f_v_m)))
vuint64m4_t vfwcvt_xu_f_v_u64m4_m(vbool16_t, vuint64m4_t, vfloat32m2_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vfwcvt_xu_f_v)))
vuint64m8_t vfwcvt_xu_f_v_u64m8(vfloat32m4_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vfwcvt_xu_f_v_m)))
vuint64m8_t vfwcvt_xu_f_v_u64m8_m(vbool8_t, vuint64m8_t, vfloat32m4_t, size_t);
#endif

#if (__riscv_xlen == 64) && (__riscv_v_elen >= 64) && (__riscv_v_elen_fp >= 32)
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vluxei64_v)))
vfloat32m1_t vluxei64_v_f32m1(const float *, vuint64m2_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vluxei64_v_m)))
vfloat32m1_t vluxei64_v_f32m1_m(vbool32_t, vfloat32m1_t, const float *, vuint64m2_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vluxei64_v)))
vfloat32m2_t vluxei64_v_f32m2(const float *, vuint64m4_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vluxei64_v_m)))
vfloat32m2_t vluxei64_v_f32m2_m(vbool16_t, vfloat32m2_t, const float *, vuint64m4_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vluxei64_v)))
vfloat32m4_t vluxei64_v_f32m4(const float *, vuint64m8_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vluxei64_v_m)))
vfloat32m4_t vluxei64_v_f32m4_m(vbool8_t, vfloat32m4_t, const float *, vuint64m8_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vluxei64_v)))
vfloat32mf2_t vluxei64_v_f32mf2(const float *, vuint64m1_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vluxei64_v_m)))
vfloat32mf2_t vluxei64_v_f32mf2_m(vbool64_t, vfloat32mf2_t, const float *, vuint64m1_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vloxei64_v)))
vfloat32m1_t vloxei64_v_f32m1(const float *, vuint64m2_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vloxei64_v_m)))
vfloat32m1_t vloxei64_v_f32m1_m(vbool32_t, vfloat32m1_t, const float *, vuint64m2_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vloxei64_v)))
vfloat32m2_t vloxei64_v_f32m2(const float *, vuint64m4_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vloxei64_v_m)))
vfloat32m2_t vloxei64_v_f32m2_m(vbool16_t, vfloat32m2_t, const float *, vuint64m4_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vloxei64_v)))
vfloat32m4_t vloxei64_v_f32m4(const float *, vuint64m8_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vloxei64_v_m)))
vfloat32m4_t vloxei64_v_f32m4_m(vbool8_t, vfloat32m4_t, const float *, vuint64m8_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vloxei64_v)))
vfloat32mf2_t vloxei64_v_f32mf2(const float *, vuint64m1_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vloxei64_v_m)))
vfloat32mf2_t vloxei64_v_f32mf2_m(vbool64_t, vfloat32mf2_t, const float *, vuint64m1_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vsuxei64_v)))
void vsuxei64_v_f32m1(float *, vuint64m2_t, vfloat32m1_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vsuxei64_v_m)))
void vsuxei64_v_f32m1_m(vbool32_t, float *, vuint64m2_t, vfloat32m1_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vsuxei64_v)))
void vsuxei64_v_f32m2(float *, vuint64m4_t, vfloat32m2_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vsuxei64_v_m)))
void vsuxei64_v_f32m2_m(vbool16_t, float *, vuint64m4_t, vfloat32m2_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vsuxei64_v)))
void vsuxei64_v_f32m4(float *, vuint64m8_t, vfloat32m4_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vsuxei64_v_m)))
void vsuxei64_v_f32m4_m(vbool8_t, float *, vuint64m8_t, vfloat32m4_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vsuxei64_v)))
void vsuxei64_v_f32mf2(float *, vuint64m1_t, vfloat32mf2_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vsuxei64_v_m)))
void vsuxei64_v_f32mf2_m(vbool64_t, float *, vuint64m1_t, vfloat32mf2_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vsoxei64_v)))
void vsoxei64_v_f32m1(float *, vuint64m2_t, vfloat32m1_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vsoxei64_v_m)))
void vsoxei64_v_f32m1_m(vbool32_t, float *, vuint64m2_t, vfloat32m1_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vsoxei64_v)))
void vsoxei64_v_f32m2(float *, vuint64m4_t, vfloat32m2_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vsoxei64_v_m)))
void vsoxei64_v_f32m2_m(vbool16_t, float *, vuint64m4_t, vfloat32m2_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vsoxei64_v)))
void vsoxei64_v_f32m4(float *, vuint64m8_t, vfloat32m4_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vsoxei64_v_m)))
void vsoxei64_v_f32m4_m(vbool8_t, float *, vuint64m8_t, vfloat32m4_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vsoxei64_v)))
void vsoxei64_v_f32mf2(float *, vuint64m1_t, vfloat32mf2_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vsoxei64_v_m)))
void vsoxei64_v_f32mf2_m(vbool64_t, float *, vuint64m1_t, vfloat32mf2_t, size_t);
#endif

#if (__riscv_v_elen >= 64) && (__riscv_v_elen_fp >= 64)
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vlse64_v)))
vfloat64m1_t vlse64_v_f64m1(const double *, ptrdiff_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vlse64_v_m)))
vfloat64m1_t vlse64_v_f64m1_m(vbool64_t, vfloat64m1_t, const double *, ptrdiff_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vlse64_v)))
vfloat64m2_t vlse64_v_f64m2(const double *, ptrdiff_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vlse64_v_m)))
vfloat64m2_t vlse64_v_f64m2_m(vbool32_t, vfloat64m2_t, const double *, ptrdiff_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vlse64_v)))
vfloat64m4_t vlse64_v_f64m4(const double *, ptrdiff_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vlse64_v_m)))
vfloat64m4_t vlse64_v_f64m4_m(vbool16_t, vfloat64m4_t, const double *, ptrdiff_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vlse64_v)))
vfloat64m8_t vlse64_v_f64m8(const double *, ptrdiff_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vlse64_v_m)))
vfloat64m8_t vlse64_v_f64m8_m(vbool8_t, vfloat64m8_t, const double *, ptrdiff_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vloxseg2ei8_v)))
void vloxseg2ei8_v_f64m1(vfloat64m1_t *, vfloat64m1_t *, const double *, vuint8mf8_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vloxseg2ei8_v_m)))
void vloxseg2ei8_v_f64m1_m(vfloat64m1_t *, vfloat64m1_t *, vbool64_t, vfloat64m1_t, vfloat64m1_t, const double *, vuint8mf8_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vloxseg2ei8_v)))
void vloxseg2ei8_v_f64m2(vfloat64m2_t *, vfloat64m2_t *, const double *, vuint8mf4_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vloxseg2ei8_v_m)))
void vloxseg2ei8_v_f64m2_m(vfloat64m2_t *, vfloat64m2_t *, vbool32_t, vfloat64m2_t, vfloat64m2_t, const double *, vuint8mf4_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vloxseg2ei8_v)))
void vloxseg2ei8_v_f64m4(vfloat64m4_t *, vfloat64m4_t *, const double *, vuint8mf2_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vloxseg2ei8_v_m)))
void vloxseg2ei8_v_f64m4_m(vfloat64m4_t *, vfloat64m4_t *, vbool16_t, vfloat64m4_t, vfloat64m4_t, const double *, vuint8mf2_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vloxseg3ei8_v)))
void vloxseg3ei8_v_f64m1(vfloat64m1_t *, vfloat64m1_t *, vfloat64m1_t *, const double *, vuint8mf8_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vloxseg3ei8_v_m)))
void vloxseg3ei8_v_f64m1_m(vfloat64m1_t *, vfloat64m1_t *, vfloat64m1_t *, vbool64_t, vfloat64m1_t, vfloat64m1_t, vfloat64m1_t, const double *, vuint8mf8_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vloxseg3ei8_v)))
void vloxseg3ei8_v_f64m2(vfloat64m2_t *, vfloat64m2_t *, vfloat64m2_t *, const double *, vuint8mf4_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vloxseg3ei8_v_m)))
void vloxseg3ei8_v_f64m2_m(vfloat64m2_t *, vfloat64m2_t *, vfloat64m2_t *, vbool32_t, vfloat64m2_t, vfloat64m2_t, vfloat64m2_t, const double *, vuint8mf4_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vloxseg4ei8_v)))
void vloxseg4ei8_v_f64m1(vfloat64m1_t *, vfloat64m1_t *, vfloat64m1_t *, vfloat64m1_t *, const double *, vuint8mf8_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vloxseg4ei8_v_m)))
void vloxseg4ei8_v_f64m1_m(vfloat64m1_t *, vfloat64m1_t *, vfloat64m1_t *, vfloat64m1_t *, vbool64_t, vfloat64m1_t, vfloat64m1_t, vfloat64m1_t, vfloat64m1_t, const double *, vuint8mf8_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vloxseg4ei8_v)))
void vloxseg4ei8_v_f64m2(vfloat64m2_t *, vfloat64m2_t *, vfloat64m2_t *, vfloat64m2_t *, const double *, vuint8mf4_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vloxseg4ei8_v_m)))
void vloxseg4ei8_v_f64m2_m(vfloat64m2_t *, vfloat64m2_t *, vfloat64m2_t *, vfloat64m2_t *, vbool32_t, vfloat64m2_t, vfloat64m2_t, vfloat64m2_t, vfloat64m2_t, const double *, vuint8mf4_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vloxseg5ei8_v)))
void vloxseg5ei8_v_f64m1(vfloat64m1_t *, vfloat64m1_t *, vfloat64m1_t *, vfloat64m1_t *, vfloat64m1_t *, const double *, vuint8mf8_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vloxseg5ei8_v_m)))
void vloxseg5ei8_v_f64m1_m(vfloat64m1_t *, vfloat64m1_t *, vfloat64m1_t *, vfloat64m1_t *, vfloat64m1_t *, vbool64_t, vfloat64m1_t, vfloat64m1_t, vfloat64m1_t, vfloat64m1_t, vfloat64m1_t, const double *, vuint8mf8_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vloxseg6ei8_v)))
void vloxseg6ei8_v_f64m1(vfloat64m1_t *, vfloat64m1_t *, vfloat64m1_t *, vfloat64m1_t *, vfloat64m1_t *, vfloat64m1_t *, const double *, vuint8mf8_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vloxseg6ei8_v_m)))
void vloxseg6ei8_v_f64m1_m(vfloat64m1_t *, vfloat64m1_t *, vfloat64m1_t *, vfloat64m1_t *, vfloat64m1_t *, vfloat64m1_t *, vbool64_t, vfloat64m1_t, vfloat64m1_t, vfloat64m1_t, vfloat64m1_t, vfloat64m1_t, vfloat64m1_t, const double *, vuint8mf8_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vloxseg7ei8_v)))
void vloxseg7ei8_v_f64m1(vfloat64m1_t *, vfloat64m1_t *, vfloat64m1_t *, vfloat64m1_t *, vfloat64m1_t *, vfloat64m1_t *, vfloat64m1_t *, const double *, vuint8mf8_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vloxseg7ei8_v_m)))
void vloxseg7ei8_v_f64m1_m(vfloat64m1_t *, vfloat64m1_t *, vfloat64m1_t *, vfloat64m1_t *, vfloat64m1_t *, vfloat64m1_t *, vfloat64m1_t *, vbool64_t, vfloat64m1_t, vfloat64m1_t, vfloat64m1_t, vfloat64m1_t, vfloat64m1_t, vfloat64m1_t, vfloat64m1_t, const double *, vuint8mf8_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vloxseg8ei8_v)))
void vloxseg8ei8_v_f64m1(vfloat64m1_t *, vfloat64m1_t *, vfloat64m1_t *, vfloat64m1_t *, vfloat64m1_t *, vfloat64m1_t *, vfloat64m1_t *, vfloat64m1_t *, const double *, vuint8mf8_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vloxseg8ei8_v_m)))
void vloxseg8ei8_v_f64m1_m(vfloat64m1_t *, vfloat64m1_t *, vfloat64m1_t *, vfloat64m1_t *, vfloat64m1_t *, vfloat64m1_t *, vfloat64m1_t *, vfloat64m1_t *, vbool64_t, vfloat64m1_t, vfloat64m1_t, vfloat64m1_t, vfloat64m1_t, vfloat64m1_t, vfloat64m1_t, vfloat64m1_t, vfloat64m1_t, const double *, vuint8mf8_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vloxseg2ei16_v)))
void vloxseg2ei16_v_f64m1(vfloat64m1_t *, vfloat64m1_t *, const double *, vuint16mf4_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vloxseg2ei16_v_m)))
void vloxseg2ei16_v_f64m1_m(vfloat64m1_t *, vfloat64m1_t *, vbool64_t, vfloat64m1_t, vfloat64m1_t, const double *, vuint16mf4_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vloxseg2ei16_v)))
void vloxseg2ei16_v_f64m2(vfloat64m2_t *, vfloat64m2_t *, const double *, vuint16mf2_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vloxseg2ei16_v_m)))
void vloxseg2ei16_v_f64m2_m(vfloat64m2_t *, vfloat64m2_t *, vbool32_t, vfloat64m2_t, vfloat64m2_t, const double *, vuint16mf2_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vloxseg2ei16_v)))
void vloxseg2ei16_v_f64m4(vfloat64m4_t *, vfloat64m4_t *, const double *, vuint16m1_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vloxseg2ei16_v_m)))
void vloxseg2ei16_v_f64m4_m(vfloat64m4_t *, vfloat64m4_t *, vbool16_t, vfloat64m4_t, vfloat64m4_t, const double *, vuint16m1_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vloxseg3ei16_v)))
void vloxseg3ei16_v_f64m1(vfloat64m1_t *, vfloat64m1_t *, vfloat64m1_t *, const double *, vuint16mf4_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vloxseg3ei16_v_m)))
void vloxseg3ei16_v_f64m1_m(vfloat64m1_t *, vfloat64m1_t *, vfloat64m1_t *, vbool64_t, vfloat64m1_t, vfloat64m1_t, vfloat64m1_t, const double *, vuint16mf4_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vloxseg3ei16_v)))
void vloxseg3ei16_v_f64m2(vfloat64m2_t *, vfloat64m2_t *, vfloat64m2_t *, const double *, vuint16mf2_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vloxseg3ei16_v_m)))
void vloxseg3ei16_v_f64m2_m(vfloat64m2_t *, vfloat64m2_t *, vfloat64m2_t *, vbool32_t, vfloat64m2_t, vfloat64m2_t, vfloat64m2_t, const double *, vuint16mf2_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vloxseg4ei16_v)))
void vloxseg4ei16_v_f64m1(vfloat64m1_t *, vfloat64m1_t *, vfloat64m1_t *, vfloat64m1_t *, const double *, vuint16mf4_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vloxseg4ei16_v_m)))
void vloxseg4ei16_v_f64m1_m(vfloat64m1_t *, vfloat64m1_t *, vfloat64m1_t *, vfloat64m1_t *, vbool64_t, vfloat64m1_t, vfloat64m1_t, vfloat64m1_t, vfloat64m1_t, const double *, vuint16mf4_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vloxseg4ei16_v)))
void vloxseg4ei16_v_f64m2(vfloat64m2_t *, vfloat64m2_t *, vfloat64m2_t *, vfloat64m2_t *, const double *, vuint16mf2_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vloxseg4ei16_v_m)))
void vloxseg4ei16_v_f64m2_m(vfloat64m2_t *, vfloat64m2_t *, vfloat64m2_t *, vfloat64m2_t *, vbool32_t, vfloat64m2_t, vfloat64m2_t, vfloat64m2_t, vfloat64m2_t, const double *, vuint16mf2_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vsse64_v)))
void vsse64_v_f64m1(double *, ptrdiff_t, vfloat64m1_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vsse64_v_m)))
void vsse64_v_f64m1_m(vbool64_t, double *, ptrdiff_t, vfloat64m1_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vsse64_v)))
void vsse64_v_f64m2(double *, ptrdiff_t, vfloat64m2_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vsse64_v_m)))
void vsse64_v_f64m2_m(vbool32_t, double *, ptrdiff_t, vfloat64m2_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vsse64_v)))
void vsse64_v_f64m4(double *, ptrdiff_t, vfloat64m4_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vsse64_v_m)))
void vsse64_v_f64m4_m(vbool16_t, double *, ptrdiff_t, vfloat64m4_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vsse64_v)))
void vsse64_v_f64m8(double *, ptrdiff_t, vfloat64m8_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vsse64_v_m)))
void vsse64_v_f64m8_m(vbool8_t, double *, ptrdiff_t, vfloat64m8_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vloxseg5ei16_v)))
void vloxseg5ei16_v_f64m1(vfloat64m1_t *, vfloat64m1_t *, vfloat64m1_t *, vfloat64m1_t *, vfloat64m1_t *, const double *, vuint16mf4_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vloxseg5ei16_v_m)))
void vloxseg5ei16_v_f64m1_m(vfloat64m1_t *, vfloat64m1_t *, vfloat64m1_t *, vfloat64m1_t *, vfloat64m1_t *, vbool64_t, vfloat64m1_t, vfloat64m1_t, vfloat64m1_t, vfloat64m1_t, vfloat64m1_t, const double *, vuint16mf4_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vloxseg6ei16_v)))
void vloxseg6ei16_v_f64m1(vfloat64m1_t *, vfloat64m1_t *, vfloat64m1_t *, vfloat64m1_t *, vfloat64m1_t *, vfloat64m1_t *, const double *, vuint16mf4_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vloxseg6ei16_v_m)))
void vloxseg6ei16_v_f64m1_m(vfloat64m1_t *, vfloat64m1_t *, vfloat64m1_t *, vfloat64m1_t *, vfloat64m1_t *, vfloat64m1_t *, vbool64_t, vfloat64m1_t, vfloat64m1_t, vfloat64m1_t, vfloat64m1_t, vfloat64m1_t, vfloat64m1_t, const double *, vuint16mf4_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vloxseg7ei16_v)))
void vloxseg7ei16_v_f64m1(vfloat64m1_t *, vfloat64m1_t *, vfloat64m1_t *, vfloat64m1_t *, vfloat64m1_t *, vfloat64m1_t *, vfloat64m1_t *, const double *, vuint16mf4_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vloxseg7ei16_v_m)))
void vloxseg7ei16_v_f64m1_m(vfloat64m1_t *, vfloat64m1_t *, vfloat64m1_t *, vfloat64m1_t *, vfloat64m1_t *, vfloat64m1_t *, vfloat64m1_t *, vbool64_t, vfloat64m1_t, vfloat64m1_t, vfloat64m1_t, vfloat64m1_t, vfloat64m1_t, vfloat64m1_t, vfloat64m1_t, const double *, vuint16mf4_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vloxseg8ei16_v)))
void vloxseg8ei16_v_f64m1(vfloat64m1_t *, vfloat64m1_t *, vfloat64m1_t *, vfloat64m1_t *, vfloat64m1_t *, vfloat64m1_t *, vfloat64m1_t *, vfloat64m1_t *, const double *, vuint16mf4_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vloxseg8ei16_v_m)))
void vloxseg8ei16_v_f64m1_m(vfloat64m1_t *, vfloat64m1_t *, vfloat64m1_t *, vfloat64m1_t *, vfloat64m1_t *, vfloat64m1_t *, vfloat64m1_t *, vfloat64m1_t *, vbool64_t, vfloat64m1_t, vfloat64m1_t, vfloat64m1_t, vfloat64m1_t, vfloat64m1_t, vfloat64m1_t, vfloat64m1_t, vfloat64m1_t, const double *, vuint16mf4_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vloxseg2ei32_v)))
void vloxseg2ei32_v_f64m1(vfloat64m1_t *, vfloat64m1_t *, const double *, vuint32mf2_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vloxseg2ei32_v_m)))
void vloxseg2ei32_v_f64m1_m(vfloat64m1_t *, vfloat64m1_t *, vbool64_t, vfloat64m1_t, vfloat64m1_t, const double *, vuint32mf2_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vloxseg2ei32_v)))
void vloxseg2ei32_v_f64m2(vfloat64m2_t *, vfloat64m2_t *, const double *, vuint32m1_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vloxseg2ei32_v_m)))
void vloxseg2ei32_v_f64m2_m(vfloat64m2_t *, vfloat64m2_t *, vbool32_t, vfloat64m2_t, vfloat64m2_t, const double *, vuint32m1_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vloxseg2ei32_v)))
void vloxseg2ei32_v_f64m4(vfloat64m4_t *, vfloat64m4_t *, const double *, vuint32m2_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vloxseg2ei32_v_m)))
void vloxseg2ei32_v_f64m4_m(vfloat64m4_t *, vfloat64m4_t *, vbool16_t, vfloat64m4_t, vfloat64m4_t, const double *, vuint32m2_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vloxseg3ei32_v)))
void vloxseg3ei32_v_f64m1(vfloat64m1_t *, vfloat64m1_t *, vfloat64m1_t *, const double *, vuint32mf2_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vloxseg3ei32_v_m)))
void vloxseg3ei32_v_f64m1_m(vfloat64m1_t *, vfloat64m1_t *, vfloat64m1_t *, vbool64_t, vfloat64m1_t, vfloat64m1_t, vfloat64m1_t, const double *, vuint32mf2_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vloxseg3ei32_v)))
void vloxseg3ei32_v_f64m2(vfloat64m2_t *, vfloat64m2_t *, vfloat64m2_t *, const double *, vuint32m1_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vloxseg3ei32_v_m)))
void vloxseg3ei32_v_f64m2_m(vfloat64m2_t *, vfloat64m2_t *, vfloat64m2_t *, vbool32_t, vfloat64m2_t, vfloat64m2_t, vfloat64m2_t, const double *, vuint32m1_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vloxseg4ei32_v)))
void vloxseg4ei32_v_f64m1(vfloat64m1_t *, vfloat64m1_t *, vfloat64m1_t *, vfloat64m1_t *, const double *, vuint32mf2_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vloxseg4ei32_v_m)))
void vloxseg4ei32_v_f64m1_m(vfloat64m1_t *, vfloat64m1_t *, vfloat64m1_t *, vfloat64m1_t *, vbool64_t, vfloat64m1_t, vfloat64m1_t, vfloat64m1_t, vfloat64m1_t, const double *, vuint32mf2_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vloxseg4ei32_v)))
void vloxseg4ei32_v_f64m2(vfloat64m2_t *, vfloat64m2_t *, vfloat64m2_t *, vfloat64m2_t *, const double *, vuint32m1_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vloxseg4ei32_v_m)))
void vloxseg4ei32_v_f64m2_m(vfloat64m2_t *, vfloat64m2_t *, vfloat64m2_t *, vfloat64m2_t *, vbool32_t, vfloat64m2_t, vfloat64m2_t, vfloat64m2_t, vfloat64m2_t, const double *, vuint32m1_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vloxseg5ei32_v)))
void vloxseg5ei32_v_f64m1(vfloat64m1_t *, vfloat64m1_t *, vfloat64m1_t *, vfloat64m1_t *, vfloat64m1_t *, const double *, vuint32mf2_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vloxseg5ei32_v_m)))
void vloxseg5ei32_v_f64m1_m(vfloat64m1_t *, vfloat64m1_t *, vfloat64m1_t *, vfloat64m1_t *, vfloat64m1_t *, vbool64_t, vfloat64m1_t, vfloat64m1_t, vfloat64m1_t, vfloat64m1_t, vfloat64m1_t, const double *, vuint32mf2_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vloxseg6ei32_v)))
void vloxseg6ei32_v_f64m1(vfloat64m1_t *, vfloat64m1_t *, vfloat64m1_t *, vfloat64m1_t *, vfloat64m1_t *, vfloat64m1_t *, const double *, vuint32mf2_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vloxseg6ei32_v_m)))
void vloxseg6ei32_v_f64m1_m(vfloat64m1_t *, vfloat64m1_t *, vfloat64m1_t *, vfloat64m1_t *, vfloat64m1_t *, vfloat64m1_t *, vbool64_t, vfloat64m1_t, vfloat64m1_t, vfloat64m1_t, vfloat64m1_t, vfloat64m1_t, vfloat64m1_t, const double *, vuint32mf2_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vloxseg7ei32_v)))
void vloxseg7ei32_v_f64m1(vfloat64m1_t *, vfloat64m1_t *, vfloat64m1_t *, vfloat64m1_t *, vfloat64m1_t *, vfloat64m1_t *, vfloat64m1_t *, const double *, vuint32mf2_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vloxseg7ei32_v_m)))
void vloxseg7ei32_v_f64m1_m(vfloat64m1_t *, vfloat64m1_t *, vfloat64m1_t *, vfloat64m1_t *, vfloat64m1_t *, vfloat64m1_t *, vfloat64m1_t *, vbool64_t, vfloat64m1_t, vfloat64m1_t, vfloat64m1_t, vfloat64m1_t, vfloat64m1_t, vfloat64m1_t, vfloat64m1_t, const double *, vuint32mf2_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vloxseg8ei32_v)))
void vloxseg8ei32_v_f64m1(vfloat64m1_t *, vfloat64m1_t *, vfloat64m1_t *, vfloat64m1_t *, vfloat64m1_t *, vfloat64m1_t *, vfloat64m1_t *, vfloat64m1_t *, const double *, vuint32mf2_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vloxseg8ei32_v_m)))
void vloxseg8ei32_v_f64m1_m(vfloat64m1_t *, vfloat64m1_t *, vfloat64m1_t *, vfloat64m1_t *, vfloat64m1_t *, vfloat64m1_t *, vfloat64m1_t *, vfloat64m1_t *, vbool64_t, vfloat64m1_t, vfloat64m1_t, vfloat64m1_t, vfloat64m1_t, vfloat64m1_t, vfloat64m1_t, vfloat64m1_t, vfloat64m1_t, const double *, vuint32mf2_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vloxseg2ei64_v)))
void vloxseg2ei64_v_f64m1(vfloat64m1_t *, vfloat64m1_t *, const double *, vuint64m1_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vloxseg2ei64_v_m)))
void vloxseg2ei64_v_f64m1_m(vfloat64m1_t *, vfloat64m1_t *, vbool64_t, vfloat64m1_t, vfloat64m1_t, const double *, vuint64m1_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vloxseg2ei64_v)))
void vloxseg2ei64_v_f64m2(vfloat64m2_t *, vfloat64m2_t *, const double *, vuint64m2_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vloxseg2ei64_v_m)))
void vloxseg2ei64_v_f64m2_m(vfloat64m2_t *, vfloat64m2_t *, vbool32_t, vfloat64m2_t, vfloat64m2_t, const double *, vuint64m2_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vloxseg2ei64_v)))
void vloxseg2ei64_v_f64m4(vfloat64m4_t *, vfloat64m4_t *, const double *, vuint64m4_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vloxseg2ei64_v_m)))
void vloxseg2ei64_v_f64m4_m(vfloat64m4_t *, vfloat64m4_t *, vbool16_t, vfloat64m4_t, vfloat64m4_t, const double *, vuint64m4_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vloxseg3ei64_v)))
void vloxseg3ei64_v_f64m1(vfloat64m1_t *, vfloat64m1_t *, vfloat64m1_t *, const double *, vuint64m1_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vloxseg3ei64_v_m)))
void vloxseg3ei64_v_f64m1_m(vfloat64m1_t *, vfloat64m1_t *, vfloat64m1_t *, vbool64_t, vfloat64m1_t, vfloat64m1_t, vfloat64m1_t, const double *, vuint64m1_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vloxseg3ei64_v)))
void vloxseg3ei64_v_f64m2(vfloat64m2_t *, vfloat64m2_t *, vfloat64m2_t *, const double *, vuint64m2_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vloxseg3ei64_v_m)))
void vloxseg3ei64_v_f64m2_m(vfloat64m2_t *, vfloat64m2_t *, vfloat64m2_t *, vbool32_t, vfloat64m2_t, vfloat64m2_t, vfloat64m2_t, const double *, vuint64m2_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vloxseg4ei64_v)))
void vloxseg4ei64_v_f64m1(vfloat64m1_t *, vfloat64m1_t *, vfloat64m1_t *, vfloat64m1_t *, const double *, vuint64m1_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vloxseg4ei64_v_m)))
void vloxseg4ei64_v_f64m1_m(vfloat64m1_t *, vfloat64m1_t *, vfloat64m1_t *, vfloat64m1_t *, vbool64_t, vfloat64m1_t, vfloat64m1_t, vfloat64m1_t, vfloat64m1_t, const double *, vuint64m1_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vloxseg4ei64_v)))
void vloxseg4ei64_v_f64m2(vfloat64m2_t *, vfloat64m2_t *, vfloat64m2_t *, vfloat64m2_t *, const double *, vuint64m2_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vloxseg4ei64_v_m)))
void vloxseg4ei64_v_f64m2_m(vfloat64m2_t *, vfloat64m2_t *, vfloat64m2_t *, vfloat64m2_t *, vbool32_t, vfloat64m2_t, vfloat64m2_t, vfloat64m2_t, vfloat64m2_t, const double *, vuint64m2_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vloxseg5ei64_v)))
void vloxseg5ei64_v_f64m1(vfloat64m1_t *, vfloat64m1_t *, vfloat64m1_t *, vfloat64m1_t *, vfloat64m1_t *, const double *, vuint64m1_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vloxseg5ei64_v_m)))
void vloxseg5ei64_v_f64m1_m(vfloat64m1_t *, vfloat64m1_t *, vfloat64m1_t *, vfloat64m1_t *, vfloat64m1_t *, vbool64_t, vfloat64m1_t, vfloat64m1_t, vfloat64m1_t, vfloat64m1_t, vfloat64m1_t, const double *, vuint64m1_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vloxseg6ei64_v)))
void vloxseg6ei64_v_f64m1(vfloat64m1_t *, vfloat64m1_t *, vfloat64m1_t *, vfloat64m1_t *, vfloat64m1_t *, vfloat64m1_t *, const double *, vuint64m1_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vloxseg6ei64_v_m)))
void vloxseg6ei64_v_f64m1_m(vfloat64m1_t *, vfloat64m1_t *, vfloat64m1_t *, vfloat64m1_t *, vfloat64m1_t *, vfloat64m1_t *, vbool64_t, vfloat64m1_t, vfloat64m1_t, vfloat64m1_t, vfloat64m1_t, vfloat64m1_t, vfloat64m1_t, const double *, vuint64m1_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vloxseg7ei64_v)))
void vloxseg7ei64_v_f64m1(vfloat64m1_t *, vfloat64m1_t *, vfloat64m1_t *, vfloat64m1_t *, vfloat64m1_t *, vfloat64m1_t *, vfloat64m1_t *, const double *, vuint64m1_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vloxseg7ei64_v_m)))
void vloxseg7ei64_v_f64m1_m(vfloat64m1_t *, vfloat64m1_t *, vfloat64m1_t *, vfloat64m1_t *, vfloat64m1_t *, vfloat64m1_t *, vfloat64m1_t *, vbool64_t, vfloat64m1_t, vfloat64m1_t, vfloat64m1_t, vfloat64m1_t, vfloat64m1_t, vfloat64m1_t, vfloat64m1_t, const double *, vuint64m1_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vloxseg8ei64_v)))
void vloxseg8ei64_v_f64m1(vfloat64m1_t *, vfloat64m1_t *, vfloat64m1_t *, vfloat64m1_t *, vfloat64m1_t *, vfloat64m1_t *, vfloat64m1_t *, vfloat64m1_t *, const double *, vuint64m1_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vloxseg8ei64_v_m)))
void vloxseg8ei64_v_f64m1_m(vfloat64m1_t *, vfloat64m1_t *, vfloat64m1_t *, vfloat64m1_t *, vfloat64m1_t *, vfloat64m1_t *, vfloat64m1_t *, vfloat64m1_t *, vbool64_t, vfloat64m1_t, vfloat64m1_t, vfloat64m1_t, vfloat64m1_t, vfloat64m1_t, vfloat64m1_t, vfloat64m1_t, vfloat64m1_t, const double *, vuint64m1_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vsseg2e64_v)))
void vsseg2e64_v_f64m1(double *, vfloat64m1_t, vfloat64m1_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vsseg2e64_v_m)))
void vsseg2e64_v_f64m1_m(vbool64_t, double *, vfloat64m1_t, vfloat64m1_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vsseg2e64_v)))
void vsseg2e64_v_f64m2(double *, vfloat64m2_t, vfloat64m2_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vsseg2e64_v_m)))
void vsseg2e64_v_f64m2_m(vbool32_t, double *, vfloat64m2_t, vfloat64m2_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vsseg2e64_v)))
void vsseg2e64_v_f64m4(double *, vfloat64m4_t, vfloat64m4_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vsseg2e64_v_m)))
void vsseg2e64_v_f64m4_m(vbool16_t, double *, vfloat64m4_t, vfloat64m4_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vsseg3e64_v)))
void vsseg3e64_v_f64m1(double *, vfloat64m1_t, vfloat64m1_t, vfloat64m1_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vsseg3e64_v_m)))
void vsseg3e64_v_f64m1_m(vbool64_t, double *, vfloat64m1_t, vfloat64m1_t, vfloat64m1_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vsseg3e64_v)))
void vsseg3e64_v_f64m2(double *, vfloat64m2_t, vfloat64m2_t, vfloat64m2_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vsseg3e64_v_m)))
void vsseg3e64_v_f64m2_m(vbool32_t, double *, vfloat64m2_t, vfloat64m2_t, vfloat64m2_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vsseg4e64_v)))
void vsseg4e64_v_f64m1(double *, vfloat64m1_t, vfloat64m1_t, vfloat64m1_t, vfloat64m1_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vsseg4e64_v_m)))
void vsseg4e64_v_f64m1_m(vbool64_t, double *, vfloat64m1_t, vfloat64m1_t, vfloat64m1_t, vfloat64m1_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vsseg4e64_v)))
void vsseg4e64_v_f64m2(double *, vfloat64m2_t, vfloat64m2_t, vfloat64m2_t, vfloat64m2_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vsseg4e64_v_m)))
void vsseg4e64_v_f64m2_m(vbool32_t, double *, vfloat64m2_t, vfloat64m2_t, vfloat64m2_t, vfloat64m2_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vsseg5e64_v)))
void vsseg5e64_v_f64m1(double *, vfloat64m1_t, vfloat64m1_t, vfloat64m1_t, vfloat64m1_t, vfloat64m1_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vsseg5e64_v_m)))
void vsseg5e64_v_f64m1_m(vbool64_t, double *, vfloat64m1_t, vfloat64m1_t, vfloat64m1_t, vfloat64m1_t, vfloat64m1_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vsseg6e64_v)))
void vsseg6e64_v_f64m1(double *, vfloat64m1_t, vfloat64m1_t, vfloat64m1_t, vfloat64m1_t, vfloat64m1_t, vfloat64m1_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vsseg6e64_v_m)))
void vsseg6e64_v_f64m1_m(vbool64_t, double *, vfloat64m1_t, vfloat64m1_t, vfloat64m1_t, vfloat64m1_t, vfloat64m1_t, vfloat64m1_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vsseg7e64_v)))
void vsseg7e64_v_f64m1(double *, vfloat64m1_t, vfloat64m1_t, vfloat64m1_t, vfloat64m1_t, vfloat64m1_t, vfloat64m1_t, vfloat64m1_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vsseg7e64_v_m)))
void vsseg7e64_v_f64m1_m(vbool64_t, double *, vfloat64m1_t, vfloat64m1_t, vfloat64m1_t, vfloat64m1_t, vfloat64m1_t, vfloat64m1_t, vfloat64m1_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vsseg8e64_v)))
void vsseg8e64_v_f64m1(double *, vfloat64m1_t, vfloat64m1_t, vfloat64m1_t, vfloat64m1_t, vfloat64m1_t, vfloat64m1_t, vfloat64m1_t, vfloat64m1_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vsseg8e64_v_m)))
void vsseg8e64_v_f64m1_m(vbool64_t, double *, vfloat64m1_t, vfloat64m1_t, vfloat64m1_t, vfloat64m1_t, vfloat64m1_t, vfloat64m1_t, vfloat64m1_t, vfloat64m1_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vssseg2e64_v)))
void vssseg2e64_v_f64m1(double *, ptrdiff_t, vfloat64m1_t, vfloat64m1_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vssseg2e64_v_m)))
void vssseg2e64_v_f64m1_m(vbool64_t, double *, ptrdiff_t, vfloat64m1_t, vfloat64m1_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vssseg2e64_v)))
void vssseg2e64_v_f64m2(double *, ptrdiff_t, vfloat64m2_t, vfloat64m2_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vssseg2e64_v_m)))
void vssseg2e64_v_f64m2_m(vbool32_t, double *, ptrdiff_t, vfloat64m2_t, vfloat64m2_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vssseg2e64_v)))
void vssseg2e64_v_f64m4(double *, ptrdiff_t, vfloat64m4_t, vfloat64m4_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vssseg2e64_v_m)))
void vssseg2e64_v_f64m4_m(vbool16_t, double *, ptrdiff_t, vfloat64m4_t, vfloat64m4_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vssseg3e64_v)))
void vssseg3e64_v_f64m1(double *, ptrdiff_t, vfloat64m1_t, vfloat64m1_t, vfloat64m1_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vssseg3e64_v_m)))
void vssseg3e64_v_f64m1_m(vbool64_t, double *, ptrdiff_t, vfloat64m1_t, vfloat64m1_t, vfloat64m1_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vssseg3e64_v)))
void vssseg3e64_v_f64m2(double *, ptrdiff_t, vfloat64m2_t, vfloat64m2_t, vfloat64m2_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vssseg3e64_v_m)))
void vssseg3e64_v_f64m2_m(vbool32_t, double *, ptrdiff_t, vfloat64m2_t, vfloat64m2_t, vfloat64m2_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vssseg4e64_v)))
void vssseg4e64_v_f64m1(double *, ptrdiff_t, vfloat64m1_t, vfloat64m1_t, vfloat64m1_t, vfloat64m1_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vssseg4e64_v_m)))
void vssseg4e64_v_f64m1_m(vbool64_t, double *, ptrdiff_t, vfloat64m1_t, vfloat64m1_t, vfloat64m1_t, vfloat64m1_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vssseg4e64_v)))
void vssseg4e64_v_f64m2(double *, ptrdiff_t, vfloat64m2_t, vfloat64m2_t, vfloat64m2_t, vfloat64m2_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vssseg4e64_v_m)))
void vssseg4e64_v_f64m2_m(vbool32_t, double *, ptrdiff_t, vfloat64m2_t, vfloat64m2_t, vfloat64m2_t, vfloat64m2_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vssseg5e64_v)))
void vssseg5e64_v_f64m1(double *, ptrdiff_t, vfloat64m1_t, vfloat64m1_t, vfloat64m1_t, vfloat64m1_t, vfloat64m1_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vssseg5e64_v_m)))
void vssseg5e64_v_f64m1_m(vbool64_t, double *, ptrdiff_t, vfloat64m1_t, vfloat64m1_t, vfloat64m1_t, vfloat64m1_t, vfloat64m1_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vssseg6e64_v)))
void vssseg6e64_v_f64m1(double *, ptrdiff_t, vfloat64m1_t, vfloat64m1_t, vfloat64m1_t, vfloat64m1_t, vfloat64m1_t, vfloat64m1_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vssseg6e64_v_m)))
void vssseg6e64_v_f64m1_m(vbool64_t, double *, ptrdiff_t, vfloat64m1_t, vfloat64m1_t, vfloat64m1_t, vfloat64m1_t, vfloat64m1_t, vfloat64m1_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vssseg7e64_v)))
void vssseg7e64_v_f64m1(double *, ptrdiff_t, vfloat64m1_t, vfloat64m1_t, vfloat64m1_t, vfloat64m1_t, vfloat64m1_t, vfloat64m1_t, vfloat64m1_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vssseg7e64_v_m)))
void vssseg7e64_v_f64m1_m(vbool64_t, double *, ptrdiff_t, vfloat64m1_t, vfloat64m1_t, vfloat64m1_t, vfloat64m1_t, vfloat64m1_t, vfloat64m1_t, vfloat64m1_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vssseg8e64_v)))
void vssseg8e64_v_f64m1(double *, ptrdiff_t, vfloat64m1_t, vfloat64m1_t, vfloat64m1_t, vfloat64m1_t, vfloat64m1_t, vfloat64m1_t, vfloat64m1_t, vfloat64m1_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vssseg8e64_v_m)))
void vssseg8e64_v_f64m1_m(vbool64_t, double *, ptrdiff_t, vfloat64m1_t, vfloat64m1_t, vfloat64m1_t, vfloat64m1_t, vfloat64m1_t, vfloat64m1_t, vfloat64m1_t, vfloat64m1_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vluxei8_v)))
vfloat64m1_t vluxei8_v_f64m1(const double *, vuint8mf8_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vluxei8_v_m)))
vfloat64m1_t vluxei8_v_f64m1_m(vbool64_t, vfloat64m1_t, const double *, vuint8mf8_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vluxei8_v)))
vfloat64m2_t vluxei8_v_f64m2(const double *, vuint8mf4_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vluxei8_v_m)))
vfloat64m2_t vluxei8_v_f64m2_m(vbool32_t, vfloat64m2_t, const double *, vuint8mf4_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vluxei8_v)))
vfloat64m4_t vluxei8_v_f64m4(const double *, vuint8mf2_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vluxei8_v_m)))
vfloat64m4_t vluxei8_v_f64m4_m(vbool16_t, vfloat64m4_t, const double *, vuint8mf2_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vluxei8_v)))
vfloat64m8_t vluxei8_v_f64m8(const double *, vuint8m1_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vluxei8_v_m)))
vfloat64m8_t vluxei8_v_f64m8_m(vbool8_t, vfloat64m8_t, const double *, vuint8m1_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vluxei16_v)))
vfloat64m1_t vluxei16_v_f64m1(const double *, vuint16mf4_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vluxei16_v_m)))
vfloat64m1_t vluxei16_v_f64m1_m(vbool64_t, vfloat64m1_t, const double *, vuint16mf4_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vluxei16_v)))
vfloat64m2_t vluxei16_v_f64m2(const double *, vuint16mf2_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vluxei16_v_m)))
vfloat64m2_t vluxei16_v_f64m2_m(vbool32_t, vfloat64m2_t, const double *, vuint16mf2_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vluxei16_v)))
vfloat64m4_t vluxei16_v_f64m4(const double *, vuint16m1_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vluxei16_v_m)))
vfloat64m4_t vluxei16_v_f64m4_m(vbool16_t, vfloat64m4_t, const double *, vuint16m1_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vluxei16_v)))
vfloat64m8_t vluxei16_v_f64m8(const double *, vuint16m2_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vluxei16_v_m)))
vfloat64m8_t vluxei16_v_f64m8_m(vbool8_t, vfloat64m8_t, const double *, vuint16m2_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vluxei32_v)))
vfloat64m1_t vluxei32_v_f64m1(const double *, vuint32mf2_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vluxei32_v_m)))
vfloat64m1_t vluxei32_v_f64m1_m(vbool64_t, vfloat64m1_t, const double *, vuint32mf2_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vluxei32_v)))
vfloat64m2_t vluxei32_v_f64m2(const double *, vuint32m1_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vluxei32_v_m)))
vfloat64m2_t vluxei32_v_f64m2_m(vbool32_t, vfloat64m2_t, const double *, vuint32m1_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vluxei32_v)))
vfloat64m4_t vluxei32_v_f64m4(const double *, vuint32m2_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vluxei32_v_m)))
vfloat64m4_t vluxei32_v_f64m4_m(vbool16_t, vfloat64m4_t, const double *, vuint32m2_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vluxei32_v)))
vfloat64m8_t vluxei32_v_f64m8(const double *, vuint32m4_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vluxei32_v_m)))
vfloat64m8_t vluxei32_v_f64m8_m(vbool8_t, vfloat64m8_t, const double *, vuint32m4_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vsuxseg2ei8_v)))
void vsuxseg2ei8_v_f64m1(double *, vuint8mf8_t, vfloat64m1_t, vfloat64m1_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vsuxseg2ei8_v_m)))
void vsuxseg2ei8_v_f64m1_m(vbool64_t, double *, vuint8mf8_t, vfloat64m1_t, vfloat64m1_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vsuxseg2ei8_v)))
void vsuxseg2ei8_v_f64m2(double *, vuint8mf4_t, vfloat64m2_t, vfloat64m2_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vsuxseg2ei8_v_m)))
void vsuxseg2ei8_v_f64m2_m(vbool32_t, double *, vuint8mf4_t, vfloat64m2_t, vfloat64m2_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vsuxseg2ei8_v)))
void vsuxseg2ei8_v_f64m4(double *, vuint8mf2_t, vfloat64m4_t, vfloat64m4_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vsuxseg2ei8_v_m)))
void vsuxseg2ei8_v_f64m4_m(vbool16_t, double *, vuint8mf2_t, vfloat64m4_t, vfloat64m4_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vsuxseg3ei8_v)))
void vsuxseg3ei8_v_f64m1(double *, vuint8mf8_t, vfloat64m1_t, vfloat64m1_t, vfloat64m1_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vsuxseg3ei8_v_m)))
void vsuxseg3ei8_v_f64m1_m(vbool64_t, double *, vuint8mf8_t, vfloat64m1_t, vfloat64m1_t, vfloat64m1_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vsuxseg3ei8_v)))
void vsuxseg3ei8_v_f64m2(double *, vuint8mf4_t, vfloat64m2_t, vfloat64m2_t, vfloat64m2_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vsuxseg3ei8_v_m)))
void vsuxseg3ei8_v_f64m2_m(vbool32_t, double *, vuint8mf4_t, vfloat64m2_t, vfloat64m2_t, vfloat64m2_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vsuxseg4ei8_v)))
void vsuxseg4ei8_v_f64m1(double *, vuint8mf8_t, vfloat64m1_t, vfloat64m1_t, vfloat64m1_t, vfloat64m1_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vsuxseg4ei8_v_m)))
void vsuxseg4ei8_v_f64m1_m(vbool64_t, double *, vuint8mf8_t, vfloat64m1_t, vfloat64m1_t, vfloat64m1_t, vfloat64m1_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vsuxseg4ei8_v)))
void vsuxseg4ei8_v_f64m2(double *, vuint8mf4_t, vfloat64m2_t, vfloat64m2_t, vfloat64m2_t, vfloat64m2_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vsuxseg4ei8_v_m)))
void vsuxseg4ei8_v_f64m2_m(vbool32_t, double *, vuint8mf4_t, vfloat64m2_t, vfloat64m2_t, vfloat64m2_t, vfloat64m2_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vsuxseg5ei8_v)))
void vsuxseg5ei8_v_f64m1(double *, vuint8mf8_t, vfloat64m1_t, vfloat64m1_t, vfloat64m1_t, vfloat64m1_t, vfloat64m1_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vsuxseg5ei8_v_m)))
void vsuxseg5ei8_v_f64m1_m(vbool64_t, double *, vuint8mf8_t, vfloat64m1_t, vfloat64m1_t, vfloat64m1_t, vfloat64m1_t, vfloat64m1_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vsuxseg6ei8_v)))
void vsuxseg6ei8_v_f64m1(double *, vuint8mf8_t, vfloat64m1_t, vfloat64m1_t, vfloat64m1_t, vfloat64m1_t, vfloat64m1_t, vfloat64m1_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vsuxseg6ei8_v_m)))
void vsuxseg6ei8_v_f64m1_m(vbool64_t, double *, vuint8mf8_t, vfloat64m1_t, vfloat64m1_t, vfloat64m1_t, vfloat64m1_t, vfloat64m1_t, vfloat64m1_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vsuxseg7ei8_v)))
void vsuxseg7ei8_v_f64m1(double *, vuint8mf8_t, vfloat64m1_t, vfloat64m1_t, vfloat64m1_t, vfloat64m1_t, vfloat64m1_t, vfloat64m1_t, vfloat64m1_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vsuxseg7ei8_v_m)))
void vsuxseg7ei8_v_f64m1_m(vbool64_t, double *, vuint8mf8_t, vfloat64m1_t, vfloat64m1_t, vfloat64m1_t, vfloat64m1_t, vfloat64m1_t, vfloat64m1_t, vfloat64m1_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vsuxseg8ei8_v)))
void vsuxseg8ei8_v_f64m1(double *, vuint8mf8_t, vfloat64m1_t, vfloat64m1_t, vfloat64m1_t, vfloat64m1_t, vfloat64m1_t, vfloat64m1_t, vfloat64m1_t, vfloat64m1_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vsuxseg8ei8_v_m)))
void vsuxseg8ei8_v_f64m1_m(vbool64_t, double *, vuint8mf8_t, vfloat64m1_t, vfloat64m1_t, vfloat64m1_t, vfloat64m1_t, vfloat64m1_t, vfloat64m1_t, vfloat64m1_t, vfloat64m1_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vsuxseg2ei16_v)))
void vsuxseg2ei16_v_f64m1(double *, vuint16mf4_t, vfloat64m1_t, vfloat64m1_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vsuxseg2ei16_v_m)))
void vsuxseg2ei16_v_f64m1_m(vbool64_t, double *, vuint16mf4_t, vfloat64m1_t, vfloat64m1_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vsuxseg2ei16_v)))
void vsuxseg2ei16_v_f64m2(double *, vuint16mf2_t, vfloat64m2_t, vfloat64m2_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vsuxseg2ei16_v_m)))
void vsuxseg2ei16_v_f64m2_m(vbool32_t, double *, vuint16mf2_t, vfloat64m2_t, vfloat64m2_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vsuxseg2ei16_v)))
void vsuxseg2ei16_v_f64m4(double *, vuint16m1_t, vfloat64m4_t, vfloat64m4_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vsuxseg2ei16_v_m)))
void vsuxseg2ei16_v_f64m4_m(vbool16_t, double *, vuint16m1_t, vfloat64m4_t, vfloat64m4_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vsuxseg3ei16_v)))
void vsuxseg3ei16_v_f64m1(double *, vuint16mf4_t, vfloat64m1_t, vfloat64m1_t, vfloat64m1_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vsuxseg3ei16_v_m)))
void vsuxseg3ei16_v_f64m1_m(vbool64_t, double *, vuint16mf4_t, vfloat64m1_t, vfloat64m1_t, vfloat64m1_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vsuxseg3ei16_v)))
void vsuxseg3ei16_v_f64m2(double *, vuint16mf2_t, vfloat64m2_t, vfloat64m2_t, vfloat64m2_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vsuxseg3ei16_v_m)))
void vsuxseg3ei16_v_f64m2_m(vbool32_t, double *, vuint16mf2_t, vfloat64m2_t, vfloat64m2_t, vfloat64m2_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vsuxseg4ei16_v)))
void vsuxseg4ei16_v_f64m1(double *, vuint16mf4_t, vfloat64m1_t, vfloat64m1_t, vfloat64m1_t, vfloat64m1_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vsuxseg4ei16_v_m)))
void vsuxseg4ei16_v_f64m1_m(vbool64_t, double *, vuint16mf4_t, vfloat64m1_t, vfloat64m1_t, vfloat64m1_t, vfloat64m1_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vsuxseg4ei16_v)))
void vsuxseg4ei16_v_f64m2(double *, vuint16mf2_t, vfloat64m2_t, vfloat64m2_t, vfloat64m2_t, vfloat64m2_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vsuxseg4ei16_v_m)))
void vsuxseg4ei16_v_f64m2_m(vbool32_t, double *, vuint16mf2_t, vfloat64m2_t, vfloat64m2_t, vfloat64m2_t, vfloat64m2_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vsuxseg5ei16_v)))
void vsuxseg5ei16_v_f64m1(double *, vuint16mf4_t, vfloat64m1_t, vfloat64m1_t, vfloat64m1_t, vfloat64m1_t, vfloat64m1_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vsuxseg5ei16_v_m)))
void vsuxseg5ei16_v_f64m1_m(vbool64_t, double *, vuint16mf4_t, vfloat64m1_t, vfloat64m1_t, vfloat64m1_t, vfloat64m1_t, vfloat64m1_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vsuxseg6ei16_v)))
void vsuxseg6ei16_v_f64m1(double *, vuint16mf4_t, vfloat64m1_t, vfloat64m1_t, vfloat64m1_t, vfloat64m1_t, vfloat64m1_t, vfloat64m1_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vsuxseg6ei16_v_m)))
void vsuxseg6ei16_v_f64m1_m(vbool64_t, double *, vuint16mf4_t, vfloat64m1_t, vfloat64m1_t, vfloat64m1_t, vfloat64m1_t, vfloat64m1_t, vfloat64m1_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vsuxseg7ei16_v)))
void vsuxseg7ei16_v_f64m1(double *, vuint16mf4_t, vfloat64m1_t, vfloat64m1_t, vfloat64m1_t, vfloat64m1_t, vfloat64m1_t, vfloat64m1_t, vfloat64m1_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vsuxseg7ei16_v_m)))
void vsuxseg7ei16_v_f64m1_m(vbool64_t, double *, vuint16mf4_t, vfloat64m1_t, vfloat64m1_t, vfloat64m1_t, vfloat64m1_t, vfloat64m1_t, vfloat64m1_t, vfloat64m1_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vsuxseg8ei16_v)))
void vsuxseg8ei16_v_f64m1(double *, vuint16mf4_t, vfloat64m1_t, vfloat64m1_t, vfloat64m1_t, vfloat64m1_t, vfloat64m1_t, vfloat64m1_t, vfloat64m1_t, vfloat64m1_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vsuxseg8ei16_v_m)))
void vsuxseg8ei16_v_f64m1_m(vbool64_t, double *, vuint16mf4_t, vfloat64m1_t, vfloat64m1_t, vfloat64m1_t, vfloat64m1_t, vfloat64m1_t, vfloat64m1_t, vfloat64m1_t, vfloat64m1_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vsuxseg2ei32_v)))
void vsuxseg2ei32_v_f64m1(double *, vuint32mf2_t, vfloat64m1_t, vfloat64m1_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vsuxseg2ei32_v_m)))
void vsuxseg2ei32_v_f64m1_m(vbool64_t, double *, vuint32mf2_t, vfloat64m1_t, vfloat64m1_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vsuxseg2ei32_v)))
void vsuxseg2ei32_v_f64m2(double *, vuint32m1_t, vfloat64m2_t, vfloat64m2_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vsuxseg2ei32_v_m)))
void vsuxseg2ei32_v_f64m2_m(vbool32_t, double *, vuint32m1_t, vfloat64m2_t, vfloat64m2_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vsuxseg2ei32_v)))
void vsuxseg2ei32_v_f64m4(double *, vuint32m2_t, vfloat64m4_t, vfloat64m4_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vsuxseg2ei32_v_m)))
void vsuxseg2ei32_v_f64m4_m(vbool16_t, double *, vuint32m2_t, vfloat64m4_t, vfloat64m4_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vsuxseg3ei32_v)))
void vsuxseg3ei32_v_f64m1(double *, vuint32mf2_t, vfloat64m1_t, vfloat64m1_t, vfloat64m1_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vsuxseg3ei32_v_m)))
void vsuxseg3ei32_v_f64m1_m(vbool64_t, double *, vuint32mf2_t, vfloat64m1_t, vfloat64m1_t, vfloat64m1_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vsuxseg3ei32_v)))
void vsuxseg3ei32_v_f64m2(double *, vuint32m1_t, vfloat64m2_t, vfloat64m2_t, vfloat64m2_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vsuxseg3ei32_v_m)))
void vsuxseg3ei32_v_f64m2_m(vbool32_t, double *, vuint32m1_t, vfloat64m2_t, vfloat64m2_t, vfloat64m2_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vsuxseg4ei32_v)))
void vsuxseg4ei32_v_f64m1(double *, vuint32mf2_t, vfloat64m1_t, vfloat64m1_t, vfloat64m1_t, vfloat64m1_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vsuxseg4ei32_v_m)))
void vsuxseg4ei32_v_f64m1_m(vbool64_t, double *, vuint32mf2_t, vfloat64m1_t, vfloat64m1_t, vfloat64m1_t, vfloat64m1_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vsuxseg4ei32_v)))
void vsuxseg4ei32_v_f64m2(double *, vuint32m1_t, vfloat64m2_t, vfloat64m2_t, vfloat64m2_t, vfloat64m2_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vsuxseg4ei32_v_m)))
void vsuxseg4ei32_v_f64m2_m(vbool32_t, double *, vuint32m1_t, vfloat64m2_t, vfloat64m2_t, vfloat64m2_t, vfloat64m2_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vsuxseg5ei32_v)))
void vsuxseg5ei32_v_f64m1(double *, vuint32mf2_t, vfloat64m1_t, vfloat64m1_t, vfloat64m1_t, vfloat64m1_t, vfloat64m1_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vsuxseg5ei32_v_m)))
void vsuxseg5ei32_v_f64m1_m(vbool64_t, double *, vuint32mf2_t, vfloat64m1_t, vfloat64m1_t, vfloat64m1_t, vfloat64m1_t, vfloat64m1_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vsuxseg6ei32_v)))
void vsuxseg6ei32_v_f64m1(double *, vuint32mf2_t, vfloat64m1_t, vfloat64m1_t, vfloat64m1_t, vfloat64m1_t, vfloat64m1_t, vfloat64m1_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vsuxseg6ei32_v_m)))
void vsuxseg6ei32_v_f64m1_m(vbool64_t, double *, vuint32mf2_t, vfloat64m1_t, vfloat64m1_t, vfloat64m1_t, vfloat64m1_t, vfloat64m1_t, vfloat64m1_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vsuxseg7ei32_v)))
void vsuxseg7ei32_v_f64m1(double *, vuint32mf2_t, vfloat64m1_t, vfloat64m1_t, vfloat64m1_t, vfloat64m1_t, vfloat64m1_t, vfloat64m1_t, vfloat64m1_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vsuxseg7ei32_v_m)))
void vsuxseg7ei32_v_f64m1_m(vbool64_t, double *, vuint32mf2_t, vfloat64m1_t, vfloat64m1_t, vfloat64m1_t, vfloat64m1_t, vfloat64m1_t, vfloat64m1_t, vfloat64m1_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vsuxseg8ei32_v)))
void vsuxseg8ei32_v_f64m1(double *, vuint32mf2_t, vfloat64m1_t, vfloat64m1_t, vfloat64m1_t, vfloat64m1_t, vfloat64m1_t, vfloat64m1_t, vfloat64m1_t, vfloat64m1_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vsuxseg8ei32_v_m)))
void vsuxseg8ei32_v_f64m1_m(vbool64_t, double *, vuint32mf2_t, vfloat64m1_t, vfloat64m1_t, vfloat64m1_t, vfloat64m1_t, vfloat64m1_t, vfloat64m1_t, vfloat64m1_t, vfloat64m1_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vsuxseg2ei64_v)))
void vsuxseg2ei64_v_f64m1(double *, vuint64m1_t, vfloat64m1_t, vfloat64m1_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vsuxseg2ei64_v_m)))
void vsuxseg2ei64_v_f64m1_m(vbool64_t, double *, vuint64m1_t, vfloat64m1_t, vfloat64m1_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vsuxseg2ei64_v)))
void vsuxseg2ei64_v_f64m2(double *, vuint64m2_t, vfloat64m2_t, vfloat64m2_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vsuxseg2ei64_v_m)))
void vsuxseg2ei64_v_f64m2_m(vbool32_t, double *, vuint64m2_t, vfloat64m2_t, vfloat64m2_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vsuxseg2ei64_v)))
void vsuxseg2ei64_v_f64m4(double *, vuint64m4_t, vfloat64m4_t, vfloat64m4_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vsuxseg2ei64_v_m)))
void vsuxseg2ei64_v_f64m4_m(vbool16_t, double *, vuint64m4_t, vfloat64m4_t, vfloat64m4_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vsuxseg3ei64_v)))
void vsuxseg3ei64_v_f64m1(double *, vuint64m1_t, vfloat64m1_t, vfloat64m1_t, vfloat64m1_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vsuxseg3ei64_v_m)))
void vsuxseg3ei64_v_f64m1_m(vbool64_t, double *, vuint64m1_t, vfloat64m1_t, vfloat64m1_t, vfloat64m1_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vsuxseg3ei64_v)))
void vsuxseg3ei64_v_f64m2(double *, vuint64m2_t, vfloat64m2_t, vfloat64m2_t, vfloat64m2_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vsuxseg3ei64_v_m)))
void vsuxseg3ei64_v_f64m2_m(vbool32_t, double *, vuint64m2_t, vfloat64m2_t, vfloat64m2_t, vfloat64m2_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vsuxseg4ei64_v)))
void vsuxseg4ei64_v_f64m1(double *, vuint64m1_t, vfloat64m1_t, vfloat64m1_t, vfloat64m1_t, vfloat64m1_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vsuxseg4ei64_v_m)))
void vsuxseg4ei64_v_f64m1_m(vbool64_t, double *, vuint64m1_t, vfloat64m1_t, vfloat64m1_t, vfloat64m1_t, vfloat64m1_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vsuxseg4ei64_v)))
void vsuxseg4ei64_v_f64m2(double *, vuint64m2_t, vfloat64m2_t, vfloat64m2_t, vfloat64m2_t, vfloat64m2_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vsuxseg4ei64_v_m)))
void vsuxseg4ei64_v_f64m2_m(vbool32_t, double *, vuint64m2_t, vfloat64m2_t, vfloat64m2_t, vfloat64m2_t, vfloat64m2_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vsuxseg5ei64_v)))
void vsuxseg5ei64_v_f64m1(double *, vuint64m1_t, vfloat64m1_t, vfloat64m1_t, vfloat64m1_t, vfloat64m1_t, vfloat64m1_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vsuxseg5ei64_v_m)))
void vsuxseg5ei64_v_f64m1_m(vbool64_t, double *, vuint64m1_t, vfloat64m1_t, vfloat64m1_t, vfloat64m1_t, vfloat64m1_t, vfloat64m1_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vsuxseg6ei64_v)))
void vsuxseg6ei64_v_f64m1(double *, vuint64m1_t, vfloat64m1_t, vfloat64m1_t, vfloat64m1_t, vfloat64m1_t, vfloat64m1_t, vfloat64m1_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vsuxseg6ei64_v_m)))
void vsuxseg6ei64_v_f64m1_m(vbool64_t, double *, vuint64m1_t, vfloat64m1_t, vfloat64m1_t, vfloat64m1_t, vfloat64m1_t, vfloat64m1_t, vfloat64m1_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vsuxseg7ei64_v)))
void vsuxseg7ei64_v_f64m1(double *, vuint64m1_t, vfloat64m1_t, vfloat64m1_t, vfloat64m1_t, vfloat64m1_t, vfloat64m1_t, vfloat64m1_t, vfloat64m1_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vsuxseg7ei64_v_m)))
void vsuxseg7ei64_v_f64m1_m(vbool64_t, double *, vuint64m1_t, vfloat64m1_t, vfloat64m1_t, vfloat64m1_t, vfloat64m1_t, vfloat64m1_t, vfloat64m1_t, vfloat64m1_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vsuxseg8ei64_v)))
void vsuxseg8ei64_v_f64m1(double *, vuint64m1_t, vfloat64m1_t, vfloat64m1_t, vfloat64m1_t, vfloat64m1_t, vfloat64m1_t, vfloat64m1_t, vfloat64m1_t, vfloat64m1_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vsuxseg8ei64_v_m)))
void vsuxseg8ei64_v_f64m1_m(vbool64_t, double *, vuint64m1_t, vfloat64m1_t, vfloat64m1_t, vfloat64m1_t, vfloat64m1_t, vfloat64m1_t, vfloat64m1_t, vfloat64m1_t, vfloat64m1_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vsoxseg2ei8_v)))
void vsoxseg2ei8_v_f64m1(double *, vuint8mf8_t, vfloat64m1_t, vfloat64m1_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vsoxseg2ei8_v_m)))
void vsoxseg2ei8_v_f64m1_m(vbool64_t, double *, vuint8mf8_t, vfloat64m1_t, vfloat64m1_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vsoxseg2ei8_v)))
void vsoxseg2ei8_v_f64m2(double *, vuint8mf4_t, vfloat64m2_t, vfloat64m2_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vsoxseg2ei8_v_m)))
void vsoxseg2ei8_v_f64m2_m(vbool32_t, double *, vuint8mf4_t, vfloat64m2_t, vfloat64m2_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vsoxseg2ei8_v)))
void vsoxseg2ei8_v_f64m4(double *, vuint8mf2_t, vfloat64m4_t, vfloat64m4_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vsoxseg2ei8_v_m)))
void vsoxseg2ei8_v_f64m4_m(vbool16_t, double *, vuint8mf2_t, vfloat64m4_t, vfloat64m4_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vsoxseg3ei8_v)))
void vsoxseg3ei8_v_f64m1(double *, vuint8mf8_t, vfloat64m1_t, vfloat64m1_t, vfloat64m1_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vsoxseg3ei8_v_m)))
void vsoxseg3ei8_v_f64m1_m(vbool64_t, double *, vuint8mf8_t, vfloat64m1_t, vfloat64m1_t, vfloat64m1_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vsoxseg3ei8_v)))
void vsoxseg3ei8_v_f64m2(double *, vuint8mf4_t, vfloat64m2_t, vfloat64m2_t, vfloat64m2_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vsoxseg3ei8_v_m)))
void vsoxseg3ei8_v_f64m2_m(vbool32_t, double *, vuint8mf4_t, vfloat64m2_t, vfloat64m2_t, vfloat64m2_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vsoxseg4ei8_v)))
void vsoxseg4ei8_v_f64m1(double *, vuint8mf8_t, vfloat64m1_t, vfloat64m1_t, vfloat64m1_t, vfloat64m1_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vsoxseg4ei8_v_m)))
void vsoxseg4ei8_v_f64m1_m(vbool64_t, double *, vuint8mf8_t, vfloat64m1_t, vfloat64m1_t, vfloat64m1_t, vfloat64m1_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vsoxseg4ei8_v)))
void vsoxseg4ei8_v_f64m2(double *, vuint8mf4_t, vfloat64m2_t, vfloat64m2_t, vfloat64m2_t, vfloat64m2_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vsoxseg4ei8_v_m)))
void vsoxseg4ei8_v_f64m2_m(vbool32_t, double *, vuint8mf4_t, vfloat64m2_t, vfloat64m2_t, vfloat64m2_t, vfloat64m2_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vsoxseg5ei8_v)))
void vsoxseg5ei8_v_f64m1(double *, vuint8mf8_t, vfloat64m1_t, vfloat64m1_t, vfloat64m1_t, vfloat64m1_t, vfloat64m1_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vsoxseg5ei8_v_m)))
void vsoxseg5ei8_v_f64m1_m(vbool64_t, double *, vuint8mf8_t, vfloat64m1_t, vfloat64m1_t, vfloat64m1_t, vfloat64m1_t, vfloat64m1_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vsoxseg6ei8_v)))
void vsoxseg6ei8_v_f64m1(double *, vuint8mf8_t, vfloat64m1_t, vfloat64m1_t, vfloat64m1_t, vfloat64m1_t, vfloat64m1_t, vfloat64m1_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vsoxseg6ei8_v_m)))
void vsoxseg6ei8_v_f64m1_m(vbool64_t, double *, vuint8mf8_t, vfloat64m1_t, vfloat64m1_t, vfloat64m1_t, vfloat64m1_t, vfloat64m1_t, vfloat64m1_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vsoxseg7ei8_v)))
void vsoxseg7ei8_v_f64m1(double *, vuint8mf8_t, vfloat64m1_t, vfloat64m1_t, vfloat64m1_t, vfloat64m1_t, vfloat64m1_t, vfloat64m1_t, vfloat64m1_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vsoxseg7ei8_v_m)))
void vsoxseg7ei8_v_f64m1_m(vbool64_t, double *, vuint8mf8_t, vfloat64m1_t, vfloat64m1_t, vfloat64m1_t, vfloat64m1_t, vfloat64m1_t, vfloat64m1_t, vfloat64m1_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vsoxseg8ei8_v)))
void vsoxseg8ei8_v_f64m1(double *, vuint8mf8_t, vfloat64m1_t, vfloat64m1_t, vfloat64m1_t, vfloat64m1_t, vfloat64m1_t, vfloat64m1_t, vfloat64m1_t, vfloat64m1_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vsoxseg8ei8_v_m)))
void vsoxseg8ei8_v_f64m1_m(vbool64_t, double *, vuint8mf8_t, vfloat64m1_t, vfloat64m1_t, vfloat64m1_t, vfloat64m1_t, vfloat64m1_t, vfloat64m1_t, vfloat64m1_t, vfloat64m1_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vsoxseg2ei16_v)))
void vsoxseg2ei16_v_f64m1(double *, vuint16mf4_t, vfloat64m1_t, vfloat64m1_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vsoxseg2ei16_v_m)))
void vsoxseg2ei16_v_f64m1_m(vbool64_t, double *, vuint16mf4_t, vfloat64m1_t, vfloat64m1_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vsoxseg2ei16_v)))
void vsoxseg2ei16_v_f64m2(double *, vuint16mf2_t, vfloat64m2_t, vfloat64m2_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vsoxseg2ei16_v_m)))
void vsoxseg2ei16_v_f64m2_m(vbool32_t, double *, vuint16mf2_t, vfloat64m2_t, vfloat64m2_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vsoxseg2ei16_v)))
void vsoxseg2ei16_v_f64m4(double *, vuint16m1_t, vfloat64m4_t, vfloat64m4_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vsoxseg2ei16_v_m)))
void vsoxseg2ei16_v_f64m4_m(vbool16_t, double *, vuint16m1_t, vfloat64m4_t, vfloat64m4_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vsoxseg3ei16_v)))
void vsoxseg3ei16_v_f64m1(double *, vuint16mf4_t, vfloat64m1_t, vfloat64m1_t, vfloat64m1_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vsoxseg3ei16_v_m)))
void vsoxseg3ei16_v_f64m1_m(vbool64_t, double *, vuint16mf4_t, vfloat64m1_t, vfloat64m1_t, vfloat64m1_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vsoxseg3ei16_v)))
void vsoxseg3ei16_v_f64m2(double *, vuint16mf2_t, vfloat64m2_t, vfloat64m2_t, vfloat64m2_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vsoxseg3ei16_v_m)))
void vsoxseg3ei16_v_f64m2_m(vbool32_t, double *, vuint16mf2_t, vfloat64m2_t, vfloat64m2_t, vfloat64m2_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vsoxseg4ei16_v)))
void vsoxseg4ei16_v_f64m1(double *, vuint16mf4_t, vfloat64m1_t, vfloat64m1_t, vfloat64m1_t, vfloat64m1_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vsoxseg4ei16_v_m)))
void vsoxseg4ei16_v_f64m1_m(vbool64_t, double *, vuint16mf4_t, vfloat64m1_t, vfloat64m1_t, vfloat64m1_t, vfloat64m1_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vsoxseg4ei16_v)))
void vsoxseg4ei16_v_f64m2(double *, vuint16mf2_t, vfloat64m2_t, vfloat64m2_t, vfloat64m2_t, vfloat64m2_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vsoxseg4ei16_v_m)))
void vsoxseg4ei16_v_f64m2_m(vbool32_t, double *, vuint16mf2_t, vfloat64m2_t, vfloat64m2_t, vfloat64m2_t, vfloat64m2_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vsoxseg5ei16_v)))
void vsoxseg5ei16_v_f64m1(double *, vuint16mf4_t, vfloat64m1_t, vfloat64m1_t, vfloat64m1_t, vfloat64m1_t, vfloat64m1_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vsoxseg5ei16_v_m)))
void vsoxseg5ei16_v_f64m1_m(vbool64_t, double *, vuint16mf4_t, vfloat64m1_t, vfloat64m1_t, vfloat64m1_t, vfloat64m1_t, vfloat64m1_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vsoxseg6ei16_v)))
void vsoxseg6ei16_v_f64m1(double *, vuint16mf4_t, vfloat64m1_t, vfloat64m1_t, vfloat64m1_t, vfloat64m1_t, vfloat64m1_t, vfloat64m1_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vsoxseg6ei16_v_m)))
void vsoxseg6ei16_v_f64m1_m(vbool64_t, double *, vuint16mf4_t, vfloat64m1_t, vfloat64m1_t, vfloat64m1_t, vfloat64m1_t, vfloat64m1_t, vfloat64m1_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vsoxseg7ei16_v)))
void vsoxseg7ei16_v_f64m1(double *, vuint16mf4_t, vfloat64m1_t, vfloat64m1_t, vfloat64m1_t, vfloat64m1_t, vfloat64m1_t, vfloat64m1_t, vfloat64m1_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vsoxseg7ei16_v_m)))
void vsoxseg7ei16_v_f64m1_m(vbool64_t, double *, vuint16mf4_t, vfloat64m1_t, vfloat64m1_t, vfloat64m1_t, vfloat64m1_t, vfloat64m1_t, vfloat64m1_t, vfloat64m1_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vsoxseg8ei16_v)))
void vsoxseg8ei16_v_f64m1(double *, vuint16mf4_t, vfloat64m1_t, vfloat64m1_t, vfloat64m1_t, vfloat64m1_t, vfloat64m1_t, vfloat64m1_t, vfloat64m1_t, vfloat64m1_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vsoxseg8ei16_v_m)))
void vsoxseg8ei16_v_f64m1_m(vbool64_t, double *, vuint16mf4_t, vfloat64m1_t, vfloat64m1_t, vfloat64m1_t, vfloat64m1_t, vfloat64m1_t, vfloat64m1_t, vfloat64m1_t, vfloat64m1_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vsoxseg2ei32_v)))
void vsoxseg2ei32_v_f64m1(double *, vuint32mf2_t, vfloat64m1_t, vfloat64m1_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vsoxseg2ei32_v_m)))
void vsoxseg2ei32_v_f64m1_m(vbool64_t, double *, vuint32mf2_t, vfloat64m1_t, vfloat64m1_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vsoxseg2ei32_v)))
void vsoxseg2ei32_v_f64m2(double *, vuint32m1_t, vfloat64m2_t, vfloat64m2_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vsoxseg2ei32_v_m)))
void vsoxseg2ei32_v_f64m2_m(vbool32_t, double *, vuint32m1_t, vfloat64m2_t, vfloat64m2_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vsoxseg2ei32_v)))
void vsoxseg2ei32_v_f64m4(double *, vuint32m2_t, vfloat64m4_t, vfloat64m4_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vsoxseg2ei32_v_m)))
void vsoxseg2ei32_v_f64m4_m(vbool16_t, double *, vuint32m2_t, vfloat64m4_t, vfloat64m4_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vsoxseg3ei32_v)))
void vsoxseg3ei32_v_f64m1(double *, vuint32mf2_t, vfloat64m1_t, vfloat64m1_t, vfloat64m1_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vsoxseg3ei32_v_m)))
void vsoxseg3ei32_v_f64m1_m(vbool64_t, double *, vuint32mf2_t, vfloat64m1_t, vfloat64m1_t, vfloat64m1_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vsoxseg3ei32_v)))
void vsoxseg3ei32_v_f64m2(double *, vuint32m1_t, vfloat64m2_t, vfloat64m2_t, vfloat64m2_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vsoxseg3ei32_v_m)))
void vsoxseg3ei32_v_f64m2_m(vbool32_t, double *, vuint32m1_t, vfloat64m2_t, vfloat64m2_t, vfloat64m2_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vsoxseg4ei32_v)))
void vsoxseg4ei32_v_f64m1(double *, vuint32mf2_t, vfloat64m1_t, vfloat64m1_t, vfloat64m1_t, vfloat64m1_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vsoxseg4ei32_v_m)))
void vsoxseg4ei32_v_f64m1_m(vbool64_t, double *, vuint32mf2_t, vfloat64m1_t, vfloat64m1_t, vfloat64m1_t, vfloat64m1_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vsoxseg4ei32_v)))
void vsoxseg4ei32_v_f64m2(double *, vuint32m1_t, vfloat64m2_t, vfloat64m2_t, vfloat64m2_t, vfloat64m2_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vsoxseg4ei32_v_m)))
void vsoxseg4ei32_v_f64m2_m(vbool32_t, double *, vuint32m1_t, vfloat64m2_t, vfloat64m2_t, vfloat64m2_t, vfloat64m2_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vsoxseg5ei32_v)))
void vsoxseg5ei32_v_f64m1(double *, vuint32mf2_t, vfloat64m1_t, vfloat64m1_t, vfloat64m1_t, vfloat64m1_t, vfloat64m1_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vsoxseg5ei32_v_m)))
void vsoxseg5ei32_v_f64m1_m(vbool64_t, double *, vuint32mf2_t, vfloat64m1_t, vfloat64m1_t, vfloat64m1_t, vfloat64m1_t, vfloat64m1_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vsoxseg6ei32_v)))
void vsoxseg6ei32_v_f64m1(double *, vuint32mf2_t, vfloat64m1_t, vfloat64m1_t, vfloat64m1_t, vfloat64m1_t, vfloat64m1_t, vfloat64m1_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vsoxseg6ei32_v_m)))
void vsoxseg6ei32_v_f64m1_m(vbool64_t, double *, vuint32mf2_t, vfloat64m1_t, vfloat64m1_t, vfloat64m1_t, vfloat64m1_t, vfloat64m1_t, vfloat64m1_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vsoxseg7ei32_v)))
void vsoxseg7ei32_v_f64m1(double *, vuint32mf2_t, vfloat64m1_t, vfloat64m1_t, vfloat64m1_t, vfloat64m1_t, vfloat64m1_t, vfloat64m1_t, vfloat64m1_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vsoxseg7ei32_v_m)))
void vsoxseg7ei32_v_f64m1_m(vbool64_t, double *, vuint32mf2_t, vfloat64m1_t, vfloat64m1_t, vfloat64m1_t, vfloat64m1_t, vfloat64m1_t, vfloat64m1_t, vfloat64m1_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vsoxseg8ei32_v)))
void vsoxseg8ei32_v_f64m1(double *, vuint32mf2_t, vfloat64m1_t, vfloat64m1_t, vfloat64m1_t, vfloat64m1_t, vfloat64m1_t, vfloat64m1_t, vfloat64m1_t, vfloat64m1_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vsoxseg8ei32_v_m)))
void vsoxseg8ei32_v_f64m1_m(vbool64_t, double *, vuint32mf2_t, vfloat64m1_t, vfloat64m1_t, vfloat64m1_t, vfloat64m1_t, vfloat64m1_t, vfloat64m1_t, vfloat64m1_t, vfloat64m1_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vsoxseg2ei64_v)))
void vsoxseg2ei64_v_f64m1(double *, vuint64m1_t, vfloat64m1_t, vfloat64m1_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vsoxseg2ei64_v_m)))
void vsoxseg2ei64_v_f64m1_m(vbool64_t, double *, vuint64m1_t, vfloat64m1_t, vfloat64m1_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vsoxseg2ei64_v)))
void vsoxseg2ei64_v_f64m2(double *, vuint64m2_t, vfloat64m2_t, vfloat64m2_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vsoxseg2ei64_v_m)))
void vsoxseg2ei64_v_f64m2_m(vbool32_t, double *, vuint64m2_t, vfloat64m2_t, vfloat64m2_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vsoxseg2ei64_v)))
void vsoxseg2ei64_v_f64m4(double *, vuint64m4_t, vfloat64m4_t, vfloat64m4_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vsoxseg2ei64_v_m)))
void vsoxseg2ei64_v_f64m4_m(vbool16_t, double *, vuint64m4_t, vfloat64m4_t, vfloat64m4_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vsoxseg3ei64_v)))
void vsoxseg3ei64_v_f64m1(double *, vuint64m1_t, vfloat64m1_t, vfloat64m1_t, vfloat64m1_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vsoxseg3ei64_v_m)))
void vsoxseg3ei64_v_f64m1_m(vbool64_t, double *, vuint64m1_t, vfloat64m1_t, vfloat64m1_t, vfloat64m1_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vsoxseg3ei64_v)))
void vsoxseg3ei64_v_f64m2(double *, vuint64m2_t, vfloat64m2_t, vfloat64m2_t, vfloat64m2_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vsoxseg3ei64_v_m)))
void vsoxseg3ei64_v_f64m2_m(vbool32_t, double *, vuint64m2_t, vfloat64m2_t, vfloat64m2_t, vfloat64m2_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vsoxseg4ei64_v)))
void vsoxseg4ei64_v_f64m1(double *, vuint64m1_t, vfloat64m1_t, vfloat64m1_t, vfloat64m1_t, vfloat64m1_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vsoxseg4ei64_v_m)))
void vsoxseg4ei64_v_f64m1_m(vbool64_t, double *, vuint64m1_t, vfloat64m1_t, vfloat64m1_t, vfloat64m1_t, vfloat64m1_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vsoxseg4ei64_v)))
void vsoxseg4ei64_v_f64m2(double *, vuint64m2_t, vfloat64m2_t, vfloat64m2_t, vfloat64m2_t, vfloat64m2_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vsoxseg4ei64_v_m)))
void vsoxseg4ei64_v_f64m2_m(vbool32_t, double *, vuint64m2_t, vfloat64m2_t, vfloat64m2_t, vfloat64m2_t, vfloat64m2_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vsoxseg5ei64_v)))
void vsoxseg5ei64_v_f64m1(double *, vuint64m1_t, vfloat64m1_t, vfloat64m1_t, vfloat64m1_t, vfloat64m1_t, vfloat64m1_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vsoxseg5ei64_v_m)))
void vsoxseg5ei64_v_f64m1_m(vbool64_t, double *, vuint64m1_t, vfloat64m1_t, vfloat64m1_t, vfloat64m1_t, vfloat64m1_t, vfloat64m1_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vsoxseg6ei64_v)))
void vsoxseg6ei64_v_f64m1(double *, vuint64m1_t, vfloat64m1_t, vfloat64m1_t, vfloat64m1_t, vfloat64m1_t, vfloat64m1_t, vfloat64m1_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vsoxseg6ei64_v_m)))
void vsoxseg6ei64_v_f64m1_m(vbool64_t, double *, vuint64m1_t, vfloat64m1_t, vfloat64m1_t, vfloat64m1_t, vfloat64m1_t, vfloat64m1_t, vfloat64m1_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vsoxseg7ei64_v)))
void vsoxseg7ei64_v_f64m1(double *, vuint64m1_t, vfloat64m1_t, vfloat64m1_t, vfloat64m1_t, vfloat64m1_t, vfloat64m1_t, vfloat64m1_t, vfloat64m1_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vsoxseg7ei64_v_m)))
void vsoxseg7ei64_v_f64m1_m(vbool64_t, double *, vuint64m1_t, vfloat64m1_t, vfloat64m1_t, vfloat64m1_t, vfloat64m1_t, vfloat64m1_t, vfloat64m1_t, vfloat64m1_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vsoxseg8ei64_v)))
void vsoxseg8ei64_v_f64m1(double *, vuint64m1_t, vfloat64m1_t, vfloat64m1_t, vfloat64m1_t, vfloat64m1_t, vfloat64m1_t, vfloat64m1_t, vfloat64m1_t, vfloat64m1_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vsoxseg8ei64_v_m)))
void vsoxseg8ei64_v_f64m1_m(vbool64_t, double *, vuint64m1_t, vfloat64m1_t, vfloat64m1_t, vfloat64m1_t, vfloat64m1_t, vfloat64m1_t, vfloat64m1_t, vfloat64m1_t, vfloat64m1_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vloxei8_v)))
vfloat64m1_t vloxei8_v_f64m1(const double *, vuint8mf8_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vloxei8_v_m)))
vfloat64m1_t vloxei8_v_f64m1_m(vbool64_t, vfloat64m1_t, const double *, vuint8mf8_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vloxei8_v)))
vfloat64m2_t vloxei8_v_f64m2(const double *, vuint8mf4_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vloxei8_v_m)))
vfloat64m2_t vloxei8_v_f64m2_m(vbool32_t, vfloat64m2_t, const double *, vuint8mf4_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vloxei8_v)))
vfloat64m4_t vloxei8_v_f64m4(const double *, vuint8mf2_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vloxei8_v_m)))
vfloat64m4_t vloxei8_v_f64m4_m(vbool16_t, vfloat64m4_t, const double *, vuint8mf2_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vloxei8_v)))
vfloat64m8_t vloxei8_v_f64m8(const double *, vuint8m1_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vloxei8_v_m)))
vfloat64m8_t vloxei8_v_f64m8_m(vbool8_t, vfloat64m8_t, const double *, vuint8m1_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vloxei16_v)))
vfloat64m1_t vloxei16_v_f64m1(const double *, vuint16mf4_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vloxei16_v_m)))
vfloat64m1_t vloxei16_v_f64m1_m(vbool64_t, vfloat64m1_t, const double *, vuint16mf4_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vloxei16_v)))
vfloat64m2_t vloxei16_v_f64m2(const double *, vuint16mf2_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vloxei16_v_m)))
vfloat64m2_t vloxei16_v_f64m2_m(vbool32_t, vfloat64m2_t, const double *, vuint16mf2_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vloxei16_v)))
vfloat64m4_t vloxei16_v_f64m4(const double *, vuint16m1_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vloxei16_v_m)))
vfloat64m4_t vloxei16_v_f64m4_m(vbool16_t, vfloat64m4_t, const double *, vuint16m1_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vloxei16_v)))
vfloat64m8_t vloxei16_v_f64m8(const double *, vuint16m2_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vloxei16_v_m)))
vfloat64m8_t vloxei16_v_f64m8_m(vbool8_t, vfloat64m8_t, const double *, vuint16m2_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vloxei32_v)))
vfloat64m1_t vloxei32_v_f64m1(const double *, vuint32mf2_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vloxei32_v_m)))
vfloat64m1_t vloxei32_v_f64m1_m(vbool64_t, vfloat64m1_t, const double *, vuint32mf2_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vloxei32_v)))
vfloat64m2_t vloxei32_v_f64m2(const double *, vuint32m1_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vloxei32_v_m)))
vfloat64m2_t vloxei32_v_f64m2_m(vbool32_t, vfloat64m2_t, const double *, vuint32m1_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vloxei32_v)))
vfloat64m4_t vloxei32_v_f64m4(const double *, vuint32m2_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vloxei32_v_m)))
vfloat64m4_t vloxei32_v_f64m4_m(vbool16_t, vfloat64m4_t, const double *, vuint32m2_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vloxei32_v)))
vfloat64m8_t vloxei32_v_f64m8(const double *, vuint32m4_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vloxei32_v_m)))
vfloat64m8_t vloxei32_v_f64m8_m(vbool8_t, vfloat64m8_t, const double *, vuint32m4_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vmv_v_v)))
vfloat64m1_t vmv_v_v_f64m1(vfloat64m1_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vmv_v_v)))
vfloat64m2_t vmv_v_v_f64m2(vfloat64m2_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vmv_v_v)))
vfloat64m4_t vmv_v_v_f64m4(vfloat64m4_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vmv_v_v)))
vfloat64m8_t vmv_v_v_f64m8(vfloat64m8_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vfadd_vv)))
vfloat64m1_t vfadd_vv_f64m1(vfloat64m1_t, vfloat64m1_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vfadd_vv_m)))
vfloat64m1_t vfadd_vv_f64m1_m(vbool64_t, vfloat64m1_t, vfloat64m1_t, vfloat64m1_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vfadd_vv)))
vfloat64m2_t vfadd_vv_f64m2(vfloat64m2_t, vfloat64m2_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vfadd_vv_m)))
vfloat64m2_t vfadd_vv_f64m2_m(vbool32_t, vfloat64m2_t, vfloat64m2_t, vfloat64m2_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vfadd_vv)))
vfloat64m4_t vfadd_vv_f64m4(vfloat64m4_t, vfloat64m4_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vfadd_vv_m)))
vfloat64m4_t vfadd_vv_f64m4_m(vbool16_t, vfloat64m4_t, vfloat64m4_t, vfloat64m4_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vfadd_vv)))
vfloat64m8_t vfadd_vv_f64m8(vfloat64m8_t, vfloat64m8_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vfadd_vv_m)))
vfloat64m8_t vfadd_vv_f64m8_m(vbool8_t, vfloat64m8_t, vfloat64m8_t, vfloat64m8_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vfadd_vf)))
vfloat64m1_t vfadd_vf_f64m1(vfloat64m1_t, double, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vfadd_vf_m)))
vfloat64m1_t vfadd_vf_f64m1_m(vbool64_t, vfloat64m1_t, vfloat64m1_t, double, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vfadd_vf)))
vfloat64m2_t vfadd_vf_f64m2(vfloat64m2_t, double, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vfadd_vf_m)))
vfloat64m2_t vfadd_vf_f64m2_m(vbool32_t, vfloat64m2_t, vfloat64m2_t, double, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vfadd_vf)))
vfloat64m4_t vfadd_vf_f64m4(vfloat64m4_t, double, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vfadd_vf_m)))
vfloat64m4_t vfadd_vf_f64m4_m(vbool16_t, vfloat64m4_t, vfloat64m4_t, double, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vfadd_vf)))
vfloat64m8_t vfadd_vf_f64m8(vfloat64m8_t, double, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vfadd_vf_m)))
vfloat64m8_t vfadd_vf_f64m8_m(vbool8_t, vfloat64m8_t, vfloat64m8_t, double, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vfsub_vv)))
vfloat64m1_t vfsub_vv_f64m1(vfloat64m1_t, vfloat64m1_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vfsub_vv_m)))
vfloat64m1_t vfsub_vv_f64m1_m(vbool64_t, vfloat64m1_t, vfloat64m1_t, vfloat64m1_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vfsub_vv)))
vfloat64m2_t vfsub_vv_f64m2(vfloat64m2_t, vfloat64m2_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vfsub_vv_m)))
vfloat64m2_t vfsub_vv_f64m2_m(vbool32_t, vfloat64m2_t, vfloat64m2_t, vfloat64m2_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vfsub_vv)))
vfloat64m4_t vfsub_vv_f64m4(vfloat64m4_t, vfloat64m4_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vfsub_vv_m)))
vfloat64m4_t vfsub_vv_f64m4_m(vbool16_t, vfloat64m4_t, vfloat64m4_t, vfloat64m4_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vfsub_vv)))
vfloat64m8_t vfsub_vv_f64m8(vfloat64m8_t, vfloat64m8_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vfsub_vv_m)))
vfloat64m8_t vfsub_vv_f64m8_m(vbool8_t, vfloat64m8_t, vfloat64m8_t, vfloat64m8_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vfsub_vf)))
vfloat64m1_t vfsub_vf_f64m1(vfloat64m1_t, double, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vfsub_vf_m)))
vfloat64m1_t vfsub_vf_f64m1_m(vbool64_t, vfloat64m1_t, vfloat64m1_t, double, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vfsub_vf)))
vfloat64m2_t vfsub_vf_f64m2(vfloat64m2_t, double, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vfsub_vf_m)))
vfloat64m2_t vfsub_vf_f64m2_m(vbool32_t, vfloat64m2_t, vfloat64m2_t, double, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vfsub_vf)))
vfloat64m4_t vfsub_vf_f64m4(vfloat64m4_t, double, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vfsub_vf_m)))
vfloat64m4_t vfsub_vf_f64m4_m(vbool16_t, vfloat64m4_t, vfloat64m4_t, double, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vfsub_vf)))
vfloat64m8_t vfsub_vf_f64m8(vfloat64m8_t, double, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vfsub_vf_m)))
vfloat64m8_t vfsub_vf_f64m8_m(vbool8_t, vfloat64m8_t, vfloat64m8_t, double, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vfrsub_vf)))
vfloat64m1_t vfrsub_vf_f64m1(vfloat64m1_t, double, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vfrsub_vf_m)))
vfloat64m1_t vfrsub_vf_f64m1_m(vbool64_t, vfloat64m1_t, vfloat64m1_t, double, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vfrsub_vf)))
vfloat64m2_t vfrsub_vf_f64m2(vfloat64m2_t, double, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vfrsub_vf_m)))
vfloat64m2_t vfrsub_vf_f64m2_m(vbool32_t, vfloat64m2_t, vfloat64m2_t, double, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vfrsub_vf)))
vfloat64m4_t vfrsub_vf_f64m4(vfloat64m4_t, double, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vfrsub_vf_m)))
vfloat64m4_t vfrsub_vf_f64m4_m(vbool16_t, vfloat64m4_t, vfloat64m4_t, double, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vfrsub_vf)))
vfloat64m8_t vfrsub_vf_f64m8(vfloat64m8_t, double, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vfrsub_vf_m)))
vfloat64m8_t vfrsub_vf_f64m8_m(vbool8_t, vfloat64m8_t, vfloat64m8_t, double, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vfwadd_wf)))
vfloat64m1_t vfwadd_wf_f64m1(vfloat64m1_t, float, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vfwadd_wf_m)))
vfloat64m1_t vfwadd_wf_f64m1_m(vbool64_t, vfloat64m1_t, vfloat64m1_t, float, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vfwadd_wf)))
vfloat64m2_t vfwadd_wf_f64m2(vfloat64m2_t, float, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vfwadd_wf_m)))
vfloat64m2_t vfwadd_wf_f64m2_m(vbool32_t, vfloat64m2_t, vfloat64m2_t, float, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vfwadd_wf)))
vfloat64m4_t vfwadd_wf_f64m4(vfloat64m4_t, float, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vfwadd_wf_m)))
vfloat64m4_t vfwadd_wf_f64m4_m(vbool16_t, vfloat64m4_t, vfloat64m4_t, float, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vfwadd_wf)))
vfloat64m8_t vfwadd_wf_f64m8(vfloat64m8_t, float, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vfwadd_wf_m)))
vfloat64m8_t vfwadd_wf_f64m8_m(vbool8_t, vfloat64m8_t, vfloat64m8_t, float, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vfwsub_wf)))
vfloat64m1_t vfwsub_wf_f64m1(vfloat64m1_t, float, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vfwsub_wf_m)))
vfloat64m1_t vfwsub_wf_f64m1_m(vbool64_t, vfloat64m1_t, vfloat64m1_t, float, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vfwsub_wf)))
vfloat64m2_t vfwsub_wf_f64m2(vfloat64m2_t, float, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vfwsub_wf_m)))
vfloat64m2_t vfwsub_wf_f64m2_m(vbool32_t, vfloat64m2_t, vfloat64m2_t, float, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vfwsub_wf)))
vfloat64m4_t vfwsub_wf_f64m4(vfloat64m4_t, float, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vfwsub_wf_m)))
vfloat64m4_t vfwsub_wf_f64m4_m(vbool16_t, vfloat64m4_t, vfloat64m4_t, float, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vfwsub_wf)))
vfloat64m8_t vfwsub_wf_f64m8(vfloat64m8_t, float, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vfwsub_wf_m)))
vfloat64m8_t vfwsub_wf_f64m8_m(vbool8_t, vfloat64m8_t, vfloat64m8_t, float, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vfmul_vv)))
vfloat64m1_t vfmul_vv_f64m1(vfloat64m1_t, vfloat64m1_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vfmul_vv_m)))
vfloat64m1_t vfmul_vv_f64m1_m(vbool64_t, vfloat64m1_t, vfloat64m1_t, vfloat64m1_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vfmul_vv)))
vfloat64m2_t vfmul_vv_f64m2(vfloat64m2_t, vfloat64m2_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vfmul_vv_m)))
vfloat64m2_t vfmul_vv_f64m2_m(vbool32_t, vfloat64m2_t, vfloat64m2_t, vfloat64m2_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vfmul_vv)))
vfloat64m4_t vfmul_vv_f64m4(vfloat64m4_t, vfloat64m4_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vfmul_vv_m)))
vfloat64m4_t vfmul_vv_f64m4_m(vbool16_t, vfloat64m4_t, vfloat64m4_t, vfloat64m4_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vfmul_vv)))
vfloat64m8_t vfmul_vv_f64m8(vfloat64m8_t, vfloat64m8_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vfmul_vv_m)))
vfloat64m8_t vfmul_vv_f64m8_m(vbool8_t, vfloat64m8_t, vfloat64m8_t, vfloat64m8_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vfmul_vf)))
vfloat64m1_t vfmul_vf_f64m1(vfloat64m1_t, double, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vfmul_vf_m)))
vfloat64m1_t vfmul_vf_f64m1_m(vbool64_t, vfloat64m1_t, vfloat64m1_t, double, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vfmul_vf)))
vfloat64m2_t vfmul_vf_f64m2(vfloat64m2_t, double, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vfmul_vf_m)))
vfloat64m2_t vfmul_vf_f64m2_m(vbool32_t, vfloat64m2_t, vfloat64m2_t, double, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vfmul_vf)))
vfloat64m4_t vfmul_vf_f64m4(vfloat64m4_t, double, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vfmul_vf_m)))
vfloat64m4_t vfmul_vf_f64m4_m(vbool16_t, vfloat64m4_t, vfloat64m4_t, double, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vfmul_vf)))
vfloat64m8_t vfmul_vf_f64m8(vfloat64m8_t, double, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vfmul_vf_m)))
vfloat64m8_t vfmul_vf_f64m8_m(vbool8_t, vfloat64m8_t, vfloat64m8_t, double, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vfdiv_vv)))
vfloat64m1_t vfdiv_vv_f64m1(vfloat64m1_t, vfloat64m1_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vfdiv_vv_m)))
vfloat64m1_t vfdiv_vv_f64m1_m(vbool64_t, vfloat64m1_t, vfloat64m1_t, vfloat64m1_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vfdiv_vv)))
vfloat64m2_t vfdiv_vv_f64m2(vfloat64m2_t, vfloat64m2_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vfdiv_vv_m)))
vfloat64m2_t vfdiv_vv_f64m2_m(vbool32_t, vfloat64m2_t, vfloat64m2_t, vfloat64m2_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vfdiv_vv)))
vfloat64m4_t vfdiv_vv_f64m4(vfloat64m4_t, vfloat64m4_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vfdiv_vv_m)))
vfloat64m4_t vfdiv_vv_f64m4_m(vbool16_t, vfloat64m4_t, vfloat64m4_t, vfloat64m4_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vfdiv_vv)))
vfloat64m8_t vfdiv_vv_f64m8(vfloat64m8_t, vfloat64m8_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vfdiv_vv_m)))
vfloat64m8_t vfdiv_vv_f64m8_m(vbool8_t, vfloat64m8_t, vfloat64m8_t, vfloat64m8_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vfdiv_vf)))
vfloat64m1_t vfdiv_vf_f64m1(vfloat64m1_t, double, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vfdiv_vf_m)))
vfloat64m1_t vfdiv_vf_f64m1_m(vbool64_t, vfloat64m1_t, vfloat64m1_t, double, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vfdiv_vf)))
vfloat64m2_t vfdiv_vf_f64m2(vfloat64m2_t, double, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vfdiv_vf_m)))
vfloat64m2_t vfdiv_vf_f64m2_m(vbool32_t, vfloat64m2_t, vfloat64m2_t, double, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vfdiv_vf)))
vfloat64m4_t vfdiv_vf_f64m4(vfloat64m4_t, double, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vfdiv_vf_m)))
vfloat64m4_t vfdiv_vf_f64m4_m(vbool16_t, vfloat64m4_t, vfloat64m4_t, double, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vfdiv_vf)))
vfloat64m8_t vfdiv_vf_f64m8(vfloat64m8_t, double, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vfdiv_vf_m)))
vfloat64m8_t vfdiv_vf_f64m8_m(vbool8_t, vfloat64m8_t, vfloat64m8_t, double, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vfrdiv_vf)))
vfloat64m1_t vfrdiv_vf_f64m1(vfloat64m1_t, double, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vfrdiv_vf_m)))
vfloat64m1_t vfrdiv_vf_f64m1_m(vbool64_t, vfloat64m1_t, vfloat64m1_t, double, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vfrdiv_vf)))
vfloat64m2_t vfrdiv_vf_f64m2(vfloat64m2_t, double, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vfrdiv_vf_m)))
vfloat64m2_t vfrdiv_vf_f64m2_m(vbool32_t, vfloat64m2_t, vfloat64m2_t, double, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vfrdiv_vf)))
vfloat64m4_t vfrdiv_vf_f64m4(vfloat64m4_t, double, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vfrdiv_vf_m)))
vfloat64m4_t vfrdiv_vf_f64m4_m(vbool16_t, vfloat64m4_t, vfloat64m4_t, double, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vfrdiv_vf)))
vfloat64m8_t vfrdiv_vf_f64m8(vfloat64m8_t, double, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vfrdiv_vf_m)))
vfloat64m8_t vfrdiv_vf_f64m8_m(vbool8_t, vfloat64m8_t, vfloat64m8_t, double, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vfmacc_vv)))
vfloat64m1_t vfmacc_vv_f64m1(vfloat64m1_t, vfloat64m1_t, vfloat64m1_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vfmacc_vv_m)))
vfloat64m1_t vfmacc_vv_f64m1_m(vbool64_t, vfloat64m1_t, vfloat64m1_t, vfloat64m1_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vfmacc_vv)))
vfloat64m2_t vfmacc_vv_f64m2(vfloat64m2_t, vfloat64m2_t, vfloat64m2_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vfmacc_vv_m)))
vfloat64m2_t vfmacc_vv_f64m2_m(vbool32_t, vfloat64m2_t, vfloat64m2_t, vfloat64m2_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vfmacc_vv)))
vfloat64m4_t vfmacc_vv_f64m4(vfloat64m4_t, vfloat64m4_t, vfloat64m4_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vfmacc_vv_m)))
vfloat64m4_t vfmacc_vv_f64m4_m(vbool16_t, vfloat64m4_t, vfloat64m4_t, vfloat64m4_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vfmacc_vv)))
vfloat64m8_t vfmacc_vv_f64m8(vfloat64m8_t, vfloat64m8_t, vfloat64m8_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vfmacc_vv_m)))
vfloat64m8_t vfmacc_vv_f64m8_m(vbool8_t, vfloat64m8_t, vfloat64m8_t, vfloat64m8_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vfmacc_vf)))
vfloat64m1_t vfmacc_vf_f64m1(vfloat64m1_t, double, vfloat64m1_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vfmacc_vf_m)))
vfloat64m1_t vfmacc_vf_f64m1_m(vbool64_t, vfloat64m1_t, double, vfloat64m1_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vfmacc_vf)))
vfloat64m2_t vfmacc_vf_f64m2(vfloat64m2_t, double, vfloat64m2_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vfmacc_vf_m)))
vfloat64m2_t vfmacc_vf_f64m2_m(vbool32_t, vfloat64m2_t, double, vfloat64m2_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vfmacc_vf)))
vfloat64m4_t vfmacc_vf_f64m4(vfloat64m4_t, double, vfloat64m4_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vfmacc_vf_m)))
vfloat64m4_t vfmacc_vf_f64m4_m(vbool16_t, vfloat64m4_t, double, vfloat64m4_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vfmacc_vf)))
vfloat64m8_t vfmacc_vf_f64m8(vfloat64m8_t, double, vfloat64m8_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vfmacc_vf_m)))
vfloat64m8_t vfmacc_vf_f64m8_m(vbool8_t, vfloat64m8_t, double, vfloat64m8_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vfnmacc_vv)))
vfloat64m1_t vfnmacc_vv_f64m1(vfloat64m1_t, vfloat64m1_t, vfloat64m1_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vfnmacc_vv_m)))
vfloat64m1_t vfnmacc_vv_f64m1_m(vbool64_t, vfloat64m1_t, vfloat64m1_t, vfloat64m1_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vfnmacc_vv)))
vfloat64m2_t vfnmacc_vv_f64m2(vfloat64m2_t, vfloat64m2_t, vfloat64m2_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vfnmacc_vv_m)))
vfloat64m2_t vfnmacc_vv_f64m2_m(vbool32_t, vfloat64m2_t, vfloat64m2_t, vfloat64m2_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vfnmacc_vv)))
vfloat64m4_t vfnmacc_vv_f64m4(vfloat64m4_t, vfloat64m4_t, vfloat64m4_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vfnmacc_vv_m)))
vfloat64m4_t vfnmacc_vv_f64m4_m(vbool16_t, vfloat64m4_t, vfloat64m4_t, vfloat64m4_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vfnmacc_vv)))
vfloat64m8_t vfnmacc_vv_f64m8(vfloat64m8_t, vfloat64m8_t, vfloat64m8_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vfnmacc_vv_m)))
vfloat64m8_t vfnmacc_vv_f64m8_m(vbool8_t, vfloat64m8_t, vfloat64m8_t, vfloat64m8_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vfnmacc_vf)))
vfloat64m1_t vfnmacc_vf_f64m1(vfloat64m1_t, double, vfloat64m1_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vfnmacc_vf_m)))
vfloat64m1_t vfnmacc_vf_f64m1_m(vbool64_t, vfloat64m1_t, double, vfloat64m1_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vfnmacc_vf)))
vfloat64m2_t vfnmacc_vf_f64m2(vfloat64m2_t, double, vfloat64m2_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vfnmacc_vf_m)))
vfloat64m2_t vfnmacc_vf_f64m2_m(vbool32_t, vfloat64m2_t, double, vfloat64m2_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vfnmacc_vf)))
vfloat64m4_t vfnmacc_vf_f64m4(vfloat64m4_t, double, vfloat64m4_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vfnmacc_vf_m)))
vfloat64m4_t vfnmacc_vf_f64m4_m(vbool16_t, vfloat64m4_t, double, vfloat64m4_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vfnmacc_vf)))
vfloat64m8_t vfnmacc_vf_f64m8(vfloat64m8_t, double, vfloat64m8_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vfnmacc_vf_m)))
vfloat64m8_t vfnmacc_vf_f64m8_m(vbool8_t, vfloat64m8_t, double, vfloat64m8_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vfmsac_vv)))
vfloat64m1_t vfmsac_vv_f64m1(vfloat64m1_t, vfloat64m1_t, vfloat64m1_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vfmsac_vv_m)))
vfloat64m1_t vfmsac_vv_f64m1_m(vbool64_t, vfloat64m1_t, vfloat64m1_t, vfloat64m1_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vfmsac_vv)))
vfloat64m2_t vfmsac_vv_f64m2(vfloat64m2_t, vfloat64m2_t, vfloat64m2_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vfmsac_vv_m)))
vfloat64m2_t vfmsac_vv_f64m2_m(vbool32_t, vfloat64m2_t, vfloat64m2_t, vfloat64m2_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vfmsac_vv)))
vfloat64m4_t vfmsac_vv_f64m4(vfloat64m4_t, vfloat64m4_t, vfloat64m4_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vfmsac_vv_m)))
vfloat64m4_t vfmsac_vv_f64m4_m(vbool16_t, vfloat64m4_t, vfloat64m4_t, vfloat64m4_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vfmsac_vv)))
vfloat64m8_t vfmsac_vv_f64m8(vfloat64m8_t, vfloat64m8_t, vfloat64m8_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vfmsac_vv_m)))
vfloat64m8_t vfmsac_vv_f64m8_m(vbool8_t, vfloat64m8_t, vfloat64m8_t, vfloat64m8_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vfmsac_vf)))
vfloat64m1_t vfmsac_vf_f64m1(vfloat64m1_t, double, vfloat64m1_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vfmsac_vf_m)))
vfloat64m1_t vfmsac_vf_f64m1_m(vbool64_t, vfloat64m1_t, double, vfloat64m1_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vfmsac_vf)))
vfloat64m2_t vfmsac_vf_f64m2(vfloat64m2_t, double, vfloat64m2_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vfmsac_vf_m)))
vfloat64m2_t vfmsac_vf_f64m2_m(vbool32_t, vfloat64m2_t, double, vfloat64m2_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vfmsac_vf)))
vfloat64m4_t vfmsac_vf_f64m4(vfloat64m4_t, double, vfloat64m4_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vfmsac_vf_m)))
vfloat64m4_t vfmsac_vf_f64m4_m(vbool16_t, vfloat64m4_t, double, vfloat64m4_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vfmsac_vf)))
vfloat64m8_t vfmsac_vf_f64m8(vfloat64m8_t, double, vfloat64m8_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vfmsac_vf_m)))
vfloat64m8_t vfmsac_vf_f64m8_m(vbool8_t, vfloat64m8_t, double, vfloat64m8_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vfnmsac_vv)))
vfloat64m1_t vfnmsac_vv_f64m1(vfloat64m1_t, vfloat64m1_t, vfloat64m1_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vfnmsac_vv_m)))
vfloat64m1_t vfnmsac_vv_f64m1_m(vbool64_t, vfloat64m1_t, vfloat64m1_t, vfloat64m1_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vfnmsac_vv)))
vfloat64m2_t vfnmsac_vv_f64m2(vfloat64m2_t, vfloat64m2_t, vfloat64m2_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vfnmsac_vv_m)))
vfloat64m2_t vfnmsac_vv_f64m2_m(vbool32_t, vfloat64m2_t, vfloat64m2_t, vfloat64m2_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vfnmsac_vv)))
vfloat64m4_t vfnmsac_vv_f64m4(vfloat64m4_t, vfloat64m4_t, vfloat64m4_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vfnmsac_vv_m)))
vfloat64m4_t vfnmsac_vv_f64m4_m(vbool16_t, vfloat64m4_t, vfloat64m4_t, vfloat64m4_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vfnmsac_vv)))
vfloat64m8_t vfnmsac_vv_f64m8(vfloat64m8_t, vfloat64m8_t, vfloat64m8_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vfnmsac_vv_m)))
vfloat64m8_t vfnmsac_vv_f64m8_m(vbool8_t, vfloat64m8_t, vfloat64m8_t, vfloat64m8_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vfnmsac_vf)))
vfloat64m1_t vfnmsac_vf_f64m1(vfloat64m1_t, double, vfloat64m1_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vfnmsac_vf_m)))
vfloat64m1_t vfnmsac_vf_f64m1_m(vbool64_t, vfloat64m1_t, double, vfloat64m1_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vfnmsac_vf)))
vfloat64m2_t vfnmsac_vf_f64m2(vfloat64m2_t, double, vfloat64m2_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vfnmsac_vf_m)))
vfloat64m2_t vfnmsac_vf_f64m2_m(vbool32_t, vfloat64m2_t, double, vfloat64m2_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vfnmsac_vf)))
vfloat64m4_t vfnmsac_vf_f64m4(vfloat64m4_t, double, vfloat64m4_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vfnmsac_vf_m)))
vfloat64m4_t vfnmsac_vf_f64m4_m(vbool16_t, vfloat64m4_t, double, vfloat64m4_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vfnmsac_vf)))
vfloat64m8_t vfnmsac_vf_f64m8(vfloat64m8_t, double, vfloat64m8_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vfnmsac_vf_m)))
vfloat64m8_t vfnmsac_vf_f64m8_m(vbool8_t, vfloat64m8_t, double, vfloat64m8_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vfmadd_vv)))
vfloat64m1_t vfmadd_vv_f64m1(vfloat64m1_t, vfloat64m1_t, vfloat64m1_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vfmadd_vv_m)))
vfloat64m1_t vfmadd_vv_f64m1_m(vbool64_t, vfloat64m1_t, vfloat64m1_t, vfloat64m1_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vfmadd_vv)))
vfloat64m2_t vfmadd_vv_f64m2(vfloat64m2_t, vfloat64m2_t, vfloat64m2_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vfmadd_vv_m)))
vfloat64m2_t vfmadd_vv_f64m2_m(vbool32_t, vfloat64m2_t, vfloat64m2_t, vfloat64m2_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vfmadd_vv)))
vfloat64m4_t vfmadd_vv_f64m4(vfloat64m4_t, vfloat64m4_t, vfloat64m4_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vfmadd_vv_m)))
vfloat64m4_t vfmadd_vv_f64m4_m(vbool16_t, vfloat64m4_t, vfloat64m4_t, vfloat64m4_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vfmadd_vv)))
vfloat64m8_t vfmadd_vv_f64m8(vfloat64m8_t, vfloat64m8_t, vfloat64m8_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vfmadd_vv_m)))
vfloat64m8_t vfmadd_vv_f64m8_m(vbool8_t, vfloat64m8_t, vfloat64m8_t, vfloat64m8_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vfmadd_vf)))
vfloat64m1_t vfmadd_vf_f64m1(vfloat64m1_t, double, vfloat64m1_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vfmadd_vf_m)))
vfloat64m1_t vfmadd_vf_f64m1_m(vbool64_t, vfloat64m1_t, double, vfloat64m1_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vfmadd_vf)))
vfloat64m2_t vfmadd_vf_f64m2(vfloat64m2_t, double, vfloat64m2_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vfmadd_vf_m)))
vfloat64m2_t vfmadd_vf_f64m2_m(vbool32_t, vfloat64m2_t, double, vfloat64m2_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vfmadd_vf)))
vfloat64m4_t vfmadd_vf_f64m4(vfloat64m4_t, double, vfloat64m4_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vfmadd_vf_m)))
vfloat64m4_t vfmadd_vf_f64m4_m(vbool16_t, vfloat64m4_t, double, vfloat64m4_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vfmadd_vf)))
vfloat64m8_t vfmadd_vf_f64m8(vfloat64m8_t, double, vfloat64m8_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vfmadd_vf_m)))
vfloat64m8_t vfmadd_vf_f64m8_m(vbool8_t, vfloat64m8_t, double, vfloat64m8_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vfnmadd_vv)))
vfloat64m1_t vfnmadd_vv_f64m1(vfloat64m1_t, vfloat64m1_t, vfloat64m1_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vfnmadd_vv_m)))
vfloat64m1_t vfnmadd_vv_f64m1_m(vbool64_t, vfloat64m1_t, vfloat64m1_t, vfloat64m1_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vfnmadd_vv)))
vfloat64m2_t vfnmadd_vv_f64m2(vfloat64m2_t, vfloat64m2_t, vfloat64m2_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vfnmadd_vv_m)))
vfloat64m2_t vfnmadd_vv_f64m2_m(vbool32_t, vfloat64m2_t, vfloat64m2_t, vfloat64m2_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vfnmadd_vv)))
vfloat64m4_t vfnmadd_vv_f64m4(vfloat64m4_t, vfloat64m4_t, vfloat64m4_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vfnmadd_vv_m)))
vfloat64m4_t vfnmadd_vv_f64m4_m(vbool16_t, vfloat64m4_t, vfloat64m4_t, vfloat64m4_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vfnmadd_vv)))
vfloat64m8_t vfnmadd_vv_f64m8(vfloat64m8_t, vfloat64m8_t, vfloat64m8_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vfnmadd_vv_m)))
vfloat64m8_t vfnmadd_vv_f64m8_m(vbool8_t, vfloat64m8_t, vfloat64m8_t, vfloat64m8_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vfnmadd_vf)))
vfloat64m1_t vfnmadd_vf_f64m1(vfloat64m1_t, double, vfloat64m1_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vfnmadd_vf_m)))
vfloat64m1_t vfnmadd_vf_f64m1_m(vbool64_t, vfloat64m1_t, double, vfloat64m1_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vfnmadd_vf)))
vfloat64m2_t vfnmadd_vf_f64m2(vfloat64m2_t, double, vfloat64m2_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vfnmadd_vf_m)))
vfloat64m2_t vfnmadd_vf_f64m2_m(vbool32_t, vfloat64m2_t, double, vfloat64m2_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vfnmadd_vf)))
vfloat64m4_t vfnmadd_vf_f64m4(vfloat64m4_t, double, vfloat64m4_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vfnmadd_vf_m)))
vfloat64m4_t vfnmadd_vf_f64m4_m(vbool16_t, vfloat64m4_t, double, vfloat64m4_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vfnmadd_vf)))
vfloat64m8_t vfnmadd_vf_f64m8(vfloat64m8_t, double, vfloat64m8_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vfnmadd_vf_m)))
vfloat64m8_t vfnmadd_vf_f64m8_m(vbool8_t, vfloat64m8_t, double, vfloat64m8_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vfmsub_vv)))
vfloat64m1_t vfmsub_vv_f64m1(vfloat64m1_t, vfloat64m1_t, vfloat64m1_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vfmsub_vv_m)))
vfloat64m1_t vfmsub_vv_f64m1_m(vbool64_t, vfloat64m1_t, vfloat64m1_t, vfloat64m1_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vfmsub_vv)))
vfloat64m2_t vfmsub_vv_f64m2(vfloat64m2_t, vfloat64m2_t, vfloat64m2_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vfmsub_vv_m)))
vfloat64m2_t vfmsub_vv_f64m2_m(vbool32_t, vfloat64m2_t, vfloat64m2_t, vfloat64m2_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vfmsub_vv)))
vfloat64m4_t vfmsub_vv_f64m4(vfloat64m4_t, vfloat64m4_t, vfloat64m4_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vfmsub_vv_m)))
vfloat64m4_t vfmsub_vv_f64m4_m(vbool16_t, vfloat64m4_t, vfloat64m4_t, vfloat64m4_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vfmsub_vv)))
vfloat64m8_t vfmsub_vv_f64m8(vfloat64m8_t, vfloat64m8_t, vfloat64m8_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vfmsub_vv_m)))
vfloat64m8_t vfmsub_vv_f64m8_m(vbool8_t, vfloat64m8_t, vfloat64m8_t, vfloat64m8_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vfmsub_vf)))
vfloat64m1_t vfmsub_vf_f64m1(vfloat64m1_t, double, vfloat64m1_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vfmsub_vf_m)))
vfloat64m1_t vfmsub_vf_f64m1_m(vbool64_t, vfloat64m1_t, double, vfloat64m1_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vfmsub_vf)))
vfloat64m2_t vfmsub_vf_f64m2(vfloat64m2_t, double, vfloat64m2_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vfmsub_vf_m)))
vfloat64m2_t vfmsub_vf_f64m2_m(vbool32_t, vfloat64m2_t, double, vfloat64m2_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vfmsub_vf)))
vfloat64m4_t vfmsub_vf_f64m4(vfloat64m4_t, double, vfloat64m4_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vfmsub_vf_m)))
vfloat64m4_t vfmsub_vf_f64m4_m(vbool16_t, vfloat64m4_t, double, vfloat64m4_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vfmsub_vf)))
vfloat64m8_t vfmsub_vf_f64m8(vfloat64m8_t, double, vfloat64m8_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vfmsub_vf_m)))
vfloat64m8_t vfmsub_vf_f64m8_m(vbool8_t, vfloat64m8_t, double, vfloat64m8_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vfnmsub_vv)))
vfloat64m1_t vfnmsub_vv_f64m1(vfloat64m1_t, vfloat64m1_t, vfloat64m1_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vfnmsub_vv_m)))
vfloat64m1_t vfnmsub_vv_f64m1_m(vbool64_t, vfloat64m1_t, vfloat64m1_t, vfloat64m1_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vfnmsub_vv)))
vfloat64m2_t vfnmsub_vv_f64m2(vfloat64m2_t, vfloat64m2_t, vfloat64m2_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vfnmsub_vv_m)))
vfloat64m2_t vfnmsub_vv_f64m2_m(vbool32_t, vfloat64m2_t, vfloat64m2_t, vfloat64m2_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vfnmsub_vv)))
vfloat64m4_t vfnmsub_vv_f64m4(vfloat64m4_t, vfloat64m4_t, vfloat64m4_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vfnmsub_vv_m)))
vfloat64m4_t vfnmsub_vv_f64m4_m(vbool16_t, vfloat64m4_t, vfloat64m4_t, vfloat64m4_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vfnmsub_vv)))
vfloat64m8_t vfnmsub_vv_f64m8(vfloat64m8_t, vfloat64m8_t, vfloat64m8_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vfnmsub_vv_m)))
vfloat64m8_t vfnmsub_vv_f64m8_m(vbool8_t, vfloat64m8_t, vfloat64m8_t, vfloat64m8_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vfnmsub_vf)))
vfloat64m1_t vfnmsub_vf_f64m1(vfloat64m1_t, double, vfloat64m1_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vfnmsub_vf_m)))
vfloat64m1_t vfnmsub_vf_f64m1_m(vbool64_t, vfloat64m1_t, double, vfloat64m1_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vfnmsub_vf)))
vfloat64m2_t vfnmsub_vf_f64m2(vfloat64m2_t, double, vfloat64m2_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vfnmsub_vf_m)))
vfloat64m2_t vfnmsub_vf_f64m2_m(vbool32_t, vfloat64m2_t, double, vfloat64m2_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vfnmsub_vf)))
vfloat64m4_t vfnmsub_vf_f64m4(vfloat64m4_t, double, vfloat64m4_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vfnmsub_vf_m)))
vfloat64m4_t vfnmsub_vf_f64m4_m(vbool16_t, vfloat64m4_t, double, vfloat64m4_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vfnmsub_vf)))
vfloat64m8_t vfnmsub_vf_f64m8(vfloat64m8_t, double, vfloat64m8_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vfnmsub_vf_m)))
vfloat64m8_t vfnmsub_vf_f64m8_m(vbool8_t, vfloat64m8_t, double, vfloat64m8_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vfmin_vv)))
vfloat64m1_t vfmin_vv_f64m1(vfloat64m1_t, vfloat64m1_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vfmin_vv_m)))
vfloat64m1_t vfmin_vv_f64m1_m(vbool64_t, vfloat64m1_t, vfloat64m1_t, vfloat64m1_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vfmin_vv)))
vfloat64m2_t vfmin_vv_f64m2(vfloat64m2_t, vfloat64m2_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vfmin_vv_m)))
vfloat64m2_t vfmin_vv_f64m2_m(vbool32_t, vfloat64m2_t, vfloat64m2_t, vfloat64m2_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vfmin_vv)))
vfloat64m4_t vfmin_vv_f64m4(vfloat64m4_t, vfloat64m4_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vfmin_vv_m)))
vfloat64m4_t vfmin_vv_f64m4_m(vbool16_t, vfloat64m4_t, vfloat64m4_t, vfloat64m4_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vfmin_vv)))
vfloat64m8_t vfmin_vv_f64m8(vfloat64m8_t, vfloat64m8_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vfmin_vv_m)))
vfloat64m8_t vfmin_vv_f64m8_m(vbool8_t, vfloat64m8_t, vfloat64m8_t, vfloat64m8_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vfmin_vf)))
vfloat64m1_t vfmin_vf_f64m1(vfloat64m1_t, double, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vfmin_vf_m)))
vfloat64m1_t vfmin_vf_f64m1_m(vbool64_t, vfloat64m1_t, vfloat64m1_t, double, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vfmin_vf)))
vfloat64m2_t vfmin_vf_f64m2(vfloat64m2_t, double, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vfmin_vf_m)))
vfloat64m2_t vfmin_vf_f64m2_m(vbool32_t, vfloat64m2_t, vfloat64m2_t, double, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vfmin_vf)))
vfloat64m4_t vfmin_vf_f64m4(vfloat64m4_t, double, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vfmin_vf_m)))
vfloat64m4_t vfmin_vf_f64m4_m(vbool16_t, vfloat64m4_t, vfloat64m4_t, double, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vfmin_vf)))
vfloat64m8_t vfmin_vf_f64m8(vfloat64m8_t, double, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vfmin_vf_m)))
vfloat64m8_t vfmin_vf_f64m8_m(vbool8_t, vfloat64m8_t, vfloat64m8_t, double, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vfmax_vv)))
vfloat64m1_t vfmax_vv_f64m1(vfloat64m1_t, vfloat64m1_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vfmax_vv_m)))
vfloat64m1_t vfmax_vv_f64m1_m(vbool64_t, vfloat64m1_t, vfloat64m1_t, vfloat64m1_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vfmax_vv)))
vfloat64m2_t vfmax_vv_f64m2(vfloat64m2_t, vfloat64m2_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vfmax_vv_m)))
vfloat64m2_t vfmax_vv_f64m2_m(vbool32_t, vfloat64m2_t, vfloat64m2_t, vfloat64m2_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vfmax_vv)))
vfloat64m4_t vfmax_vv_f64m4(vfloat64m4_t, vfloat64m4_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vfmax_vv_m)))
vfloat64m4_t vfmax_vv_f64m4_m(vbool16_t, vfloat64m4_t, vfloat64m4_t, vfloat64m4_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vfmax_vv)))
vfloat64m8_t vfmax_vv_f64m8(vfloat64m8_t, vfloat64m8_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vfmax_vv_m)))
vfloat64m8_t vfmax_vv_f64m8_m(vbool8_t, vfloat64m8_t, vfloat64m8_t, vfloat64m8_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vfmax_vf)))
vfloat64m1_t vfmax_vf_f64m1(vfloat64m1_t, double, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vfmax_vf_m)))
vfloat64m1_t vfmax_vf_f64m1_m(vbool64_t, vfloat64m1_t, vfloat64m1_t, double, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vfmax_vf)))
vfloat64m2_t vfmax_vf_f64m2(vfloat64m2_t, double, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vfmax_vf_m)))
vfloat64m2_t vfmax_vf_f64m2_m(vbool32_t, vfloat64m2_t, vfloat64m2_t, double, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vfmax_vf)))
vfloat64m4_t vfmax_vf_f64m4(vfloat64m4_t, double, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vfmax_vf_m)))
vfloat64m4_t vfmax_vf_f64m4_m(vbool16_t, vfloat64m4_t, vfloat64m4_t, double, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vfmax_vf)))
vfloat64m8_t vfmax_vf_f64m8(vfloat64m8_t, double, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vfmax_vf_m)))
vfloat64m8_t vfmax_vf_f64m8_m(vbool8_t, vfloat64m8_t, vfloat64m8_t, double, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vfsgnj_vv)))
vfloat64m1_t vfsgnj_vv_f64m1(vfloat64m1_t, vfloat64m1_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vfsgnj_vv_m)))
vfloat64m1_t vfsgnj_vv_f64m1_m(vbool64_t, vfloat64m1_t, vfloat64m1_t, vfloat64m1_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vfsgnj_vv)))
vfloat64m2_t vfsgnj_vv_f64m2(vfloat64m2_t, vfloat64m2_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vfsgnj_vv_m)))
vfloat64m2_t vfsgnj_vv_f64m2_m(vbool32_t, vfloat64m2_t, vfloat64m2_t, vfloat64m2_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vfsgnj_vv)))
vfloat64m4_t vfsgnj_vv_f64m4(vfloat64m4_t, vfloat64m4_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vfsgnj_vv_m)))
vfloat64m4_t vfsgnj_vv_f64m4_m(vbool16_t, vfloat64m4_t, vfloat64m4_t, vfloat64m4_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vfsgnj_vv)))
vfloat64m8_t vfsgnj_vv_f64m8(vfloat64m8_t, vfloat64m8_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vfsgnj_vv_m)))
vfloat64m8_t vfsgnj_vv_f64m8_m(vbool8_t, vfloat64m8_t, vfloat64m8_t, vfloat64m8_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vfsgnj_vf)))
vfloat64m1_t vfsgnj_vf_f64m1(vfloat64m1_t, double, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vfsgnj_vf_m)))
vfloat64m1_t vfsgnj_vf_f64m1_m(vbool64_t, vfloat64m1_t, vfloat64m1_t, double, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vfsgnj_vf)))
vfloat64m2_t vfsgnj_vf_f64m2(vfloat64m2_t, double, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vfsgnj_vf_m)))
vfloat64m2_t vfsgnj_vf_f64m2_m(vbool32_t, vfloat64m2_t, vfloat64m2_t, double, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vfsgnj_vf)))
vfloat64m4_t vfsgnj_vf_f64m4(vfloat64m4_t, double, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vfsgnj_vf_m)))
vfloat64m4_t vfsgnj_vf_f64m4_m(vbool16_t, vfloat64m4_t, vfloat64m4_t, double, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vfsgnj_vf)))
vfloat64m8_t vfsgnj_vf_f64m8(vfloat64m8_t, double, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vfsgnj_vf_m)))
vfloat64m8_t vfsgnj_vf_f64m8_m(vbool8_t, vfloat64m8_t, vfloat64m8_t, double, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vfsgnjn_vv)))
vfloat64m1_t vfsgnjn_vv_f64m1(vfloat64m1_t, vfloat64m1_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vfsgnjn_vv_m)))
vfloat64m1_t vfsgnjn_vv_f64m1_m(vbool64_t, vfloat64m1_t, vfloat64m1_t, vfloat64m1_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vfsgnjn_vv)))
vfloat64m2_t vfsgnjn_vv_f64m2(vfloat64m2_t, vfloat64m2_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vfsgnjn_vv_m)))
vfloat64m2_t vfsgnjn_vv_f64m2_m(vbool32_t, vfloat64m2_t, vfloat64m2_t, vfloat64m2_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vfsgnjn_vv)))
vfloat64m4_t vfsgnjn_vv_f64m4(vfloat64m4_t, vfloat64m4_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vfsgnjn_vv_m)))
vfloat64m4_t vfsgnjn_vv_f64m4_m(vbool16_t, vfloat64m4_t, vfloat64m4_t, vfloat64m4_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vfsgnjn_vv)))
vfloat64m8_t vfsgnjn_vv_f64m8(vfloat64m8_t, vfloat64m8_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vfsgnjn_vv_m)))
vfloat64m8_t vfsgnjn_vv_f64m8_m(vbool8_t, vfloat64m8_t, vfloat64m8_t, vfloat64m8_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vfsgnjn_vf)))
vfloat64m1_t vfsgnjn_vf_f64m1(vfloat64m1_t, double, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vfsgnjn_vf_m)))
vfloat64m1_t vfsgnjn_vf_f64m1_m(vbool64_t, vfloat64m1_t, vfloat64m1_t, double, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vfsgnjn_vf)))
vfloat64m2_t vfsgnjn_vf_f64m2(vfloat64m2_t, double, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vfsgnjn_vf_m)))
vfloat64m2_t vfsgnjn_vf_f64m2_m(vbool32_t, vfloat64m2_t, vfloat64m2_t, double, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vfsgnjn_vf)))
vfloat64m4_t vfsgnjn_vf_f64m4(vfloat64m4_t, double, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vfsgnjn_vf_m)))
vfloat64m4_t vfsgnjn_vf_f64m4_m(vbool16_t, vfloat64m4_t, vfloat64m4_t, double, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vfsgnjn_vf)))
vfloat64m8_t vfsgnjn_vf_f64m8(vfloat64m8_t, double, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vfsgnjn_vf_m)))
vfloat64m8_t vfsgnjn_vf_f64m8_m(vbool8_t, vfloat64m8_t, vfloat64m8_t, double, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vfsgnjx_vv)))
vfloat64m1_t vfsgnjx_vv_f64m1(vfloat64m1_t, vfloat64m1_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vfsgnjx_vv_m)))
vfloat64m1_t vfsgnjx_vv_f64m1_m(vbool64_t, vfloat64m1_t, vfloat64m1_t, vfloat64m1_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vfsgnjx_vv)))
vfloat64m2_t vfsgnjx_vv_f64m2(vfloat64m2_t, vfloat64m2_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vfsgnjx_vv_m)))
vfloat64m2_t vfsgnjx_vv_f64m2_m(vbool32_t, vfloat64m2_t, vfloat64m2_t, vfloat64m2_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vfsgnjx_vv)))
vfloat64m4_t vfsgnjx_vv_f64m4(vfloat64m4_t, vfloat64m4_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vfsgnjx_vv_m)))
vfloat64m4_t vfsgnjx_vv_f64m4_m(vbool16_t, vfloat64m4_t, vfloat64m4_t, vfloat64m4_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vfsgnjx_vv)))
vfloat64m8_t vfsgnjx_vv_f64m8(vfloat64m8_t, vfloat64m8_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vfsgnjx_vv_m)))
vfloat64m8_t vfsgnjx_vv_f64m8_m(vbool8_t, vfloat64m8_t, vfloat64m8_t, vfloat64m8_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vfsgnjx_vf)))
vfloat64m1_t vfsgnjx_vf_f64m1(vfloat64m1_t, double, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vfsgnjx_vf_m)))
vfloat64m1_t vfsgnjx_vf_f64m1_m(vbool64_t, vfloat64m1_t, vfloat64m1_t, double, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vfsgnjx_vf)))
vfloat64m2_t vfsgnjx_vf_f64m2(vfloat64m2_t, double, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vfsgnjx_vf_m)))
vfloat64m2_t vfsgnjx_vf_f64m2_m(vbool32_t, vfloat64m2_t, vfloat64m2_t, double, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vfsgnjx_vf)))
vfloat64m4_t vfsgnjx_vf_f64m4(vfloat64m4_t, double, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vfsgnjx_vf_m)))
vfloat64m4_t vfsgnjx_vf_f64m4_m(vbool16_t, vfloat64m4_t, vfloat64m4_t, double, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vfsgnjx_vf)))
vfloat64m8_t vfsgnjx_vf_f64m8(vfloat64m8_t, double, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vfsgnjx_vf_m)))
vfloat64m8_t vfsgnjx_vf_f64m8_m(vbool8_t, vfloat64m8_t, vfloat64m8_t, double, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vfabs_v)))
vfloat64m1_t vfabs_v_f64m1(vfloat64m1_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vfabs_v_m)))
vfloat64m1_t vfabs_v_f64m1_m(vbool64_t, vfloat64m1_t, vfloat64m1_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vfabs_v)))
vfloat64m2_t vfabs_v_f64m2(vfloat64m2_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vfabs_v_m)))
vfloat64m2_t vfabs_v_f64m2_m(vbool32_t, vfloat64m2_t, vfloat64m2_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vfabs_v)))
vfloat64m4_t vfabs_v_f64m4(vfloat64m4_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vfabs_v_m)))
vfloat64m4_t vfabs_v_f64m4_m(vbool16_t, vfloat64m4_t, vfloat64m4_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vfabs_v)))
vfloat64m8_t vfabs_v_f64m8(vfloat64m8_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vfabs_v_m)))
vfloat64m8_t vfabs_v_f64m8_m(vbool8_t, vfloat64m8_t, vfloat64m8_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vmfeq_vv)))
vbool64_t vmfeq_vv_f64m1_b64(vfloat64m1_t, vfloat64m1_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vmfeq_vv_m)))
vbool64_t vmfeq_vv_f64m1_b64_m(vbool64_t, vbool64_t, vfloat64m1_t, vfloat64m1_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vmfeq_vv)))
vbool32_t vmfeq_vv_f64m2_b32(vfloat64m2_t, vfloat64m2_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vmfeq_vv_m)))
vbool32_t vmfeq_vv_f64m2_b32_m(vbool32_t, vbool32_t, vfloat64m2_t, vfloat64m2_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vmfeq_vv)))
vbool16_t vmfeq_vv_f64m4_b16(vfloat64m4_t, vfloat64m4_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vmfeq_vv_m)))
vbool16_t vmfeq_vv_f64m4_b16_m(vbool16_t, vbool16_t, vfloat64m4_t, vfloat64m4_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vmfeq_vv)))
vbool8_t vmfeq_vv_f64m8_b8(vfloat64m8_t, vfloat64m8_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vmfeq_vv_m)))
vbool8_t vmfeq_vv_f64m8_b8_m(vbool8_t, vbool8_t, vfloat64m8_t, vfloat64m8_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vmfeq_vf)))
vbool64_t vmfeq_vf_f64m1_b64(vfloat64m1_t, double, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vmfeq_vf_m)))
vbool64_t vmfeq_vf_f64m1_b64_m(vbool64_t, vbool64_t, vfloat64m1_t, double, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vmfeq_vf)))
vbool32_t vmfeq_vf_f64m2_b32(vfloat64m2_t, double, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vmfeq_vf_m)))
vbool32_t vmfeq_vf_f64m2_b32_m(vbool32_t, vbool32_t, vfloat64m2_t, double, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vmfeq_vf)))
vbool16_t vmfeq_vf_f64m4_b16(vfloat64m4_t, double, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vmfeq_vf_m)))
vbool16_t vmfeq_vf_f64m4_b16_m(vbool16_t, vbool16_t, vfloat64m4_t, double, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vmfeq_vf)))
vbool8_t vmfeq_vf_f64m8_b8(vfloat64m8_t, double, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vmfeq_vf_m)))
vbool8_t vmfeq_vf_f64m8_b8_m(vbool8_t, vbool8_t, vfloat64m8_t, double, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vmfne_vv)))
vbool64_t vmfne_vv_f64m1_b64(vfloat64m1_t, vfloat64m1_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vmfne_vv_m)))
vbool64_t vmfne_vv_f64m1_b64_m(vbool64_t, vbool64_t, vfloat64m1_t, vfloat64m1_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vmfne_vv)))
vbool32_t vmfne_vv_f64m2_b32(vfloat64m2_t, vfloat64m2_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vmfne_vv_m)))
vbool32_t vmfne_vv_f64m2_b32_m(vbool32_t, vbool32_t, vfloat64m2_t, vfloat64m2_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vmfne_vv)))
vbool16_t vmfne_vv_f64m4_b16(vfloat64m4_t, vfloat64m4_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vmfne_vv_m)))
vbool16_t vmfne_vv_f64m4_b16_m(vbool16_t, vbool16_t, vfloat64m4_t, vfloat64m4_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vmfne_vv)))
vbool8_t vmfne_vv_f64m8_b8(vfloat64m8_t, vfloat64m8_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vmfne_vv_m)))
vbool8_t vmfne_vv_f64m8_b8_m(vbool8_t, vbool8_t, vfloat64m8_t, vfloat64m8_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vmfne_vf)))
vbool64_t vmfne_vf_f64m1_b64(vfloat64m1_t, double, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vmfne_vf_m)))
vbool64_t vmfne_vf_f64m1_b64_m(vbool64_t, vbool64_t, vfloat64m1_t, double, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vmfne_vf)))
vbool32_t vmfne_vf_f64m2_b32(vfloat64m2_t, double, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vmfne_vf_m)))
vbool32_t vmfne_vf_f64m2_b32_m(vbool32_t, vbool32_t, vfloat64m2_t, double, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vmfne_vf)))
vbool16_t vmfne_vf_f64m4_b16(vfloat64m4_t, double, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vmfne_vf_m)))
vbool16_t vmfne_vf_f64m4_b16_m(vbool16_t, vbool16_t, vfloat64m4_t, double, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vmfne_vf)))
vbool8_t vmfne_vf_f64m8_b8(vfloat64m8_t, double, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vmfne_vf_m)))
vbool8_t vmfne_vf_f64m8_b8_m(vbool8_t, vbool8_t, vfloat64m8_t, double, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vmflt_vv)))
vbool64_t vmflt_vv_f64m1_b64(vfloat64m1_t, vfloat64m1_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vmflt_vv_m)))
vbool64_t vmflt_vv_f64m1_b64_m(vbool64_t, vbool64_t, vfloat64m1_t, vfloat64m1_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vmflt_vv)))
vbool32_t vmflt_vv_f64m2_b32(vfloat64m2_t, vfloat64m2_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vmflt_vv_m)))
vbool32_t vmflt_vv_f64m2_b32_m(vbool32_t, vbool32_t, vfloat64m2_t, vfloat64m2_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vmflt_vv)))
vbool16_t vmflt_vv_f64m4_b16(vfloat64m4_t, vfloat64m4_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vmflt_vv_m)))
vbool16_t vmflt_vv_f64m4_b16_m(vbool16_t, vbool16_t, vfloat64m4_t, vfloat64m4_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vmflt_vv)))
vbool8_t vmflt_vv_f64m8_b8(vfloat64m8_t, vfloat64m8_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vmflt_vv_m)))
vbool8_t vmflt_vv_f64m8_b8_m(vbool8_t, vbool8_t, vfloat64m8_t, vfloat64m8_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vmflt_vf)))
vbool64_t vmflt_vf_f64m1_b64(vfloat64m1_t, double, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vmflt_vf_m)))
vbool64_t vmflt_vf_f64m1_b64_m(vbool64_t, vbool64_t, vfloat64m1_t, double, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vmflt_vf)))
vbool32_t vmflt_vf_f64m2_b32(vfloat64m2_t, double, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vmflt_vf_m)))
vbool32_t vmflt_vf_f64m2_b32_m(vbool32_t, vbool32_t, vfloat64m2_t, double, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vmflt_vf)))
vbool16_t vmflt_vf_f64m4_b16(vfloat64m4_t, double, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vmflt_vf_m)))
vbool16_t vmflt_vf_f64m4_b16_m(vbool16_t, vbool16_t, vfloat64m4_t, double, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vmflt_vf)))
vbool8_t vmflt_vf_f64m8_b8(vfloat64m8_t, double, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vmflt_vf_m)))
vbool8_t vmflt_vf_f64m8_b8_m(vbool8_t, vbool8_t, vfloat64m8_t, double, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vmfle_vv)))
vbool64_t vmfle_vv_f64m1_b64(vfloat64m1_t, vfloat64m1_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vmfle_vv_m)))
vbool64_t vmfle_vv_f64m1_b64_m(vbool64_t, vbool64_t, vfloat64m1_t, vfloat64m1_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vmfle_vv)))
vbool32_t vmfle_vv_f64m2_b32(vfloat64m2_t, vfloat64m2_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vmfle_vv_m)))
vbool32_t vmfle_vv_f64m2_b32_m(vbool32_t, vbool32_t, vfloat64m2_t, vfloat64m2_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vmfle_vv)))
vbool16_t vmfle_vv_f64m4_b16(vfloat64m4_t, vfloat64m4_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vmfle_vv_m)))
vbool16_t vmfle_vv_f64m4_b16_m(vbool16_t, vbool16_t, vfloat64m4_t, vfloat64m4_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vmfle_vv)))
vbool8_t vmfle_vv_f64m8_b8(vfloat64m8_t, vfloat64m8_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vmfle_vv_m)))
vbool8_t vmfle_vv_f64m8_b8_m(vbool8_t, vbool8_t, vfloat64m8_t, vfloat64m8_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vmfle_vf)))
vbool64_t vmfle_vf_f64m1_b64(vfloat64m1_t, double, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vmfle_vf_m)))
vbool64_t vmfle_vf_f64m1_b64_m(vbool64_t, vbool64_t, vfloat64m1_t, double, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vmfle_vf)))
vbool32_t vmfle_vf_f64m2_b32(vfloat64m2_t, double, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vmfle_vf_m)))
vbool32_t vmfle_vf_f64m2_b32_m(vbool32_t, vbool32_t, vfloat64m2_t, double, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vmfle_vf)))
vbool16_t vmfle_vf_f64m4_b16(vfloat64m4_t, double, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vmfle_vf_m)))
vbool16_t vmfle_vf_f64m4_b16_m(vbool16_t, vbool16_t, vfloat64m4_t, double, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vmfle_vf)))
vbool8_t vmfle_vf_f64m8_b8(vfloat64m8_t, double, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vmfle_vf_m)))
vbool8_t vmfle_vf_f64m8_b8_m(vbool8_t, vbool8_t, vfloat64m8_t, double, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vmfgt_vv)))
vbool64_t vmfgt_vv_f64m1_b64(vfloat64m1_t, vfloat64m1_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vmfgt_vv_m)))
vbool64_t vmfgt_vv_f64m1_b64_m(vbool64_t, vbool64_t, vfloat64m1_t, vfloat64m1_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vmfgt_vv)))
vbool32_t vmfgt_vv_f64m2_b32(vfloat64m2_t, vfloat64m2_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vmfgt_vv_m)))
vbool32_t vmfgt_vv_f64m2_b32_m(vbool32_t, vbool32_t, vfloat64m2_t, vfloat64m2_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vmfgt_vv)))
vbool16_t vmfgt_vv_f64m4_b16(vfloat64m4_t, vfloat64m4_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vmfgt_vv_m)))
vbool16_t vmfgt_vv_f64m4_b16_m(vbool16_t, vbool16_t, vfloat64m4_t, vfloat64m4_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vmfgt_vv)))
vbool8_t vmfgt_vv_f64m8_b8(vfloat64m8_t, vfloat64m8_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vmfgt_vv_m)))
vbool8_t vmfgt_vv_f64m8_b8_m(vbool8_t, vbool8_t, vfloat64m8_t, vfloat64m8_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vmfgt_vf)))
vbool64_t vmfgt_vf_f64m1_b64(vfloat64m1_t, double, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vmfgt_vf_m)))
vbool64_t vmfgt_vf_f64m1_b64_m(vbool64_t, vbool64_t, vfloat64m1_t, double, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vmfgt_vf)))
vbool32_t vmfgt_vf_f64m2_b32(vfloat64m2_t, double, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vmfgt_vf_m)))
vbool32_t vmfgt_vf_f64m2_b32_m(vbool32_t, vbool32_t, vfloat64m2_t, double, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vmfgt_vf)))
vbool16_t vmfgt_vf_f64m4_b16(vfloat64m4_t, double, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vmfgt_vf_m)))
vbool16_t vmfgt_vf_f64m4_b16_m(vbool16_t, vbool16_t, vfloat64m4_t, double, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vmfgt_vf)))
vbool8_t vmfgt_vf_f64m8_b8(vfloat64m8_t, double, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vmfgt_vf_m)))
vbool8_t vmfgt_vf_f64m8_b8_m(vbool8_t, vbool8_t, vfloat64m8_t, double, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vmfge_vv)))
vbool64_t vmfge_vv_f64m1_b64(vfloat64m1_t, vfloat64m1_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vmfge_vv_m)))
vbool64_t vmfge_vv_f64m1_b64_m(vbool64_t, vbool64_t, vfloat64m1_t, vfloat64m1_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vmfge_vv)))
vbool32_t vmfge_vv_f64m2_b32(vfloat64m2_t, vfloat64m2_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vmfge_vv_m)))
vbool32_t vmfge_vv_f64m2_b32_m(vbool32_t, vbool32_t, vfloat64m2_t, vfloat64m2_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vmfge_vv)))
vbool16_t vmfge_vv_f64m4_b16(vfloat64m4_t, vfloat64m4_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vmfge_vv_m)))
vbool16_t vmfge_vv_f64m4_b16_m(vbool16_t, vbool16_t, vfloat64m4_t, vfloat64m4_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vmfge_vv)))
vbool8_t vmfge_vv_f64m8_b8(vfloat64m8_t, vfloat64m8_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vmfge_vv_m)))
vbool8_t vmfge_vv_f64m8_b8_m(vbool8_t, vbool8_t, vfloat64m8_t, vfloat64m8_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vmfge_vf)))
vbool64_t vmfge_vf_f64m1_b64(vfloat64m1_t, double, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vmfge_vf_m)))
vbool64_t vmfge_vf_f64m1_b64_m(vbool64_t, vbool64_t, vfloat64m1_t, double, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vmfge_vf)))
vbool32_t vmfge_vf_f64m2_b32(vfloat64m2_t, double, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vmfge_vf_m)))
vbool32_t vmfge_vf_f64m2_b32_m(vbool32_t, vbool32_t, vfloat64m2_t, double, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vmfge_vf)))
vbool16_t vmfge_vf_f64m4_b16(vfloat64m4_t, double, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vmfge_vf_m)))
vbool16_t vmfge_vf_f64m4_b16_m(vbool16_t, vbool16_t, vfloat64m4_t, double, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vmfge_vf)))
vbool8_t vmfge_vf_f64m8_b8(vfloat64m8_t, double, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vmfge_vf_m)))
vbool8_t vmfge_vf_f64m8_b8_m(vbool8_t, vbool8_t, vfloat64m8_t, double, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vmerge_vvm)))
vfloat64m1_t vmerge_vvm_f64m1(vbool64_t, vfloat64m1_t, vfloat64m1_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vmerge_vvm)))
vfloat64m2_t vmerge_vvm_f64m2(vbool32_t, vfloat64m2_t, vfloat64m2_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vmerge_vvm)))
vfloat64m4_t vmerge_vvm_f64m4(vbool16_t, vfloat64m4_t, vfloat64m4_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vmerge_vvm)))
vfloat64m8_t vmerge_vvm_f64m8(vbool8_t, vfloat64m8_t, vfloat64m8_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vfmerge_vfm)))
vfloat64m1_t vfmerge_vfm_f64m1(vbool64_t, vfloat64m1_t, double, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vfmerge_vfm)))
vfloat64m2_t vfmerge_vfm_f64m2(vbool32_t, vfloat64m2_t, double, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vfmerge_vfm)))
vfloat64m4_t vfmerge_vfm_f64m4(vbool16_t, vfloat64m4_t, double, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vfmerge_vfm)))
vfloat64m8_t vfmerge_vfm_f64m8(vbool8_t, vfloat64m8_t, double, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vfmv_v_f)))
vfloat64m1_t vfmv_v_f_f64m1(double, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vfmv_v_f)))
vfloat64m2_t vfmv_v_f_f64m2(double, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vfmv_v_f)))
vfloat64m4_t vfmv_v_f_f64m4(double, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vfmv_v_f)))
vfloat64m8_t vfmv_v_f_f64m8(double, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vfredmax_vs)))
vfloat64m1_t vfredmax_vs_f64m1_f64m1(vfloat64m1_t, vfloat64m1_t, vfloat64m1_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vfredmax_vs_m)))
vfloat64m1_t vfredmax_vs_f64m1_f64m1_m(vbool64_t, vfloat64m1_t, vfloat64m1_t, vfloat64m1_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vfredmax_vs)))
vfloat64m1_t vfredmax_vs_f64m2_f64m1(vfloat64m1_t, vfloat64m2_t, vfloat64m1_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vfredmax_vs_m)))
vfloat64m1_t vfredmax_vs_f64m2_f64m1_m(vbool32_t, vfloat64m1_t, vfloat64m2_t, vfloat64m1_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vfredmax_vs)))
vfloat64m1_t vfredmax_vs_f64m4_f64m1(vfloat64m1_t, vfloat64m4_t, vfloat64m1_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vfredmax_vs_m)))
vfloat64m1_t vfredmax_vs_f64m4_f64m1_m(vbool16_t, vfloat64m1_t, vfloat64m4_t, vfloat64m1_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vfredmax_vs)))
vfloat64m1_t vfredmax_vs_f64m8_f64m1(vfloat64m1_t, vfloat64m8_t, vfloat64m1_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vfredmax_vs_m)))
vfloat64m1_t vfredmax_vs_f64m8_f64m1_m(vbool8_t, vfloat64m1_t, vfloat64m8_t, vfloat64m1_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vfredmin_vs)))
vfloat64m1_t vfredmin_vs_f64m1_f64m1(vfloat64m1_t, vfloat64m1_t, vfloat64m1_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vfredmin_vs_m)))
vfloat64m1_t vfredmin_vs_f64m1_f64m1_m(vbool64_t, vfloat64m1_t, vfloat64m1_t, vfloat64m1_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vfredmin_vs)))
vfloat64m1_t vfredmin_vs_f64m2_f64m1(vfloat64m1_t, vfloat64m2_t, vfloat64m1_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vfredmin_vs_m)))
vfloat64m1_t vfredmin_vs_f64m2_f64m1_m(vbool32_t, vfloat64m1_t, vfloat64m2_t, vfloat64m1_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vfredmin_vs)))
vfloat64m1_t vfredmin_vs_f64m4_f64m1(vfloat64m1_t, vfloat64m4_t, vfloat64m1_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vfredmin_vs_m)))
vfloat64m1_t vfredmin_vs_f64m4_f64m1_m(vbool16_t, vfloat64m1_t, vfloat64m4_t, vfloat64m1_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vfredmin_vs)))
vfloat64m1_t vfredmin_vs_f64m8_f64m1(vfloat64m1_t, vfloat64m8_t, vfloat64m1_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vfredmin_vs_m)))
vfloat64m1_t vfredmin_vs_f64m8_f64m1_m(vbool8_t, vfloat64m1_t, vfloat64m8_t, vfloat64m1_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vfredusum_vs)))
vfloat64m1_t vfredusum_vs_f64m1_f64m1(vfloat64m1_t, vfloat64m1_t, vfloat64m1_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vfredusum_vs_m)))
vfloat64m1_t vfredusum_vs_f64m1_f64m1_m(vbool64_t, vfloat64m1_t, vfloat64m1_t, vfloat64m1_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vfredusum_vs)))
vfloat64m1_t vfredusum_vs_f64m2_f64m1(vfloat64m1_t, vfloat64m2_t, vfloat64m1_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vfredusum_vs_m)))
vfloat64m1_t vfredusum_vs_f64m2_f64m1_m(vbool32_t, vfloat64m1_t, vfloat64m2_t, vfloat64m1_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vfredusum_vs)))
vfloat64m1_t vfredusum_vs_f64m4_f64m1(vfloat64m1_t, vfloat64m4_t, vfloat64m1_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vfredusum_vs_m)))
vfloat64m1_t vfredusum_vs_f64m4_f64m1_m(vbool16_t, vfloat64m1_t, vfloat64m4_t, vfloat64m1_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vfredusum_vs)))
vfloat64m1_t vfredusum_vs_f64m8_f64m1(vfloat64m1_t, vfloat64m8_t, vfloat64m1_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vfredusum_vs_m)))
vfloat64m1_t vfredusum_vs_f64m8_f64m1_m(vbool8_t, vfloat64m1_t, vfloat64m8_t, vfloat64m1_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vfredosum_vs)))
vfloat64m1_t vfredosum_vs_f64m1_f64m1(vfloat64m1_t, vfloat64m1_t, vfloat64m1_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vfredosum_vs_m)))
vfloat64m1_t vfredosum_vs_f64m1_f64m1_m(vbool64_t, vfloat64m1_t, vfloat64m1_t, vfloat64m1_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vfredosum_vs)))
vfloat64m1_t vfredosum_vs_f64m2_f64m1(vfloat64m1_t, vfloat64m2_t, vfloat64m1_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vfredosum_vs_m)))
vfloat64m1_t vfredosum_vs_f64m2_f64m1_m(vbool32_t, vfloat64m1_t, vfloat64m2_t, vfloat64m1_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vfredosum_vs)))
vfloat64m1_t vfredosum_vs_f64m4_f64m1(vfloat64m1_t, vfloat64m4_t, vfloat64m1_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vfredosum_vs_m)))
vfloat64m1_t vfredosum_vs_f64m4_f64m1_m(vbool16_t, vfloat64m1_t, vfloat64m4_t, vfloat64m1_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vfredosum_vs)))
vfloat64m1_t vfredosum_vs_f64m8_f64m1(vfloat64m1_t, vfloat64m8_t, vfloat64m1_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vfredosum_vs_m)))
vfloat64m1_t vfredosum_vs_f64m8_f64m1_m(vbool8_t, vfloat64m1_t, vfloat64m8_t, vfloat64m1_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vfmv_f_s)))
double vfmv_f_s_f64m1_f64(vfloat64m1_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vfmv_f_s)))
double vfmv_f_s_f64m2_f64(vfloat64m2_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vfmv_f_s)))
double vfmv_f_s_f64m4_f64(vfloat64m4_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vfmv_f_s)))
double vfmv_f_s_f64m8_f64(vfloat64m8_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vfmv_s_f)))
vfloat64m1_t vfmv_s_f_f64m1(vfloat64m1_t, double, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vfmv_s_f)))
vfloat64m2_t vfmv_s_f_f64m2(vfloat64m2_t, double, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vfmv_s_f)))
vfloat64m4_t vfmv_s_f_f64m4(vfloat64m4_t, double, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vfmv_s_f)))
vfloat64m8_t vfmv_s_f_f64m8(vfloat64m8_t, double, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vslideup_vx)))
vfloat64m1_t vslideup_vx_f64m1(vfloat64m1_t, vfloat64m1_t, size_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vslideup_vx_m)))
vfloat64m1_t vslideup_vx_f64m1_m(vbool64_t, vfloat64m1_t, vfloat64m1_t, size_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vslideup_vx)))
vfloat64m2_t vslideup_vx_f64m2(vfloat64m2_t, vfloat64m2_t, size_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vslideup_vx_m)))
vfloat64m2_t vslideup_vx_f64m2_m(vbool32_t, vfloat64m2_t, vfloat64m2_t, size_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vslideup_vx)))
vfloat64m4_t vslideup_vx_f64m4(vfloat64m4_t, vfloat64m4_t, size_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vslideup_vx_m)))
vfloat64m4_t vslideup_vx_f64m4_m(vbool16_t, vfloat64m4_t, vfloat64m4_t, size_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vslideup_vx)))
vfloat64m8_t vslideup_vx_f64m8(vfloat64m8_t, vfloat64m8_t, size_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vslideup_vx_m)))
vfloat64m8_t vslideup_vx_f64m8_m(vbool8_t, vfloat64m8_t, vfloat64m8_t, size_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vslidedown_vx)))
vfloat64m1_t vslidedown_vx_f64m1(vfloat64m1_t, vfloat64m1_t, size_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vslidedown_vx_m)))
vfloat64m1_t vslidedown_vx_f64m1_m(vbool64_t, vfloat64m1_t, vfloat64m1_t, size_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vslidedown_vx)))
vfloat64m2_t vslidedown_vx_f64m2(vfloat64m2_t, vfloat64m2_t, size_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vslidedown_vx_m)))
vfloat64m2_t vslidedown_vx_f64m2_m(vbool32_t, vfloat64m2_t, vfloat64m2_t, size_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vslidedown_vx)))
vfloat64m4_t vslidedown_vx_f64m4(vfloat64m4_t, vfloat64m4_t, size_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vslidedown_vx_m)))
vfloat64m4_t vslidedown_vx_f64m4_m(vbool16_t, vfloat64m4_t, vfloat64m4_t, size_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vslidedown_vx)))
vfloat64m8_t vslidedown_vx_f64m8(vfloat64m8_t, vfloat64m8_t, size_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vslidedown_vx_m)))
vfloat64m8_t vslidedown_vx_f64m8_m(vbool8_t, vfloat64m8_t, vfloat64m8_t, size_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vfslide1up_vf)))
vfloat64m1_t vfslide1up_vf_f64m1(vfloat64m1_t, double, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vfslide1up_vf_m)))
vfloat64m1_t vfslide1up_vf_f64m1_m(vbool64_t, vfloat64m1_t, vfloat64m1_t, double, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vfslide1up_vf)))
vfloat64m2_t vfslide1up_vf_f64m2(vfloat64m2_t, double, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vfslide1up_vf_m)))
vfloat64m2_t vfslide1up_vf_f64m2_m(vbool32_t, vfloat64m2_t, vfloat64m2_t, double, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vfslide1up_vf)))
vfloat64m4_t vfslide1up_vf_f64m4(vfloat64m4_t, double, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vfslide1up_vf_m)))
vfloat64m4_t vfslide1up_vf_f64m4_m(vbool16_t, vfloat64m4_t, vfloat64m4_t, double, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vfslide1up_vf)))
vfloat64m8_t vfslide1up_vf_f64m8(vfloat64m8_t, double, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vfslide1up_vf_m)))
vfloat64m8_t vfslide1up_vf_f64m8_m(vbool8_t, vfloat64m8_t, vfloat64m8_t, double, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vfslide1down_vf)))
vfloat64m1_t vfslide1down_vf_f64m1(vfloat64m1_t, double, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vfslide1down_vf_m)))
vfloat64m1_t vfslide1down_vf_f64m1_m(vbool64_t, vfloat64m1_t, vfloat64m1_t, double, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vfslide1down_vf)))
vfloat64m2_t vfslide1down_vf_f64m2(vfloat64m2_t, double, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vfslide1down_vf_m)))
vfloat64m2_t vfslide1down_vf_f64m2_m(vbool32_t, vfloat64m2_t, vfloat64m2_t, double, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vfslide1down_vf)))
vfloat64m4_t vfslide1down_vf_f64m4(vfloat64m4_t, double, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vfslide1down_vf_m)))
vfloat64m4_t vfslide1down_vf_f64m4_m(vbool16_t, vfloat64m4_t, vfloat64m4_t, double, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vfslide1down_vf)))
vfloat64m8_t vfslide1down_vf_f64m8(vfloat64m8_t, double, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vfslide1down_vf_m)))
vfloat64m8_t vfslide1down_vf_f64m8_m(vbool8_t, vfloat64m8_t, vfloat64m8_t, double, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vrgather_vv)))
vfloat64m1_t vrgather_vv_f64m1(vfloat64m1_t, vuint64m1_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vrgather_vv_m)))
vfloat64m1_t vrgather_vv_f64m1_m(vbool64_t, vfloat64m1_t, vfloat64m1_t, vuint64m1_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vrgather_vv)))
vfloat64m2_t vrgather_vv_f64m2(vfloat64m2_t, vuint64m2_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vrgather_vv_m)))
vfloat64m2_t vrgather_vv_f64m2_m(vbool32_t, vfloat64m2_t, vfloat64m2_t, vuint64m2_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vrgather_vv)))
vfloat64m4_t vrgather_vv_f64m4(vfloat64m4_t, vuint64m4_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vrgather_vv_m)))
vfloat64m4_t vrgather_vv_f64m4_m(vbool16_t, vfloat64m4_t, vfloat64m4_t, vuint64m4_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vrgather_vv)))
vfloat64m8_t vrgather_vv_f64m8(vfloat64m8_t, vuint64m8_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vrgather_vv_m)))
vfloat64m8_t vrgather_vv_f64m8_m(vbool8_t, vfloat64m8_t, vfloat64m8_t, vuint64m8_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vrgather_vx)))
vfloat64m1_t vrgather_vx_f64m1(vfloat64m1_t, size_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vrgather_vx_m)))
vfloat64m1_t vrgather_vx_f64m1_m(vbool64_t, vfloat64m1_t, vfloat64m1_t, size_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vrgather_vx)))
vfloat64m2_t vrgather_vx_f64m2(vfloat64m2_t, size_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vrgather_vx_m)))
vfloat64m2_t vrgather_vx_f64m2_m(vbool32_t, vfloat64m2_t, vfloat64m2_t, size_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vrgather_vx)))
vfloat64m4_t vrgather_vx_f64m4(vfloat64m4_t, size_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vrgather_vx_m)))
vfloat64m4_t vrgather_vx_f64m4_m(vbool16_t, vfloat64m4_t, vfloat64m4_t, size_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vrgather_vx)))
vfloat64m8_t vrgather_vx_f64m8(vfloat64m8_t, size_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vrgather_vx_m)))
vfloat64m8_t vrgather_vx_f64m8_m(vbool8_t, vfloat64m8_t, vfloat64m8_t, size_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vrgatherei16_vv)))
vfloat64m1_t vrgatherei16_vv_f64m1(vfloat64m1_t, vuint16mf4_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vrgatherei16_vv_m)))
vfloat64m1_t vrgatherei16_vv_f64m1_m(vbool64_t, vfloat64m1_t, vfloat64m1_t, vuint16mf4_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vrgatherei16_vv)))
vfloat64m2_t vrgatherei16_vv_f64m2(vfloat64m2_t, vuint16mf2_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vrgatherei16_vv_m)))
vfloat64m2_t vrgatherei16_vv_f64m2_m(vbool32_t, vfloat64m2_t, vfloat64m2_t, vuint16mf2_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vrgatherei16_vv)))
vfloat64m4_t vrgatherei16_vv_f64m4(vfloat64m4_t, vuint16m1_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vrgatherei16_vv_m)))
vfloat64m4_t vrgatherei16_vv_f64m4_m(vbool16_t, vfloat64m4_t, vfloat64m4_t, vuint16m1_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vrgatherei16_vv)))
vfloat64m8_t vrgatherei16_vv_f64m8(vfloat64m8_t, vuint16m2_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vrgatherei16_vv_m)))
vfloat64m8_t vrgatherei16_vv_f64m8_m(vbool8_t, vfloat64m8_t, vfloat64m8_t, vuint16m2_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vcompress_vm)))
vfloat64m1_t vcompress_vm_f64m1(vbool64_t, vfloat64m1_t, vfloat64m1_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vcompress_vm)))
vfloat64m2_t vcompress_vm_f64m2(vbool32_t, vfloat64m2_t, vfloat64m2_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vcompress_vm)))
vfloat64m4_t vcompress_vm_f64m4(vbool16_t, vfloat64m4_t, vfloat64m4_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vcompress_vm)))
vfloat64m8_t vcompress_vm_f64m8(vbool8_t, vfloat64m8_t, vfloat64m8_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vget_v)))
vfloat64m1_t vget_v_f64m2_f64m1(vfloat64m2_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vget_v)))
vfloat64m1_t vget_v_f64m4_f64m1(vfloat64m4_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vget_v)))
vfloat64m1_t vget_v_f64m8_f64m1(vfloat64m8_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vget_v)))
vfloat64m2_t vget_v_f64m4_f64m2(vfloat64m4_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vget_v)))
vfloat64m2_t vget_v_f64m8_f64m2(vfloat64m8_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vget_v)))
vfloat64m4_t vget_v_f64m8_f64m4(vfloat64m8_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vset_v)))
vfloat64m2_t vset_v_f64m1_f64m2(vfloat64m2_t, size_t, vfloat64m1_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vset_v)))
vfloat64m4_t vset_v_f64m1_f64m4(vfloat64m4_t, size_t, vfloat64m1_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vset_v)))
vfloat64m4_t vset_v_f64m2_f64m4(vfloat64m4_t, size_t, vfloat64m2_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vset_v)))
vfloat64m8_t vset_v_f64m1_f64m8(vfloat64m8_t, size_t, vfloat64m1_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vset_v)))
vfloat64m8_t vset_v_f64m2_f64m8(vfloat64m8_t, size_t, vfloat64m2_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vset_v)))
vfloat64m8_t vset_v_f64m4_f64m8(vfloat64m8_t, size_t, vfloat64m4_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vsuxei8_v)))
void vsuxei8_v_f64m1(double *, vuint8mf8_t, vfloat64m1_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vsuxei8_v_m)))
void vsuxei8_v_f64m1_m(vbool64_t, double *, vuint8mf8_t, vfloat64m1_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vsuxei8_v)))
void vsuxei8_v_f64m2(double *, vuint8mf4_t, vfloat64m2_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vsuxei8_v_m)))
void vsuxei8_v_f64m2_m(vbool32_t, double *, vuint8mf4_t, vfloat64m2_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vsuxei8_v)))
void vsuxei8_v_f64m4(double *, vuint8mf2_t, vfloat64m4_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vsuxei8_v_m)))
void vsuxei8_v_f64m4_m(vbool16_t, double *, vuint8mf2_t, vfloat64m4_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vsuxei8_v)))
void vsuxei8_v_f64m8(double *, vuint8m1_t, vfloat64m8_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vsuxei8_v_m)))
void vsuxei8_v_f64m8_m(vbool8_t, double *, vuint8m1_t, vfloat64m8_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vsuxei16_v)))
void vsuxei16_v_f64m1(double *, vuint16mf4_t, vfloat64m1_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vsuxei16_v_m)))
void vsuxei16_v_f64m1_m(vbool64_t, double *, vuint16mf4_t, vfloat64m1_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vsuxei16_v)))
void vsuxei16_v_f64m2(double *, vuint16mf2_t, vfloat64m2_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vsuxei16_v_m)))
void vsuxei16_v_f64m2_m(vbool32_t, double *, vuint16mf2_t, vfloat64m2_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vsuxei16_v)))
void vsuxei16_v_f64m4(double *, vuint16m1_t, vfloat64m4_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vsuxei16_v_m)))
void vsuxei16_v_f64m4_m(vbool16_t, double *, vuint16m1_t, vfloat64m4_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vsuxei16_v)))
void vsuxei16_v_f64m8(double *, vuint16m2_t, vfloat64m8_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vsuxei16_v_m)))
void vsuxei16_v_f64m8_m(vbool8_t, double *, vuint16m2_t, vfloat64m8_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vsuxei32_v)))
void vsuxei32_v_f64m1(double *, vuint32mf2_t, vfloat64m1_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vsuxei32_v_m)))
void vsuxei32_v_f64m1_m(vbool64_t, double *, vuint32mf2_t, vfloat64m1_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vsuxei32_v)))
void vsuxei32_v_f64m2(double *, vuint32m1_t, vfloat64m2_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vsuxei32_v_m)))
void vsuxei32_v_f64m2_m(vbool32_t, double *, vuint32m1_t, vfloat64m2_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vsuxei32_v)))
void vsuxei32_v_f64m4(double *, vuint32m2_t, vfloat64m4_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vsuxei32_v_m)))
void vsuxei32_v_f64m4_m(vbool16_t, double *, vuint32m2_t, vfloat64m4_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vsuxei32_v)))
void vsuxei32_v_f64m8(double *, vuint32m4_t, vfloat64m8_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vsuxei32_v_m)))
void vsuxei32_v_f64m8_m(vbool8_t, double *, vuint32m4_t, vfloat64m8_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vsoxei8_v)))
void vsoxei8_v_f64m1(double *, vuint8mf8_t, vfloat64m1_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vsoxei8_v_m)))
void vsoxei8_v_f64m1_m(vbool64_t, double *, vuint8mf8_t, vfloat64m1_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vsoxei8_v)))
void vsoxei8_v_f64m2(double *, vuint8mf4_t, vfloat64m2_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vsoxei8_v_m)))
void vsoxei8_v_f64m2_m(vbool32_t, double *, vuint8mf4_t, vfloat64m2_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vsoxei8_v)))
void vsoxei8_v_f64m4(double *, vuint8mf2_t, vfloat64m4_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vsoxei8_v_m)))
void vsoxei8_v_f64m4_m(vbool16_t, double *, vuint8mf2_t, vfloat64m4_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vsoxei8_v)))
void vsoxei8_v_f64m8(double *, vuint8m1_t, vfloat64m8_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vsoxei8_v_m)))
void vsoxei8_v_f64m8_m(vbool8_t, double *, vuint8m1_t, vfloat64m8_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vsoxei16_v)))
void vsoxei16_v_f64m1(double *, vuint16mf4_t, vfloat64m1_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vsoxei16_v_m)))
void vsoxei16_v_f64m1_m(vbool64_t, double *, vuint16mf4_t, vfloat64m1_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vsoxei16_v)))
void vsoxei16_v_f64m2(double *, vuint16mf2_t, vfloat64m2_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vsoxei16_v_m)))
void vsoxei16_v_f64m2_m(vbool32_t, double *, vuint16mf2_t, vfloat64m2_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vsoxei16_v)))
void vsoxei16_v_f64m4(double *, vuint16m1_t, vfloat64m4_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vsoxei16_v_m)))
void vsoxei16_v_f64m4_m(vbool16_t, double *, vuint16m1_t, vfloat64m4_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vsoxei16_v)))
void vsoxei16_v_f64m8(double *, vuint16m2_t, vfloat64m8_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vsoxei16_v_m)))
void vsoxei16_v_f64m8_m(vbool8_t, double *, vuint16m2_t, vfloat64m8_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vsoxei32_v)))
void vsoxei32_v_f64m1(double *, vuint32mf2_t, vfloat64m1_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vsoxei32_v_m)))
void vsoxei32_v_f64m1_m(vbool64_t, double *, vuint32mf2_t, vfloat64m1_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vsoxei32_v)))
void vsoxei32_v_f64m2(double *, vuint32m1_t, vfloat64m2_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vsoxei32_v_m)))
void vsoxei32_v_f64m2_m(vbool32_t, double *, vuint32m1_t, vfloat64m2_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vsoxei32_v)))
void vsoxei32_v_f64m4(double *, vuint32m2_t, vfloat64m4_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vsoxei32_v_m)))
void vsoxei32_v_f64m4_m(vbool16_t, double *, vuint32m2_t, vfloat64m4_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vsoxei32_v)))
void vsoxei32_v_f64m8(double *, vuint32m4_t, vfloat64m8_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vsoxei32_v_m)))
void vsoxei32_v_f64m8_m(vbool8_t, double *, vuint32m4_t, vfloat64m8_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vle64ff_v)))
vfloat64m1_t vle64ff_v_f64m1(const double *, size_t *, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vle64ff_v_m)))
vfloat64m1_t vle64ff_v_f64m1_m(vbool64_t, vfloat64m1_t, const double *, size_t *, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vle64ff_v)))
vfloat64m2_t vle64ff_v_f64m2(const double *, size_t *, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vle64ff_v_m)))
vfloat64m2_t vle64ff_v_f64m2_m(vbool32_t, vfloat64m2_t, const double *, size_t *, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vle64ff_v)))
vfloat64m4_t vle64ff_v_f64m4(const double *, size_t *, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vle64ff_v_m)))
vfloat64m4_t vle64ff_v_f64m4_m(vbool16_t, vfloat64m4_t, const double *, size_t *, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vle64ff_v)))
vfloat64m8_t vle64ff_v_f64m8(const double *, size_t *, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vle64ff_v_m)))
vfloat64m8_t vle64ff_v_f64m8_m(vbool8_t, vfloat64m8_t, const double *, size_t *, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vlseg2e64_v)))
void vlseg2e64_v_f64m1(vfloat64m1_t *, vfloat64m1_t *, const double *, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vlseg2e64_v_m)))
void vlseg2e64_v_f64m1_m(vfloat64m1_t *, vfloat64m1_t *, vbool64_t, vfloat64m1_t, vfloat64m1_t, const double *, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vlseg2e64_v)))
void vlseg2e64_v_f64m2(vfloat64m2_t *, vfloat64m2_t *, const double *, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vlseg2e64_v_m)))
void vlseg2e64_v_f64m2_m(vfloat64m2_t *, vfloat64m2_t *, vbool32_t, vfloat64m2_t, vfloat64m2_t, const double *, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vlseg2e64_v)))
void vlseg2e64_v_f64m4(vfloat64m4_t *, vfloat64m4_t *, const double *, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vlseg2e64_v_m)))
void vlseg2e64_v_f64m4_m(vfloat64m4_t *, vfloat64m4_t *, vbool16_t, vfloat64m4_t, vfloat64m4_t, const double *, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vlseg3e64_v)))
void vlseg3e64_v_f64m1(vfloat64m1_t *, vfloat64m1_t *, vfloat64m1_t *, const double *, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vlseg3e64_v_m)))
void vlseg3e64_v_f64m1_m(vfloat64m1_t *, vfloat64m1_t *, vfloat64m1_t *, vbool64_t, vfloat64m1_t, vfloat64m1_t, vfloat64m1_t, const double *, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vlseg3e64_v)))
void vlseg3e64_v_f64m2(vfloat64m2_t *, vfloat64m2_t *, vfloat64m2_t *, const double *, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vlseg3e64_v_m)))
void vlseg3e64_v_f64m2_m(vfloat64m2_t *, vfloat64m2_t *, vfloat64m2_t *, vbool32_t, vfloat64m2_t, vfloat64m2_t, vfloat64m2_t, const double *, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vlseg4e64_v)))
void vlseg4e64_v_f64m1(vfloat64m1_t *, vfloat64m1_t *, vfloat64m1_t *, vfloat64m1_t *, const double *, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vlseg4e64_v_m)))
void vlseg4e64_v_f64m1_m(vfloat64m1_t *, vfloat64m1_t *, vfloat64m1_t *, vfloat64m1_t *, vbool64_t, vfloat64m1_t, vfloat64m1_t, vfloat64m1_t, vfloat64m1_t, const double *, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vlseg4e64_v)))
void vlseg4e64_v_f64m2(vfloat64m2_t *, vfloat64m2_t *, vfloat64m2_t *, vfloat64m2_t *, const double *, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vlseg4e64_v_m)))
void vlseg4e64_v_f64m2_m(vfloat64m2_t *, vfloat64m2_t *, vfloat64m2_t *, vfloat64m2_t *, vbool32_t, vfloat64m2_t, vfloat64m2_t, vfloat64m2_t, vfloat64m2_t, const double *, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vlseg5e64_v)))
void vlseg5e64_v_f64m1(vfloat64m1_t *, vfloat64m1_t *, vfloat64m1_t *, vfloat64m1_t *, vfloat64m1_t *, const double *, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vlseg5e64_v_m)))
void vlseg5e64_v_f64m1_m(vfloat64m1_t *, vfloat64m1_t *, vfloat64m1_t *, vfloat64m1_t *, vfloat64m1_t *, vbool64_t, vfloat64m1_t, vfloat64m1_t, vfloat64m1_t, vfloat64m1_t, vfloat64m1_t, const double *, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vlseg6e64_v)))
void vlseg6e64_v_f64m1(vfloat64m1_t *, vfloat64m1_t *, vfloat64m1_t *, vfloat64m1_t *, vfloat64m1_t *, vfloat64m1_t *, const double *, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vlseg6e64_v_m)))
void vlseg6e64_v_f64m1_m(vfloat64m1_t *, vfloat64m1_t *, vfloat64m1_t *, vfloat64m1_t *, vfloat64m1_t *, vfloat64m1_t *, vbool64_t, vfloat64m1_t, vfloat64m1_t, vfloat64m1_t, vfloat64m1_t, vfloat64m1_t, vfloat64m1_t, const double *, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vlseg7e64_v)))
void vlseg7e64_v_f64m1(vfloat64m1_t *, vfloat64m1_t *, vfloat64m1_t *, vfloat64m1_t *, vfloat64m1_t *, vfloat64m1_t *, vfloat64m1_t *, const double *, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vlseg7e64_v_m)))
void vlseg7e64_v_f64m1_m(vfloat64m1_t *, vfloat64m1_t *, vfloat64m1_t *, vfloat64m1_t *, vfloat64m1_t *, vfloat64m1_t *, vfloat64m1_t *, vbool64_t, vfloat64m1_t, vfloat64m1_t, vfloat64m1_t, vfloat64m1_t, vfloat64m1_t, vfloat64m1_t, vfloat64m1_t, const double *, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vlseg8e64_v)))
void vlseg8e64_v_f64m1(vfloat64m1_t *, vfloat64m1_t *, vfloat64m1_t *, vfloat64m1_t *, vfloat64m1_t *, vfloat64m1_t *, vfloat64m1_t *, vfloat64m1_t *, const double *, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vlseg8e64_v_m)))
void vlseg8e64_v_f64m1_m(vfloat64m1_t *, vfloat64m1_t *, vfloat64m1_t *, vfloat64m1_t *, vfloat64m1_t *, vfloat64m1_t *, vfloat64m1_t *, vfloat64m1_t *, vbool64_t, vfloat64m1_t, vfloat64m1_t, vfloat64m1_t, vfloat64m1_t, vfloat64m1_t, vfloat64m1_t, vfloat64m1_t, vfloat64m1_t, const double *, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vlseg2e64ff_v)))
void vlseg2e64ff_v_f64m1(vfloat64m1_t *, vfloat64m1_t *, const double *, size_t *, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vlseg2e64ff_v_m)))
void vlseg2e64ff_v_f64m1_m(vfloat64m1_t *, vfloat64m1_t *, vbool64_t, vfloat64m1_t, vfloat64m1_t, const double *, size_t *, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vlseg2e64ff_v)))
void vlseg2e64ff_v_f64m2(vfloat64m2_t *, vfloat64m2_t *, const double *, size_t *, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vlseg2e64ff_v_m)))
void vlseg2e64ff_v_f64m2_m(vfloat64m2_t *, vfloat64m2_t *, vbool32_t, vfloat64m2_t, vfloat64m2_t, const double *, size_t *, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vlseg2e64ff_v)))
void vlseg2e64ff_v_f64m4(vfloat64m4_t *, vfloat64m4_t *, const double *, size_t *, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vlseg2e64ff_v_m)))
void vlseg2e64ff_v_f64m4_m(vfloat64m4_t *, vfloat64m4_t *, vbool16_t, vfloat64m4_t, vfloat64m4_t, const double *, size_t *, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vlseg3e64ff_v)))
void vlseg3e64ff_v_f64m1(vfloat64m1_t *, vfloat64m1_t *, vfloat64m1_t *, const double *, size_t *, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vlseg3e64ff_v_m)))
void vlseg3e64ff_v_f64m1_m(vfloat64m1_t *, vfloat64m1_t *, vfloat64m1_t *, vbool64_t, vfloat64m1_t, vfloat64m1_t, vfloat64m1_t, const double *, size_t *, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vlseg3e64ff_v)))
void vlseg3e64ff_v_f64m2(vfloat64m2_t *, vfloat64m2_t *, vfloat64m2_t *, const double *, size_t *, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vlseg3e64ff_v_m)))
void vlseg3e64ff_v_f64m2_m(vfloat64m2_t *, vfloat64m2_t *, vfloat64m2_t *, vbool32_t, vfloat64m2_t, vfloat64m2_t, vfloat64m2_t, const double *, size_t *, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vlseg4e64ff_v)))
void vlseg4e64ff_v_f64m1(vfloat64m1_t *, vfloat64m1_t *, vfloat64m1_t *, vfloat64m1_t *, const double *, size_t *, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vlseg4e64ff_v_m)))
void vlseg4e64ff_v_f64m1_m(vfloat64m1_t *, vfloat64m1_t *, vfloat64m1_t *, vfloat64m1_t *, vbool64_t, vfloat64m1_t, vfloat64m1_t, vfloat64m1_t, vfloat64m1_t, const double *, size_t *, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vlseg4e64ff_v)))
void vlseg4e64ff_v_f64m2(vfloat64m2_t *, vfloat64m2_t *, vfloat64m2_t *, vfloat64m2_t *, const double *, size_t *, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vlseg4e64ff_v_m)))
void vlseg4e64ff_v_f64m2_m(vfloat64m2_t *, vfloat64m2_t *, vfloat64m2_t *, vfloat64m2_t *, vbool32_t, vfloat64m2_t, vfloat64m2_t, vfloat64m2_t, vfloat64m2_t, const double *, size_t *, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vlseg5e64ff_v)))
void vlseg5e64ff_v_f64m1(vfloat64m1_t *, vfloat64m1_t *, vfloat64m1_t *, vfloat64m1_t *, vfloat64m1_t *, const double *, size_t *, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vlseg5e64ff_v_m)))
void vlseg5e64ff_v_f64m1_m(vfloat64m1_t *, vfloat64m1_t *, vfloat64m1_t *, vfloat64m1_t *, vfloat64m1_t *, vbool64_t, vfloat64m1_t, vfloat64m1_t, vfloat64m1_t, vfloat64m1_t, vfloat64m1_t, const double *, size_t *, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vlseg6e64ff_v)))
void vlseg6e64ff_v_f64m1(vfloat64m1_t *, vfloat64m1_t *, vfloat64m1_t *, vfloat64m1_t *, vfloat64m1_t *, vfloat64m1_t *, const double *, size_t *, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vlseg6e64ff_v_m)))
void vlseg6e64ff_v_f64m1_m(vfloat64m1_t *, vfloat64m1_t *, vfloat64m1_t *, vfloat64m1_t *, vfloat64m1_t *, vfloat64m1_t *, vbool64_t, vfloat64m1_t, vfloat64m1_t, vfloat64m1_t, vfloat64m1_t, vfloat64m1_t, vfloat64m1_t, const double *, size_t *, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vlseg7e64ff_v)))
void vlseg7e64ff_v_f64m1(vfloat64m1_t *, vfloat64m1_t *, vfloat64m1_t *, vfloat64m1_t *, vfloat64m1_t *, vfloat64m1_t *, vfloat64m1_t *, const double *, size_t *, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vlseg7e64ff_v_m)))
void vlseg7e64ff_v_f64m1_m(vfloat64m1_t *, vfloat64m1_t *, vfloat64m1_t *, vfloat64m1_t *, vfloat64m1_t *, vfloat64m1_t *, vfloat64m1_t *, vbool64_t, vfloat64m1_t, vfloat64m1_t, vfloat64m1_t, vfloat64m1_t, vfloat64m1_t, vfloat64m1_t, vfloat64m1_t, const double *, size_t *, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vlseg8e64ff_v)))
void vlseg8e64ff_v_f64m1(vfloat64m1_t *, vfloat64m1_t *, vfloat64m1_t *, vfloat64m1_t *, vfloat64m1_t *, vfloat64m1_t *, vfloat64m1_t *, vfloat64m1_t *, const double *, size_t *, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vlseg8e64ff_v_m)))
void vlseg8e64ff_v_f64m1_m(vfloat64m1_t *, vfloat64m1_t *, vfloat64m1_t *, vfloat64m1_t *, vfloat64m1_t *, vfloat64m1_t *, vfloat64m1_t *, vfloat64m1_t *, vbool64_t, vfloat64m1_t, vfloat64m1_t, vfloat64m1_t, vfloat64m1_t, vfloat64m1_t, vfloat64m1_t, vfloat64m1_t, vfloat64m1_t, const double *, size_t *, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vlsseg2e64_v)))
void vlsseg2e64_v_f64m1(vfloat64m1_t *, vfloat64m1_t *, const double *, ptrdiff_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vlsseg2e64_v_m)))
void vlsseg2e64_v_f64m1_m(vfloat64m1_t *, vfloat64m1_t *, vbool64_t, vfloat64m1_t, vfloat64m1_t, const double *, ptrdiff_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vlsseg2e64_v)))
void vlsseg2e64_v_f64m2(vfloat64m2_t *, vfloat64m2_t *, const double *, ptrdiff_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vlsseg2e64_v_m)))
void vlsseg2e64_v_f64m2_m(vfloat64m2_t *, vfloat64m2_t *, vbool32_t, vfloat64m2_t, vfloat64m2_t, const double *, ptrdiff_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vlsseg2e64_v)))
void vlsseg2e64_v_f64m4(vfloat64m4_t *, vfloat64m4_t *, const double *, ptrdiff_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vlsseg2e64_v_m)))
void vlsseg2e64_v_f64m4_m(vfloat64m4_t *, vfloat64m4_t *, vbool16_t, vfloat64m4_t, vfloat64m4_t, const double *, ptrdiff_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vlsseg3e64_v)))
void vlsseg3e64_v_f64m1(vfloat64m1_t *, vfloat64m1_t *, vfloat64m1_t *, const double *, ptrdiff_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vlsseg3e64_v_m)))
void vlsseg3e64_v_f64m1_m(vfloat64m1_t *, vfloat64m1_t *, vfloat64m1_t *, vbool64_t, vfloat64m1_t, vfloat64m1_t, vfloat64m1_t, const double *, ptrdiff_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vlsseg3e64_v)))
void vlsseg3e64_v_f64m2(vfloat64m2_t *, vfloat64m2_t *, vfloat64m2_t *, const double *, ptrdiff_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vlsseg3e64_v_m)))
void vlsseg3e64_v_f64m2_m(vfloat64m2_t *, vfloat64m2_t *, vfloat64m2_t *, vbool32_t, vfloat64m2_t, vfloat64m2_t, vfloat64m2_t, const double *, ptrdiff_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vlsseg4e64_v)))
void vlsseg4e64_v_f64m1(vfloat64m1_t *, vfloat64m1_t *, vfloat64m1_t *, vfloat64m1_t *, const double *, ptrdiff_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vlsseg4e64_v_m)))
void vlsseg4e64_v_f64m1_m(vfloat64m1_t *, vfloat64m1_t *, vfloat64m1_t *, vfloat64m1_t *, vbool64_t, vfloat64m1_t, vfloat64m1_t, vfloat64m1_t, vfloat64m1_t, const double *, ptrdiff_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vlsseg4e64_v)))
void vlsseg4e64_v_f64m2(vfloat64m2_t *, vfloat64m2_t *, vfloat64m2_t *, vfloat64m2_t *, const double *, ptrdiff_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vlsseg4e64_v_m)))
void vlsseg4e64_v_f64m2_m(vfloat64m2_t *, vfloat64m2_t *, vfloat64m2_t *, vfloat64m2_t *, vbool32_t, vfloat64m2_t, vfloat64m2_t, vfloat64m2_t, vfloat64m2_t, const double *, ptrdiff_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vlsseg5e64_v)))
void vlsseg5e64_v_f64m1(vfloat64m1_t *, vfloat64m1_t *, vfloat64m1_t *, vfloat64m1_t *, vfloat64m1_t *, const double *, ptrdiff_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vlsseg5e64_v_m)))
void vlsseg5e64_v_f64m1_m(vfloat64m1_t *, vfloat64m1_t *, vfloat64m1_t *, vfloat64m1_t *, vfloat64m1_t *, vbool64_t, vfloat64m1_t, vfloat64m1_t, vfloat64m1_t, vfloat64m1_t, vfloat64m1_t, const double *, ptrdiff_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vlsseg6e64_v)))
void vlsseg6e64_v_f64m1(vfloat64m1_t *, vfloat64m1_t *, vfloat64m1_t *, vfloat64m1_t *, vfloat64m1_t *, vfloat64m1_t *, const double *, ptrdiff_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vlsseg6e64_v_m)))
void vlsseg6e64_v_f64m1_m(vfloat64m1_t *, vfloat64m1_t *, vfloat64m1_t *, vfloat64m1_t *, vfloat64m1_t *, vfloat64m1_t *, vbool64_t, vfloat64m1_t, vfloat64m1_t, vfloat64m1_t, vfloat64m1_t, vfloat64m1_t, vfloat64m1_t, const double *, ptrdiff_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vlsseg7e64_v)))
void vlsseg7e64_v_f64m1(vfloat64m1_t *, vfloat64m1_t *, vfloat64m1_t *, vfloat64m1_t *, vfloat64m1_t *, vfloat64m1_t *, vfloat64m1_t *, const double *, ptrdiff_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vlsseg7e64_v_m)))
void vlsseg7e64_v_f64m1_m(vfloat64m1_t *, vfloat64m1_t *, vfloat64m1_t *, vfloat64m1_t *, vfloat64m1_t *, vfloat64m1_t *, vfloat64m1_t *, vbool64_t, vfloat64m1_t, vfloat64m1_t, vfloat64m1_t, vfloat64m1_t, vfloat64m1_t, vfloat64m1_t, vfloat64m1_t, const double *, ptrdiff_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vlsseg8e64_v)))
void vlsseg8e64_v_f64m1(vfloat64m1_t *, vfloat64m1_t *, vfloat64m1_t *, vfloat64m1_t *, vfloat64m1_t *, vfloat64m1_t *, vfloat64m1_t *, vfloat64m1_t *, const double *, ptrdiff_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vlsseg8e64_v_m)))
void vlsseg8e64_v_f64m1_m(vfloat64m1_t *, vfloat64m1_t *, vfloat64m1_t *, vfloat64m1_t *, vfloat64m1_t *, vfloat64m1_t *, vfloat64m1_t *, vfloat64m1_t *, vbool64_t, vfloat64m1_t, vfloat64m1_t, vfloat64m1_t, vfloat64m1_t, vfloat64m1_t, vfloat64m1_t, vfloat64m1_t, vfloat64m1_t, const double *, ptrdiff_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vfneg_v)))
vfloat64m1_t vfneg_v_f64m1(vfloat64m1_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vfneg_v_m)))
vfloat64m1_t vfneg_v_f64m1_m(vbool64_t, vfloat64m1_t, vfloat64m1_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vfneg_v)))
vfloat64m2_t vfneg_v_f64m2(vfloat64m2_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vfneg_v_m)))
vfloat64m2_t vfneg_v_f64m2_m(vbool32_t, vfloat64m2_t, vfloat64m2_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vfneg_v)))
vfloat64m4_t vfneg_v_f64m4(vfloat64m4_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vfneg_v_m)))
vfloat64m4_t vfneg_v_f64m4_m(vbool16_t, vfloat64m4_t, vfloat64m4_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vfneg_v)))
vfloat64m8_t vfneg_v_f64m8(vfloat64m8_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vfneg_v_m)))
vfloat64m8_t vfneg_v_f64m8_m(vbool8_t, vfloat64m8_t, vfloat64m8_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vluxseg2ei8_v)))
void vluxseg2ei8_v_f64m1(vfloat64m1_t *, vfloat64m1_t *, const double *, vuint8mf8_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vluxseg2ei8_v_m)))
void vluxseg2ei8_v_f64m1_m(vfloat64m1_t *, vfloat64m1_t *, vbool64_t, vfloat64m1_t, vfloat64m1_t, const double *, vuint8mf8_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vluxseg2ei8_v)))
void vluxseg2ei8_v_f64m2(vfloat64m2_t *, vfloat64m2_t *, const double *, vuint8mf4_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vluxseg2ei8_v_m)))
void vluxseg2ei8_v_f64m2_m(vfloat64m2_t *, vfloat64m2_t *, vbool32_t, vfloat64m2_t, vfloat64m2_t, const double *, vuint8mf4_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vluxseg2ei8_v)))
void vluxseg2ei8_v_f64m4(vfloat64m4_t *, vfloat64m4_t *, const double *, vuint8mf2_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vluxseg2ei8_v_m)))
void vluxseg2ei8_v_f64m4_m(vfloat64m4_t *, vfloat64m4_t *, vbool16_t, vfloat64m4_t, vfloat64m4_t, const double *, vuint8mf2_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vluxseg3ei8_v)))
void vluxseg3ei8_v_f64m1(vfloat64m1_t *, vfloat64m1_t *, vfloat64m1_t *, const double *, vuint8mf8_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vluxseg3ei8_v_m)))
void vluxseg3ei8_v_f64m1_m(vfloat64m1_t *, vfloat64m1_t *, vfloat64m1_t *, vbool64_t, vfloat64m1_t, vfloat64m1_t, vfloat64m1_t, const double *, vuint8mf8_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vluxseg3ei8_v)))
void vluxseg3ei8_v_f64m2(vfloat64m2_t *, vfloat64m2_t *, vfloat64m2_t *, const double *, vuint8mf4_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vluxseg3ei8_v_m)))
void vluxseg3ei8_v_f64m2_m(vfloat64m2_t *, vfloat64m2_t *, vfloat64m2_t *, vbool32_t, vfloat64m2_t, vfloat64m2_t, vfloat64m2_t, const double *, vuint8mf4_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vluxseg4ei8_v)))
void vluxseg4ei8_v_f64m1(vfloat64m1_t *, vfloat64m1_t *, vfloat64m1_t *, vfloat64m1_t *, const double *, vuint8mf8_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vluxseg4ei8_v_m)))
void vluxseg4ei8_v_f64m1_m(vfloat64m1_t *, vfloat64m1_t *, vfloat64m1_t *, vfloat64m1_t *, vbool64_t, vfloat64m1_t, vfloat64m1_t, vfloat64m1_t, vfloat64m1_t, const double *, vuint8mf8_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vluxseg4ei8_v)))
void vluxseg4ei8_v_f64m2(vfloat64m2_t *, vfloat64m2_t *, vfloat64m2_t *, vfloat64m2_t *, const double *, vuint8mf4_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vluxseg4ei8_v_m)))
void vluxseg4ei8_v_f64m2_m(vfloat64m2_t *, vfloat64m2_t *, vfloat64m2_t *, vfloat64m2_t *, vbool32_t, vfloat64m2_t, vfloat64m2_t, vfloat64m2_t, vfloat64m2_t, const double *, vuint8mf4_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vluxseg5ei8_v)))
void vluxseg5ei8_v_f64m1(vfloat64m1_t *, vfloat64m1_t *, vfloat64m1_t *, vfloat64m1_t *, vfloat64m1_t *, const double *, vuint8mf8_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vluxseg5ei8_v_m)))
void vluxseg5ei8_v_f64m1_m(vfloat64m1_t *, vfloat64m1_t *, vfloat64m1_t *, vfloat64m1_t *, vfloat64m1_t *, vbool64_t, vfloat64m1_t, vfloat64m1_t, vfloat64m1_t, vfloat64m1_t, vfloat64m1_t, const double *, vuint8mf8_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vluxseg6ei8_v)))
void vluxseg6ei8_v_f64m1(vfloat64m1_t *, vfloat64m1_t *, vfloat64m1_t *, vfloat64m1_t *, vfloat64m1_t *, vfloat64m1_t *, const double *, vuint8mf8_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vluxseg6ei8_v_m)))
void vluxseg6ei8_v_f64m1_m(vfloat64m1_t *, vfloat64m1_t *, vfloat64m1_t *, vfloat64m1_t *, vfloat64m1_t *, vfloat64m1_t *, vbool64_t, vfloat64m1_t, vfloat64m1_t, vfloat64m1_t, vfloat64m1_t, vfloat64m1_t, vfloat64m1_t, const double *, vuint8mf8_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vluxseg7ei8_v)))
void vluxseg7ei8_v_f64m1(vfloat64m1_t *, vfloat64m1_t *, vfloat64m1_t *, vfloat64m1_t *, vfloat64m1_t *, vfloat64m1_t *, vfloat64m1_t *, const double *, vuint8mf8_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vluxseg7ei8_v_m)))
void vluxseg7ei8_v_f64m1_m(vfloat64m1_t *, vfloat64m1_t *, vfloat64m1_t *, vfloat64m1_t *, vfloat64m1_t *, vfloat64m1_t *, vfloat64m1_t *, vbool64_t, vfloat64m1_t, vfloat64m1_t, vfloat64m1_t, vfloat64m1_t, vfloat64m1_t, vfloat64m1_t, vfloat64m1_t, const double *, vuint8mf8_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vluxseg8ei8_v)))
void vluxseg8ei8_v_f64m1(vfloat64m1_t *, vfloat64m1_t *, vfloat64m1_t *, vfloat64m1_t *, vfloat64m1_t *, vfloat64m1_t *, vfloat64m1_t *, vfloat64m1_t *, const double *, vuint8mf8_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vluxseg8ei8_v_m)))
void vluxseg8ei8_v_f64m1_m(vfloat64m1_t *, vfloat64m1_t *, vfloat64m1_t *, vfloat64m1_t *, vfloat64m1_t *, vfloat64m1_t *, vfloat64m1_t *, vfloat64m1_t *, vbool64_t, vfloat64m1_t, vfloat64m1_t, vfloat64m1_t, vfloat64m1_t, vfloat64m1_t, vfloat64m1_t, vfloat64m1_t, vfloat64m1_t, const double *, vuint8mf8_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vluxseg2ei16_v)))
void vluxseg2ei16_v_f64m1(vfloat64m1_t *, vfloat64m1_t *, const double *, vuint16mf4_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vluxseg2ei16_v_m)))
void vluxseg2ei16_v_f64m1_m(vfloat64m1_t *, vfloat64m1_t *, vbool64_t, vfloat64m1_t, vfloat64m1_t, const double *, vuint16mf4_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vluxseg2ei16_v)))
void vluxseg2ei16_v_f64m2(vfloat64m2_t *, vfloat64m2_t *, const double *, vuint16mf2_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vluxseg2ei16_v_m)))
void vluxseg2ei16_v_f64m2_m(vfloat64m2_t *, vfloat64m2_t *, vbool32_t, vfloat64m2_t, vfloat64m2_t, const double *, vuint16mf2_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vluxseg2ei16_v)))
void vluxseg2ei16_v_f64m4(vfloat64m4_t *, vfloat64m4_t *, const double *, vuint16m1_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vluxseg2ei16_v_m)))
void vluxseg2ei16_v_f64m4_m(vfloat64m4_t *, vfloat64m4_t *, vbool16_t, vfloat64m4_t, vfloat64m4_t, const double *, vuint16m1_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vluxseg3ei16_v)))
void vluxseg3ei16_v_f64m1(vfloat64m1_t *, vfloat64m1_t *, vfloat64m1_t *, const double *, vuint16mf4_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vluxseg3ei16_v_m)))
void vluxseg3ei16_v_f64m1_m(vfloat64m1_t *, vfloat64m1_t *, vfloat64m1_t *, vbool64_t, vfloat64m1_t, vfloat64m1_t, vfloat64m1_t, const double *, vuint16mf4_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vluxseg3ei16_v)))
void vluxseg3ei16_v_f64m2(vfloat64m2_t *, vfloat64m2_t *, vfloat64m2_t *, const double *, vuint16mf2_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vluxseg3ei16_v_m)))
void vluxseg3ei16_v_f64m2_m(vfloat64m2_t *, vfloat64m2_t *, vfloat64m2_t *, vbool32_t, vfloat64m2_t, vfloat64m2_t, vfloat64m2_t, const double *, vuint16mf2_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vluxseg4ei16_v)))
void vluxseg4ei16_v_f64m1(vfloat64m1_t *, vfloat64m1_t *, vfloat64m1_t *, vfloat64m1_t *, const double *, vuint16mf4_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vluxseg4ei16_v_m)))
void vluxseg4ei16_v_f64m1_m(vfloat64m1_t *, vfloat64m1_t *, vfloat64m1_t *, vfloat64m1_t *, vbool64_t, vfloat64m1_t, vfloat64m1_t, vfloat64m1_t, vfloat64m1_t, const double *, vuint16mf4_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vluxseg4ei16_v)))
void vluxseg4ei16_v_f64m2(vfloat64m2_t *, vfloat64m2_t *, vfloat64m2_t *, vfloat64m2_t *, const double *, vuint16mf2_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vluxseg4ei16_v_m)))
void vluxseg4ei16_v_f64m2_m(vfloat64m2_t *, vfloat64m2_t *, vfloat64m2_t *, vfloat64m2_t *, vbool32_t, vfloat64m2_t, vfloat64m2_t, vfloat64m2_t, vfloat64m2_t, const double *, vuint16mf2_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vluxseg5ei16_v)))
void vluxseg5ei16_v_f64m1(vfloat64m1_t *, vfloat64m1_t *, vfloat64m1_t *, vfloat64m1_t *, vfloat64m1_t *, const double *, vuint16mf4_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vluxseg5ei16_v_m)))
void vluxseg5ei16_v_f64m1_m(vfloat64m1_t *, vfloat64m1_t *, vfloat64m1_t *, vfloat64m1_t *, vfloat64m1_t *, vbool64_t, vfloat64m1_t, vfloat64m1_t, vfloat64m1_t, vfloat64m1_t, vfloat64m1_t, const double *, vuint16mf4_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vluxseg6ei16_v)))
void vluxseg6ei16_v_f64m1(vfloat64m1_t *, vfloat64m1_t *, vfloat64m1_t *, vfloat64m1_t *, vfloat64m1_t *, vfloat64m1_t *, const double *, vuint16mf4_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vluxseg6ei16_v_m)))
void vluxseg6ei16_v_f64m1_m(vfloat64m1_t *, vfloat64m1_t *, vfloat64m1_t *, vfloat64m1_t *, vfloat64m1_t *, vfloat64m1_t *, vbool64_t, vfloat64m1_t, vfloat64m1_t, vfloat64m1_t, vfloat64m1_t, vfloat64m1_t, vfloat64m1_t, const double *, vuint16mf4_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vluxseg7ei16_v)))
void vluxseg7ei16_v_f64m1(vfloat64m1_t *, vfloat64m1_t *, vfloat64m1_t *, vfloat64m1_t *, vfloat64m1_t *, vfloat64m1_t *, vfloat64m1_t *, const double *, vuint16mf4_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vluxseg7ei16_v_m)))
void vluxseg7ei16_v_f64m1_m(vfloat64m1_t *, vfloat64m1_t *, vfloat64m1_t *, vfloat64m1_t *, vfloat64m1_t *, vfloat64m1_t *, vfloat64m1_t *, vbool64_t, vfloat64m1_t, vfloat64m1_t, vfloat64m1_t, vfloat64m1_t, vfloat64m1_t, vfloat64m1_t, vfloat64m1_t, const double *, vuint16mf4_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vluxseg8ei16_v)))
void vluxseg8ei16_v_f64m1(vfloat64m1_t *, vfloat64m1_t *, vfloat64m1_t *, vfloat64m1_t *, vfloat64m1_t *, vfloat64m1_t *, vfloat64m1_t *, vfloat64m1_t *, const double *, vuint16mf4_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vluxseg8ei16_v_m)))
void vluxseg8ei16_v_f64m1_m(vfloat64m1_t *, vfloat64m1_t *, vfloat64m1_t *, vfloat64m1_t *, vfloat64m1_t *, vfloat64m1_t *, vfloat64m1_t *, vfloat64m1_t *, vbool64_t, vfloat64m1_t, vfloat64m1_t, vfloat64m1_t, vfloat64m1_t, vfloat64m1_t, vfloat64m1_t, vfloat64m1_t, vfloat64m1_t, const double *, vuint16mf4_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vluxseg2ei32_v)))
void vluxseg2ei32_v_f64m1(vfloat64m1_t *, vfloat64m1_t *, const double *, vuint32mf2_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vluxseg2ei32_v_m)))
void vluxseg2ei32_v_f64m1_m(vfloat64m1_t *, vfloat64m1_t *, vbool64_t, vfloat64m1_t, vfloat64m1_t, const double *, vuint32mf2_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vluxseg2ei32_v)))
void vluxseg2ei32_v_f64m2(vfloat64m2_t *, vfloat64m2_t *, const double *, vuint32m1_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vluxseg2ei32_v_m)))
void vluxseg2ei32_v_f64m2_m(vfloat64m2_t *, vfloat64m2_t *, vbool32_t, vfloat64m2_t, vfloat64m2_t, const double *, vuint32m1_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vluxseg2ei32_v)))
void vluxseg2ei32_v_f64m4(vfloat64m4_t *, vfloat64m4_t *, const double *, vuint32m2_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vluxseg2ei32_v_m)))
void vluxseg2ei32_v_f64m4_m(vfloat64m4_t *, vfloat64m4_t *, vbool16_t, vfloat64m4_t, vfloat64m4_t, const double *, vuint32m2_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vluxseg3ei32_v)))
void vluxseg3ei32_v_f64m1(vfloat64m1_t *, vfloat64m1_t *, vfloat64m1_t *, const double *, vuint32mf2_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vluxseg3ei32_v_m)))
void vluxseg3ei32_v_f64m1_m(vfloat64m1_t *, vfloat64m1_t *, vfloat64m1_t *, vbool64_t, vfloat64m1_t, vfloat64m1_t, vfloat64m1_t, const double *, vuint32mf2_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vluxseg3ei32_v)))
void vluxseg3ei32_v_f64m2(vfloat64m2_t *, vfloat64m2_t *, vfloat64m2_t *, const double *, vuint32m1_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vluxseg3ei32_v_m)))
void vluxseg3ei32_v_f64m2_m(vfloat64m2_t *, vfloat64m2_t *, vfloat64m2_t *, vbool32_t, vfloat64m2_t, vfloat64m2_t, vfloat64m2_t, const double *, vuint32m1_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vluxseg4ei32_v)))
void vluxseg4ei32_v_f64m1(vfloat64m1_t *, vfloat64m1_t *, vfloat64m1_t *, vfloat64m1_t *, const double *, vuint32mf2_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vluxseg4ei32_v_m)))
void vluxseg4ei32_v_f64m1_m(vfloat64m1_t *, vfloat64m1_t *, vfloat64m1_t *, vfloat64m1_t *, vbool64_t, vfloat64m1_t, vfloat64m1_t, vfloat64m1_t, vfloat64m1_t, const double *, vuint32mf2_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vluxseg4ei32_v)))
void vluxseg4ei32_v_f64m2(vfloat64m2_t *, vfloat64m2_t *, vfloat64m2_t *, vfloat64m2_t *, const double *, vuint32m1_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vluxseg4ei32_v_m)))
void vluxseg4ei32_v_f64m2_m(vfloat64m2_t *, vfloat64m2_t *, vfloat64m2_t *, vfloat64m2_t *, vbool32_t, vfloat64m2_t, vfloat64m2_t, vfloat64m2_t, vfloat64m2_t, const double *, vuint32m1_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vluxseg5ei32_v)))
void vluxseg5ei32_v_f64m1(vfloat64m1_t *, vfloat64m1_t *, vfloat64m1_t *, vfloat64m1_t *, vfloat64m1_t *, const double *, vuint32mf2_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vluxseg5ei32_v_m)))
void vluxseg5ei32_v_f64m1_m(vfloat64m1_t *, vfloat64m1_t *, vfloat64m1_t *, vfloat64m1_t *, vfloat64m1_t *, vbool64_t, vfloat64m1_t, vfloat64m1_t, vfloat64m1_t, vfloat64m1_t, vfloat64m1_t, const double *, vuint32mf2_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vluxseg6ei32_v)))
void vluxseg6ei32_v_f64m1(vfloat64m1_t *, vfloat64m1_t *, vfloat64m1_t *, vfloat64m1_t *, vfloat64m1_t *, vfloat64m1_t *, const double *, vuint32mf2_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vluxseg6ei32_v_m)))
void vluxseg6ei32_v_f64m1_m(vfloat64m1_t *, vfloat64m1_t *, vfloat64m1_t *, vfloat64m1_t *, vfloat64m1_t *, vfloat64m1_t *, vbool64_t, vfloat64m1_t, vfloat64m1_t, vfloat64m1_t, vfloat64m1_t, vfloat64m1_t, vfloat64m1_t, const double *, vuint32mf2_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vluxseg7ei32_v)))
void vluxseg7ei32_v_f64m1(vfloat64m1_t *, vfloat64m1_t *, vfloat64m1_t *, vfloat64m1_t *, vfloat64m1_t *, vfloat64m1_t *, vfloat64m1_t *, const double *, vuint32mf2_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vluxseg7ei32_v_m)))
void vluxseg7ei32_v_f64m1_m(vfloat64m1_t *, vfloat64m1_t *, vfloat64m1_t *, vfloat64m1_t *, vfloat64m1_t *, vfloat64m1_t *, vfloat64m1_t *, vbool64_t, vfloat64m1_t, vfloat64m1_t, vfloat64m1_t, vfloat64m1_t, vfloat64m1_t, vfloat64m1_t, vfloat64m1_t, const double *, vuint32mf2_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vluxseg8ei32_v)))
void vluxseg8ei32_v_f64m1(vfloat64m1_t *, vfloat64m1_t *, vfloat64m1_t *, vfloat64m1_t *, vfloat64m1_t *, vfloat64m1_t *, vfloat64m1_t *, vfloat64m1_t *, const double *, vuint32mf2_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vluxseg8ei32_v_m)))
void vluxseg8ei32_v_f64m1_m(vfloat64m1_t *, vfloat64m1_t *, vfloat64m1_t *, vfloat64m1_t *, vfloat64m1_t *, vfloat64m1_t *, vfloat64m1_t *, vfloat64m1_t *, vbool64_t, vfloat64m1_t, vfloat64m1_t, vfloat64m1_t, vfloat64m1_t, vfloat64m1_t, vfloat64m1_t, vfloat64m1_t, vfloat64m1_t, const double *, vuint32mf2_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vluxseg2ei64_v)))
void vluxseg2ei64_v_f64m1(vfloat64m1_t *, vfloat64m1_t *, const double *, vuint64m1_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vluxseg2ei64_v_m)))
void vluxseg2ei64_v_f64m1_m(vfloat64m1_t *, vfloat64m1_t *, vbool64_t, vfloat64m1_t, vfloat64m1_t, const double *, vuint64m1_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vluxseg2ei64_v)))
void vluxseg2ei64_v_f64m2(vfloat64m2_t *, vfloat64m2_t *, const double *, vuint64m2_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vluxseg2ei64_v_m)))
void vluxseg2ei64_v_f64m2_m(vfloat64m2_t *, vfloat64m2_t *, vbool32_t, vfloat64m2_t, vfloat64m2_t, const double *, vuint64m2_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vluxseg2ei64_v)))
void vluxseg2ei64_v_f64m4(vfloat64m4_t *, vfloat64m4_t *, const double *, vuint64m4_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vluxseg2ei64_v_m)))
void vluxseg2ei64_v_f64m4_m(vfloat64m4_t *, vfloat64m4_t *, vbool16_t, vfloat64m4_t, vfloat64m4_t, const double *, vuint64m4_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vluxseg3ei64_v)))
void vluxseg3ei64_v_f64m1(vfloat64m1_t *, vfloat64m1_t *, vfloat64m1_t *, const double *, vuint64m1_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vluxseg3ei64_v_m)))
void vluxseg3ei64_v_f64m1_m(vfloat64m1_t *, vfloat64m1_t *, vfloat64m1_t *, vbool64_t, vfloat64m1_t, vfloat64m1_t, vfloat64m1_t, const double *, vuint64m1_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vluxseg3ei64_v)))
void vluxseg3ei64_v_f64m2(vfloat64m2_t *, vfloat64m2_t *, vfloat64m2_t *, const double *, vuint64m2_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vluxseg3ei64_v_m)))
void vluxseg3ei64_v_f64m2_m(vfloat64m2_t *, vfloat64m2_t *, vfloat64m2_t *, vbool32_t, vfloat64m2_t, vfloat64m2_t, vfloat64m2_t, const double *, vuint64m2_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vluxseg4ei64_v)))
void vluxseg4ei64_v_f64m1(vfloat64m1_t *, vfloat64m1_t *, vfloat64m1_t *, vfloat64m1_t *, const double *, vuint64m1_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vluxseg4ei64_v_m)))
void vluxseg4ei64_v_f64m1_m(vfloat64m1_t *, vfloat64m1_t *, vfloat64m1_t *, vfloat64m1_t *, vbool64_t, vfloat64m1_t, vfloat64m1_t, vfloat64m1_t, vfloat64m1_t, const double *, vuint64m1_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vluxseg4ei64_v)))
void vluxseg4ei64_v_f64m2(vfloat64m2_t *, vfloat64m2_t *, vfloat64m2_t *, vfloat64m2_t *, const double *, vuint64m2_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vluxseg4ei64_v_m)))
void vluxseg4ei64_v_f64m2_m(vfloat64m2_t *, vfloat64m2_t *, vfloat64m2_t *, vfloat64m2_t *, vbool32_t, vfloat64m2_t, vfloat64m2_t, vfloat64m2_t, vfloat64m2_t, const double *, vuint64m2_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vluxseg5ei64_v)))
void vluxseg5ei64_v_f64m1(vfloat64m1_t *, vfloat64m1_t *, vfloat64m1_t *, vfloat64m1_t *, vfloat64m1_t *, const double *, vuint64m1_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vluxseg5ei64_v_m)))
void vluxseg5ei64_v_f64m1_m(vfloat64m1_t *, vfloat64m1_t *, vfloat64m1_t *, vfloat64m1_t *, vfloat64m1_t *, vbool64_t, vfloat64m1_t, vfloat64m1_t, vfloat64m1_t, vfloat64m1_t, vfloat64m1_t, const double *, vuint64m1_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vluxseg6ei64_v)))
void vluxseg6ei64_v_f64m1(vfloat64m1_t *, vfloat64m1_t *, vfloat64m1_t *, vfloat64m1_t *, vfloat64m1_t *, vfloat64m1_t *, const double *, vuint64m1_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vluxseg6ei64_v_m)))
void vluxseg6ei64_v_f64m1_m(vfloat64m1_t *, vfloat64m1_t *, vfloat64m1_t *, vfloat64m1_t *, vfloat64m1_t *, vfloat64m1_t *, vbool64_t, vfloat64m1_t, vfloat64m1_t, vfloat64m1_t, vfloat64m1_t, vfloat64m1_t, vfloat64m1_t, const double *, vuint64m1_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vluxseg7ei64_v)))
void vluxseg7ei64_v_f64m1(vfloat64m1_t *, vfloat64m1_t *, vfloat64m1_t *, vfloat64m1_t *, vfloat64m1_t *, vfloat64m1_t *, vfloat64m1_t *, const double *, vuint64m1_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vluxseg7ei64_v_m)))
void vluxseg7ei64_v_f64m1_m(vfloat64m1_t *, vfloat64m1_t *, vfloat64m1_t *, vfloat64m1_t *, vfloat64m1_t *, vfloat64m1_t *, vfloat64m1_t *, vbool64_t, vfloat64m1_t, vfloat64m1_t, vfloat64m1_t, vfloat64m1_t, vfloat64m1_t, vfloat64m1_t, vfloat64m1_t, const double *, vuint64m1_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vluxseg8ei64_v)))
void vluxseg8ei64_v_f64m1(vfloat64m1_t *, vfloat64m1_t *, vfloat64m1_t *, vfloat64m1_t *, vfloat64m1_t *, vfloat64m1_t *, vfloat64m1_t *, vfloat64m1_t *, const double *, vuint64m1_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vluxseg8ei64_v_m)))
void vluxseg8ei64_v_f64m1_m(vfloat64m1_t *, vfloat64m1_t *, vfloat64m1_t *, vfloat64m1_t *, vfloat64m1_t *, vfloat64m1_t *, vfloat64m1_t *, vfloat64m1_t *, vbool64_t, vfloat64m1_t, vfloat64m1_t, vfloat64m1_t, vfloat64m1_t, vfloat64m1_t, vfloat64m1_t, vfloat64m1_t, vfloat64m1_t, const double *, vuint64m1_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vle64_v)))
vfloat64m1_t vle64_v_f64m1(const double *, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vle64_v_m)))
vfloat64m1_t vle64_v_f64m1_m(vbool64_t, vfloat64m1_t, const double *, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vle64_v)))
vfloat64m2_t vle64_v_f64m2(const double *, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vle64_v_m)))
vfloat64m2_t vle64_v_f64m2_m(vbool32_t, vfloat64m2_t, const double *, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vle64_v)))
vfloat64m4_t vle64_v_f64m4(const double *, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vle64_v_m)))
vfloat64m4_t vle64_v_f64m4_m(vbool16_t, vfloat64m4_t, const double *, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vle64_v)))
vfloat64m8_t vle64_v_f64m8(const double *, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vle64_v_m)))
vfloat64m8_t vle64_v_f64m8_m(vbool8_t, vfloat64m8_t, const double *, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vse64_v)))
void vse64_v_f64m1(double *, vfloat64m1_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vse64_v_m)))
void vse64_v_f64m1_m(vbool64_t, double *, vfloat64m1_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vse64_v)))
void vse64_v_f64m2(double *, vfloat64m2_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vse64_v_m)))
void vse64_v_f64m2_m(vbool32_t, double *, vfloat64m2_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vse64_v)))
void vse64_v_f64m4(double *, vfloat64m4_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vse64_v_m)))
void vse64_v_f64m4_m(vbool16_t, double *, vfloat64m4_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vse64_v)))
void vse64_v_f64m8(double *, vfloat64m8_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vse64_v_m)))
void vse64_v_f64m8_m(vbool8_t, double *, vfloat64m8_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vfclass_v)))
vuint64m1_t vfclass_v_u64m1(vfloat64m1_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vfclass_v_m)))
vuint64m1_t vfclass_v_u64m1_m(vbool64_t, vuint64m1_t, vfloat64m1_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vfclass_v)))
vuint64m2_t vfclass_v_u64m2(vfloat64m2_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vfclass_v_m)))
vuint64m2_t vfclass_v_u64m2_m(vbool32_t, vuint64m2_t, vfloat64m2_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vfclass_v)))
vuint64m4_t vfclass_v_u64m4(vfloat64m4_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vfclass_v_m)))
vuint64m4_t vfclass_v_u64m4_m(vbool16_t, vuint64m4_t, vfloat64m4_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vfclass_v)))
vuint64m8_t vfclass_v_u64m8(vfloat64m8_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vfclass_v_m)))
vuint64m8_t vfclass_v_u64m8_m(vbool8_t, vuint64m8_t, vfloat64m8_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vfcvt_f_x_v)))
vfloat64m1_t vfcvt_f_x_v_f64m1(vint64m1_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vfcvt_f_x_v_m)))
vfloat64m1_t vfcvt_f_x_v_f64m1_m(vbool64_t, vfloat64m1_t, vint64m1_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vfcvt_f_x_v)))
vfloat64m2_t vfcvt_f_x_v_f64m2(vint64m2_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vfcvt_f_x_v_m)))
vfloat64m2_t vfcvt_f_x_v_f64m2_m(vbool32_t, vfloat64m2_t, vint64m2_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vfcvt_f_x_v)))
vfloat64m4_t vfcvt_f_x_v_f64m4(vint64m4_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vfcvt_f_x_v_m)))
vfloat64m4_t vfcvt_f_x_v_f64m4_m(vbool16_t, vfloat64m4_t, vint64m4_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vfcvt_f_x_v)))
vfloat64m8_t vfcvt_f_x_v_f64m8(vint64m8_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vfcvt_f_x_v_m)))
vfloat64m8_t vfcvt_f_x_v_f64m8_m(vbool8_t, vfloat64m8_t, vint64m8_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vfcvt_f_xu_v)))
vfloat64m1_t vfcvt_f_xu_v_f64m1(vuint64m1_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vfcvt_f_xu_v_m)))
vfloat64m1_t vfcvt_f_xu_v_f64m1_m(vbool64_t, vfloat64m1_t, vuint64m1_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vfcvt_f_xu_v)))
vfloat64m2_t vfcvt_f_xu_v_f64m2(vuint64m2_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vfcvt_f_xu_v_m)))
vfloat64m2_t vfcvt_f_xu_v_f64m2_m(vbool32_t, vfloat64m2_t, vuint64m2_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vfcvt_f_xu_v)))
vfloat64m4_t vfcvt_f_xu_v_f64m4(vuint64m4_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vfcvt_f_xu_v_m)))
vfloat64m4_t vfcvt_f_xu_v_f64m4_m(vbool16_t, vfloat64m4_t, vuint64m4_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vfcvt_f_xu_v)))
vfloat64m8_t vfcvt_f_xu_v_f64m8(vuint64m8_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vfcvt_f_xu_v_m)))
vfloat64m8_t vfcvt_f_xu_v_f64m8_m(vbool8_t, vfloat64m8_t, vuint64m8_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vfcvt_rtz_x_f_v)))
vint64m1_t vfcvt_rtz_x_f_v_i64m1(vfloat64m1_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vfcvt_rtz_x_f_v_m)))
vint64m1_t vfcvt_rtz_x_f_v_i64m1_m(vbool64_t, vint64m1_t, vfloat64m1_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vfcvt_rtz_x_f_v)))
vint64m2_t vfcvt_rtz_x_f_v_i64m2(vfloat64m2_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vfcvt_rtz_x_f_v_m)))
vint64m2_t vfcvt_rtz_x_f_v_i64m2_m(vbool32_t, vint64m2_t, vfloat64m2_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vfcvt_rtz_x_f_v)))
vint64m4_t vfcvt_rtz_x_f_v_i64m4(vfloat64m4_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vfcvt_rtz_x_f_v_m)))
vint64m4_t vfcvt_rtz_x_f_v_i64m4_m(vbool16_t, vint64m4_t, vfloat64m4_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vfcvt_rtz_x_f_v)))
vint64m8_t vfcvt_rtz_x_f_v_i64m8(vfloat64m8_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vfcvt_rtz_x_f_v_m)))
vint64m8_t vfcvt_rtz_x_f_v_i64m8_m(vbool8_t, vint64m8_t, vfloat64m8_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vfcvt_rtz_xu_f_v)))
vuint64m1_t vfcvt_rtz_xu_f_v_u64m1(vfloat64m1_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vfcvt_rtz_xu_f_v_m)))
vuint64m1_t vfcvt_rtz_xu_f_v_u64m1_m(vbool64_t, vuint64m1_t, vfloat64m1_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vfcvt_rtz_xu_f_v)))
vuint64m2_t vfcvt_rtz_xu_f_v_u64m2(vfloat64m2_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vfcvt_rtz_xu_f_v_m)))
vuint64m2_t vfcvt_rtz_xu_f_v_u64m2_m(vbool32_t, vuint64m2_t, vfloat64m2_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vfcvt_rtz_xu_f_v)))
vuint64m4_t vfcvt_rtz_xu_f_v_u64m4(vfloat64m4_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vfcvt_rtz_xu_f_v_m)))
vuint64m4_t vfcvt_rtz_xu_f_v_u64m4_m(vbool16_t, vuint64m4_t, vfloat64m4_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vfcvt_rtz_xu_f_v)))
vuint64m8_t vfcvt_rtz_xu_f_v_u64m8(vfloat64m8_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vfcvt_rtz_xu_f_v_m)))
vuint64m8_t vfcvt_rtz_xu_f_v_u64m8_m(vbool8_t, vuint64m8_t, vfloat64m8_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vfcvt_x_f_v)))
vint64m1_t vfcvt_x_f_v_i64m1(vfloat64m1_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vfcvt_x_f_v_m)))
vint64m1_t vfcvt_x_f_v_i64m1_m(vbool64_t, vint64m1_t, vfloat64m1_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vfcvt_x_f_v)))
vint64m2_t vfcvt_x_f_v_i64m2(vfloat64m2_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vfcvt_x_f_v_m)))
vint64m2_t vfcvt_x_f_v_i64m2_m(vbool32_t, vint64m2_t, vfloat64m2_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vfcvt_x_f_v)))
vint64m4_t vfcvt_x_f_v_i64m4(vfloat64m4_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vfcvt_x_f_v_m)))
vint64m4_t vfcvt_x_f_v_i64m4_m(vbool16_t, vint64m4_t, vfloat64m4_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vfcvt_x_f_v)))
vint64m8_t vfcvt_x_f_v_i64m8(vfloat64m8_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vfcvt_x_f_v_m)))
vint64m8_t vfcvt_x_f_v_i64m8_m(vbool8_t, vint64m8_t, vfloat64m8_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vfcvt_xu_f_v)))
vuint64m1_t vfcvt_xu_f_v_u64m1(vfloat64m1_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vfcvt_xu_f_v_m)))
vuint64m1_t vfcvt_xu_f_v_u64m1_m(vbool64_t, vuint64m1_t, vfloat64m1_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vfcvt_xu_f_v)))
vuint64m2_t vfcvt_xu_f_v_u64m2(vfloat64m2_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vfcvt_xu_f_v_m)))
vuint64m2_t vfcvt_xu_f_v_u64m2_m(vbool32_t, vuint64m2_t, vfloat64m2_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vfcvt_xu_f_v)))
vuint64m4_t vfcvt_xu_f_v_u64m4(vfloat64m4_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vfcvt_xu_f_v_m)))
vuint64m4_t vfcvt_xu_f_v_u64m4_m(vbool16_t, vuint64m4_t, vfloat64m4_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vfcvt_xu_f_v)))
vuint64m8_t vfcvt_xu_f_v_u64m8(vfloat64m8_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vfcvt_xu_f_v_m)))
vuint64m8_t vfcvt_xu_f_v_u64m8_m(vbool8_t, vuint64m8_t, vfloat64m8_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vfncvt_rtz_x_f_w)))
vint32mf2_t vfncvt_rtz_x_f_w_i32mf2(vfloat64m1_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vfncvt_rtz_x_f_w_m)))
vint32mf2_t vfncvt_rtz_x_f_w_i32mf2_m(vbool64_t, vint32mf2_t, vfloat64m1_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vfncvt_rtz_x_f_w)))
vint32m1_t vfncvt_rtz_x_f_w_i32m1(vfloat64m2_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vfncvt_rtz_x_f_w_m)))
vint32m1_t vfncvt_rtz_x_f_w_i32m1_m(vbool32_t, vint32m1_t, vfloat64m2_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vfncvt_rtz_x_f_w)))
vint32m2_t vfncvt_rtz_x_f_w_i32m2(vfloat64m4_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vfncvt_rtz_x_f_w_m)))
vint32m2_t vfncvt_rtz_x_f_w_i32m2_m(vbool16_t, vint32m2_t, vfloat64m4_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vfncvt_rtz_x_f_w)))
vint32m4_t vfncvt_rtz_x_f_w_i32m4(vfloat64m8_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vfncvt_rtz_x_f_w_m)))
vint32m4_t vfncvt_rtz_x_f_w_i32m4_m(vbool8_t, vint32m4_t, vfloat64m8_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vfncvt_rtz_xu_f_w)))
vuint32mf2_t vfncvt_rtz_xu_f_w_u32mf2(vfloat64m1_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vfncvt_rtz_xu_f_w_m)))
vuint32mf2_t vfncvt_rtz_xu_f_w_u32mf2_m(vbool64_t, vuint32mf2_t, vfloat64m1_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vfncvt_rtz_xu_f_w)))
vuint32m1_t vfncvt_rtz_xu_f_w_u32m1(vfloat64m2_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vfncvt_rtz_xu_f_w_m)))
vuint32m1_t vfncvt_rtz_xu_f_w_u32m1_m(vbool32_t, vuint32m1_t, vfloat64m2_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vfncvt_rtz_xu_f_w)))
vuint32m2_t vfncvt_rtz_xu_f_w_u32m2(vfloat64m4_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vfncvt_rtz_xu_f_w_m)))
vuint32m2_t vfncvt_rtz_xu_f_w_u32m2_m(vbool16_t, vuint32m2_t, vfloat64m4_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vfncvt_rtz_xu_f_w)))
vuint32m4_t vfncvt_rtz_xu_f_w_u32m4(vfloat64m8_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vfncvt_rtz_xu_f_w_m)))
vuint32m4_t vfncvt_rtz_xu_f_w_u32m4_m(vbool8_t, vuint32m4_t, vfloat64m8_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vfncvt_x_f_w)))
vint32mf2_t vfncvt_x_f_w_i32mf2(vfloat64m1_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vfncvt_x_f_w_m)))
vint32mf2_t vfncvt_x_f_w_i32mf2_m(vbool64_t, vint32mf2_t, vfloat64m1_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vfncvt_x_f_w)))
vint32m1_t vfncvt_x_f_w_i32m1(vfloat64m2_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vfncvt_x_f_w_m)))
vint32m1_t vfncvt_x_f_w_i32m1_m(vbool32_t, vint32m1_t, vfloat64m2_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vfncvt_x_f_w)))
vint32m2_t vfncvt_x_f_w_i32m2(vfloat64m4_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vfncvt_x_f_w_m)))
vint32m2_t vfncvt_x_f_w_i32m2_m(vbool16_t, vint32m2_t, vfloat64m4_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vfncvt_x_f_w)))
vint32m4_t vfncvt_x_f_w_i32m4(vfloat64m8_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vfncvt_x_f_w_m)))
vint32m4_t vfncvt_x_f_w_i32m4_m(vbool8_t, vint32m4_t, vfloat64m8_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vfncvt_xu_f_w)))
vuint32mf2_t vfncvt_xu_f_w_u32mf2(vfloat64m1_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vfncvt_xu_f_w_m)))
vuint32mf2_t vfncvt_xu_f_w_u32mf2_m(vbool64_t, vuint32mf2_t, vfloat64m1_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vfncvt_xu_f_w)))
vuint32m1_t vfncvt_xu_f_w_u32m1(vfloat64m2_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vfncvt_xu_f_w_m)))
vuint32m1_t vfncvt_xu_f_w_u32m1_m(vbool32_t, vuint32m1_t, vfloat64m2_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vfncvt_xu_f_w)))
vuint32m2_t vfncvt_xu_f_w_u32m2(vfloat64m4_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vfncvt_xu_f_w_m)))
vuint32m2_t vfncvt_xu_f_w_u32m2_m(vbool16_t, vuint32m2_t, vfloat64m4_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vfncvt_xu_f_w)))
vuint32m4_t vfncvt_xu_f_w_u32m4(vfloat64m8_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vfncvt_xu_f_w_m)))
vuint32m4_t vfncvt_xu_f_w_u32m4_m(vbool8_t, vuint32m4_t, vfloat64m8_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vfrec7_v)))
vfloat64m1_t vfrec7_v_f64m1(vfloat64m1_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vfrec7_v_m)))
vfloat64m1_t vfrec7_v_f64m1_m(vbool64_t, vfloat64m1_t, vfloat64m1_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vfrec7_v)))
vfloat64m2_t vfrec7_v_f64m2(vfloat64m2_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vfrec7_v_m)))
vfloat64m2_t vfrec7_v_f64m2_m(vbool32_t, vfloat64m2_t, vfloat64m2_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vfrec7_v)))
vfloat64m4_t vfrec7_v_f64m4(vfloat64m4_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vfrec7_v_m)))
vfloat64m4_t vfrec7_v_f64m4_m(vbool16_t, vfloat64m4_t, vfloat64m4_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vfrec7_v)))
vfloat64m8_t vfrec7_v_f64m8(vfloat64m8_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vfrec7_v_m)))
vfloat64m8_t vfrec7_v_f64m8_m(vbool8_t, vfloat64m8_t, vfloat64m8_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vfrsqrt7_v)))
vfloat64m1_t vfrsqrt7_v_f64m1(vfloat64m1_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vfrsqrt7_v_m)))
vfloat64m1_t vfrsqrt7_v_f64m1_m(vbool64_t, vfloat64m1_t, vfloat64m1_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vfrsqrt7_v)))
vfloat64m2_t vfrsqrt7_v_f64m2(vfloat64m2_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vfrsqrt7_v_m)))
vfloat64m2_t vfrsqrt7_v_f64m2_m(vbool32_t, vfloat64m2_t, vfloat64m2_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vfrsqrt7_v)))
vfloat64m4_t vfrsqrt7_v_f64m4(vfloat64m4_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vfrsqrt7_v_m)))
vfloat64m4_t vfrsqrt7_v_f64m4_m(vbool16_t, vfloat64m4_t, vfloat64m4_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vfrsqrt7_v)))
vfloat64m8_t vfrsqrt7_v_f64m8(vfloat64m8_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vfrsqrt7_v_m)))
vfloat64m8_t vfrsqrt7_v_f64m8_m(vbool8_t, vfloat64m8_t, vfloat64m8_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vfsqrt_v)))
vfloat64m1_t vfsqrt_v_f64m1(vfloat64m1_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vfsqrt_v_m)))
vfloat64m1_t vfsqrt_v_f64m1_m(vbool64_t, vfloat64m1_t, vfloat64m1_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vfsqrt_v)))
vfloat64m2_t vfsqrt_v_f64m2(vfloat64m2_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vfsqrt_v_m)))
vfloat64m2_t vfsqrt_v_f64m2_m(vbool32_t, vfloat64m2_t, vfloat64m2_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vfsqrt_v)))
vfloat64m4_t vfsqrt_v_f64m4(vfloat64m4_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vfsqrt_v_m)))
vfloat64m4_t vfsqrt_v_f64m4_m(vbool16_t, vfloat64m4_t, vfloat64m4_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vfsqrt_v)))
vfloat64m8_t vfsqrt_v_f64m8(vfloat64m8_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vfsqrt_v_m)))
vfloat64m8_t vfsqrt_v_f64m8_m(vbool8_t, vfloat64m8_t, vfloat64m8_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vfwcvt_f_x_v)))
vfloat64m1_t vfwcvt_f_x_v_f64m1(vint32mf2_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vfwcvt_f_x_v_m)))
vfloat64m1_t vfwcvt_f_x_v_f64m1_m(vbool64_t, vfloat64m1_t, vint32mf2_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vfwcvt_f_x_v)))
vfloat64m2_t vfwcvt_f_x_v_f64m2(vint32m1_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vfwcvt_f_x_v_m)))
vfloat64m2_t vfwcvt_f_x_v_f64m2_m(vbool32_t, vfloat64m2_t, vint32m1_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vfwcvt_f_x_v)))
vfloat64m4_t vfwcvt_f_x_v_f64m4(vint32m2_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vfwcvt_f_x_v_m)))
vfloat64m4_t vfwcvt_f_x_v_f64m4_m(vbool16_t, vfloat64m4_t, vint32m2_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vfwcvt_f_x_v)))
vfloat64m8_t vfwcvt_f_x_v_f64m8(vint32m4_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vfwcvt_f_x_v_m)))
vfloat64m8_t vfwcvt_f_x_v_f64m8_m(vbool8_t, vfloat64m8_t, vint32m4_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vfwcvt_f_xu_v)))
vfloat64m1_t vfwcvt_f_xu_v_f64m1(vuint32mf2_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vfwcvt_f_xu_v_m)))
vfloat64m1_t vfwcvt_f_xu_v_f64m1_m(vbool64_t, vfloat64m1_t, vuint32mf2_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vfwcvt_f_xu_v)))
vfloat64m2_t vfwcvt_f_xu_v_f64m2(vuint32m1_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vfwcvt_f_xu_v_m)))
vfloat64m2_t vfwcvt_f_xu_v_f64m2_m(vbool32_t, vfloat64m2_t, vuint32m1_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vfwcvt_f_xu_v)))
vfloat64m4_t vfwcvt_f_xu_v_f64m4(vuint32m2_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vfwcvt_f_xu_v_m)))
vfloat64m4_t vfwcvt_f_xu_v_f64m4_m(vbool16_t, vfloat64m4_t, vuint32m2_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vfwcvt_f_xu_v)))
vfloat64m8_t vfwcvt_f_xu_v_f64m8(vuint32m4_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vfwcvt_f_xu_v_m)))
vfloat64m8_t vfwcvt_f_xu_v_f64m8_m(vbool8_t, vfloat64m8_t, vuint32m4_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vlmul_ext_v)))
vfloat64m2_t vlmul_ext_v_f64m1_f64m2(vfloat64m1_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vlmul_ext_v)))
vfloat64m4_t vlmul_ext_v_f64m1_f64m4(vfloat64m1_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vlmul_ext_v)))
vfloat64m4_t vlmul_ext_v_f64m2_f64m4(vfloat64m2_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vlmul_ext_v)))
vfloat64m8_t vlmul_ext_v_f64m1_f64m8(vfloat64m1_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vlmul_ext_v)))
vfloat64m8_t vlmul_ext_v_f64m2_f64m8(vfloat64m2_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vlmul_ext_v)))
vfloat64m8_t vlmul_ext_v_f64m4_f64m8(vfloat64m4_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vlmul_trunc_v)))
vfloat64m1_t vlmul_trunc_v_f64m2_f64m1(vfloat64m2_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vlmul_trunc_v)))
vfloat64m1_t vlmul_trunc_v_f64m4_f64m1(vfloat64m4_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vlmul_trunc_v)))
vfloat64m1_t vlmul_trunc_v_f64m8_f64m1(vfloat64m8_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vlmul_trunc_v)))
vfloat64m2_t vlmul_trunc_v_f64m4_f64m2(vfloat64m4_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vlmul_trunc_v)))
vfloat64m2_t vlmul_trunc_v_f64m8_f64m2(vfloat64m8_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vlmul_trunc_v)))
vfloat64m4_t vlmul_trunc_v_f64m8_f64m4(vfloat64m8_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vreinterpret_v)))
vfloat64m1_t vreinterpret_v_i64m1_f64m1(vint64m1_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vreinterpret_v)))
vfloat64m2_t vreinterpret_v_i64m2_f64m2(vint64m2_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vreinterpret_v)))
vfloat64m4_t vreinterpret_v_i64m4_f64m4(vint64m4_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vreinterpret_v)))
vfloat64m8_t vreinterpret_v_i64m8_f64m8(vint64m8_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vreinterpret_v)))
vfloat64m1_t vreinterpret_v_u64m1_f64m1(vuint64m1_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vreinterpret_v)))
vfloat64m2_t vreinterpret_v_u64m2_f64m2(vuint64m2_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vreinterpret_v)))
vfloat64m4_t vreinterpret_v_u64m4_f64m4(vuint64m4_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vreinterpret_v)))
vfloat64m8_t vreinterpret_v_u64m8_f64m8(vuint64m8_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vreinterpret_v)))
vint64m1_t vreinterpret_v_f64m1_i64m1(vfloat64m1_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vreinterpret_v)))
vint64m2_t vreinterpret_v_f64m2_i64m2(vfloat64m2_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vreinterpret_v)))
vint64m4_t vreinterpret_v_f64m4_i64m4(vfloat64m4_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vreinterpret_v)))
vint64m8_t vreinterpret_v_f64m8_i64m8(vfloat64m8_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vreinterpret_v)))
vuint64m1_t vreinterpret_v_f64m1_u64m1(vfloat64m1_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vreinterpret_v)))
vuint64m2_t vreinterpret_v_f64m2_u64m2(vfloat64m2_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vreinterpret_v)))
vuint64m4_t vreinterpret_v_f64m4_u64m4(vfloat64m4_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vreinterpret_v)))
vuint64m8_t vreinterpret_v_f64m8_u64m8(vfloat64m8_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vundefined)))
vfloat64m1_t vundefined_f64m1();
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vundefined)))
vfloat64m2_t vundefined_f64m2();
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vundefined)))
vfloat64m4_t vundefined_f64m4();
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vundefined)))
vfloat64m8_t vundefined_f64m8();
#endif

#if (__riscv_xlen == 64) && (__riscv_v_elen >= 64) && (__riscv_v_elen_fp >= 64)
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vluxei64_v)))
vfloat64m1_t vluxei64_v_f64m1(const double *, vuint64m1_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vluxei64_v_m)))
vfloat64m1_t vluxei64_v_f64m1_m(vbool64_t, vfloat64m1_t, const double *, vuint64m1_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vluxei64_v)))
vfloat64m2_t vluxei64_v_f64m2(const double *, vuint64m2_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vluxei64_v_m)))
vfloat64m2_t vluxei64_v_f64m2_m(vbool32_t, vfloat64m2_t, const double *, vuint64m2_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vluxei64_v)))
vfloat64m4_t vluxei64_v_f64m4(const double *, vuint64m4_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vluxei64_v_m)))
vfloat64m4_t vluxei64_v_f64m4_m(vbool16_t, vfloat64m4_t, const double *, vuint64m4_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vluxei64_v)))
vfloat64m8_t vluxei64_v_f64m8(const double *, vuint64m8_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vluxei64_v_m)))
vfloat64m8_t vluxei64_v_f64m8_m(vbool8_t, vfloat64m8_t, const double *, vuint64m8_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vloxei64_v)))
vfloat64m1_t vloxei64_v_f64m1(const double *, vuint64m1_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vloxei64_v_m)))
vfloat64m1_t vloxei64_v_f64m1_m(vbool64_t, vfloat64m1_t, const double *, vuint64m1_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vloxei64_v)))
vfloat64m2_t vloxei64_v_f64m2(const double *, vuint64m2_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vloxei64_v_m)))
vfloat64m2_t vloxei64_v_f64m2_m(vbool32_t, vfloat64m2_t, const double *, vuint64m2_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vloxei64_v)))
vfloat64m4_t vloxei64_v_f64m4(const double *, vuint64m4_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vloxei64_v_m)))
vfloat64m4_t vloxei64_v_f64m4_m(vbool16_t, vfloat64m4_t, const double *, vuint64m4_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vloxei64_v)))
vfloat64m8_t vloxei64_v_f64m8(const double *, vuint64m8_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vloxei64_v_m)))
vfloat64m8_t vloxei64_v_f64m8_m(vbool8_t, vfloat64m8_t, const double *, vuint64m8_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vsuxei64_v)))
void vsuxei64_v_f64m1(double *, vuint64m1_t, vfloat64m1_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vsuxei64_v_m)))
void vsuxei64_v_f64m1_m(vbool64_t, double *, vuint64m1_t, vfloat64m1_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vsuxei64_v)))
void vsuxei64_v_f64m2(double *, vuint64m2_t, vfloat64m2_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vsuxei64_v_m)))
void vsuxei64_v_f64m2_m(vbool32_t, double *, vuint64m2_t, vfloat64m2_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vsuxei64_v)))
void vsuxei64_v_f64m4(double *, vuint64m4_t, vfloat64m4_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vsuxei64_v_m)))
void vsuxei64_v_f64m4_m(vbool16_t, double *, vuint64m4_t, vfloat64m4_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vsuxei64_v)))
void vsuxei64_v_f64m8(double *, vuint64m8_t, vfloat64m8_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vsuxei64_v_m)))
void vsuxei64_v_f64m8_m(vbool8_t, double *, vuint64m8_t, vfloat64m8_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vsoxei64_v)))
void vsoxei64_v_f64m1(double *, vuint64m1_t, vfloat64m1_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vsoxei64_v_m)))
void vsoxei64_v_f64m1_m(vbool64_t, double *, vuint64m1_t, vfloat64m1_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vsoxei64_v)))
void vsoxei64_v_f64m2(double *, vuint64m2_t, vfloat64m2_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vsoxei64_v_m)))
void vsoxei64_v_f64m2_m(vbool32_t, double *, vuint64m2_t, vfloat64m2_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vsoxei64_v)))
void vsoxei64_v_f64m4(double *, vuint64m4_t, vfloat64m4_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vsoxei64_v_m)))
void vsoxei64_v_f64m4_m(vbool16_t, double *, vuint64m4_t, vfloat64m4_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vsoxei64_v)))
void vsoxei64_v_f64m8(double *, vuint64m8_t, vfloat64m8_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vsoxei64_v_m)))
void vsoxei64_v_f64m8_m(vbool8_t, double *, vuint64m8_t, vfloat64m8_t, size_t);
#endif

#if (__riscv_v_elen >= 64) && (__riscv_v_elen_fp >= 32) && (__riscv_v_elen_fp >= 64)
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vfwadd_vv)))
vfloat64m1_t vfwadd_vv_f64m1(vfloat32mf2_t, vfloat32mf2_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vfwadd_vv_m)))
vfloat64m1_t vfwadd_vv_f64m1_m(vbool64_t, vfloat64m1_t, vfloat32mf2_t, vfloat32mf2_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vfwadd_vv)))
vfloat64m2_t vfwadd_vv_f64m2(vfloat32m1_t, vfloat32m1_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vfwadd_vv_m)))
vfloat64m2_t vfwadd_vv_f64m2_m(vbool32_t, vfloat64m2_t, vfloat32m1_t, vfloat32m1_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vfwadd_vv)))
vfloat64m4_t vfwadd_vv_f64m4(vfloat32m2_t, vfloat32m2_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vfwadd_vv_m)))
vfloat64m4_t vfwadd_vv_f64m4_m(vbool16_t, vfloat64m4_t, vfloat32m2_t, vfloat32m2_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vfwadd_vv)))
vfloat64m8_t vfwadd_vv_f64m8(vfloat32m4_t, vfloat32m4_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vfwadd_vv_m)))
vfloat64m8_t vfwadd_vv_f64m8_m(vbool8_t, vfloat64m8_t, vfloat32m4_t, vfloat32m4_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vfwadd_vf)))
vfloat64m1_t vfwadd_vf_f64m1(vfloat32mf2_t, float, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vfwadd_vf_m)))
vfloat64m1_t vfwadd_vf_f64m1_m(vbool64_t, vfloat64m1_t, vfloat32mf2_t, float, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vfwadd_vf)))
vfloat64m2_t vfwadd_vf_f64m2(vfloat32m1_t, float, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vfwadd_vf_m)))
vfloat64m2_t vfwadd_vf_f64m2_m(vbool32_t, vfloat64m2_t, vfloat32m1_t, float, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vfwadd_vf)))
vfloat64m4_t vfwadd_vf_f64m4(vfloat32m2_t, float, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vfwadd_vf_m)))
vfloat64m4_t vfwadd_vf_f64m4_m(vbool16_t, vfloat64m4_t, vfloat32m2_t, float, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vfwadd_vf)))
vfloat64m8_t vfwadd_vf_f64m8(vfloat32m4_t, float, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vfwadd_vf_m)))
vfloat64m8_t vfwadd_vf_f64m8_m(vbool8_t, vfloat64m8_t, vfloat32m4_t, float, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vfwsub_vv)))
vfloat64m1_t vfwsub_vv_f64m1(vfloat32mf2_t, vfloat32mf2_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vfwsub_vv_m)))
vfloat64m1_t vfwsub_vv_f64m1_m(vbool64_t, vfloat64m1_t, vfloat32mf2_t, vfloat32mf2_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vfwsub_vv)))
vfloat64m2_t vfwsub_vv_f64m2(vfloat32m1_t, vfloat32m1_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vfwsub_vv_m)))
vfloat64m2_t vfwsub_vv_f64m2_m(vbool32_t, vfloat64m2_t, vfloat32m1_t, vfloat32m1_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vfwsub_vv)))
vfloat64m4_t vfwsub_vv_f64m4(vfloat32m2_t, vfloat32m2_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vfwsub_vv_m)))
vfloat64m4_t vfwsub_vv_f64m4_m(vbool16_t, vfloat64m4_t, vfloat32m2_t, vfloat32m2_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vfwsub_vv)))
vfloat64m8_t vfwsub_vv_f64m8(vfloat32m4_t, vfloat32m4_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vfwsub_vv_m)))
vfloat64m8_t vfwsub_vv_f64m8_m(vbool8_t, vfloat64m8_t, vfloat32m4_t, vfloat32m4_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vfwsub_vf)))
vfloat64m1_t vfwsub_vf_f64m1(vfloat32mf2_t, float, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vfwsub_vf_m)))
vfloat64m1_t vfwsub_vf_f64m1_m(vbool64_t, vfloat64m1_t, vfloat32mf2_t, float, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vfwsub_vf)))
vfloat64m2_t vfwsub_vf_f64m2(vfloat32m1_t, float, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vfwsub_vf_m)))
vfloat64m2_t vfwsub_vf_f64m2_m(vbool32_t, vfloat64m2_t, vfloat32m1_t, float, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vfwsub_vf)))
vfloat64m4_t vfwsub_vf_f64m4(vfloat32m2_t, float, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vfwsub_vf_m)))
vfloat64m4_t vfwsub_vf_f64m4_m(vbool16_t, vfloat64m4_t, vfloat32m2_t, float, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vfwsub_vf)))
vfloat64m8_t vfwsub_vf_f64m8(vfloat32m4_t, float, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vfwsub_vf_m)))
vfloat64m8_t vfwsub_vf_f64m8_m(vbool8_t, vfloat64m8_t, vfloat32m4_t, float, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vfwadd_wv)))
vfloat64m1_t vfwadd_wv_f64m1(vfloat64m1_t, vfloat32mf2_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vfwadd_wv_m)))
vfloat64m1_t vfwadd_wv_f64m1_m(vbool64_t, vfloat64m1_t, vfloat64m1_t, vfloat32mf2_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vfwadd_wv)))
vfloat64m2_t vfwadd_wv_f64m2(vfloat64m2_t, vfloat32m1_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vfwadd_wv_m)))
vfloat64m2_t vfwadd_wv_f64m2_m(vbool32_t, vfloat64m2_t, vfloat64m2_t, vfloat32m1_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vfwadd_wv)))
vfloat64m4_t vfwadd_wv_f64m4(vfloat64m4_t, vfloat32m2_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vfwadd_wv_m)))
vfloat64m4_t vfwadd_wv_f64m4_m(vbool16_t, vfloat64m4_t, vfloat64m4_t, vfloat32m2_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vfwadd_wv)))
vfloat64m8_t vfwadd_wv_f64m8(vfloat64m8_t, vfloat32m4_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vfwadd_wv_m)))
vfloat64m8_t vfwadd_wv_f64m8_m(vbool8_t, vfloat64m8_t, vfloat64m8_t, vfloat32m4_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vfwsub_wv)))
vfloat64m1_t vfwsub_wv_f64m1(vfloat64m1_t, vfloat32mf2_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vfwsub_wv_m)))
vfloat64m1_t vfwsub_wv_f64m1_m(vbool64_t, vfloat64m1_t, vfloat64m1_t, vfloat32mf2_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vfwsub_wv)))
vfloat64m2_t vfwsub_wv_f64m2(vfloat64m2_t, vfloat32m1_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vfwsub_wv_m)))
vfloat64m2_t vfwsub_wv_f64m2_m(vbool32_t, vfloat64m2_t, vfloat64m2_t, vfloat32m1_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vfwsub_wv)))
vfloat64m4_t vfwsub_wv_f64m4(vfloat64m4_t, vfloat32m2_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vfwsub_wv_m)))
vfloat64m4_t vfwsub_wv_f64m4_m(vbool16_t, vfloat64m4_t, vfloat64m4_t, vfloat32m2_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vfwsub_wv)))
vfloat64m8_t vfwsub_wv_f64m8(vfloat64m8_t, vfloat32m4_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vfwsub_wv_m)))
vfloat64m8_t vfwsub_wv_f64m8_m(vbool8_t, vfloat64m8_t, vfloat64m8_t, vfloat32m4_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vfwmul_vv)))
vfloat64m1_t vfwmul_vv_f64m1(vfloat32mf2_t, vfloat32mf2_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vfwmul_vv_m)))
vfloat64m1_t vfwmul_vv_f64m1_m(vbool64_t, vfloat64m1_t, vfloat32mf2_t, vfloat32mf2_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vfwmul_vv)))
vfloat64m2_t vfwmul_vv_f64m2(vfloat32m1_t, vfloat32m1_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vfwmul_vv_m)))
vfloat64m2_t vfwmul_vv_f64m2_m(vbool32_t, vfloat64m2_t, vfloat32m1_t, vfloat32m1_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vfwmul_vv)))
vfloat64m4_t vfwmul_vv_f64m4(vfloat32m2_t, vfloat32m2_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vfwmul_vv_m)))
vfloat64m4_t vfwmul_vv_f64m4_m(vbool16_t, vfloat64m4_t, vfloat32m2_t, vfloat32m2_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vfwmul_vv)))
vfloat64m8_t vfwmul_vv_f64m8(vfloat32m4_t, vfloat32m4_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vfwmul_vv_m)))
vfloat64m8_t vfwmul_vv_f64m8_m(vbool8_t, vfloat64m8_t, vfloat32m4_t, vfloat32m4_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vfwmul_vf)))
vfloat64m1_t vfwmul_vf_f64m1(vfloat32mf2_t, float, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vfwmul_vf_m)))
vfloat64m1_t vfwmul_vf_f64m1_m(vbool64_t, vfloat64m1_t, vfloat32mf2_t, float, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vfwmul_vf)))
vfloat64m2_t vfwmul_vf_f64m2(vfloat32m1_t, float, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vfwmul_vf_m)))
vfloat64m2_t vfwmul_vf_f64m2_m(vbool32_t, vfloat64m2_t, vfloat32m1_t, float, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vfwmul_vf)))
vfloat64m4_t vfwmul_vf_f64m4(vfloat32m2_t, float, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vfwmul_vf_m)))
vfloat64m4_t vfwmul_vf_f64m4_m(vbool16_t, vfloat64m4_t, vfloat32m2_t, float, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vfwmul_vf)))
vfloat64m8_t vfwmul_vf_f64m8(vfloat32m4_t, float, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vfwmul_vf_m)))
vfloat64m8_t vfwmul_vf_f64m8_m(vbool8_t, vfloat64m8_t, vfloat32m4_t, float, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vfwmacc_vv)))
vfloat64m1_t vfwmacc_vv_f64m1(vfloat64m1_t, vfloat32mf2_t, vfloat32mf2_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vfwmacc_vv_m)))
vfloat64m1_t vfwmacc_vv_f64m1_m(vbool64_t, vfloat64m1_t, vfloat32mf2_t, vfloat32mf2_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vfwmacc_vv)))
vfloat64m2_t vfwmacc_vv_f64m2(vfloat64m2_t, vfloat32m1_t, vfloat32m1_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vfwmacc_vv_m)))
vfloat64m2_t vfwmacc_vv_f64m2_m(vbool32_t, vfloat64m2_t, vfloat32m1_t, vfloat32m1_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vfwmacc_vv)))
vfloat64m4_t vfwmacc_vv_f64m4(vfloat64m4_t, vfloat32m2_t, vfloat32m2_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vfwmacc_vv_m)))
vfloat64m4_t vfwmacc_vv_f64m4_m(vbool16_t, vfloat64m4_t, vfloat32m2_t, vfloat32m2_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vfwmacc_vv)))
vfloat64m8_t vfwmacc_vv_f64m8(vfloat64m8_t, vfloat32m4_t, vfloat32m4_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vfwmacc_vv_m)))
vfloat64m8_t vfwmacc_vv_f64m8_m(vbool8_t, vfloat64m8_t, vfloat32m4_t, vfloat32m4_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vfwmacc_vf)))
vfloat64m1_t vfwmacc_vf_f64m1(vfloat64m1_t, float, vfloat32mf2_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vfwmacc_vf_m)))
vfloat64m1_t vfwmacc_vf_f64m1_m(vbool64_t, vfloat64m1_t, float, vfloat32mf2_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vfwmacc_vf)))
vfloat64m2_t vfwmacc_vf_f64m2(vfloat64m2_t, float, vfloat32m1_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vfwmacc_vf_m)))
vfloat64m2_t vfwmacc_vf_f64m2_m(vbool32_t, vfloat64m2_t, float, vfloat32m1_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vfwmacc_vf)))
vfloat64m4_t vfwmacc_vf_f64m4(vfloat64m4_t, float, vfloat32m2_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vfwmacc_vf_m)))
vfloat64m4_t vfwmacc_vf_f64m4_m(vbool16_t, vfloat64m4_t, float, vfloat32m2_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vfwmacc_vf)))
vfloat64m8_t vfwmacc_vf_f64m8(vfloat64m8_t, float, vfloat32m4_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vfwmacc_vf_m)))
vfloat64m8_t vfwmacc_vf_f64m8_m(vbool8_t, vfloat64m8_t, float, vfloat32m4_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vfwnmacc_vv)))
vfloat64m1_t vfwnmacc_vv_f64m1(vfloat64m1_t, vfloat32mf2_t, vfloat32mf2_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vfwnmacc_vv_m)))
vfloat64m1_t vfwnmacc_vv_f64m1_m(vbool64_t, vfloat64m1_t, vfloat32mf2_t, vfloat32mf2_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vfwnmacc_vv)))
vfloat64m2_t vfwnmacc_vv_f64m2(vfloat64m2_t, vfloat32m1_t, vfloat32m1_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vfwnmacc_vv_m)))
vfloat64m2_t vfwnmacc_vv_f64m2_m(vbool32_t, vfloat64m2_t, vfloat32m1_t, vfloat32m1_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vfwnmacc_vv)))
vfloat64m4_t vfwnmacc_vv_f64m4(vfloat64m4_t, vfloat32m2_t, vfloat32m2_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vfwnmacc_vv_m)))
vfloat64m4_t vfwnmacc_vv_f64m4_m(vbool16_t, vfloat64m4_t, vfloat32m2_t, vfloat32m2_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vfwnmacc_vv)))
vfloat64m8_t vfwnmacc_vv_f64m8(vfloat64m8_t, vfloat32m4_t, vfloat32m4_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vfwnmacc_vv_m)))
vfloat64m8_t vfwnmacc_vv_f64m8_m(vbool8_t, vfloat64m8_t, vfloat32m4_t, vfloat32m4_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vfwnmacc_vf)))
vfloat64m1_t vfwnmacc_vf_f64m1(vfloat64m1_t, float, vfloat32mf2_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vfwnmacc_vf_m)))
vfloat64m1_t vfwnmacc_vf_f64m1_m(vbool64_t, vfloat64m1_t, float, vfloat32mf2_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vfwnmacc_vf)))
vfloat64m2_t vfwnmacc_vf_f64m2(vfloat64m2_t, float, vfloat32m1_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vfwnmacc_vf_m)))
vfloat64m2_t vfwnmacc_vf_f64m2_m(vbool32_t, vfloat64m2_t, float, vfloat32m1_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vfwnmacc_vf)))
vfloat64m4_t vfwnmacc_vf_f64m4(vfloat64m4_t, float, vfloat32m2_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vfwnmacc_vf_m)))
vfloat64m4_t vfwnmacc_vf_f64m4_m(vbool16_t, vfloat64m4_t, float, vfloat32m2_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vfwnmacc_vf)))
vfloat64m8_t vfwnmacc_vf_f64m8(vfloat64m8_t, float, vfloat32m4_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vfwnmacc_vf_m)))
vfloat64m8_t vfwnmacc_vf_f64m8_m(vbool8_t, vfloat64m8_t, float, vfloat32m4_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vfwmsac_vv)))
vfloat64m1_t vfwmsac_vv_f64m1(vfloat64m1_t, vfloat32mf2_t, vfloat32mf2_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vfwmsac_vv_m)))
vfloat64m1_t vfwmsac_vv_f64m1_m(vbool64_t, vfloat64m1_t, vfloat32mf2_t, vfloat32mf2_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vfwmsac_vv)))
vfloat64m2_t vfwmsac_vv_f64m2(vfloat64m2_t, vfloat32m1_t, vfloat32m1_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vfwmsac_vv_m)))
vfloat64m2_t vfwmsac_vv_f64m2_m(vbool32_t, vfloat64m2_t, vfloat32m1_t, vfloat32m1_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vfwmsac_vv)))
vfloat64m4_t vfwmsac_vv_f64m4(vfloat64m4_t, vfloat32m2_t, vfloat32m2_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vfwmsac_vv_m)))
vfloat64m4_t vfwmsac_vv_f64m4_m(vbool16_t, vfloat64m4_t, vfloat32m2_t, vfloat32m2_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vfwmsac_vv)))
vfloat64m8_t vfwmsac_vv_f64m8(vfloat64m8_t, vfloat32m4_t, vfloat32m4_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vfwmsac_vv_m)))
vfloat64m8_t vfwmsac_vv_f64m8_m(vbool8_t, vfloat64m8_t, vfloat32m4_t, vfloat32m4_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vfwmsac_vf)))
vfloat64m1_t vfwmsac_vf_f64m1(vfloat64m1_t, float, vfloat32mf2_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vfwmsac_vf_m)))
vfloat64m1_t vfwmsac_vf_f64m1_m(vbool64_t, vfloat64m1_t, float, vfloat32mf2_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vfwmsac_vf)))
vfloat64m2_t vfwmsac_vf_f64m2(vfloat64m2_t, float, vfloat32m1_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vfwmsac_vf_m)))
vfloat64m2_t vfwmsac_vf_f64m2_m(vbool32_t, vfloat64m2_t, float, vfloat32m1_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vfwmsac_vf)))
vfloat64m4_t vfwmsac_vf_f64m4(vfloat64m4_t, float, vfloat32m2_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vfwmsac_vf_m)))
vfloat64m4_t vfwmsac_vf_f64m4_m(vbool16_t, vfloat64m4_t, float, vfloat32m2_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vfwmsac_vf)))
vfloat64m8_t vfwmsac_vf_f64m8(vfloat64m8_t, float, vfloat32m4_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vfwmsac_vf_m)))
vfloat64m8_t vfwmsac_vf_f64m8_m(vbool8_t, vfloat64m8_t, float, vfloat32m4_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vfwnmsac_vv)))
vfloat64m1_t vfwnmsac_vv_f64m1(vfloat64m1_t, vfloat32mf2_t, vfloat32mf2_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vfwnmsac_vv_m)))
vfloat64m1_t vfwnmsac_vv_f64m1_m(vbool64_t, vfloat64m1_t, vfloat32mf2_t, vfloat32mf2_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vfwnmsac_vv)))
vfloat64m2_t vfwnmsac_vv_f64m2(vfloat64m2_t, vfloat32m1_t, vfloat32m1_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vfwnmsac_vv_m)))
vfloat64m2_t vfwnmsac_vv_f64m2_m(vbool32_t, vfloat64m2_t, vfloat32m1_t, vfloat32m1_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vfwnmsac_vv)))
vfloat64m4_t vfwnmsac_vv_f64m4(vfloat64m4_t, vfloat32m2_t, vfloat32m2_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vfwnmsac_vv_m)))
vfloat64m4_t vfwnmsac_vv_f64m4_m(vbool16_t, vfloat64m4_t, vfloat32m2_t, vfloat32m2_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vfwnmsac_vv)))
vfloat64m8_t vfwnmsac_vv_f64m8(vfloat64m8_t, vfloat32m4_t, vfloat32m4_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vfwnmsac_vv_m)))
vfloat64m8_t vfwnmsac_vv_f64m8_m(vbool8_t, vfloat64m8_t, vfloat32m4_t, vfloat32m4_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vfwnmsac_vf)))
vfloat64m1_t vfwnmsac_vf_f64m1(vfloat64m1_t, float, vfloat32mf2_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vfwnmsac_vf_m)))
vfloat64m1_t vfwnmsac_vf_f64m1_m(vbool64_t, vfloat64m1_t, float, vfloat32mf2_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vfwnmsac_vf)))
vfloat64m2_t vfwnmsac_vf_f64m2(vfloat64m2_t, float, vfloat32m1_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vfwnmsac_vf_m)))
vfloat64m2_t vfwnmsac_vf_f64m2_m(vbool32_t, vfloat64m2_t, float, vfloat32m1_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vfwnmsac_vf)))
vfloat64m4_t vfwnmsac_vf_f64m4(vfloat64m4_t, float, vfloat32m2_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vfwnmsac_vf_m)))
vfloat64m4_t vfwnmsac_vf_f64m4_m(vbool16_t, vfloat64m4_t, float, vfloat32m2_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vfwnmsac_vf)))
vfloat64m8_t vfwnmsac_vf_f64m8(vfloat64m8_t, float, vfloat32m4_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vfwnmsac_vf_m)))
vfloat64m8_t vfwnmsac_vf_f64m8_m(vbool8_t, vfloat64m8_t, float, vfloat32m4_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vfwredusum_vs)))
vfloat64m1_t vfwredusum_vs_f32m1_f64m1(vfloat64m1_t, vfloat32m1_t, vfloat64m1_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vfwredusum_vs_m)))
vfloat64m1_t vfwredusum_vs_f32m1_f64m1_m(vbool32_t, vfloat64m1_t, vfloat32m1_t, vfloat64m1_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vfwredusum_vs)))
vfloat64m1_t vfwredusum_vs_f32m2_f64m1(vfloat64m1_t, vfloat32m2_t, vfloat64m1_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vfwredusum_vs_m)))
vfloat64m1_t vfwredusum_vs_f32m2_f64m1_m(vbool16_t, vfloat64m1_t, vfloat32m2_t, vfloat64m1_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vfwredusum_vs)))
vfloat64m1_t vfwredusum_vs_f32m4_f64m1(vfloat64m1_t, vfloat32m4_t, vfloat64m1_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vfwredusum_vs_m)))
vfloat64m1_t vfwredusum_vs_f32m4_f64m1_m(vbool8_t, vfloat64m1_t, vfloat32m4_t, vfloat64m1_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vfwredusum_vs)))
vfloat64m1_t vfwredusum_vs_f32m8_f64m1(vfloat64m1_t, vfloat32m8_t, vfloat64m1_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vfwredusum_vs_m)))
vfloat64m1_t vfwredusum_vs_f32m8_f64m1_m(vbool4_t, vfloat64m1_t, vfloat32m8_t, vfloat64m1_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vfwredusum_vs)))
vfloat64m1_t vfwredusum_vs_f32mf2_f64m1(vfloat64m1_t, vfloat32mf2_t, vfloat64m1_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vfwredusum_vs_m)))
vfloat64m1_t vfwredusum_vs_f32mf2_f64m1_m(vbool64_t, vfloat64m1_t, vfloat32mf2_t, vfloat64m1_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vfwredosum_vs)))
vfloat64m1_t vfwredosum_vs_f32m1_f64m1(vfloat64m1_t, vfloat32m1_t, vfloat64m1_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vfwredosum_vs_m)))
vfloat64m1_t vfwredosum_vs_f32m1_f64m1_m(vbool32_t, vfloat64m1_t, vfloat32m1_t, vfloat64m1_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vfwredosum_vs)))
vfloat64m1_t vfwredosum_vs_f32m2_f64m1(vfloat64m1_t, vfloat32m2_t, vfloat64m1_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vfwredosum_vs_m)))
vfloat64m1_t vfwredosum_vs_f32m2_f64m1_m(vbool16_t, vfloat64m1_t, vfloat32m2_t, vfloat64m1_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vfwredosum_vs)))
vfloat64m1_t vfwredosum_vs_f32m4_f64m1(vfloat64m1_t, vfloat32m4_t, vfloat64m1_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vfwredosum_vs_m)))
vfloat64m1_t vfwredosum_vs_f32m4_f64m1_m(vbool8_t, vfloat64m1_t, vfloat32m4_t, vfloat64m1_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vfwredosum_vs)))
vfloat64m1_t vfwredosum_vs_f32m8_f64m1(vfloat64m1_t, vfloat32m8_t, vfloat64m1_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vfwredosum_vs_m)))
vfloat64m1_t vfwredosum_vs_f32m8_f64m1_m(vbool4_t, vfloat64m1_t, vfloat32m8_t, vfloat64m1_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vfwredosum_vs)))
vfloat64m1_t vfwredosum_vs_f32mf2_f64m1(vfloat64m1_t, vfloat32mf2_t, vfloat64m1_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vfwredosum_vs_m)))
vfloat64m1_t vfwredosum_vs_f32mf2_f64m1_m(vbool64_t, vfloat64m1_t, vfloat32mf2_t, vfloat64m1_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vfncvt_f_f_w)))
vfloat32mf2_t vfncvt_f_f_w_f32mf2(vfloat64m1_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vfncvt_f_f_w_m)))
vfloat32mf2_t vfncvt_f_f_w_f32mf2_m(vbool64_t, vfloat32mf2_t, vfloat64m1_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vfncvt_f_f_w)))
vfloat32m1_t vfncvt_f_f_w_f32m1(vfloat64m2_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vfncvt_f_f_w_m)))
vfloat32m1_t vfncvt_f_f_w_f32m1_m(vbool32_t, vfloat32m1_t, vfloat64m2_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vfncvt_f_f_w)))
vfloat32m2_t vfncvt_f_f_w_f32m2(vfloat64m4_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vfncvt_f_f_w_m)))
vfloat32m2_t vfncvt_f_f_w_f32m2_m(vbool16_t, vfloat32m2_t, vfloat64m4_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vfncvt_f_f_w)))
vfloat32m4_t vfncvt_f_f_w_f32m4(vfloat64m8_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vfncvt_f_f_w_m)))
vfloat32m4_t vfncvt_f_f_w_f32m4_m(vbool8_t, vfloat32m4_t, vfloat64m8_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vfncvt_rod_f_f_w)))
vfloat32mf2_t vfncvt_rod_f_f_w_f32mf2(vfloat64m1_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vfncvt_rod_f_f_w_m)))
vfloat32mf2_t vfncvt_rod_f_f_w_f32mf2_m(vbool64_t, vfloat32mf2_t, vfloat64m1_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vfncvt_rod_f_f_w)))
vfloat32m1_t vfncvt_rod_f_f_w_f32m1(vfloat64m2_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vfncvt_rod_f_f_w_m)))
vfloat32m1_t vfncvt_rod_f_f_w_f32m1_m(vbool32_t, vfloat32m1_t, vfloat64m2_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vfncvt_rod_f_f_w)))
vfloat32m2_t vfncvt_rod_f_f_w_f32m2(vfloat64m4_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vfncvt_rod_f_f_w_m)))
vfloat32m2_t vfncvt_rod_f_f_w_f32m2_m(vbool16_t, vfloat32m2_t, vfloat64m4_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vfncvt_rod_f_f_w)))
vfloat32m4_t vfncvt_rod_f_f_w_f32m4(vfloat64m8_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vfncvt_rod_f_f_w_m)))
vfloat32m4_t vfncvt_rod_f_f_w_f32m4_m(vbool8_t, vfloat32m4_t, vfloat64m8_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vfwcvt_f_f_v)))
vfloat64m1_t vfwcvt_f_f_v_f64m1(vfloat32mf2_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vfwcvt_f_f_v_m)))
vfloat64m1_t vfwcvt_f_f_v_f64m1_m(vbool64_t, vfloat64m1_t, vfloat32mf2_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vfwcvt_f_f_v)))
vfloat64m2_t vfwcvt_f_f_v_f64m2(vfloat32m1_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vfwcvt_f_f_v_m)))
vfloat64m2_t vfwcvt_f_f_v_f64m2_m(vbool32_t, vfloat64m2_t, vfloat32m1_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vfwcvt_f_f_v)))
vfloat64m4_t vfwcvt_f_f_v_f64m4(vfloat32m2_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vfwcvt_f_f_v_m)))
vfloat64m4_t vfwcvt_f_f_v_f64m4_m(vbool16_t, vfloat64m4_t, vfloat32m2_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vfwcvt_f_f_v)))
vfloat64m8_t vfwcvt_f_f_v_f64m8(vfloat32m4_t, size_t);
__rvv_ai __attribute__((__clang_builtin_alias__(__builtin_rvv_vfwcvt_f_f_v_m)))
vfloat64m8_t vfwcvt_f_f_v_f64m8_m(vbool8_t, vfloat64m8_t, vfloat32m4_t, size_t);
#endif

#undef __rvv_ai

#define __riscv_v_intrinsic_overloading 1
#define __rvv_aio static __inline__ __attribute__((__overloadable__))
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vadd_vv)))
vint8m1_t vadd(vint8m1_t, vint8m1_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vadd_vv_m)))
vint8m1_t vadd(vbool8_t, vint8m1_t, vint8m1_t, vint8m1_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vadd_vv)))
vint8m2_t vadd(vint8m2_t, vint8m2_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vadd_vv_m)))
vint8m2_t vadd(vbool4_t, vint8m2_t, vint8m2_t, vint8m2_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vadd_vv)))
vint8m4_t vadd(vint8m4_t, vint8m4_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vadd_vv_m)))
vint8m4_t vadd(vbool2_t, vint8m4_t, vint8m4_t, vint8m4_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vadd_vv)))
vint8m8_t vadd(vint8m8_t, vint8m8_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vadd_vv_m)))
vint8m8_t vadd(vbool1_t, vint8m8_t, vint8m8_t, vint8m8_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vadd_vv)))
vint8mf2_t vadd(vint8mf2_t, vint8mf2_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vadd_vv_m)))
vint8mf2_t vadd(vbool16_t, vint8mf2_t, vint8mf2_t, vint8mf2_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vadd_vv)))
vint8mf4_t vadd(vint8mf4_t, vint8mf4_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vadd_vv_m)))
vint8mf4_t vadd(vbool32_t, vint8mf4_t, vint8mf4_t, vint8mf4_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vadd_vv)))
vint8mf8_t vadd(vint8mf8_t, vint8mf8_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vadd_vv_m)))
vint8mf8_t vadd(vbool64_t, vint8mf8_t, vint8mf8_t, vint8mf8_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vadd_vv)))
vint16m1_t vadd(vint16m1_t, vint16m1_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vadd_vv_m)))
vint16m1_t vadd(vbool16_t, vint16m1_t, vint16m1_t, vint16m1_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vadd_vv)))
vint16m2_t vadd(vint16m2_t, vint16m2_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vadd_vv_m)))
vint16m2_t vadd(vbool8_t, vint16m2_t, vint16m2_t, vint16m2_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vadd_vv)))
vint16m4_t vadd(vint16m4_t, vint16m4_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vadd_vv_m)))
vint16m4_t vadd(vbool4_t, vint16m4_t, vint16m4_t, vint16m4_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vadd_vv)))
vint16m8_t vadd(vint16m8_t, vint16m8_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vadd_vv_m)))
vint16m8_t vadd(vbool2_t, vint16m8_t, vint16m8_t, vint16m8_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vadd_vv)))
vint16mf2_t vadd(vint16mf2_t, vint16mf2_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vadd_vv_m)))
vint16mf2_t vadd(vbool32_t, vint16mf2_t, vint16mf2_t, vint16mf2_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vadd_vv)))
vint16mf4_t vadd(vint16mf4_t, vint16mf4_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vadd_vv_m)))
vint16mf4_t vadd(vbool64_t, vint16mf4_t, vint16mf4_t, vint16mf4_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vadd_vv)))
vint32m1_t vadd(vint32m1_t, vint32m1_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vadd_vv_m)))
vint32m1_t vadd(vbool32_t, vint32m1_t, vint32m1_t, vint32m1_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vadd_vv)))
vint32m2_t vadd(vint32m2_t, vint32m2_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vadd_vv_m)))
vint32m2_t vadd(vbool16_t, vint32m2_t, vint32m2_t, vint32m2_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vadd_vv)))
vint32m4_t vadd(vint32m4_t, vint32m4_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vadd_vv_m)))
vint32m4_t vadd(vbool8_t, vint32m4_t, vint32m4_t, vint32m4_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vadd_vv)))
vint32m8_t vadd(vint32m8_t, vint32m8_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vadd_vv_m)))
vint32m8_t vadd(vbool4_t, vint32m8_t, vint32m8_t, vint32m8_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vadd_vv)))
vint32mf2_t vadd(vint32mf2_t, vint32mf2_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vadd_vv_m)))
vint32mf2_t vadd(vbool64_t, vint32mf2_t, vint32mf2_t, vint32mf2_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vwaddu_vv)))
vuint16mf4_t vwaddu_vv(vuint8mf8_t, vuint8mf8_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vwaddu_vv_m)))
vuint16mf4_t vwaddu_vv(vbool64_t, vuint16mf4_t, vuint8mf8_t, vuint8mf8_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vwaddu_vv)))
vuint16mf2_t vwaddu_vv(vuint8mf4_t, vuint8mf4_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vwaddu_vv_m)))
vuint16mf2_t vwaddu_vv(vbool32_t, vuint16mf2_t, vuint8mf4_t, vuint8mf4_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vwaddu_vv)))
vuint16m1_t vwaddu_vv(vuint8mf2_t, vuint8mf2_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vwaddu_vv_m)))
vuint16m1_t vwaddu_vv(vbool16_t, vuint16m1_t, vuint8mf2_t, vuint8mf2_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vwaddu_vv)))
vuint16m2_t vwaddu_vv(vuint8m1_t, vuint8m1_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vwaddu_vv_m)))
vuint16m2_t vwaddu_vv(vbool8_t, vuint16m2_t, vuint8m1_t, vuint8m1_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vwaddu_vv)))
vuint16m4_t vwaddu_vv(vuint8m2_t, vuint8m2_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vwaddu_vv_m)))
vuint16m4_t vwaddu_vv(vbool4_t, vuint16m4_t, vuint8m2_t, vuint8m2_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vwaddu_vv)))
vuint16m8_t vwaddu_vv(vuint8m4_t, vuint8m4_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vwaddu_vv_m)))
vuint16m8_t vwaddu_vv(vbool2_t, vuint16m8_t, vuint8m4_t, vuint8m4_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vwaddu_vv)))
vuint32mf2_t vwaddu_vv(vuint16mf4_t, vuint16mf4_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vwaddu_vv_m)))
vuint32mf2_t vwaddu_vv(vbool64_t, vuint32mf2_t, vuint16mf4_t, vuint16mf4_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vwaddu_vv)))
vuint32m1_t vwaddu_vv(vuint16mf2_t, vuint16mf2_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vwaddu_vv_m)))
vuint32m1_t vwaddu_vv(vbool32_t, vuint32m1_t, vuint16mf2_t, vuint16mf2_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vwaddu_vv)))
vuint32m2_t vwaddu_vv(vuint16m1_t, vuint16m1_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vwaddu_vv_m)))
vuint32m2_t vwaddu_vv(vbool16_t, vuint32m2_t, vuint16m1_t, vuint16m1_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vwaddu_vv)))
vuint32m4_t vwaddu_vv(vuint16m2_t, vuint16m2_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vwaddu_vv_m)))
vuint32m4_t vwaddu_vv(vbool8_t, vuint32m4_t, vuint16m2_t, vuint16m2_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vwaddu_vv)))
vuint32m8_t vwaddu_vv(vuint16m4_t, vuint16m4_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vwaddu_vv_m)))
vuint32m8_t vwaddu_vv(vbool4_t, vuint32m8_t, vuint16m4_t, vuint16m4_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vluxei8_v)))
vuint8m1_t vluxei8(const uint8_t *, vuint8m1_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vluxei8_v_m)))
vuint8m1_t vluxei8(vbool8_t, vuint8m1_t, const uint8_t *, vuint8m1_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vluxei8_v)))
vuint8m2_t vluxei8(const uint8_t *, vuint8m2_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vluxei8_v_m)))
vuint8m2_t vluxei8(vbool4_t, vuint8m2_t, const uint8_t *, vuint8m2_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vluxei8_v)))
vuint8m4_t vluxei8(const uint8_t *, vuint8m4_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vluxei8_v_m)))
vuint8m4_t vluxei8(vbool2_t, vuint8m4_t, const uint8_t *, vuint8m4_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vluxei8_v)))
vuint8m8_t vluxei8(const uint8_t *, vuint8m8_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vluxei8_v_m)))
vuint8m8_t vluxei8(vbool1_t, vuint8m8_t, const uint8_t *, vuint8m8_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vluxei8_v)))
vuint8mf2_t vluxei8(const uint8_t *, vuint8mf2_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vluxei8_v_m)))
vuint8mf2_t vluxei8(vbool16_t, vuint8mf2_t, const uint8_t *, vuint8mf2_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vluxei8_v)))
vuint8mf4_t vluxei8(const uint8_t *, vuint8mf4_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vluxei8_v_m)))
vuint8mf4_t vluxei8(vbool32_t, vuint8mf4_t, const uint8_t *, vuint8mf4_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vluxei8_v)))
vuint8mf8_t vluxei8(const uint8_t *, vuint8mf8_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vluxei8_v_m)))
vuint8mf8_t vluxei8(vbool64_t, vuint8mf8_t, const uint8_t *, vuint8mf8_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vsse16_v)))
void vsse16(int16_t *, ptrdiff_t, vint16m1_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vsse16_v_m)))
void vsse16(vbool16_t, int16_t *, ptrdiff_t, vint16m1_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vsse16_v)))
void vsse16(int16_t *, ptrdiff_t, vint16m2_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vsse16_v_m)))
void vsse16(vbool8_t, int16_t *, ptrdiff_t, vint16m2_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vsse16_v)))
void vsse16(int16_t *, ptrdiff_t, vint16m4_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vsse16_v_m)))
void vsse16(vbool4_t, int16_t *, ptrdiff_t, vint16m4_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vsse16_v)))
void vsse16(int16_t *, ptrdiff_t, vint16m8_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vsse16_v_m)))
void vsse16(vbool2_t, int16_t *, ptrdiff_t, vint16m8_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vsse16_v)))
void vsse16(int16_t *, ptrdiff_t, vint16mf2_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vsse16_v_m)))
void vsse16(vbool32_t, int16_t *, ptrdiff_t, vint16mf2_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vsse16_v)))
void vsse16(int16_t *, ptrdiff_t, vint16mf4_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vsse16_v_m)))
void vsse16(vbool64_t, int16_t *, ptrdiff_t, vint16mf4_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vsse16_v)))
void vsse16(uint16_t *, ptrdiff_t, vuint16m1_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vsse16_v_m)))
void vsse16(vbool16_t, uint16_t *, ptrdiff_t, vuint16m1_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vsse16_v)))
void vsse16(uint16_t *, ptrdiff_t, vuint16m2_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vsse16_v_m)))
void vsse16(vbool8_t, uint16_t *, ptrdiff_t, vuint16m2_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vsse16_v)))
void vsse16(uint16_t *, ptrdiff_t, vuint16m4_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vsse16_v_m)))
void vsse16(vbool4_t, uint16_t *, ptrdiff_t, vuint16m4_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vsse16_v)))
void vsse16(uint16_t *, ptrdiff_t, vuint16m8_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vsse16_v_m)))
void vsse16(vbool2_t, uint16_t *, ptrdiff_t, vuint16m8_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vsse16_v)))
void vsse16(uint16_t *, ptrdiff_t, vuint16mf2_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vsse16_v_m)))
void vsse16(vbool32_t, uint16_t *, ptrdiff_t, vuint16mf2_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vsse16_v)))
void vsse16(uint16_t *, ptrdiff_t, vuint16mf4_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vsse16_v_m)))
void vsse16(vbool64_t, uint16_t *, ptrdiff_t, vuint16mf4_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vsse32_v)))
void vsse32(int32_t *, ptrdiff_t, vint32m1_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vsse32_v_m)))
void vsse32(vbool32_t, int32_t *, ptrdiff_t, vint32m1_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vsse32_v)))
void vsse32(int32_t *, ptrdiff_t, vint32m2_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vsse32_v_m)))
void vsse32(vbool16_t, int32_t *, ptrdiff_t, vint32m2_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vsse32_v)))
void vsse32(int32_t *, ptrdiff_t, vint32m4_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vsse32_v_m)))
void vsse32(vbool8_t, int32_t *, ptrdiff_t, vint32m4_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vsse32_v)))
void vsse32(int32_t *, ptrdiff_t, vint32m8_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vsse32_v_m)))
void vsse32(vbool4_t, int32_t *, ptrdiff_t, vint32m8_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vsse32_v)))
void vsse32(int32_t *, ptrdiff_t, vint32mf2_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vsse32_v_m)))
void vsse32(vbool64_t, int32_t *, ptrdiff_t, vint32mf2_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vsse32_v)))
void vsse32(uint32_t *, ptrdiff_t, vuint32m1_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vsse32_v_m)))
void vsse32(vbool32_t, uint32_t *, ptrdiff_t, vuint32m1_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vsse32_v)))
void vsse32(uint32_t *, ptrdiff_t, vuint32m2_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vsse32_v_m)))
void vsse32(vbool16_t, uint32_t *, ptrdiff_t, vuint32m2_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vsse32_v)))
void vsse32(uint32_t *, ptrdiff_t, vuint32m4_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vsse32_v_m)))
void vsse32(vbool8_t, uint32_t *, ptrdiff_t, vuint32m4_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vsse32_v)))
void vsse32(uint32_t *, ptrdiff_t, vuint32m8_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vsse32_v_m)))
void vsse32(vbool4_t, uint32_t *, ptrdiff_t, vuint32m8_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vsse32_v)))
void vsse32(uint32_t *, ptrdiff_t, vuint32mf2_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vsse32_v_m)))
void vsse32(vbool64_t, uint32_t *, ptrdiff_t, vuint32mf2_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vsseg3e8_v)))
void vsseg3e8(int8_t *, vint8m1_t, vint8m1_t, vint8m1_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vsseg3e8_v_m)))
void vsseg3e8(vbool8_t, int8_t *, vint8m1_t, vint8m1_t, vint8m1_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vsseg3e8_v)))
void vsseg3e8(int8_t *, vint8m2_t, vint8m2_t, vint8m2_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vsseg3e8_v_m)))
void vsseg3e8(vbool4_t, int8_t *, vint8m2_t, vint8m2_t, vint8m2_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vsseg3e8_v)))
void vsseg3e8(int8_t *, vint8mf2_t, vint8mf2_t, vint8mf2_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vsseg3e8_v_m)))
void vsseg3e8(vbool16_t, int8_t *, vint8mf2_t, vint8mf2_t, vint8mf2_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vsseg3e8_v)))
void vsseg3e8(int8_t *, vint8mf4_t, vint8mf4_t, vint8mf4_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vsseg3e8_v_m)))
void vsseg3e8(vbool32_t, int8_t *, vint8mf4_t, vint8mf4_t, vint8mf4_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vsseg3e8_v)))
void vsseg3e8(int8_t *, vint8mf8_t, vint8mf8_t, vint8mf8_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vsseg3e8_v_m)))
void vsseg3e8(vbool64_t, int8_t *, vint8mf8_t, vint8mf8_t, vint8mf8_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vluxei16_v)))
vint8m1_t vluxei16(const int8_t *, vuint16m2_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vluxei16_v_m)))
vint8m1_t vluxei16(vbool8_t, vint8m1_t, const int8_t *, vuint16m2_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vluxei16_v)))
vint8m2_t vluxei16(const int8_t *, vuint16m4_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vluxei16_v_m)))
vint8m2_t vluxei16(vbool4_t, vint8m2_t, const int8_t *, vuint16m4_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vluxei16_v)))
vint8m4_t vluxei16(const int8_t *, vuint16m8_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vluxei16_v_m)))
vint8m4_t vluxei16(vbool2_t, vint8m4_t, const int8_t *, vuint16m8_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vluxei16_v)))
vint8mf2_t vluxei16(const int8_t *, vuint16m1_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vluxei16_v_m)))
vint8mf2_t vluxei16(vbool16_t, vint8mf2_t, const int8_t *, vuint16m1_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vluxei16_v)))
vint8mf4_t vluxei16(const int8_t *, vuint16mf2_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vluxei16_v_m)))
vint8mf4_t vluxei16(vbool32_t, vint8mf4_t, const int8_t *, vuint16mf2_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vluxei16_v)))
vint8mf8_t vluxei16(const int8_t *, vuint16mf4_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vluxei16_v_m)))
vint8mf8_t vluxei16(vbool64_t, vint8mf8_t, const int8_t *, vuint16mf4_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vsseg3e8_v)))
void vsseg3e8(uint8_t *, vuint8m1_t, vuint8m1_t, vuint8m1_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vsseg3e8_v_m)))
void vsseg3e8(vbool8_t, uint8_t *, vuint8m1_t, vuint8m1_t, vuint8m1_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vsseg3e8_v)))
void vsseg3e8(uint8_t *, vuint8m2_t, vuint8m2_t, vuint8m2_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vsseg3e8_v_m)))
void vsseg3e8(vbool4_t, uint8_t *, vuint8m2_t, vuint8m2_t, vuint8m2_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vsseg3e8_v)))
void vsseg3e8(uint8_t *, vuint8mf2_t, vuint8mf2_t, vuint8mf2_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vsseg3e8_v_m)))
void vsseg3e8(vbool16_t, uint8_t *, vuint8mf2_t, vuint8mf2_t, vuint8mf2_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vsseg3e8_v)))
void vsseg3e8(uint8_t *, vuint8mf4_t, vuint8mf4_t, vuint8mf4_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vsseg3e8_v_m)))
void vsseg3e8(vbool32_t, uint8_t *, vuint8mf4_t, vuint8mf4_t, vuint8mf4_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vsseg3e8_v)))
void vsseg3e8(uint8_t *, vuint8mf8_t, vuint8mf8_t, vuint8mf8_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vsseg3e8_v_m)))
void vsseg3e8(vbool64_t, uint8_t *, vuint8mf8_t, vuint8mf8_t, vuint8mf8_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vsseg4e8_v)))
void vsseg4e8(int8_t *, vint8m1_t, vint8m1_t, vint8m1_t, vint8m1_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vsseg4e8_v_m)))
void vsseg4e8(vbool8_t, int8_t *, vint8m1_t, vint8m1_t, vint8m1_t, vint8m1_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vsseg4e8_v)))
void vsseg4e8(int8_t *, vint8m2_t, vint8m2_t, vint8m2_t, vint8m2_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vsseg4e8_v_m)))
void vsseg4e8(vbool4_t, int8_t *, vint8m2_t, vint8m2_t, vint8m2_t, vint8m2_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vsseg4e8_v)))
void vsseg4e8(int8_t *, vint8mf2_t, vint8mf2_t, vint8mf2_t, vint8mf2_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vsseg4e8_v_m)))
void vsseg4e8(vbool16_t, int8_t *, vint8mf2_t, vint8mf2_t, vint8mf2_t, vint8mf2_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vsseg4e8_v)))
void vsseg4e8(int8_t *, vint8mf4_t, vint8mf4_t, vint8mf4_t, vint8mf4_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vsseg4e8_v_m)))
void vsseg4e8(vbool32_t, int8_t *, vint8mf4_t, vint8mf4_t, vint8mf4_t, vint8mf4_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vsseg4e8_v)))
void vsseg4e8(int8_t *, vint8mf8_t, vint8mf8_t, vint8mf8_t, vint8mf8_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vsseg4e8_v_m)))
void vsseg4e8(vbool64_t, int8_t *, vint8mf8_t, vint8mf8_t, vint8mf8_t, vint8mf8_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vsseg4e8_v)))
void vsseg4e8(uint8_t *, vuint8m1_t, vuint8m1_t, vuint8m1_t, vuint8m1_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vsseg4e8_v_m)))
void vsseg4e8(vbool8_t, uint8_t *, vuint8m1_t, vuint8m1_t, vuint8m1_t, vuint8m1_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vsseg4e8_v)))
void vsseg4e8(uint8_t *, vuint8m2_t, vuint8m2_t, vuint8m2_t, vuint8m2_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vsseg4e8_v_m)))
void vsseg4e8(vbool4_t, uint8_t *, vuint8m2_t, vuint8m2_t, vuint8m2_t, vuint8m2_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vsseg4e8_v)))
void vsseg4e8(uint8_t *, vuint8mf2_t, vuint8mf2_t, vuint8mf2_t, vuint8mf2_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vsseg4e8_v_m)))
void vsseg4e8(vbool16_t, uint8_t *, vuint8mf2_t, vuint8mf2_t, vuint8mf2_t, vuint8mf2_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vsseg4e8_v)))
void vsseg4e8(uint8_t *, vuint8mf4_t, vuint8mf4_t, vuint8mf4_t, vuint8mf4_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vsseg4e8_v_m)))
void vsseg4e8(vbool32_t, uint8_t *, vuint8mf4_t, vuint8mf4_t, vuint8mf4_t, vuint8mf4_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vsseg4e8_v)))
void vsseg4e8(uint8_t *, vuint8mf8_t, vuint8mf8_t, vuint8mf8_t, vuint8mf8_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vsseg4e8_v_m)))
void vsseg4e8(vbool64_t, uint8_t *, vuint8mf8_t, vuint8mf8_t, vuint8mf8_t, vuint8mf8_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vsseg5e8_v)))
void vsseg5e8(int8_t *, vint8m1_t, vint8m1_t, vint8m1_t, vint8m1_t, vint8m1_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vsseg5e8_v_m)))
void vsseg5e8(vbool8_t, int8_t *, vint8m1_t, vint8m1_t, vint8m1_t, vint8m1_t, vint8m1_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vsseg5e8_v)))
void vsseg5e8(int8_t *, vint8mf2_t, vint8mf2_t, vint8mf2_t, vint8mf2_t, vint8mf2_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vsseg5e8_v_m)))
void vsseg5e8(vbool16_t, int8_t *, vint8mf2_t, vint8mf2_t, vint8mf2_t, vint8mf2_t, vint8mf2_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vsseg5e8_v)))
void vsseg5e8(int8_t *, vint8mf4_t, vint8mf4_t, vint8mf4_t, vint8mf4_t, vint8mf4_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vsseg5e8_v_m)))
void vsseg5e8(vbool32_t, int8_t *, vint8mf4_t, vint8mf4_t, vint8mf4_t, vint8mf4_t, vint8mf4_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vsseg5e8_v)))
void vsseg5e8(int8_t *, vint8mf8_t, vint8mf8_t, vint8mf8_t, vint8mf8_t, vint8mf8_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vsseg5e8_v_m)))
void vsseg5e8(vbool64_t, int8_t *, vint8mf8_t, vint8mf8_t, vint8mf8_t, vint8mf8_t, vint8mf8_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vsseg5e8_v)))
void vsseg5e8(uint8_t *, vuint8m1_t, vuint8m1_t, vuint8m1_t, vuint8m1_t, vuint8m1_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vsseg5e8_v_m)))
void vsseg5e8(vbool8_t, uint8_t *, vuint8m1_t, vuint8m1_t, vuint8m1_t, vuint8m1_t, vuint8m1_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vsseg5e8_v)))
void vsseg5e8(uint8_t *, vuint8mf2_t, vuint8mf2_t, vuint8mf2_t, vuint8mf2_t, vuint8mf2_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vsseg5e8_v_m)))
void vsseg5e8(vbool16_t, uint8_t *, vuint8mf2_t, vuint8mf2_t, vuint8mf2_t, vuint8mf2_t, vuint8mf2_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vsseg5e8_v)))
void vsseg5e8(uint8_t *, vuint8mf4_t, vuint8mf4_t, vuint8mf4_t, vuint8mf4_t, vuint8mf4_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vsseg5e8_v_m)))
void vsseg5e8(vbool32_t, uint8_t *, vuint8mf4_t, vuint8mf4_t, vuint8mf4_t, vuint8mf4_t, vuint8mf4_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vsseg5e8_v)))
void vsseg5e8(uint8_t *, vuint8mf8_t, vuint8mf8_t, vuint8mf8_t, vuint8mf8_t, vuint8mf8_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vsseg5e8_v_m)))
void vsseg5e8(vbool64_t, uint8_t *, vuint8mf8_t, vuint8mf8_t, vuint8mf8_t, vuint8mf8_t, vuint8mf8_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vsseg6e8_v)))
void vsseg6e8(int8_t *, vint8m1_t, vint8m1_t, vint8m1_t, vint8m1_t, vint8m1_t, vint8m1_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vsseg6e8_v_m)))
void vsseg6e8(vbool8_t, int8_t *, vint8m1_t, vint8m1_t, vint8m1_t, vint8m1_t, vint8m1_t, vint8m1_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vsseg6e8_v)))
void vsseg6e8(int8_t *, vint8mf2_t, vint8mf2_t, vint8mf2_t, vint8mf2_t, vint8mf2_t, vint8mf2_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vsseg6e8_v_m)))
void vsseg6e8(vbool16_t, int8_t *, vint8mf2_t, vint8mf2_t, vint8mf2_t, vint8mf2_t, vint8mf2_t, vint8mf2_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vsseg6e8_v)))
void vsseg6e8(int8_t *, vint8mf4_t, vint8mf4_t, vint8mf4_t, vint8mf4_t, vint8mf4_t, vint8mf4_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vsseg6e8_v_m)))
void vsseg6e8(vbool32_t, int8_t *, vint8mf4_t, vint8mf4_t, vint8mf4_t, vint8mf4_t, vint8mf4_t, vint8mf4_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vsseg6e8_v)))
void vsseg6e8(int8_t *, vint8mf8_t, vint8mf8_t, vint8mf8_t, vint8mf8_t, vint8mf8_t, vint8mf8_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vsseg6e8_v_m)))
void vsseg6e8(vbool64_t, int8_t *, vint8mf8_t, vint8mf8_t, vint8mf8_t, vint8mf8_t, vint8mf8_t, vint8mf8_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vsseg6e8_v)))
void vsseg6e8(uint8_t *, vuint8m1_t, vuint8m1_t, vuint8m1_t, vuint8m1_t, vuint8m1_t, vuint8m1_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vsseg6e8_v_m)))
void vsseg6e8(vbool8_t, uint8_t *, vuint8m1_t, vuint8m1_t, vuint8m1_t, vuint8m1_t, vuint8m1_t, vuint8m1_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vsseg6e8_v)))
void vsseg6e8(uint8_t *, vuint8mf2_t, vuint8mf2_t, vuint8mf2_t, vuint8mf2_t, vuint8mf2_t, vuint8mf2_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vsseg6e8_v_m)))
void vsseg6e8(vbool16_t, uint8_t *, vuint8mf2_t, vuint8mf2_t, vuint8mf2_t, vuint8mf2_t, vuint8mf2_t, vuint8mf2_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vsseg6e8_v)))
void vsseg6e8(uint8_t *, vuint8mf4_t, vuint8mf4_t, vuint8mf4_t, vuint8mf4_t, vuint8mf4_t, vuint8mf4_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vsseg6e8_v_m)))
void vsseg6e8(vbool32_t, uint8_t *, vuint8mf4_t, vuint8mf4_t, vuint8mf4_t, vuint8mf4_t, vuint8mf4_t, vuint8mf4_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vsseg6e8_v)))
void vsseg6e8(uint8_t *, vuint8mf8_t, vuint8mf8_t, vuint8mf8_t, vuint8mf8_t, vuint8mf8_t, vuint8mf8_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vsseg6e8_v_m)))
void vsseg6e8(vbool64_t, uint8_t *, vuint8mf8_t, vuint8mf8_t, vuint8mf8_t, vuint8mf8_t, vuint8mf8_t, vuint8mf8_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vsseg7e8_v)))
void vsseg7e8(int8_t *, vint8m1_t, vint8m1_t, vint8m1_t, vint8m1_t, vint8m1_t, vint8m1_t, vint8m1_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vsseg7e8_v_m)))
void vsseg7e8(vbool8_t, int8_t *, vint8m1_t, vint8m1_t, vint8m1_t, vint8m1_t, vint8m1_t, vint8m1_t, vint8m1_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vsseg7e8_v)))
void vsseg7e8(int8_t *, vint8mf2_t, vint8mf2_t, vint8mf2_t, vint8mf2_t, vint8mf2_t, vint8mf2_t, vint8mf2_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vsseg7e8_v_m)))
void vsseg7e8(vbool16_t, int8_t *, vint8mf2_t, vint8mf2_t, vint8mf2_t, vint8mf2_t, vint8mf2_t, vint8mf2_t, vint8mf2_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vsseg7e8_v)))
void vsseg7e8(int8_t *, vint8mf4_t, vint8mf4_t, vint8mf4_t, vint8mf4_t, vint8mf4_t, vint8mf4_t, vint8mf4_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vsseg7e8_v_m)))
void vsseg7e8(vbool32_t, int8_t *, vint8mf4_t, vint8mf4_t, vint8mf4_t, vint8mf4_t, vint8mf4_t, vint8mf4_t, vint8mf4_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vsseg7e8_v)))
void vsseg7e8(int8_t *, vint8mf8_t, vint8mf8_t, vint8mf8_t, vint8mf8_t, vint8mf8_t, vint8mf8_t, vint8mf8_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vsseg7e8_v_m)))
void vsseg7e8(vbool64_t, int8_t *, vint8mf8_t, vint8mf8_t, vint8mf8_t, vint8mf8_t, vint8mf8_t, vint8mf8_t, vint8mf8_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vsseg7e8_v)))
void vsseg7e8(uint8_t *, vuint8m1_t, vuint8m1_t, vuint8m1_t, vuint8m1_t, vuint8m1_t, vuint8m1_t, vuint8m1_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vsseg7e8_v_m)))
void vsseg7e8(vbool8_t, uint8_t *, vuint8m1_t, vuint8m1_t, vuint8m1_t, vuint8m1_t, vuint8m1_t, vuint8m1_t, vuint8m1_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vsseg7e8_v)))
void vsseg7e8(uint8_t *, vuint8mf2_t, vuint8mf2_t, vuint8mf2_t, vuint8mf2_t, vuint8mf2_t, vuint8mf2_t, vuint8mf2_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vsseg7e8_v_m)))
void vsseg7e8(vbool16_t, uint8_t *, vuint8mf2_t, vuint8mf2_t, vuint8mf2_t, vuint8mf2_t, vuint8mf2_t, vuint8mf2_t, vuint8mf2_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vsseg7e8_v)))
void vsseg7e8(uint8_t *, vuint8mf4_t, vuint8mf4_t, vuint8mf4_t, vuint8mf4_t, vuint8mf4_t, vuint8mf4_t, vuint8mf4_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vsseg7e8_v_m)))
void vsseg7e8(vbool32_t, uint8_t *, vuint8mf4_t, vuint8mf4_t, vuint8mf4_t, vuint8mf4_t, vuint8mf4_t, vuint8mf4_t, vuint8mf4_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vsseg7e8_v)))
void vsseg7e8(uint8_t *, vuint8mf8_t, vuint8mf8_t, vuint8mf8_t, vuint8mf8_t, vuint8mf8_t, vuint8mf8_t, vuint8mf8_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vsseg7e8_v_m)))
void vsseg7e8(vbool64_t, uint8_t *, vuint8mf8_t, vuint8mf8_t, vuint8mf8_t, vuint8mf8_t, vuint8mf8_t, vuint8mf8_t, vuint8mf8_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vsseg8e8_v)))
void vsseg8e8(int8_t *, vint8m1_t, vint8m1_t, vint8m1_t, vint8m1_t, vint8m1_t, vint8m1_t, vint8m1_t, vint8m1_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vsseg8e8_v_m)))
void vsseg8e8(vbool8_t, int8_t *, vint8m1_t, vint8m1_t, vint8m1_t, vint8m1_t, vint8m1_t, vint8m1_t, vint8m1_t, vint8m1_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vsseg8e8_v)))
void vsseg8e8(int8_t *, vint8mf2_t, vint8mf2_t, vint8mf2_t, vint8mf2_t, vint8mf2_t, vint8mf2_t, vint8mf2_t, vint8mf2_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vsseg8e8_v_m)))
void vsseg8e8(vbool16_t, int8_t *, vint8mf2_t, vint8mf2_t, vint8mf2_t, vint8mf2_t, vint8mf2_t, vint8mf2_t, vint8mf2_t, vint8mf2_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vsseg8e8_v)))
void vsseg8e8(int8_t *, vint8mf4_t, vint8mf4_t, vint8mf4_t, vint8mf4_t, vint8mf4_t, vint8mf4_t, vint8mf4_t, vint8mf4_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vsseg8e8_v_m)))
void vsseg8e8(vbool32_t, int8_t *, vint8mf4_t, vint8mf4_t, vint8mf4_t, vint8mf4_t, vint8mf4_t, vint8mf4_t, vint8mf4_t, vint8mf4_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vsseg8e8_v)))
void vsseg8e8(int8_t *, vint8mf8_t, vint8mf8_t, vint8mf8_t, vint8mf8_t, vint8mf8_t, vint8mf8_t, vint8mf8_t, vint8mf8_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vsseg8e8_v_m)))
void vsseg8e8(vbool64_t, int8_t *, vint8mf8_t, vint8mf8_t, vint8mf8_t, vint8mf8_t, vint8mf8_t, vint8mf8_t, vint8mf8_t, vint8mf8_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vluxei16_v)))
vuint8m1_t vluxei16(const uint8_t *, vuint16m2_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vluxei16_v_m)))
vuint8m1_t vluxei16(vbool8_t, vuint8m1_t, const uint8_t *, vuint16m2_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vluxei16_v)))
vuint8m2_t vluxei16(const uint8_t *, vuint16m4_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vluxei16_v_m)))
vuint8m2_t vluxei16(vbool4_t, vuint8m2_t, const uint8_t *, vuint16m4_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vluxei16_v)))
vuint8m4_t vluxei16(const uint8_t *, vuint16m8_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vluxei16_v_m)))
vuint8m4_t vluxei16(vbool2_t, vuint8m4_t, const uint8_t *, vuint16m8_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vluxei16_v)))
vuint8mf2_t vluxei16(const uint8_t *, vuint16m1_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vluxei16_v_m)))
vuint8mf2_t vluxei16(vbool16_t, vuint8mf2_t, const uint8_t *, vuint16m1_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vluxei16_v)))
vuint8mf4_t vluxei16(const uint8_t *, vuint16mf2_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vluxei16_v_m)))
vuint8mf4_t vluxei16(vbool32_t, vuint8mf4_t, const uint8_t *, vuint16mf2_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vluxei16_v)))
vuint8mf8_t vluxei16(const uint8_t *, vuint16mf4_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vluxei16_v_m)))
vuint8mf8_t vluxei16(vbool64_t, vuint8mf8_t, const uint8_t *, vuint16mf4_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vsseg8e8_v)))
void vsseg8e8(uint8_t *, vuint8m1_t, vuint8m1_t, vuint8m1_t, vuint8m1_t, vuint8m1_t, vuint8m1_t, vuint8m1_t, vuint8m1_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vsseg8e8_v_m)))
void vsseg8e8(vbool8_t, uint8_t *, vuint8m1_t, vuint8m1_t, vuint8m1_t, vuint8m1_t, vuint8m1_t, vuint8m1_t, vuint8m1_t, vuint8m1_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vsseg8e8_v)))
void vsseg8e8(uint8_t *, vuint8mf2_t, vuint8mf2_t, vuint8mf2_t, vuint8mf2_t, vuint8mf2_t, vuint8mf2_t, vuint8mf2_t, vuint8mf2_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vsseg8e8_v_m)))
void vsseg8e8(vbool16_t, uint8_t *, vuint8mf2_t, vuint8mf2_t, vuint8mf2_t, vuint8mf2_t, vuint8mf2_t, vuint8mf2_t, vuint8mf2_t, vuint8mf2_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vsseg8e8_v)))
void vsseg8e8(uint8_t *, vuint8mf4_t, vuint8mf4_t, vuint8mf4_t, vuint8mf4_t, vuint8mf4_t, vuint8mf4_t, vuint8mf4_t, vuint8mf4_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vsseg8e8_v_m)))
void vsseg8e8(vbool32_t, uint8_t *, vuint8mf4_t, vuint8mf4_t, vuint8mf4_t, vuint8mf4_t, vuint8mf4_t, vuint8mf4_t, vuint8mf4_t, vuint8mf4_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vsseg8e8_v)))
void vsseg8e8(uint8_t *, vuint8mf8_t, vuint8mf8_t, vuint8mf8_t, vuint8mf8_t, vuint8mf8_t, vuint8mf8_t, vuint8mf8_t, vuint8mf8_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vsseg8e8_v_m)))
void vsseg8e8(vbool64_t, uint8_t *, vuint8mf8_t, vuint8mf8_t, vuint8mf8_t, vuint8mf8_t, vuint8mf8_t, vuint8mf8_t, vuint8mf8_t, vuint8mf8_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vsseg2e16_v)))
void vsseg2e16(int16_t *, vint16m1_t, vint16m1_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vsseg2e16_v_m)))
void vsseg2e16(vbool16_t, int16_t *, vint16m1_t, vint16m1_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vsseg2e16_v)))
void vsseg2e16(int16_t *, vint16m2_t, vint16m2_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vsseg2e16_v_m)))
void vsseg2e16(vbool8_t, int16_t *, vint16m2_t, vint16m2_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vsseg2e16_v)))
void vsseg2e16(int16_t *, vint16m4_t, vint16m4_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vsseg2e16_v_m)))
void vsseg2e16(vbool4_t, int16_t *, vint16m4_t, vint16m4_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vsseg2e16_v)))
void vsseg2e16(int16_t *, vint16mf2_t, vint16mf2_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vsseg2e16_v_m)))
void vsseg2e16(vbool32_t, int16_t *, vint16mf2_t, vint16mf2_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vsseg2e16_v)))
void vsseg2e16(int16_t *, vint16mf4_t, vint16mf4_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vsseg2e16_v_m)))
void vsseg2e16(vbool64_t, int16_t *, vint16mf4_t, vint16mf4_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vsseg2e16_v)))
void vsseg2e16(uint16_t *, vuint16m1_t, vuint16m1_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vsseg2e16_v_m)))
void vsseg2e16(vbool16_t, uint16_t *, vuint16m1_t, vuint16m1_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vsseg2e16_v)))
void vsseg2e16(uint16_t *, vuint16m2_t, vuint16m2_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vsseg2e16_v_m)))
void vsseg2e16(vbool8_t, uint16_t *, vuint16m2_t, vuint16m2_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vsseg2e16_v)))
void vsseg2e16(uint16_t *, vuint16m4_t, vuint16m4_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vsseg2e16_v_m)))
void vsseg2e16(vbool4_t, uint16_t *, vuint16m4_t, vuint16m4_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vsseg2e16_v)))
void vsseg2e16(uint16_t *, vuint16mf2_t, vuint16mf2_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vsseg2e16_v_m)))
void vsseg2e16(vbool32_t, uint16_t *, vuint16mf2_t, vuint16mf2_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vsseg2e16_v)))
void vsseg2e16(uint16_t *, vuint16mf4_t, vuint16mf4_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vsseg2e16_v_m)))
void vsseg2e16(vbool64_t, uint16_t *, vuint16mf4_t, vuint16mf4_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vsseg3e16_v)))
void vsseg3e16(int16_t *, vint16m1_t, vint16m1_t, vint16m1_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vsseg3e16_v_m)))
void vsseg3e16(vbool16_t, int16_t *, vint16m1_t, vint16m1_t, vint16m1_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vsseg3e16_v)))
void vsseg3e16(int16_t *, vint16m2_t, vint16m2_t, vint16m2_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vsseg3e16_v_m)))
void vsseg3e16(vbool8_t, int16_t *, vint16m2_t, vint16m2_t, vint16m2_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vsseg3e16_v)))
void vsseg3e16(int16_t *, vint16mf2_t, vint16mf2_t, vint16mf2_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vsseg3e16_v_m)))
void vsseg3e16(vbool32_t, int16_t *, vint16mf2_t, vint16mf2_t, vint16mf2_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vsseg3e16_v)))
void vsseg3e16(int16_t *, vint16mf4_t, vint16mf4_t, vint16mf4_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vsseg3e16_v_m)))
void vsseg3e16(vbool64_t, int16_t *, vint16mf4_t, vint16mf4_t, vint16mf4_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vsseg3e16_v)))
void vsseg3e16(uint16_t *, vuint16m1_t, vuint16m1_t, vuint16m1_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vsseg3e16_v_m)))
void vsseg3e16(vbool16_t, uint16_t *, vuint16m1_t, vuint16m1_t, vuint16m1_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vsseg3e16_v)))
void vsseg3e16(uint16_t *, vuint16m2_t, vuint16m2_t, vuint16m2_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vsseg3e16_v_m)))
void vsseg3e16(vbool8_t, uint16_t *, vuint16m2_t, vuint16m2_t, vuint16m2_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vsseg3e16_v)))
void vsseg3e16(uint16_t *, vuint16mf2_t, vuint16mf2_t, vuint16mf2_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vsseg3e16_v_m)))
void vsseg3e16(vbool32_t, uint16_t *, vuint16mf2_t, vuint16mf2_t, vuint16mf2_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vsseg3e16_v)))
void vsseg3e16(uint16_t *, vuint16mf4_t, vuint16mf4_t, vuint16mf4_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vsseg3e16_v_m)))
void vsseg3e16(vbool64_t, uint16_t *, vuint16mf4_t, vuint16mf4_t, vuint16mf4_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vsseg4e16_v)))
void vsseg4e16(int16_t *, vint16m1_t, vint16m1_t, vint16m1_t, vint16m1_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vsseg4e16_v_m)))
void vsseg4e16(vbool16_t, int16_t *, vint16m1_t, vint16m1_t, vint16m1_t, vint16m1_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vsseg4e16_v)))
void vsseg4e16(int16_t *, vint16m2_t, vint16m2_t, vint16m2_t, vint16m2_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vsseg4e16_v_m)))
void vsseg4e16(vbool8_t, int16_t *, vint16m2_t, vint16m2_t, vint16m2_t, vint16m2_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vsseg4e16_v)))
void vsseg4e16(int16_t *, vint16mf2_t, vint16mf2_t, vint16mf2_t, vint16mf2_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vsseg4e16_v_m)))
void vsseg4e16(vbool32_t, int16_t *, vint16mf2_t, vint16mf2_t, vint16mf2_t, vint16mf2_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vsseg4e16_v)))
void vsseg4e16(int16_t *, vint16mf4_t, vint16mf4_t, vint16mf4_t, vint16mf4_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vsseg4e16_v_m)))
void vsseg4e16(vbool64_t, int16_t *, vint16mf4_t, vint16mf4_t, vint16mf4_t, vint16mf4_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vsseg4e16_v)))
void vsseg4e16(uint16_t *, vuint16m1_t, vuint16m1_t, vuint16m1_t, vuint16m1_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vsseg4e16_v_m)))
void vsseg4e16(vbool16_t, uint16_t *, vuint16m1_t, vuint16m1_t, vuint16m1_t, vuint16m1_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vsseg4e16_v)))
void vsseg4e16(uint16_t *, vuint16m2_t, vuint16m2_t, vuint16m2_t, vuint16m2_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vsseg4e16_v_m)))
void vsseg4e16(vbool8_t, uint16_t *, vuint16m2_t, vuint16m2_t, vuint16m2_t, vuint16m2_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vsseg4e16_v)))
void vsseg4e16(uint16_t *, vuint16mf2_t, vuint16mf2_t, vuint16mf2_t, vuint16mf2_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vsseg4e16_v_m)))
void vsseg4e16(vbool32_t, uint16_t *, vuint16mf2_t, vuint16mf2_t, vuint16mf2_t, vuint16mf2_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vsseg4e16_v)))
void vsseg4e16(uint16_t *, vuint16mf4_t, vuint16mf4_t, vuint16mf4_t, vuint16mf4_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vsseg4e16_v_m)))
void vsseg4e16(vbool64_t, uint16_t *, vuint16mf4_t, vuint16mf4_t, vuint16mf4_t, vuint16mf4_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vsseg5e16_v)))
void vsseg5e16(int16_t *, vint16m1_t, vint16m1_t, vint16m1_t, vint16m1_t, vint16m1_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vsseg5e16_v_m)))
void vsseg5e16(vbool16_t, int16_t *, vint16m1_t, vint16m1_t, vint16m1_t, vint16m1_t, vint16m1_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vsseg5e16_v)))
void vsseg5e16(int16_t *, vint16mf2_t, vint16mf2_t, vint16mf2_t, vint16mf2_t, vint16mf2_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vsseg5e16_v_m)))
void vsseg5e16(vbool32_t, int16_t *, vint16mf2_t, vint16mf2_t, vint16mf2_t, vint16mf2_t, vint16mf2_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vsseg5e16_v)))
void vsseg5e16(int16_t *, vint16mf4_t, vint16mf4_t, vint16mf4_t, vint16mf4_t, vint16mf4_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vsseg5e16_v_m)))
void vsseg5e16(vbool64_t, int16_t *, vint16mf4_t, vint16mf4_t, vint16mf4_t, vint16mf4_t, vint16mf4_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vsseg5e16_v)))
void vsseg5e16(uint16_t *, vuint16m1_t, vuint16m1_t, vuint16m1_t, vuint16m1_t, vuint16m1_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vsseg5e16_v_m)))
void vsseg5e16(vbool16_t, uint16_t *, vuint16m1_t, vuint16m1_t, vuint16m1_t, vuint16m1_t, vuint16m1_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vsseg5e16_v)))
void vsseg5e16(uint16_t *, vuint16mf2_t, vuint16mf2_t, vuint16mf2_t, vuint16mf2_t, vuint16mf2_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vsseg5e16_v_m)))
void vsseg5e16(vbool32_t, uint16_t *, vuint16mf2_t, vuint16mf2_t, vuint16mf2_t, vuint16mf2_t, vuint16mf2_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vsseg5e16_v)))
void vsseg5e16(uint16_t *, vuint16mf4_t, vuint16mf4_t, vuint16mf4_t, vuint16mf4_t, vuint16mf4_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vsseg5e16_v_m)))
void vsseg5e16(vbool64_t, uint16_t *, vuint16mf4_t, vuint16mf4_t, vuint16mf4_t, vuint16mf4_t, vuint16mf4_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vsseg6e16_v)))
void vsseg6e16(int16_t *, vint16m1_t, vint16m1_t, vint16m1_t, vint16m1_t, vint16m1_t, vint16m1_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vsseg6e16_v_m)))
void vsseg6e16(vbool16_t, int16_t *, vint16m1_t, vint16m1_t, vint16m1_t, vint16m1_t, vint16m1_t, vint16m1_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vsseg6e16_v)))
void vsseg6e16(int16_t *, vint16mf2_t, vint16mf2_t, vint16mf2_t, vint16mf2_t, vint16mf2_t, vint16mf2_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vsseg6e16_v_m)))
void vsseg6e16(vbool32_t, int16_t *, vint16mf2_t, vint16mf2_t, vint16mf2_t, vint16mf2_t, vint16mf2_t, vint16mf2_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vsseg6e16_v)))
void vsseg6e16(int16_t *, vint16mf4_t, vint16mf4_t, vint16mf4_t, vint16mf4_t, vint16mf4_t, vint16mf4_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vsseg6e16_v_m)))
void vsseg6e16(vbool64_t, int16_t *, vint16mf4_t, vint16mf4_t, vint16mf4_t, vint16mf4_t, vint16mf4_t, vint16mf4_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vluxei32_v)))
vint8m1_t vluxei32(const int8_t *, vuint32m4_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vluxei32_v_m)))
vint8m1_t vluxei32(vbool8_t, vint8m1_t, const int8_t *, vuint32m4_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vluxei32_v)))
vint8m2_t vluxei32(const int8_t *, vuint32m8_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vluxei32_v_m)))
vint8m2_t vluxei32(vbool4_t, vint8m2_t, const int8_t *, vuint32m8_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vluxei32_v)))
vint8mf2_t vluxei32(const int8_t *, vuint32m2_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vluxei32_v_m)))
vint8mf2_t vluxei32(vbool16_t, vint8mf2_t, const int8_t *, vuint32m2_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vluxei32_v)))
vint8mf4_t vluxei32(const int8_t *, vuint32m1_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vluxei32_v_m)))
vint8mf4_t vluxei32(vbool32_t, vint8mf4_t, const int8_t *, vuint32m1_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vluxei32_v)))
vint8mf8_t vluxei32(const int8_t *, vuint32mf2_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vluxei32_v_m)))
vint8mf8_t vluxei32(vbool64_t, vint8mf8_t, const int8_t *, vuint32mf2_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vsseg6e16_v)))
void vsseg6e16(uint16_t *, vuint16m1_t, vuint16m1_t, vuint16m1_t, vuint16m1_t, vuint16m1_t, vuint16m1_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vsseg6e16_v_m)))
void vsseg6e16(vbool16_t, uint16_t *, vuint16m1_t, vuint16m1_t, vuint16m1_t, vuint16m1_t, vuint16m1_t, vuint16m1_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vsseg6e16_v)))
void vsseg6e16(uint16_t *, vuint16mf2_t, vuint16mf2_t, vuint16mf2_t, vuint16mf2_t, vuint16mf2_t, vuint16mf2_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vsseg6e16_v_m)))
void vsseg6e16(vbool32_t, uint16_t *, vuint16mf2_t, vuint16mf2_t, vuint16mf2_t, vuint16mf2_t, vuint16mf2_t, vuint16mf2_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vsseg6e16_v)))
void vsseg6e16(uint16_t *, vuint16mf4_t, vuint16mf4_t, vuint16mf4_t, vuint16mf4_t, vuint16mf4_t, vuint16mf4_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vsseg6e16_v_m)))
void vsseg6e16(vbool64_t, uint16_t *, vuint16mf4_t, vuint16mf4_t, vuint16mf4_t, vuint16mf4_t, vuint16mf4_t, vuint16mf4_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vsseg7e16_v)))
void vsseg7e16(int16_t *, vint16m1_t, vint16m1_t, vint16m1_t, vint16m1_t, vint16m1_t, vint16m1_t, vint16m1_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vsseg7e16_v_m)))
void vsseg7e16(vbool16_t, int16_t *, vint16m1_t, vint16m1_t, vint16m1_t, vint16m1_t, vint16m1_t, vint16m1_t, vint16m1_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vsseg7e16_v)))
void vsseg7e16(int16_t *, vint16mf2_t, vint16mf2_t, vint16mf2_t, vint16mf2_t, vint16mf2_t, vint16mf2_t, vint16mf2_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vsseg7e16_v_m)))
void vsseg7e16(vbool32_t, int16_t *, vint16mf2_t, vint16mf2_t, vint16mf2_t, vint16mf2_t, vint16mf2_t, vint16mf2_t, vint16mf2_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vsseg7e16_v)))
void vsseg7e16(int16_t *, vint16mf4_t, vint16mf4_t, vint16mf4_t, vint16mf4_t, vint16mf4_t, vint16mf4_t, vint16mf4_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vsseg7e16_v_m)))
void vsseg7e16(vbool64_t, int16_t *, vint16mf4_t, vint16mf4_t, vint16mf4_t, vint16mf4_t, vint16mf4_t, vint16mf4_t, vint16mf4_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vsseg7e16_v)))
void vsseg7e16(uint16_t *, vuint16m1_t, vuint16m1_t, vuint16m1_t, vuint16m1_t, vuint16m1_t, vuint16m1_t, vuint16m1_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vsseg7e16_v_m)))
void vsseg7e16(vbool16_t, uint16_t *, vuint16m1_t, vuint16m1_t, vuint16m1_t, vuint16m1_t, vuint16m1_t, vuint16m1_t, vuint16m1_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vsseg7e16_v)))
void vsseg7e16(uint16_t *, vuint16mf2_t, vuint16mf2_t, vuint16mf2_t, vuint16mf2_t, vuint16mf2_t, vuint16mf2_t, vuint16mf2_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vsseg7e16_v_m)))
void vsseg7e16(vbool32_t, uint16_t *, vuint16mf2_t, vuint16mf2_t, vuint16mf2_t, vuint16mf2_t, vuint16mf2_t, vuint16mf2_t, vuint16mf2_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vsseg7e16_v)))
void vsseg7e16(uint16_t *, vuint16mf4_t, vuint16mf4_t, vuint16mf4_t, vuint16mf4_t, vuint16mf4_t, vuint16mf4_t, vuint16mf4_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vsseg7e16_v_m)))
void vsseg7e16(vbool64_t, uint16_t *, vuint16mf4_t, vuint16mf4_t, vuint16mf4_t, vuint16mf4_t, vuint16mf4_t, vuint16mf4_t, vuint16mf4_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vsseg8e16_v)))
void vsseg8e16(int16_t *, vint16m1_t, vint16m1_t, vint16m1_t, vint16m1_t, vint16m1_t, vint16m1_t, vint16m1_t, vint16m1_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vsseg8e16_v_m)))
void vsseg8e16(vbool16_t, int16_t *, vint16m1_t, vint16m1_t, vint16m1_t, vint16m1_t, vint16m1_t, vint16m1_t, vint16m1_t, vint16m1_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vsseg8e16_v)))
void vsseg8e16(int16_t *, vint16mf2_t, vint16mf2_t, vint16mf2_t, vint16mf2_t, vint16mf2_t, vint16mf2_t, vint16mf2_t, vint16mf2_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vsseg8e16_v_m)))
void vsseg8e16(vbool32_t, int16_t *, vint16mf2_t, vint16mf2_t, vint16mf2_t, vint16mf2_t, vint16mf2_t, vint16mf2_t, vint16mf2_t, vint16mf2_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vsseg8e16_v)))
void vsseg8e16(int16_t *, vint16mf4_t, vint16mf4_t, vint16mf4_t, vint16mf4_t, vint16mf4_t, vint16mf4_t, vint16mf4_t, vint16mf4_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vsseg8e16_v_m)))
void vsseg8e16(vbool64_t, int16_t *, vint16mf4_t, vint16mf4_t, vint16mf4_t, vint16mf4_t, vint16mf4_t, vint16mf4_t, vint16mf4_t, vint16mf4_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vsseg8e16_v)))
void vsseg8e16(uint16_t *, vuint16m1_t, vuint16m1_t, vuint16m1_t, vuint16m1_t, vuint16m1_t, vuint16m1_t, vuint16m1_t, vuint16m1_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vsseg8e16_v_m)))
void vsseg8e16(vbool16_t, uint16_t *, vuint16m1_t, vuint16m1_t, vuint16m1_t, vuint16m1_t, vuint16m1_t, vuint16m1_t, vuint16m1_t, vuint16m1_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vsseg8e16_v)))
void vsseg8e16(uint16_t *, vuint16mf2_t, vuint16mf2_t, vuint16mf2_t, vuint16mf2_t, vuint16mf2_t, vuint16mf2_t, vuint16mf2_t, vuint16mf2_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vsseg8e16_v_m)))
void vsseg8e16(vbool32_t, uint16_t *, vuint16mf2_t, vuint16mf2_t, vuint16mf2_t, vuint16mf2_t, vuint16mf2_t, vuint16mf2_t, vuint16mf2_t, vuint16mf2_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vsseg8e16_v)))
void vsseg8e16(uint16_t *, vuint16mf4_t, vuint16mf4_t, vuint16mf4_t, vuint16mf4_t, vuint16mf4_t, vuint16mf4_t, vuint16mf4_t, vuint16mf4_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vsseg8e16_v_m)))
void vsseg8e16(vbool64_t, uint16_t *, vuint16mf4_t, vuint16mf4_t, vuint16mf4_t, vuint16mf4_t, vuint16mf4_t, vuint16mf4_t, vuint16mf4_t, vuint16mf4_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vsseg2e32_v)))
void vsseg2e32(int32_t *, vint32m1_t, vint32m1_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vsseg2e32_v_m)))
void vsseg2e32(vbool32_t, int32_t *, vint32m1_t, vint32m1_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vsseg2e32_v)))
void vsseg2e32(int32_t *, vint32m2_t, vint32m2_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vsseg2e32_v_m)))
void vsseg2e32(vbool16_t, int32_t *, vint32m2_t, vint32m2_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vsseg2e32_v)))
void vsseg2e32(int32_t *, vint32m4_t, vint32m4_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vsseg2e32_v_m)))
void vsseg2e32(vbool8_t, int32_t *, vint32m4_t, vint32m4_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vsseg2e32_v)))
void vsseg2e32(int32_t *, vint32mf2_t, vint32mf2_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vsseg2e32_v_m)))
void vsseg2e32(vbool64_t, int32_t *, vint32mf2_t, vint32mf2_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vsseg2e32_v)))
void vsseg2e32(uint32_t *, vuint32m1_t, vuint32m1_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vsseg2e32_v_m)))
void vsseg2e32(vbool32_t, uint32_t *, vuint32m1_t, vuint32m1_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vsseg2e32_v)))
void vsseg2e32(uint32_t *, vuint32m2_t, vuint32m2_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vsseg2e32_v_m)))
void vsseg2e32(vbool16_t, uint32_t *, vuint32m2_t, vuint32m2_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vsseg2e32_v)))
void vsseg2e32(uint32_t *, vuint32m4_t, vuint32m4_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vsseg2e32_v_m)))
void vsseg2e32(vbool8_t, uint32_t *, vuint32m4_t, vuint32m4_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vsseg2e32_v)))
void vsseg2e32(uint32_t *, vuint32mf2_t, vuint32mf2_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vsseg2e32_v_m)))
void vsseg2e32(vbool64_t, uint32_t *, vuint32mf2_t, vuint32mf2_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vsseg3e32_v)))
void vsseg3e32(int32_t *, vint32m1_t, vint32m1_t, vint32m1_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vsseg3e32_v_m)))
void vsseg3e32(vbool32_t, int32_t *, vint32m1_t, vint32m1_t, vint32m1_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vsseg3e32_v)))
void vsseg3e32(int32_t *, vint32m2_t, vint32m2_t, vint32m2_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vsseg3e32_v_m)))
void vsseg3e32(vbool16_t, int32_t *, vint32m2_t, vint32m2_t, vint32m2_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vsseg3e32_v)))
void vsseg3e32(int32_t *, vint32mf2_t, vint32mf2_t, vint32mf2_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vsseg3e32_v_m)))
void vsseg3e32(vbool64_t, int32_t *, vint32mf2_t, vint32mf2_t, vint32mf2_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vsseg3e32_v)))
void vsseg3e32(uint32_t *, vuint32m1_t, vuint32m1_t, vuint32m1_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vsseg3e32_v_m)))
void vsseg3e32(vbool32_t, uint32_t *, vuint32m1_t, vuint32m1_t, vuint32m1_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vsseg3e32_v)))
void vsseg3e32(uint32_t *, vuint32m2_t, vuint32m2_t, vuint32m2_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vsseg3e32_v_m)))
void vsseg3e32(vbool16_t, uint32_t *, vuint32m2_t, vuint32m2_t, vuint32m2_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vsseg3e32_v)))
void vsseg3e32(uint32_t *, vuint32mf2_t, vuint32mf2_t, vuint32mf2_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vsseg3e32_v_m)))
void vsseg3e32(vbool64_t, uint32_t *, vuint32mf2_t, vuint32mf2_t, vuint32mf2_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vsseg4e32_v)))
void vsseg4e32(int32_t *, vint32m1_t, vint32m1_t, vint32m1_t, vint32m1_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vsseg4e32_v_m)))
void vsseg4e32(vbool32_t, int32_t *, vint32m1_t, vint32m1_t, vint32m1_t, vint32m1_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vsseg4e32_v)))
void vsseg4e32(int32_t *, vint32m2_t, vint32m2_t, vint32m2_t, vint32m2_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vsseg4e32_v_m)))
void vsseg4e32(vbool16_t, int32_t *, vint32m2_t, vint32m2_t, vint32m2_t, vint32m2_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vsseg4e32_v)))
void vsseg4e32(int32_t *, vint32mf2_t, vint32mf2_t, vint32mf2_t, vint32mf2_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vsseg4e32_v_m)))
void vsseg4e32(vbool64_t, int32_t *, vint32mf2_t, vint32mf2_t, vint32mf2_t, vint32mf2_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vluxei32_v)))
vuint8m1_t vluxei32(const uint8_t *, vuint32m4_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vluxei32_v_m)))
vuint8m1_t vluxei32(vbool8_t, vuint8m1_t, const uint8_t *, vuint32m4_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vluxei32_v)))
vuint8m2_t vluxei32(const uint8_t *, vuint32m8_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vluxei32_v_m)))
vuint8m2_t vluxei32(vbool4_t, vuint8m2_t, const uint8_t *, vuint32m8_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vluxei32_v)))
vuint8mf2_t vluxei32(const uint8_t *, vuint32m2_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vluxei32_v_m)))
vuint8mf2_t vluxei32(vbool16_t, vuint8mf2_t, const uint8_t *, vuint32m2_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vluxei32_v)))
vuint8mf4_t vluxei32(const uint8_t *, vuint32m1_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vluxei32_v_m)))
vuint8mf4_t vluxei32(vbool32_t, vuint8mf4_t, const uint8_t *, vuint32m1_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vluxei32_v)))
vuint8mf8_t vluxei32(const uint8_t *, vuint32mf2_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vluxei32_v_m)))
vuint8mf8_t vluxei32(vbool64_t, vuint8mf8_t, const uint8_t *, vuint32mf2_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vsseg4e32_v)))
void vsseg4e32(uint32_t *, vuint32m1_t, vuint32m1_t, vuint32m1_t, vuint32m1_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vsseg4e32_v_m)))
void vsseg4e32(vbool32_t, uint32_t *, vuint32m1_t, vuint32m1_t, vuint32m1_t, vuint32m1_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vsseg4e32_v)))
void vsseg4e32(uint32_t *, vuint32m2_t, vuint32m2_t, vuint32m2_t, vuint32m2_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vsseg4e32_v_m)))
void vsseg4e32(vbool16_t, uint32_t *, vuint32m2_t, vuint32m2_t, vuint32m2_t, vuint32m2_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vsseg4e32_v)))
void vsseg4e32(uint32_t *, vuint32mf2_t, vuint32mf2_t, vuint32mf2_t, vuint32mf2_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vsseg4e32_v_m)))
void vsseg4e32(vbool64_t, uint32_t *, vuint32mf2_t, vuint32mf2_t, vuint32mf2_t, vuint32mf2_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vsseg5e32_v)))
void vsseg5e32(int32_t *, vint32m1_t, vint32m1_t, vint32m1_t, vint32m1_t, vint32m1_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vsseg5e32_v_m)))
void vsseg5e32(vbool32_t, int32_t *, vint32m1_t, vint32m1_t, vint32m1_t, vint32m1_t, vint32m1_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vsseg5e32_v)))
void vsseg5e32(int32_t *, vint32mf2_t, vint32mf2_t, vint32mf2_t, vint32mf2_t, vint32mf2_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vsseg5e32_v_m)))
void vsseg5e32(vbool64_t, int32_t *, vint32mf2_t, vint32mf2_t, vint32mf2_t, vint32mf2_t, vint32mf2_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vsseg5e32_v)))
void vsseg5e32(uint32_t *, vuint32m1_t, vuint32m1_t, vuint32m1_t, vuint32m1_t, vuint32m1_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vsseg5e32_v_m)))
void vsseg5e32(vbool32_t, uint32_t *, vuint32m1_t, vuint32m1_t, vuint32m1_t, vuint32m1_t, vuint32m1_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vsseg5e32_v)))
void vsseg5e32(uint32_t *, vuint32mf2_t, vuint32mf2_t, vuint32mf2_t, vuint32mf2_t, vuint32mf2_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vsseg5e32_v_m)))
void vsseg5e32(vbool64_t, uint32_t *, vuint32mf2_t, vuint32mf2_t, vuint32mf2_t, vuint32mf2_t, vuint32mf2_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vsseg6e32_v)))
void vsseg6e32(int32_t *, vint32m1_t, vint32m1_t, vint32m1_t, vint32m1_t, vint32m1_t, vint32m1_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vsseg6e32_v_m)))
void vsseg6e32(vbool32_t, int32_t *, vint32m1_t, vint32m1_t, vint32m1_t, vint32m1_t, vint32m1_t, vint32m1_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vsseg6e32_v)))
void vsseg6e32(int32_t *, vint32mf2_t, vint32mf2_t, vint32mf2_t, vint32mf2_t, vint32mf2_t, vint32mf2_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vsseg6e32_v_m)))
void vsseg6e32(vbool64_t, int32_t *, vint32mf2_t, vint32mf2_t, vint32mf2_t, vint32mf2_t, vint32mf2_t, vint32mf2_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vsseg6e32_v)))
void vsseg6e32(uint32_t *, vuint32m1_t, vuint32m1_t, vuint32m1_t, vuint32m1_t, vuint32m1_t, vuint32m1_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vsseg6e32_v_m)))
void vsseg6e32(vbool32_t, uint32_t *, vuint32m1_t, vuint32m1_t, vuint32m1_t, vuint32m1_t, vuint32m1_t, vuint32m1_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vsseg6e32_v)))
void vsseg6e32(uint32_t *, vuint32mf2_t, vuint32mf2_t, vuint32mf2_t, vuint32mf2_t, vuint32mf2_t, vuint32mf2_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vsseg6e32_v_m)))
void vsseg6e32(vbool64_t, uint32_t *, vuint32mf2_t, vuint32mf2_t, vuint32mf2_t, vuint32mf2_t, vuint32mf2_t, vuint32mf2_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vsseg7e32_v)))
void vsseg7e32(int32_t *, vint32m1_t, vint32m1_t, vint32m1_t, vint32m1_t, vint32m1_t, vint32m1_t, vint32m1_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vsseg7e32_v_m)))
void vsseg7e32(vbool32_t, int32_t *, vint32m1_t, vint32m1_t, vint32m1_t, vint32m1_t, vint32m1_t, vint32m1_t, vint32m1_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vsseg7e32_v)))
void vsseg7e32(int32_t *, vint32mf2_t, vint32mf2_t, vint32mf2_t, vint32mf2_t, vint32mf2_t, vint32mf2_t, vint32mf2_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vsseg7e32_v_m)))
void vsseg7e32(vbool64_t, int32_t *, vint32mf2_t, vint32mf2_t, vint32mf2_t, vint32mf2_t, vint32mf2_t, vint32mf2_t, vint32mf2_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vsseg7e32_v)))
void vsseg7e32(uint32_t *, vuint32m1_t, vuint32m1_t, vuint32m1_t, vuint32m1_t, vuint32m1_t, vuint32m1_t, vuint32m1_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vsseg7e32_v_m)))
void vsseg7e32(vbool32_t, uint32_t *, vuint32m1_t, vuint32m1_t, vuint32m1_t, vuint32m1_t, vuint32m1_t, vuint32m1_t, vuint32m1_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vsseg7e32_v)))
void vsseg7e32(uint32_t *, vuint32mf2_t, vuint32mf2_t, vuint32mf2_t, vuint32mf2_t, vuint32mf2_t, vuint32mf2_t, vuint32mf2_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vsseg7e32_v_m)))
void vsseg7e32(vbool64_t, uint32_t *, vuint32mf2_t, vuint32mf2_t, vuint32mf2_t, vuint32mf2_t, vuint32mf2_t, vuint32mf2_t, vuint32mf2_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vsseg8e32_v)))
void vsseg8e32(int32_t *, vint32m1_t, vint32m1_t, vint32m1_t, vint32m1_t, vint32m1_t, vint32m1_t, vint32m1_t, vint32m1_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vsseg8e32_v_m)))
void vsseg8e32(vbool32_t, int32_t *, vint32m1_t, vint32m1_t, vint32m1_t, vint32m1_t, vint32m1_t, vint32m1_t, vint32m1_t, vint32m1_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vsseg8e32_v)))
void vsseg8e32(int32_t *, vint32mf2_t, vint32mf2_t, vint32mf2_t, vint32mf2_t, vint32mf2_t, vint32mf2_t, vint32mf2_t, vint32mf2_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vsseg8e32_v_m)))
void vsseg8e32(vbool64_t, int32_t *, vint32mf2_t, vint32mf2_t, vint32mf2_t, vint32mf2_t, vint32mf2_t, vint32mf2_t, vint32mf2_t, vint32mf2_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vsseg8e32_v)))
void vsseg8e32(uint32_t *, vuint32m1_t, vuint32m1_t, vuint32m1_t, vuint32m1_t, vuint32m1_t, vuint32m1_t, vuint32m1_t, vuint32m1_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vsseg8e32_v_m)))
void vsseg8e32(vbool32_t, uint32_t *, vuint32m1_t, vuint32m1_t, vuint32m1_t, vuint32m1_t, vuint32m1_t, vuint32m1_t, vuint32m1_t, vuint32m1_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vsseg8e32_v)))
void vsseg8e32(uint32_t *, vuint32mf2_t, vuint32mf2_t, vuint32mf2_t, vuint32mf2_t, vuint32mf2_t, vuint32mf2_t, vuint32mf2_t, vuint32mf2_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vsseg8e32_v_m)))
void vsseg8e32(vbool64_t, uint32_t *, vuint32mf2_t, vuint32mf2_t, vuint32mf2_t, vuint32mf2_t, vuint32mf2_t, vuint32mf2_t, vuint32mf2_t, vuint32mf2_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vluxei8_v)))
vint16m1_t vluxei8(const int16_t *, vuint8mf2_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vluxei8_v_m)))
vint16m1_t vluxei8(vbool16_t, vint16m1_t, const int16_t *, vuint8mf2_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vluxei8_v)))
vint16m2_t vluxei8(const int16_t *, vuint8m1_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vluxei8_v_m)))
vint16m2_t vluxei8(vbool8_t, vint16m2_t, const int16_t *, vuint8m1_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vluxei8_v)))
vint16m4_t vluxei8(const int16_t *, vuint8m2_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vluxei8_v_m)))
vint16m4_t vluxei8(vbool4_t, vint16m4_t, const int16_t *, vuint8m2_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vluxei8_v)))
vint16m8_t vluxei8(const int16_t *, vuint8m4_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vluxei8_v_m)))
vint16m8_t vluxei8(vbool2_t, vint16m8_t, const int16_t *, vuint8m4_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vluxei8_v)))
vint16mf2_t vluxei8(const int16_t *, vuint8mf4_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vluxei8_v_m)))
vint16mf2_t vluxei8(vbool32_t, vint16mf2_t, const int16_t *, vuint8mf4_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vluxei8_v)))
vint16mf4_t vluxei8(const int16_t *, vuint8mf8_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vluxei8_v_m)))
vint16mf4_t vluxei8(vbool64_t, vint16mf4_t, const int16_t *, vuint8mf8_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vluxei8_v)))
vuint16m1_t vluxei8(const uint16_t *, vuint8mf2_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vluxei8_v_m)))
vuint16m1_t vluxei8(vbool16_t, vuint16m1_t, const uint16_t *, vuint8mf2_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vluxei8_v)))
vuint16m2_t vluxei8(const uint16_t *, vuint8m1_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vluxei8_v_m)))
vuint16m2_t vluxei8(vbool8_t, vuint16m2_t, const uint16_t *, vuint8m1_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vluxei8_v)))
vuint16m4_t vluxei8(const uint16_t *, vuint8m2_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vluxei8_v_m)))
vuint16m4_t vluxei8(vbool4_t, vuint16m4_t, const uint16_t *, vuint8m2_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vluxei8_v)))
vuint16m8_t vluxei8(const uint16_t *, vuint8m4_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vluxei8_v_m)))
vuint16m8_t vluxei8(vbool2_t, vuint16m8_t, const uint16_t *, vuint8m4_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vluxei8_v)))
vuint16mf2_t vluxei8(const uint16_t *, vuint8mf4_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vluxei8_v_m)))
vuint16mf2_t vluxei8(vbool32_t, vuint16mf2_t, const uint16_t *, vuint8mf4_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vluxei8_v)))
vuint16mf4_t vluxei8(const uint16_t *, vuint8mf8_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vluxei8_v_m)))
vuint16mf4_t vluxei8(vbool64_t, vuint16mf4_t, const uint16_t *, vuint8mf8_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vluxei16_v)))
vint16m1_t vluxei16(const int16_t *, vuint16m1_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vluxei16_v_m)))
vint16m1_t vluxei16(vbool16_t, vint16m1_t, const int16_t *, vuint16m1_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vluxei16_v)))
vint16m2_t vluxei16(const int16_t *, vuint16m2_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vluxei16_v_m)))
vint16m2_t vluxei16(vbool8_t, vint16m2_t, const int16_t *, vuint16m2_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vluxei16_v)))
vint16m4_t vluxei16(const int16_t *, vuint16m4_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vluxei16_v_m)))
vint16m4_t vluxei16(vbool4_t, vint16m4_t, const int16_t *, vuint16m4_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vluxei16_v)))
vint16m8_t vluxei16(const int16_t *, vuint16m8_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vluxei16_v_m)))
vint16m8_t vluxei16(vbool2_t, vint16m8_t, const int16_t *, vuint16m8_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vluxei16_v)))
vint16mf2_t vluxei16(const int16_t *, vuint16mf2_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vluxei16_v_m)))
vint16mf2_t vluxei16(vbool32_t, vint16mf2_t, const int16_t *, vuint16mf2_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vluxei16_v)))
vint16mf4_t vluxei16(const int16_t *, vuint16mf4_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vluxei16_v_m)))
vint16mf4_t vluxei16(vbool64_t, vint16mf4_t, const int16_t *, vuint16mf4_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vluxei16_v)))
vuint16m1_t vluxei16(const uint16_t *, vuint16m1_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vluxei16_v_m)))
vuint16m1_t vluxei16(vbool16_t, vuint16m1_t, const uint16_t *, vuint16m1_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vluxei16_v)))
vuint16m2_t vluxei16(const uint16_t *, vuint16m2_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vluxei16_v_m)))
vuint16m2_t vluxei16(vbool8_t, vuint16m2_t, const uint16_t *, vuint16m2_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vluxei16_v)))
vuint16m4_t vluxei16(const uint16_t *, vuint16m4_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vluxei16_v_m)))
vuint16m4_t vluxei16(vbool4_t, vuint16m4_t, const uint16_t *, vuint16m4_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vluxei16_v)))
vuint16m8_t vluxei16(const uint16_t *, vuint16m8_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vluxei16_v_m)))
vuint16m8_t vluxei16(vbool2_t, vuint16m8_t, const uint16_t *, vuint16m8_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vluxei16_v)))
vuint16mf2_t vluxei16(const uint16_t *, vuint16mf2_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vluxei16_v_m)))
vuint16mf2_t vluxei16(vbool32_t, vuint16mf2_t, const uint16_t *, vuint16mf2_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vluxei16_v)))
vuint16mf4_t vluxei16(const uint16_t *, vuint16mf4_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vluxei16_v_m)))
vuint16mf4_t vluxei16(vbool64_t, vuint16mf4_t, const uint16_t *, vuint16mf4_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vssseg3e8_v)))
void vssseg3e8(int8_t *, ptrdiff_t, vint8m1_t, vint8m1_t, vint8m1_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vssseg3e8_v_m)))
void vssseg3e8(vbool8_t, int8_t *, ptrdiff_t, vint8m1_t, vint8m1_t, vint8m1_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vssseg3e8_v)))
void vssseg3e8(int8_t *, ptrdiff_t, vint8m2_t, vint8m2_t, vint8m2_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vssseg3e8_v_m)))
void vssseg3e8(vbool4_t, int8_t *, ptrdiff_t, vint8m2_t, vint8m2_t, vint8m2_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vssseg3e8_v)))
void vssseg3e8(int8_t *, ptrdiff_t, vint8mf2_t, vint8mf2_t, vint8mf2_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vssseg3e8_v_m)))
void vssseg3e8(vbool16_t, int8_t *, ptrdiff_t, vint8mf2_t, vint8mf2_t, vint8mf2_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vssseg3e8_v)))
void vssseg3e8(int8_t *, ptrdiff_t, vint8mf4_t, vint8mf4_t, vint8mf4_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vssseg3e8_v_m)))
void vssseg3e8(vbool32_t, int8_t *, ptrdiff_t, vint8mf4_t, vint8mf4_t, vint8mf4_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vssseg3e8_v)))
void vssseg3e8(int8_t *, ptrdiff_t, vint8mf8_t, vint8mf8_t, vint8mf8_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vssseg3e8_v_m)))
void vssseg3e8(vbool64_t, int8_t *, ptrdiff_t, vint8mf8_t, vint8mf8_t, vint8mf8_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vssseg3e8_v)))
void vssseg3e8(uint8_t *, ptrdiff_t, vuint8m1_t, vuint8m1_t, vuint8m1_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vssseg3e8_v_m)))
void vssseg3e8(vbool8_t, uint8_t *, ptrdiff_t, vuint8m1_t, vuint8m1_t, vuint8m1_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vssseg3e8_v)))
void vssseg3e8(uint8_t *, ptrdiff_t, vuint8m2_t, vuint8m2_t, vuint8m2_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vssseg3e8_v_m)))
void vssseg3e8(vbool4_t, uint8_t *, ptrdiff_t, vuint8m2_t, vuint8m2_t, vuint8m2_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vssseg3e8_v)))
void vssseg3e8(uint8_t *, ptrdiff_t, vuint8mf2_t, vuint8mf2_t, vuint8mf2_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vssseg3e8_v_m)))
void vssseg3e8(vbool16_t, uint8_t *, ptrdiff_t, vuint8mf2_t, vuint8mf2_t, vuint8mf2_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vssseg3e8_v)))
void vssseg3e8(uint8_t *, ptrdiff_t, vuint8mf4_t, vuint8mf4_t, vuint8mf4_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vssseg3e8_v_m)))
void vssseg3e8(vbool32_t, uint8_t *, ptrdiff_t, vuint8mf4_t, vuint8mf4_t, vuint8mf4_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vssseg3e8_v)))
void vssseg3e8(uint8_t *, ptrdiff_t, vuint8mf8_t, vuint8mf8_t, vuint8mf8_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vssseg3e8_v_m)))
void vssseg3e8(vbool64_t, uint8_t *, ptrdiff_t, vuint8mf8_t, vuint8mf8_t, vuint8mf8_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vssseg4e8_v)))
void vssseg4e8(int8_t *, ptrdiff_t, vint8m1_t, vint8m1_t, vint8m1_t, vint8m1_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vssseg4e8_v_m)))
void vssseg4e8(vbool8_t, int8_t *, ptrdiff_t, vint8m1_t, vint8m1_t, vint8m1_t, vint8m1_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vssseg4e8_v)))
void vssseg4e8(int8_t *, ptrdiff_t, vint8m2_t, vint8m2_t, vint8m2_t, vint8m2_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vssseg4e8_v_m)))
void vssseg4e8(vbool4_t, int8_t *, ptrdiff_t, vint8m2_t, vint8m2_t, vint8m2_t, vint8m2_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vssseg4e8_v)))
void vssseg4e8(int8_t *, ptrdiff_t, vint8mf2_t, vint8mf2_t, vint8mf2_t, vint8mf2_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vssseg4e8_v_m)))
void vssseg4e8(vbool16_t, int8_t *, ptrdiff_t, vint8mf2_t, vint8mf2_t, vint8mf2_t, vint8mf2_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vssseg4e8_v)))
void vssseg4e8(int8_t *, ptrdiff_t, vint8mf4_t, vint8mf4_t, vint8mf4_t, vint8mf4_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vssseg4e8_v_m)))
void vssseg4e8(vbool32_t, int8_t *, ptrdiff_t, vint8mf4_t, vint8mf4_t, vint8mf4_t, vint8mf4_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vssseg4e8_v)))
void vssseg4e8(int8_t *, ptrdiff_t, vint8mf8_t, vint8mf8_t, vint8mf8_t, vint8mf8_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vssseg4e8_v_m)))
void vssseg4e8(vbool64_t, int8_t *, ptrdiff_t, vint8mf8_t, vint8mf8_t, vint8mf8_t, vint8mf8_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vssseg4e8_v)))
void vssseg4e8(uint8_t *, ptrdiff_t, vuint8m1_t, vuint8m1_t, vuint8m1_t, vuint8m1_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vssseg4e8_v_m)))
void vssseg4e8(vbool8_t, uint8_t *, ptrdiff_t, vuint8m1_t, vuint8m1_t, vuint8m1_t, vuint8m1_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vssseg4e8_v)))
void vssseg4e8(uint8_t *, ptrdiff_t, vuint8m2_t, vuint8m2_t, vuint8m2_t, vuint8m2_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vssseg4e8_v_m)))
void vssseg4e8(vbool4_t, uint8_t *, ptrdiff_t, vuint8m2_t, vuint8m2_t, vuint8m2_t, vuint8m2_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vssseg4e8_v)))
void vssseg4e8(uint8_t *, ptrdiff_t, vuint8mf2_t, vuint8mf2_t, vuint8mf2_t, vuint8mf2_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vssseg4e8_v_m)))
void vssseg4e8(vbool16_t, uint8_t *, ptrdiff_t, vuint8mf2_t, vuint8mf2_t, vuint8mf2_t, vuint8mf2_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vssseg4e8_v)))
void vssseg4e8(uint8_t *, ptrdiff_t, vuint8mf4_t, vuint8mf4_t, vuint8mf4_t, vuint8mf4_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vssseg4e8_v_m)))
void vssseg4e8(vbool32_t, uint8_t *, ptrdiff_t, vuint8mf4_t, vuint8mf4_t, vuint8mf4_t, vuint8mf4_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vssseg4e8_v)))
void vssseg4e8(uint8_t *, ptrdiff_t, vuint8mf8_t, vuint8mf8_t, vuint8mf8_t, vuint8mf8_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vssseg4e8_v_m)))
void vssseg4e8(vbool64_t, uint8_t *, ptrdiff_t, vuint8mf8_t, vuint8mf8_t, vuint8mf8_t, vuint8mf8_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vssseg5e8_v)))
void vssseg5e8(int8_t *, ptrdiff_t, vint8m1_t, vint8m1_t, vint8m1_t, vint8m1_t, vint8m1_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vssseg5e8_v_m)))
void vssseg5e8(vbool8_t, int8_t *, ptrdiff_t, vint8m1_t, vint8m1_t, vint8m1_t, vint8m1_t, vint8m1_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vssseg5e8_v)))
void vssseg5e8(int8_t *, ptrdiff_t, vint8mf2_t, vint8mf2_t, vint8mf2_t, vint8mf2_t, vint8mf2_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vssseg5e8_v_m)))
void vssseg5e8(vbool16_t, int8_t *, ptrdiff_t, vint8mf2_t, vint8mf2_t, vint8mf2_t, vint8mf2_t, vint8mf2_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vssseg5e8_v)))
void vssseg5e8(int8_t *, ptrdiff_t, vint8mf4_t, vint8mf4_t, vint8mf4_t, vint8mf4_t, vint8mf4_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vssseg5e8_v_m)))
void vssseg5e8(vbool32_t, int8_t *, ptrdiff_t, vint8mf4_t, vint8mf4_t, vint8mf4_t, vint8mf4_t, vint8mf4_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vssseg5e8_v)))
void vssseg5e8(int8_t *, ptrdiff_t, vint8mf8_t, vint8mf8_t, vint8mf8_t, vint8mf8_t, vint8mf8_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vssseg5e8_v_m)))
void vssseg5e8(vbool64_t, int8_t *, ptrdiff_t, vint8mf8_t, vint8mf8_t, vint8mf8_t, vint8mf8_t, vint8mf8_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vluxei32_v)))
vint16m1_t vluxei32(const int16_t *, vuint32m2_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vluxei32_v_m)))
vint16m1_t vluxei32(vbool16_t, vint16m1_t, const int16_t *, vuint32m2_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vluxei32_v)))
vint16m2_t vluxei32(const int16_t *, vuint32m4_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vluxei32_v_m)))
vint16m2_t vluxei32(vbool8_t, vint16m2_t, const int16_t *, vuint32m4_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vluxei32_v)))
vint16m4_t vluxei32(const int16_t *, vuint32m8_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vluxei32_v_m)))
vint16m4_t vluxei32(vbool4_t, vint16m4_t, const int16_t *, vuint32m8_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vluxei32_v)))
vint16mf2_t vluxei32(const int16_t *, vuint32m1_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vluxei32_v_m)))
vint16mf2_t vluxei32(vbool32_t, vint16mf2_t, const int16_t *, vuint32m1_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vluxei32_v)))
vint16mf4_t vluxei32(const int16_t *, vuint32mf2_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vluxei32_v_m)))
vint16mf4_t vluxei32(vbool64_t, vint16mf4_t, const int16_t *, vuint32mf2_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vssseg5e8_v)))
void vssseg5e8(uint8_t *, ptrdiff_t, vuint8m1_t, vuint8m1_t, vuint8m1_t, vuint8m1_t, vuint8m1_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vssseg5e8_v_m)))
void vssseg5e8(vbool8_t, uint8_t *, ptrdiff_t, vuint8m1_t, vuint8m1_t, vuint8m1_t, vuint8m1_t, vuint8m1_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vssseg5e8_v)))
void vssseg5e8(uint8_t *, ptrdiff_t, vuint8mf2_t, vuint8mf2_t, vuint8mf2_t, vuint8mf2_t, vuint8mf2_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vssseg5e8_v_m)))
void vssseg5e8(vbool16_t, uint8_t *, ptrdiff_t, vuint8mf2_t, vuint8mf2_t, vuint8mf2_t, vuint8mf2_t, vuint8mf2_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vssseg5e8_v)))
void vssseg5e8(uint8_t *, ptrdiff_t, vuint8mf4_t, vuint8mf4_t, vuint8mf4_t, vuint8mf4_t, vuint8mf4_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vssseg5e8_v_m)))
void vssseg5e8(vbool32_t, uint8_t *, ptrdiff_t, vuint8mf4_t, vuint8mf4_t, vuint8mf4_t, vuint8mf4_t, vuint8mf4_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vssseg5e8_v)))
void vssseg5e8(uint8_t *, ptrdiff_t, vuint8mf8_t, vuint8mf8_t, vuint8mf8_t, vuint8mf8_t, vuint8mf8_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vssseg5e8_v_m)))
void vssseg5e8(vbool64_t, uint8_t *, ptrdiff_t, vuint8mf8_t, vuint8mf8_t, vuint8mf8_t, vuint8mf8_t, vuint8mf8_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vssseg6e8_v)))
void vssseg6e8(int8_t *, ptrdiff_t, vint8m1_t, vint8m1_t, vint8m1_t, vint8m1_t, vint8m1_t, vint8m1_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vssseg6e8_v_m)))
void vssseg6e8(vbool8_t, int8_t *, ptrdiff_t, vint8m1_t, vint8m1_t, vint8m1_t, vint8m1_t, vint8m1_t, vint8m1_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vssseg6e8_v)))
void vssseg6e8(int8_t *, ptrdiff_t, vint8mf2_t, vint8mf2_t, vint8mf2_t, vint8mf2_t, vint8mf2_t, vint8mf2_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vssseg6e8_v_m)))
void vssseg6e8(vbool16_t, int8_t *, ptrdiff_t, vint8mf2_t, vint8mf2_t, vint8mf2_t, vint8mf2_t, vint8mf2_t, vint8mf2_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vssseg6e8_v)))
void vssseg6e8(int8_t *, ptrdiff_t, vint8mf4_t, vint8mf4_t, vint8mf4_t, vint8mf4_t, vint8mf4_t, vint8mf4_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vssseg6e8_v_m)))
void vssseg6e8(vbool32_t, int8_t *, ptrdiff_t, vint8mf4_t, vint8mf4_t, vint8mf4_t, vint8mf4_t, vint8mf4_t, vint8mf4_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vssseg6e8_v)))
void vssseg6e8(int8_t *, ptrdiff_t, vint8mf8_t, vint8mf8_t, vint8mf8_t, vint8mf8_t, vint8mf8_t, vint8mf8_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vssseg6e8_v_m)))
void vssseg6e8(vbool64_t, int8_t *, ptrdiff_t, vint8mf8_t, vint8mf8_t, vint8mf8_t, vint8mf8_t, vint8mf8_t, vint8mf8_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vssseg6e8_v)))
void vssseg6e8(uint8_t *, ptrdiff_t, vuint8m1_t, vuint8m1_t, vuint8m1_t, vuint8m1_t, vuint8m1_t, vuint8m1_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vssseg6e8_v_m)))
void vssseg6e8(vbool8_t, uint8_t *, ptrdiff_t, vuint8m1_t, vuint8m1_t, vuint8m1_t, vuint8m1_t, vuint8m1_t, vuint8m1_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vssseg6e8_v)))
void vssseg6e8(uint8_t *, ptrdiff_t, vuint8mf2_t, vuint8mf2_t, vuint8mf2_t, vuint8mf2_t, vuint8mf2_t, vuint8mf2_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vssseg6e8_v_m)))
void vssseg6e8(vbool16_t, uint8_t *, ptrdiff_t, vuint8mf2_t, vuint8mf2_t, vuint8mf2_t, vuint8mf2_t, vuint8mf2_t, vuint8mf2_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vssseg6e8_v)))
void vssseg6e8(uint8_t *, ptrdiff_t, vuint8mf4_t, vuint8mf4_t, vuint8mf4_t, vuint8mf4_t, vuint8mf4_t, vuint8mf4_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vssseg6e8_v_m)))
void vssseg6e8(vbool32_t, uint8_t *, ptrdiff_t, vuint8mf4_t, vuint8mf4_t, vuint8mf4_t, vuint8mf4_t, vuint8mf4_t, vuint8mf4_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vssseg6e8_v)))
void vssseg6e8(uint8_t *, ptrdiff_t, vuint8mf8_t, vuint8mf8_t, vuint8mf8_t, vuint8mf8_t, vuint8mf8_t, vuint8mf8_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vssseg6e8_v_m)))
void vssseg6e8(vbool64_t, uint8_t *, ptrdiff_t, vuint8mf8_t, vuint8mf8_t, vuint8mf8_t, vuint8mf8_t, vuint8mf8_t, vuint8mf8_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vssseg7e8_v)))
void vssseg7e8(int8_t *, ptrdiff_t, vint8m1_t, vint8m1_t, vint8m1_t, vint8m1_t, vint8m1_t, vint8m1_t, vint8m1_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vssseg7e8_v_m)))
void vssseg7e8(vbool8_t, int8_t *, ptrdiff_t, vint8m1_t, vint8m1_t, vint8m1_t, vint8m1_t, vint8m1_t, vint8m1_t, vint8m1_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vssseg7e8_v)))
void vssseg7e8(int8_t *, ptrdiff_t, vint8mf2_t, vint8mf2_t, vint8mf2_t, vint8mf2_t, vint8mf2_t, vint8mf2_t, vint8mf2_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vssseg7e8_v_m)))
void vssseg7e8(vbool16_t, int8_t *, ptrdiff_t, vint8mf2_t, vint8mf2_t, vint8mf2_t, vint8mf2_t, vint8mf2_t, vint8mf2_t, vint8mf2_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vssseg7e8_v)))
void vssseg7e8(int8_t *, ptrdiff_t, vint8mf4_t, vint8mf4_t, vint8mf4_t, vint8mf4_t, vint8mf4_t, vint8mf4_t, vint8mf4_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vssseg7e8_v_m)))
void vssseg7e8(vbool32_t, int8_t *, ptrdiff_t, vint8mf4_t, vint8mf4_t, vint8mf4_t, vint8mf4_t, vint8mf4_t, vint8mf4_t, vint8mf4_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vssseg7e8_v)))
void vssseg7e8(int8_t *, ptrdiff_t, vint8mf8_t, vint8mf8_t, vint8mf8_t, vint8mf8_t, vint8mf8_t, vint8mf8_t, vint8mf8_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vssseg7e8_v_m)))
void vssseg7e8(vbool64_t, int8_t *, ptrdiff_t, vint8mf8_t, vint8mf8_t, vint8mf8_t, vint8mf8_t, vint8mf8_t, vint8mf8_t, vint8mf8_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vssseg7e8_v)))
void vssseg7e8(uint8_t *, ptrdiff_t, vuint8m1_t, vuint8m1_t, vuint8m1_t, vuint8m1_t, vuint8m1_t, vuint8m1_t, vuint8m1_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vssseg7e8_v_m)))
void vssseg7e8(vbool8_t, uint8_t *, ptrdiff_t, vuint8m1_t, vuint8m1_t, vuint8m1_t, vuint8m1_t, vuint8m1_t, vuint8m1_t, vuint8m1_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vssseg7e8_v)))
void vssseg7e8(uint8_t *, ptrdiff_t, vuint8mf2_t, vuint8mf2_t, vuint8mf2_t, vuint8mf2_t, vuint8mf2_t, vuint8mf2_t, vuint8mf2_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vssseg7e8_v_m)))
void vssseg7e8(vbool16_t, uint8_t *, ptrdiff_t, vuint8mf2_t, vuint8mf2_t, vuint8mf2_t, vuint8mf2_t, vuint8mf2_t, vuint8mf2_t, vuint8mf2_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vssseg7e8_v)))
void vssseg7e8(uint8_t *, ptrdiff_t, vuint8mf4_t, vuint8mf4_t, vuint8mf4_t, vuint8mf4_t, vuint8mf4_t, vuint8mf4_t, vuint8mf4_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vssseg7e8_v_m)))
void vssseg7e8(vbool32_t, uint8_t *, ptrdiff_t, vuint8mf4_t, vuint8mf4_t, vuint8mf4_t, vuint8mf4_t, vuint8mf4_t, vuint8mf4_t, vuint8mf4_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vssseg7e8_v)))
void vssseg7e8(uint8_t *, ptrdiff_t, vuint8mf8_t, vuint8mf8_t, vuint8mf8_t, vuint8mf8_t, vuint8mf8_t, vuint8mf8_t, vuint8mf8_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vssseg7e8_v_m)))
void vssseg7e8(vbool64_t, uint8_t *, ptrdiff_t, vuint8mf8_t, vuint8mf8_t, vuint8mf8_t, vuint8mf8_t, vuint8mf8_t, vuint8mf8_t, vuint8mf8_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vssseg8e8_v)))
void vssseg8e8(int8_t *, ptrdiff_t, vint8m1_t, vint8m1_t, vint8m1_t, vint8m1_t, vint8m1_t, vint8m1_t, vint8m1_t, vint8m1_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vssseg8e8_v_m)))
void vssseg8e8(vbool8_t, int8_t *, ptrdiff_t, vint8m1_t, vint8m1_t, vint8m1_t, vint8m1_t, vint8m1_t, vint8m1_t, vint8m1_t, vint8m1_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vssseg8e8_v)))
void vssseg8e8(int8_t *, ptrdiff_t, vint8mf2_t, vint8mf2_t, vint8mf2_t, vint8mf2_t, vint8mf2_t, vint8mf2_t, vint8mf2_t, vint8mf2_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vssseg8e8_v_m)))
void vssseg8e8(vbool16_t, int8_t *, ptrdiff_t, vint8mf2_t, vint8mf2_t, vint8mf2_t, vint8mf2_t, vint8mf2_t, vint8mf2_t, vint8mf2_t, vint8mf2_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vssseg8e8_v)))
void vssseg8e8(int8_t *, ptrdiff_t, vint8mf4_t, vint8mf4_t, vint8mf4_t, vint8mf4_t, vint8mf4_t, vint8mf4_t, vint8mf4_t, vint8mf4_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vssseg8e8_v_m)))
void vssseg8e8(vbool32_t, int8_t *, ptrdiff_t, vint8mf4_t, vint8mf4_t, vint8mf4_t, vint8mf4_t, vint8mf4_t, vint8mf4_t, vint8mf4_t, vint8mf4_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vssseg8e8_v)))
void vssseg8e8(int8_t *, ptrdiff_t, vint8mf8_t, vint8mf8_t, vint8mf8_t, vint8mf8_t, vint8mf8_t, vint8mf8_t, vint8mf8_t, vint8mf8_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vssseg8e8_v_m)))
void vssseg8e8(vbool64_t, int8_t *, ptrdiff_t, vint8mf8_t, vint8mf8_t, vint8mf8_t, vint8mf8_t, vint8mf8_t, vint8mf8_t, vint8mf8_t, vint8mf8_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vssseg8e8_v)))
void vssseg8e8(uint8_t *, ptrdiff_t, vuint8m1_t, vuint8m1_t, vuint8m1_t, vuint8m1_t, vuint8m1_t, vuint8m1_t, vuint8m1_t, vuint8m1_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vssseg8e8_v_m)))
void vssseg8e8(vbool8_t, uint8_t *, ptrdiff_t, vuint8m1_t, vuint8m1_t, vuint8m1_t, vuint8m1_t, vuint8m1_t, vuint8m1_t, vuint8m1_t, vuint8m1_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vssseg8e8_v)))
void vssseg8e8(uint8_t *, ptrdiff_t, vuint8mf2_t, vuint8mf2_t, vuint8mf2_t, vuint8mf2_t, vuint8mf2_t, vuint8mf2_t, vuint8mf2_t, vuint8mf2_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vssseg8e8_v_m)))
void vssseg8e8(vbool16_t, uint8_t *, ptrdiff_t, vuint8mf2_t, vuint8mf2_t, vuint8mf2_t, vuint8mf2_t, vuint8mf2_t, vuint8mf2_t, vuint8mf2_t, vuint8mf2_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vssseg8e8_v)))
void vssseg8e8(uint8_t *, ptrdiff_t, vuint8mf4_t, vuint8mf4_t, vuint8mf4_t, vuint8mf4_t, vuint8mf4_t, vuint8mf4_t, vuint8mf4_t, vuint8mf4_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vssseg8e8_v_m)))
void vssseg8e8(vbool32_t, uint8_t *, ptrdiff_t, vuint8mf4_t, vuint8mf4_t, vuint8mf4_t, vuint8mf4_t, vuint8mf4_t, vuint8mf4_t, vuint8mf4_t, vuint8mf4_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vssseg8e8_v)))
void vssseg8e8(uint8_t *, ptrdiff_t, vuint8mf8_t, vuint8mf8_t, vuint8mf8_t, vuint8mf8_t, vuint8mf8_t, vuint8mf8_t, vuint8mf8_t, vuint8mf8_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vssseg8e8_v_m)))
void vssseg8e8(vbool64_t, uint8_t *, ptrdiff_t, vuint8mf8_t, vuint8mf8_t, vuint8mf8_t, vuint8mf8_t, vuint8mf8_t, vuint8mf8_t, vuint8mf8_t, vuint8mf8_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vssseg2e16_v)))
void vssseg2e16(int16_t *, ptrdiff_t, vint16m1_t, vint16m1_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vssseg2e16_v_m)))
void vssseg2e16(vbool16_t, int16_t *, ptrdiff_t, vint16m1_t, vint16m1_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vssseg2e16_v)))
void vssseg2e16(int16_t *, ptrdiff_t, vint16m2_t, vint16m2_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vssseg2e16_v_m)))
void vssseg2e16(vbool8_t, int16_t *, ptrdiff_t, vint16m2_t, vint16m2_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vssseg2e16_v)))
void vssseg2e16(int16_t *, ptrdiff_t, vint16m4_t, vint16m4_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vssseg2e16_v_m)))
void vssseg2e16(vbool4_t, int16_t *, ptrdiff_t, vint16m4_t, vint16m4_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vssseg2e16_v)))
void vssseg2e16(int16_t *, ptrdiff_t, vint16mf2_t, vint16mf2_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vssseg2e16_v_m)))
void vssseg2e16(vbool32_t, int16_t *, ptrdiff_t, vint16mf2_t, vint16mf2_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vssseg2e16_v)))
void vssseg2e16(int16_t *, ptrdiff_t, vint16mf4_t, vint16mf4_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vssseg2e16_v_m)))
void vssseg2e16(vbool64_t, int16_t *, ptrdiff_t, vint16mf4_t, vint16mf4_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vssseg2e16_v)))
void vssseg2e16(uint16_t *, ptrdiff_t, vuint16m1_t, vuint16m1_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vssseg2e16_v_m)))
void vssseg2e16(vbool16_t, uint16_t *, ptrdiff_t, vuint16m1_t, vuint16m1_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vssseg2e16_v)))
void vssseg2e16(uint16_t *, ptrdiff_t, vuint16m2_t, vuint16m2_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vssseg2e16_v_m)))
void vssseg2e16(vbool8_t, uint16_t *, ptrdiff_t, vuint16m2_t, vuint16m2_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vssseg2e16_v)))
void vssseg2e16(uint16_t *, ptrdiff_t, vuint16m4_t, vuint16m4_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vssseg2e16_v_m)))
void vssseg2e16(vbool4_t, uint16_t *, ptrdiff_t, vuint16m4_t, vuint16m4_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vssseg2e16_v)))
void vssseg2e16(uint16_t *, ptrdiff_t, vuint16mf2_t, vuint16mf2_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vssseg2e16_v_m)))
void vssseg2e16(vbool32_t, uint16_t *, ptrdiff_t, vuint16mf2_t, vuint16mf2_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vssseg2e16_v)))
void vssseg2e16(uint16_t *, ptrdiff_t, vuint16mf4_t, vuint16mf4_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vssseg2e16_v_m)))
void vssseg2e16(vbool64_t, uint16_t *, ptrdiff_t, vuint16mf4_t, vuint16mf4_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vssseg3e16_v)))
void vssseg3e16(int16_t *, ptrdiff_t, vint16m1_t, vint16m1_t, vint16m1_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vssseg3e16_v_m)))
void vssseg3e16(vbool16_t, int16_t *, ptrdiff_t, vint16m1_t, vint16m1_t, vint16m1_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vssseg3e16_v)))
void vssseg3e16(int16_t *, ptrdiff_t, vint16m2_t, vint16m2_t, vint16m2_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vssseg3e16_v_m)))
void vssseg3e16(vbool8_t, int16_t *, ptrdiff_t, vint16m2_t, vint16m2_t, vint16m2_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vssseg3e16_v)))
void vssseg3e16(int16_t *, ptrdiff_t, vint16mf2_t, vint16mf2_t, vint16mf2_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vssseg3e16_v_m)))
void vssseg3e16(vbool32_t, int16_t *, ptrdiff_t, vint16mf2_t, vint16mf2_t, vint16mf2_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vssseg3e16_v)))
void vssseg3e16(int16_t *, ptrdiff_t, vint16mf4_t, vint16mf4_t, vint16mf4_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vssseg3e16_v_m)))
void vssseg3e16(vbool64_t, int16_t *, ptrdiff_t, vint16mf4_t, vint16mf4_t, vint16mf4_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vluxei32_v)))
vuint16m1_t vluxei32(const uint16_t *, vuint32m2_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vluxei32_v_m)))
vuint16m1_t vluxei32(vbool16_t, vuint16m1_t, const uint16_t *, vuint32m2_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vluxei32_v)))
vuint16m2_t vluxei32(const uint16_t *, vuint32m4_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vluxei32_v_m)))
vuint16m2_t vluxei32(vbool8_t, vuint16m2_t, const uint16_t *, vuint32m4_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vluxei32_v)))
vuint16m4_t vluxei32(const uint16_t *, vuint32m8_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vluxei32_v_m)))
vuint16m4_t vluxei32(vbool4_t, vuint16m4_t, const uint16_t *, vuint32m8_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vluxei32_v)))
vuint16mf2_t vluxei32(const uint16_t *, vuint32m1_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vluxei32_v_m)))
vuint16mf2_t vluxei32(vbool32_t, vuint16mf2_t, const uint16_t *, vuint32m1_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vluxei32_v)))
vuint16mf4_t vluxei32(const uint16_t *, vuint32mf2_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vluxei32_v_m)))
vuint16mf4_t vluxei32(vbool64_t, vuint16mf4_t, const uint16_t *, vuint32mf2_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vssseg3e16_v)))
void vssseg3e16(uint16_t *, ptrdiff_t, vuint16m1_t, vuint16m1_t, vuint16m1_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vssseg3e16_v_m)))
void vssseg3e16(vbool16_t, uint16_t *, ptrdiff_t, vuint16m1_t, vuint16m1_t, vuint16m1_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vssseg3e16_v)))
void vssseg3e16(uint16_t *, ptrdiff_t, vuint16m2_t, vuint16m2_t, vuint16m2_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vssseg3e16_v_m)))
void vssseg3e16(vbool8_t, uint16_t *, ptrdiff_t, vuint16m2_t, vuint16m2_t, vuint16m2_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vssseg3e16_v)))
void vssseg3e16(uint16_t *, ptrdiff_t, vuint16mf2_t, vuint16mf2_t, vuint16mf2_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vssseg3e16_v_m)))
void vssseg3e16(vbool32_t, uint16_t *, ptrdiff_t, vuint16mf2_t, vuint16mf2_t, vuint16mf2_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vssseg3e16_v)))
void vssseg3e16(uint16_t *, ptrdiff_t, vuint16mf4_t, vuint16mf4_t, vuint16mf4_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vssseg3e16_v_m)))
void vssseg3e16(vbool64_t, uint16_t *, ptrdiff_t, vuint16mf4_t, vuint16mf4_t, vuint16mf4_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vssseg4e16_v)))
void vssseg4e16(int16_t *, ptrdiff_t, vint16m1_t, vint16m1_t, vint16m1_t, vint16m1_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vssseg4e16_v_m)))
void vssseg4e16(vbool16_t, int16_t *, ptrdiff_t, vint16m1_t, vint16m1_t, vint16m1_t, vint16m1_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vssseg4e16_v)))
void vssseg4e16(int16_t *, ptrdiff_t, vint16m2_t, vint16m2_t, vint16m2_t, vint16m2_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vssseg4e16_v_m)))
void vssseg4e16(vbool8_t, int16_t *, ptrdiff_t, vint16m2_t, vint16m2_t, vint16m2_t, vint16m2_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vssseg4e16_v)))
void vssseg4e16(int16_t *, ptrdiff_t, vint16mf2_t, vint16mf2_t, vint16mf2_t, vint16mf2_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vssseg4e16_v_m)))
void vssseg4e16(vbool32_t, int16_t *, ptrdiff_t, vint16mf2_t, vint16mf2_t, vint16mf2_t, vint16mf2_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vssseg4e16_v)))
void vssseg4e16(int16_t *, ptrdiff_t, vint16mf4_t, vint16mf4_t, vint16mf4_t, vint16mf4_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vssseg4e16_v_m)))
void vssseg4e16(vbool64_t, int16_t *, ptrdiff_t, vint16mf4_t, vint16mf4_t, vint16mf4_t, vint16mf4_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vssseg4e16_v)))
void vssseg4e16(uint16_t *, ptrdiff_t, vuint16m1_t, vuint16m1_t, vuint16m1_t, vuint16m1_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vssseg4e16_v_m)))
void vssseg4e16(vbool16_t, uint16_t *, ptrdiff_t, vuint16m1_t, vuint16m1_t, vuint16m1_t, vuint16m1_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vssseg4e16_v)))
void vssseg4e16(uint16_t *, ptrdiff_t, vuint16m2_t, vuint16m2_t, vuint16m2_t, vuint16m2_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vssseg4e16_v_m)))
void vssseg4e16(vbool8_t, uint16_t *, ptrdiff_t, vuint16m2_t, vuint16m2_t, vuint16m2_t, vuint16m2_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vssseg4e16_v)))
void vssseg4e16(uint16_t *, ptrdiff_t, vuint16mf2_t, vuint16mf2_t, vuint16mf2_t, vuint16mf2_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vssseg4e16_v_m)))
void vssseg4e16(vbool32_t, uint16_t *, ptrdiff_t, vuint16mf2_t, vuint16mf2_t, vuint16mf2_t, vuint16mf2_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vssseg4e16_v)))
void vssseg4e16(uint16_t *, ptrdiff_t, vuint16mf4_t, vuint16mf4_t, vuint16mf4_t, vuint16mf4_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vssseg4e16_v_m)))
void vssseg4e16(vbool64_t, uint16_t *, ptrdiff_t, vuint16mf4_t, vuint16mf4_t, vuint16mf4_t, vuint16mf4_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vssseg5e16_v)))
void vssseg5e16(int16_t *, ptrdiff_t, vint16m1_t, vint16m1_t, vint16m1_t, vint16m1_t, vint16m1_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vssseg5e16_v_m)))
void vssseg5e16(vbool16_t, int16_t *, ptrdiff_t, vint16m1_t, vint16m1_t, vint16m1_t, vint16m1_t, vint16m1_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vssseg5e16_v)))
void vssseg5e16(int16_t *, ptrdiff_t, vint16mf2_t, vint16mf2_t, vint16mf2_t, vint16mf2_t, vint16mf2_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vssseg5e16_v_m)))
void vssseg5e16(vbool32_t, int16_t *, ptrdiff_t, vint16mf2_t, vint16mf2_t, vint16mf2_t, vint16mf2_t, vint16mf2_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vssseg5e16_v)))
void vssseg5e16(int16_t *, ptrdiff_t, vint16mf4_t, vint16mf4_t, vint16mf4_t, vint16mf4_t, vint16mf4_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vssseg5e16_v_m)))
void vssseg5e16(vbool64_t, int16_t *, ptrdiff_t, vint16mf4_t, vint16mf4_t, vint16mf4_t, vint16mf4_t, vint16mf4_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vssseg5e16_v)))
void vssseg5e16(uint16_t *, ptrdiff_t, vuint16m1_t, vuint16m1_t, vuint16m1_t, vuint16m1_t, vuint16m1_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vssseg5e16_v_m)))
void vssseg5e16(vbool16_t, uint16_t *, ptrdiff_t, vuint16m1_t, vuint16m1_t, vuint16m1_t, vuint16m1_t, vuint16m1_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vssseg5e16_v)))
void vssseg5e16(uint16_t *, ptrdiff_t, vuint16mf2_t, vuint16mf2_t, vuint16mf2_t, vuint16mf2_t, vuint16mf2_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vssseg5e16_v_m)))
void vssseg5e16(vbool32_t, uint16_t *, ptrdiff_t, vuint16mf2_t, vuint16mf2_t, vuint16mf2_t, vuint16mf2_t, vuint16mf2_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vssseg5e16_v)))
void vssseg5e16(uint16_t *, ptrdiff_t, vuint16mf4_t, vuint16mf4_t, vuint16mf4_t, vuint16mf4_t, vuint16mf4_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vssseg5e16_v_m)))
void vssseg5e16(vbool64_t, uint16_t *, ptrdiff_t, vuint16mf4_t, vuint16mf4_t, vuint16mf4_t, vuint16mf4_t, vuint16mf4_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vssseg6e16_v)))
void vssseg6e16(int16_t *, ptrdiff_t, vint16m1_t, vint16m1_t, vint16m1_t, vint16m1_t, vint16m1_t, vint16m1_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vssseg6e16_v_m)))
void vssseg6e16(vbool16_t, int16_t *, ptrdiff_t, vint16m1_t, vint16m1_t, vint16m1_t, vint16m1_t, vint16m1_t, vint16m1_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vssseg6e16_v)))
void vssseg6e16(int16_t *, ptrdiff_t, vint16mf2_t, vint16mf2_t, vint16mf2_t, vint16mf2_t, vint16mf2_t, vint16mf2_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vssseg6e16_v_m)))
void vssseg6e16(vbool32_t, int16_t *, ptrdiff_t, vint16mf2_t, vint16mf2_t, vint16mf2_t, vint16mf2_t, vint16mf2_t, vint16mf2_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vssseg6e16_v)))
void vssseg6e16(int16_t *, ptrdiff_t, vint16mf4_t, vint16mf4_t, vint16mf4_t, vint16mf4_t, vint16mf4_t, vint16mf4_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vssseg6e16_v_m)))
void vssseg6e16(vbool64_t, int16_t *, ptrdiff_t, vint16mf4_t, vint16mf4_t, vint16mf4_t, vint16mf4_t, vint16mf4_t, vint16mf4_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vssseg6e16_v)))
void vssseg6e16(uint16_t *, ptrdiff_t, vuint16m1_t, vuint16m1_t, vuint16m1_t, vuint16m1_t, vuint16m1_t, vuint16m1_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vssseg6e16_v_m)))
void vssseg6e16(vbool16_t, uint16_t *, ptrdiff_t, vuint16m1_t, vuint16m1_t, vuint16m1_t, vuint16m1_t, vuint16m1_t, vuint16m1_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vssseg6e16_v)))
void vssseg6e16(uint16_t *, ptrdiff_t, vuint16mf2_t, vuint16mf2_t, vuint16mf2_t, vuint16mf2_t, vuint16mf2_t, vuint16mf2_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vssseg6e16_v_m)))
void vssseg6e16(vbool32_t, uint16_t *, ptrdiff_t, vuint16mf2_t, vuint16mf2_t, vuint16mf2_t, vuint16mf2_t, vuint16mf2_t, vuint16mf2_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vssseg6e16_v)))
void vssseg6e16(uint16_t *, ptrdiff_t, vuint16mf4_t, vuint16mf4_t, vuint16mf4_t, vuint16mf4_t, vuint16mf4_t, vuint16mf4_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vssseg6e16_v_m)))
void vssseg6e16(vbool64_t, uint16_t *, ptrdiff_t, vuint16mf4_t, vuint16mf4_t, vuint16mf4_t, vuint16mf4_t, vuint16mf4_t, vuint16mf4_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vssseg7e16_v)))
void vssseg7e16(int16_t *, ptrdiff_t, vint16m1_t, vint16m1_t, vint16m1_t, vint16m1_t, vint16m1_t, vint16m1_t, vint16m1_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vssseg7e16_v_m)))
void vssseg7e16(vbool16_t, int16_t *, ptrdiff_t, vint16m1_t, vint16m1_t, vint16m1_t, vint16m1_t, vint16m1_t, vint16m1_t, vint16m1_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vssseg7e16_v)))
void vssseg7e16(int16_t *, ptrdiff_t, vint16mf2_t, vint16mf2_t, vint16mf2_t, vint16mf2_t, vint16mf2_t, vint16mf2_t, vint16mf2_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vssseg7e16_v_m)))
void vssseg7e16(vbool32_t, int16_t *, ptrdiff_t, vint16mf2_t, vint16mf2_t, vint16mf2_t, vint16mf2_t, vint16mf2_t, vint16mf2_t, vint16mf2_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vssseg7e16_v)))
void vssseg7e16(int16_t *, ptrdiff_t, vint16mf4_t, vint16mf4_t, vint16mf4_t, vint16mf4_t, vint16mf4_t, vint16mf4_t, vint16mf4_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vssseg7e16_v_m)))
void vssseg7e16(vbool64_t, int16_t *, ptrdiff_t, vint16mf4_t, vint16mf4_t, vint16mf4_t, vint16mf4_t, vint16mf4_t, vint16mf4_t, vint16mf4_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vssseg7e16_v)))
void vssseg7e16(uint16_t *, ptrdiff_t, vuint16m1_t, vuint16m1_t, vuint16m1_t, vuint16m1_t, vuint16m1_t, vuint16m1_t, vuint16m1_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vssseg7e16_v_m)))
void vssseg7e16(vbool16_t, uint16_t *, ptrdiff_t, vuint16m1_t, vuint16m1_t, vuint16m1_t, vuint16m1_t, vuint16m1_t, vuint16m1_t, vuint16m1_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vssseg7e16_v)))
void vssseg7e16(uint16_t *, ptrdiff_t, vuint16mf2_t, vuint16mf2_t, vuint16mf2_t, vuint16mf2_t, vuint16mf2_t, vuint16mf2_t, vuint16mf2_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vssseg7e16_v_m)))
void vssseg7e16(vbool32_t, uint16_t *, ptrdiff_t, vuint16mf2_t, vuint16mf2_t, vuint16mf2_t, vuint16mf2_t, vuint16mf2_t, vuint16mf2_t, vuint16mf2_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vssseg7e16_v)))
void vssseg7e16(uint16_t *, ptrdiff_t, vuint16mf4_t, vuint16mf4_t, vuint16mf4_t, vuint16mf4_t, vuint16mf4_t, vuint16mf4_t, vuint16mf4_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vssseg7e16_v_m)))
void vssseg7e16(vbool64_t, uint16_t *, ptrdiff_t, vuint16mf4_t, vuint16mf4_t, vuint16mf4_t, vuint16mf4_t, vuint16mf4_t, vuint16mf4_t, vuint16mf4_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vssseg8e16_v)))
void vssseg8e16(int16_t *, ptrdiff_t, vint16m1_t, vint16m1_t, vint16m1_t, vint16m1_t, vint16m1_t, vint16m1_t, vint16m1_t, vint16m1_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vssseg8e16_v_m)))
void vssseg8e16(vbool16_t, int16_t *, ptrdiff_t, vint16m1_t, vint16m1_t, vint16m1_t, vint16m1_t, vint16m1_t, vint16m1_t, vint16m1_t, vint16m1_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vssseg8e16_v)))
void vssseg8e16(int16_t *, ptrdiff_t, vint16mf2_t, vint16mf2_t, vint16mf2_t, vint16mf2_t, vint16mf2_t, vint16mf2_t, vint16mf2_t, vint16mf2_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vssseg8e16_v_m)))
void vssseg8e16(vbool32_t, int16_t *, ptrdiff_t, vint16mf2_t, vint16mf2_t, vint16mf2_t, vint16mf2_t, vint16mf2_t, vint16mf2_t, vint16mf2_t, vint16mf2_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vssseg8e16_v)))
void vssseg8e16(int16_t *, ptrdiff_t, vint16mf4_t, vint16mf4_t, vint16mf4_t, vint16mf4_t, vint16mf4_t, vint16mf4_t, vint16mf4_t, vint16mf4_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vssseg8e16_v_m)))
void vssseg8e16(vbool64_t, int16_t *, ptrdiff_t, vint16mf4_t, vint16mf4_t, vint16mf4_t, vint16mf4_t, vint16mf4_t, vint16mf4_t, vint16mf4_t, vint16mf4_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vssseg8e16_v)))
void vssseg8e16(uint16_t *, ptrdiff_t, vuint16m1_t, vuint16m1_t, vuint16m1_t, vuint16m1_t, vuint16m1_t, vuint16m1_t, vuint16m1_t, vuint16m1_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vssseg8e16_v_m)))
void vssseg8e16(vbool16_t, uint16_t *, ptrdiff_t, vuint16m1_t, vuint16m1_t, vuint16m1_t, vuint16m1_t, vuint16m1_t, vuint16m1_t, vuint16m1_t, vuint16m1_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vssseg8e16_v)))
void vssseg8e16(uint16_t *, ptrdiff_t, vuint16mf2_t, vuint16mf2_t, vuint16mf2_t, vuint16mf2_t, vuint16mf2_t, vuint16mf2_t, vuint16mf2_t, vuint16mf2_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vssseg8e16_v_m)))
void vssseg8e16(vbool32_t, uint16_t *, ptrdiff_t, vuint16mf2_t, vuint16mf2_t, vuint16mf2_t, vuint16mf2_t, vuint16mf2_t, vuint16mf2_t, vuint16mf2_t, vuint16mf2_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vssseg8e16_v)))
void vssseg8e16(uint16_t *, ptrdiff_t, vuint16mf4_t, vuint16mf4_t, vuint16mf4_t, vuint16mf4_t, vuint16mf4_t, vuint16mf4_t, vuint16mf4_t, vuint16mf4_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vssseg8e16_v_m)))
void vssseg8e16(vbool64_t, uint16_t *, ptrdiff_t, vuint16mf4_t, vuint16mf4_t, vuint16mf4_t, vuint16mf4_t, vuint16mf4_t, vuint16mf4_t, vuint16mf4_t, vuint16mf4_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vssseg2e32_v)))
void vssseg2e32(int32_t *, ptrdiff_t, vint32m1_t, vint32m1_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vssseg2e32_v_m)))
void vssseg2e32(vbool32_t, int32_t *, ptrdiff_t, vint32m1_t, vint32m1_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vssseg2e32_v)))
void vssseg2e32(int32_t *, ptrdiff_t, vint32m2_t, vint32m2_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vssseg2e32_v_m)))
void vssseg2e32(vbool16_t, int32_t *, ptrdiff_t, vint32m2_t, vint32m2_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vssseg2e32_v)))
void vssseg2e32(int32_t *, ptrdiff_t, vint32m4_t, vint32m4_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vssseg2e32_v_m)))
void vssseg2e32(vbool8_t, int32_t *, ptrdiff_t, vint32m4_t, vint32m4_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vssseg2e32_v)))
void vssseg2e32(int32_t *, ptrdiff_t, vint32mf2_t, vint32mf2_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vssseg2e32_v_m)))
void vssseg2e32(vbool64_t, int32_t *, ptrdiff_t, vint32mf2_t, vint32mf2_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vssseg2e32_v)))
void vssseg2e32(uint32_t *, ptrdiff_t, vuint32m1_t, vuint32m1_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vssseg2e32_v_m)))
void vssseg2e32(vbool32_t, uint32_t *, ptrdiff_t, vuint32m1_t, vuint32m1_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vssseg2e32_v)))
void vssseg2e32(uint32_t *, ptrdiff_t, vuint32m2_t, vuint32m2_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vssseg2e32_v_m)))
void vssseg2e32(vbool16_t, uint32_t *, ptrdiff_t, vuint32m2_t, vuint32m2_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vssseg2e32_v)))
void vssseg2e32(uint32_t *, ptrdiff_t, vuint32m4_t, vuint32m4_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vssseg2e32_v_m)))
void vssseg2e32(vbool8_t, uint32_t *, ptrdiff_t, vuint32m4_t, vuint32m4_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vssseg2e32_v)))
void vssseg2e32(uint32_t *, ptrdiff_t, vuint32mf2_t, vuint32mf2_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vssseg2e32_v_m)))
void vssseg2e32(vbool64_t, uint32_t *, ptrdiff_t, vuint32mf2_t, vuint32mf2_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vssseg3e32_v)))
void vssseg3e32(int32_t *, ptrdiff_t, vint32m1_t, vint32m1_t, vint32m1_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vssseg3e32_v_m)))
void vssseg3e32(vbool32_t, int32_t *, ptrdiff_t, vint32m1_t, vint32m1_t, vint32m1_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vssseg3e32_v)))
void vssseg3e32(int32_t *, ptrdiff_t, vint32m2_t, vint32m2_t, vint32m2_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vssseg3e32_v_m)))
void vssseg3e32(vbool16_t, int32_t *, ptrdiff_t, vint32m2_t, vint32m2_t, vint32m2_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vssseg3e32_v)))
void vssseg3e32(int32_t *, ptrdiff_t, vint32mf2_t, vint32mf2_t, vint32mf2_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vssseg3e32_v_m)))
void vssseg3e32(vbool64_t, int32_t *, ptrdiff_t, vint32mf2_t, vint32mf2_t, vint32mf2_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vssseg3e32_v)))
void vssseg3e32(uint32_t *, ptrdiff_t, vuint32m1_t, vuint32m1_t, vuint32m1_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vssseg3e32_v_m)))
void vssseg3e32(vbool32_t, uint32_t *, ptrdiff_t, vuint32m1_t, vuint32m1_t, vuint32m1_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vssseg3e32_v)))
void vssseg3e32(uint32_t *, ptrdiff_t, vuint32m2_t, vuint32m2_t, vuint32m2_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vssseg3e32_v_m)))
void vssseg3e32(vbool16_t, uint32_t *, ptrdiff_t, vuint32m2_t, vuint32m2_t, vuint32m2_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vssseg3e32_v)))
void vssseg3e32(uint32_t *, ptrdiff_t, vuint32mf2_t, vuint32mf2_t, vuint32mf2_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vssseg3e32_v_m)))
void vssseg3e32(vbool64_t, uint32_t *, ptrdiff_t, vuint32mf2_t, vuint32mf2_t, vuint32mf2_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vssseg4e32_v)))
void vssseg4e32(int32_t *, ptrdiff_t, vint32m1_t, vint32m1_t, vint32m1_t, vint32m1_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vssseg4e32_v_m)))
void vssseg4e32(vbool32_t, int32_t *, ptrdiff_t, vint32m1_t, vint32m1_t, vint32m1_t, vint32m1_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vssseg4e32_v)))
void vssseg4e32(int32_t *, ptrdiff_t, vint32m2_t, vint32m2_t, vint32m2_t, vint32m2_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vssseg4e32_v_m)))
void vssseg4e32(vbool16_t, int32_t *, ptrdiff_t, vint32m2_t, vint32m2_t, vint32m2_t, vint32m2_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vssseg4e32_v)))
void vssseg4e32(int32_t *, ptrdiff_t, vint32mf2_t, vint32mf2_t, vint32mf2_t, vint32mf2_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vssseg4e32_v_m)))
void vssseg4e32(vbool64_t, int32_t *, ptrdiff_t, vint32mf2_t, vint32mf2_t, vint32mf2_t, vint32mf2_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vssseg4e32_v)))
void vssseg4e32(uint32_t *, ptrdiff_t, vuint32m1_t, vuint32m1_t, vuint32m1_t, vuint32m1_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vssseg4e32_v_m)))
void vssseg4e32(vbool32_t, uint32_t *, ptrdiff_t, vuint32m1_t, vuint32m1_t, vuint32m1_t, vuint32m1_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vssseg4e32_v)))
void vssseg4e32(uint32_t *, ptrdiff_t, vuint32m2_t, vuint32m2_t, vuint32m2_t, vuint32m2_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vssseg4e32_v_m)))
void vssseg4e32(vbool16_t, uint32_t *, ptrdiff_t, vuint32m2_t, vuint32m2_t, vuint32m2_t, vuint32m2_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vssseg4e32_v)))
void vssseg4e32(uint32_t *, ptrdiff_t, vuint32mf2_t, vuint32mf2_t, vuint32mf2_t, vuint32mf2_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vssseg4e32_v_m)))
void vssseg4e32(vbool64_t, uint32_t *, ptrdiff_t, vuint32mf2_t, vuint32mf2_t, vuint32mf2_t, vuint32mf2_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vssseg5e32_v)))
void vssseg5e32(int32_t *, ptrdiff_t, vint32m1_t, vint32m1_t, vint32m1_t, vint32m1_t, vint32m1_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vssseg5e32_v_m)))
void vssseg5e32(vbool32_t, int32_t *, ptrdiff_t, vint32m1_t, vint32m1_t, vint32m1_t, vint32m1_t, vint32m1_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vssseg5e32_v)))
void vssseg5e32(int32_t *, ptrdiff_t, vint32mf2_t, vint32mf2_t, vint32mf2_t, vint32mf2_t, vint32mf2_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vssseg5e32_v_m)))
void vssseg5e32(vbool64_t, int32_t *, ptrdiff_t, vint32mf2_t, vint32mf2_t, vint32mf2_t, vint32mf2_t, vint32mf2_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vssseg5e32_v)))
void vssseg5e32(uint32_t *, ptrdiff_t, vuint32m1_t, vuint32m1_t, vuint32m1_t, vuint32m1_t, vuint32m1_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vssseg5e32_v_m)))
void vssseg5e32(vbool32_t, uint32_t *, ptrdiff_t, vuint32m1_t, vuint32m1_t, vuint32m1_t, vuint32m1_t, vuint32m1_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vssseg5e32_v)))
void vssseg5e32(uint32_t *, ptrdiff_t, vuint32mf2_t, vuint32mf2_t, vuint32mf2_t, vuint32mf2_t, vuint32mf2_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vssseg5e32_v_m)))
void vssseg5e32(vbool64_t, uint32_t *, ptrdiff_t, vuint32mf2_t, vuint32mf2_t, vuint32mf2_t, vuint32mf2_t, vuint32mf2_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vssseg6e32_v)))
void vssseg6e32(int32_t *, ptrdiff_t, vint32m1_t, vint32m1_t, vint32m1_t, vint32m1_t, vint32m1_t, vint32m1_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vssseg6e32_v_m)))
void vssseg6e32(vbool32_t, int32_t *, ptrdiff_t, vint32m1_t, vint32m1_t, vint32m1_t, vint32m1_t, vint32m1_t, vint32m1_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vssseg6e32_v)))
void vssseg6e32(int32_t *, ptrdiff_t, vint32mf2_t, vint32mf2_t, vint32mf2_t, vint32mf2_t, vint32mf2_t, vint32mf2_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vssseg6e32_v_m)))
void vssseg6e32(vbool64_t, int32_t *, ptrdiff_t, vint32mf2_t, vint32mf2_t, vint32mf2_t, vint32mf2_t, vint32mf2_t, vint32mf2_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vssseg6e32_v)))
void vssseg6e32(uint32_t *, ptrdiff_t, vuint32m1_t, vuint32m1_t, vuint32m1_t, vuint32m1_t, vuint32m1_t, vuint32m1_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vssseg6e32_v_m)))
void vssseg6e32(vbool32_t, uint32_t *, ptrdiff_t, vuint32m1_t, vuint32m1_t, vuint32m1_t, vuint32m1_t, vuint32m1_t, vuint32m1_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vssseg6e32_v)))
void vssseg6e32(uint32_t *, ptrdiff_t, vuint32mf2_t, vuint32mf2_t, vuint32mf2_t, vuint32mf2_t, vuint32mf2_t, vuint32mf2_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vssseg6e32_v_m)))
void vssseg6e32(vbool64_t, uint32_t *, ptrdiff_t, vuint32mf2_t, vuint32mf2_t, vuint32mf2_t, vuint32mf2_t, vuint32mf2_t, vuint32mf2_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vssseg7e32_v)))
void vssseg7e32(int32_t *, ptrdiff_t, vint32m1_t, vint32m1_t, vint32m1_t, vint32m1_t, vint32m1_t, vint32m1_t, vint32m1_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vssseg7e32_v_m)))
void vssseg7e32(vbool32_t, int32_t *, ptrdiff_t, vint32m1_t, vint32m1_t, vint32m1_t, vint32m1_t, vint32m1_t, vint32m1_t, vint32m1_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vssseg7e32_v)))
void vssseg7e32(int32_t *, ptrdiff_t, vint32mf2_t, vint32mf2_t, vint32mf2_t, vint32mf2_t, vint32mf2_t, vint32mf2_t, vint32mf2_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vssseg7e32_v_m)))
void vssseg7e32(vbool64_t, int32_t *, ptrdiff_t, vint32mf2_t, vint32mf2_t, vint32mf2_t, vint32mf2_t, vint32mf2_t, vint32mf2_t, vint32mf2_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vssseg7e32_v)))
void vssseg7e32(uint32_t *, ptrdiff_t, vuint32m1_t, vuint32m1_t, vuint32m1_t, vuint32m1_t, vuint32m1_t, vuint32m1_t, vuint32m1_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vssseg7e32_v_m)))
void vssseg7e32(vbool32_t, uint32_t *, ptrdiff_t, vuint32m1_t, vuint32m1_t, vuint32m1_t, vuint32m1_t, vuint32m1_t, vuint32m1_t, vuint32m1_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vssseg7e32_v)))
void vssseg7e32(uint32_t *, ptrdiff_t, vuint32mf2_t, vuint32mf2_t, vuint32mf2_t, vuint32mf2_t, vuint32mf2_t, vuint32mf2_t, vuint32mf2_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vssseg7e32_v_m)))
void vssseg7e32(vbool64_t, uint32_t *, ptrdiff_t, vuint32mf2_t, vuint32mf2_t, vuint32mf2_t, vuint32mf2_t, vuint32mf2_t, vuint32mf2_t, vuint32mf2_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vssseg8e32_v)))
void vssseg8e32(int32_t *, ptrdiff_t, vint32m1_t, vint32m1_t, vint32m1_t, vint32m1_t, vint32m1_t, vint32m1_t, vint32m1_t, vint32m1_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vssseg8e32_v_m)))
void vssseg8e32(vbool32_t, int32_t *, ptrdiff_t, vint32m1_t, vint32m1_t, vint32m1_t, vint32m1_t, vint32m1_t, vint32m1_t, vint32m1_t, vint32m1_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vssseg8e32_v)))
void vssseg8e32(int32_t *, ptrdiff_t, vint32mf2_t, vint32mf2_t, vint32mf2_t, vint32mf2_t, vint32mf2_t, vint32mf2_t, vint32mf2_t, vint32mf2_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vssseg8e32_v_m)))
void vssseg8e32(vbool64_t, int32_t *, ptrdiff_t, vint32mf2_t, vint32mf2_t, vint32mf2_t, vint32mf2_t, vint32mf2_t, vint32mf2_t, vint32mf2_t, vint32mf2_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vssseg8e32_v)))
void vssseg8e32(uint32_t *, ptrdiff_t, vuint32m1_t, vuint32m1_t, vuint32m1_t, vuint32m1_t, vuint32m1_t, vuint32m1_t, vuint32m1_t, vuint32m1_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vssseg8e32_v_m)))
void vssseg8e32(vbool32_t, uint32_t *, ptrdiff_t, vuint32m1_t, vuint32m1_t, vuint32m1_t, vuint32m1_t, vuint32m1_t, vuint32m1_t, vuint32m1_t, vuint32m1_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vssseg8e32_v)))
void vssseg8e32(uint32_t *, ptrdiff_t, vuint32mf2_t, vuint32mf2_t, vuint32mf2_t, vuint32mf2_t, vuint32mf2_t, vuint32mf2_t, vuint32mf2_t, vuint32mf2_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vssseg8e32_v_m)))
void vssseg8e32(vbool64_t, uint32_t *, ptrdiff_t, vuint32mf2_t, vuint32mf2_t, vuint32mf2_t, vuint32mf2_t, vuint32mf2_t, vuint32mf2_t, vuint32mf2_t, vuint32mf2_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vluxei8_v)))
vint32m1_t vluxei8(const int32_t *, vuint8mf4_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vluxei8_v_m)))
vint32m1_t vluxei8(vbool32_t, vint32m1_t, const int32_t *, vuint8mf4_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vluxei8_v)))
vint32m2_t vluxei8(const int32_t *, vuint8mf2_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vluxei8_v_m)))
vint32m2_t vluxei8(vbool16_t, vint32m2_t, const int32_t *, vuint8mf2_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vluxei8_v)))
vint32m4_t vluxei8(const int32_t *, vuint8m1_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vluxei8_v_m)))
vint32m4_t vluxei8(vbool8_t, vint32m4_t, const int32_t *, vuint8m1_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vluxei8_v)))
vint32m8_t vluxei8(const int32_t *, vuint8m2_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vluxei8_v_m)))
vint32m8_t vluxei8(vbool4_t, vint32m8_t, const int32_t *, vuint8m2_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vluxei8_v)))
vint32mf2_t vluxei8(const int32_t *, vuint8mf8_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vluxei8_v_m)))
vint32mf2_t vluxei8(vbool64_t, vint32mf2_t, const int32_t *, vuint8mf8_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vluxei8_v)))
vuint32m1_t vluxei8(const uint32_t *, vuint8mf4_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vluxei8_v_m)))
vuint32m1_t vluxei8(vbool32_t, vuint32m1_t, const uint32_t *, vuint8mf4_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vluxei8_v)))
vuint32m2_t vluxei8(const uint32_t *, vuint8mf2_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vluxei8_v_m)))
vuint32m2_t vluxei8(vbool16_t, vuint32m2_t, const uint32_t *, vuint8mf2_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vluxei8_v)))
vuint32m4_t vluxei8(const uint32_t *, vuint8m1_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vluxei8_v_m)))
vuint32m4_t vluxei8(vbool8_t, vuint32m4_t, const uint32_t *, vuint8m1_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vluxei8_v)))
vuint32m8_t vluxei8(const uint32_t *, vuint8m2_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vluxei8_v_m)))
vuint32m8_t vluxei8(vbool4_t, vuint32m8_t, const uint32_t *, vuint8m2_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vluxei8_v)))
vuint32mf2_t vluxei8(const uint32_t *, vuint8mf8_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vluxei8_v_m)))
vuint32mf2_t vluxei8(vbool64_t, vuint32mf2_t, const uint32_t *, vuint8mf8_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vluxei16_v)))
vint32m1_t vluxei16(const int32_t *, vuint16mf2_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vluxei16_v_m)))
vint32m1_t vluxei16(vbool32_t, vint32m1_t, const int32_t *, vuint16mf2_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vluxei16_v)))
vint32m2_t vluxei16(const int32_t *, vuint16m1_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vluxei16_v_m)))
vint32m2_t vluxei16(vbool16_t, vint32m2_t, const int32_t *, vuint16m1_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vluxei16_v)))
vint32m4_t vluxei16(const int32_t *, vuint16m2_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vluxei16_v_m)))
vint32m4_t vluxei16(vbool8_t, vint32m4_t, const int32_t *, vuint16m2_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vluxei16_v)))
vint32m8_t vluxei16(const int32_t *, vuint16m4_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vluxei16_v_m)))
vint32m8_t vluxei16(vbool4_t, vint32m8_t, const int32_t *, vuint16m4_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vluxei16_v)))
vint32mf2_t vluxei16(const int32_t *, vuint16mf4_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vluxei16_v_m)))
vint32mf2_t vluxei16(vbool64_t, vint32mf2_t, const int32_t *, vuint16mf4_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vluxei16_v)))
vuint32m1_t vluxei16(const uint32_t *, vuint16mf2_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vluxei16_v_m)))
vuint32m1_t vluxei16(vbool32_t, vuint32m1_t, const uint32_t *, vuint16mf2_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vluxei16_v)))
vuint32m2_t vluxei16(const uint32_t *, vuint16m1_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vluxei16_v_m)))
vuint32m2_t vluxei16(vbool16_t, vuint32m2_t, const uint32_t *, vuint16m1_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vluxei16_v)))
vuint32m4_t vluxei16(const uint32_t *, vuint16m2_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vluxei16_v_m)))
vuint32m4_t vluxei16(vbool8_t, vuint32m4_t, const uint32_t *, vuint16m2_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vluxei16_v)))
vuint32m8_t vluxei16(const uint32_t *, vuint16m4_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vluxei16_v_m)))
vuint32m8_t vluxei16(vbool4_t, vuint32m8_t, const uint32_t *, vuint16m4_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vluxei16_v)))
vuint32mf2_t vluxei16(const uint32_t *, vuint16mf4_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vluxei16_v_m)))
vuint32mf2_t vluxei16(vbool64_t, vuint32mf2_t, const uint32_t *, vuint16mf4_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vsuxseg3ei8_v)))
void vsuxseg3ei8(int8_t *, vuint8m1_t, vint8m1_t, vint8m1_t, vint8m1_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vsuxseg3ei8_v_m)))
void vsuxseg3ei8(vbool8_t, int8_t *, vuint8m1_t, vint8m1_t, vint8m1_t, vint8m1_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vsuxseg3ei8_v)))
void vsuxseg3ei8(int8_t *, vuint8m2_t, vint8m2_t, vint8m2_t, vint8m2_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vsuxseg3ei8_v_m)))
void vsuxseg3ei8(vbool4_t, int8_t *, vuint8m2_t, vint8m2_t, vint8m2_t, vint8m2_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vsuxseg3ei8_v)))
void vsuxseg3ei8(int8_t *, vuint8mf2_t, vint8mf2_t, vint8mf2_t, vint8mf2_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vsuxseg3ei8_v_m)))
void vsuxseg3ei8(vbool16_t, int8_t *, vuint8mf2_t, vint8mf2_t, vint8mf2_t, vint8mf2_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vsuxseg3ei8_v)))
void vsuxseg3ei8(int8_t *, vuint8mf4_t, vint8mf4_t, vint8mf4_t, vint8mf4_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vsuxseg3ei8_v_m)))
void vsuxseg3ei8(vbool32_t, int8_t *, vuint8mf4_t, vint8mf4_t, vint8mf4_t, vint8mf4_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vsuxseg3ei8_v)))
void vsuxseg3ei8(int8_t *, vuint8mf8_t, vint8mf8_t, vint8mf8_t, vint8mf8_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vsuxseg3ei8_v_m)))
void vsuxseg3ei8(vbool64_t, int8_t *, vuint8mf8_t, vint8mf8_t, vint8mf8_t, vint8mf8_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vsuxseg3ei8_v)))
void vsuxseg3ei8(uint8_t *, vuint8m1_t, vuint8m1_t, vuint8m1_t, vuint8m1_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vsuxseg3ei8_v_m)))
void vsuxseg3ei8(vbool8_t, uint8_t *, vuint8m1_t, vuint8m1_t, vuint8m1_t, vuint8m1_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vsuxseg3ei8_v)))
void vsuxseg3ei8(uint8_t *, vuint8m2_t, vuint8m2_t, vuint8m2_t, vuint8m2_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vsuxseg3ei8_v_m)))
void vsuxseg3ei8(vbool4_t, uint8_t *, vuint8m2_t, vuint8m2_t, vuint8m2_t, vuint8m2_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vsuxseg3ei8_v)))
void vsuxseg3ei8(uint8_t *, vuint8mf2_t, vuint8mf2_t, vuint8mf2_t, vuint8mf2_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vsuxseg3ei8_v_m)))
void vsuxseg3ei8(vbool16_t, uint8_t *, vuint8mf2_t, vuint8mf2_t, vuint8mf2_t, vuint8mf2_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vsuxseg3ei8_v)))
void vsuxseg3ei8(uint8_t *, vuint8mf4_t, vuint8mf4_t, vuint8mf4_t, vuint8mf4_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vsuxseg3ei8_v_m)))
void vsuxseg3ei8(vbool32_t, uint8_t *, vuint8mf4_t, vuint8mf4_t, vuint8mf4_t, vuint8mf4_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vsuxseg3ei8_v)))
void vsuxseg3ei8(uint8_t *, vuint8mf8_t, vuint8mf8_t, vuint8mf8_t, vuint8mf8_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vsuxseg3ei8_v_m)))
void vsuxseg3ei8(vbool64_t, uint8_t *, vuint8mf8_t, vuint8mf8_t, vuint8mf8_t, vuint8mf8_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vsuxseg4ei8_v)))
void vsuxseg4ei8(int8_t *, vuint8m1_t, vint8m1_t, vint8m1_t, vint8m1_t, vint8m1_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vsuxseg4ei8_v_m)))
void vsuxseg4ei8(vbool8_t, int8_t *, vuint8m1_t, vint8m1_t, vint8m1_t, vint8m1_t, vint8m1_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vsuxseg4ei8_v)))
void vsuxseg4ei8(int8_t *, vuint8m2_t, vint8m2_t, vint8m2_t, vint8m2_t, vint8m2_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vsuxseg4ei8_v_m)))
void vsuxseg4ei8(vbool4_t, int8_t *, vuint8m2_t, vint8m2_t, vint8m2_t, vint8m2_t, vint8m2_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vsuxseg4ei8_v)))
void vsuxseg4ei8(int8_t *, vuint8mf2_t, vint8mf2_t, vint8mf2_t, vint8mf2_t, vint8mf2_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vsuxseg4ei8_v_m)))
void vsuxseg4ei8(vbool16_t, int8_t *, vuint8mf2_t, vint8mf2_t, vint8mf2_t, vint8mf2_t, vint8mf2_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vsuxseg4ei8_v)))
void vsuxseg4ei8(int8_t *, vuint8mf4_t, vint8mf4_t, vint8mf4_t, vint8mf4_t, vint8mf4_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vsuxseg4ei8_v_m)))
void vsuxseg4ei8(vbool32_t, int8_t *, vuint8mf4_t, vint8mf4_t, vint8mf4_t, vint8mf4_t, vint8mf4_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vsuxseg4ei8_v)))
void vsuxseg4ei8(int8_t *, vuint8mf8_t, vint8mf8_t, vint8mf8_t, vint8mf8_t, vint8mf8_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vsuxseg4ei8_v_m)))
void vsuxseg4ei8(vbool64_t, int8_t *, vuint8mf8_t, vint8mf8_t, vint8mf8_t, vint8mf8_t, vint8mf8_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vsuxseg4ei8_v)))
void vsuxseg4ei8(uint8_t *, vuint8m1_t, vuint8m1_t, vuint8m1_t, vuint8m1_t, vuint8m1_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vsuxseg4ei8_v_m)))
void vsuxseg4ei8(vbool8_t, uint8_t *, vuint8m1_t, vuint8m1_t, vuint8m1_t, vuint8m1_t, vuint8m1_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vsuxseg4ei8_v)))
void vsuxseg4ei8(uint8_t *, vuint8m2_t, vuint8m2_t, vuint8m2_t, vuint8m2_t, vuint8m2_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vsuxseg4ei8_v_m)))
void vsuxseg4ei8(vbool4_t, uint8_t *, vuint8m2_t, vuint8m2_t, vuint8m2_t, vuint8m2_t, vuint8m2_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vsuxseg4ei8_v)))
void vsuxseg4ei8(uint8_t *, vuint8mf2_t, vuint8mf2_t, vuint8mf2_t, vuint8mf2_t, vuint8mf2_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vsuxseg4ei8_v_m)))
void vsuxseg4ei8(vbool16_t, uint8_t *, vuint8mf2_t, vuint8mf2_t, vuint8mf2_t, vuint8mf2_t, vuint8mf2_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vsuxseg4ei8_v)))
void vsuxseg4ei8(uint8_t *, vuint8mf4_t, vuint8mf4_t, vuint8mf4_t, vuint8mf4_t, vuint8mf4_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vsuxseg4ei8_v_m)))
void vsuxseg4ei8(vbool32_t, uint8_t *, vuint8mf4_t, vuint8mf4_t, vuint8mf4_t, vuint8mf4_t, vuint8mf4_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vsuxseg4ei8_v)))
void vsuxseg4ei8(uint8_t *, vuint8mf8_t, vuint8mf8_t, vuint8mf8_t, vuint8mf8_t, vuint8mf8_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vsuxseg4ei8_v_m)))
void vsuxseg4ei8(vbool64_t, uint8_t *, vuint8mf8_t, vuint8mf8_t, vuint8mf8_t, vuint8mf8_t, vuint8mf8_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vsuxseg5ei8_v)))
void vsuxseg5ei8(int8_t *, vuint8m1_t, vint8m1_t, vint8m1_t, vint8m1_t, vint8m1_t, vint8m1_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vsuxseg5ei8_v_m)))
void vsuxseg5ei8(vbool8_t, int8_t *, vuint8m1_t, vint8m1_t, vint8m1_t, vint8m1_t, vint8m1_t, vint8m1_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vsuxseg5ei8_v)))
void vsuxseg5ei8(int8_t *, vuint8mf2_t, vint8mf2_t, vint8mf2_t, vint8mf2_t, vint8mf2_t, vint8mf2_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vsuxseg5ei8_v_m)))
void vsuxseg5ei8(vbool16_t, int8_t *, vuint8mf2_t, vint8mf2_t, vint8mf2_t, vint8mf2_t, vint8mf2_t, vint8mf2_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vsuxseg5ei8_v)))
void vsuxseg5ei8(int8_t *, vuint8mf4_t, vint8mf4_t, vint8mf4_t, vint8mf4_t, vint8mf4_t, vint8mf4_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vsuxseg5ei8_v_m)))
void vsuxseg5ei8(vbool32_t, int8_t *, vuint8mf4_t, vint8mf4_t, vint8mf4_t, vint8mf4_t, vint8mf4_t, vint8mf4_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vsuxseg5ei8_v)))
void vsuxseg5ei8(int8_t *, vuint8mf8_t, vint8mf8_t, vint8mf8_t, vint8mf8_t, vint8mf8_t, vint8mf8_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vsuxseg5ei8_v_m)))
void vsuxseg5ei8(vbool64_t, int8_t *, vuint8mf8_t, vint8mf8_t, vint8mf8_t, vint8mf8_t, vint8mf8_t, vint8mf8_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vsuxseg5ei8_v)))
void vsuxseg5ei8(uint8_t *, vuint8m1_t, vuint8m1_t, vuint8m1_t, vuint8m1_t, vuint8m1_t, vuint8m1_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vsuxseg5ei8_v_m)))
void vsuxseg5ei8(vbool8_t, uint8_t *, vuint8m1_t, vuint8m1_t, vuint8m1_t, vuint8m1_t, vuint8m1_t, vuint8m1_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vsuxseg5ei8_v)))
void vsuxseg5ei8(uint8_t *, vuint8mf2_t, vuint8mf2_t, vuint8mf2_t, vuint8mf2_t, vuint8mf2_t, vuint8mf2_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vsuxseg5ei8_v_m)))
void vsuxseg5ei8(vbool16_t, uint8_t *, vuint8mf2_t, vuint8mf2_t, vuint8mf2_t, vuint8mf2_t, vuint8mf2_t, vuint8mf2_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vsuxseg5ei8_v)))
void vsuxseg5ei8(uint8_t *, vuint8mf4_t, vuint8mf4_t, vuint8mf4_t, vuint8mf4_t, vuint8mf4_t, vuint8mf4_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vsuxseg5ei8_v_m)))
void vsuxseg5ei8(vbool32_t, uint8_t *, vuint8mf4_t, vuint8mf4_t, vuint8mf4_t, vuint8mf4_t, vuint8mf4_t, vuint8mf4_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vsuxseg5ei8_v)))
void vsuxseg5ei8(uint8_t *, vuint8mf8_t, vuint8mf8_t, vuint8mf8_t, vuint8mf8_t, vuint8mf8_t, vuint8mf8_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vsuxseg5ei8_v_m)))
void vsuxseg5ei8(vbool64_t, uint8_t *, vuint8mf8_t, vuint8mf8_t, vuint8mf8_t, vuint8mf8_t, vuint8mf8_t, vuint8mf8_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vsuxseg6ei8_v)))
void vsuxseg6ei8(int8_t *, vuint8m1_t, vint8m1_t, vint8m1_t, vint8m1_t, vint8m1_t, vint8m1_t, vint8m1_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vsuxseg6ei8_v_m)))
void vsuxseg6ei8(vbool8_t, int8_t *, vuint8m1_t, vint8m1_t, vint8m1_t, vint8m1_t, vint8m1_t, vint8m1_t, vint8m1_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vsuxseg6ei8_v)))
void vsuxseg6ei8(int8_t *, vuint8mf2_t, vint8mf2_t, vint8mf2_t, vint8mf2_t, vint8mf2_t, vint8mf2_t, vint8mf2_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vsuxseg6ei8_v_m)))
void vsuxseg6ei8(vbool16_t, int8_t *, vuint8mf2_t, vint8mf2_t, vint8mf2_t, vint8mf2_t, vint8mf2_t, vint8mf2_t, vint8mf2_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vsuxseg6ei8_v)))
void vsuxseg6ei8(int8_t *, vuint8mf4_t, vint8mf4_t, vint8mf4_t, vint8mf4_t, vint8mf4_t, vint8mf4_t, vint8mf4_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vsuxseg6ei8_v_m)))
void vsuxseg6ei8(vbool32_t, int8_t *, vuint8mf4_t, vint8mf4_t, vint8mf4_t, vint8mf4_t, vint8mf4_t, vint8mf4_t, vint8mf4_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vsuxseg6ei8_v)))
void vsuxseg6ei8(int8_t *, vuint8mf8_t, vint8mf8_t, vint8mf8_t, vint8mf8_t, vint8mf8_t, vint8mf8_t, vint8mf8_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vsuxseg6ei8_v_m)))
void vsuxseg6ei8(vbool64_t, int8_t *, vuint8mf8_t, vint8mf8_t, vint8mf8_t, vint8mf8_t, vint8mf8_t, vint8mf8_t, vint8mf8_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vsuxseg6ei8_v)))
void vsuxseg6ei8(uint8_t *, vuint8m1_t, vuint8m1_t, vuint8m1_t, vuint8m1_t, vuint8m1_t, vuint8m1_t, vuint8m1_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vsuxseg6ei8_v_m)))
void vsuxseg6ei8(vbool8_t, uint8_t *, vuint8m1_t, vuint8m1_t, vuint8m1_t, vuint8m1_t, vuint8m1_t, vuint8m1_t, vuint8m1_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vsuxseg6ei8_v)))
void vsuxseg6ei8(uint8_t *, vuint8mf2_t, vuint8mf2_t, vuint8mf2_t, vuint8mf2_t, vuint8mf2_t, vuint8mf2_t, vuint8mf2_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vsuxseg6ei8_v_m)))
void vsuxseg6ei8(vbool16_t, uint8_t *, vuint8mf2_t, vuint8mf2_t, vuint8mf2_t, vuint8mf2_t, vuint8mf2_t, vuint8mf2_t, vuint8mf2_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vsuxseg6ei8_v)))
void vsuxseg6ei8(uint8_t *, vuint8mf4_t, vuint8mf4_t, vuint8mf4_t, vuint8mf4_t, vuint8mf4_t, vuint8mf4_t, vuint8mf4_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vsuxseg6ei8_v_m)))
void vsuxseg6ei8(vbool32_t, uint8_t *, vuint8mf4_t, vuint8mf4_t, vuint8mf4_t, vuint8mf4_t, vuint8mf4_t, vuint8mf4_t, vuint8mf4_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vsuxseg6ei8_v)))
void vsuxseg6ei8(uint8_t *, vuint8mf8_t, vuint8mf8_t, vuint8mf8_t, vuint8mf8_t, vuint8mf8_t, vuint8mf8_t, vuint8mf8_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vsuxseg6ei8_v_m)))
void vsuxseg6ei8(vbool64_t, uint8_t *, vuint8mf8_t, vuint8mf8_t, vuint8mf8_t, vuint8mf8_t, vuint8mf8_t, vuint8mf8_t, vuint8mf8_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vsuxseg7ei8_v)))
void vsuxseg7ei8(int8_t *, vuint8m1_t, vint8m1_t, vint8m1_t, vint8m1_t, vint8m1_t, vint8m1_t, vint8m1_t, vint8m1_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vsuxseg7ei8_v_m)))
void vsuxseg7ei8(vbool8_t, int8_t *, vuint8m1_t, vint8m1_t, vint8m1_t, vint8m1_t, vint8m1_t, vint8m1_t, vint8m1_t, vint8m1_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vsuxseg7ei8_v)))
void vsuxseg7ei8(int8_t *, vuint8mf2_t, vint8mf2_t, vint8mf2_t, vint8mf2_t, vint8mf2_t, vint8mf2_t, vint8mf2_t, vint8mf2_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vsuxseg7ei8_v_m)))
void vsuxseg7ei8(vbool16_t, int8_t *, vuint8mf2_t, vint8mf2_t, vint8mf2_t, vint8mf2_t, vint8mf2_t, vint8mf2_t, vint8mf2_t, vint8mf2_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vsuxseg7ei8_v)))
void vsuxseg7ei8(int8_t *, vuint8mf4_t, vint8mf4_t, vint8mf4_t, vint8mf4_t, vint8mf4_t, vint8mf4_t, vint8mf4_t, vint8mf4_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vsuxseg7ei8_v_m)))
void vsuxseg7ei8(vbool32_t, int8_t *, vuint8mf4_t, vint8mf4_t, vint8mf4_t, vint8mf4_t, vint8mf4_t, vint8mf4_t, vint8mf4_t, vint8mf4_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vsuxseg7ei8_v)))
void vsuxseg7ei8(int8_t *, vuint8mf8_t, vint8mf8_t, vint8mf8_t, vint8mf8_t, vint8mf8_t, vint8mf8_t, vint8mf8_t, vint8mf8_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vsuxseg7ei8_v_m)))
void vsuxseg7ei8(vbool64_t, int8_t *, vuint8mf8_t, vint8mf8_t, vint8mf8_t, vint8mf8_t, vint8mf8_t, vint8mf8_t, vint8mf8_t, vint8mf8_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vluxei32_v)))
vint32m1_t vluxei32(const int32_t *, vuint32m1_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vluxei32_v_m)))
vint32m1_t vluxei32(vbool32_t, vint32m1_t, const int32_t *, vuint32m1_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vluxei32_v)))
vint32m2_t vluxei32(const int32_t *, vuint32m2_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vluxei32_v_m)))
vint32m2_t vluxei32(vbool16_t, vint32m2_t, const int32_t *, vuint32m2_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vluxei32_v)))
vint32m4_t vluxei32(const int32_t *, vuint32m4_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vluxei32_v_m)))
vint32m4_t vluxei32(vbool8_t, vint32m4_t, const int32_t *, vuint32m4_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vluxei32_v)))
vint32m8_t vluxei32(const int32_t *, vuint32m8_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vluxei32_v_m)))
vint32m8_t vluxei32(vbool4_t, vint32m8_t, const int32_t *, vuint32m8_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vluxei32_v)))
vint32mf2_t vluxei32(const int32_t *, vuint32mf2_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vluxei32_v_m)))
vint32mf2_t vluxei32(vbool64_t, vint32mf2_t, const int32_t *, vuint32mf2_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vsuxseg7ei8_v)))
void vsuxseg7ei8(uint8_t *, vuint8m1_t, vuint8m1_t, vuint8m1_t, vuint8m1_t, vuint8m1_t, vuint8m1_t, vuint8m1_t, vuint8m1_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vsuxseg7ei8_v_m)))
void vsuxseg7ei8(vbool8_t, uint8_t *, vuint8m1_t, vuint8m1_t, vuint8m1_t, vuint8m1_t, vuint8m1_t, vuint8m1_t, vuint8m1_t, vuint8m1_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vsuxseg7ei8_v)))
void vsuxseg7ei8(uint8_t *, vuint8mf2_t, vuint8mf2_t, vuint8mf2_t, vuint8mf2_t, vuint8mf2_t, vuint8mf2_t, vuint8mf2_t, vuint8mf2_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vsuxseg7ei8_v_m)))
void vsuxseg7ei8(vbool16_t, uint8_t *, vuint8mf2_t, vuint8mf2_t, vuint8mf2_t, vuint8mf2_t, vuint8mf2_t, vuint8mf2_t, vuint8mf2_t, vuint8mf2_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vsuxseg7ei8_v)))
void vsuxseg7ei8(uint8_t *, vuint8mf4_t, vuint8mf4_t, vuint8mf4_t, vuint8mf4_t, vuint8mf4_t, vuint8mf4_t, vuint8mf4_t, vuint8mf4_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vsuxseg7ei8_v_m)))
void vsuxseg7ei8(vbool32_t, uint8_t *, vuint8mf4_t, vuint8mf4_t, vuint8mf4_t, vuint8mf4_t, vuint8mf4_t, vuint8mf4_t, vuint8mf4_t, vuint8mf4_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vsuxseg7ei8_v)))
void vsuxseg7ei8(uint8_t *, vuint8mf8_t, vuint8mf8_t, vuint8mf8_t, vuint8mf8_t, vuint8mf8_t, vuint8mf8_t, vuint8mf8_t, vuint8mf8_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vsuxseg7ei8_v_m)))
void vsuxseg7ei8(vbool64_t, uint8_t *, vuint8mf8_t, vuint8mf8_t, vuint8mf8_t, vuint8mf8_t, vuint8mf8_t, vuint8mf8_t, vuint8mf8_t, vuint8mf8_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vsuxseg8ei8_v)))
void vsuxseg8ei8(int8_t *, vuint8m1_t, vint8m1_t, vint8m1_t, vint8m1_t, vint8m1_t, vint8m1_t, vint8m1_t, vint8m1_t, vint8m1_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vsuxseg8ei8_v_m)))
void vsuxseg8ei8(vbool8_t, int8_t *, vuint8m1_t, vint8m1_t, vint8m1_t, vint8m1_t, vint8m1_t, vint8m1_t, vint8m1_t, vint8m1_t, vint8m1_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vsuxseg8ei8_v)))
void vsuxseg8ei8(int8_t *, vuint8mf2_t, vint8mf2_t, vint8mf2_t, vint8mf2_t, vint8mf2_t, vint8mf2_t, vint8mf2_t, vint8mf2_t, vint8mf2_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vsuxseg8ei8_v_m)))
void vsuxseg8ei8(vbool16_t, int8_t *, vuint8mf2_t, vint8mf2_t, vint8mf2_t, vint8mf2_t, vint8mf2_t, vint8mf2_t, vint8mf2_t, vint8mf2_t, vint8mf2_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vsuxseg8ei8_v)))
void vsuxseg8ei8(int8_t *, vuint8mf4_t, vint8mf4_t, vint8mf4_t, vint8mf4_t, vint8mf4_t, vint8mf4_t, vint8mf4_t, vint8mf4_t, vint8mf4_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vsuxseg8ei8_v_m)))
void vsuxseg8ei8(vbool32_t, int8_t *, vuint8mf4_t, vint8mf4_t, vint8mf4_t, vint8mf4_t, vint8mf4_t, vint8mf4_t, vint8mf4_t, vint8mf4_t, vint8mf4_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vsuxseg8ei8_v)))
void vsuxseg8ei8(int8_t *, vuint8mf8_t, vint8mf8_t, vint8mf8_t, vint8mf8_t, vint8mf8_t, vint8mf8_t, vint8mf8_t, vint8mf8_t, vint8mf8_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vsuxseg8ei8_v_m)))
void vsuxseg8ei8(vbool64_t, int8_t *, vuint8mf8_t, vint8mf8_t, vint8mf8_t, vint8mf8_t, vint8mf8_t, vint8mf8_t, vint8mf8_t, vint8mf8_t, vint8mf8_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vsuxseg8ei8_v)))
void vsuxseg8ei8(uint8_t *, vuint8m1_t, vuint8m1_t, vuint8m1_t, vuint8m1_t, vuint8m1_t, vuint8m1_t, vuint8m1_t, vuint8m1_t, vuint8m1_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vsuxseg8ei8_v_m)))
void vsuxseg8ei8(vbool8_t, uint8_t *, vuint8m1_t, vuint8m1_t, vuint8m1_t, vuint8m1_t, vuint8m1_t, vuint8m1_t, vuint8m1_t, vuint8m1_t, vuint8m1_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vsuxseg8ei8_v)))
void vsuxseg8ei8(uint8_t *, vuint8mf2_t, vuint8mf2_t, vuint8mf2_t, vuint8mf2_t, vuint8mf2_t, vuint8mf2_t, vuint8mf2_t, vuint8mf2_t, vuint8mf2_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vsuxseg8ei8_v_m)))
void vsuxseg8ei8(vbool16_t, uint8_t *, vuint8mf2_t, vuint8mf2_t, vuint8mf2_t, vuint8mf2_t, vuint8mf2_t, vuint8mf2_t, vuint8mf2_t, vuint8mf2_t, vuint8mf2_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vsuxseg8ei8_v)))
void vsuxseg8ei8(uint8_t *, vuint8mf4_t, vuint8mf4_t, vuint8mf4_t, vuint8mf4_t, vuint8mf4_t, vuint8mf4_t, vuint8mf4_t, vuint8mf4_t, vuint8mf4_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vsuxseg8ei8_v_m)))
void vsuxseg8ei8(vbool32_t, uint8_t *, vuint8mf4_t, vuint8mf4_t, vuint8mf4_t, vuint8mf4_t, vuint8mf4_t, vuint8mf4_t, vuint8mf4_t, vuint8mf4_t, vuint8mf4_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vsuxseg8ei8_v)))
void vsuxseg8ei8(uint8_t *, vuint8mf8_t, vuint8mf8_t, vuint8mf8_t, vuint8mf8_t, vuint8mf8_t, vuint8mf8_t, vuint8mf8_t, vuint8mf8_t, vuint8mf8_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vsuxseg8ei8_v_m)))
void vsuxseg8ei8(vbool64_t, uint8_t *, vuint8mf8_t, vuint8mf8_t, vuint8mf8_t, vuint8mf8_t, vuint8mf8_t, vuint8mf8_t, vuint8mf8_t, vuint8mf8_t, vuint8mf8_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vsuxseg2ei16_v)))
void vsuxseg2ei16(int8_t *, vuint16m2_t, vint8m1_t, vint8m1_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vsuxseg2ei16_v_m)))
void vsuxseg2ei16(vbool8_t, int8_t *, vuint16m2_t, vint8m1_t, vint8m1_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vsuxseg2ei16_v)))
void vsuxseg2ei16(int8_t *, vuint16m4_t, vint8m2_t, vint8m2_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vsuxseg2ei16_v_m)))
void vsuxseg2ei16(vbool4_t, int8_t *, vuint16m4_t, vint8m2_t, vint8m2_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vsuxseg2ei16_v)))
void vsuxseg2ei16(int8_t *, vuint16m8_t, vint8m4_t, vint8m4_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vsuxseg2ei16_v_m)))
void vsuxseg2ei16(vbool2_t, int8_t *, vuint16m8_t, vint8m4_t, vint8m4_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vsuxseg2ei16_v)))
void vsuxseg2ei16(int8_t *, vuint16m1_t, vint8mf2_t, vint8mf2_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vsuxseg2ei16_v_m)))
void vsuxseg2ei16(vbool16_t, int8_t *, vuint16m1_t, vint8mf2_t, vint8mf2_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vsuxseg2ei16_v)))
void vsuxseg2ei16(int8_t *, vuint16mf2_t, vint8mf4_t, vint8mf4_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vsuxseg2ei16_v_m)))
void vsuxseg2ei16(vbool32_t, int8_t *, vuint16mf2_t, vint8mf4_t, vint8mf4_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vsuxseg2ei16_v)))
void vsuxseg2ei16(int8_t *, vuint16mf4_t, vint8mf8_t, vint8mf8_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vsuxseg2ei16_v_m)))
void vsuxseg2ei16(vbool64_t, int8_t *, vuint16mf4_t, vint8mf8_t, vint8mf8_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vsuxseg2ei16_v)))
void vsuxseg2ei16(uint8_t *, vuint16m2_t, vuint8m1_t, vuint8m1_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vsuxseg2ei16_v_m)))
void vsuxseg2ei16(vbool8_t, uint8_t *, vuint16m2_t, vuint8m1_t, vuint8m1_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vsuxseg2ei16_v)))
void vsuxseg2ei16(uint8_t *, vuint16m4_t, vuint8m2_t, vuint8m2_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vsuxseg2ei16_v_m)))
void vsuxseg2ei16(vbool4_t, uint8_t *, vuint16m4_t, vuint8m2_t, vuint8m2_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vsuxseg2ei16_v)))
void vsuxseg2ei16(uint8_t *, vuint16m8_t, vuint8m4_t, vuint8m4_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vsuxseg2ei16_v_m)))
void vsuxseg2ei16(vbool2_t, uint8_t *, vuint16m8_t, vuint8m4_t, vuint8m4_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vsuxseg2ei16_v)))
void vsuxseg2ei16(uint8_t *, vuint16m1_t, vuint8mf2_t, vuint8mf2_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vsuxseg2ei16_v_m)))
void vsuxseg2ei16(vbool16_t, uint8_t *, vuint16m1_t, vuint8mf2_t, vuint8mf2_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vsuxseg2ei16_v)))
void vsuxseg2ei16(uint8_t *, vuint16mf2_t, vuint8mf4_t, vuint8mf4_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vsuxseg2ei16_v_m)))
void vsuxseg2ei16(vbool32_t, uint8_t *, vuint16mf2_t, vuint8mf4_t, vuint8mf4_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vsuxseg2ei16_v)))
void vsuxseg2ei16(uint8_t *, vuint16mf4_t, vuint8mf8_t, vuint8mf8_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vsuxseg2ei16_v_m)))
void vsuxseg2ei16(vbool64_t, uint8_t *, vuint16mf4_t, vuint8mf8_t, vuint8mf8_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vsuxseg3ei16_v)))
void vsuxseg3ei16(int8_t *, vuint16m2_t, vint8m1_t, vint8m1_t, vint8m1_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vsuxseg3ei16_v_m)))
void vsuxseg3ei16(vbool8_t, int8_t *, vuint16m2_t, vint8m1_t, vint8m1_t, vint8m1_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vsuxseg3ei16_v)))
void vsuxseg3ei16(int8_t *, vuint16m4_t, vint8m2_t, vint8m2_t, vint8m2_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vsuxseg3ei16_v_m)))
void vsuxseg3ei16(vbool4_t, int8_t *, vuint16m4_t, vint8m2_t, vint8m2_t, vint8m2_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vsuxseg3ei16_v)))
void vsuxseg3ei16(int8_t *, vuint16m1_t, vint8mf2_t, vint8mf2_t, vint8mf2_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vsuxseg3ei16_v_m)))
void vsuxseg3ei16(vbool16_t, int8_t *, vuint16m1_t, vint8mf2_t, vint8mf2_t, vint8mf2_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vsuxseg3ei16_v)))
void vsuxseg3ei16(int8_t *, vuint16mf2_t, vint8mf4_t, vint8mf4_t, vint8mf4_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vsuxseg3ei16_v_m)))
void vsuxseg3ei16(vbool32_t, int8_t *, vuint16mf2_t, vint8mf4_t, vint8mf4_t, vint8mf4_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vsuxseg3ei16_v)))
void vsuxseg3ei16(int8_t *, vuint16mf4_t, vint8mf8_t, vint8mf8_t, vint8mf8_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vsuxseg3ei16_v_m)))
void vsuxseg3ei16(vbool64_t, int8_t *, vuint16mf4_t, vint8mf8_t, vint8mf8_t, vint8mf8_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vsuxseg3ei16_v)))
void vsuxseg3ei16(uint8_t *, vuint16m2_t, vuint8m1_t, vuint8m1_t, vuint8m1_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vsuxseg3ei16_v_m)))
void vsuxseg3ei16(vbool8_t, uint8_t *, vuint16m2_t, vuint8m1_t, vuint8m1_t, vuint8m1_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vsuxseg3ei16_v)))
void vsuxseg3ei16(uint8_t *, vuint16m4_t, vuint8m2_t, vuint8m2_t, vuint8m2_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vsuxseg3ei16_v_m)))
void vsuxseg3ei16(vbool4_t, uint8_t *, vuint16m4_t, vuint8m2_t, vuint8m2_t, vuint8m2_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vsuxseg3ei16_v)))
void vsuxseg3ei16(uint8_t *, vuint16m1_t, vuint8mf2_t, vuint8mf2_t, vuint8mf2_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vsuxseg3ei16_v_m)))
void vsuxseg3ei16(vbool16_t, uint8_t *, vuint16m1_t, vuint8mf2_t, vuint8mf2_t, vuint8mf2_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vsuxseg3ei16_v)))
void vsuxseg3ei16(uint8_t *, vuint16mf2_t, vuint8mf4_t, vuint8mf4_t, vuint8mf4_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vsuxseg3ei16_v_m)))
void vsuxseg3ei16(vbool32_t, uint8_t *, vuint16mf2_t, vuint8mf4_t, vuint8mf4_t, vuint8mf4_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vsuxseg3ei16_v)))
void vsuxseg3ei16(uint8_t *, vuint16mf4_t, vuint8mf8_t, vuint8mf8_t, vuint8mf8_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vsuxseg3ei16_v_m)))
void vsuxseg3ei16(vbool64_t, uint8_t *, vuint16mf4_t, vuint8mf8_t, vuint8mf8_t, vuint8mf8_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vsuxseg4ei16_v)))
void vsuxseg4ei16(int8_t *, vuint16m2_t, vint8m1_t, vint8m1_t, vint8m1_t, vint8m1_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vsuxseg4ei16_v_m)))
void vsuxseg4ei16(vbool8_t, int8_t *, vuint16m2_t, vint8m1_t, vint8m1_t, vint8m1_t, vint8m1_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vsuxseg4ei16_v)))
void vsuxseg4ei16(int8_t *, vuint16m4_t, vint8m2_t, vint8m2_t, vint8m2_t, vint8m2_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vsuxseg4ei16_v_m)))
void vsuxseg4ei16(vbool4_t, int8_t *, vuint16m4_t, vint8m2_t, vint8m2_t, vint8m2_t, vint8m2_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vsuxseg4ei16_v)))
void vsuxseg4ei16(int8_t *, vuint16m1_t, vint8mf2_t, vint8mf2_t, vint8mf2_t, vint8mf2_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vsuxseg4ei16_v_m)))
void vsuxseg4ei16(vbool16_t, int8_t *, vuint16m1_t, vint8mf2_t, vint8mf2_t, vint8mf2_t, vint8mf2_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vsuxseg4ei16_v)))
void vsuxseg4ei16(int8_t *, vuint16mf2_t, vint8mf4_t, vint8mf4_t, vint8mf4_t, vint8mf4_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vsuxseg4ei16_v_m)))
void vsuxseg4ei16(vbool32_t, int8_t *, vuint16mf2_t, vint8mf4_t, vint8mf4_t, vint8mf4_t, vint8mf4_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vsuxseg4ei16_v)))
void vsuxseg4ei16(int8_t *, vuint16mf4_t, vint8mf8_t, vint8mf8_t, vint8mf8_t, vint8mf8_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vsuxseg4ei16_v_m)))
void vsuxseg4ei16(vbool64_t, int8_t *, vuint16mf4_t, vint8mf8_t, vint8mf8_t, vint8mf8_t, vint8mf8_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vsuxseg4ei16_v)))
void vsuxseg4ei16(uint8_t *, vuint16m2_t, vuint8m1_t, vuint8m1_t, vuint8m1_t, vuint8m1_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vsuxseg4ei16_v_m)))
void vsuxseg4ei16(vbool8_t, uint8_t *, vuint16m2_t, vuint8m1_t, vuint8m1_t, vuint8m1_t, vuint8m1_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vsuxseg4ei16_v)))
void vsuxseg4ei16(uint8_t *, vuint16m4_t, vuint8m2_t, vuint8m2_t, vuint8m2_t, vuint8m2_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vsuxseg4ei16_v_m)))
void vsuxseg4ei16(vbool4_t, uint8_t *, vuint16m4_t, vuint8m2_t, vuint8m2_t, vuint8m2_t, vuint8m2_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vsuxseg4ei16_v)))
void vsuxseg4ei16(uint8_t *, vuint16m1_t, vuint8mf2_t, vuint8mf2_t, vuint8mf2_t, vuint8mf2_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vsuxseg4ei16_v_m)))
void vsuxseg4ei16(vbool16_t, uint8_t *, vuint16m1_t, vuint8mf2_t, vuint8mf2_t, vuint8mf2_t, vuint8mf2_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vsuxseg4ei16_v)))
void vsuxseg4ei16(uint8_t *, vuint16mf2_t, vuint8mf4_t, vuint8mf4_t, vuint8mf4_t, vuint8mf4_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vsuxseg4ei16_v_m)))
void vsuxseg4ei16(vbool32_t, uint8_t *, vuint16mf2_t, vuint8mf4_t, vuint8mf4_t, vuint8mf4_t, vuint8mf4_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vsuxseg4ei16_v)))
void vsuxseg4ei16(uint8_t *, vuint16mf4_t, vuint8mf8_t, vuint8mf8_t, vuint8mf8_t, vuint8mf8_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vsuxseg4ei16_v_m)))
void vsuxseg4ei16(vbool64_t, uint8_t *, vuint16mf4_t, vuint8mf8_t, vuint8mf8_t, vuint8mf8_t, vuint8mf8_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vsuxseg5ei16_v)))
void vsuxseg5ei16(int8_t *, vuint16m2_t, vint8m1_t, vint8m1_t, vint8m1_t, vint8m1_t, vint8m1_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vsuxseg5ei16_v_m)))
void vsuxseg5ei16(vbool8_t, int8_t *, vuint16m2_t, vint8m1_t, vint8m1_t, vint8m1_t, vint8m1_t, vint8m1_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vsuxseg5ei16_v)))
void vsuxseg5ei16(int8_t *, vuint16m1_t, vint8mf2_t, vint8mf2_t, vint8mf2_t, vint8mf2_t, vint8mf2_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vsuxseg5ei16_v_m)))
void vsuxseg5ei16(vbool16_t, int8_t *, vuint16m1_t, vint8mf2_t, vint8mf2_t, vint8mf2_t, vint8mf2_t, vint8mf2_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vsuxseg5ei16_v)))
void vsuxseg5ei16(int8_t *, vuint16mf2_t, vint8mf4_t, vint8mf4_t, vint8mf4_t, vint8mf4_t, vint8mf4_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vsuxseg5ei16_v_m)))
void vsuxseg5ei16(vbool32_t, int8_t *, vuint16mf2_t, vint8mf4_t, vint8mf4_t, vint8mf4_t, vint8mf4_t, vint8mf4_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vsuxseg5ei16_v)))
void vsuxseg5ei16(int8_t *, vuint16mf4_t, vint8mf8_t, vint8mf8_t, vint8mf8_t, vint8mf8_t, vint8mf8_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vsuxseg5ei16_v_m)))
void vsuxseg5ei16(vbool64_t, int8_t *, vuint16mf4_t, vint8mf8_t, vint8mf8_t, vint8mf8_t, vint8mf8_t, vint8mf8_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vluxei32_v)))
vuint32m1_t vluxei32(const uint32_t *, vuint32m1_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vluxei32_v_m)))
vuint32m1_t vluxei32(vbool32_t, vuint32m1_t, const uint32_t *, vuint32m1_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vluxei32_v)))
vuint32m2_t vluxei32(const uint32_t *, vuint32m2_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vluxei32_v_m)))
vuint32m2_t vluxei32(vbool16_t, vuint32m2_t, const uint32_t *, vuint32m2_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vluxei32_v)))
vuint32m4_t vluxei32(const uint32_t *, vuint32m4_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vluxei32_v_m)))
vuint32m4_t vluxei32(vbool8_t, vuint32m4_t, const uint32_t *, vuint32m4_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vluxei32_v)))
vuint32m8_t vluxei32(const uint32_t *, vuint32m8_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vluxei32_v_m)))
vuint32m8_t vluxei32(vbool4_t, vuint32m8_t, const uint32_t *, vuint32m8_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vluxei32_v)))
vuint32mf2_t vluxei32(const uint32_t *, vuint32mf2_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vluxei32_v_m)))
vuint32mf2_t vluxei32(vbool64_t, vuint32mf2_t, const uint32_t *, vuint32mf2_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vsuxseg5ei16_v)))
void vsuxseg5ei16(uint8_t *, vuint16m2_t, vuint8m1_t, vuint8m1_t, vuint8m1_t, vuint8m1_t, vuint8m1_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vsuxseg5ei16_v_m)))
void vsuxseg5ei16(vbool8_t, uint8_t *, vuint16m2_t, vuint8m1_t, vuint8m1_t, vuint8m1_t, vuint8m1_t, vuint8m1_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vsuxseg5ei16_v)))
void vsuxseg5ei16(uint8_t *, vuint16m1_t, vuint8mf2_t, vuint8mf2_t, vuint8mf2_t, vuint8mf2_t, vuint8mf2_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vsuxseg5ei16_v_m)))
void vsuxseg5ei16(vbool16_t, uint8_t *, vuint16m1_t, vuint8mf2_t, vuint8mf2_t, vuint8mf2_t, vuint8mf2_t, vuint8mf2_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vsuxseg5ei16_v)))
void vsuxseg5ei16(uint8_t *, vuint16mf2_t, vuint8mf4_t, vuint8mf4_t, vuint8mf4_t, vuint8mf4_t, vuint8mf4_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vsuxseg5ei16_v_m)))
void vsuxseg5ei16(vbool32_t, uint8_t *, vuint16mf2_t, vuint8mf4_t, vuint8mf4_t, vuint8mf4_t, vuint8mf4_t, vuint8mf4_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vsuxseg5ei16_v)))
void vsuxseg5ei16(uint8_t *, vuint16mf4_t, vuint8mf8_t, vuint8mf8_t, vuint8mf8_t, vuint8mf8_t, vuint8mf8_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vsuxseg5ei16_v_m)))
void vsuxseg5ei16(vbool64_t, uint8_t *, vuint16mf4_t, vuint8mf8_t, vuint8mf8_t, vuint8mf8_t, vuint8mf8_t, vuint8mf8_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vsuxseg6ei16_v)))
void vsuxseg6ei16(int8_t *, vuint16m2_t, vint8m1_t, vint8m1_t, vint8m1_t, vint8m1_t, vint8m1_t, vint8m1_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vsuxseg6ei16_v_m)))
void vsuxseg6ei16(vbool8_t, int8_t *, vuint16m2_t, vint8m1_t, vint8m1_t, vint8m1_t, vint8m1_t, vint8m1_t, vint8m1_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vsuxseg6ei16_v)))
void vsuxseg6ei16(int8_t *, vuint16m1_t, vint8mf2_t, vint8mf2_t, vint8mf2_t, vint8mf2_t, vint8mf2_t, vint8mf2_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vsuxseg6ei16_v_m)))
void vsuxseg6ei16(vbool16_t, int8_t *, vuint16m1_t, vint8mf2_t, vint8mf2_t, vint8mf2_t, vint8mf2_t, vint8mf2_t, vint8mf2_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vsuxseg6ei16_v)))
void vsuxseg6ei16(int8_t *, vuint16mf2_t, vint8mf4_t, vint8mf4_t, vint8mf4_t, vint8mf4_t, vint8mf4_t, vint8mf4_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vsuxseg6ei16_v_m)))
void vsuxseg6ei16(vbool32_t, int8_t *, vuint16mf2_t, vint8mf4_t, vint8mf4_t, vint8mf4_t, vint8mf4_t, vint8mf4_t, vint8mf4_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vsuxseg6ei16_v)))
void vsuxseg6ei16(int8_t *, vuint16mf4_t, vint8mf8_t, vint8mf8_t, vint8mf8_t, vint8mf8_t, vint8mf8_t, vint8mf8_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vsuxseg6ei16_v_m)))
void vsuxseg6ei16(vbool64_t, int8_t *, vuint16mf4_t, vint8mf8_t, vint8mf8_t, vint8mf8_t, vint8mf8_t, vint8mf8_t, vint8mf8_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vsuxseg6ei16_v)))
void vsuxseg6ei16(uint8_t *, vuint16m2_t, vuint8m1_t, vuint8m1_t, vuint8m1_t, vuint8m1_t, vuint8m1_t, vuint8m1_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vsuxseg6ei16_v_m)))
void vsuxseg6ei16(vbool8_t, uint8_t *, vuint16m2_t, vuint8m1_t, vuint8m1_t, vuint8m1_t, vuint8m1_t, vuint8m1_t, vuint8m1_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vsuxseg6ei16_v)))
void vsuxseg6ei16(uint8_t *, vuint16m1_t, vuint8mf2_t, vuint8mf2_t, vuint8mf2_t, vuint8mf2_t, vuint8mf2_t, vuint8mf2_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vsuxseg6ei16_v_m)))
void vsuxseg6ei16(vbool16_t, uint8_t *, vuint16m1_t, vuint8mf2_t, vuint8mf2_t, vuint8mf2_t, vuint8mf2_t, vuint8mf2_t, vuint8mf2_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vsuxseg6ei16_v)))
void vsuxseg6ei16(uint8_t *, vuint16mf2_t, vuint8mf4_t, vuint8mf4_t, vuint8mf4_t, vuint8mf4_t, vuint8mf4_t, vuint8mf4_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vsuxseg6ei16_v_m)))
void vsuxseg6ei16(vbool32_t, uint8_t *, vuint16mf2_t, vuint8mf4_t, vuint8mf4_t, vuint8mf4_t, vuint8mf4_t, vuint8mf4_t, vuint8mf4_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vsuxseg6ei16_v)))
void vsuxseg6ei16(uint8_t *, vuint16mf4_t, vuint8mf8_t, vuint8mf8_t, vuint8mf8_t, vuint8mf8_t, vuint8mf8_t, vuint8mf8_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vsuxseg6ei16_v_m)))
void vsuxseg6ei16(vbool64_t, uint8_t *, vuint16mf4_t, vuint8mf8_t, vuint8mf8_t, vuint8mf8_t, vuint8mf8_t, vuint8mf8_t, vuint8mf8_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vsuxseg7ei16_v)))
void vsuxseg7ei16(int8_t *, vuint16m2_t, vint8m1_t, vint8m1_t, vint8m1_t, vint8m1_t, vint8m1_t, vint8m1_t, vint8m1_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vsuxseg7ei16_v_m)))
void vsuxseg7ei16(vbool8_t, int8_t *, vuint16m2_t, vint8m1_t, vint8m1_t, vint8m1_t, vint8m1_t, vint8m1_t, vint8m1_t, vint8m1_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vsuxseg7ei16_v)))
void vsuxseg7ei16(int8_t *, vuint16m1_t, vint8mf2_t, vint8mf2_t, vint8mf2_t, vint8mf2_t, vint8mf2_t, vint8mf2_t, vint8mf2_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vsuxseg7ei16_v_m)))
void vsuxseg7ei16(vbool16_t, int8_t *, vuint16m1_t, vint8mf2_t, vint8mf2_t, vint8mf2_t, vint8mf2_t, vint8mf2_t, vint8mf2_t, vint8mf2_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vsuxseg7ei16_v)))
void vsuxseg7ei16(int8_t *, vuint16mf2_t, vint8mf4_t, vint8mf4_t, vint8mf4_t, vint8mf4_t, vint8mf4_t, vint8mf4_t, vint8mf4_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vsuxseg7ei16_v_m)))
void vsuxseg7ei16(vbool32_t, int8_t *, vuint16mf2_t, vint8mf4_t, vint8mf4_t, vint8mf4_t, vint8mf4_t, vint8mf4_t, vint8mf4_t, vint8mf4_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vsuxseg7ei16_v)))
void vsuxseg7ei16(int8_t *, vuint16mf4_t, vint8mf8_t, vint8mf8_t, vint8mf8_t, vint8mf8_t, vint8mf8_t, vint8mf8_t, vint8mf8_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vsuxseg7ei16_v_m)))
void vsuxseg7ei16(vbool64_t, int8_t *, vuint16mf4_t, vint8mf8_t, vint8mf8_t, vint8mf8_t, vint8mf8_t, vint8mf8_t, vint8mf8_t, vint8mf8_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vsuxseg7ei16_v)))
void vsuxseg7ei16(uint8_t *, vuint16m2_t, vuint8m1_t, vuint8m1_t, vuint8m1_t, vuint8m1_t, vuint8m1_t, vuint8m1_t, vuint8m1_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vsuxseg7ei16_v_m)))
void vsuxseg7ei16(vbool8_t, uint8_t *, vuint16m2_t, vuint8m1_t, vuint8m1_t, vuint8m1_t, vuint8m1_t, vuint8m1_t, vuint8m1_t, vuint8m1_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vsuxseg7ei16_v)))
void vsuxseg7ei16(uint8_t *, vuint16m1_t, vuint8mf2_t, vuint8mf2_t, vuint8mf2_t, vuint8mf2_t, vuint8mf2_t, vuint8mf2_t, vuint8mf2_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vsuxseg7ei16_v_m)))
void vsuxseg7ei16(vbool16_t, uint8_t *, vuint16m1_t, vuint8mf2_t, vuint8mf2_t, vuint8mf2_t, vuint8mf2_t, vuint8mf2_t, vuint8mf2_t, vuint8mf2_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vsuxseg7ei16_v)))
void vsuxseg7ei16(uint8_t *, vuint16mf2_t, vuint8mf4_t, vuint8mf4_t, vuint8mf4_t, vuint8mf4_t, vuint8mf4_t, vuint8mf4_t, vuint8mf4_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vsuxseg7ei16_v_m)))
void vsuxseg7ei16(vbool32_t, uint8_t *, vuint16mf2_t, vuint8mf4_t, vuint8mf4_t, vuint8mf4_t, vuint8mf4_t, vuint8mf4_t, vuint8mf4_t, vuint8mf4_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vsuxseg7ei16_v)))
void vsuxseg7ei16(uint8_t *, vuint16mf4_t, vuint8mf8_t, vuint8mf8_t, vuint8mf8_t, vuint8mf8_t, vuint8mf8_t, vuint8mf8_t, vuint8mf8_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vsuxseg7ei16_v_m)))
void vsuxseg7ei16(vbool64_t, uint8_t *, vuint16mf4_t, vuint8mf8_t, vuint8mf8_t, vuint8mf8_t, vuint8mf8_t, vuint8mf8_t, vuint8mf8_t, vuint8mf8_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vsuxseg8ei16_v)))
void vsuxseg8ei16(int8_t *, vuint16m2_t, vint8m1_t, vint8m1_t, vint8m1_t, vint8m1_t, vint8m1_t, vint8m1_t, vint8m1_t, vint8m1_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vsuxseg8ei16_v_m)))
void vsuxseg8ei16(vbool8_t, int8_t *, vuint16m2_t, vint8m1_t, vint8m1_t, vint8m1_t, vint8m1_t, vint8m1_t, vint8m1_t, vint8m1_t, vint8m1_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vsuxseg8ei16_v)))
void vsuxseg8ei16(int8_t *, vuint16m1_t, vint8mf2_t, vint8mf2_t, vint8mf2_t, vint8mf2_t, vint8mf2_t, vint8mf2_t, vint8mf2_t, vint8mf2_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vsuxseg8ei16_v_m)))
void vsuxseg8ei16(vbool16_t, int8_t *, vuint16m1_t, vint8mf2_t, vint8mf2_t, vint8mf2_t, vint8mf2_t, vint8mf2_t, vint8mf2_t, vint8mf2_t, vint8mf2_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vsuxseg8ei16_v)))
void vsuxseg8ei16(int8_t *, vuint16mf2_t, vint8mf4_t, vint8mf4_t, vint8mf4_t, vint8mf4_t, vint8mf4_t, vint8mf4_t, vint8mf4_t, vint8mf4_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vsuxseg8ei16_v_m)))
void vsuxseg8ei16(vbool32_t, int8_t *, vuint16mf2_t, vint8mf4_t, vint8mf4_t, vint8mf4_t, vint8mf4_t, vint8mf4_t, vint8mf4_t, vint8mf4_t, vint8mf4_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vsuxseg8ei16_v)))
void vsuxseg8ei16(int8_t *, vuint16mf4_t, vint8mf8_t, vint8mf8_t, vint8mf8_t, vint8mf8_t, vint8mf8_t, vint8mf8_t, vint8mf8_t, vint8mf8_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vsuxseg8ei16_v_m)))
void vsuxseg8ei16(vbool64_t, int8_t *, vuint16mf4_t, vint8mf8_t, vint8mf8_t, vint8mf8_t, vint8mf8_t, vint8mf8_t, vint8mf8_t, vint8mf8_t, vint8mf8_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vsuxseg8ei16_v)))
void vsuxseg8ei16(uint8_t *, vuint16m2_t, vuint8m1_t, vuint8m1_t, vuint8m1_t, vuint8m1_t, vuint8m1_t, vuint8m1_t, vuint8m1_t, vuint8m1_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vsuxseg8ei16_v_m)))
void vsuxseg8ei16(vbool8_t, uint8_t *, vuint16m2_t, vuint8m1_t, vuint8m1_t, vuint8m1_t, vuint8m1_t, vuint8m1_t, vuint8m1_t, vuint8m1_t, vuint8m1_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vsuxseg8ei16_v)))
void vsuxseg8ei16(uint8_t *, vuint16m1_t, vuint8mf2_t, vuint8mf2_t, vuint8mf2_t, vuint8mf2_t, vuint8mf2_t, vuint8mf2_t, vuint8mf2_t, vuint8mf2_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vsuxseg8ei16_v_m)))
void vsuxseg8ei16(vbool16_t, uint8_t *, vuint16m1_t, vuint8mf2_t, vuint8mf2_t, vuint8mf2_t, vuint8mf2_t, vuint8mf2_t, vuint8mf2_t, vuint8mf2_t, vuint8mf2_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vsuxseg8ei16_v)))
void vsuxseg8ei16(uint8_t *, vuint16mf2_t, vuint8mf4_t, vuint8mf4_t, vuint8mf4_t, vuint8mf4_t, vuint8mf4_t, vuint8mf4_t, vuint8mf4_t, vuint8mf4_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vsuxseg8ei16_v_m)))
void vsuxseg8ei16(vbool32_t, uint8_t *, vuint16mf2_t, vuint8mf4_t, vuint8mf4_t, vuint8mf4_t, vuint8mf4_t, vuint8mf4_t, vuint8mf4_t, vuint8mf4_t, vuint8mf4_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vsuxseg8ei16_v)))
void vsuxseg8ei16(uint8_t *, vuint16mf4_t, vuint8mf8_t, vuint8mf8_t, vuint8mf8_t, vuint8mf8_t, vuint8mf8_t, vuint8mf8_t, vuint8mf8_t, vuint8mf8_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vsuxseg8ei16_v_m)))
void vsuxseg8ei16(vbool64_t, uint8_t *, vuint16mf4_t, vuint8mf8_t, vuint8mf8_t, vuint8mf8_t, vuint8mf8_t, vuint8mf8_t, vuint8mf8_t, vuint8mf8_t, vuint8mf8_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vsuxseg2ei32_v)))
void vsuxseg2ei32(int8_t *, vuint32m4_t, vint8m1_t, vint8m1_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vsuxseg2ei32_v_m)))
void vsuxseg2ei32(vbool8_t, int8_t *, vuint32m4_t, vint8m1_t, vint8m1_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vsuxseg2ei32_v)))
void vsuxseg2ei32(int8_t *, vuint32m8_t, vint8m2_t, vint8m2_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vsuxseg2ei32_v_m)))
void vsuxseg2ei32(vbool4_t, int8_t *, vuint32m8_t, vint8m2_t, vint8m2_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vsuxseg2ei32_v)))
void vsuxseg2ei32(int8_t *, vuint32m2_t, vint8mf2_t, vint8mf2_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vsuxseg2ei32_v_m)))
void vsuxseg2ei32(vbool16_t, int8_t *, vuint32m2_t, vint8mf2_t, vint8mf2_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vsuxseg2ei32_v)))
void vsuxseg2ei32(int8_t *, vuint32m1_t, vint8mf4_t, vint8mf4_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vsuxseg2ei32_v_m)))
void vsuxseg2ei32(vbool32_t, int8_t *, vuint32m1_t, vint8mf4_t, vint8mf4_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vsuxseg2ei32_v)))
void vsuxseg2ei32(int8_t *, vuint32mf2_t, vint8mf8_t, vint8mf8_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vsuxseg2ei32_v_m)))
void vsuxseg2ei32(vbool64_t, int8_t *, vuint32mf2_t, vint8mf8_t, vint8mf8_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vsuxseg2ei32_v)))
void vsuxseg2ei32(uint8_t *, vuint32m4_t, vuint8m1_t, vuint8m1_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vsuxseg2ei32_v_m)))
void vsuxseg2ei32(vbool8_t, uint8_t *, vuint32m4_t, vuint8m1_t, vuint8m1_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vsuxseg2ei32_v)))
void vsuxseg2ei32(uint8_t *, vuint32m8_t, vuint8m2_t, vuint8m2_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vsuxseg2ei32_v_m)))
void vsuxseg2ei32(vbool4_t, uint8_t *, vuint32m8_t, vuint8m2_t, vuint8m2_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vsuxseg2ei32_v)))
void vsuxseg2ei32(uint8_t *, vuint32m2_t, vuint8mf2_t, vuint8mf2_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vsuxseg2ei32_v_m)))
void vsuxseg2ei32(vbool16_t, uint8_t *, vuint32m2_t, vuint8mf2_t, vuint8mf2_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vsuxseg2ei32_v)))
void vsuxseg2ei32(uint8_t *, vuint32m1_t, vuint8mf4_t, vuint8mf4_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vsuxseg2ei32_v_m)))
void vsuxseg2ei32(vbool32_t, uint8_t *, vuint32m1_t, vuint8mf4_t, vuint8mf4_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vsuxseg2ei32_v)))
void vsuxseg2ei32(uint8_t *, vuint32mf2_t, vuint8mf8_t, vuint8mf8_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vsuxseg2ei32_v_m)))
void vsuxseg2ei32(vbool64_t, uint8_t *, vuint32mf2_t, vuint8mf8_t, vuint8mf8_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vsuxseg3ei32_v)))
void vsuxseg3ei32(int8_t *, vuint32m4_t, vint8m1_t, vint8m1_t, vint8m1_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vsuxseg3ei32_v_m)))
void vsuxseg3ei32(vbool8_t, int8_t *, vuint32m4_t, vint8m1_t, vint8m1_t, vint8m1_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vsuxseg3ei32_v)))
void vsuxseg3ei32(int8_t *, vuint32m8_t, vint8m2_t, vint8m2_t, vint8m2_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vsuxseg3ei32_v_m)))
void vsuxseg3ei32(vbool4_t, int8_t *, vuint32m8_t, vint8m2_t, vint8m2_t, vint8m2_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vsuxseg3ei32_v)))
void vsuxseg3ei32(int8_t *, vuint32m2_t, vint8mf2_t, vint8mf2_t, vint8mf2_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vsuxseg3ei32_v_m)))
void vsuxseg3ei32(vbool16_t, int8_t *, vuint32m2_t, vint8mf2_t, vint8mf2_t, vint8mf2_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vsuxseg3ei32_v)))
void vsuxseg3ei32(int8_t *, vuint32m1_t, vint8mf4_t, vint8mf4_t, vint8mf4_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vsuxseg3ei32_v_m)))
void vsuxseg3ei32(vbool32_t, int8_t *, vuint32m1_t, vint8mf4_t, vint8mf4_t, vint8mf4_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vsuxseg3ei32_v)))
void vsuxseg3ei32(int8_t *, vuint32mf2_t, vint8mf8_t, vint8mf8_t, vint8mf8_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vsuxseg3ei32_v_m)))
void vsuxseg3ei32(vbool64_t, int8_t *, vuint32mf2_t, vint8mf8_t, vint8mf8_t, vint8mf8_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vsuxseg3ei32_v)))
void vsuxseg3ei32(uint8_t *, vuint32m4_t, vuint8m1_t, vuint8m1_t, vuint8m1_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vsuxseg3ei32_v_m)))
void vsuxseg3ei32(vbool8_t, uint8_t *, vuint32m4_t, vuint8m1_t, vuint8m1_t, vuint8m1_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vsuxseg3ei32_v)))
void vsuxseg3ei32(uint8_t *, vuint32m8_t, vuint8m2_t, vuint8m2_t, vuint8m2_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vsuxseg3ei32_v_m)))
void vsuxseg3ei32(vbool4_t, uint8_t *, vuint32m8_t, vuint8m2_t, vuint8m2_t, vuint8m2_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vsuxseg3ei32_v)))
void vsuxseg3ei32(uint8_t *, vuint32m2_t, vuint8mf2_t, vuint8mf2_t, vuint8mf2_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vsuxseg3ei32_v_m)))
void vsuxseg3ei32(vbool16_t, uint8_t *, vuint32m2_t, vuint8mf2_t, vuint8mf2_t, vuint8mf2_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vsuxseg3ei32_v)))
void vsuxseg3ei32(uint8_t *, vuint32m1_t, vuint8mf4_t, vuint8mf4_t, vuint8mf4_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vsuxseg3ei32_v_m)))
void vsuxseg3ei32(vbool32_t, uint8_t *, vuint32m1_t, vuint8mf4_t, vuint8mf4_t, vuint8mf4_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vsuxseg3ei32_v)))
void vsuxseg3ei32(uint8_t *, vuint32mf2_t, vuint8mf8_t, vuint8mf8_t, vuint8mf8_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vsuxseg3ei32_v_m)))
void vsuxseg3ei32(vbool64_t, uint8_t *, vuint32mf2_t, vuint8mf8_t, vuint8mf8_t, vuint8mf8_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vsuxseg4ei32_v)))
void vsuxseg4ei32(int8_t *, vuint32m4_t, vint8m1_t, vint8m1_t, vint8m1_t, vint8m1_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vsuxseg4ei32_v_m)))
void vsuxseg4ei32(vbool8_t, int8_t *, vuint32m4_t, vint8m1_t, vint8m1_t, vint8m1_t, vint8m1_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vsuxseg4ei32_v)))
void vsuxseg4ei32(int8_t *, vuint32m8_t, vint8m2_t, vint8m2_t, vint8m2_t, vint8m2_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vsuxseg4ei32_v_m)))
void vsuxseg4ei32(vbool4_t, int8_t *, vuint32m8_t, vint8m2_t, vint8m2_t, vint8m2_t, vint8m2_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vsuxseg4ei32_v)))
void vsuxseg4ei32(int8_t *, vuint32m2_t, vint8mf2_t, vint8mf2_t, vint8mf2_t, vint8mf2_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vsuxseg4ei32_v_m)))
void vsuxseg4ei32(vbool16_t, int8_t *, vuint32m2_t, vint8mf2_t, vint8mf2_t, vint8mf2_t, vint8mf2_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vsuxseg4ei32_v)))
void vsuxseg4ei32(int8_t *, vuint32m1_t, vint8mf4_t, vint8mf4_t, vint8mf4_t, vint8mf4_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vsuxseg4ei32_v_m)))
void vsuxseg4ei32(vbool32_t, int8_t *, vuint32m1_t, vint8mf4_t, vint8mf4_t, vint8mf4_t, vint8mf4_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vsuxseg4ei32_v)))
void vsuxseg4ei32(int8_t *, vuint32mf2_t, vint8mf8_t, vint8mf8_t, vint8mf8_t, vint8mf8_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vsuxseg4ei32_v_m)))
void vsuxseg4ei32(vbool64_t, int8_t *, vuint32mf2_t, vint8mf8_t, vint8mf8_t, vint8mf8_t, vint8mf8_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vsuxseg4ei32_v)))
void vsuxseg4ei32(uint8_t *, vuint32m4_t, vuint8m1_t, vuint8m1_t, vuint8m1_t, vuint8m1_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vsuxseg4ei32_v_m)))
void vsuxseg4ei32(vbool8_t, uint8_t *, vuint32m4_t, vuint8m1_t, vuint8m1_t, vuint8m1_t, vuint8m1_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vsuxseg4ei32_v)))
void vsuxseg4ei32(uint8_t *, vuint32m8_t, vuint8m2_t, vuint8m2_t, vuint8m2_t, vuint8m2_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vsuxseg4ei32_v_m)))
void vsuxseg4ei32(vbool4_t, uint8_t *, vuint32m8_t, vuint8m2_t, vuint8m2_t, vuint8m2_t, vuint8m2_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vsuxseg4ei32_v)))
void vsuxseg4ei32(uint8_t *, vuint32m2_t, vuint8mf2_t, vuint8mf2_t, vuint8mf2_t, vuint8mf2_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vsuxseg4ei32_v_m)))
void vsuxseg4ei32(vbool16_t, uint8_t *, vuint32m2_t, vuint8mf2_t, vuint8mf2_t, vuint8mf2_t, vuint8mf2_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vsuxseg4ei32_v)))
void vsuxseg4ei32(uint8_t *, vuint32m1_t, vuint8mf4_t, vuint8mf4_t, vuint8mf4_t, vuint8mf4_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vsuxseg4ei32_v_m)))
void vsuxseg4ei32(vbool32_t, uint8_t *, vuint32m1_t, vuint8mf4_t, vuint8mf4_t, vuint8mf4_t, vuint8mf4_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vsuxseg4ei32_v)))
void vsuxseg4ei32(uint8_t *, vuint32mf2_t, vuint8mf8_t, vuint8mf8_t, vuint8mf8_t, vuint8mf8_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vsuxseg4ei32_v_m)))
void vsuxseg4ei32(vbool64_t, uint8_t *, vuint32mf2_t, vuint8mf8_t, vuint8mf8_t, vuint8mf8_t, vuint8mf8_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vsuxseg5ei32_v)))
void vsuxseg5ei32(int8_t *, vuint32m4_t, vint8m1_t, vint8m1_t, vint8m1_t, vint8m1_t, vint8m1_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vsuxseg5ei32_v_m)))
void vsuxseg5ei32(vbool8_t, int8_t *, vuint32m4_t, vint8m1_t, vint8m1_t, vint8m1_t, vint8m1_t, vint8m1_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vsuxseg5ei32_v)))
void vsuxseg5ei32(int8_t *, vuint32m2_t, vint8mf2_t, vint8mf2_t, vint8mf2_t, vint8mf2_t, vint8mf2_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vsuxseg5ei32_v_m)))
void vsuxseg5ei32(vbool16_t, int8_t *, vuint32m2_t, vint8mf2_t, vint8mf2_t, vint8mf2_t, vint8mf2_t, vint8mf2_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vsuxseg5ei32_v)))
void vsuxseg5ei32(int8_t *, vuint32m1_t, vint8mf4_t, vint8mf4_t, vint8mf4_t, vint8mf4_t, vint8mf4_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vsuxseg5ei32_v_m)))
void vsuxseg5ei32(vbool32_t, int8_t *, vuint32m1_t, vint8mf4_t, vint8mf4_t, vint8mf4_t, vint8mf4_t, vint8mf4_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vsuxseg5ei32_v)))
void vsuxseg5ei32(int8_t *, vuint32mf2_t, vint8mf8_t, vint8mf8_t, vint8mf8_t, vint8mf8_t, vint8mf8_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vsuxseg5ei32_v_m)))
void vsuxseg5ei32(vbool64_t, int8_t *, vuint32mf2_t, vint8mf8_t, vint8mf8_t, vint8mf8_t, vint8mf8_t, vint8mf8_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vsuxseg5ei32_v)))
void vsuxseg5ei32(uint8_t *, vuint32m4_t, vuint8m1_t, vuint8m1_t, vuint8m1_t, vuint8m1_t, vuint8m1_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vsuxseg5ei32_v_m)))
void vsuxseg5ei32(vbool8_t, uint8_t *, vuint32m4_t, vuint8m1_t, vuint8m1_t, vuint8m1_t, vuint8m1_t, vuint8m1_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vsuxseg5ei32_v)))
void vsuxseg5ei32(uint8_t *, vuint32m2_t, vuint8mf2_t, vuint8mf2_t, vuint8mf2_t, vuint8mf2_t, vuint8mf2_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vsuxseg5ei32_v_m)))
void vsuxseg5ei32(vbool16_t, uint8_t *, vuint32m2_t, vuint8mf2_t, vuint8mf2_t, vuint8mf2_t, vuint8mf2_t, vuint8mf2_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vsuxseg5ei32_v)))
void vsuxseg5ei32(uint8_t *, vuint32m1_t, vuint8mf4_t, vuint8mf4_t, vuint8mf4_t, vuint8mf4_t, vuint8mf4_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vsuxseg5ei32_v_m)))
void vsuxseg5ei32(vbool32_t, uint8_t *, vuint32m1_t, vuint8mf4_t, vuint8mf4_t, vuint8mf4_t, vuint8mf4_t, vuint8mf4_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vsuxseg5ei32_v)))
void vsuxseg5ei32(uint8_t *, vuint32mf2_t, vuint8mf8_t, vuint8mf8_t, vuint8mf8_t, vuint8mf8_t, vuint8mf8_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vsuxseg5ei32_v_m)))
void vsuxseg5ei32(vbool64_t, uint8_t *, vuint32mf2_t, vuint8mf8_t, vuint8mf8_t, vuint8mf8_t, vuint8mf8_t, vuint8mf8_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vsuxseg6ei32_v)))
void vsuxseg6ei32(int8_t *, vuint32m4_t, vint8m1_t, vint8m1_t, vint8m1_t, vint8m1_t, vint8m1_t, vint8m1_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vsuxseg6ei32_v_m)))
void vsuxseg6ei32(vbool8_t, int8_t *, vuint32m4_t, vint8m1_t, vint8m1_t, vint8m1_t, vint8m1_t, vint8m1_t, vint8m1_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vsuxseg6ei32_v)))
void vsuxseg6ei32(int8_t *, vuint32m2_t, vint8mf2_t, vint8mf2_t, vint8mf2_t, vint8mf2_t, vint8mf2_t, vint8mf2_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vsuxseg6ei32_v_m)))
void vsuxseg6ei32(vbool16_t, int8_t *, vuint32m2_t, vint8mf2_t, vint8mf2_t, vint8mf2_t, vint8mf2_t, vint8mf2_t, vint8mf2_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vsuxseg6ei32_v)))
void vsuxseg6ei32(int8_t *, vuint32m1_t, vint8mf4_t, vint8mf4_t, vint8mf4_t, vint8mf4_t, vint8mf4_t, vint8mf4_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vsuxseg6ei32_v_m)))
void vsuxseg6ei32(vbool32_t, int8_t *, vuint32m1_t, vint8mf4_t, vint8mf4_t, vint8mf4_t, vint8mf4_t, vint8mf4_t, vint8mf4_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vsuxseg6ei32_v)))
void vsuxseg6ei32(int8_t *, vuint32mf2_t, vint8mf8_t, vint8mf8_t, vint8mf8_t, vint8mf8_t, vint8mf8_t, vint8mf8_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vsuxseg6ei32_v_m)))
void vsuxseg6ei32(vbool64_t, int8_t *, vuint32mf2_t, vint8mf8_t, vint8mf8_t, vint8mf8_t, vint8mf8_t, vint8mf8_t, vint8mf8_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vsuxseg6ei32_v)))
void vsuxseg6ei32(uint8_t *, vuint32m4_t, vuint8m1_t, vuint8m1_t, vuint8m1_t, vuint8m1_t, vuint8m1_t, vuint8m1_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vsuxseg6ei32_v_m)))
void vsuxseg6ei32(vbool8_t, uint8_t *, vuint32m4_t, vuint8m1_t, vuint8m1_t, vuint8m1_t, vuint8m1_t, vuint8m1_t, vuint8m1_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vsuxseg6ei32_v)))
void vsuxseg6ei32(uint8_t *, vuint32m2_t, vuint8mf2_t, vuint8mf2_t, vuint8mf2_t, vuint8mf2_t, vuint8mf2_t, vuint8mf2_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vsuxseg6ei32_v_m)))
void vsuxseg6ei32(vbool16_t, uint8_t *, vuint32m2_t, vuint8mf2_t, vuint8mf2_t, vuint8mf2_t, vuint8mf2_t, vuint8mf2_t, vuint8mf2_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vsuxseg6ei32_v)))
void vsuxseg6ei32(uint8_t *, vuint32m1_t, vuint8mf4_t, vuint8mf4_t, vuint8mf4_t, vuint8mf4_t, vuint8mf4_t, vuint8mf4_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vsuxseg6ei32_v_m)))
void vsuxseg6ei32(vbool32_t, uint8_t *, vuint32m1_t, vuint8mf4_t, vuint8mf4_t, vuint8mf4_t, vuint8mf4_t, vuint8mf4_t, vuint8mf4_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vsuxseg6ei32_v)))
void vsuxseg6ei32(uint8_t *, vuint32mf2_t, vuint8mf8_t, vuint8mf8_t, vuint8mf8_t, vuint8mf8_t, vuint8mf8_t, vuint8mf8_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vsuxseg6ei32_v_m)))
void vsuxseg6ei32(vbool64_t, uint8_t *, vuint32mf2_t, vuint8mf8_t, vuint8mf8_t, vuint8mf8_t, vuint8mf8_t, vuint8mf8_t, vuint8mf8_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vsuxseg7ei32_v)))
void vsuxseg7ei32(int8_t *, vuint32m4_t, vint8m1_t, vint8m1_t, vint8m1_t, vint8m1_t, vint8m1_t, vint8m1_t, vint8m1_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vsuxseg7ei32_v_m)))
void vsuxseg7ei32(vbool8_t, int8_t *, vuint32m4_t, vint8m1_t, vint8m1_t, vint8m1_t, vint8m1_t, vint8m1_t, vint8m1_t, vint8m1_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vsuxseg7ei32_v)))
void vsuxseg7ei32(int8_t *, vuint32m2_t, vint8mf2_t, vint8mf2_t, vint8mf2_t, vint8mf2_t, vint8mf2_t, vint8mf2_t, vint8mf2_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vsuxseg7ei32_v_m)))
void vsuxseg7ei32(vbool16_t, int8_t *, vuint32m2_t, vint8mf2_t, vint8mf2_t, vint8mf2_t, vint8mf2_t, vint8mf2_t, vint8mf2_t, vint8mf2_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vsuxseg7ei32_v)))
void vsuxseg7ei32(int8_t *, vuint32m1_t, vint8mf4_t, vint8mf4_t, vint8mf4_t, vint8mf4_t, vint8mf4_t, vint8mf4_t, vint8mf4_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vsuxseg7ei32_v_m)))
void vsuxseg7ei32(vbool32_t, int8_t *, vuint32m1_t, vint8mf4_t, vint8mf4_t, vint8mf4_t, vint8mf4_t, vint8mf4_t, vint8mf4_t, vint8mf4_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vsuxseg7ei32_v)))
void vsuxseg7ei32(int8_t *, vuint32mf2_t, vint8mf8_t, vint8mf8_t, vint8mf8_t, vint8mf8_t, vint8mf8_t, vint8mf8_t, vint8mf8_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vsuxseg7ei32_v_m)))
void vsuxseg7ei32(vbool64_t, int8_t *, vuint32mf2_t, vint8mf8_t, vint8mf8_t, vint8mf8_t, vint8mf8_t, vint8mf8_t, vint8mf8_t, vint8mf8_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vsuxseg7ei32_v)))
void vsuxseg7ei32(uint8_t *, vuint32m4_t, vuint8m1_t, vuint8m1_t, vuint8m1_t, vuint8m1_t, vuint8m1_t, vuint8m1_t, vuint8m1_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vsuxseg7ei32_v_m)))
void vsuxseg7ei32(vbool8_t, uint8_t *, vuint32m4_t, vuint8m1_t, vuint8m1_t, vuint8m1_t, vuint8m1_t, vuint8m1_t, vuint8m1_t, vuint8m1_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vsuxseg7ei32_v)))
void vsuxseg7ei32(uint8_t *, vuint32m2_t, vuint8mf2_t, vuint8mf2_t, vuint8mf2_t, vuint8mf2_t, vuint8mf2_t, vuint8mf2_t, vuint8mf2_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vsuxseg7ei32_v_m)))
void vsuxseg7ei32(vbool16_t, uint8_t *, vuint32m2_t, vuint8mf2_t, vuint8mf2_t, vuint8mf2_t, vuint8mf2_t, vuint8mf2_t, vuint8mf2_t, vuint8mf2_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vsuxseg7ei32_v)))
void vsuxseg7ei32(uint8_t *, vuint32m1_t, vuint8mf4_t, vuint8mf4_t, vuint8mf4_t, vuint8mf4_t, vuint8mf4_t, vuint8mf4_t, vuint8mf4_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vsuxseg7ei32_v_m)))
void vsuxseg7ei32(vbool32_t, uint8_t *, vuint32m1_t, vuint8mf4_t, vuint8mf4_t, vuint8mf4_t, vuint8mf4_t, vuint8mf4_t, vuint8mf4_t, vuint8mf4_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vsuxseg7ei32_v)))
void vsuxseg7ei32(uint8_t *, vuint32mf2_t, vuint8mf8_t, vuint8mf8_t, vuint8mf8_t, vuint8mf8_t, vuint8mf8_t, vuint8mf8_t, vuint8mf8_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vsuxseg7ei32_v_m)))
void vsuxseg7ei32(vbool64_t, uint8_t *, vuint32mf2_t, vuint8mf8_t, vuint8mf8_t, vuint8mf8_t, vuint8mf8_t, vuint8mf8_t, vuint8mf8_t, vuint8mf8_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vsuxseg8ei32_v)))
void vsuxseg8ei32(int8_t *, vuint32m4_t, vint8m1_t, vint8m1_t, vint8m1_t, vint8m1_t, vint8m1_t, vint8m1_t, vint8m1_t, vint8m1_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vsuxseg8ei32_v_m)))
void vsuxseg8ei32(vbool8_t, int8_t *, vuint32m4_t, vint8m1_t, vint8m1_t, vint8m1_t, vint8m1_t, vint8m1_t, vint8m1_t, vint8m1_t, vint8m1_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vsuxseg8ei32_v)))
void vsuxseg8ei32(int8_t *, vuint32m2_t, vint8mf2_t, vint8mf2_t, vint8mf2_t, vint8mf2_t, vint8mf2_t, vint8mf2_t, vint8mf2_t, vint8mf2_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vsuxseg8ei32_v_m)))
void vsuxseg8ei32(vbool16_t, int8_t *, vuint32m2_t, vint8mf2_t, vint8mf2_t, vint8mf2_t, vint8mf2_t, vint8mf2_t, vint8mf2_t, vint8mf2_t, vint8mf2_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vsuxseg8ei32_v)))
void vsuxseg8ei32(int8_t *, vuint32m1_t, vint8mf4_t, vint8mf4_t, vint8mf4_t, vint8mf4_t, vint8mf4_t, vint8mf4_t, vint8mf4_t, vint8mf4_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vsuxseg8ei32_v_m)))
void vsuxseg8ei32(vbool32_t, int8_t *, vuint32m1_t, vint8mf4_t, vint8mf4_t, vint8mf4_t, vint8mf4_t, vint8mf4_t, vint8mf4_t, vint8mf4_t, vint8mf4_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vsuxseg8ei32_v)))
void vsuxseg8ei32(int8_t *, vuint32mf2_t, vint8mf8_t, vint8mf8_t, vint8mf8_t, vint8mf8_t, vint8mf8_t, vint8mf8_t, vint8mf8_t, vint8mf8_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vsuxseg8ei32_v_m)))
void vsuxseg8ei32(vbool64_t, int8_t *, vuint32mf2_t, vint8mf8_t, vint8mf8_t, vint8mf8_t, vint8mf8_t, vint8mf8_t, vint8mf8_t, vint8mf8_t, vint8mf8_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vsuxseg8ei32_v)))
void vsuxseg8ei32(uint8_t *, vuint32m4_t, vuint8m1_t, vuint8m1_t, vuint8m1_t, vuint8m1_t, vuint8m1_t, vuint8m1_t, vuint8m1_t, vuint8m1_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vsuxseg8ei32_v_m)))
void vsuxseg8ei32(vbool8_t, uint8_t *, vuint32m4_t, vuint8m1_t, vuint8m1_t, vuint8m1_t, vuint8m1_t, vuint8m1_t, vuint8m1_t, vuint8m1_t, vuint8m1_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vsuxseg8ei32_v)))
void vsuxseg8ei32(uint8_t *, vuint32m2_t, vuint8mf2_t, vuint8mf2_t, vuint8mf2_t, vuint8mf2_t, vuint8mf2_t, vuint8mf2_t, vuint8mf2_t, vuint8mf2_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vsuxseg8ei32_v_m)))
void vsuxseg8ei32(vbool16_t, uint8_t *, vuint32m2_t, vuint8mf2_t, vuint8mf2_t, vuint8mf2_t, vuint8mf2_t, vuint8mf2_t, vuint8mf2_t, vuint8mf2_t, vuint8mf2_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vsuxseg8ei32_v)))
void vsuxseg8ei32(uint8_t *, vuint32m1_t, vuint8mf4_t, vuint8mf4_t, vuint8mf4_t, vuint8mf4_t, vuint8mf4_t, vuint8mf4_t, vuint8mf4_t, vuint8mf4_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vsuxseg8ei32_v_m)))
void vsuxseg8ei32(vbool32_t, uint8_t *, vuint32m1_t, vuint8mf4_t, vuint8mf4_t, vuint8mf4_t, vuint8mf4_t, vuint8mf4_t, vuint8mf4_t, vuint8mf4_t, vuint8mf4_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vsuxseg8ei32_v)))
void vsuxseg8ei32(uint8_t *, vuint32mf2_t, vuint8mf8_t, vuint8mf8_t, vuint8mf8_t, vuint8mf8_t, vuint8mf8_t, vuint8mf8_t, vuint8mf8_t, vuint8mf8_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vsuxseg8ei32_v_m)))
void vsuxseg8ei32(vbool64_t, uint8_t *, vuint32mf2_t, vuint8mf8_t, vuint8mf8_t, vuint8mf8_t, vuint8mf8_t, vuint8mf8_t, vuint8mf8_t, vuint8mf8_t, vuint8mf8_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vsuxseg2ei8_v)))
void vsuxseg2ei8(int16_t *, vuint8mf2_t, vint16m1_t, vint16m1_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vsuxseg2ei8_v_m)))
void vsuxseg2ei8(vbool16_t, int16_t *, vuint8mf2_t, vint16m1_t, vint16m1_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vsuxseg2ei8_v)))
void vsuxseg2ei8(int16_t *, vuint8m1_t, vint16m2_t, vint16m2_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vsuxseg2ei8_v_m)))
void vsuxseg2ei8(vbool8_t, int16_t *, vuint8m1_t, vint16m2_t, vint16m2_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vsuxseg2ei8_v)))
void vsuxseg2ei8(int16_t *, vuint8m2_t, vint16m4_t, vint16m4_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vsuxseg2ei8_v_m)))
void vsuxseg2ei8(vbool4_t, int16_t *, vuint8m2_t, vint16m4_t, vint16m4_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vsuxseg2ei8_v)))
void vsuxseg2ei8(int16_t *, vuint8mf4_t, vint16mf2_t, vint16mf2_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vsuxseg2ei8_v_m)))
void vsuxseg2ei8(vbool32_t, int16_t *, vuint8mf4_t, vint16mf2_t, vint16mf2_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vsuxseg2ei8_v)))
void vsuxseg2ei8(int16_t *, vuint8mf8_t, vint16mf4_t, vint16mf4_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vsuxseg2ei8_v_m)))
void vsuxseg2ei8(vbool64_t, int16_t *, vuint8mf8_t, vint16mf4_t, vint16mf4_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vsuxseg2ei8_v)))
void vsuxseg2ei8(uint16_t *, vuint8mf2_t, vuint16m1_t, vuint16m1_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vsuxseg2ei8_v_m)))
void vsuxseg2ei8(vbool16_t, uint16_t *, vuint8mf2_t, vuint16m1_t, vuint16m1_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vsuxseg2ei8_v)))
void vsuxseg2ei8(uint16_t *, vuint8m1_t, vuint16m2_t, vuint16m2_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vsuxseg2ei8_v_m)))
void vsuxseg2ei8(vbool8_t, uint16_t *, vuint8m1_t, vuint16m2_t, vuint16m2_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vsuxseg2ei8_v)))
void vsuxseg2ei8(uint16_t *, vuint8m2_t, vuint16m4_t, vuint16m4_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vsuxseg2ei8_v_m)))
void vsuxseg2ei8(vbool4_t, uint16_t *, vuint8m2_t, vuint16m4_t, vuint16m4_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vsuxseg2ei8_v)))
void vsuxseg2ei8(uint16_t *, vuint8mf4_t, vuint16mf2_t, vuint16mf2_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vsuxseg2ei8_v_m)))
void vsuxseg2ei8(vbool32_t, uint16_t *, vuint8mf4_t, vuint16mf2_t, vuint16mf2_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vsuxseg2ei8_v)))
void vsuxseg2ei8(uint16_t *, vuint8mf8_t, vuint16mf4_t, vuint16mf4_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vsuxseg2ei8_v_m)))
void vsuxseg2ei8(vbool64_t, uint16_t *, vuint8mf8_t, vuint16mf4_t, vuint16mf4_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vsuxseg3ei8_v)))
void vsuxseg3ei8(int16_t *, vuint8mf2_t, vint16m1_t, vint16m1_t, vint16m1_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vsuxseg3ei8_v_m)))
void vsuxseg3ei8(vbool16_t, int16_t *, vuint8mf2_t, vint16m1_t, vint16m1_t, vint16m1_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vsuxseg3ei8_v)))
void vsuxseg3ei8(int16_t *, vuint8m1_t, vint16m2_t, vint16m2_t, vint16m2_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vsuxseg3ei8_v_m)))
void vsuxseg3ei8(vbool8_t, int16_t *, vuint8m1_t, vint16m2_t, vint16m2_t, vint16m2_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vsuxseg3ei8_v)))
void vsuxseg3ei8(int16_t *, vuint8mf4_t, vint16mf2_t, vint16mf2_t, vint16mf2_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vsuxseg3ei8_v_m)))
void vsuxseg3ei8(vbool32_t, int16_t *, vuint8mf4_t, vint16mf2_t, vint16mf2_t, vint16mf2_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vsuxseg3ei8_v)))
void vsuxseg3ei8(int16_t *, vuint8mf8_t, vint16mf4_t, vint16mf4_t, vint16mf4_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vsuxseg3ei8_v_m)))
void vsuxseg3ei8(vbool64_t, int16_t *, vuint8mf8_t, vint16mf4_t, vint16mf4_t, vint16mf4_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vsuxseg3ei8_v)))
void vsuxseg3ei8(uint16_t *, vuint8mf2_t, vuint16m1_t, vuint16m1_t, vuint16m1_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vsuxseg3ei8_v_m)))
void vsuxseg3ei8(vbool16_t, uint16_t *, vuint8mf2_t, vuint16m1_t, vuint16m1_t, vuint16m1_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vsuxseg3ei8_v)))
void vsuxseg3ei8(uint16_t *, vuint8m1_t, vuint16m2_t, vuint16m2_t, vuint16m2_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vsuxseg3ei8_v_m)))
void vsuxseg3ei8(vbool8_t, uint16_t *, vuint8m1_t, vuint16m2_t, vuint16m2_t, vuint16m2_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vsuxseg3ei8_v)))
void vsuxseg3ei8(uint16_t *, vuint8mf4_t, vuint16mf2_t, vuint16mf2_t, vuint16mf2_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vsuxseg3ei8_v_m)))
void vsuxseg3ei8(vbool32_t, uint16_t *, vuint8mf4_t, vuint16mf2_t, vuint16mf2_t, vuint16mf2_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vsuxseg3ei8_v)))
void vsuxseg3ei8(uint16_t *, vuint8mf8_t, vuint16mf4_t, vuint16mf4_t, vuint16mf4_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vsuxseg3ei8_v_m)))
void vsuxseg3ei8(vbool64_t, uint16_t *, vuint8mf8_t, vuint16mf4_t, vuint16mf4_t, vuint16mf4_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vsuxseg4ei8_v)))
void vsuxseg4ei8(int16_t *, vuint8mf2_t, vint16m1_t, vint16m1_t, vint16m1_t, vint16m1_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vsuxseg4ei8_v_m)))
void vsuxseg4ei8(vbool16_t, int16_t *, vuint8mf2_t, vint16m1_t, vint16m1_t, vint16m1_t, vint16m1_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vsuxseg4ei8_v)))
void vsuxseg4ei8(int16_t *, vuint8m1_t, vint16m2_t, vint16m2_t, vint16m2_t, vint16m2_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vsuxseg4ei8_v_m)))
void vsuxseg4ei8(vbool8_t, int16_t *, vuint8m1_t, vint16m2_t, vint16m2_t, vint16m2_t, vint16m2_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vsuxseg4ei8_v)))
void vsuxseg4ei8(int16_t *, vuint8mf4_t, vint16mf2_t, vint16mf2_t, vint16mf2_t, vint16mf2_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vsuxseg4ei8_v_m)))
void vsuxseg4ei8(vbool32_t, int16_t *, vuint8mf4_t, vint16mf2_t, vint16mf2_t, vint16mf2_t, vint16mf2_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vsuxseg4ei8_v)))
void vsuxseg4ei8(int16_t *, vuint8mf8_t, vint16mf4_t, vint16mf4_t, vint16mf4_t, vint16mf4_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vsuxseg4ei8_v_m)))
void vsuxseg4ei8(vbool64_t, int16_t *, vuint8mf8_t, vint16mf4_t, vint16mf4_t, vint16mf4_t, vint16mf4_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vsuxseg4ei8_v)))
void vsuxseg4ei8(uint16_t *, vuint8mf2_t, vuint16m1_t, vuint16m1_t, vuint16m1_t, vuint16m1_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vsuxseg4ei8_v_m)))
void vsuxseg4ei8(vbool16_t, uint16_t *, vuint8mf2_t, vuint16m1_t, vuint16m1_t, vuint16m1_t, vuint16m1_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vsuxseg4ei8_v)))
void vsuxseg4ei8(uint16_t *, vuint8m1_t, vuint16m2_t, vuint16m2_t, vuint16m2_t, vuint16m2_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vsuxseg4ei8_v_m)))
void vsuxseg4ei8(vbool8_t, uint16_t *, vuint8m1_t, vuint16m2_t, vuint16m2_t, vuint16m2_t, vuint16m2_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vsuxseg4ei8_v)))
void vsuxseg4ei8(uint16_t *, vuint8mf4_t, vuint16mf2_t, vuint16mf2_t, vuint16mf2_t, vuint16mf2_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vsuxseg4ei8_v_m)))
void vsuxseg4ei8(vbool32_t, uint16_t *, vuint8mf4_t, vuint16mf2_t, vuint16mf2_t, vuint16mf2_t, vuint16mf2_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vsuxseg4ei8_v)))
void vsuxseg4ei8(uint16_t *, vuint8mf8_t, vuint16mf4_t, vuint16mf4_t, vuint16mf4_t, vuint16mf4_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vsuxseg4ei8_v_m)))
void vsuxseg4ei8(vbool64_t, uint16_t *, vuint8mf8_t, vuint16mf4_t, vuint16mf4_t, vuint16mf4_t, vuint16mf4_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vsuxseg5ei8_v)))
void vsuxseg5ei8(int16_t *, vuint8mf2_t, vint16m1_t, vint16m1_t, vint16m1_t, vint16m1_t, vint16m1_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vsuxseg5ei8_v_m)))
void vsuxseg5ei8(vbool16_t, int16_t *, vuint8mf2_t, vint16m1_t, vint16m1_t, vint16m1_t, vint16m1_t, vint16m1_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vsuxseg5ei8_v)))
void vsuxseg5ei8(int16_t *, vuint8mf4_t, vint16mf2_t, vint16mf2_t, vint16mf2_t, vint16mf2_t, vint16mf2_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vsuxseg5ei8_v_m)))
void vsuxseg5ei8(vbool32_t, int16_t *, vuint8mf4_t, vint16mf2_t, vint16mf2_t, vint16mf2_t, vint16mf2_t, vint16mf2_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vsuxseg5ei8_v)))
void vsuxseg5ei8(int16_t *, vuint8mf8_t, vint16mf4_t, vint16mf4_t, vint16mf4_t, vint16mf4_t, vint16mf4_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vsuxseg5ei8_v_m)))
void vsuxseg5ei8(vbool64_t, int16_t *, vuint8mf8_t, vint16mf4_t, vint16mf4_t, vint16mf4_t, vint16mf4_t, vint16mf4_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vsuxseg5ei8_v)))
void vsuxseg5ei8(uint16_t *, vuint8mf2_t, vuint16m1_t, vuint16m1_t, vuint16m1_t, vuint16m1_t, vuint16m1_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vsuxseg5ei8_v_m)))
void vsuxseg5ei8(vbool16_t, uint16_t *, vuint8mf2_t, vuint16m1_t, vuint16m1_t, vuint16m1_t, vuint16m1_t, vuint16m1_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vsuxseg5ei8_v)))
void vsuxseg5ei8(uint16_t *, vuint8mf4_t, vuint16mf2_t, vuint16mf2_t, vuint16mf2_t, vuint16mf2_t, vuint16mf2_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vsuxseg5ei8_v_m)))
void vsuxseg5ei8(vbool32_t, uint16_t *, vuint8mf4_t, vuint16mf2_t, vuint16mf2_t, vuint16mf2_t, vuint16mf2_t, vuint16mf2_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vsuxseg5ei8_v)))
void vsuxseg5ei8(uint16_t *, vuint8mf8_t, vuint16mf4_t, vuint16mf4_t, vuint16mf4_t, vuint16mf4_t, vuint16mf4_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vsuxseg5ei8_v_m)))
void vsuxseg5ei8(vbool64_t, uint16_t *, vuint8mf8_t, vuint16mf4_t, vuint16mf4_t, vuint16mf4_t, vuint16mf4_t, vuint16mf4_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vsuxseg6ei8_v)))
void vsuxseg6ei8(int16_t *, vuint8mf2_t, vint16m1_t, vint16m1_t, vint16m1_t, vint16m1_t, vint16m1_t, vint16m1_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vsuxseg6ei8_v_m)))
void vsuxseg6ei8(vbool16_t, int16_t *, vuint8mf2_t, vint16m1_t, vint16m1_t, vint16m1_t, vint16m1_t, vint16m1_t, vint16m1_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vsuxseg6ei8_v)))
void vsuxseg6ei8(int16_t *, vuint8mf4_t, vint16mf2_t, vint16mf2_t, vint16mf2_t, vint16mf2_t, vint16mf2_t, vint16mf2_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vsuxseg6ei8_v_m)))
void vsuxseg6ei8(vbool32_t, int16_t *, vuint8mf4_t, vint16mf2_t, vint16mf2_t, vint16mf2_t, vint16mf2_t, vint16mf2_t, vint16mf2_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vsuxseg6ei8_v)))
void vsuxseg6ei8(int16_t *, vuint8mf8_t, vint16mf4_t, vint16mf4_t, vint16mf4_t, vint16mf4_t, vint16mf4_t, vint16mf4_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vsuxseg6ei8_v_m)))
void vsuxseg6ei8(vbool64_t, int16_t *, vuint8mf8_t, vint16mf4_t, vint16mf4_t, vint16mf4_t, vint16mf4_t, vint16mf4_t, vint16mf4_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vsuxseg6ei8_v)))
void vsuxseg6ei8(uint16_t *, vuint8mf2_t, vuint16m1_t, vuint16m1_t, vuint16m1_t, vuint16m1_t, vuint16m1_t, vuint16m1_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vsuxseg6ei8_v_m)))
void vsuxseg6ei8(vbool16_t, uint16_t *, vuint8mf2_t, vuint16m1_t, vuint16m1_t, vuint16m1_t, vuint16m1_t, vuint16m1_t, vuint16m1_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vsuxseg6ei8_v)))
void vsuxseg6ei8(uint16_t *, vuint8mf4_t, vuint16mf2_t, vuint16mf2_t, vuint16mf2_t, vuint16mf2_t, vuint16mf2_t, vuint16mf2_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vsuxseg6ei8_v_m)))
void vsuxseg6ei8(vbool32_t, uint16_t *, vuint8mf4_t, vuint16mf2_t, vuint16mf2_t, vuint16mf2_t, vuint16mf2_t, vuint16mf2_t, vuint16mf2_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vsuxseg6ei8_v)))
void vsuxseg6ei8(uint16_t *, vuint8mf8_t, vuint16mf4_t, vuint16mf4_t, vuint16mf4_t, vuint16mf4_t, vuint16mf4_t, vuint16mf4_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vsuxseg6ei8_v_m)))
void vsuxseg6ei8(vbool64_t, uint16_t *, vuint8mf8_t, vuint16mf4_t, vuint16mf4_t, vuint16mf4_t, vuint16mf4_t, vuint16mf4_t, vuint16mf4_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vsuxseg7ei8_v)))
void vsuxseg7ei8(int16_t *, vuint8mf2_t, vint16m1_t, vint16m1_t, vint16m1_t, vint16m1_t, vint16m1_t, vint16m1_t, vint16m1_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vsuxseg7ei8_v_m)))
void vsuxseg7ei8(vbool16_t, int16_t *, vuint8mf2_t, vint16m1_t, vint16m1_t, vint16m1_t, vint16m1_t, vint16m1_t, vint16m1_t, vint16m1_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vsuxseg7ei8_v)))
void vsuxseg7ei8(int16_t *, vuint8mf4_t, vint16mf2_t, vint16mf2_t, vint16mf2_t, vint16mf2_t, vint16mf2_t, vint16mf2_t, vint16mf2_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vsuxseg7ei8_v_m)))
void vsuxseg7ei8(vbool32_t, int16_t *, vuint8mf4_t, vint16mf2_t, vint16mf2_t, vint16mf2_t, vint16mf2_t, vint16mf2_t, vint16mf2_t, vint16mf2_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vsuxseg7ei8_v)))
void vsuxseg7ei8(int16_t *, vuint8mf8_t, vint16mf4_t, vint16mf4_t, vint16mf4_t, vint16mf4_t, vint16mf4_t, vint16mf4_t, vint16mf4_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vsuxseg7ei8_v_m)))
void vsuxseg7ei8(vbool64_t, int16_t *, vuint8mf8_t, vint16mf4_t, vint16mf4_t, vint16mf4_t, vint16mf4_t, vint16mf4_t, vint16mf4_t, vint16mf4_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vsuxseg7ei8_v)))
void vsuxseg7ei8(uint16_t *, vuint8mf2_t, vuint16m1_t, vuint16m1_t, vuint16m1_t, vuint16m1_t, vuint16m1_t, vuint16m1_t, vuint16m1_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vsuxseg7ei8_v_m)))
void vsuxseg7ei8(vbool16_t, uint16_t *, vuint8mf2_t, vuint16m1_t, vuint16m1_t, vuint16m1_t, vuint16m1_t, vuint16m1_t, vuint16m1_t, vuint16m1_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vsuxseg7ei8_v)))
void vsuxseg7ei8(uint16_t *, vuint8mf4_t, vuint16mf2_t, vuint16mf2_t, vuint16mf2_t, vuint16mf2_t, vuint16mf2_t, vuint16mf2_t, vuint16mf2_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vsuxseg7ei8_v_m)))
void vsuxseg7ei8(vbool32_t, uint16_t *, vuint8mf4_t, vuint16mf2_t, vuint16mf2_t, vuint16mf2_t, vuint16mf2_t, vuint16mf2_t, vuint16mf2_t, vuint16mf2_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vsuxseg7ei8_v)))
void vsuxseg7ei8(uint16_t *, vuint8mf8_t, vuint16mf4_t, vuint16mf4_t, vuint16mf4_t, vuint16mf4_t, vuint16mf4_t, vuint16mf4_t, vuint16mf4_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vsuxseg7ei8_v_m)))
void vsuxseg7ei8(vbool64_t, uint16_t *, vuint8mf8_t, vuint16mf4_t, vuint16mf4_t, vuint16mf4_t, vuint16mf4_t, vuint16mf4_t, vuint16mf4_t, vuint16mf4_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vsuxseg8ei8_v)))
void vsuxseg8ei8(int16_t *, vuint8mf2_t, vint16m1_t, vint16m1_t, vint16m1_t, vint16m1_t, vint16m1_t, vint16m1_t, vint16m1_t, vint16m1_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vsuxseg8ei8_v_m)))
void vsuxseg8ei8(vbool16_t, int16_t *, vuint8mf2_t, vint16m1_t, vint16m1_t, vint16m1_t, vint16m1_t, vint16m1_t, vint16m1_t, vint16m1_t, vint16m1_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vsuxseg8ei8_v)))
void vsuxseg8ei8(int16_t *, vuint8mf4_t, vint16mf2_t, vint16mf2_t, vint16mf2_t, vint16mf2_t, vint16mf2_t, vint16mf2_t, vint16mf2_t, vint16mf2_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vsuxseg8ei8_v_m)))
void vsuxseg8ei8(vbool32_t, int16_t *, vuint8mf4_t, vint16mf2_t, vint16mf2_t, vint16mf2_t, vint16mf2_t, vint16mf2_t, vint16mf2_t, vint16mf2_t, vint16mf2_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vsuxseg8ei8_v)))
void vsuxseg8ei8(int16_t *, vuint8mf8_t, vint16mf4_t, vint16mf4_t, vint16mf4_t, vint16mf4_t, vint16mf4_t, vint16mf4_t, vint16mf4_t, vint16mf4_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vsuxseg8ei8_v_m)))
void vsuxseg8ei8(vbool64_t, int16_t *, vuint8mf8_t, vint16mf4_t, vint16mf4_t, vint16mf4_t, vint16mf4_t, vint16mf4_t, vint16mf4_t, vint16mf4_t, vint16mf4_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vsuxseg8ei8_v)))
void vsuxseg8ei8(uint16_t *, vuint8mf2_t, vuint16m1_t, vuint16m1_t, vuint16m1_t, vuint16m1_t, vuint16m1_t, vuint16m1_t, vuint16m1_t, vuint16m1_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vsuxseg8ei8_v_m)))
void vsuxseg8ei8(vbool16_t, uint16_t *, vuint8mf2_t, vuint16m1_t, vuint16m1_t, vuint16m1_t, vuint16m1_t, vuint16m1_t, vuint16m1_t, vuint16m1_t, vuint16m1_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vsuxseg8ei8_v)))
void vsuxseg8ei8(uint16_t *, vuint8mf4_t, vuint16mf2_t, vuint16mf2_t, vuint16mf2_t, vuint16mf2_t, vuint16mf2_t, vuint16mf2_t, vuint16mf2_t, vuint16mf2_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vsuxseg8ei8_v_m)))
void vsuxseg8ei8(vbool32_t, uint16_t *, vuint8mf4_t, vuint16mf2_t, vuint16mf2_t, vuint16mf2_t, vuint16mf2_t, vuint16mf2_t, vuint16mf2_t, vuint16mf2_t, vuint16mf2_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vsuxseg8ei8_v)))
void vsuxseg8ei8(uint16_t *, vuint8mf8_t, vuint16mf4_t, vuint16mf4_t, vuint16mf4_t, vuint16mf4_t, vuint16mf4_t, vuint16mf4_t, vuint16mf4_t, vuint16mf4_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vsuxseg8ei8_v_m)))
void vsuxseg8ei8(vbool64_t, uint16_t *, vuint8mf8_t, vuint16mf4_t, vuint16mf4_t, vuint16mf4_t, vuint16mf4_t, vuint16mf4_t, vuint16mf4_t, vuint16mf4_t, vuint16mf4_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vsuxseg2ei16_v)))
void vsuxseg2ei16(int16_t *, vuint16m1_t, vint16m1_t, vint16m1_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vsuxseg2ei16_v_m)))
void vsuxseg2ei16(vbool16_t, int16_t *, vuint16m1_t, vint16m1_t, vint16m1_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vsuxseg2ei16_v)))
void vsuxseg2ei16(int16_t *, vuint16m2_t, vint16m2_t, vint16m2_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vsuxseg2ei16_v_m)))
void vsuxseg2ei16(vbool8_t, int16_t *, vuint16m2_t, vint16m2_t, vint16m2_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vsuxseg2ei16_v)))
void vsuxseg2ei16(int16_t *, vuint16m4_t, vint16m4_t, vint16m4_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vsuxseg2ei16_v_m)))
void vsuxseg2ei16(vbool4_t, int16_t *, vuint16m4_t, vint16m4_t, vint16m4_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vsuxseg2ei16_v)))
void vsuxseg2ei16(int16_t *, vuint16mf2_t, vint16mf2_t, vint16mf2_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vsuxseg2ei16_v_m)))
void vsuxseg2ei16(vbool32_t, int16_t *, vuint16mf2_t, vint16mf2_t, vint16mf2_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vsuxseg2ei16_v)))
void vsuxseg2ei16(int16_t *, vuint16mf4_t, vint16mf4_t, vint16mf4_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vsuxseg2ei16_v_m)))
void vsuxseg2ei16(vbool64_t, int16_t *, vuint16mf4_t, vint16mf4_t, vint16mf4_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vsuxseg2ei16_v)))
void vsuxseg2ei16(uint16_t *, vuint16m1_t, vuint16m1_t, vuint16m1_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vsuxseg2ei16_v_m)))
void vsuxseg2ei16(vbool16_t, uint16_t *, vuint16m1_t, vuint16m1_t, vuint16m1_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vsuxseg2ei16_v)))
void vsuxseg2ei16(uint16_t *, vuint16m2_t, vuint16m2_t, vuint16m2_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vsuxseg2ei16_v_m)))
void vsuxseg2ei16(vbool8_t, uint16_t *, vuint16m2_t, vuint16m2_t, vuint16m2_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vsuxseg2ei16_v)))
void vsuxseg2ei16(uint16_t *, vuint16m4_t, vuint16m4_t, vuint16m4_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vsuxseg2ei16_v_m)))
void vsuxseg2ei16(vbool4_t, uint16_t *, vuint16m4_t, vuint16m4_t, vuint16m4_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vsuxseg2ei16_v)))
void vsuxseg2ei16(uint16_t *, vuint16mf2_t, vuint16mf2_t, vuint16mf2_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vsuxseg2ei16_v_m)))
void vsuxseg2ei16(vbool32_t, uint16_t *, vuint16mf2_t, vuint16mf2_t, vuint16mf2_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vsuxseg2ei16_v)))
void vsuxseg2ei16(uint16_t *, vuint16mf4_t, vuint16mf4_t, vuint16mf4_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vsuxseg2ei16_v_m)))
void vsuxseg2ei16(vbool64_t, uint16_t *, vuint16mf4_t, vuint16mf4_t, vuint16mf4_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vsuxseg3ei16_v)))
void vsuxseg3ei16(int16_t *, vuint16m1_t, vint16m1_t, vint16m1_t, vint16m1_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vsuxseg3ei16_v_m)))
void vsuxseg3ei16(vbool16_t, int16_t *, vuint16m1_t, vint16m1_t, vint16m1_t, vint16m1_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vsuxseg3ei16_v)))
void vsuxseg3ei16(int16_t *, vuint16m2_t, vint16m2_t, vint16m2_t, vint16m2_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vsuxseg3ei16_v_m)))
void vsuxseg3ei16(vbool8_t, int16_t *, vuint16m2_t, vint16m2_t, vint16m2_t, vint16m2_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vsuxseg3ei16_v)))
void vsuxseg3ei16(int16_t *, vuint16mf2_t, vint16mf2_t, vint16mf2_t, vint16mf2_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vsuxseg3ei16_v_m)))
void vsuxseg3ei16(vbool32_t, int16_t *, vuint16mf2_t, vint16mf2_t, vint16mf2_t, vint16mf2_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vsuxseg3ei16_v)))
void vsuxseg3ei16(int16_t *, vuint16mf4_t, vint16mf4_t, vint16mf4_t, vint16mf4_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vsuxseg3ei16_v_m)))
void vsuxseg3ei16(vbool64_t, int16_t *, vuint16mf4_t, vint16mf4_t, vint16mf4_t, vint16mf4_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vsuxseg3ei16_v)))
void vsuxseg3ei16(uint16_t *, vuint16m1_t, vuint16m1_t, vuint16m1_t, vuint16m1_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vsuxseg3ei16_v_m)))
void vsuxseg3ei16(vbool16_t, uint16_t *, vuint16m1_t, vuint16m1_t, vuint16m1_t, vuint16m1_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vsuxseg3ei16_v)))
void vsuxseg3ei16(uint16_t *, vuint16m2_t, vuint16m2_t, vuint16m2_t, vuint16m2_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vsuxseg3ei16_v_m)))
void vsuxseg3ei16(vbool8_t, uint16_t *, vuint16m2_t, vuint16m2_t, vuint16m2_t, vuint16m2_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vsuxseg3ei16_v)))
void vsuxseg3ei16(uint16_t *, vuint16mf2_t, vuint16mf2_t, vuint16mf2_t, vuint16mf2_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vsuxseg3ei16_v_m)))
void vsuxseg3ei16(vbool32_t, uint16_t *, vuint16mf2_t, vuint16mf2_t, vuint16mf2_t, vuint16mf2_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vsuxseg3ei16_v)))
void vsuxseg3ei16(uint16_t *, vuint16mf4_t, vuint16mf4_t, vuint16mf4_t, vuint16mf4_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vsuxseg3ei16_v_m)))
void vsuxseg3ei16(vbool64_t, uint16_t *, vuint16mf4_t, vuint16mf4_t, vuint16mf4_t, vuint16mf4_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vsuxseg4ei16_v)))
void vsuxseg4ei16(int16_t *, vuint16m1_t, vint16m1_t, vint16m1_t, vint16m1_t, vint16m1_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vsuxseg4ei16_v_m)))
void vsuxseg4ei16(vbool16_t, int16_t *, vuint16m1_t, vint16m1_t, vint16m1_t, vint16m1_t, vint16m1_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vsuxseg4ei16_v)))
void vsuxseg4ei16(int16_t *, vuint16m2_t, vint16m2_t, vint16m2_t, vint16m2_t, vint16m2_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vsuxseg4ei16_v_m)))
void vsuxseg4ei16(vbool8_t, int16_t *, vuint16m2_t, vint16m2_t, vint16m2_t, vint16m2_t, vint16m2_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vsuxseg4ei16_v)))
void vsuxseg4ei16(int16_t *, vuint16mf2_t, vint16mf2_t, vint16mf2_t, vint16mf2_t, vint16mf2_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vsuxseg4ei16_v_m)))
void vsuxseg4ei16(vbool32_t, int16_t *, vuint16mf2_t, vint16mf2_t, vint16mf2_t, vint16mf2_t, vint16mf2_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vsuxseg4ei16_v)))
void vsuxseg4ei16(int16_t *, vuint16mf4_t, vint16mf4_t, vint16mf4_t, vint16mf4_t, vint16mf4_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vsuxseg4ei16_v_m)))
void vsuxseg4ei16(vbool64_t, int16_t *, vuint16mf4_t, vint16mf4_t, vint16mf4_t, vint16mf4_t, vint16mf4_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vsuxseg4ei16_v)))
void vsuxseg4ei16(uint16_t *, vuint16m1_t, vuint16m1_t, vuint16m1_t, vuint16m1_t, vuint16m1_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vsuxseg4ei16_v_m)))
void vsuxseg4ei16(vbool16_t, uint16_t *, vuint16m1_t, vuint16m1_t, vuint16m1_t, vuint16m1_t, vuint16m1_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vsuxseg4ei16_v)))
void vsuxseg4ei16(uint16_t *, vuint16m2_t, vuint16m2_t, vuint16m2_t, vuint16m2_t, vuint16m2_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vsuxseg4ei16_v_m)))
void vsuxseg4ei16(vbool8_t, uint16_t *, vuint16m2_t, vuint16m2_t, vuint16m2_t, vuint16m2_t, vuint16m2_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vsuxseg4ei16_v)))
void vsuxseg4ei16(uint16_t *, vuint16mf2_t, vuint16mf2_t, vuint16mf2_t, vuint16mf2_t, vuint16mf2_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vsuxseg4ei16_v_m)))
void vsuxseg4ei16(vbool32_t, uint16_t *, vuint16mf2_t, vuint16mf2_t, vuint16mf2_t, vuint16mf2_t, vuint16mf2_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vsuxseg4ei16_v)))
void vsuxseg4ei16(uint16_t *, vuint16mf4_t, vuint16mf4_t, vuint16mf4_t, vuint16mf4_t, vuint16mf4_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vsuxseg4ei16_v_m)))
void vsuxseg4ei16(vbool64_t, uint16_t *, vuint16mf4_t, vuint16mf4_t, vuint16mf4_t, vuint16mf4_t, vuint16mf4_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vsuxseg5ei16_v)))
void vsuxseg5ei16(int16_t *, vuint16m1_t, vint16m1_t, vint16m1_t, vint16m1_t, vint16m1_t, vint16m1_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vsuxseg5ei16_v_m)))
void vsuxseg5ei16(vbool16_t, int16_t *, vuint16m1_t, vint16m1_t, vint16m1_t, vint16m1_t, vint16m1_t, vint16m1_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vsuxseg5ei16_v)))
void vsuxseg5ei16(int16_t *, vuint16mf2_t, vint16mf2_t, vint16mf2_t, vint16mf2_t, vint16mf2_t, vint16mf2_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vsuxseg5ei16_v_m)))
void vsuxseg5ei16(vbool32_t, int16_t *, vuint16mf2_t, vint16mf2_t, vint16mf2_t, vint16mf2_t, vint16mf2_t, vint16mf2_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vsuxseg5ei16_v)))
void vsuxseg5ei16(int16_t *, vuint16mf4_t, vint16mf4_t, vint16mf4_t, vint16mf4_t, vint16mf4_t, vint16mf4_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vsuxseg5ei16_v_m)))
void vsuxseg5ei16(vbool64_t, int16_t *, vuint16mf4_t, vint16mf4_t, vint16mf4_t, vint16mf4_t, vint16mf4_t, vint16mf4_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vsuxseg5ei16_v)))
void vsuxseg5ei16(uint16_t *, vuint16m1_t, vuint16m1_t, vuint16m1_t, vuint16m1_t, vuint16m1_t, vuint16m1_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vsuxseg5ei16_v_m)))
void vsuxseg5ei16(vbool16_t, uint16_t *, vuint16m1_t, vuint16m1_t, vuint16m1_t, vuint16m1_t, vuint16m1_t, vuint16m1_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vsuxseg5ei16_v)))
void vsuxseg5ei16(uint16_t *, vuint16mf2_t, vuint16mf2_t, vuint16mf2_t, vuint16mf2_t, vuint16mf2_t, vuint16mf2_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vsuxseg5ei16_v_m)))
void vsuxseg5ei16(vbool32_t, uint16_t *, vuint16mf2_t, vuint16mf2_t, vuint16mf2_t, vuint16mf2_t, vuint16mf2_t, vuint16mf2_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vsuxseg5ei16_v)))
void vsuxseg5ei16(uint16_t *, vuint16mf4_t, vuint16mf4_t, vuint16mf4_t, vuint16mf4_t, vuint16mf4_t, vuint16mf4_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vsuxseg5ei16_v_m)))
void vsuxseg5ei16(vbool64_t, uint16_t *, vuint16mf4_t, vuint16mf4_t, vuint16mf4_t, vuint16mf4_t, vuint16mf4_t, vuint16mf4_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vsuxseg6ei16_v)))
void vsuxseg6ei16(int16_t *, vuint16m1_t, vint16m1_t, vint16m1_t, vint16m1_t, vint16m1_t, vint16m1_t, vint16m1_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vsuxseg6ei16_v_m)))
void vsuxseg6ei16(vbool16_t, int16_t *, vuint16m1_t, vint16m1_t, vint16m1_t, vint16m1_t, vint16m1_t, vint16m1_t, vint16m1_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vsuxseg6ei16_v)))
void vsuxseg6ei16(int16_t *, vuint16mf2_t, vint16mf2_t, vint16mf2_t, vint16mf2_t, vint16mf2_t, vint16mf2_t, vint16mf2_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vsuxseg6ei16_v_m)))
void vsuxseg6ei16(vbool32_t, int16_t *, vuint16mf2_t, vint16mf2_t, vint16mf2_t, vint16mf2_t, vint16mf2_t, vint16mf2_t, vint16mf2_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vsuxseg6ei16_v)))
void vsuxseg6ei16(int16_t *, vuint16mf4_t, vint16mf4_t, vint16mf4_t, vint16mf4_t, vint16mf4_t, vint16mf4_t, vint16mf4_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vsuxseg6ei16_v_m)))
void vsuxseg6ei16(vbool64_t, int16_t *, vuint16mf4_t, vint16mf4_t, vint16mf4_t, vint16mf4_t, vint16mf4_t, vint16mf4_t, vint16mf4_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vsuxseg6ei16_v)))
void vsuxseg6ei16(uint16_t *, vuint16m1_t, vuint16m1_t, vuint16m1_t, vuint16m1_t, vuint16m1_t, vuint16m1_t, vuint16m1_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vsuxseg6ei16_v_m)))
void vsuxseg6ei16(vbool16_t, uint16_t *, vuint16m1_t, vuint16m1_t, vuint16m1_t, vuint16m1_t, vuint16m1_t, vuint16m1_t, vuint16m1_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vsuxseg6ei16_v)))
void vsuxseg6ei16(uint16_t *, vuint16mf2_t, vuint16mf2_t, vuint16mf2_t, vuint16mf2_t, vuint16mf2_t, vuint16mf2_t, vuint16mf2_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vsuxseg6ei16_v_m)))
void vsuxseg6ei16(vbool32_t, uint16_t *, vuint16mf2_t, vuint16mf2_t, vuint16mf2_t, vuint16mf2_t, vuint16mf2_t, vuint16mf2_t, vuint16mf2_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vsuxseg6ei16_v)))
void vsuxseg6ei16(uint16_t *, vuint16mf4_t, vuint16mf4_t, vuint16mf4_t, vuint16mf4_t, vuint16mf4_t, vuint16mf4_t, vuint16mf4_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vsuxseg6ei16_v_m)))
void vsuxseg6ei16(vbool64_t, uint16_t *, vuint16mf4_t, vuint16mf4_t, vuint16mf4_t, vuint16mf4_t, vuint16mf4_t, vuint16mf4_t, vuint16mf4_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vsuxseg7ei16_v)))
void vsuxseg7ei16(int16_t *, vuint16m1_t, vint16m1_t, vint16m1_t, vint16m1_t, vint16m1_t, vint16m1_t, vint16m1_t, vint16m1_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vsuxseg7ei16_v_m)))
void vsuxseg7ei16(vbool16_t, int16_t *, vuint16m1_t, vint16m1_t, vint16m1_t, vint16m1_t, vint16m1_t, vint16m1_t, vint16m1_t, vint16m1_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vsuxseg7ei16_v)))
void vsuxseg7ei16(int16_t *, vuint16mf2_t, vint16mf2_t, vint16mf2_t, vint16mf2_t, vint16mf2_t, vint16mf2_t, vint16mf2_t, vint16mf2_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vsuxseg7ei16_v_m)))
void vsuxseg7ei16(vbool32_t, int16_t *, vuint16mf2_t, vint16mf2_t, vint16mf2_t, vint16mf2_t, vint16mf2_t, vint16mf2_t, vint16mf2_t, vint16mf2_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vsuxseg7ei16_v)))
void vsuxseg7ei16(int16_t *, vuint16mf4_t, vint16mf4_t, vint16mf4_t, vint16mf4_t, vint16mf4_t, vint16mf4_t, vint16mf4_t, vint16mf4_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vsuxseg7ei16_v_m)))
void vsuxseg7ei16(vbool64_t, int16_t *, vuint16mf4_t, vint16mf4_t, vint16mf4_t, vint16mf4_t, vint16mf4_t, vint16mf4_t, vint16mf4_t, vint16mf4_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vsuxseg7ei16_v)))
void vsuxseg7ei16(uint16_t *, vuint16m1_t, vuint16m1_t, vuint16m1_t, vuint16m1_t, vuint16m1_t, vuint16m1_t, vuint16m1_t, vuint16m1_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vsuxseg7ei16_v_m)))
void vsuxseg7ei16(vbool16_t, uint16_t *, vuint16m1_t, vuint16m1_t, vuint16m1_t, vuint16m1_t, vuint16m1_t, vuint16m1_t, vuint16m1_t, vuint16m1_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vsuxseg7ei16_v)))
void vsuxseg7ei16(uint16_t *, vuint16mf2_t, vuint16mf2_t, vuint16mf2_t, vuint16mf2_t, vuint16mf2_t, vuint16mf2_t, vuint16mf2_t, vuint16mf2_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vsuxseg7ei16_v_m)))
void vsuxseg7ei16(vbool32_t, uint16_t *, vuint16mf2_t, vuint16mf2_t, vuint16mf2_t, vuint16mf2_t, vuint16mf2_t, vuint16mf2_t, vuint16mf2_t, vuint16mf2_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vsuxseg7ei16_v)))
void vsuxseg7ei16(uint16_t *, vuint16mf4_t, vuint16mf4_t, vuint16mf4_t, vuint16mf4_t, vuint16mf4_t, vuint16mf4_t, vuint16mf4_t, vuint16mf4_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vsuxseg7ei16_v_m)))
void vsuxseg7ei16(vbool64_t, uint16_t *, vuint16mf4_t, vuint16mf4_t, vuint16mf4_t, vuint16mf4_t, vuint16mf4_t, vuint16mf4_t, vuint16mf4_t, vuint16mf4_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vsuxseg8ei16_v)))
void vsuxseg8ei16(int16_t *, vuint16m1_t, vint16m1_t, vint16m1_t, vint16m1_t, vint16m1_t, vint16m1_t, vint16m1_t, vint16m1_t, vint16m1_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vsuxseg8ei16_v_m)))
void vsuxseg8ei16(vbool16_t, int16_t *, vuint16m1_t, vint16m1_t, vint16m1_t, vint16m1_t, vint16m1_t, vint16m1_t, vint16m1_t, vint16m1_t, vint16m1_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vsuxseg8ei16_v)))
void vsuxseg8ei16(int16_t *, vuint16mf2_t, vint16mf2_t, vint16mf2_t, vint16mf2_t, vint16mf2_t, vint16mf2_t, vint16mf2_t, vint16mf2_t, vint16mf2_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vsuxseg8ei16_v_m)))
void vsuxseg8ei16(vbool32_t, int16_t *, vuint16mf2_t, vint16mf2_t, vint16mf2_t, vint16mf2_t, vint16mf2_t, vint16mf2_t, vint16mf2_t, vint16mf2_t, vint16mf2_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vsuxseg8ei16_v)))
void vsuxseg8ei16(int16_t *, vuint16mf4_t, vint16mf4_t, vint16mf4_t, vint16mf4_t, vint16mf4_t, vint16mf4_t, vint16mf4_t, vint16mf4_t, vint16mf4_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vsuxseg8ei16_v_m)))
void vsuxseg8ei16(vbool64_t, int16_t *, vuint16mf4_t, vint16mf4_t, vint16mf4_t, vint16mf4_t, vint16mf4_t, vint16mf4_t, vint16mf4_t, vint16mf4_t, vint16mf4_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vsuxseg8ei16_v)))
void vsuxseg8ei16(uint16_t *, vuint16m1_t, vuint16m1_t, vuint16m1_t, vuint16m1_t, vuint16m1_t, vuint16m1_t, vuint16m1_t, vuint16m1_t, vuint16m1_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vsuxseg8ei16_v_m)))
void vsuxseg8ei16(vbool16_t, uint16_t *, vuint16m1_t, vuint16m1_t, vuint16m1_t, vuint16m1_t, vuint16m1_t, vuint16m1_t, vuint16m1_t, vuint16m1_t, vuint16m1_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vsuxseg8ei16_v)))
void vsuxseg8ei16(uint16_t *, vuint16mf2_t, vuint16mf2_t, vuint16mf2_t, vuint16mf2_t, vuint16mf2_t, vuint16mf2_t, vuint16mf2_t, vuint16mf2_t, vuint16mf2_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vsuxseg8ei16_v_m)))
void vsuxseg8ei16(vbool32_t, uint16_t *, vuint16mf2_t, vuint16mf2_t, vuint16mf2_t, vuint16mf2_t, vuint16mf2_t, vuint16mf2_t, vuint16mf2_t, vuint16mf2_t, vuint16mf2_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vsuxseg8ei16_v)))
void vsuxseg8ei16(uint16_t *, vuint16mf4_t, vuint16mf4_t, vuint16mf4_t, vuint16mf4_t, vuint16mf4_t, vuint16mf4_t, vuint16mf4_t, vuint16mf4_t, vuint16mf4_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vsuxseg8ei16_v_m)))
void vsuxseg8ei16(vbool64_t, uint16_t *, vuint16mf4_t, vuint16mf4_t, vuint16mf4_t, vuint16mf4_t, vuint16mf4_t, vuint16mf4_t, vuint16mf4_t, vuint16mf4_t, vuint16mf4_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vsuxseg2ei32_v)))
void vsuxseg2ei32(int16_t *, vuint32m2_t, vint16m1_t, vint16m1_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vsuxseg2ei32_v_m)))
void vsuxseg2ei32(vbool16_t, int16_t *, vuint32m2_t, vint16m1_t, vint16m1_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vsuxseg2ei32_v)))
void vsuxseg2ei32(int16_t *, vuint32m4_t, vint16m2_t, vint16m2_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vsuxseg2ei32_v_m)))
void vsuxseg2ei32(vbool8_t, int16_t *, vuint32m4_t, vint16m2_t, vint16m2_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vsuxseg2ei32_v)))
void vsuxseg2ei32(int16_t *, vuint32m8_t, vint16m4_t, vint16m4_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vsuxseg2ei32_v_m)))
void vsuxseg2ei32(vbool4_t, int16_t *, vuint32m8_t, vint16m4_t, vint16m4_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vsuxseg2ei32_v)))
void vsuxseg2ei32(int16_t *, vuint32m1_t, vint16mf2_t, vint16mf2_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vsuxseg2ei32_v_m)))
void vsuxseg2ei32(vbool32_t, int16_t *, vuint32m1_t, vint16mf2_t, vint16mf2_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vsuxseg2ei32_v)))
void vsuxseg2ei32(int16_t *, vuint32mf2_t, vint16mf4_t, vint16mf4_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vsuxseg2ei32_v_m)))
void vsuxseg2ei32(vbool64_t, int16_t *, vuint32mf2_t, vint16mf4_t, vint16mf4_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vsuxseg2ei32_v)))
void vsuxseg2ei32(uint16_t *, vuint32m2_t, vuint16m1_t, vuint16m1_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vsuxseg2ei32_v_m)))
void vsuxseg2ei32(vbool16_t, uint16_t *, vuint32m2_t, vuint16m1_t, vuint16m1_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vsuxseg2ei32_v)))
void vsuxseg2ei32(uint16_t *, vuint32m4_t, vuint16m2_t, vuint16m2_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vsuxseg2ei32_v_m)))
void vsuxseg2ei32(vbool8_t, uint16_t *, vuint32m4_t, vuint16m2_t, vuint16m2_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vsuxseg2ei32_v)))
void vsuxseg2ei32(uint16_t *, vuint32m8_t, vuint16m4_t, vuint16m4_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vsuxseg2ei32_v_m)))
void vsuxseg2ei32(vbool4_t, uint16_t *, vuint32m8_t, vuint16m4_t, vuint16m4_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vsuxseg2ei32_v)))
void vsuxseg2ei32(uint16_t *, vuint32m1_t, vuint16mf2_t, vuint16mf2_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vsuxseg2ei32_v_m)))
void vsuxseg2ei32(vbool32_t, uint16_t *, vuint32m1_t, vuint16mf2_t, vuint16mf2_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vsuxseg2ei32_v)))
void vsuxseg2ei32(uint16_t *, vuint32mf2_t, vuint16mf4_t, vuint16mf4_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vsuxseg2ei32_v_m)))
void vsuxseg2ei32(vbool64_t, uint16_t *, vuint32mf2_t, vuint16mf4_t, vuint16mf4_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vsuxseg3ei32_v)))
void vsuxseg3ei32(int16_t *, vuint32m2_t, vint16m1_t, vint16m1_t, vint16m1_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vsuxseg3ei32_v_m)))
void vsuxseg3ei32(vbool16_t, int16_t *, vuint32m2_t, vint16m1_t, vint16m1_t, vint16m1_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vsuxseg3ei32_v)))
void vsuxseg3ei32(int16_t *, vuint32m4_t, vint16m2_t, vint16m2_t, vint16m2_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vsuxseg3ei32_v_m)))
void vsuxseg3ei32(vbool8_t, int16_t *, vuint32m4_t, vint16m2_t, vint16m2_t, vint16m2_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vsuxseg3ei32_v)))
void vsuxseg3ei32(int16_t *, vuint32m1_t, vint16mf2_t, vint16mf2_t, vint16mf2_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vsuxseg3ei32_v_m)))
void vsuxseg3ei32(vbool32_t, int16_t *, vuint32m1_t, vint16mf2_t, vint16mf2_t, vint16mf2_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vsuxseg3ei32_v)))
void vsuxseg3ei32(int16_t *, vuint32mf2_t, vint16mf4_t, vint16mf4_t, vint16mf4_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vsuxseg3ei32_v_m)))
void vsuxseg3ei32(vbool64_t, int16_t *, vuint32mf2_t, vint16mf4_t, vint16mf4_t, vint16mf4_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vsuxseg3ei32_v)))
void vsuxseg3ei32(uint16_t *, vuint32m2_t, vuint16m1_t, vuint16m1_t, vuint16m1_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vsuxseg3ei32_v_m)))
void vsuxseg3ei32(vbool16_t, uint16_t *, vuint32m2_t, vuint16m1_t, vuint16m1_t, vuint16m1_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vsuxseg3ei32_v)))
void vsuxseg3ei32(uint16_t *, vuint32m4_t, vuint16m2_t, vuint16m2_t, vuint16m2_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vsuxseg3ei32_v_m)))
void vsuxseg3ei32(vbool8_t, uint16_t *, vuint32m4_t, vuint16m2_t, vuint16m2_t, vuint16m2_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vsuxseg3ei32_v)))
void vsuxseg3ei32(uint16_t *, vuint32m1_t, vuint16mf2_t, vuint16mf2_t, vuint16mf2_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vsuxseg3ei32_v_m)))
void vsuxseg3ei32(vbool32_t, uint16_t *, vuint32m1_t, vuint16mf2_t, vuint16mf2_t, vuint16mf2_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vsuxseg3ei32_v)))
void vsuxseg3ei32(uint16_t *, vuint32mf2_t, vuint16mf4_t, vuint16mf4_t, vuint16mf4_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vsuxseg3ei32_v_m)))
void vsuxseg3ei32(vbool64_t, uint16_t *, vuint32mf2_t, vuint16mf4_t, vuint16mf4_t, vuint16mf4_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vsuxseg4ei32_v)))
void vsuxseg4ei32(int16_t *, vuint32m2_t, vint16m1_t, vint16m1_t, vint16m1_t, vint16m1_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vsuxseg4ei32_v_m)))
void vsuxseg4ei32(vbool16_t, int16_t *, vuint32m2_t, vint16m1_t, vint16m1_t, vint16m1_t, vint16m1_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vsuxseg4ei32_v)))
void vsuxseg4ei32(int16_t *, vuint32m4_t, vint16m2_t, vint16m2_t, vint16m2_t, vint16m2_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vsuxseg4ei32_v_m)))
void vsuxseg4ei32(vbool8_t, int16_t *, vuint32m4_t, vint16m2_t, vint16m2_t, vint16m2_t, vint16m2_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vsuxseg4ei32_v)))
void vsuxseg4ei32(int16_t *, vuint32m1_t, vint16mf2_t, vint16mf2_t, vint16mf2_t, vint16mf2_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vsuxseg4ei32_v_m)))
void vsuxseg4ei32(vbool32_t, int16_t *, vuint32m1_t, vint16mf2_t, vint16mf2_t, vint16mf2_t, vint16mf2_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vsuxseg4ei32_v)))
void vsuxseg4ei32(int16_t *, vuint32mf2_t, vint16mf4_t, vint16mf4_t, vint16mf4_t, vint16mf4_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vsuxseg4ei32_v_m)))
void vsuxseg4ei32(vbool64_t, int16_t *, vuint32mf2_t, vint16mf4_t, vint16mf4_t, vint16mf4_t, vint16mf4_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vsuxseg4ei32_v)))
void vsuxseg4ei32(uint16_t *, vuint32m2_t, vuint16m1_t, vuint16m1_t, vuint16m1_t, vuint16m1_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vsuxseg4ei32_v_m)))
void vsuxseg4ei32(vbool16_t, uint16_t *, vuint32m2_t, vuint16m1_t, vuint16m1_t, vuint16m1_t, vuint16m1_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vsuxseg4ei32_v)))
void vsuxseg4ei32(uint16_t *, vuint32m4_t, vuint16m2_t, vuint16m2_t, vuint16m2_t, vuint16m2_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vsuxseg4ei32_v_m)))
void vsuxseg4ei32(vbool8_t, uint16_t *, vuint32m4_t, vuint16m2_t, vuint16m2_t, vuint16m2_t, vuint16m2_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vsuxseg4ei32_v)))
void vsuxseg4ei32(uint16_t *, vuint32m1_t, vuint16mf2_t, vuint16mf2_t, vuint16mf2_t, vuint16mf2_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vsuxseg4ei32_v_m)))
void vsuxseg4ei32(vbool32_t, uint16_t *, vuint32m1_t, vuint16mf2_t, vuint16mf2_t, vuint16mf2_t, vuint16mf2_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vsuxseg4ei32_v)))
void vsuxseg4ei32(uint16_t *, vuint32mf2_t, vuint16mf4_t, vuint16mf4_t, vuint16mf4_t, vuint16mf4_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vsuxseg4ei32_v_m)))
void vsuxseg4ei32(vbool64_t, uint16_t *, vuint32mf2_t, vuint16mf4_t, vuint16mf4_t, vuint16mf4_t, vuint16mf4_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vsuxseg5ei32_v)))
void vsuxseg5ei32(int16_t *, vuint32m2_t, vint16m1_t, vint16m1_t, vint16m1_t, vint16m1_t, vint16m1_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vsuxseg5ei32_v_m)))
void vsuxseg5ei32(vbool16_t, int16_t *, vuint32m2_t, vint16m1_t, vint16m1_t, vint16m1_t, vint16m1_t, vint16m1_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vsuxseg5ei32_v)))
void vsuxseg5ei32(int16_t *, vuint32m1_t, vint16mf2_t, vint16mf2_t, vint16mf2_t, vint16mf2_t, vint16mf2_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vsuxseg5ei32_v_m)))
void vsuxseg5ei32(vbool32_t, int16_t *, vuint32m1_t, vint16mf2_t, vint16mf2_t, vint16mf2_t, vint16mf2_t, vint16mf2_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vsuxseg5ei32_v)))
void vsuxseg5ei32(int16_t *, vuint32mf2_t, vint16mf4_t, vint16mf4_t, vint16mf4_t, vint16mf4_t, vint16mf4_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vsuxseg5ei32_v_m)))
void vsuxseg5ei32(vbool64_t, int16_t *, vuint32mf2_t, vint16mf4_t, vint16mf4_t, vint16mf4_t, vint16mf4_t, vint16mf4_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vsuxseg5ei32_v)))
void vsuxseg5ei32(uint16_t *, vuint32m2_t, vuint16m1_t, vuint16m1_t, vuint16m1_t, vuint16m1_t, vuint16m1_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vsuxseg5ei32_v_m)))
void vsuxseg5ei32(vbool16_t, uint16_t *, vuint32m2_t, vuint16m1_t, vuint16m1_t, vuint16m1_t, vuint16m1_t, vuint16m1_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vsuxseg5ei32_v)))
void vsuxseg5ei32(uint16_t *, vuint32m1_t, vuint16mf2_t, vuint16mf2_t, vuint16mf2_t, vuint16mf2_t, vuint16mf2_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vsuxseg5ei32_v_m)))
void vsuxseg5ei32(vbool32_t, uint16_t *, vuint32m1_t, vuint16mf2_t, vuint16mf2_t, vuint16mf2_t, vuint16mf2_t, vuint16mf2_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vsuxseg5ei32_v)))
void vsuxseg5ei32(uint16_t *, vuint32mf2_t, vuint16mf4_t, vuint16mf4_t, vuint16mf4_t, vuint16mf4_t, vuint16mf4_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vsuxseg5ei32_v_m)))
void vsuxseg5ei32(vbool64_t, uint16_t *, vuint32mf2_t, vuint16mf4_t, vuint16mf4_t, vuint16mf4_t, vuint16mf4_t, vuint16mf4_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vsuxseg6ei32_v)))
void vsuxseg6ei32(int16_t *, vuint32m2_t, vint16m1_t, vint16m1_t, vint16m1_t, vint16m1_t, vint16m1_t, vint16m1_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vsuxseg6ei32_v_m)))
void vsuxseg6ei32(vbool16_t, int16_t *, vuint32m2_t, vint16m1_t, vint16m1_t, vint16m1_t, vint16m1_t, vint16m1_t, vint16m1_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vsuxseg6ei32_v)))
void vsuxseg6ei32(int16_t *, vuint32m1_t, vint16mf2_t, vint16mf2_t, vint16mf2_t, vint16mf2_t, vint16mf2_t, vint16mf2_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vsuxseg6ei32_v_m)))
void vsuxseg6ei32(vbool32_t, int16_t *, vuint32m1_t, vint16mf2_t, vint16mf2_t, vint16mf2_t, vint16mf2_t, vint16mf2_t, vint16mf2_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vsuxseg6ei32_v)))
void vsuxseg6ei32(int16_t *, vuint32mf2_t, vint16mf4_t, vint16mf4_t, vint16mf4_t, vint16mf4_t, vint16mf4_t, vint16mf4_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vsuxseg6ei32_v_m)))
void vsuxseg6ei32(vbool64_t, int16_t *, vuint32mf2_t, vint16mf4_t, vint16mf4_t, vint16mf4_t, vint16mf4_t, vint16mf4_t, vint16mf4_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vsuxseg6ei32_v)))
void vsuxseg6ei32(uint16_t *, vuint32m2_t, vuint16m1_t, vuint16m1_t, vuint16m1_t, vuint16m1_t, vuint16m1_t, vuint16m1_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vsuxseg6ei32_v_m)))
void vsuxseg6ei32(vbool16_t, uint16_t *, vuint32m2_t, vuint16m1_t, vuint16m1_t, vuint16m1_t, vuint16m1_t, vuint16m1_t, vuint16m1_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vsuxseg6ei32_v)))
void vsuxseg6ei32(uint16_t *, vuint32m1_t, vuint16mf2_t, vuint16mf2_t, vuint16mf2_t, vuint16mf2_t, vuint16mf2_t, vuint16mf2_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vsuxseg6ei32_v_m)))
void vsuxseg6ei32(vbool32_t, uint16_t *, vuint32m1_t, vuint16mf2_t, vuint16mf2_t, vuint16mf2_t, vuint16mf2_t, vuint16mf2_t, vuint16mf2_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vsuxseg6ei32_v)))
void vsuxseg6ei32(uint16_t *, vuint32mf2_t, vuint16mf4_t, vuint16mf4_t, vuint16mf4_t, vuint16mf4_t, vuint16mf4_t, vuint16mf4_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vsuxseg6ei32_v_m)))
void vsuxseg6ei32(vbool64_t, uint16_t *, vuint32mf2_t, vuint16mf4_t, vuint16mf4_t, vuint16mf4_t, vuint16mf4_t, vuint16mf4_t, vuint16mf4_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vsuxseg7ei32_v)))
void vsuxseg7ei32(int16_t *, vuint32m2_t, vint16m1_t, vint16m1_t, vint16m1_t, vint16m1_t, vint16m1_t, vint16m1_t, vint16m1_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vsuxseg7ei32_v_m)))
void vsuxseg7ei32(vbool16_t, int16_t *, vuint32m2_t, vint16m1_t, vint16m1_t, vint16m1_t, vint16m1_t, vint16m1_t, vint16m1_t, vint16m1_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vsuxseg7ei32_v)))
void vsuxseg7ei32(int16_t *, vuint32m1_t, vint16mf2_t, vint16mf2_t, vint16mf2_t, vint16mf2_t, vint16mf2_t, vint16mf2_t, vint16mf2_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vsuxseg7ei32_v_m)))
void vsuxseg7ei32(vbool32_t, int16_t *, vuint32m1_t, vint16mf2_t, vint16mf2_t, vint16mf2_t, vint16mf2_t, vint16mf2_t, vint16mf2_t, vint16mf2_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vsuxseg7ei32_v)))
void vsuxseg7ei32(int16_t *, vuint32mf2_t, vint16mf4_t, vint16mf4_t, vint16mf4_t, vint16mf4_t, vint16mf4_t, vint16mf4_t, vint16mf4_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vsuxseg7ei32_v_m)))
void vsuxseg7ei32(vbool64_t, int16_t *, vuint32mf2_t, vint16mf4_t, vint16mf4_t, vint16mf4_t, vint16mf4_t, vint16mf4_t, vint16mf4_t, vint16mf4_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vsuxseg7ei32_v)))
void vsuxseg7ei32(uint16_t *, vuint32m2_t, vuint16m1_t, vuint16m1_t, vuint16m1_t, vuint16m1_t, vuint16m1_t, vuint16m1_t, vuint16m1_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vsuxseg7ei32_v_m)))
void vsuxseg7ei32(vbool16_t, uint16_t *, vuint32m2_t, vuint16m1_t, vuint16m1_t, vuint16m1_t, vuint16m1_t, vuint16m1_t, vuint16m1_t, vuint16m1_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vsuxseg7ei32_v)))
void vsuxseg7ei32(uint16_t *, vuint32m1_t, vuint16mf2_t, vuint16mf2_t, vuint16mf2_t, vuint16mf2_t, vuint16mf2_t, vuint16mf2_t, vuint16mf2_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vsuxseg7ei32_v_m)))
void vsuxseg7ei32(vbool32_t, uint16_t *, vuint32m1_t, vuint16mf2_t, vuint16mf2_t, vuint16mf2_t, vuint16mf2_t, vuint16mf2_t, vuint16mf2_t, vuint16mf2_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vsuxseg7ei32_v)))
void vsuxseg7ei32(uint16_t *, vuint32mf2_t, vuint16mf4_t, vuint16mf4_t, vuint16mf4_t, vuint16mf4_t, vuint16mf4_t, vuint16mf4_t, vuint16mf4_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vsuxseg7ei32_v_m)))
void vsuxseg7ei32(vbool64_t, uint16_t *, vuint32mf2_t, vuint16mf4_t, vuint16mf4_t, vuint16mf4_t, vuint16mf4_t, vuint16mf4_t, vuint16mf4_t, vuint16mf4_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vsuxseg8ei32_v)))
void vsuxseg8ei32(int16_t *, vuint32m2_t, vint16m1_t, vint16m1_t, vint16m1_t, vint16m1_t, vint16m1_t, vint16m1_t, vint16m1_t, vint16m1_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vsuxseg8ei32_v_m)))
void vsuxseg8ei32(vbool16_t, int16_t *, vuint32m2_t, vint16m1_t, vint16m1_t, vint16m1_t, vint16m1_t, vint16m1_t, vint16m1_t, vint16m1_t, vint16m1_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vsuxseg8ei32_v)))
void vsuxseg8ei32(int16_t *, vuint32m1_t, vint16mf2_t, vint16mf2_t, vint16mf2_t, vint16mf2_t, vint16mf2_t, vint16mf2_t, vint16mf2_t, vint16mf2_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vsuxseg8ei32_v_m)))
void vsuxseg8ei32(vbool32_t, int16_t *, vuint32m1_t, vint16mf2_t, vint16mf2_t, vint16mf2_t, vint16mf2_t, vint16mf2_t, vint16mf2_t, vint16mf2_t, vint16mf2_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vsuxseg8ei32_v)))
void vsuxseg8ei32(int16_t *, vuint32mf2_t, vint16mf4_t, vint16mf4_t, vint16mf4_t, vint16mf4_t, vint16mf4_t, vint16mf4_t, vint16mf4_t, vint16mf4_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vsuxseg8ei32_v_m)))
void vsuxseg8ei32(vbool64_t, int16_t *, vuint32mf2_t, vint16mf4_t, vint16mf4_t, vint16mf4_t, vint16mf4_t, vint16mf4_t, vint16mf4_t, vint16mf4_t, vint16mf4_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vsuxseg8ei32_v)))
void vsuxseg8ei32(uint16_t *, vuint32m2_t, vuint16m1_t, vuint16m1_t, vuint16m1_t, vuint16m1_t, vuint16m1_t, vuint16m1_t, vuint16m1_t, vuint16m1_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vsuxseg8ei32_v_m)))
void vsuxseg8ei32(vbool16_t, uint16_t *, vuint32m2_t, vuint16m1_t, vuint16m1_t, vuint16m1_t, vuint16m1_t, vuint16m1_t, vuint16m1_t, vuint16m1_t, vuint16m1_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vsuxseg8ei32_v)))
void vsuxseg8ei32(uint16_t *, vuint32m1_t, vuint16mf2_t, vuint16mf2_t, vuint16mf2_t, vuint16mf2_t, vuint16mf2_t, vuint16mf2_t, vuint16mf2_t, vuint16mf2_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vsuxseg8ei32_v_m)))
void vsuxseg8ei32(vbool32_t, uint16_t *, vuint32m1_t, vuint16mf2_t, vuint16mf2_t, vuint16mf2_t, vuint16mf2_t, vuint16mf2_t, vuint16mf2_t, vuint16mf2_t, vuint16mf2_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vsuxseg8ei32_v)))
void vsuxseg8ei32(uint16_t *, vuint32mf2_t, vuint16mf4_t, vuint16mf4_t, vuint16mf4_t, vuint16mf4_t, vuint16mf4_t, vuint16mf4_t, vuint16mf4_t, vuint16mf4_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vsuxseg8ei32_v_m)))
void vsuxseg8ei32(vbool64_t, uint16_t *, vuint32mf2_t, vuint16mf4_t, vuint16mf4_t, vuint16mf4_t, vuint16mf4_t, vuint16mf4_t, vuint16mf4_t, vuint16mf4_t, vuint16mf4_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vsuxseg2ei8_v)))
void vsuxseg2ei8(int32_t *, vuint8mf4_t, vint32m1_t, vint32m1_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vsuxseg2ei8_v_m)))
void vsuxseg2ei8(vbool32_t, int32_t *, vuint8mf4_t, vint32m1_t, vint32m1_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vsuxseg2ei8_v)))
void vsuxseg2ei8(int32_t *, vuint8mf2_t, vint32m2_t, vint32m2_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vsuxseg2ei8_v_m)))
void vsuxseg2ei8(vbool16_t, int32_t *, vuint8mf2_t, vint32m2_t, vint32m2_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vsuxseg2ei8_v)))
void vsuxseg2ei8(int32_t *, vuint8m1_t, vint32m4_t, vint32m4_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vsuxseg2ei8_v_m)))
void vsuxseg2ei8(vbool8_t, int32_t *, vuint8m1_t, vint32m4_t, vint32m4_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vsuxseg2ei8_v)))
void vsuxseg2ei8(int32_t *, vuint8mf8_t, vint32mf2_t, vint32mf2_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vsuxseg2ei8_v_m)))
void vsuxseg2ei8(vbool64_t, int32_t *, vuint8mf8_t, vint32mf2_t, vint32mf2_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vsuxseg2ei8_v)))
void vsuxseg2ei8(uint32_t *, vuint8mf4_t, vuint32m1_t, vuint32m1_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vsuxseg2ei8_v_m)))
void vsuxseg2ei8(vbool32_t, uint32_t *, vuint8mf4_t, vuint32m1_t, vuint32m1_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vsuxseg2ei8_v)))
void vsuxseg2ei8(uint32_t *, vuint8mf2_t, vuint32m2_t, vuint32m2_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vsuxseg2ei8_v_m)))
void vsuxseg2ei8(vbool16_t, uint32_t *, vuint8mf2_t, vuint32m2_t, vuint32m2_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vsuxseg2ei8_v)))
void vsuxseg2ei8(uint32_t *, vuint8m1_t, vuint32m4_t, vuint32m4_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vsuxseg2ei8_v_m)))
void vsuxseg2ei8(vbool8_t, uint32_t *, vuint8m1_t, vuint32m4_t, vuint32m4_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vsuxseg2ei8_v)))
void vsuxseg2ei8(uint32_t *, vuint8mf8_t, vuint32mf2_t, vuint32mf2_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vsuxseg2ei8_v_m)))
void vsuxseg2ei8(vbool64_t, uint32_t *, vuint8mf8_t, vuint32mf2_t, vuint32mf2_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vsuxseg3ei8_v)))
void vsuxseg3ei8(int32_t *, vuint8mf4_t, vint32m1_t, vint32m1_t, vint32m1_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vsuxseg3ei8_v_m)))
void vsuxseg3ei8(vbool32_t, int32_t *, vuint8mf4_t, vint32m1_t, vint32m1_t, vint32m1_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vsuxseg3ei8_v)))
void vsuxseg3ei8(int32_t *, vuint8mf2_t, vint32m2_t, vint32m2_t, vint32m2_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vsuxseg3ei8_v_m)))
void vsuxseg3ei8(vbool16_t, int32_t *, vuint8mf2_t, vint32m2_t, vint32m2_t, vint32m2_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vsuxseg3ei8_v)))
void vsuxseg3ei8(int32_t *, vuint8mf8_t, vint32mf2_t, vint32mf2_t, vint32mf2_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vsuxseg3ei8_v_m)))
void vsuxseg3ei8(vbool64_t, int32_t *, vuint8mf8_t, vint32mf2_t, vint32mf2_t, vint32mf2_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vsuxseg3ei8_v)))
void vsuxseg3ei8(uint32_t *, vuint8mf4_t, vuint32m1_t, vuint32m1_t, vuint32m1_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vsuxseg3ei8_v_m)))
void vsuxseg3ei8(vbool32_t, uint32_t *, vuint8mf4_t, vuint32m1_t, vuint32m1_t, vuint32m1_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vsuxseg3ei8_v)))
void vsuxseg3ei8(uint32_t *, vuint8mf2_t, vuint32m2_t, vuint32m2_t, vuint32m2_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vsuxseg3ei8_v_m)))
void vsuxseg3ei8(vbool16_t, uint32_t *, vuint8mf2_t, vuint32m2_t, vuint32m2_t, vuint32m2_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vsuxseg3ei8_v)))
void vsuxseg3ei8(uint32_t *, vuint8mf8_t, vuint32mf2_t, vuint32mf2_t, vuint32mf2_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vsuxseg3ei8_v_m)))
void vsuxseg3ei8(vbool64_t, uint32_t *, vuint8mf8_t, vuint32mf2_t, vuint32mf2_t, vuint32mf2_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vsuxseg4ei8_v)))
void vsuxseg4ei8(int32_t *, vuint8mf4_t, vint32m1_t, vint32m1_t, vint32m1_t, vint32m1_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vsuxseg4ei8_v_m)))
void vsuxseg4ei8(vbool32_t, int32_t *, vuint8mf4_t, vint32m1_t, vint32m1_t, vint32m1_t, vint32m1_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vsuxseg4ei8_v)))
void vsuxseg4ei8(int32_t *, vuint8mf2_t, vint32m2_t, vint32m2_t, vint32m2_t, vint32m2_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vsuxseg4ei8_v_m)))
void vsuxseg4ei8(vbool16_t, int32_t *, vuint8mf2_t, vint32m2_t, vint32m2_t, vint32m2_t, vint32m2_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vsuxseg4ei8_v)))
void vsuxseg4ei8(int32_t *, vuint8mf8_t, vint32mf2_t, vint32mf2_t, vint32mf2_t, vint32mf2_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vsuxseg4ei8_v_m)))
void vsuxseg4ei8(vbool64_t, int32_t *, vuint8mf8_t, vint32mf2_t, vint32mf2_t, vint32mf2_t, vint32mf2_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vsuxseg4ei8_v)))
void vsuxseg4ei8(uint32_t *, vuint8mf4_t, vuint32m1_t, vuint32m1_t, vuint32m1_t, vuint32m1_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vsuxseg4ei8_v_m)))
void vsuxseg4ei8(vbool32_t, uint32_t *, vuint8mf4_t, vuint32m1_t, vuint32m1_t, vuint32m1_t, vuint32m1_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vsuxseg4ei8_v)))
void vsuxseg4ei8(uint32_t *, vuint8mf2_t, vuint32m2_t, vuint32m2_t, vuint32m2_t, vuint32m2_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vsuxseg4ei8_v_m)))
void vsuxseg4ei8(vbool16_t, uint32_t *, vuint8mf2_t, vuint32m2_t, vuint32m2_t, vuint32m2_t, vuint32m2_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vsuxseg4ei8_v)))
void vsuxseg4ei8(uint32_t *, vuint8mf8_t, vuint32mf2_t, vuint32mf2_t, vuint32mf2_t, vuint32mf2_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vsuxseg4ei8_v_m)))
void vsuxseg4ei8(vbool64_t, uint32_t *, vuint8mf8_t, vuint32mf2_t, vuint32mf2_t, vuint32mf2_t, vuint32mf2_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vsuxseg5ei8_v)))
void vsuxseg5ei8(int32_t *, vuint8mf4_t, vint32m1_t, vint32m1_t, vint32m1_t, vint32m1_t, vint32m1_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vsuxseg5ei8_v_m)))
void vsuxseg5ei8(vbool32_t, int32_t *, vuint8mf4_t, vint32m1_t, vint32m1_t, vint32m1_t, vint32m1_t, vint32m1_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vsuxseg5ei8_v)))
void vsuxseg5ei8(int32_t *, vuint8mf8_t, vint32mf2_t, vint32mf2_t, vint32mf2_t, vint32mf2_t, vint32mf2_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vsuxseg5ei8_v_m)))
void vsuxseg5ei8(vbool64_t, int32_t *, vuint8mf8_t, vint32mf2_t, vint32mf2_t, vint32mf2_t, vint32mf2_t, vint32mf2_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vsuxseg5ei8_v)))
void vsuxseg5ei8(uint32_t *, vuint8mf4_t, vuint32m1_t, vuint32m1_t, vuint32m1_t, vuint32m1_t, vuint32m1_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vsuxseg5ei8_v_m)))
void vsuxseg5ei8(vbool32_t, uint32_t *, vuint8mf4_t, vuint32m1_t, vuint32m1_t, vuint32m1_t, vuint32m1_t, vuint32m1_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vsuxseg5ei8_v)))
void vsuxseg5ei8(uint32_t *, vuint8mf8_t, vuint32mf2_t, vuint32mf2_t, vuint32mf2_t, vuint32mf2_t, vuint32mf2_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vsuxseg5ei8_v_m)))
void vsuxseg5ei8(vbool64_t, uint32_t *, vuint8mf8_t, vuint32mf2_t, vuint32mf2_t, vuint32mf2_t, vuint32mf2_t, vuint32mf2_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vsuxseg6ei8_v)))
void vsuxseg6ei8(int32_t *, vuint8mf4_t, vint32m1_t, vint32m1_t, vint32m1_t, vint32m1_t, vint32m1_t, vint32m1_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vsuxseg6ei8_v_m)))
void vsuxseg6ei8(vbool32_t, int32_t *, vuint8mf4_t, vint32m1_t, vint32m1_t, vint32m1_t, vint32m1_t, vint32m1_t, vint32m1_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vsuxseg6ei8_v)))
void vsuxseg6ei8(int32_t *, vuint8mf8_t, vint32mf2_t, vint32mf2_t, vint32mf2_t, vint32mf2_t, vint32mf2_t, vint32mf2_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vsuxseg6ei8_v_m)))
void vsuxseg6ei8(vbool64_t, int32_t *, vuint8mf8_t, vint32mf2_t, vint32mf2_t, vint32mf2_t, vint32mf2_t, vint32mf2_t, vint32mf2_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vsuxseg6ei8_v)))
void vsuxseg6ei8(uint32_t *, vuint8mf4_t, vuint32m1_t, vuint32m1_t, vuint32m1_t, vuint32m1_t, vuint32m1_t, vuint32m1_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vsuxseg6ei8_v_m)))
void vsuxseg6ei8(vbool32_t, uint32_t *, vuint8mf4_t, vuint32m1_t, vuint32m1_t, vuint32m1_t, vuint32m1_t, vuint32m1_t, vuint32m1_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vsuxseg6ei8_v)))
void vsuxseg6ei8(uint32_t *, vuint8mf8_t, vuint32mf2_t, vuint32mf2_t, vuint32mf2_t, vuint32mf2_t, vuint32mf2_t, vuint32mf2_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vsuxseg6ei8_v_m)))
void vsuxseg6ei8(vbool64_t, uint32_t *, vuint8mf8_t, vuint32mf2_t, vuint32mf2_t, vuint32mf2_t, vuint32mf2_t, vuint32mf2_t, vuint32mf2_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vsuxseg7ei8_v)))
void vsuxseg7ei8(int32_t *, vuint8mf4_t, vint32m1_t, vint32m1_t, vint32m1_t, vint32m1_t, vint32m1_t, vint32m1_t, vint32m1_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vsuxseg7ei8_v_m)))
void vsuxseg7ei8(vbool32_t, int32_t *, vuint8mf4_t, vint32m1_t, vint32m1_t, vint32m1_t, vint32m1_t, vint32m1_t, vint32m1_t, vint32m1_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vsuxseg7ei8_v)))
void vsuxseg7ei8(int32_t *, vuint8mf8_t, vint32mf2_t, vint32mf2_t, vint32mf2_t, vint32mf2_t, vint32mf2_t, vint32mf2_t, vint32mf2_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vsuxseg7ei8_v_m)))
void vsuxseg7ei8(vbool64_t, int32_t *, vuint8mf8_t, vint32mf2_t, vint32mf2_t, vint32mf2_t, vint32mf2_t, vint32mf2_t, vint32mf2_t, vint32mf2_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vsuxseg7ei8_v)))
void vsuxseg7ei8(uint32_t *, vuint8mf4_t, vuint32m1_t, vuint32m1_t, vuint32m1_t, vuint32m1_t, vuint32m1_t, vuint32m1_t, vuint32m1_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vsuxseg7ei8_v_m)))
void vsuxseg7ei8(vbool32_t, uint32_t *, vuint8mf4_t, vuint32m1_t, vuint32m1_t, vuint32m1_t, vuint32m1_t, vuint32m1_t, vuint32m1_t, vuint32m1_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vsuxseg7ei8_v)))
void vsuxseg7ei8(uint32_t *, vuint8mf8_t, vuint32mf2_t, vuint32mf2_t, vuint32mf2_t, vuint32mf2_t, vuint32mf2_t, vuint32mf2_t, vuint32mf2_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vsuxseg7ei8_v_m)))
void vsuxseg7ei8(vbool64_t, uint32_t *, vuint8mf8_t, vuint32mf2_t, vuint32mf2_t, vuint32mf2_t, vuint32mf2_t, vuint32mf2_t, vuint32mf2_t, vuint32mf2_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vsuxseg8ei8_v)))
void vsuxseg8ei8(int32_t *, vuint8mf4_t, vint32m1_t, vint32m1_t, vint32m1_t, vint32m1_t, vint32m1_t, vint32m1_t, vint32m1_t, vint32m1_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vsuxseg8ei8_v_m)))
void vsuxseg8ei8(vbool32_t, int32_t *, vuint8mf4_t, vint32m1_t, vint32m1_t, vint32m1_t, vint32m1_t, vint32m1_t, vint32m1_t, vint32m1_t, vint32m1_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vsuxseg8ei8_v)))
void vsuxseg8ei8(int32_t *, vuint8mf8_t, vint32mf2_t, vint32mf2_t, vint32mf2_t, vint32mf2_t, vint32mf2_t, vint32mf2_t, vint32mf2_t, vint32mf2_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vsuxseg8ei8_v_m)))
void vsuxseg8ei8(vbool64_t, int32_t *, vuint8mf8_t, vint32mf2_t, vint32mf2_t, vint32mf2_t, vint32mf2_t, vint32mf2_t, vint32mf2_t, vint32mf2_t, vint32mf2_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vsuxseg8ei8_v)))
void vsuxseg8ei8(uint32_t *, vuint8mf4_t, vuint32m1_t, vuint32m1_t, vuint32m1_t, vuint32m1_t, vuint32m1_t, vuint32m1_t, vuint32m1_t, vuint32m1_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vsuxseg8ei8_v_m)))
void vsuxseg8ei8(vbool32_t, uint32_t *, vuint8mf4_t, vuint32m1_t, vuint32m1_t, vuint32m1_t, vuint32m1_t, vuint32m1_t, vuint32m1_t, vuint32m1_t, vuint32m1_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vsuxseg8ei8_v)))
void vsuxseg8ei8(uint32_t *, vuint8mf8_t, vuint32mf2_t, vuint32mf2_t, vuint32mf2_t, vuint32mf2_t, vuint32mf2_t, vuint32mf2_t, vuint32mf2_t, vuint32mf2_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vsuxseg8ei8_v_m)))
void vsuxseg8ei8(vbool64_t, uint32_t *, vuint8mf8_t, vuint32mf2_t, vuint32mf2_t, vuint32mf2_t, vuint32mf2_t, vuint32mf2_t, vuint32mf2_t, vuint32mf2_t, vuint32mf2_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vsuxseg2ei16_v)))
void vsuxseg2ei16(int32_t *, vuint16mf2_t, vint32m1_t, vint32m1_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vsuxseg2ei16_v_m)))
void vsuxseg2ei16(vbool32_t, int32_t *, vuint16mf2_t, vint32m1_t, vint32m1_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vsuxseg2ei16_v)))
void vsuxseg2ei16(int32_t *, vuint16m1_t, vint32m2_t, vint32m2_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vsuxseg2ei16_v_m)))
void vsuxseg2ei16(vbool16_t, int32_t *, vuint16m1_t, vint32m2_t, vint32m2_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vsuxseg2ei16_v)))
void vsuxseg2ei16(int32_t *, vuint16m2_t, vint32m4_t, vint32m4_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vsuxseg2ei16_v_m)))
void vsuxseg2ei16(vbool8_t, int32_t *, vuint16m2_t, vint32m4_t, vint32m4_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vsuxseg2ei16_v)))
void vsuxseg2ei16(int32_t *, vuint16mf4_t, vint32mf2_t, vint32mf2_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vsuxseg2ei16_v_m)))
void vsuxseg2ei16(vbool64_t, int32_t *, vuint16mf4_t, vint32mf2_t, vint32mf2_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vsuxseg2ei16_v)))
void vsuxseg2ei16(uint32_t *, vuint16mf2_t, vuint32m1_t, vuint32m1_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vsuxseg2ei16_v_m)))
void vsuxseg2ei16(vbool32_t, uint32_t *, vuint16mf2_t, vuint32m1_t, vuint32m1_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vsuxseg2ei16_v)))
void vsuxseg2ei16(uint32_t *, vuint16m1_t, vuint32m2_t, vuint32m2_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vsuxseg2ei16_v_m)))
void vsuxseg2ei16(vbool16_t, uint32_t *, vuint16m1_t, vuint32m2_t, vuint32m2_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vsuxseg2ei16_v)))
void vsuxseg2ei16(uint32_t *, vuint16m2_t, vuint32m4_t, vuint32m4_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vsuxseg2ei16_v_m)))
void vsuxseg2ei16(vbool8_t, uint32_t *, vuint16m2_t, vuint32m4_t, vuint32m4_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vsuxseg2ei16_v)))
void vsuxseg2ei16(uint32_t *, vuint16mf4_t, vuint32mf2_t, vuint32mf2_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vsuxseg2ei16_v_m)))
void vsuxseg2ei16(vbool64_t, uint32_t *, vuint16mf4_t, vuint32mf2_t, vuint32mf2_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vsuxseg3ei16_v)))
void vsuxseg3ei16(int32_t *, vuint16mf2_t, vint32m1_t, vint32m1_t, vint32m1_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vsuxseg3ei16_v_m)))
void vsuxseg3ei16(vbool32_t, int32_t *, vuint16mf2_t, vint32m1_t, vint32m1_t, vint32m1_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vsuxseg3ei16_v)))
void vsuxseg3ei16(int32_t *, vuint16m1_t, vint32m2_t, vint32m2_t, vint32m2_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vsuxseg3ei16_v_m)))
void vsuxseg3ei16(vbool16_t, int32_t *, vuint16m1_t, vint32m2_t, vint32m2_t, vint32m2_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vsuxseg3ei16_v)))
void vsuxseg3ei16(int32_t *, vuint16mf4_t, vint32mf2_t, vint32mf2_t, vint32mf2_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vsuxseg3ei16_v_m)))
void vsuxseg3ei16(vbool64_t, int32_t *, vuint16mf4_t, vint32mf2_t, vint32mf2_t, vint32mf2_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vsuxseg3ei16_v)))
void vsuxseg3ei16(uint32_t *, vuint16mf2_t, vuint32m1_t, vuint32m1_t, vuint32m1_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vsuxseg3ei16_v_m)))
void vsuxseg3ei16(vbool32_t, uint32_t *, vuint16mf2_t, vuint32m1_t, vuint32m1_t, vuint32m1_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vsuxseg3ei16_v)))
void vsuxseg3ei16(uint32_t *, vuint16m1_t, vuint32m2_t, vuint32m2_t, vuint32m2_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vsuxseg3ei16_v_m)))
void vsuxseg3ei16(vbool16_t, uint32_t *, vuint16m1_t, vuint32m2_t, vuint32m2_t, vuint32m2_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vsuxseg3ei16_v)))
void vsuxseg3ei16(uint32_t *, vuint16mf4_t, vuint32mf2_t, vuint32mf2_t, vuint32mf2_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vsuxseg3ei16_v_m)))
void vsuxseg3ei16(vbool64_t, uint32_t *, vuint16mf4_t, vuint32mf2_t, vuint32mf2_t, vuint32mf2_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vsuxseg4ei16_v)))
void vsuxseg4ei16(int32_t *, vuint16mf2_t, vint32m1_t, vint32m1_t, vint32m1_t, vint32m1_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vsuxseg4ei16_v_m)))
void vsuxseg4ei16(vbool32_t, int32_t *, vuint16mf2_t, vint32m1_t, vint32m1_t, vint32m1_t, vint32m1_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vsuxseg4ei16_v)))
void vsuxseg4ei16(int32_t *, vuint16m1_t, vint32m2_t, vint32m2_t, vint32m2_t, vint32m2_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vsuxseg4ei16_v_m)))
void vsuxseg4ei16(vbool16_t, int32_t *, vuint16m1_t, vint32m2_t, vint32m2_t, vint32m2_t, vint32m2_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vsuxseg4ei16_v)))
void vsuxseg4ei16(int32_t *, vuint16mf4_t, vint32mf2_t, vint32mf2_t, vint32mf2_t, vint32mf2_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vsuxseg4ei16_v_m)))
void vsuxseg4ei16(vbool64_t, int32_t *, vuint16mf4_t, vint32mf2_t, vint32mf2_t, vint32mf2_t, vint32mf2_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vsuxseg4ei16_v)))
void vsuxseg4ei16(uint32_t *, vuint16mf2_t, vuint32m1_t, vuint32m1_t, vuint32m1_t, vuint32m1_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vsuxseg4ei16_v_m)))
void vsuxseg4ei16(vbool32_t, uint32_t *, vuint16mf2_t, vuint32m1_t, vuint32m1_t, vuint32m1_t, vuint32m1_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vsuxseg4ei16_v)))
void vsuxseg4ei16(uint32_t *, vuint16m1_t, vuint32m2_t, vuint32m2_t, vuint32m2_t, vuint32m2_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vsuxseg4ei16_v_m)))
void vsuxseg4ei16(vbool16_t, uint32_t *, vuint16m1_t, vuint32m2_t, vuint32m2_t, vuint32m2_t, vuint32m2_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vsuxseg4ei16_v)))
void vsuxseg4ei16(uint32_t *, vuint16mf4_t, vuint32mf2_t, vuint32mf2_t, vuint32mf2_t, vuint32mf2_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vsuxseg4ei16_v_m)))
void vsuxseg4ei16(vbool64_t, uint32_t *, vuint16mf4_t, vuint32mf2_t, vuint32mf2_t, vuint32mf2_t, vuint32mf2_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vsuxseg5ei16_v)))
void vsuxseg5ei16(int32_t *, vuint16mf2_t, vint32m1_t, vint32m1_t, vint32m1_t, vint32m1_t, vint32m1_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vsuxseg5ei16_v_m)))
void vsuxseg5ei16(vbool32_t, int32_t *, vuint16mf2_t, vint32m1_t, vint32m1_t, vint32m1_t, vint32m1_t, vint32m1_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vsuxseg5ei16_v)))
void vsuxseg5ei16(int32_t *, vuint16mf4_t, vint32mf2_t, vint32mf2_t, vint32mf2_t, vint32mf2_t, vint32mf2_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vsuxseg5ei16_v_m)))
void vsuxseg5ei16(vbool64_t, int32_t *, vuint16mf4_t, vint32mf2_t, vint32mf2_t, vint32mf2_t, vint32mf2_t, vint32mf2_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vsuxseg5ei16_v)))
void vsuxseg5ei16(uint32_t *, vuint16mf2_t, vuint32m1_t, vuint32m1_t, vuint32m1_t, vuint32m1_t, vuint32m1_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vsuxseg5ei16_v_m)))
void vsuxseg5ei16(vbool32_t, uint32_t *, vuint16mf2_t, vuint32m1_t, vuint32m1_t, vuint32m1_t, vuint32m1_t, vuint32m1_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vsuxseg5ei16_v)))
void vsuxseg5ei16(uint32_t *, vuint16mf4_t, vuint32mf2_t, vuint32mf2_t, vuint32mf2_t, vuint32mf2_t, vuint32mf2_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vsuxseg5ei16_v_m)))
void vsuxseg5ei16(vbool64_t, uint32_t *, vuint16mf4_t, vuint32mf2_t, vuint32mf2_t, vuint32mf2_t, vuint32mf2_t, vuint32mf2_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vsuxseg6ei16_v)))
void vsuxseg6ei16(int32_t *, vuint16mf2_t, vint32m1_t, vint32m1_t, vint32m1_t, vint32m1_t, vint32m1_t, vint32m1_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vsuxseg6ei16_v_m)))
void vsuxseg6ei16(vbool32_t, int32_t *, vuint16mf2_t, vint32m1_t, vint32m1_t, vint32m1_t, vint32m1_t, vint32m1_t, vint32m1_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vsuxseg6ei16_v)))
void vsuxseg6ei16(int32_t *, vuint16mf4_t, vint32mf2_t, vint32mf2_t, vint32mf2_t, vint32mf2_t, vint32mf2_t, vint32mf2_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vsuxseg6ei16_v_m)))
void vsuxseg6ei16(vbool64_t, int32_t *, vuint16mf4_t, vint32mf2_t, vint32mf2_t, vint32mf2_t, vint32mf2_t, vint32mf2_t, vint32mf2_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vsuxseg6ei16_v)))
void vsuxseg6ei16(uint32_t *, vuint16mf2_t, vuint32m1_t, vuint32m1_t, vuint32m1_t, vuint32m1_t, vuint32m1_t, vuint32m1_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vsuxseg6ei16_v_m)))
void vsuxseg6ei16(vbool32_t, uint32_t *, vuint16mf2_t, vuint32m1_t, vuint32m1_t, vuint32m1_t, vuint32m1_t, vuint32m1_t, vuint32m1_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vsuxseg6ei16_v)))
void vsuxseg6ei16(uint32_t *, vuint16mf4_t, vuint32mf2_t, vuint32mf2_t, vuint32mf2_t, vuint32mf2_t, vuint32mf2_t, vuint32mf2_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vsuxseg6ei16_v_m)))
void vsuxseg6ei16(vbool64_t, uint32_t *, vuint16mf4_t, vuint32mf2_t, vuint32mf2_t, vuint32mf2_t, vuint32mf2_t, vuint32mf2_t, vuint32mf2_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vsuxseg7ei16_v)))
void vsuxseg7ei16(int32_t *, vuint16mf2_t, vint32m1_t, vint32m1_t, vint32m1_t, vint32m1_t, vint32m1_t, vint32m1_t, vint32m1_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vsuxseg7ei16_v_m)))
void vsuxseg7ei16(vbool32_t, int32_t *, vuint16mf2_t, vint32m1_t, vint32m1_t, vint32m1_t, vint32m1_t, vint32m1_t, vint32m1_t, vint32m1_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vsuxseg7ei16_v)))
void vsuxseg7ei16(int32_t *, vuint16mf4_t, vint32mf2_t, vint32mf2_t, vint32mf2_t, vint32mf2_t, vint32mf2_t, vint32mf2_t, vint32mf2_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vsuxseg7ei16_v_m)))
void vsuxseg7ei16(vbool64_t, int32_t *, vuint16mf4_t, vint32mf2_t, vint32mf2_t, vint32mf2_t, vint32mf2_t, vint32mf2_t, vint32mf2_t, vint32mf2_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vsuxseg7ei16_v)))
void vsuxseg7ei16(uint32_t *, vuint16mf2_t, vuint32m1_t, vuint32m1_t, vuint32m1_t, vuint32m1_t, vuint32m1_t, vuint32m1_t, vuint32m1_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vsuxseg7ei16_v_m)))
void vsuxseg7ei16(vbool32_t, uint32_t *, vuint16mf2_t, vuint32m1_t, vuint32m1_t, vuint32m1_t, vuint32m1_t, vuint32m1_t, vuint32m1_t, vuint32m1_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vsuxseg7ei16_v)))
void vsuxseg7ei16(uint32_t *, vuint16mf4_t, vuint32mf2_t, vuint32mf2_t, vuint32mf2_t, vuint32mf2_t, vuint32mf2_t, vuint32mf2_t, vuint32mf2_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vsuxseg7ei16_v_m)))
void vsuxseg7ei16(vbool64_t, uint32_t *, vuint16mf4_t, vuint32mf2_t, vuint32mf2_t, vuint32mf2_t, vuint32mf2_t, vuint32mf2_t, vuint32mf2_t, vuint32mf2_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vsuxseg8ei16_v)))
void vsuxseg8ei16(int32_t *, vuint16mf2_t, vint32m1_t, vint32m1_t, vint32m1_t, vint32m1_t, vint32m1_t, vint32m1_t, vint32m1_t, vint32m1_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vsuxseg8ei16_v_m)))
void vsuxseg8ei16(vbool32_t, int32_t *, vuint16mf2_t, vint32m1_t, vint32m1_t, vint32m1_t, vint32m1_t, vint32m1_t, vint32m1_t, vint32m1_t, vint32m1_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vsuxseg8ei16_v)))
void vsuxseg8ei16(int32_t *, vuint16mf4_t, vint32mf2_t, vint32mf2_t, vint32mf2_t, vint32mf2_t, vint32mf2_t, vint32mf2_t, vint32mf2_t, vint32mf2_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vsuxseg8ei16_v_m)))
void vsuxseg8ei16(vbool64_t, int32_t *, vuint16mf4_t, vint32mf2_t, vint32mf2_t, vint32mf2_t, vint32mf2_t, vint32mf2_t, vint32mf2_t, vint32mf2_t, vint32mf2_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vsuxseg8ei16_v)))
void vsuxseg8ei16(uint32_t *, vuint16mf2_t, vuint32m1_t, vuint32m1_t, vuint32m1_t, vuint32m1_t, vuint32m1_t, vuint32m1_t, vuint32m1_t, vuint32m1_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vsuxseg8ei16_v_m)))
void vsuxseg8ei16(vbool32_t, uint32_t *, vuint16mf2_t, vuint32m1_t, vuint32m1_t, vuint32m1_t, vuint32m1_t, vuint32m1_t, vuint32m1_t, vuint32m1_t, vuint32m1_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vsuxseg8ei16_v)))
void vsuxseg8ei16(uint32_t *, vuint16mf4_t, vuint32mf2_t, vuint32mf2_t, vuint32mf2_t, vuint32mf2_t, vuint32mf2_t, vuint32mf2_t, vuint32mf2_t, vuint32mf2_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vsuxseg8ei16_v_m)))
void vsuxseg8ei16(vbool64_t, uint32_t *, vuint16mf4_t, vuint32mf2_t, vuint32mf2_t, vuint32mf2_t, vuint32mf2_t, vuint32mf2_t, vuint32mf2_t, vuint32mf2_t, vuint32mf2_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vsuxseg2ei32_v)))
void vsuxseg2ei32(int32_t *, vuint32m1_t, vint32m1_t, vint32m1_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vsuxseg2ei32_v_m)))
void vsuxseg2ei32(vbool32_t, int32_t *, vuint32m1_t, vint32m1_t, vint32m1_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vsuxseg2ei32_v)))
void vsuxseg2ei32(int32_t *, vuint32m2_t, vint32m2_t, vint32m2_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vsuxseg2ei32_v_m)))
void vsuxseg2ei32(vbool16_t, int32_t *, vuint32m2_t, vint32m2_t, vint32m2_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vsuxseg2ei32_v)))
void vsuxseg2ei32(int32_t *, vuint32m4_t, vint32m4_t, vint32m4_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vsuxseg2ei32_v_m)))
void vsuxseg2ei32(vbool8_t, int32_t *, vuint32m4_t, vint32m4_t, vint32m4_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vsuxseg2ei32_v)))
void vsuxseg2ei32(int32_t *, vuint32mf2_t, vint32mf2_t, vint32mf2_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vsuxseg2ei32_v_m)))
void vsuxseg2ei32(vbool64_t, int32_t *, vuint32mf2_t, vint32mf2_t, vint32mf2_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vsuxseg2ei32_v)))
void vsuxseg2ei32(uint32_t *, vuint32m1_t, vuint32m1_t, vuint32m1_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vsuxseg2ei32_v_m)))
void vsuxseg2ei32(vbool32_t, uint32_t *, vuint32m1_t, vuint32m1_t, vuint32m1_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vsuxseg2ei32_v)))
void vsuxseg2ei32(uint32_t *, vuint32m2_t, vuint32m2_t, vuint32m2_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vsuxseg2ei32_v_m)))
void vsuxseg2ei32(vbool16_t, uint32_t *, vuint32m2_t, vuint32m2_t, vuint32m2_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vsuxseg2ei32_v)))
void vsuxseg2ei32(uint32_t *, vuint32m4_t, vuint32m4_t, vuint32m4_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vsuxseg2ei32_v_m)))
void vsuxseg2ei32(vbool8_t, uint32_t *, vuint32m4_t, vuint32m4_t, vuint32m4_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vsuxseg2ei32_v)))
void vsuxseg2ei32(uint32_t *, vuint32mf2_t, vuint32mf2_t, vuint32mf2_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vsuxseg2ei32_v_m)))
void vsuxseg2ei32(vbool64_t, uint32_t *, vuint32mf2_t, vuint32mf2_t, vuint32mf2_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vsuxseg3ei32_v)))
void vsuxseg3ei32(int32_t *, vuint32m1_t, vint32m1_t, vint32m1_t, vint32m1_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vsuxseg3ei32_v_m)))
void vsuxseg3ei32(vbool32_t, int32_t *, vuint32m1_t, vint32m1_t, vint32m1_t, vint32m1_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vsuxseg3ei32_v)))
void vsuxseg3ei32(int32_t *, vuint32m2_t, vint32m2_t, vint32m2_t, vint32m2_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vsuxseg3ei32_v_m)))
void vsuxseg3ei32(vbool16_t, int32_t *, vuint32m2_t, vint32m2_t, vint32m2_t, vint32m2_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vsuxseg3ei32_v)))
void vsuxseg3ei32(int32_t *, vuint32mf2_t, vint32mf2_t, vint32mf2_t, vint32mf2_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vsuxseg3ei32_v_m)))
void vsuxseg3ei32(vbool64_t, int32_t *, vuint32mf2_t, vint32mf2_t, vint32mf2_t, vint32mf2_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vsuxseg3ei32_v)))
void vsuxseg3ei32(uint32_t *, vuint32m1_t, vuint32m1_t, vuint32m1_t, vuint32m1_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vsuxseg3ei32_v_m)))
void vsuxseg3ei32(vbool32_t, uint32_t *, vuint32m1_t, vuint32m1_t, vuint32m1_t, vuint32m1_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vsuxseg3ei32_v)))
void vsuxseg3ei32(uint32_t *, vuint32m2_t, vuint32m2_t, vuint32m2_t, vuint32m2_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vsuxseg3ei32_v_m)))
void vsuxseg3ei32(vbool16_t, uint32_t *, vuint32m2_t, vuint32m2_t, vuint32m2_t, vuint32m2_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vsuxseg3ei32_v)))
void vsuxseg3ei32(uint32_t *, vuint32mf2_t, vuint32mf2_t, vuint32mf2_t, vuint32mf2_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vsuxseg3ei32_v_m)))
void vsuxseg3ei32(vbool64_t, uint32_t *, vuint32mf2_t, vuint32mf2_t, vuint32mf2_t, vuint32mf2_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vsuxseg4ei32_v)))
void vsuxseg4ei32(int32_t *, vuint32m1_t, vint32m1_t, vint32m1_t, vint32m1_t, vint32m1_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vsuxseg4ei32_v_m)))
void vsuxseg4ei32(vbool32_t, int32_t *, vuint32m1_t, vint32m1_t, vint32m1_t, vint32m1_t, vint32m1_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vsuxseg4ei32_v)))
void vsuxseg4ei32(int32_t *, vuint32m2_t, vint32m2_t, vint32m2_t, vint32m2_t, vint32m2_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vsuxseg4ei32_v_m)))
void vsuxseg4ei32(vbool16_t, int32_t *, vuint32m2_t, vint32m2_t, vint32m2_t, vint32m2_t, vint32m2_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vsuxseg4ei32_v)))
void vsuxseg4ei32(int32_t *, vuint32mf2_t, vint32mf2_t, vint32mf2_t, vint32mf2_t, vint32mf2_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vsuxseg4ei32_v_m)))
void vsuxseg4ei32(vbool64_t, int32_t *, vuint32mf2_t, vint32mf2_t, vint32mf2_t, vint32mf2_t, vint32mf2_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vsuxseg4ei32_v)))
void vsuxseg4ei32(uint32_t *, vuint32m1_t, vuint32m1_t, vuint32m1_t, vuint32m1_t, vuint32m1_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vsuxseg4ei32_v_m)))
void vsuxseg4ei32(vbool32_t, uint32_t *, vuint32m1_t, vuint32m1_t, vuint32m1_t, vuint32m1_t, vuint32m1_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vsuxseg4ei32_v)))
void vsuxseg4ei32(uint32_t *, vuint32m2_t, vuint32m2_t, vuint32m2_t, vuint32m2_t, vuint32m2_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vsuxseg4ei32_v_m)))
void vsuxseg4ei32(vbool16_t, uint32_t *, vuint32m2_t, vuint32m2_t, vuint32m2_t, vuint32m2_t, vuint32m2_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vsuxseg4ei32_v)))
void vsuxseg4ei32(uint32_t *, vuint32mf2_t, vuint32mf2_t, vuint32mf2_t, vuint32mf2_t, vuint32mf2_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vsuxseg4ei32_v_m)))
void vsuxseg4ei32(vbool64_t, uint32_t *, vuint32mf2_t, vuint32mf2_t, vuint32mf2_t, vuint32mf2_t, vuint32mf2_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vsuxseg5ei32_v)))
void vsuxseg5ei32(int32_t *, vuint32m1_t, vint32m1_t, vint32m1_t, vint32m1_t, vint32m1_t, vint32m1_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vsuxseg5ei32_v_m)))
void vsuxseg5ei32(vbool32_t, int32_t *, vuint32m1_t, vint32m1_t, vint32m1_t, vint32m1_t, vint32m1_t, vint32m1_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vsuxseg5ei32_v)))
void vsuxseg5ei32(int32_t *, vuint32mf2_t, vint32mf2_t, vint32mf2_t, vint32mf2_t, vint32mf2_t, vint32mf2_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vsuxseg5ei32_v_m)))
void vsuxseg5ei32(vbool64_t, int32_t *, vuint32mf2_t, vint32mf2_t, vint32mf2_t, vint32mf2_t, vint32mf2_t, vint32mf2_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vsuxseg5ei32_v)))
void vsuxseg5ei32(uint32_t *, vuint32m1_t, vuint32m1_t, vuint32m1_t, vuint32m1_t, vuint32m1_t, vuint32m1_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vsuxseg5ei32_v_m)))
void vsuxseg5ei32(vbool32_t, uint32_t *, vuint32m1_t, vuint32m1_t, vuint32m1_t, vuint32m1_t, vuint32m1_t, vuint32m1_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vsuxseg5ei32_v)))
void vsuxseg5ei32(uint32_t *, vuint32mf2_t, vuint32mf2_t, vuint32mf2_t, vuint32mf2_t, vuint32mf2_t, vuint32mf2_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vsuxseg5ei32_v_m)))
void vsuxseg5ei32(vbool64_t, uint32_t *, vuint32mf2_t, vuint32mf2_t, vuint32mf2_t, vuint32mf2_t, vuint32mf2_t, vuint32mf2_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vsuxseg6ei32_v)))
void vsuxseg6ei32(int32_t *, vuint32m1_t, vint32m1_t, vint32m1_t, vint32m1_t, vint32m1_t, vint32m1_t, vint32m1_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vsuxseg6ei32_v_m)))
void vsuxseg6ei32(vbool32_t, int32_t *, vuint32m1_t, vint32m1_t, vint32m1_t, vint32m1_t, vint32m1_t, vint32m1_t, vint32m1_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vsuxseg6ei32_v)))
void vsuxseg6ei32(int32_t *, vuint32mf2_t, vint32mf2_t, vint32mf2_t, vint32mf2_t, vint32mf2_t, vint32mf2_t, vint32mf2_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vsuxseg6ei32_v_m)))
void vsuxseg6ei32(vbool64_t, int32_t *, vuint32mf2_t, vint32mf2_t, vint32mf2_t, vint32mf2_t, vint32mf2_t, vint32mf2_t, vint32mf2_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vsuxseg6ei32_v)))
void vsuxseg6ei32(uint32_t *, vuint32m1_t, vuint32m1_t, vuint32m1_t, vuint32m1_t, vuint32m1_t, vuint32m1_t, vuint32m1_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vsuxseg6ei32_v_m)))
void vsuxseg6ei32(vbool32_t, uint32_t *, vuint32m1_t, vuint32m1_t, vuint32m1_t, vuint32m1_t, vuint32m1_t, vuint32m1_t, vuint32m1_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vsuxseg6ei32_v)))
void vsuxseg6ei32(uint32_t *, vuint32mf2_t, vuint32mf2_t, vuint32mf2_t, vuint32mf2_t, vuint32mf2_t, vuint32mf2_t, vuint32mf2_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vsuxseg6ei32_v_m)))
void vsuxseg6ei32(vbool64_t, uint32_t *, vuint32mf2_t, vuint32mf2_t, vuint32mf2_t, vuint32mf2_t, vuint32mf2_t, vuint32mf2_t, vuint32mf2_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vsuxseg7ei32_v)))
void vsuxseg7ei32(int32_t *, vuint32m1_t, vint32m1_t, vint32m1_t, vint32m1_t, vint32m1_t, vint32m1_t, vint32m1_t, vint32m1_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vsuxseg7ei32_v_m)))
void vsuxseg7ei32(vbool32_t, int32_t *, vuint32m1_t, vint32m1_t, vint32m1_t, vint32m1_t, vint32m1_t, vint32m1_t, vint32m1_t, vint32m1_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vsuxseg7ei32_v)))
void vsuxseg7ei32(int32_t *, vuint32mf2_t, vint32mf2_t, vint32mf2_t, vint32mf2_t, vint32mf2_t, vint32mf2_t, vint32mf2_t, vint32mf2_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vsuxseg7ei32_v_m)))
void vsuxseg7ei32(vbool64_t, int32_t *, vuint32mf2_t, vint32mf2_t, vint32mf2_t, vint32mf2_t, vint32mf2_t, vint32mf2_t, vint32mf2_t, vint32mf2_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vsuxseg7ei32_v)))
void vsuxseg7ei32(uint32_t *, vuint32m1_t, vuint32m1_t, vuint32m1_t, vuint32m1_t, vuint32m1_t, vuint32m1_t, vuint32m1_t, vuint32m1_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vsuxseg7ei32_v_m)))
void vsuxseg7ei32(vbool32_t, uint32_t *, vuint32m1_t, vuint32m1_t, vuint32m1_t, vuint32m1_t, vuint32m1_t, vuint32m1_t, vuint32m1_t, vuint32m1_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vsuxseg7ei32_v)))
void vsuxseg7ei32(uint32_t *, vuint32mf2_t, vuint32mf2_t, vuint32mf2_t, vuint32mf2_t, vuint32mf2_t, vuint32mf2_t, vuint32mf2_t, vuint32mf2_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vsuxseg7ei32_v_m)))
void vsuxseg7ei32(vbool64_t, uint32_t *, vuint32mf2_t, vuint32mf2_t, vuint32mf2_t, vuint32mf2_t, vuint32mf2_t, vuint32mf2_t, vuint32mf2_t, vuint32mf2_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vsuxseg8ei32_v)))
void vsuxseg8ei32(int32_t *, vuint32m1_t, vint32m1_t, vint32m1_t, vint32m1_t, vint32m1_t, vint32m1_t, vint32m1_t, vint32m1_t, vint32m1_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vsuxseg8ei32_v_m)))
void vsuxseg8ei32(vbool32_t, int32_t *, vuint32m1_t, vint32m1_t, vint32m1_t, vint32m1_t, vint32m1_t, vint32m1_t, vint32m1_t, vint32m1_t, vint32m1_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vsuxseg8ei32_v)))
void vsuxseg8ei32(int32_t *, vuint32mf2_t, vint32mf2_t, vint32mf2_t, vint32mf2_t, vint32mf2_t, vint32mf2_t, vint32mf2_t, vint32mf2_t, vint32mf2_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vsuxseg8ei32_v_m)))
void vsuxseg8ei32(vbool64_t, int32_t *, vuint32mf2_t, vint32mf2_t, vint32mf2_t, vint32mf2_t, vint32mf2_t, vint32mf2_t, vint32mf2_t, vint32mf2_t, vint32mf2_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vsuxseg8ei32_v)))
void vsuxseg8ei32(uint32_t *, vuint32m1_t, vuint32m1_t, vuint32m1_t, vuint32m1_t, vuint32m1_t, vuint32m1_t, vuint32m1_t, vuint32m1_t, vuint32m1_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vsuxseg8ei32_v_m)))
void vsuxseg8ei32(vbool32_t, uint32_t *, vuint32m1_t, vuint32m1_t, vuint32m1_t, vuint32m1_t, vuint32m1_t, vuint32m1_t, vuint32m1_t, vuint32m1_t, vuint32m1_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vsuxseg8ei32_v)))
void vsuxseg8ei32(uint32_t *, vuint32mf2_t, vuint32mf2_t, vuint32mf2_t, vuint32mf2_t, vuint32mf2_t, vuint32mf2_t, vuint32mf2_t, vuint32mf2_t, vuint32mf2_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vsuxseg8ei32_v_m)))
void vsuxseg8ei32(vbool64_t, uint32_t *, vuint32mf2_t, vuint32mf2_t, vuint32mf2_t, vuint32mf2_t, vuint32mf2_t, vuint32mf2_t, vuint32mf2_t, vuint32mf2_t, vuint32mf2_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vloxei8_v)))
vint8m1_t vloxei8(const int8_t *, vuint8m1_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vloxei8_v_m)))
vint8m1_t vloxei8(vbool8_t, vint8m1_t, const int8_t *, vuint8m1_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vloxei8_v)))
vint8m2_t vloxei8(const int8_t *, vuint8m2_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vloxei8_v_m)))
vint8m2_t vloxei8(vbool4_t, vint8m2_t, const int8_t *, vuint8m2_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vloxei8_v)))
vint8m4_t vloxei8(const int8_t *, vuint8m4_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vloxei8_v_m)))
vint8m4_t vloxei8(vbool2_t, vint8m4_t, const int8_t *, vuint8m4_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vloxei8_v)))
vint8m8_t vloxei8(const int8_t *, vuint8m8_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vloxei8_v_m)))
vint8m8_t vloxei8(vbool1_t, vint8m8_t, const int8_t *, vuint8m8_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vloxei8_v)))
vint8mf2_t vloxei8(const int8_t *, vuint8mf2_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vloxei8_v_m)))
vint8mf2_t vloxei8(vbool16_t, vint8mf2_t, const int8_t *, vuint8mf2_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vloxei8_v)))
vint8mf4_t vloxei8(const int8_t *, vuint8mf4_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vloxei8_v_m)))
vint8mf4_t vloxei8(vbool32_t, vint8mf4_t, const int8_t *, vuint8mf4_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vloxei8_v)))
vint8mf8_t vloxei8(const int8_t *, vuint8mf8_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vloxei8_v_m)))
vint8mf8_t vloxei8(vbool64_t, vint8mf8_t, const int8_t *, vuint8mf8_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vloxei8_v)))
vuint8m1_t vloxei8(const uint8_t *, vuint8m1_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vloxei8_v_m)))
vuint8m1_t vloxei8(vbool8_t, vuint8m1_t, const uint8_t *, vuint8m1_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vloxei8_v)))
vuint8m2_t vloxei8(const uint8_t *, vuint8m2_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vloxei8_v_m)))
vuint8m2_t vloxei8(vbool4_t, vuint8m2_t, const uint8_t *, vuint8m2_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vloxei8_v)))
vuint8m4_t vloxei8(const uint8_t *, vuint8m4_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vloxei8_v_m)))
vuint8m4_t vloxei8(vbool2_t, vuint8m4_t, const uint8_t *, vuint8m4_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vloxei8_v)))
vuint8m8_t vloxei8(const uint8_t *, vuint8m8_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vloxei8_v_m)))
vuint8m8_t vloxei8(vbool1_t, vuint8m8_t, const uint8_t *, vuint8m8_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vloxei8_v)))
vuint8mf2_t vloxei8(const uint8_t *, vuint8mf2_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vloxei8_v_m)))
vuint8mf2_t vloxei8(vbool16_t, vuint8mf2_t, const uint8_t *, vuint8mf2_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vloxei8_v)))
vuint8mf4_t vloxei8(const uint8_t *, vuint8mf4_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vloxei8_v_m)))
vuint8mf4_t vloxei8(vbool32_t, vuint8mf4_t, const uint8_t *, vuint8mf4_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vloxei8_v)))
vuint8mf8_t vloxei8(const uint8_t *, vuint8mf8_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vloxei8_v_m)))
vuint8mf8_t vloxei8(vbool64_t, vuint8mf8_t, const uint8_t *, vuint8mf8_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vloxei16_v)))
vint8m1_t vloxei16(const int8_t *, vuint16m2_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vloxei16_v_m)))
vint8m1_t vloxei16(vbool8_t, vint8m1_t, const int8_t *, vuint16m2_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vloxei16_v)))
vint8m2_t vloxei16(const int8_t *, vuint16m4_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vloxei16_v_m)))
vint8m2_t vloxei16(vbool4_t, vint8m2_t, const int8_t *, vuint16m4_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vloxei16_v)))
vint8m4_t vloxei16(const int8_t *, vuint16m8_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vloxei16_v_m)))
vint8m4_t vloxei16(vbool2_t, vint8m4_t, const int8_t *, vuint16m8_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vloxei16_v)))
vint8mf2_t vloxei16(const int8_t *, vuint16m1_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vloxei16_v_m)))
vint8mf2_t vloxei16(vbool16_t, vint8mf2_t, const int8_t *, vuint16m1_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vloxei16_v)))
vint8mf4_t vloxei16(const int8_t *, vuint16mf2_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vloxei16_v_m)))
vint8mf4_t vloxei16(vbool32_t, vint8mf4_t, const int8_t *, vuint16mf2_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vloxei16_v)))
vint8mf8_t vloxei16(const int8_t *, vuint16mf4_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vloxei16_v_m)))
vint8mf8_t vloxei16(vbool64_t, vint8mf8_t, const int8_t *, vuint16mf4_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vloxei16_v)))
vuint8m1_t vloxei16(const uint8_t *, vuint16m2_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vloxei16_v_m)))
vuint8m1_t vloxei16(vbool8_t, vuint8m1_t, const uint8_t *, vuint16m2_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vloxei16_v)))
vuint8m2_t vloxei16(const uint8_t *, vuint16m4_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vloxei16_v_m)))
vuint8m2_t vloxei16(vbool4_t, vuint8m2_t, const uint8_t *, vuint16m4_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vloxei16_v)))
vuint8m4_t vloxei16(const uint8_t *, vuint16m8_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vloxei16_v_m)))
vuint8m4_t vloxei16(vbool2_t, vuint8m4_t, const uint8_t *, vuint16m8_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vloxei16_v)))
vuint8mf2_t vloxei16(const uint8_t *, vuint16m1_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vloxei16_v_m)))
vuint8mf2_t vloxei16(vbool16_t, vuint8mf2_t, const uint8_t *, vuint16m1_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vloxei16_v)))
vuint8mf4_t vloxei16(const uint8_t *, vuint16mf2_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vloxei16_v_m)))
vuint8mf4_t vloxei16(vbool32_t, vuint8mf4_t, const uint8_t *, vuint16mf2_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vloxei16_v)))
vuint8mf8_t vloxei16(const uint8_t *, vuint16mf4_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vloxei16_v_m)))
vuint8mf8_t vloxei16(vbool64_t, vuint8mf8_t, const uint8_t *, vuint16mf4_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vloxei32_v)))
vint8m1_t vloxei32(const int8_t *, vuint32m4_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vloxei32_v_m)))
vint8m1_t vloxei32(vbool8_t, vint8m1_t, const int8_t *, vuint32m4_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vloxei32_v)))
vint8m2_t vloxei32(const int8_t *, vuint32m8_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vloxei32_v_m)))
vint8m2_t vloxei32(vbool4_t, vint8m2_t, const int8_t *, vuint32m8_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vloxei32_v)))
vint8mf2_t vloxei32(const int8_t *, vuint32m2_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vloxei32_v_m)))
vint8mf2_t vloxei32(vbool16_t, vint8mf2_t, const int8_t *, vuint32m2_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vloxei32_v)))
vint8mf4_t vloxei32(const int8_t *, vuint32m1_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vloxei32_v_m)))
vint8mf4_t vloxei32(vbool32_t, vint8mf4_t, const int8_t *, vuint32m1_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vloxei32_v)))
vint8mf8_t vloxei32(const int8_t *, vuint32mf2_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vloxei32_v_m)))
vint8mf8_t vloxei32(vbool64_t, vint8mf8_t, const int8_t *, vuint32mf2_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vsoxseg2ei8_v)))
void vsoxseg2ei8(int8_t *, vuint8m1_t, vint8m1_t, vint8m1_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vsoxseg2ei8_v_m)))
void vsoxseg2ei8(vbool8_t, int8_t *, vuint8m1_t, vint8m1_t, vint8m1_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vsoxseg2ei8_v)))
void vsoxseg2ei8(int8_t *, vuint8m2_t, vint8m2_t, vint8m2_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vsoxseg2ei8_v_m)))
void vsoxseg2ei8(vbool4_t, int8_t *, vuint8m2_t, vint8m2_t, vint8m2_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vsoxseg2ei8_v)))
void vsoxseg2ei8(int8_t *, vuint8m4_t, vint8m4_t, vint8m4_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vsoxseg2ei8_v_m)))
void vsoxseg2ei8(vbool2_t, int8_t *, vuint8m4_t, vint8m4_t, vint8m4_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vsoxseg2ei8_v)))
void vsoxseg2ei8(int8_t *, vuint8mf2_t, vint8mf2_t, vint8mf2_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vsoxseg2ei8_v_m)))
void vsoxseg2ei8(vbool16_t, int8_t *, vuint8mf2_t, vint8mf2_t, vint8mf2_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vsoxseg2ei8_v)))
void vsoxseg2ei8(int8_t *, vuint8mf4_t, vint8mf4_t, vint8mf4_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vsoxseg2ei8_v_m)))
void vsoxseg2ei8(vbool32_t, int8_t *, vuint8mf4_t, vint8mf4_t, vint8mf4_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vsoxseg2ei8_v)))
void vsoxseg2ei8(int8_t *, vuint8mf8_t, vint8mf8_t, vint8mf8_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vsoxseg2ei8_v_m)))
void vsoxseg2ei8(vbool64_t, int8_t *, vuint8mf8_t, vint8mf8_t, vint8mf8_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vsoxseg2ei8_v)))
void vsoxseg2ei8(uint8_t *, vuint8m1_t, vuint8m1_t, vuint8m1_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vsoxseg2ei8_v_m)))
void vsoxseg2ei8(vbool8_t, uint8_t *, vuint8m1_t, vuint8m1_t, vuint8m1_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vsoxseg2ei8_v)))
void vsoxseg2ei8(uint8_t *, vuint8m2_t, vuint8m2_t, vuint8m2_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vsoxseg2ei8_v_m)))
void vsoxseg2ei8(vbool4_t, uint8_t *, vuint8m2_t, vuint8m2_t, vuint8m2_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vsoxseg2ei8_v)))
void vsoxseg2ei8(uint8_t *, vuint8m4_t, vuint8m4_t, vuint8m4_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vsoxseg2ei8_v_m)))
void vsoxseg2ei8(vbool2_t, uint8_t *, vuint8m4_t, vuint8m4_t, vuint8m4_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vsoxseg2ei8_v)))
void vsoxseg2ei8(uint8_t *, vuint8mf2_t, vuint8mf2_t, vuint8mf2_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vsoxseg2ei8_v_m)))
void vsoxseg2ei8(vbool16_t, uint8_t *, vuint8mf2_t, vuint8mf2_t, vuint8mf2_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vsoxseg2ei8_v)))
void vsoxseg2ei8(uint8_t *, vuint8mf4_t, vuint8mf4_t, vuint8mf4_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vsoxseg2ei8_v_m)))
void vsoxseg2ei8(vbool32_t, uint8_t *, vuint8mf4_t, vuint8mf4_t, vuint8mf4_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vsoxseg2ei8_v)))
void vsoxseg2ei8(uint8_t *, vuint8mf8_t, vuint8mf8_t, vuint8mf8_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vsoxseg2ei8_v_m)))
void vsoxseg2ei8(vbool64_t, uint8_t *, vuint8mf8_t, vuint8mf8_t, vuint8mf8_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vloxei32_v)))
vuint8m1_t vloxei32(const uint8_t *, vuint32m4_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vloxei32_v_m)))
vuint8m1_t vloxei32(vbool8_t, vuint8m1_t, const uint8_t *, vuint32m4_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vloxei32_v)))
vuint8m2_t vloxei32(const uint8_t *, vuint32m8_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vloxei32_v_m)))
vuint8m2_t vloxei32(vbool4_t, vuint8m2_t, const uint8_t *, vuint32m8_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vloxei32_v)))
vuint8mf2_t vloxei32(const uint8_t *, vuint32m2_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vloxei32_v_m)))
vuint8mf2_t vloxei32(vbool16_t, vuint8mf2_t, const uint8_t *, vuint32m2_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vloxei32_v)))
vuint8mf4_t vloxei32(const uint8_t *, vuint32m1_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vloxei32_v_m)))
vuint8mf4_t vloxei32(vbool32_t, vuint8mf4_t, const uint8_t *, vuint32m1_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vloxei32_v)))
vuint8mf8_t vloxei32(const uint8_t *, vuint32mf2_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vloxei32_v_m)))
vuint8mf8_t vloxei32(vbool64_t, vuint8mf8_t, const uint8_t *, vuint32mf2_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vsoxseg3ei8_v)))
void vsoxseg3ei8(int8_t *, vuint8m1_t, vint8m1_t, vint8m1_t, vint8m1_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vsoxseg3ei8_v_m)))
void vsoxseg3ei8(vbool8_t, int8_t *, vuint8m1_t, vint8m1_t, vint8m1_t, vint8m1_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vsoxseg3ei8_v)))
void vsoxseg3ei8(int8_t *, vuint8m2_t, vint8m2_t, vint8m2_t, vint8m2_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vsoxseg3ei8_v_m)))
void vsoxseg3ei8(vbool4_t, int8_t *, vuint8m2_t, vint8m2_t, vint8m2_t, vint8m2_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vsoxseg3ei8_v)))
void vsoxseg3ei8(int8_t *, vuint8mf2_t, vint8mf2_t, vint8mf2_t, vint8mf2_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vsoxseg3ei8_v_m)))
void vsoxseg3ei8(vbool16_t, int8_t *, vuint8mf2_t, vint8mf2_t, vint8mf2_t, vint8mf2_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vsoxseg3ei8_v)))
void vsoxseg3ei8(int8_t *, vuint8mf4_t, vint8mf4_t, vint8mf4_t, vint8mf4_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vsoxseg3ei8_v_m)))
void vsoxseg3ei8(vbool32_t, int8_t *, vuint8mf4_t, vint8mf4_t, vint8mf4_t, vint8mf4_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vsoxseg3ei8_v)))
void vsoxseg3ei8(int8_t *, vuint8mf8_t, vint8mf8_t, vint8mf8_t, vint8mf8_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vsoxseg3ei8_v_m)))
void vsoxseg3ei8(vbool64_t, int8_t *, vuint8mf8_t, vint8mf8_t, vint8mf8_t, vint8mf8_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vsoxseg3ei8_v)))
void vsoxseg3ei8(uint8_t *, vuint8m1_t, vuint8m1_t, vuint8m1_t, vuint8m1_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vsoxseg3ei8_v_m)))
void vsoxseg3ei8(vbool8_t, uint8_t *, vuint8m1_t, vuint8m1_t, vuint8m1_t, vuint8m1_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vsoxseg3ei8_v)))
void vsoxseg3ei8(uint8_t *, vuint8m2_t, vuint8m2_t, vuint8m2_t, vuint8m2_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vsoxseg3ei8_v_m)))
void vsoxseg3ei8(vbool4_t, uint8_t *, vuint8m2_t, vuint8m2_t, vuint8m2_t, vuint8m2_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vsoxseg3ei8_v)))
void vsoxseg3ei8(uint8_t *, vuint8mf2_t, vuint8mf2_t, vuint8mf2_t, vuint8mf2_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vsoxseg3ei8_v_m)))
void vsoxseg3ei8(vbool16_t, uint8_t *, vuint8mf2_t, vuint8mf2_t, vuint8mf2_t, vuint8mf2_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vsoxseg3ei8_v)))
void vsoxseg3ei8(uint8_t *, vuint8mf4_t, vuint8mf4_t, vuint8mf4_t, vuint8mf4_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vsoxseg3ei8_v_m)))
void vsoxseg3ei8(vbool32_t, uint8_t *, vuint8mf4_t, vuint8mf4_t, vuint8mf4_t, vuint8mf4_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vsoxseg3ei8_v)))
void vsoxseg3ei8(uint8_t *, vuint8mf8_t, vuint8mf8_t, vuint8mf8_t, vuint8mf8_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vsoxseg3ei8_v_m)))
void vsoxseg3ei8(vbool64_t, uint8_t *, vuint8mf8_t, vuint8mf8_t, vuint8mf8_t, vuint8mf8_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vsoxseg4ei8_v)))
void vsoxseg4ei8(int8_t *, vuint8m1_t, vint8m1_t, vint8m1_t, vint8m1_t, vint8m1_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vsoxseg4ei8_v_m)))
void vsoxseg4ei8(vbool8_t, int8_t *, vuint8m1_t, vint8m1_t, vint8m1_t, vint8m1_t, vint8m1_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vsoxseg4ei8_v)))
void vsoxseg4ei8(int8_t *, vuint8m2_t, vint8m2_t, vint8m2_t, vint8m2_t, vint8m2_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vsoxseg4ei8_v_m)))
void vsoxseg4ei8(vbool4_t, int8_t *, vuint8m2_t, vint8m2_t, vint8m2_t, vint8m2_t, vint8m2_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vsoxseg4ei8_v)))
void vsoxseg4ei8(int8_t *, vuint8mf2_t, vint8mf2_t, vint8mf2_t, vint8mf2_t, vint8mf2_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vsoxseg4ei8_v_m)))
void vsoxseg4ei8(vbool16_t, int8_t *, vuint8mf2_t, vint8mf2_t, vint8mf2_t, vint8mf2_t, vint8mf2_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vsoxseg4ei8_v)))
void vsoxseg4ei8(int8_t *, vuint8mf4_t, vint8mf4_t, vint8mf4_t, vint8mf4_t, vint8mf4_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vsoxseg4ei8_v_m)))
void vsoxseg4ei8(vbool32_t, int8_t *, vuint8mf4_t, vint8mf4_t, vint8mf4_t, vint8mf4_t, vint8mf4_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vsoxseg4ei8_v)))
void vsoxseg4ei8(int8_t *, vuint8mf8_t, vint8mf8_t, vint8mf8_t, vint8mf8_t, vint8mf8_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vsoxseg4ei8_v_m)))
void vsoxseg4ei8(vbool64_t, int8_t *, vuint8mf8_t, vint8mf8_t, vint8mf8_t, vint8mf8_t, vint8mf8_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vsoxseg4ei8_v)))
void vsoxseg4ei8(uint8_t *, vuint8m1_t, vuint8m1_t, vuint8m1_t, vuint8m1_t, vuint8m1_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vsoxseg4ei8_v_m)))
void vsoxseg4ei8(vbool8_t, uint8_t *, vuint8m1_t, vuint8m1_t, vuint8m1_t, vuint8m1_t, vuint8m1_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vsoxseg4ei8_v)))
void vsoxseg4ei8(uint8_t *, vuint8m2_t, vuint8m2_t, vuint8m2_t, vuint8m2_t, vuint8m2_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vsoxseg4ei8_v_m)))
void vsoxseg4ei8(vbool4_t, uint8_t *, vuint8m2_t, vuint8m2_t, vuint8m2_t, vuint8m2_t, vuint8m2_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vsoxseg4ei8_v)))
void vsoxseg4ei8(uint8_t *, vuint8mf2_t, vuint8mf2_t, vuint8mf2_t, vuint8mf2_t, vuint8mf2_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vsoxseg4ei8_v_m)))
void vsoxseg4ei8(vbool16_t, uint8_t *, vuint8mf2_t, vuint8mf2_t, vuint8mf2_t, vuint8mf2_t, vuint8mf2_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vsoxseg4ei8_v)))
void vsoxseg4ei8(uint8_t *, vuint8mf4_t, vuint8mf4_t, vuint8mf4_t, vuint8mf4_t, vuint8mf4_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vsoxseg4ei8_v_m)))
void vsoxseg4ei8(vbool32_t, uint8_t *, vuint8mf4_t, vuint8mf4_t, vuint8mf4_t, vuint8mf4_t, vuint8mf4_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vsoxseg4ei8_v)))
void vsoxseg4ei8(uint8_t *, vuint8mf8_t, vuint8mf8_t, vuint8mf8_t, vuint8mf8_t, vuint8mf8_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vsoxseg4ei8_v_m)))
void vsoxseg4ei8(vbool64_t, uint8_t *, vuint8mf8_t, vuint8mf8_t, vuint8mf8_t, vuint8mf8_t, vuint8mf8_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vsoxseg5ei8_v)))
void vsoxseg5ei8(int8_t *, vuint8m1_t, vint8m1_t, vint8m1_t, vint8m1_t, vint8m1_t, vint8m1_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vsoxseg5ei8_v_m)))
void vsoxseg5ei8(vbool8_t, int8_t *, vuint8m1_t, vint8m1_t, vint8m1_t, vint8m1_t, vint8m1_t, vint8m1_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vsoxseg5ei8_v)))
void vsoxseg5ei8(int8_t *, vuint8mf2_t, vint8mf2_t, vint8mf2_t, vint8mf2_t, vint8mf2_t, vint8mf2_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vsoxseg5ei8_v_m)))
void vsoxseg5ei8(vbool16_t, int8_t *, vuint8mf2_t, vint8mf2_t, vint8mf2_t, vint8mf2_t, vint8mf2_t, vint8mf2_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vsoxseg5ei8_v)))
void vsoxseg5ei8(int8_t *, vuint8mf4_t, vint8mf4_t, vint8mf4_t, vint8mf4_t, vint8mf4_t, vint8mf4_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vsoxseg5ei8_v_m)))
void vsoxseg5ei8(vbool32_t, int8_t *, vuint8mf4_t, vint8mf4_t, vint8mf4_t, vint8mf4_t, vint8mf4_t, vint8mf4_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vsoxseg5ei8_v)))
void vsoxseg5ei8(int8_t *, vuint8mf8_t, vint8mf8_t, vint8mf8_t, vint8mf8_t, vint8mf8_t, vint8mf8_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vsoxseg5ei8_v_m)))
void vsoxseg5ei8(vbool64_t, int8_t *, vuint8mf8_t, vint8mf8_t, vint8mf8_t, vint8mf8_t, vint8mf8_t, vint8mf8_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vsoxseg5ei8_v)))
void vsoxseg5ei8(uint8_t *, vuint8m1_t, vuint8m1_t, vuint8m1_t, vuint8m1_t, vuint8m1_t, vuint8m1_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vsoxseg5ei8_v_m)))
void vsoxseg5ei8(vbool8_t, uint8_t *, vuint8m1_t, vuint8m1_t, vuint8m1_t, vuint8m1_t, vuint8m1_t, vuint8m1_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vsoxseg5ei8_v)))
void vsoxseg5ei8(uint8_t *, vuint8mf2_t, vuint8mf2_t, vuint8mf2_t, vuint8mf2_t, vuint8mf2_t, vuint8mf2_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vsoxseg5ei8_v_m)))
void vsoxseg5ei8(vbool16_t, uint8_t *, vuint8mf2_t, vuint8mf2_t, vuint8mf2_t, vuint8mf2_t, vuint8mf2_t, vuint8mf2_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vsoxseg5ei8_v)))
void vsoxseg5ei8(uint8_t *, vuint8mf4_t, vuint8mf4_t, vuint8mf4_t, vuint8mf4_t, vuint8mf4_t, vuint8mf4_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vsoxseg5ei8_v_m)))
void vsoxseg5ei8(vbool32_t, uint8_t *, vuint8mf4_t, vuint8mf4_t, vuint8mf4_t, vuint8mf4_t, vuint8mf4_t, vuint8mf4_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vsoxseg5ei8_v)))
void vsoxseg5ei8(uint8_t *, vuint8mf8_t, vuint8mf8_t, vuint8mf8_t, vuint8mf8_t, vuint8mf8_t, vuint8mf8_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vsoxseg5ei8_v_m)))
void vsoxseg5ei8(vbool64_t, uint8_t *, vuint8mf8_t, vuint8mf8_t, vuint8mf8_t, vuint8mf8_t, vuint8mf8_t, vuint8mf8_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vsoxseg6ei8_v)))
void vsoxseg6ei8(int8_t *, vuint8m1_t, vint8m1_t, vint8m1_t, vint8m1_t, vint8m1_t, vint8m1_t, vint8m1_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vsoxseg6ei8_v_m)))
void vsoxseg6ei8(vbool8_t, int8_t *, vuint8m1_t, vint8m1_t, vint8m1_t, vint8m1_t, vint8m1_t, vint8m1_t, vint8m1_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vsoxseg6ei8_v)))
void vsoxseg6ei8(int8_t *, vuint8mf2_t, vint8mf2_t, vint8mf2_t, vint8mf2_t, vint8mf2_t, vint8mf2_t, vint8mf2_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vsoxseg6ei8_v_m)))
void vsoxseg6ei8(vbool16_t, int8_t *, vuint8mf2_t, vint8mf2_t, vint8mf2_t, vint8mf2_t, vint8mf2_t, vint8mf2_t, vint8mf2_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vsoxseg6ei8_v)))
void vsoxseg6ei8(int8_t *, vuint8mf4_t, vint8mf4_t, vint8mf4_t, vint8mf4_t, vint8mf4_t, vint8mf4_t, vint8mf4_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vsoxseg6ei8_v_m)))
void vsoxseg6ei8(vbool32_t, int8_t *, vuint8mf4_t, vint8mf4_t, vint8mf4_t, vint8mf4_t, vint8mf4_t, vint8mf4_t, vint8mf4_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vsoxseg6ei8_v)))
void vsoxseg6ei8(int8_t *, vuint8mf8_t, vint8mf8_t, vint8mf8_t, vint8mf8_t, vint8mf8_t, vint8mf8_t, vint8mf8_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vsoxseg6ei8_v_m)))
void vsoxseg6ei8(vbool64_t, int8_t *, vuint8mf8_t, vint8mf8_t, vint8mf8_t, vint8mf8_t, vint8mf8_t, vint8mf8_t, vint8mf8_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vsoxseg6ei8_v)))
void vsoxseg6ei8(uint8_t *, vuint8m1_t, vuint8m1_t, vuint8m1_t, vuint8m1_t, vuint8m1_t, vuint8m1_t, vuint8m1_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vsoxseg6ei8_v_m)))
void vsoxseg6ei8(vbool8_t, uint8_t *, vuint8m1_t, vuint8m1_t, vuint8m1_t, vuint8m1_t, vuint8m1_t, vuint8m1_t, vuint8m1_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vsoxseg6ei8_v)))
void vsoxseg6ei8(uint8_t *, vuint8mf2_t, vuint8mf2_t, vuint8mf2_t, vuint8mf2_t, vuint8mf2_t, vuint8mf2_t, vuint8mf2_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vsoxseg6ei8_v_m)))
void vsoxseg6ei8(vbool16_t, uint8_t *, vuint8mf2_t, vuint8mf2_t, vuint8mf2_t, vuint8mf2_t, vuint8mf2_t, vuint8mf2_t, vuint8mf2_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vsoxseg6ei8_v)))
void vsoxseg6ei8(uint8_t *, vuint8mf4_t, vuint8mf4_t, vuint8mf4_t, vuint8mf4_t, vuint8mf4_t, vuint8mf4_t, vuint8mf4_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vsoxseg6ei8_v_m)))
void vsoxseg6ei8(vbool32_t, uint8_t *, vuint8mf4_t, vuint8mf4_t, vuint8mf4_t, vuint8mf4_t, vuint8mf4_t, vuint8mf4_t, vuint8mf4_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vsoxseg6ei8_v)))
void vsoxseg6ei8(uint8_t *, vuint8mf8_t, vuint8mf8_t, vuint8mf8_t, vuint8mf8_t, vuint8mf8_t, vuint8mf8_t, vuint8mf8_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vsoxseg6ei8_v_m)))
void vsoxseg6ei8(vbool64_t, uint8_t *, vuint8mf8_t, vuint8mf8_t, vuint8mf8_t, vuint8mf8_t, vuint8mf8_t, vuint8mf8_t, vuint8mf8_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vsoxseg7ei8_v)))
void vsoxseg7ei8(int8_t *, vuint8m1_t, vint8m1_t, vint8m1_t, vint8m1_t, vint8m1_t, vint8m1_t, vint8m1_t, vint8m1_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vsoxseg7ei8_v_m)))
void vsoxseg7ei8(vbool8_t, int8_t *, vuint8m1_t, vint8m1_t, vint8m1_t, vint8m1_t, vint8m1_t, vint8m1_t, vint8m1_t, vint8m1_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vsoxseg7ei8_v)))
void vsoxseg7ei8(int8_t *, vuint8mf2_t, vint8mf2_t, vint8mf2_t, vint8mf2_t, vint8mf2_t, vint8mf2_t, vint8mf2_t, vint8mf2_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vsoxseg7ei8_v_m)))
void vsoxseg7ei8(vbool16_t, int8_t *, vuint8mf2_t, vint8mf2_t, vint8mf2_t, vint8mf2_t, vint8mf2_t, vint8mf2_t, vint8mf2_t, vint8mf2_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vsoxseg7ei8_v)))
void vsoxseg7ei8(int8_t *, vuint8mf4_t, vint8mf4_t, vint8mf4_t, vint8mf4_t, vint8mf4_t, vint8mf4_t, vint8mf4_t, vint8mf4_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vsoxseg7ei8_v_m)))
void vsoxseg7ei8(vbool32_t, int8_t *, vuint8mf4_t, vint8mf4_t, vint8mf4_t, vint8mf4_t, vint8mf4_t, vint8mf4_t, vint8mf4_t, vint8mf4_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vsoxseg7ei8_v)))
void vsoxseg7ei8(int8_t *, vuint8mf8_t, vint8mf8_t, vint8mf8_t, vint8mf8_t, vint8mf8_t, vint8mf8_t, vint8mf8_t, vint8mf8_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vsoxseg7ei8_v_m)))
void vsoxseg7ei8(vbool64_t, int8_t *, vuint8mf8_t, vint8mf8_t, vint8mf8_t, vint8mf8_t, vint8mf8_t, vint8mf8_t, vint8mf8_t, vint8mf8_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vsoxseg7ei8_v)))
void vsoxseg7ei8(uint8_t *, vuint8m1_t, vuint8m1_t, vuint8m1_t, vuint8m1_t, vuint8m1_t, vuint8m1_t, vuint8m1_t, vuint8m1_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vsoxseg7ei8_v_m)))
void vsoxseg7ei8(vbool8_t, uint8_t *, vuint8m1_t, vuint8m1_t, vuint8m1_t, vuint8m1_t, vuint8m1_t, vuint8m1_t, vuint8m1_t, vuint8m1_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vsoxseg7ei8_v)))
void vsoxseg7ei8(uint8_t *, vuint8mf2_t, vuint8mf2_t, vuint8mf2_t, vuint8mf2_t, vuint8mf2_t, vuint8mf2_t, vuint8mf2_t, vuint8mf2_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vsoxseg7ei8_v_m)))
void vsoxseg7ei8(vbool16_t, uint8_t *, vuint8mf2_t, vuint8mf2_t, vuint8mf2_t, vuint8mf2_t, vuint8mf2_t, vuint8mf2_t, vuint8mf2_t, vuint8mf2_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vsoxseg7ei8_v)))
void vsoxseg7ei8(uint8_t *, vuint8mf4_t, vuint8mf4_t, vuint8mf4_t, vuint8mf4_t, vuint8mf4_t, vuint8mf4_t, vuint8mf4_t, vuint8mf4_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vsoxseg7ei8_v_m)))
void vsoxseg7ei8(vbool32_t, uint8_t *, vuint8mf4_t, vuint8mf4_t, vuint8mf4_t, vuint8mf4_t, vuint8mf4_t, vuint8mf4_t, vuint8mf4_t, vuint8mf4_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vsoxseg7ei8_v)))
void vsoxseg7ei8(uint8_t *, vuint8mf8_t, vuint8mf8_t, vuint8mf8_t, vuint8mf8_t, vuint8mf8_t, vuint8mf8_t, vuint8mf8_t, vuint8mf8_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vsoxseg7ei8_v_m)))
void vsoxseg7ei8(vbool64_t, uint8_t *, vuint8mf8_t, vuint8mf8_t, vuint8mf8_t, vuint8mf8_t, vuint8mf8_t, vuint8mf8_t, vuint8mf8_t, vuint8mf8_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vsoxseg8ei8_v)))
void vsoxseg8ei8(int8_t *, vuint8m1_t, vint8m1_t, vint8m1_t, vint8m1_t, vint8m1_t, vint8m1_t, vint8m1_t, vint8m1_t, vint8m1_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vsoxseg8ei8_v_m)))
void vsoxseg8ei8(vbool8_t, int8_t *, vuint8m1_t, vint8m1_t, vint8m1_t, vint8m1_t, vint8m1_t, vint8m1_t, vint8m1_t, vint8m1_t, vint8m1_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vsoxseg8ei8_v)))
void vsoxseg8ei8(int8_t *, vuint8mf2_t, vint8mf2_t, vint8mf2_t, vint8mf2_t, vint8mf2_t, vint8mf2_t, vint8mf2_t, vint8mf2_t, vint8mf2_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vsoxseg8ei8_v_m)))
void vsoxseg8ei8(vbool16_t, int8_t *, vuint8mf2_t, vint8mf2_t, vint8mf2_t, vint8mf2_t, vint8mf2_t, vint8mf2_t, vint8mf2_t, vint8mf2_t, vint8mf2_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vsoxseg8ei8_v)))
void vsoxseg8ei8(int8_t *, vuint8mf4_t, vint8mf4_t, vint8mf4_t, vint8mf4_t, vint8mf4_t, vint8mf4_t, vint8mf4_t, vint8mf4_t, vint8mf4_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vsoxseg8ei8_v_m)))
void vsoxseg8ei8(vbool32_t, int8_t *, vuint8mf4_t, vint8mf4_t, vint8mf4_t, vint8mf4_t, vint8mf4_t, vint8mf4_t, vint8mf4_t, vint8mf4_t, vint8mf4_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vsoxseg8ei8_v)))
void vsoxseg8ei8(int8_t *, vuint8mf8_t, vint8mf8_t, vint8mf8_t, vint8mf8_t, vint8mf8_t, vint8mf8_t, vint8mf8_t, vint8mf8_t, vint8mf8_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vsoxseg8ei8_v_m)))
void vsoxseg8ei8(vbool64_t, int8_t *, vuint8mf8_t, vint8mf8_t, vint8mf8_t, vint8mf8_t, vint8mf8_t, vint8mf8_t, vint8mf8_t, vint8mf8_t, vint8mf8_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vsoxseg8ei8_v)))
void vsoxseg8ei8(uint8_t *, vuint8m1_t, vuint8m1_t, vuint8m1_t, vuint8m1_t, vuint8m1_t, vuint8m1_t, vuint8m1_t, vuint8m1_t, vuint8m1_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vsoxseg8ei8_v_m)))
void vsoxseg8ei8(vbool8_t, uint8_t *, vuint8m1_t, vuint8m1_t, vuint8m1_t, vuint8m1_t, vuint8m1_t, vuint8m1_t, vuint8m1_t, vuint8m1_t, vuint8m1_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vsoxseg8ei8_v)))
void vsoxseg8ei8(uint8_t *, vuint8mf2_t, vuint8mf2_t, vuint8mf2_t, vuint8mf2_t, vuint8mf2_t, vuint8mf2_t, vuint8mf2_t, vuint8mf2_t, vuint8mf2_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vsoxseg8ei8_v_m)))
void vsoxseg8ei8(vbool16_t, uint8_t *, vuint8mf2_t, vuint8mf2_t, vuint8mf2_t, vuint8mf2_t, vuint8mf2_t, vuint8mf2_t, vuint8mf2_t, vuint8mf2_t, vuint8mf2_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vsoxseg8ei8_v)))
void vsoxseg8ei8(uint8_t *, vuint8mf4_t, vuint8mf4_t, vuint8mf4_t, vuint8mf4_t, vuint8mf4_t, vuint8mf4_t, vuint8mf4_t, vuint8mf4_t, vuint8mf4_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vsoxseg8ei8_v_m)))
void vsoxseg8ei8(vbool32_t, uint8_t *, vuint8mf4_t, vuint8mf4_t, vuint8mf4_t, vuint8mf4_t, vuint8mf4_t, vuint8mf4_t, vuint8mf4_t, vuint8mf4_t, vuint8mf4_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vsoxseg8ei8_v)))
void vsoxseg8ei8(uint8_t *, vuint8mf8_t, vuint8mf8_t, vuint8mf8_t, vuint8mf8_t, vuint8mf8_t, vuint8mf8_t, vuint8mf8_t, vuint8mf8_t, vuint8mf8_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vsoxseg8ei8_v_m)))
void vsoxseg8ei8(vbool64_t, uint8_t *, vuint8mf8_t, vuint8mf8_t, vuint8mf8_t, vuint8mf8_t, vuint8mf8_t, vuint8mf8_t, vuint8mf8_t, vuint8mf8_t, vuint8mf8_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vsoxseg2ei16_v)))
void vsoxseg2ei16(int8_t *, vuint16m2_t, vint8m1_t, vint8m1_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vsoxseg2ei16_v_m)))
void vsoxseg2ei16(vbool8_t, int8_t *, vuint16m2_t, vint8m1_t, vint8m1_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vsoxseg2ei16_v)))
void vsoxseg2ei16(int8_t *, vuint16m4_t, vint8m2_t, vint8m2_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vsoxseg2ei16_v_m)))
void vsoxseg2ei16(vbool4_t, int8_t *, vuint16m4_t, vint8m2_t, vint8m2_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vsoxseg2ei16_v)))
void vsoxseg2ei16(int8_t *, vuint16m8_t, vint8m4_t, vint8m4_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vsoxseg2ei16_v_m)))
void vsoxseg2ei16(vbool2_t, int8_t *, vuint16m8_t, vint8m4_t, vint8m4_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vsoxseg2ei16_v)))
void vsoxseg2ei16(int8_t *, vuint16m1_t, vint8mf2_t, vint8mf2_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vsoxseg2ei16_v_m)))
void vsoxseg2ei16(vbool16_t, int8_t *, vuint16m1_t, vint8mf2_t, vint8mf2_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vsoxseg2ei16_v)))
void vsoxseg2ei16(int8_t *, vuint16mf2_t, vint8mf4_t, vint8mf4_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vsoxseg2ei16_v_m)))
void vsoxseg2ei16(vbool32_t, int8_t *, vuint16mf2_t, vint8mf4_t, vint8mf4_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vsoxseg2ei16_v)))
void vsoxseg2ei16(int8_t *, vuint16mf4_t, vint8mf8_t, vint8mf8_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vsoxseg2ei16_v_m)))
void vsoxseg2ei16(vbool64_t, int8_t *, vuint16mf4_t, vint8mf8_t, vint8mf8_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vsoxseg2ei16_v)))
void vsoxseg2ei16(uint8_t *, vuint16m2_t, vuint8m1_t, vuint8m1_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vsoxseg2ei16_v_m)))
void vsoxseg2ei16(vbool8_t, uint8_t *, vuint16m2_t, vuint8m1_t, vuint8m1_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vsoxseg2ei16_v)))
void vsoxseg2ei16(uint8_t *, vuint16m4_t, vuint8m2_t, vuint8m2_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vsoxseg2ei16_v_m)))
void vsoxseg2ei16(vbool4_t, uint8_t *, vuint16m4_t, vuint8m2_t, vuint8m2_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vsoxseg2ei16_v)))
void vsoxseg2ei16(uint8_t *, vuint16m8_t, vuint8m4_t, vuint8m4_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vsoxseg2ei16_v_m)))
void vsoxseg2ei16(vbool2_t, uint8_t *, vuint16m8_t, vuint8m4_t, vuint8m4_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vsoxseg2ei16_v)))
void vsoxseg2ei16(uint8_t *, vuint16m1_t, vuint8mf2_t, vuint8mf2_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vsoxseg2ei16_v_m)))
void vsoxseg2ei16(vbool16_t, uint8_t *, vuint16m1_t, vuint8mf2_t, vuint8mf2_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vsoxseg2ei16_v)))
void vsoxseg2ei16(uint8_t *, vuint16mf2_t, vuint8mf4_t, vuint8mf4_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vsoxseg2ei16_v_m)))
void vsoxseg2ei16(vbool32_t, uint8_t *, vuint16mf2_t, vuint8mf4_t, vuint8mf4_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vsoxseg2ei16_v)))
void vsoxseg2ei16(uint8_t *, vuint16mf4_t, vuint8mf8_t, vuint8mf8_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vsoxseg2ei16_v_m)))
void vsoxseg2ei16(vbool64_t, uint8_t *, vuint16mf4_t, vuint8mf8_t, vuint8mf8_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vsoxseg3ei16_v)))
void vsoxseg3ei16(int8_t *, vuint16m2_t, vint8m1_t, vint8m1_t, vint8m1_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vsoxseg3ei16_v_m)))
void vsoxseg3ei16(vbool8_t, int8_t *, vuint16m2_t, vint8m1_t, vint8m1_t, vint8m1_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vsoxseg3ei16_v)))
void vsoxseg3ei16(int8_t *, vuint16m4_t, vint8m2_t, vint8m2_t, vint8m2_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vsoxseg3ei16_v_m)))
void vsoxseg3ei16(vbool4_t, int8_t *, vuint16m4_t, vint8m2_t, vint8m2_t, vint8m2_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vsoxseg3ei16_v)))
void vsoxseg3ei16(int8_t *, vuint16m1_t, vint8mf2_t, vint8mf2_t, vint8mf2_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vsoxseg3ei16_v_m)))
void vsoxseg3ei16(vbool16_t, int8_t *, vuint16m1_t, vint8mf2_t, vint8mf2_t, vint8mf2_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vsoxseg3ei16_v)))
void vsoxseg3ei16(int8_t *, vuint16mf2_t, vint8mf4_t, vint8mf4_t, vint8mf4_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vsoxseg3ei16_v_m)))
void vsoxseg3ei16(vbool32_t, int8_t *, vuint16mf2_t, vint8mf4_t, vint8mf4_t, vint8mf4_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vsoxseg3ei16_v)))
void vsoxseg3ei16(int8_t *, vuint16mf4_t, vint8mf8_t, vint8mf8_t, vint8mf8_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vsoxseg3ei16_v_m)))
void vsoxseg3ei16(vbool64_t, int8_t *, vuint16mf4_t, vint8mf8_t, vint8mf8_t, vint8mf8_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vsoxseg3ei16_v)))
void vsoxseg3ei16(uint8_t *, vuint16m2_t, vuint8m1_t, vuint8m1_t, vuint8m1_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vsoxseg3ei16_v_m)))
void vsoxseg3ei16(vbool8_t, uint8_t *, vuint16m2_t, vuint8m1_t, vuint8m1_t, vuint8m1_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vsoxseg3ei16_v)))
void vsoxseg3ei16(uint8_t *, vuint16m4_t, vuint8m2_t, vuint8m2_t, vuint8m2_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vsoxseg3ei16_v_m)))
void vsoxseg3ei16(vbool4_t, uint8_t *, vuint16m4_t, vuint8m2_t, vuint8m2_t, vuint8m2_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vsoxseg3ei16_v)))
void vsoxseg3ei16(uint8_t *, vuint16m1_t, vuint8mf2_t, vuint8mf2_t, vuint8mf2_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vsoxseg3ei16_v_m)))
void vsoxseg3ei16(vbool16_t, uint8_t *, vuint16m1_t, vuint8mf2_t, vuint8mf2_t, vuint8mf2_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vsoxseg3ei16_v)))
void vsoxseg3ei16(uint8_t *, vuint16mf2_t, vuint8mf4_t, vuint8mf4_t, vuint8mf4_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vsoxseg3ei16_v_m)))
void vsoxseg3ei16(vbool32_t, uint8_t *, vuint16mf2_t, vuint8mf4_t, vuint8mf4_t, vuint8mf4_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vsoxseg3ei16_v)))
void vsoxseg3ei16(uint8_t *, vuint16mf4_t, vuint8mf8_t, vuint8mf8_t, vuint8mf8_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vsoxseg3ei16_v_m)))
void vsoxseg3ei16(vbool64_t, uint8_t *, vuint16mf4_t, vuint8mf8_t, vuint8mf8_t, vuint8mf8_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vsoxseg4ei16_v)))
void vsoxseg4ei16(int8_t *, vuint16m2_t, vint8m1_t, vint8m1_t, vint8m1_t, vint8m1_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vsoxseg4ei16_v_m)))
void vsoxseg4ei16(vbool8_t, int8_t *, vuint16m2_t, vint8m1_t, vint8m1_t, vint8m1_t, vint8m1_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vsoxseg4ei16_v)))
void vsoxseg4ei16(int8_t *, vuint16m4_t, vint8m2_t, vint8m2_t, vint8m2_t, vint8m2_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vsoxseg4ei16_v_m)))
void vsoxseg4ei16(vbool4_t, int8_t *, vuint16m4_t, vint8m2_t, vint8m2_t, vint8m2_t, vint8m2_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vsoxseg4ei16_v)))
void vsoxseg4ei16(int8_t *, vuint16m1_t, vint8mf2_t, vint8mf2_t, vint8mf2_t, vint8mf2_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vsoxseg4ei16_v_m)))
void vsoxseg4ei16(vbool16_t, int8_t *, vuint16m1_t, vint8mf2_t, vint8mf2_t, vint8mf2_t, vint8mf2_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vsoxseg4ei16_v)))
void vsoxseg4ei16(int8_t *, vuint16mf2_t, vint8mf4_t, vint8mf4_t, vint8mf4_t, vint8mf4_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vsoxseg4ei16_v_m)))
void vsoxseg4ei16(vbool32_t, int8_t *, vuint16mf2_t, vint8mf4_t, vint8mf4_t, vint8mf4_t, vint8mf4_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vsoxseg4ei16_v)))
void vsoxseg4ei16(int8_t *, vuint16mf4_t, vint8mf8_t, vint8mf8_t, vint8mf8_t, vint8mf8_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vsoxseg4ei16_v_m)))
void vsoxseg4ei16(vbool64_t, int8_t *, vuint16mf4_t, vint8mf8_t, vint8mf8_t, vint8mf8_t, vint8mf8_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vsoxseg4ei16_v)))
void vsoxseg4ei16(uint8_t *, vuint16m2_t, vuint8m1_t, vuint8m1_t, vuint8m1_t, vuint8m1_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vsoxseg4ei16_v_m)))
void vsoxseg4ei16(vbool8_t, uint8_t *, vuint16m2_t, vuint8m1_t, vuint8m1_t, vuint8m1_t, vuint8m1_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vsoxseg4ei16_v)))
void vsoxseg4ei16(uint8_t *, vuint16m4_t, vuint8m2_t, vuint8m2_t, vuint8m2_t, vuint8m2_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vsoxseg4ei16_v_m)))
void vsoxseg4ei16(vbool4_t, uint8_t *, vuint16m4_t, vuint8m2_t, vuint8m2_t, vuint8m2_t, vuint8m2_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vsoxseg4ei16_v)))
void vsoxseg4ei16(uint8_t *, vuint16m1_t, vuint8mf2_t, vuint8mf2_t, vuint8mf2_t, vuint8mf2_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vsoxseg4ei16_v_m)))
void vsoxseg4ei16(vbool16_t, uint8_t *, vuint16m1_t, vuint8mf2_t, vuint8mf2_t, vuint8mf2_t, vuint8mf2_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vsoxseg4ei16_v)))
void vsoxseg4ei16(uint8_t *, vuint16mf2_t, vuint8mf4_t, vuint8mf4_t, vuint8mf4_t, vuint8mf4_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vsoxseg4ei16_v_m)))
void vsoxseg4ei16(vbool32_t, uint8_t *, vuint16mf2_t, vuint8mf4_t, vuint8mf4_t, vuint8mf4_t, vuint8mf4_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vsoxseg4ei16_v)))
void vsoxseg4ei16(uint8_t *, vuint16mf4_t, vuint8mf8_t, vuint8mf8_t, vuint8mf8_t, vuint8mf8_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vsoxseg4ei16_v_m)))
void vsoxseg4ei16(vbool64_t, uint8_t *, vuint16mf4_t, vuint8mf8_t, vuint8mf8_t, vuint8mf8_t, vuint8mf8_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vsoxseg5ei16_v)))
void vsoxseg5ei16(int8_t *, vuint16m2_t, vint8m1_t, vint8m1_t, vint8m1_t, vint8m1_t, vint8m1_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vsoxseg5ei16_v_m)))
void vsoxseg5ei16(vbool8_t, int8_t *, vuint16m2_t, vint8m1_t, vint8m1_t, vint8m1_t, vint8m1_t, vint8m1_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vsoxseg5ei16_v)))
void vsoxseg5ei16(int8_t *, vuint16m1_t, vint8mf2_t, vint8mf2_t, vint8mf2_t, vint8mf2_t, vint8mf2_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vsoxseg5ei16_v_m)))
void vsoxseg5ei16(vbool16_t, int8_t *, vuint16m1_t, vint8mf2_t, vint8mf2_t, vint8mf2_t, vint8mf2_t, vint8mf2_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vsoxseg5ei16_v)))
void vsoxseg5ei16(int8_t *, vuint16mf2_t, vint8mf4_t, vint8mf4_t, vint8mf4_t, vint8mf4_t, vint8mf4_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vsoxseg5ei16_v_m)))
void vsoxseg5ei16(vbool32_t, int8_t *, vuint16mf2_t, vint8mf4_t, vint8mf4_t, vint8mf4_t, vint8mf4_t, vint8mf4_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vsoxseg5ei16_v)))
void vsoxseg5ei16(int8_t *, vuint16mf4_t, vint8mf8_t, vint8mf8_t, vint8mf8_t, vint8mf8_t, vint8mf8_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vsoxseg5ei16_v_m)))
void vsoxseg5ei16(vbool64_t, int8_t *, vuint16mf4_t, vint8mf8_t, vint8mf8_t, vint8mf8_t, vint8mf8_t, vint8mf8_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vsoxseg5ei16_v)))
void vsoxseg5ei16(uint8_t *, vuint16m2_t, vuint8m1_t, vuint8m1_t, vuint8m1_t, vuint8m1_t, vuint8m1_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vsoxseg5ei16_v_m)))
void vsoxseg5ei16(vbool8_t, uint8_t *, vuint16m2_t, vuint8m1_t, vuint8m1_t, vuint8m1_t, vuint8m1_t, vuint8m1_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vsoxseg5ei16_v)))
void vsoxseg5ei16(uint8_t *, vuint16m1_t, vuint8mf2_t, vuint8mf2_t, vuint8mf2_t, vuint8mf2_t, vuint8mf2_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vsoxseg5ei16_v_m)))
void vsoxseg5ei16(vbool16_t, uint8_t *, vuint16m1_t, vuint8mf2_t, vuint8mf2_t, vuint8mf2_t, vuint8mf2_t, vuint8mf2_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vsoxseg5ei16_v)))
void vsoxseg5ei16(uint8_t *, vuint16mf2_t, vuint8mf4_t, vuint8mf4_t, vuint8mf4_t, vuint8mf4_t, vuint8mf4_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vsoxseg5ei16_v_m)))
void vsoxseg5ei16(vbool32_t, uint8_t *, vuint16mf2_t, vuint8mf4_t, vuint8mf4_t, vuint8mf4_t, vuint8mf4_t, vuint8mf4_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vsoxseg5ei16_v)))
void vsoxseg5ei16(uint8_t *, vuint16mf4_t, vuint8mf8_t, vuint8mf8_t, vuint8mf8_t, vuint8mf8_t, vuint8mf8_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vsoxseg5ei16_v_m)))
void vsoxseg5ei16(vbool64_t, uint8_t *, vuint16mf4_t, vuint8mf8_t, vuint8mf8_t, vuint8mf8_t, vuint8mf8_t, vuint8mf8_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vsoxseg6ei16_v)))
void vsoxseg6ei16(int8_t *, vuint16m2_t, vint8m1_t, vint8m1_t, vint8m1_t, vint8m1_t, vint8m1_t, vint8m1_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vsoxseg6ei16_v_m)))
void vsoxseg6ei16(vbool8_t, int8_t *, vuint16m2_t, vint8m1_t, vint8m1_t, vint8m1_t, vint8m1_t, vint8m1_t, vint8m1_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vsoxseg6ei16_v)))
void vsoxseg6ei16(int8_t *, vuint16m1_t, vint8mf2_t, vint8mf2_t, vint8mf2_t, vint8mf2_t, vint8mf2_t, vint8mf2_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vsoxseg6ei16_v_m)))
void vsoxseg6ei16(vbool16_t, int8_t *, vuint16m1_t, vint8mf2_t, vint8mf2_t, vint8mf2_t, vint8mf2_t, vint8mf2_t, vint8mf2_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vsoxseg6ei16_v)))
void vsoxseg6ei16(int8_t *, vuint16mf2_t, vint8mf4_t, vint8mf4_t, vint8mf4_t, vint8mf4_t, vint8mf4_t, vint8mf4_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vsoxseg6ei16_v_m)))
void vsoxseg6ei16(vbool32_t, int8_t *, vuint16mf2_t, vint8mf4_t, vint8mf4_t, vint8mf4_t, vint8mf4_t, vint8mf4_t, vint8mf4_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vsoxseg6ei16_v)))
void vsoxseg6ei16(int8_t *, vuint16mf4_t, vint8mf8_t, vint8mf8_t, vint8mf8_t, vint8mf8_t, vint8mf8_t, vint8mf8_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vsoxseg6ei16_v_m)))
void vsoxseg6ei16(vbool64_t, int8_t *, vuint16mf4_t, vint8mf8_t, vint8mf8_t, vint8mf8_t, vint8mf8_t, vint8mf8_t, vint8mf8_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vsoxseg6ei16_v)))
void vsoxseg6ei16(uint8_t *, vuint16m2_t, vuint8m1_t, vuint8m1_t, vuint8m1_t, vuint8m1_t, vuint8m1_t, vuint8m1_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vsoxseg6ei16_v_m)))
void vsoxseg6ei16(vbool8_t, uint8_t *, vuint16m2_t, vuint8m1_t, vuint8m1_t, vuint8m1_t, vuint8m1_t, vuint8m1_t, vuint8m1_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vsoxseg6ei16_v)))
void vsoxseg6ei16(uint8_t *, vuint16m1_t, vuint8mf2_t, vuint8mf2_t, vuint8mf2_t, vuint8mf2_t, vuint8mf2_t, vuint8mf2_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vsoxseg6ei16_v_m)))
void vsoxseg6ei16(vbool16_t, uint8_t *, vuint16m1_t, vuint8mf2_t, vuint8mf2_t, vuint8mf2_t, vuint8mf2_t, vuint8mf2_t, vuint8mf2_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vsoxseg6ei16_v)))
void vsoxseg6ei16(uint8_t *, vuint16mf2_t, vuint8mf4_t, vuint8mf4_t, vuint8mf4_t, vuint8mf4_t, vuint8mf4_t, vuint8mf4_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vsoxseg6ei16_v_m)))
void vsoxseg6ei16(vbool32_t, uint8_t *, vuint16mf2_t, vuint8mf4_t, vuint8mf4_t, vuint8mf4_t, vuint8mf4_t, vuint8mf4_t, vuint8mf4_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vsoxseg6ei16_v)))
void vsoxseg6ei16(uint8_t *, vuint16mf4_t, vuint8mf8_t, vuint8mf8_t, vuint8mf8_t, vuint8mf8_t, vuint8mf8_t, vuint8mf8_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vsoxseg6ei16_v_m)))
void vsoxseg6ei16(vbool64_t, uint8_t *, vuint16mf4_t, vuint8mf8_t, vuint8mf8_t, vuint8mf8_t, vuint8mf8_t, vuint8mf8_t, vuint8mf8_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vsoxseg7ei16_v)))
void vsoxseg7ei16(int8_t *, vuint16m2_t, vint8m1_t, vint8m1_t, vint8m1_t, vint8m1_t, vint8m1_t, vint8m1_t, vint8m1_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vsoxseg7ei16_v_m)))
void vsoxseg7ei16(vbool8_t, int8_t *, vuint16m2_t, vint8m1_t, vint8m1_t, vint8m1_t, vint8m1_t, vint8m1_t, vint8m1_t, vint8m1_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vsoxseg7ei16_v)))
void vsoxseg7ei16(int8_t *, vuint16m1_t, vint8mf2_t, vint8mf2_t, vint8mf2_t, vint8mf2_t, vint8mf2_t, vint8mf2_t, vint8mf2_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vsoxseg7ei16_v_m)))
void vsoxseg7ei16(vbool16_t, int8_t *, vuint16m1_t, vint8mf2_t, vint8mf2_t, vint8mf2_t, vint8mf2_t, vint8mf2_t, vint8mf2_t, vint8mf2_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vsoxseg7ei16_v)))
void vsoxseg7ei16(int8_t *, vuint16mf2_t, vint8mf4_t, vint8mf4_t, vint8mf4_t, vint8mf4_t, vint8mf4_t, vint8mf4_t, vint8mf4_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vsoxseg7ei16_v_m)))
void vsoxseg7ei16(vbool32_t, int8_t *, vuint16mf2_t, vint8mf4_t, vint8mf4_t, vint8mf4_t, vint8mf4_t, vint8mf4_t, vint8mf4_t, vint8mf4_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vsoxseg7ei16_v)))
void vsoxseg7ei16(int8_t *, vuint16mf4_t, vint8mf8_t, vint8mf8_t, vint8mf8_t, vint8mf8_t, vint8mf8_t, vint8mf8_t, vint8mf8_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vsoxseg7ei16_v_m)))
void vsoxseg7ei16(vbool64_t, int8_t *, vuint16mf4_t, vint8mf8_t, vint8mf8_t, vint8mf8_t, vint8mf8_t, vint8mf8_t, vint8mf8_t, vint8mf8_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vsoxseg7ei16_v)))
void vsoxseg7ei16(uint8_t *, vuint16m2_t, vuint8m1_t, vuint8m1_t, vuint8m1_t, vuint8m1_t, vuint8m1_t, vuint8m1_t, vuint8m1_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vsoxseg7ei16_v_m)))
void vsoxseg7ei16(vbool8_t, uint8_t *, vuint16m2_t, vuint8m1_t, vuint8m1_t, vuint8m1_t, vuint8m1_t, vuint8m1_t, vuint8m1_t, vuint8m1_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vsoxseg7ei16_v)))
void vsoxseg7ei16(uint8_t *, vuint16m1_t, vuint8mf2_t, vuint8mf2_t, vuint8mf2_t, vuint8mf2_t, vuint8mf2_t, vuint8mf2_t, vuint8mf2_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vsoxseg7ei16_v_m)))
void vsoxseg7ei16(vbool16_t, uint8_t *, vuint16m1_t, vuint8mf2_t, vuint8mf2_t, vuint8mf2_t, vuint8mf2_t, vuint8mf2_t, vuint8mf2_t, vuint8mf2_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vsoxseg7ei16_v)))
void vsoxseg7ei16(uint8_t *, vuint16mf2_t, vuint8mf4_t, vuint8mf4_t, vuint8mf4_t, vuint8mf4_t, vuint8mf4_t, vuint8mf4_t, vuint8mf4_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vsoxseg7ei16_v_m)))
void vsoxseg7ei16(vbool32_t, uint8_t *, vuint16mf2_t, vuint8mf4_t, vuint8mf4_t, vuint8mf4_t, vuint8mf4_t, vuint8mf4_t, vuint8mf4_t, vuint8mf4_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vsoxseg7ei16_v)))
void vsoxseg7ei16(uint8_t *, vuint16mf4_t, vuint8mf8_t, vuint8mf8_t, vuint8mf8_t, vuint8mf8_t, vuint8mf8_t, vuint8mf8_t, vuint8mf8_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vsoxseg7ei16_v_m)))
void vsoxseg7ei16(vbool64_t, uint8_t *, vuint16mf4_t, vuint8mf8_t, vuint8mf8_t, vuint8mf8_t, vuint8mf8_t, vuint8mf8_t, vuint8mf8_t, vuint8mf8_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vsoxseg8ei16_v)))
void vsoxseg8ei16(int8_t *, vuint16m2_t, vint8m1_t, vint8m1_t, vint8m1_t, vint8m1_t, vint8m1_t, vint8m1_t, vint8m1_t, vint8m1_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vsoxseg8ei16_v_m)))
void vsoxseg8ei16(vbool8_t, int8_t *, vuint16m2_t, vint8m1_t, vint8m1_t, vint8m1_t, vint8m1_t, vint8m1_t, vint8m1_t, vint8m1_t, vint8m1_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vsoxseg8ei16_v)))
void vsoxseg8ei16(int8_t *, vuint16m1_t, vint8mf2_t, vint8mf2_t, vint8mf2_t, vint8mf2_t, vint8mf2_t, vint8mf2_t, vint8mf2_t, vint8mf2_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vsoxseg8ei16_v_m)))
void vsoxseg8ei16(vbool16_t, int8_t *, vuint16m1_t, vint8mf2_t, vint8mf2_t, vint8mf2_t, vint8mf2_t, vint8mf2_t, vint8mf2_t, vint8mf2_t, vint8mf2_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vsoxseg8ei16_v)))
void vsoxseg8ei16(int8_t *, vuint16mf2_t, vint8mf4_t, vint8mf4_t, vint8mf4_t, vint8mf4_t, vint8mf4_t, vint8mf4_t, vint8mf4_t, vint8mf4_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vsoxseg8ei16_v_m)))
void vsoxseg8ei16(vbool32_t, int8_t *, vuint16mf2_t, vint8mf4_t, vint8mf4_t, vint8mf4_t, vint8mf4_t, vint8mf4_t, vint8mf4_t, vint8mf4_t, vint8mf4_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vsoxseg8ei16_v)))
void vsoxseg8ei16(int8_t *, vuint16mf4_t, vint8mf8_t, vint8mf8_t, vint8mf8_t, vint8mf8_t, vint8mf8_t, vint8mf8_t, vint8mf8_t, vint8mf8_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vsoxseg8ei16_v_m)))
void vsoxseg8ei16(vbool64_t, int8_t *, vuint16mf4_t, vint8mf8_t, vint8mf8_t, vint8mf8_t, vint8mf8_t, vint8mf8_t, vint8mf8_t, vint8mf8_t, vint8mf8_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vsoxseg8ei16_v)))
void vsoxseg8ei16(uint8_t *, vuint16m2_t, vuint8m1_t, vuint8m1_t, vuint8m1_t, vuint8m1_t, vuint8m1_t, vuint8m1_t, vuint8m1_t, vuint8m1_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vsoxseg8ei16_v_m)))
void vsoxseg8ei16(vbool8_t, uint8_t *, vuint16m2_t, vuint8m1_t, vuint8m1_t, vuint8m1_t, vuint8m1_t, vuint8m1_t, vuint8m1_t, vuint8m1_t, vuint8m1_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vsoxseg8ei16_v)))
void vsoxseg8ei16(uint8_t *, vuint16m1_t, vuint8mf2_t, vuint8mf2_t, vuint8mf2_t, vuint8mf2_t, vuint8mf2_t, vuint8mf2_t, vuint8mf2_t, vuint8mf2_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vsoxseg8ei16_v_m)))
void vsoxseg8ei16(vbool16_t, uint8_t *, vuint16m1_t, vuint8mf2_t, vuint8mf2_t, vuint8mf2_t, vuint8mf2_t, vuint8mf2_t, vuint8mf2_t, vuint8mf2_t, vuint8mf2_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vsoxseg8ei16_v)))
void vsoxseg8ei16(uint8_t *, vuint16mf2_t, vuint8mf4_t, vuint8mf4_t, vuint8mf4_t, vuint8mf4_t, vuint8mf4_t, vuint8mf4_t, vuint8mf4_t, vuint8mf4_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vsoxseg8ei16_v_m)))
void vsoxseg8ei16(vbool32_t, uint8_t *, vuint16mf2_t, vuint8mf4_t, vuint8mf4_t, vuint8mf4_t, vuint8mf4_t, vuint8mf4_t, vuint8mf4_t, vuint8mf4_t, vuint8mf4_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vsoxseg8ei16_v)))
void vsoxseg8ei16(uint8_t *, vuint16mf4_t, vuint8mf8_t, vuint8mf8_t, vuint8mf8_t, vuint8mf8_t, vuint8mf8_t, vuint8mf8_t, vuint8mf8_t, vuint8mf8_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vsoxseg8ei16_v_m)))
void vsoxseg8ei16(vbool64_t, uint8_t *, vuint16mf4_t, vuint8mf8_t, vuint8mf8_t, vuint8mf8_t, vuint8mf8_t, vuint8mf8_t, vuint8mf8_t, vuint8mf8_t, vuint8mf8_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vsoxseg2ei32_v)))
void vsoxseg2ei32(int8_t *, vuint32m4_t, vint8m1_t, vint8m1_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vsoxseg2ei32_v_m)))
void vsoxseg2ei32(vbool8_t, int8_t *, vuint32m4_t, vint8m1_t, vint8m1_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vsoxseg2ei32_v)))
void vsoxseg2ei32(int8_t *, vuint32m8_t, vint8m2_t, vint8m2_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vsoxseg2ei32_v_m)))
void vsoxseg2ei32(vbool4_t, int8_t *, vuint32m8_t, vint8m2_t, vint8m2_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vsoxseg2ei32_v)))
void vsoxseg2ei32(int8_t *, vuint32m2_t, vint8mf2_t, vint8mf2_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vsoxseg2ei32_v_m)))
void vsoxseg2ei32(vbool16_t, int8_t *, vuint32m2_t, vint8mf2_t, vint8mf2_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vsoxseg2ei32_v)))
void vsoxseg2ei32(int8_t *, vuint32m1_t, vint8mf4_t, vint8mf4_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vsoxseg2ei32_v_m)))
void vsoxseg2ei32(vbool32_t, int8_t *, vuint32m1_t, vint8mf4_t, vint8mf4_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vsoxseg2ei32_v)))
void vsoxseg2ei32(int8_t *, vuint32mf2_t, vint8mf8_t, vint8mf8_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vsoxseg2ei32_v_m)))
void vsoxseg2ei32(vbool64_t, int8_t *, vuint32mf2_t, vint8mf8_t, vint8mf8_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vsoxseg2ei32_v)))
void vsoxseg2ei32(uint8_t *, vuint32m4_t, vuint8m1_t, vuint8m1_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vsoxseg2ei32_v_m)))
void vsoxseg2ei32(vbool8_t, uint8_t *, vuint32m4_t, vuint8m1_t, vuint8m1_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vsoxseg2ei32_v)))
void vsoxseg2ei32(uint8_t *, vuint32m8_t, vuint8m2_t, vuint8m2_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vsoxseg2ei32_v_m)))
void vsoxseg2ei32(vbool4_t, uint8_t *, vuint32m8_t, vuint8m2_t, vuint8m2_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vsoxseg2ei32_v)))
void vsoxseg2ei32(uint8_t *, vuint32m2_t, vuint8mf2_t, vuint8mf2_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vsoxseg2ei32_v_m)))
void vsoxseg2ei32(vbool16_t, uint8_t *, vuint32m2_t, vuint8mf2_t, vuint8mf2_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vsoxseg2ei32_v)))
void vsoxseg2ei32(uint8_t *, vuint32m1_t, vuint8mf4_t, vuint8mf4_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vsoxseg2ei32_v_m)))
void vsoxseg2ei32(vbool32_t, uint8_t *, vuint32m1_t, vuint8mf4_t, vuint8mf4_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vsoxseg2ei32_v)))
void vsoxseg2ei32(uint8_t *, vuint32mf2_t, vuint8mf8_t, vuint8mf8_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vsoxseg2ei32_v_m)))
void vsoxseg2ei32(vbool64_t, uint8_t *, vuint32mf2_t, vuint8mf8_t, vuint8mf8_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vsoxseg3ei32_v)))
void vsoxseg3ei32(int8_t *, vuint32m4_t, vint8m1_t, vint8m1_t, vint8m1_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vsoxseg3ei32_v_m)))
void vsoxseg3ei32(vbool8_t, int8_t *, vuint32m4_t, vint8m1_t, vint8m1_t, vint8m1_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vsoxseg3ei32_v)))
void vsoxseg3ei32(int8_t *, vuint32m8_t, vint8m2_t, vint8m2_t, vint8m2_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vsoxseg3ei32_v_m)))
void vsoxseg3ei32(vbool4_t, int8_t *, vuint32m8_t, vint8m2_t, vint8m2_t, vint8m2_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vsoxseg3ei32_v)))
void vsoxseg3ei32(int8_t *, vuint32m2_t, vint8mf2_t, vint8mf2_t, vint8mf2_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vsoxseg3ei32_v_m)))
void vsoxseg3ei32(vbool16_t, int8_t *, vuint32m2_t, vint8mf2_t, vint8mf2_t, vint8mf2_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vsoxseg3ei32_v)))
void vsoxseg3ei32(int8_t *, vuint32m1_t, vint8mf4_t, vint8mf4_t, vint8mf4_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vsoxseg3ei32_v_m)))
void vsoxseg3ei32(vbool32_t, int8_t *, vuint32m1_t, vint8mf4_t, vint8mf4_t, vint8mf4_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vsoxseg3ei32_v)))
void vsoxseg3ei32(int8_t *, vuint32mf2_t, vint8mf8_t, vint8mf8_t, vint8mf8_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vsoxseg3ei32_v_m)))
void vsoxseg3ei32(vbool64_t, int8_t *, vuint32mf2_t, vint8mf8_t, vint8mf8_t, vint8mf8_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vsoxseg3ei32_v)))
void vsoxseg3ei32(uint8_t *, vuint32m4_t, vuint8m1_t, vuint8m1_t, vuint8m1_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vsoxseg3ei32_v_m)))
void vsoxseg3ei32(vbool8_t, uint8_t *, vuint32m4_t, vuint8m1_t, vuint8m1_t, vuint8m1_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vsoxseg3ei32_v)))
void vsoxseg3ei32(uint8_t *, vuint32m8_t, vuint8m2_t, vuint8m2_t, vuint8m2_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vsoxseg3ei32_v_m)))
void vsoxseg3ei32(vbool4_t, uint8_t *, vuint32m8_t, vuint8m2_t, vuint8m2_t, vuint8m2_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vsoxseg3ei32_v)))
void vsoxseg3ei32(uint8_t *, vuint32m2_t, vuint8mf2_t, vuint8mf2_t, vuint8mf2_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vsoxseg3ei32_v_m)))
void vsoxseg3ei32(vbool16_t, uint8_t *, vuint32m2_t, vuint8mf2_t, vuint8mf2_t, vuint8mf2_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vsoxseg3ei32_v)))
void vsoxseg3ei32(uint8_t *, vuint32m1_t, vuint8mf4_t, vuint8mf4_t, vuint8mf4_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vsoxseg3ei32_v_m)))
void vsoxseg3ei32(vbool32_t, uint8_t *, vuint32m1_t, vuint8mf4_t, vuint8mf4_t, vuint8mf4_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vsoxseg3ei32_v)))
void vsoxseg3ei32(uint8_t *, vuint32mf2_t, vuint8mf8_t, vuint8mf8_t, vuint8mf8_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vsoxseg3ei32_v_m)))
void vsoxseg3ei32(vbool64_t, uint8_t *, vuint32mf2_t, vuint8mf8_t, vuint8mf8_t, vuint8mf8_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vloxei8_v)))
vint16m1_t vloxei8(const int16_t *, vuint8mf2_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vloxei8_v_m)))
vint16m1_t vloxei8(vbool16_t, vint16m1_t, const int16_t *, vuint8mf2_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vloxei8_v)))
vint16m2_t vloxei8(const int16_t *, vuint8m1_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vloxei8_v_m)))
vint16m2_t vloxei8(vbool8_t, vint16m2_t, const int16_t *, vuint8m1_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vloxei8_v)))
vint16m4_t vloxei8(const int16_t *, vuint8m2_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vloxei8_v_m)))
vint16m4_t vloxei8(vbool4_t, vint16m4_t, const int16_t *, vuint8m2_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vloxei8_v)))
vint16m8_t vloxei8(const int16_t *, vuint8m4_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vloxei8_v_m)))
vint16m8_t vloxei8(vbool2_t, vint16m8_t, const int16_t *, vuint8m4_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vloxei8_v)))
vint16mf2_t vloxei8(const int16_t *, vuint8mf4_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vloxei8_v_m)))
vint16mf2_t vloxei8(vbool32_t, vint16mf2_t, const int16_t *, vuint8mf4_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vloxei8_v)))
vint16mf4_t vloxei8(const int16_t *, vuint8mf8_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vloxei8_v_m)))
vint16mf4_t vloxei8(vbool64_t, vint16mf4_t, const int16_t *, vuint8mf8_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vsoxseg4ei32_v)))
void vsoxseg4ei32(int8_t *, vuint32m4_t, vint8m1_t, vint8m1_t, vint8m1_t, vint8m1_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vsoxseg4ei32_v_m)))
void vsoxseg4ei32(vbool8_t, int8_t *, vuint32m4_t, vint8m1_t, vint8m1_t, vint8m1_t, vint8m1_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vsoxseg4ei32_v)))
void vsoxseg4ei32(int8_t *, vuint32m8_t, vint8m2_t, vint8m2_t, vint8m2_t, vint8m2_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vsoxseg4ei32_v_m)))
void vsoxseg4ei32(vbool4_t, int8_t *, vuint32m8_t, vint8m2_t, vint8m2_t, vint8m2_t, vint8m2_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vsoxseg4ei32_v)))
void vsoxseg4ei32(int8_t *, vuint32m2_t, vint8mf2_t, vint8mf2_t, vint8mf2_t, vint8mf2_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vsoxseg4ei32_v_m)))
void vsoxseg4ei32(vbool16_t, int8_t *, vuint32m2_t, vint8mf2_t, vint8mf2_t, vint8mf2_t, vint8mf2_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vsoxseg4ei32_v)))
void vsoxseg4ei32(int8_t *, vuint32m1_t, vint8mf4_t, vint8mf4_t, vint8mf4_t, vint8mf4_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vsoxseg4ei32_v_m)))
void vsoxseg4ei32(vbool32_t, int8_t *, vuint32m1_t, vint8mf4_t, vint8mf4_t, vint8mf4_t, vint8mf4_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vsoxseg4ei32_v)))
void vsoxseg4ei32(int8_t *, vuint32mf2_t, vint8mf8_t, vint8mf8_t, vint8mf8_t, vint8mf8_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vsoxseg4ei32_v_m)))
void vsoxseg4ei32(vbool64_t, int8_t *, vuint32mf2_t, vint8mf8_t, vint8mf8_t, vint8mf8_t, vint8mf8_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vsoxseg4ei32_v)))
void vsoxseg4ei32(uint8_t *, vuint32m4_t, vuint8m1_t, vuint8m1_t, vuint8m1_t, vuint8m1_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vsoxseg4ei32_v_m)))
void vsoxseg4ei32(vbool8_t, uint8_t *, vuint32m4_t, vuint8m1_t, vuint8m1_t, vuint8m1_t, vuint8m1_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vsoxseg4ei32_v)))
void vsoxseg4ei32(uint8_t *, vuint32m8_t, vuint8m2_t, vuint8m2_t, vuint8m2_t, vuint8m2_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vsoxseg4ei32_v_m)))
void vsoxseg4ei32(vbool4_t, uint8_t *, vuint32m8_t, vuint8m2_t, vuint8m2_t, vuint8m2_t, vuint8m2_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vsoxseg4ei32_v)))
void vsoxseg4ei32(uint8_t *, vuint32m2_t, vuint8mf2_t, vuint8mf2_t, vuint8mf2_t, vuint8mf2_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vsoxseg4ei32_v_m)))
void vsoxseg4ei32(vbool16_t, uint8_t *, vuint32m2_t, vuint8mf2_t, vuint8mf2_t, vuint8mf2_t, vuint8mf2_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vsoxseg4ei32_v)))
void vsoxseg4ei32(uint8_t *, vuint32m1_t, vuint8mf4_t, vuint8mf4_t, vuint8mf4_t, vuint8mf4_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vsoxseg4ei32_v_m)))
void vsoxseg4ei32(vbool32_t, uint8_t *, vuint32m1_t, vuint8mf4_t, vuint8mf4_t, vuint8mf4_t, vuint8mf4_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vsoxseg4ei32_v)))
void vsoxseg4ei32(uint8_t *, vuint32mf2_t, vuint8mf8_t, vuint8mf8_t, vuint8mf8_t, vuint8mf8_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vsoxseg4ei32_v_m)))
void vsoxseg4ei32(vbool64_t, uint8_t *, vuint32mf2_t, vuint8mf8_t, vuint8mf8_t, vuint8mf8_t, vuint8mf8_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vsoxseg5ei32_v)))
void vsoxseg5ei32(int8_t *, vuint32m4_t, vint8m1_t, vint8m1_t, vint8m1_t, vint8m1_t, vint8m1_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vsoxseg5ei32_v_m)))
void vsoxseg5ei32(vbool8_t, int8_t *, vuint32m4_t, vint8m1_t, vint8m1_t, vint8m1_t, vint8m1_t, vint8m1_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vsoxseg5ei32_v)))
void vsoxseg5ei32(int8_t *, vuint32m2_t, vint8mf2_t, vint8mf2_t, vint8mf2_t, vint8mf2_t, vint8mf2_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vsoxseg5ei32_v_m)))
void vsoxseg5ei32(vbool16_t, int8_t *, vuint32m2_t, vint8mf2_t, vint8mf2_t, vint8mf2_t, vint8mf2_t, vint8mf2_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vsoxseg5ei32_v)))
void vsoxseg5ei32(int8_t *, vuint32m1_t, vint8mf4_t, vint8mf4_t, vint8mf4_t, vint8mf4_t, vint8mf4_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vsoxseg5ei32_v_m)))
void vsoxseg5ei32(vbool32_t, int8_t *, vuint32m1_t, vint8mf4_t, vint8mf4_t, vint8mf4_t, vint8mf4_t, vint8mf4_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vsoxseg5ei32_v)))
void vsoxseg5ei32(int8_t *, vuint32mf2_t, vint8mf8_t, vint8mf8_t, vint8mf8_t, vint8mf8_t, vint8mf8_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vsoxseg5ei32_v_m)))
void vsoxseg5ei32(vbool64_t, int8_t *, vuint32mf2_t, vint8mf8_t, vint8mf8_t, vint8mf8_t, vint8mf8_t, vint8mf8_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vsoxseg5ei32_v)))
void vsoxseg5ei32(uint8_t *, vuint32m4_t, vuint8m1_t, vuint8m1_t, vuint8m1_t, vuint8m1_t, vuint8m1_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vsoxseg5ei32_v_m)))
void vsoxseg5ei32(vbool8_t, uint8_t *, vuint32m4_t, vuint8m1_t, vuint8m1_t, vuint8m1_t, vuint8m1_t, vuint8m1_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vsoxseg5ei32_v)))
void vsoxseg5ei32(uint8_t *, vuint32m2_t, vuint8mf2_t, vuint8mf2_t, vuint8mf2_t, vuint8mf2_t, vuint8mf2_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vsoxseg5ei32_v_m)))
void vsoxseg5ei32(vbool16_t, uint8_t *, vuint32m2_t, vuint8mf2_t, vuint8mf2_t, vuint8mf2_t, vuint8mf2_t, vuint8mf2_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vsoxseg5ei32_v)))
void vsoxseg5ei32(uint8_t *, vuint32m1_t, vuint8mf4_t, vuint8mf4_t, vuint8mf4_t, vuint8mf4_t, vuint8mf4_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vsoxseg5ei32_v_m)))
void vsoxseg5ei32(vbool32_t, uint8_t *, vuint32m1_t, vuint8mf4_t, vuint8mf4_t, vuint8mf4_t, vuint8mf4_t, vuint8mf4_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vsoxseg5ei32_v)))
void vsoxseg5ei32(uint8_t *, vuint32mf2_t, vuint8mf8_t, vuint8mf8_t, vuint8mf8_t, vuint8mf8_t, vuint8mf8_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vsoxseg5ei32_v_m)))
void vsoxseg5ei32(vbool64_t, uint8_t *, vuint32mf2_t, vuint8mf8_t, vuint8mf8_t, vuint8mf8_t, vuint8mf8_t, vuint8mf8_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vsoxseg6ei32_v)))
void vsoxseg6ei32(int8_t *, vuint32m4_t, vint8m1_t, vint8m1_t, vint8m1_t, vint8m1_t, vint8m1_t, vint8m1_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vsoxseg6ei32_v_m)))
void vsoxseg6ei32(vbool8_t, int8_t *, vuint32m4_t, vint8m1_t, vint8m1_t, vint8m1_t, vint8m1_t, vint8m1_t, vint8m1_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vsoxseg6ei32_v)))
void vsoxseg6ei32(int8_t *, vuint32m2_t, vint8mf2_t, vint8mf2_t, vint8mf2_t, vint8mf2_t, vint8mf2_t, vint8mf2_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vsoxseg6ei32_v_m)))
void vsoxseg6ei32(vbool16_t, int8_t *, vuint32m2_t, vint8mf2_t, vint8mf2_t, vint8mf2_t, vint8mf2_t, vint8mf2_t, vint8mf2_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vsoxseg6ei32_v)))
void vsoxseg6ei32(int8_t *, vuint32m1_t, vint8mf4_t, vint8mf4_t, vint8mf4_t, vint8mf4_t, vint8mf4_t, vint8mf4_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vsoxseg6ei32_v_m)))
void vsoxseg6ei32(vbool32_t, int8_t *, vuint32m1_t, vint8mf4_t, vint8mf4_t, vint8mf4_t, vint8mf4_t, vint8mf4_t, vint8mf4_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vsoxseg6ei32_v)))
void vsoxseg6ei32(int8_t *, vuint32mf2_t, vint8mf8_t, vint8mf8_t, vint8mf8_t, vint8mf8_t, vint8mf8_t, vint8mf8_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vsoxseg6ei32_v_m)))
void vsoxseg6ei32(vbool64_t, int8_t *, vuint32mf2_t, vint8mf8_t, vint8mf8_t, vint8mf8_t, vint8mf8_t, vint8mf8_t, vint8mf8_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vsoxseg6ei32_v)))
void vsoxseg6ei32(uint8_t *, vuint32m4_t, vuint8m1_t, vuint8m1_t, vuint8m1_t, vuint8m1_t, vuint8m1_t, vuint8m1_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vsoxseg6ei32_v_m)))
void vsoxseg6ei32(vbool8_t, uint8_t *, vuint32m4_t, vuint8m1_t, vuint8m1_t, vuint8m1_t, vuint8m1_t, vuint8m1_t, vuint8m1_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vsoxseg6ei32_v)))
void vsoxseg6ei32(uint8_t *, vuint32m2_t, vuint8mf2_t, vuint8mf2_t, vuint8mf2_t, vuint8mf2_t, vuint8mf2_t, vuint8mf2_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vsoxseg6ei32_v_m)))
void vsoxseg6ei32(vbool16_t, uint8_t *, vuint32m2_t, vuint8mf2_t, vuint8mf2_t, vuint8mf2_t, vuint8mf2_t, vuint8mf2_t, vuint8mf2_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vsoxseg6ei32_v)))
void vsoxseg6ei32(uint8_t *, vuint32m1_t, vuint8mf4_t, vuint8mf4_t, vuint8mf4_t, vuint8mf4_t, vuint8mf4_t, vuint8mf4_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vsoxseg6ei32_v_m)))
void vsoxseg6ei32(vbool32_t, uint8_t *, vuint32m1_t, vuint8mf4_t, vuint8mf4_t, vuint8mf4_t, vuint8mf4_t, vuint8mf4_t, vuint8mf4_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vsoxseg6ei32_v)))
void vsoxseg6ei32(uint8_t *, vuint32mf2_t, vuint8mf8_t, vuint8mf8_t, vuint8mf8_t, vuint8mf8_t, vuint8mf8_t, vuint8mf8_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vsoxseg6ei32_v_m)))
void vsoxseg6ei32(vbool64_t, uint8_t *, vuint32mf2_t, vuint8mf8_t, vuint8mf8_t, vuint8mf8_t, vuint8mf8_t, vuint8mf8_t, vuint8mf8_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vsoxseg7ei32_v)))
void vsoxseg7ei32(int8_t *, vuint32m4_t, vint8m1_t, vint8m1_t, vint8m1_t, vint8m1_t, vint8m1_t, vint8m1_t, vint8m1_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vsoxseg7ei32_v_m)))
void vsoxseg7ei32(vbool8_t, int8_t *, vuint32m4_t, vint8m1_t, vint8m1_t, vint8m1_t, vint8m1_t, vint8m1_t, vint8m1_t, vint8m1_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vsoxseg7ei32_v)))
void vsoxseg7ei32(int8_t *, vuint32m2_t, vint8mf2_t, vint8mf2_t, vint8mf2_t, vint8mf2_t, vint8mf2_t, vint8mf2_t, vint8mf2_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vsoxseg7ei32_v_m)))
void vsoxseg7ei32(vbool16_t, int8_t *, vuint32m2_t, vint8mf2_t, vint8mf2_t, vint8mf2_t, vint8mf2_t, vint8mf2_t, vint8mf2_t, vint8mf2_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vsoxseg7ei32_v)))
void vsoxseg7ei32(int8_t *, vuint32m1_t, vint8mf4_t, vint8mf4_t, vint8mf4_t, vint8mf4_t, vint8mf4_t, vint8mf4_t, vint8mf4_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vsoxseg7ei32_v_m)))
void vsoxseg7ei32(vbool32_t, int8_t *, vuint32m1_t, vint8mf4_t, vint8mf4_t, vint8mf4_t, vint8mf4_t, vint8mf4_t, vint8mf4_t, vint8mf4_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vsoxseg7ei32_v)))
void vsoxseg7ei32(int8_t *, vuint32mf2_t, vint8mf8_t, vint8mf8_t, vint8mf8_t, vint8mf8_t, vint8mf8_t, vint8mf8_t, vint8mf8_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vsoxseg7ei32_v_m)))
void vsoxseg7ei32(vbool64_t, int8_t *, vuint32mf2_t, vint8mf8_t, vint8mf8_t, vint8mf8_t, vint8mf8_t, vint8mf8_t, vint8mf8_t, vint8mf8_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vsoxseg7ei32_v)))
void vsoxseg7ei32(uint8_t *, vuint32m4_t, vuint8m1_t, vuint8m1_t, vuint8m1_t, vuint8m1_t, vuint8m1_t, vuint8m1_t, vuint8m1_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vsoxseg7ei32_v_m)))
void vsoxseg7ei32(vbool8_t, uint8_t *, vuint32m4_t, vuint8m1_t, vuint8m1_t, vuint8m1_t, vuint8m1_t, vuint8m1_t, vuint8m1_t, vuint8m1_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vsoxseg7ei32_v)))
void vsoxseg7ei32(uint8_t *, vuint32m2_t, vuint8mf2_t, vuint8mf2_t, vuint8mf2_t, vuint8mf2_t, vuint8mf2_t, vuint8mf2_t, vuint8mf2_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vsoxseg7ei32_v_m)))
void vsoxseg7ei32(vbool16_t, uint8_t *, vuint32m2_t, vuint8mf2_t, vuint8mf2_t, vuint8mf2_t, vuint8mf2_t, vuint8mf2_t, vuint8mf2_t, vuint8mf2_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vsoxseg7ei32_v)))
void vsoxseg7ei32(uint8_t *, vuint32m1_t, vuint8mf4_t, vuint8mf4_t, vuint8mf4_t, vuint8mf4_t, vuint8mf4_t, vuint8mf4_t, vuint8mf4_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vsoxseg7ei32_v_m)))
void vsoxseg7ei32(vbool32_t, uint8_t *, vuint32m1_t, vuint8mf4_t, vuint8mf4_t, vuint8mf4_t, vuint8mf4_t, vuint8mf4_t, vuint8mf4_t, vuint8mf4_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vsoxseg7ei32_v)))
void vsoxseg7ei32(uint8_t *, vuint32mf2_t, vuint8mf8_t, vuint8mf8_t, vuint8mf8_t, vuint8mf8_t, vuint8mf8_t, vuint8mf8_t, vuint8mf8_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vsoxseg7ei32_v_m)))
void vsoxseg7ei32(vbool64_t, uint8_t *, vuint32mf2_t, vuint8mf8_t, vuint8mf8_t, vuint8mf8_t, vuint8mf8_t, vuint8mf8_t, vuint8mf8_t, vuint8mf8_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vsoxseg8ei32_v)))
void vsoxseg8ei32(int8_t *, vuint32m4_t, vint8m1_t, vint8m1_t, vint8m1_t, vint8m1_t, vint8m1_t, vint8m1_t, vint8m1_t, vint8m1_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vsoxseg8ei32_v_m)))
void vsoxseg8ei32(vbool8_t, int8_t *, vuint32m4_t, vint8m1_t, vint8m1_t, vint8m1_t, vint8m1_t, vint8m1_t, vint8m1_t, vint8m1_t, vint8m1_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vsoxseg8ei32_v)))
void vsoxseg8ei32(int8_t *, vuint32m2_t, vint8mf2_t, vint8mf2_t, vint8mf2_t, vint8mf2_t, vint8mf2_t, vint8mf2_t, vint8mf2_t, vint8mf2_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vsoxseg8ei32_v_m)))
void vsoxseg8ei32(vbool16_t, int8_t *, vuint32m2_t, vint8mf2_t, vint8mf2_t, vint8mf2_t, vint8mf2_t, vint8mf2_t, vint8mf2_t, vint8mf2_t, vint8mf2_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vsoxseg8ei32_v)))
void vsoxseg8ei32(int8_t *, vuint32m1_t, vint8mf4_t, vint8mf4_t, vint8mf4_t, vint8mf4_t, vint8mf4_t, vint8mf4_t, vint8mf4_t, vint8mf4_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vsoxseg8ei32_v_m)))
void vsoxseg8ei32(vbool32_t, int8_t *, vuint32m1_t, vint8mf4_t, vint8mf4_t, vint8mf4_t, vint8mf4_t, vint8mf4_t, vint8mf4_t, vint8mf4_t, vint8mf4_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vsoxseg8ei32_v)))
void vsoxseg8ei32(int8_t *, vuint32mf2_t, vint8mf8_t, vint8mf8_t, vint8mf8_t, vint8mf8_t, vint8mf8_t, vint8mf8_t, vint8mf8_t, vint8mf8_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vsoxseg8ei32_v_m)))
void vsoxseg8ei32(vbool64_t, int8_t *, vuint32mf2_t, vint8mf8_t, vint8mf8_t, vint8mf8_t, vint8mf8_t, vint8mf8_t, vint8mf8_t, vint8mf8_t, vint8mf8_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vsoxseg8ei32_v)))
void vsoxseg8ei32(uint8_t *, vuint32m4_t, vuint8m1_t, vuint8m1_t, vuint8m1_t, vuint8m1_t, vuint8m1_t, vuint8m1_t, vuint8m1_t, vuint8m1_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vsoxseg8ei32_v_m)))
void vsoxseg8ei32(vbool8_t, uint8_t *, vuint32m4_t, vuint8m1_t, vuint8m1_t, vuint8m1_t, vuint8m1_t, vuint8m1_t, vuint8m1_t, vuint8m1_t, vuint8m1_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vsoxseg8ei32_v)))
void vsoxseg8ei32(uint8_t *, vuint32m2_t, vuint8mf2_t, vuint8mf2_t, vuint8mf2_t, vuint8mf2_t, vuint8mf2_t, vuint8mf2_t, vuint8mf2_t, vuint8mf2_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vsoxseg8ei32_v_m)))
void vsoxseg8ei32(vbool16_t, uint8_t *, vuint32m2_t, vuint8mf2_t, vuint8mf2_t, vuint8mf2_t, vuint8mf2_t, vuint8mf2_t, vuint8mf2_t, vuint8mf2_t, vuint8mf2_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vsoxseg8ei32_v)))
void vsoxseg8ei32(uint8_t *, vuint32m1_t, vuint8mf4_t, vuint8mf4_t, vuint8mf4_t, vuint8mf4_t, vuint8mf4_t, vuint8mf4_t, vuint8mf4_t, vuint8mf4_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vsoxseg8ei32_v_m)))
void vsoxseg8ei32(vbool32_t, uint8_t *, vuint32m1_t, vuint8mf4_t, vuint8mf4_t, vuint8mf4_t, vuint8mf4_t, vuint8mf4_t, vuint8mf4_t, vuint8mf4_t, vuint8mf4_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vsoxseg8ei32_v)))
void vsoxseg8ei32(uint8_t *, vuint32mf2_t, vuint8mf8_t, vuint8mf8_t, vuint8mf8_t, vuint8mf8_t, vuint8mf8_t, vuint8mf8_t, vuint8mf8_t, vuint8mf8_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vsoxseg8ei32_v_m)))
void vsoxseg8ei32(vbool64_t, uint8_t *, vuint32mf2_t, vuint8mf8_t, vuint8mf8_t, vuint8mf8_t, vuint8mf8_t, vuint8mf8_t, vuint8mf8_t, vuint8mf8_t, vuint8mf8_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vloxei8_v)))
vuint16m1_t vloxei8(const uint16_t *, vuint8mf2_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vloxei8_v_m)))
vuint16m1_t vloxei8(vbool16_t, vuint16m1_t, const uint16_t *, vuint8mf2_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vloxei8_v)))
vuint16m2_t vloxei8(const uint16_t *, vuint8m1_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vloxei8_v_m)))
vuint16m2_t vloxei8(vbool8_t, vuint16m2_t, const uint16_t *, vuint8m1_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vloxei8_v)))
vuint16m4_t vloxei8(const uint16_t *, vuint8m2_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vloxei8_v_m)))
vuint16m4_t vloxei8(vbool4_t, vuint16m4_t, const uint16_t *, vuint8m2_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vloxei8_v)))
vuint16m8_t vloxei8(const uint16_t *, vuint8m4_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vloxei8_v_m)))
vuint16m8_t vloxei8(vbool2_t, vuint16m8_t, const uint16_t *, vuint8m4_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vloxei8_v)))
vuint16mf2_t vloxei8(const uint16_t *, vuint8mf4_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vloxei8_v_m)))
vuint16mf2_t vloxei8(vbool32_t, vuint16mf2_t, const uint16_t *, vuint8mf4_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vloxei8_v)))
vuint16mf4_t vloxei8(const uint16_t *, vuint8mf8_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vloxei8_v_m)))
vuint16mf4_t vloxei8(vbool64_t, vuint16mf4_t, const uint16_t *, vuint8mf8_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vloxei16_v)))
vint16m1_t vloxei16(const int16_t *, vuint16m1_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vloxei16_v_m)))
vint16m1_t vloxei16(vbool16_t, vint16m1_t, const int16_t *, vuint16m1_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vloxei16_v)))
vint16m2_t vloxei16(const int16_t *, vuint16m2_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vloxei16_v_m)))
vint16m2_t vloxei16(vbool8_t, vint16m2_t, const int16_t *, vuint16m2_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vloxei16_v)))
vint16m4_t vloxei16(const int16_t *, vuint16m4_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vloxei16_v_m)))
vint16m4_t vloxei16(vbool4_t, vint16m4_t, const int16_t *, vuint16m4_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vloxei16_v)))
vint16m8_t vloxei16(const int16_t *, vuint16m8_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vloxei16_v_m)))
vint16m8_t vloxei16(vbool2_t, vint16m8_t, const int16_t *, vuint16m8_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vloxei16_v)))
vint16mf2_t vloxei16(const int16_t *, vuint16mf2_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vloxei16_v_m)))
vint16mf2_t vloxei16(vbool32_t, vint16mf2_t, const int16_t *, vuint16mf2_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vloxei16_v)))
vint16mf4_t vloxei16(const int16_t *, vuint16mf4_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vloxei16_v_m)))
vint16mf4_t vloxei16(vbool64_t, vint16mf4_t, const int16_t *, vuint16mf4_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vsoxseg2ei8_v)))
void vsoxseg2ei8(int16_t *, vuint8mf2_t, vint16m1_t, vint16m1_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vsoxseg2ei8_v_m)))
void vsoxseg2ei8(vbool16_t, int16_t *, vuint8mf2_t, vint16m1_t, vint16m1_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vsoxseg2ei8_v)))
void vsoxseg2ei8(int16_t *, vuint8m1_t, vint16m2_t, vint16m2_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vsoxseg2ei8_v_m)))
void vsoxseg2ei8(vbool8_t, int16_t *, vuint8m1_t, vint16m2_t, vint16m2_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vsoxseg2ei8_v)))
void vsoxseg2ei8(int16_t *, vuint8m2_t, vint16m4_t, vint16m4_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vsoxseg2ei8_v_m)))
void vsoxseg2ei8(vbool4_t, int16_t *, vuint8m2_t, vint16m4_t, vint16m4_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vsoxseg2ei8_v)))
void vsoxseg2ei8(int16_t *, vuint8mf4_t, vint16mf2_t, vint16mf2_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vsoxseg2ei8_v_m)))
void vsoxseg2ei8(vbool32_t, int16_t *, vuint8mf4_t, vint16mf2_t, vint16mf2_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vsoxseg2ei8_v)))
void vsoxseg2ei8(int16_t *, vuint8mf8_t, vint16mf4_t, vint16mf4_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vsoxseg2ei8_v_m)))
void vsoxseg2ei8(vbool64_t, int16_t *, vuint8mf8_t, vint16mf4_t, vint16mf4_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vsoxseg2ei8_v)))
void vsoxseg2ei8(uint16_t *, vuint8mf2_t, vuint16m1_t, vuint16m1_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vsoxseg2ei8_v_m)))
void vsoxseg2ei8(vbool16_t, uint16_t *, vuint8mf2_t, vuint16m1_t, vuint16m1_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vsoxseg2ei8_v)))
void vsoxseg2ei8(uint16_t *, vuint8m1_t, vuint16m2_t, vuint16m2_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vsoxseg2ei8_v_m)))
void vsoxseg2ei8(vbool8_t, uint16_t *, vuint8m1_t, vuint16m2_t, vuint16m2_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vsoxseg2ei8_v)))
void vsoxseg2ei8(uint16_t *, vuint8m2_t, vuint16m4_t, vuint16m4_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vsoxseg2ei8_v_m)))
void vsoxseg2ei8(vbool4_t, uint16_t *, vuint8m2_t, vuint16m4_t, vuint16m4_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vsoxseg2ei8_v)))
void vsoxseg2ei8(uint16_t *, vuint8mf4_t, vuint16mf2_t, vuint16mf2_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vsoxseg2ei8_v_m)))
void vsoxseg2ei8(vbool32_t, uint16_t *, vuint8mf4_t, vuint16mf2_t, vuint16mf2_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vsoxseg2ei8_v)))
void vsoxseg2ei8(uint16_t *, vuint8mf8_t, vuint16mf4_t, vuint16mf4_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vsoxseg2ei8_v_m)))
void vsoxseg2ei8(vbool64_t, uint16_t *, vuint8mf8_t, vuint16mf4_t, vuint16mf4_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vsoxseg3ei8_v)))
void vsoxseg3ei8(int16_t *, vuint8mf2_t, vint16m1_t, vint16m1_t, vint16m1_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vsoxseg3ei8_v_m)))
void vsoxseg3ei8(vbool16_t, int16_t *, vuint8mf2_t, vint16m1_t, vint16m1_t, vint16m1_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vsoxseg3ei8_v)))
void vsoxseg3ei8(int16_t *, vuint8m1_t, vint16m2_t, vint16m2_t, vint16m2_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vsoxseg3ei8_v_m)))
void vsoxseg3ei8(vbool8_t, int16_t *, vuint8m1_t, vint16m2_t, vint16m2_t, vint16m2_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vsoxseg3ei8_v)))
void vsoxseg3ei8(int16_t *, vuint8mf4_t, vint16mf2_t, vint16mf2_t, vint16mf2_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vsoxseg3ei8_v_m)))
void vsoxseg3ei8(vbool32_t, int16_t *, vuint8mf4_t, vint16mf2_t, vint16mf2_t, vint16mf2_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vsoxseg3ei8_v)))
void vsoxseg3ei8(int16_t *, vuint8mf8_t, vint16mf4_t, vint16mf4_t, vint16mf4_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vsoxseg3ei8_v_m)))
void vsoxseg3ei8(vbool64_t, int16_t *, vuint8mf8_t, vint16mf4_t, vint16mf4_t, vint16mf4_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vsoxseg3ei8_v)))
void vsoxseg3ei8(uint16_t *, vuint8mf2_t, vuint16m1_t, vuint16m1_t, vuint16m1_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vsoxseg3ei8_v_m)))
void vsoxseg3ei8(vbool16_t, uint16_t *, vuint8mf2_t, vuint16m1_t, vuint16m1_t, vuint16m1_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vsoxseg3ei8_v)))
void vsoxseg3ei8(uint16_t *, vuint8m1_t, vuint16m2_t, vuint16m2_t, vuint16m2_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vsoxseg3ei8_v_m)))
void vsoxseg3ei8(vbool8_t, uint16_t *, vuint8m1_t, vuint16m2_t, vuint16m2_t, vuint16m2_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vsoxseg3ei8_v)))
void vsoxseg3ei8(uint16_t *, vuint8mf4_t, vuint16mf2_t, vuint16mf2_t, vuint16mf2_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vsoxseg3ei8_v_m)))
void vsoxseg3ei8(vbool32_t, uint16_t *, vuint8mf4_t, vuint16mf2_t, vuint16mf2_t, vuint16mf2_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vsoxseg3ei8_v)))
void vsoxseg3ei8(uint16_t *, vuint8mf8_t, vuint16mf4_t, vuint16mf4_t, vuint16mf4_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vsoxseg3ei8_v_m)))
void vsoxseg3ei8(vbool64_t, uint16_t *, vuint8mf8_t, vuint16mf4_t, vuint16mf4_t, vuint16mf4_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vsoxseg4ei8_v)))
void vsoxseg4ei8(int16_t *, vuint8mf2_t, vint16m1_t, vint16m1_t, vint16m1_t, vint16m1_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vsoxseg4ei8_v_m)))
void vsoxseg4ei8(vbool16_t, int16_t *, vuint8mf2_t, vint16m1_t, vint16m1_t, vint16m1_t, vint16m1_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vsoxseg4ei8_v)))
void vsoxseg4ei8(int16_t *, vuint8m1_t, vint16m2_t, vint16m2_t, vint16m2_t, vint16m2_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vsoxseg4ei8_v_m)))
void vsoxseg4ei8(vbool8_t, int16_t *, vuint8m1_t, vint16m2_t, vint16m2_t, vint16m2_t, vint16m2_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vsoxseg4ei8_v)))
void vsoxseg4ei8(int16_t *, vuint8mf4_t, vint16mf2_t, vint16mf2_t, vint16mf2_t, vint16mf2_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vsoxseg4ei8_v_m)))
void vsoxseg4ei8(vbool32_t, int16_t *, vuint8mf4_t, vint16mf2_t, vint16mf2_t, vint16mf2_t, vint16mf2_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vsoxseg4ei8_v)))
void vsoxseg4ei8(int16_t *, vuint8mf8_t, vint16mf4_t, vint16mf4_t, vint16mf4_t, vint16mf4_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vsoxseg4ei8_v_m)))
void vsoxseg4ei8(vbool64_t, int16_t *, vuint8mf8_t, vint16mf4_t, vint16mf4_t, vint16mf4_t, vint16mf4_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vsoxseg4ei8_v)))
void vsoxseg4ei8(uint16_t *, vuint8mf2_t, vuint16m1_t, vuint16m1_t, vuint16m1_t, vuint16m1_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vsoxseg4ei8_v_m)))
void vsoxseg4ei8(vbool16_t, uint16_t *, vuint8mf2_t, vuint16m1_t, vuint16m1_t, vuint16m1_t, vuint16m1_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vsoxseg4ei8_v)))
void vsoxseg4ei8(uint16_t *, vuint8m1_t, vuint16m2_t, vuint16m2_t, vuint16m2_t, vuint16m2_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vsoxseg4ei8_v_m)))
void vsoxseg4ei8(vbool8_t, uint16_t *, vuint8m1_t, vuint16m2_t, vuint16m2_t, vuint16m2_t, vuint16m2_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vsoxseg4ei8_v)))
void vsoxseg4ei8(uint16_t *, vuint8mf4_t, vuint16mf2_t, vuint16mf2_t, vuint16mf2_t, vuint16mf2_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vsoxseg4ei8_v_m)))
void vsoxseg4ei8(vbool32_t, uint16_t *, vuint8mf4_t, vuint16mf2_t, vuint16mf2_t, vuint16mf2_t, vuint16mf2_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vsoxseg4ei8_v)))
void vsoxseg4ei8(uint16_t *, vuint8mf8_t, vuint16mf4_t, vuint16mf4_t, vuint16mf4_t, vuint16mf4_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vsoxseg4ei8_v_m)))
void vsoxseg4ei8(vbool64_t, uint16_t *, vuint8mf8_t, vuint16mf4_t, vuint16mf4_t, vuint16mf4_t, vuint16mf4_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vloxei16_v)))
vuint16m1_t vloxei16(const uint16_t *, vuint16m1_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vloxei16_v_m)))
vuint16m1_t vloxei16(vbool16_t, vuint16m1_t, const uint16_t *, vuint16m1_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vloxei16_v)))
vuint16m2_t vloxei16(const uint16_t *, vuint16m2_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vloxei16_v_m)))
vuint16m2_t vloxei16(vbool8_t, vuint16m2_t, const uint16_t *, vuint16m2_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vloxei16_v)))
vuint16m4_t vloxei16(const uint16_t *, vuint16m4_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vloxei16_v_m)))
vuint16m4_t vloxei16(vbool4_t, vuint16m4_t, const uint16_t *, vuint16m4_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vloxei16_v)))
vuint16m8_t vloxei16(const uint16_t *, vuint16m8_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vloxei16_v_m)))
vuint16m8_t vloxei16(vbool2_t, vuint16m8_t, const uint16_t *, vuint16m8_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vloxei16_v)))
vuint16mf2_t vloxei16(const uint16_t *, vuint16mf2_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vloxei16_v_m)))
vuint16mf2_t vloxei16(vbool32_t, vuint16mf2_t, const uint16_t *, vuint16mf2_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vloxei16_v)))
vuint16mf4_t vloxei16(const uint16_t *, vuint16mf4_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vloxei16_v_m)))
vuint16mf4_t vloxei16(vbool64_t, vuint16mf4_t, const uint16_t *, vuint16mf4_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vsoxseg5ei8_v)))
void vsoxseg5ei8(int16_t *, vuint8mf2_t, vint16m1_t, vint16m1_t, vint16m1_t, vint16m1_t, vint16m1_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vsoxseg5ei8_v_m)))
void vsoxseg5ei8(vbool16_t, int16_t *, vuint8mf2_t, vint16m1_t, vint16m1_t, vint16m1_t, vint16m1_t, vint16m1_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vsoxseg5ei8_v)))
void vsoxseg5ei8(int16_t *, vuint8mf4_t, vint16mf2_t, vint16mf2_t, vint16mf2_t, vint16mf2_t, vint16mf2_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vsoxseg5ei8_v_m)))
void vsoxseg5ei8(vbool32_t, int16_t *, vuint8mf4_t, vint16mf2_t, vint16mf2_t, vint16mf2_t, vint16mf2_t, vint16mf2_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vsoxseg5ei8_v)))
void vsoxseg5ei8(int16_t *, vuint8mf8_t, vint16mf4_t, vint16mf4_t, vint16mf4_t, vint16mf4_t, vint16mf4_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vsoxseg5ei8_v_m)))
void vsoxseg5ei8(vbool64_t, int16_t *, vuint8mf8_t, vint16mf4_t, vint16mf4_t, vint16mf4_t, vint16mf4_t, vint16mf4_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vsoxseg5ei8_v)))
void vsoxseg5ei8(uint16_t *, vuint8mf2_t, vuint16m1_t, vuint16m1_t, vuint16m1_t, vuint16m1_t, vuint16m1_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vsoxseg5ei8_v_m)))
void vsoxseg5ei8(vbool16_t, uint16_t *, vuint8mf2_t, vuint16m1_t, vuint16m1_t, vuint16m1_t, vuint16m1_t, vuint16m1_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vsoxseg5ei8_v)))
void vsoxseg5ei8(uint16_t *, vuint8mf4_t, vuint16mf2_t, vuint16mf2_t, vuint16mf2_t, vuint16mf2_t, vuint16mf2_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vsoxseg5ei8_v_m)))
void vsoxseg5ei8(vbool32_t, uint16_t *, vuint8mf4_t, vuint16mf2_t, vuint16mf2_t, vuint16mf2_t, vuint16mf2_t, vuint16mf2_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vsoxseg5ei8_v)))
void vsoxseg5ei8(uint16_t *, vuint8mf8_t, vuint16mf4_t, vuint16mf4_t, vuint16mf4_t, vuint16mf4_t, vuint16mf4_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vsoxseg5ei8_v_m)))
void vsoxseg5ei8(vbool64_t, uint16_t *, vuint8mf8_t, vuint16mf4_t, vuint16mf4_t, vuint16mf4_t, vuint16mf4_t, vuint16mf4_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vsoxseg6ei8_v)))
void vsoxseg6ei8(int16_t *, vuint8mf2_t, vint16m1_t, vint16m1_t, vint16m1_t, vint16m1_t, vint16m1_t, vint16m1_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vsoxseg6ei8_v_m)))
void vsoxseg6ei8(vbool16_t, int16_t *, vuint8mf2_t, vint16m1_t, vint16m1_t, vint16m1_t, vint16m1_t, vint16m1_t, vint16m1_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vsoxseg6ei8_v)))
void vsoxseg6ei8(int16_t *, vuint8mf4_t, vint16mf2_t, vint16mf2_t, vint16mf2_t, vint16mf2_t, vint16mf2_t, vint16mf2_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vsoxseg6ei8_v_m)))
void vsoxseg6ei8(vbool32_t, int16_t *, vuint8mf4_t, vint16mf2_t, vint16mf2_t, vint16mf2_t, vint16mf2_t, vint16mf2_t, vint16mf2_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vsoxseg6ei8_v)))
void vsoxseg6ei8(int16_t *, vuint8mf8_t, vint16mf4_t, vint16mf4_t, vint16mf4_t, vint16mf4_t, vint16mf4_t, vint16mf4_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vsoxseg6ei8_v_m)))
void vsoxseg6ei8(vbool64_t, int16_t *, vuint8mf8_t, vint16mf4_t, vint16mf4_t, vint16mf4_t, vint16mf4_t, vint16mf4_t, vint16mf4_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vsoxseg6ei8_v)))
void vsoxseg6ei8(uint16_t *, vuint8mf2_t, vuint16m1_t, vuint16m1_t, vuint16m1_t, vuint16m1_t, vuint16m1_t, vuint16m1_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vsoxseg6ei8_v_m)))
void vsoxseg6ei8(vbool16_t, uint16_t *, vuint8mf2_t, vuint16m1_t, vuint16m1_t, vuint16m1_t, vuint16m1_t, vuint16m1_t, vuint16m1_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vsoxseg6ei8_v)))
void vsoxseg6ei8(uint16_t *, vuint8mf4_t, vuint16mf2_t, vuint16mf2_t, vuint16mf2_t, vuint16mf2_t, vuint16mf2_t, vuint16mf2_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vsoxseg6ei8_v_m)))
void vsoxseg6ei8(vbool32_t, uint16_t *, vuint8mf4_t, vuint16mf2_t, vuint16mf2_t, vuint16mf2_t, vuint16mf2_t, vuint16mf2_t, vuint16mf2_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vsoxseg6ei8_v)))
void vsoxseg6ei8(uint16_t *, vuint8mf8_t, vuint16mf4_t, vuint16mf4_t, vuint16mf4_t, vuint16mf4_t, vuint16mf4_t, vuint16mf4_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vsoxseg6ei8_v_m)))
void vsoxseg6ei8(vbool64_t, uint16_t *, vuint8mf8_t, vuint16mf4_t, vuint16mf4_t, vuint16mf4_t, vuint16mf4_t, vuint16mf4_t, vuint16mf4_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vsoxseg7ei8_v)))
void vsoxseg7ei8(int16_t *, vuint8mf2_t, vint16m1_t, vint16m1_t, vint16m1_t, vint16m1_t, vint16m1_t, vint16m1_t, vint16m1_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vsoxseg7ei8_v_m)))
void vsoxseg7ei8(vbool16_t, int16_t *, vuint8mf2_t, vint16m1_t, vint16m1_t, vint16m1_t, vint16m1_t, vint16m1_t, vint16m1_t, vint16m1_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vsoxseg7ei8_v)))
void vsoxseg7ei8(int16_t *, vuint8mf4_t, vint16mf2_t, vint16mf2_t, vint16mf2_t, vint16mf2_t, vint16mf2_t, vint16mf2_t, vint16mf2_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vsoxseg7ei8_v_m)))
void vsoxseg7ei8(vbool32_t, int16_t *, vuint8mf4_t, vint16mf2_t, vint16mf2_t, vint16mf2_t, vint16mf2_t, vint16mf2_t, vint16mf2_t, vint16mf2_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vsoxseg7ei8_v)))
void vsoxseg7ei8(int16_t *, vuint8mf8_t, vint16mf4_t, vint16mf4_t, vint16mf4_t, vint16mf4_t, vint16mf4_t, vint16mf4_t, vint16mf4_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vsoxseg7ei8_v_m)))
void vsoxseg7ei8(vbool64_t, int16_t *, vuint8mf8_t, vint16mf4_t, vint16mf4_t, vint16mf4_t, vint16mf4_t, vint16mf4_t, vint16mf4_t, vint16mf4_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vsoxseg7ei8_v)))
void vsoxseg7ei8(uint16_t *, vuint8mf2_t, vuint16m1_t, vuint16m1_t, vuint16m1_t, vuint16m1_t, vuint16m1_t, vuint16m1_t, vuint16m1_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vsoxseg7ei8_v_m)))
void vsoxseg7ei8(vbool16_t, uint16_t *, vuint8mf2_t, vuint16m1_t, vuint16m1_t, vuint16m1_t, vuint16m1_t, vuint16m1_t, vuint16m1_t, vuint16m1_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vsoxseg7ei8_v)))
void vsoxseg7ei8(uint16_t *, vuint8mf4_t, vuint16mf2_t, vuint16mf2_t, vuint16mf2_t, vuint16mf2_t, vuint16mf2_t, vuint16mf2_t, vuint16mf2_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vsoxseg7ei8_v_m)))
void vsoxseg7ei8(vbool32_t, uint16_t *, vuint8mf4_t, vuint16mf2_t, vuint16mf2_t, vuint16mf2_t, vuint16mf2_t, vuint16mf2_t, vuint16mf2_t, vuint16mf2_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vsoxseg7ei8_v)))
void vsoxseg7ei8(uint16_t *, vuint8mf8_t, vuint16mf4_t, vuint16mf4_t, vuint16mf4_t, vuint16mf4_t, vuint16mf4_t, vuint16mf4_t, vuint16mf4_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vsoxseg7ei8_v_m)))
void vsoxseg7ei8(vbool64_t, uint16_t *, vuint8mf8_t, vuint16mf4_t, vuint16mf4_t, vuint16mf4_t, vuint16mf4_t, vuint16mf4_t, vuint16mf4_t, vuint16mf4_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vsoxseg8ei8_v)))
void vsoxseg8ei8(int16_t *, vuint8mf2_t, vint16m1_t, vint16m1_t, vint16m1_t, vint16m1_t, vint16m1_t, vint16m1_t, vint16m1_t, vint16m1_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vsoxseg8ei8_v_m)))
void vsoxseg8ei8(vbool16_t, int16_t *, vuint8mf2_t, vint16m1_t, vint16m1_t, vint16m1_t, vint16m1_t, vint16m1_t, vint16m1_t, vint16m1_t, vint16m1_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vsoxseg8ei8_v)))
void vsoxseg8ei8(int16_t *, vuint8mf4_t, vint16mf2_t, vint16mf2_t, vint16mf2_t, vint16mf2_t, vint16mf2_t, vint16mf2_t, vint16mf2_t, vint16mf2_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vsoxseg8ei8_v_m)))
void vsoxseg8ei8(vbool32_t, int16_t *, vuint8mf4_t, vint16mf2_t, vint16mf2_t, vint16mf2_t, vint16mf2_t, vint16mf2_t, vint16mf2_t, vint16mf2_t, vint16mf2_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vsoxseg8ei8_v)))
void vsoxseg8ei8(int16_t *, vuint8mf8_t, vint16mf4_t, vint16mf4_t, vint16mf4_t, vint16mf4_t, vint16mf4_t, vint16mf4_t, vint16mf4_t, vint16mf4_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vsoxseg8ei8_v_m)))
void vsoxseg8ei8(vbool64_t, int16_t *, vuint8mf8_t, vint16mf4_t, vint16mf4_t, vint16mf4_t, vint16mf4_t, vint16mf4_t, vint16mf4_t, vint16mf4_t, vint16mf4_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vsoxseg8ei8_v)))
void vsoxseg8ei8(uint16_t *, vuint8mf2_t, vuint16m1_t, vuint16m1_t, vuint16m1_t, vuint16m1_t, vuint16m1_t, vuint16m1_t, vuint16m1_t, vuint16m1_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vsoxseg8ei8_v_m)))
void vsoxseg8ei8(vbool16_t, uint16_t *, vuint8mf2_t, vuint16m1_t, vuint16m1_t, vuint16m1_t, vuint16m1_t, vuint16m1_t, vuint16m1_t, vuint16m1_t, vuint16m1_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vsoxseg8ei8_v)))
void vsoxseg8ei8(uint16_t *, vuint8mf4_t, vuint16mf2_t, vuint16mf2_t, vuint16mf2_t, vuint16mf2_t, vuint16mf2_t, vuint16mf2_t, vuint16mf2_t, vuint16mf2_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vsoxseg8ei8_v_m)))
void vsoxseg8ei8(vbool32_t, uint16_t *, vuint8mf4_t, vuint16mf2_t, vuint16mf2_t, vuint16mf2_t, vuint16mf2_t, vuint16mf2_t, vuint16mf2_t, vuint16mf2_t, vuint16mf2_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vsoxseg8ei8_v)))
void vsoxseg8ei8(uint16_t *, vuint8mf8_t, vuint16mf4_t, vuint16mf4_t, vuint16mf4_t, vuint16mf4_t, vuint16mf4_t, vuint16mf4_t, vuint16mf4_t, vuint16mf4_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vsoxseg8ei8_v_m)))
void vsoxseg8ei8(vbool64_t, uint16_t *, vuint8mf8_t, vuint16mf4_t, vuint16mf4_t, vuint16mf4_t, vuint16mf4_t, vuint16mf4_t, vuint16mf4_t, vuint16mf4_t, vuint16mf4_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vsoxseg2ei16_v)))
void vsoxseg2ei16(int16_t *, vuint16m1_t, vint16m1_t, vint16m1_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vsoxseg2ei16_v_m)))
void vsoxseg2ei16(vbool16_t, int16_t *, vuint16m1_t, vint16m1_t, vint16m1_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vsoxseg2ei16_v)))
void vsoxseg2ei16(int16_t *, vuint16m2_t, vint16m2_t, vint16m2_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vsoxseg2ei16_v_m)))
void vsoxseg2ei16(vbool8_t, int16_t *, vuint16m2_t, vint16m2_t, vint16m2_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vsoxseg2ei16_v)))
void vsoxseg2ei16(int16_t *, vuint16m4_t, vint16m4_t, vint16m4_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vsoxseg2ei16_v_m)))
void vsoxseg2ei16(vbool4_t, int16_t *, vuint16m4_t, vint16m4_t, vint16m4_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vsoxseg2ei16_v)))
void vsoxseg2ei16(int16_t *, vuint16mf2_t, vint16mf2_t, vint16mf2_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vsoxseg2ei16_v_m)))
void vsoxseg2ei16(vbool32_t, int16_t *, vuint16mf2_t, vint16mf2_t, vint16mf2_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vsoxseg2ei16_v)))
void vsoxseg2ei16(int16_t *, vuint16mf4_t, vint16mf4_t, vint16mf4_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vsoxseg2ei16_v_m)))
void vsoxseg2ei16(vbool64_t, int16_t *, vuint16mf4_t, vint16mf4_t, vint16mf4_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vsoxseg2ei16_v)))
void vsoxseg2ei16(uint16_t *, vuint16m1_t, vuint16m1_t, vuint16m1_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vsoxseg2ei16_v_m)))
void vsoxseg2ei16(vbool16_t, uint16_t *, vuint16m1_t, vuint16m1_t, vuint16m1_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vsoxseg2ei16_v)))
void vsoxseg2ei16(uint16_t *, vuint16m2_t, vuint16m2_t, vuint16m2_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vsoxseg2ei16_v_m)))
void vsoxseg2ei16(vbool8_t, uint16_t *, vuint16m2_t, vuint16m2_t, vuint16m2_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vsoxseg2ei16_v)))
void vsoxseg2ei16(uint16_t *, vuint16m4_t, vuint16m4_t, vuint16m4_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vsoxseg2ei16_v_m)))
void vsoxseg2ei16(vbool4_t, uint16_t *, vuint16m4_t, vuint16m4_t, vuint16m4_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vsoxseg2ei16_v)))
void vsoxseg2ei16(uint16_t *, vuint16mf2_t, vuint16mf2_t, vuint16mf2_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vsoxseg2ei16_v_m)))
void vsoxseg2ei16(vbool32_t, uint16_t *, vuint16mf2_t, vuint16mf2_t, vuint16mf2_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vsoxseg2ei16_v)))
void vsoxseg2ei16(uint16_t *, vuint16mf4_t, vuint16mf4_t, vuint16mf4_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vsoxseg2ei16_v_m)))
void vsoxseg2ei16(vbool64_t, uint16_t *, vuint16mf4_t, vuint16mf4_t, vuint16mf4_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vloxei32_v)))
vint16m1_t vloxei32(const int16_t *, vuint32m2_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vloxei32_v_m)))
vint16m1_t vloxei32(vbool16_t, vint16m1_t, const int16_t *, vuint32m2_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vloxei32_v)))
vint16m2_t vloxei32(const int16_t *, vuint32m4_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vloxei32_v_m)))
vint16m2_t vloxei32(vbool8_t, vint16m2_t, const int16_t *, vuint32m4_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vloxei32_v)))
vint16m4_t vloxei32(const int16_t *, vuint32m8_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vloxei32_v_m)))
vint16m4_t vloxei32(vbool4_t, vint16m4_t, const int16_t *, vuint32m8_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vloxei32_v)))
vint16mf2_t vloxei32(const int16_t *, vuint32m1_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vloxei32_v_m)))
vint16mf2_t vloxei32(vbool32_t, vint16mf2_t, const int16_t *, vuint32m1_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vloxei32_v)))
vint16mf4_t vloxei32(const int16_t *, vuint32mf2_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vloxei32_v_m)))
vint16mf4_t vloxei32(vbool64_t, vint16mf4_t, const int16_t *, vuint32mf2_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vsoxseg3ei16_v)))
void vsoxseg3ei16(int16_t *, vuint16m1_t, vint16m1_t, vint16m1_t, vint16m1_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vsoxseg3ei16_v_m)))
void vsoxseg3ei16(vbool16_t, int16_t *, vuint16m1_t, vint16m1_t, vint16m1_t, vint16m1_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vsoxseg3ei16_v)))
void vsoxseg3ei16(int16_t *, vuint16m2_t, vint16m2_t, vint16m2_t, vint16m2_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vsoxseg3ei16_v_m)))
void vsoxseg3ei16(vbool8_t, int16_t *, vuint16m2_t, vint16m2_t, vint16m2_t, vint16m2_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vsoxseg3ei16_v)))
void vsoxseg3ei16(int16_t *, vuint16mf2_t, vint16mf2_t, vint16mf2_t, vint16mf2_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vsoxseg3ei16_v_m)))
void vsoxseg3ei16(vbool32_t, int16_t *, vuint16mf2_t, vint16mf2_t, vint16mf2_t, vint16mf2_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vsoxseg3ei16_v)))
void vsoxseg3ei16(int16_t *, vuint16mf4_t, vint16mf4_t, vint16mf4_t, vint16mf4_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vsoxseg3ei16_v_m)))
void vsoxseg3ei16(vbool64_t, int16_t *, vuint16mf4_t, vint16mf4_t, vint16mf4_t, vint16mf4_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vsoxseg3ei16_v)))
void vsoxseg3ei16(uint16_t *, vuint16m1_t, vuint16m1_t, vuint16m1_t, vuint16m1_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vsoxseg3ei16_v_m)))
void vsoxseg3ei16(vbool16_t, uint16_t *, vuint16m1_t, vuint16m1_t, vuint16m1_t, vuint16m1_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vsoxseg3ei16_v)))
void vsoxseg3ei16(uint16_t *, vuint16m2_t, vuint16m2_t, vuint16m2_t, vuint16m2_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vsoxseg3ei16_v_m)))
void vsoxseg3ei16(vbool8_t, uint16_t *, vuint16m2_t, vuint16m2_t, vuint16m2_t, vuint16m2_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vsoxseg3ei16_v)))
void vsoxseg3ei16(uint16_t *, vuint16mf2_t, vuint16mf2_t, vuint16mf2_t, vuint16mf2_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vsoxseg3ei16_v_m)))
void vsoxseg3ei16(vbool32_t, uint16_t *, vuint16mf2_t, vuint16mf2_t, vuint16mf2_t, vuint16mf2_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vsoxseg3ei16_v)))
void vsoxseg3ei16(uint16_t *, vuint16mf4_t, vuint16mf4_t, vuint16mf4_t, vuint16mf4_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vsoxseg3ei16_v_m)))
void vsoxseg3ei16(vbool64_t, uint16_t *, vuint16mf4_t, vuint16mf4_t, vuint16mf4_t, vuint16mf4_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vsoxseg4ei16_v)))
void vsoxseg4ei16(int16_t *, vuint16m1_t, vint16m1_t, vint16m1_t, vint16m1_t, vint16m1_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vsoxseg4ei16_v_m)))
void vsoxseg4ei16(vbool16_t, int16_t *, vuint16m1_t, vint16m1_t, vint16m1_t, vint16m1_t, vint16m1_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vsoxseg4ei16_v)))
void vsoxseg4ei16(int16_t *, vuint16m2_t, vint16m2_t, vint16m2_t, vint16m2_t, vint16m2_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vsoxseg4ei16_v_m)))
void vsoxseg4ei16(vbool8_t, int16_t *, vuint16m2_t, vint16m2_t, vint16m2_t, vint16m2_t, vint16m2_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vsoxseg4ei16_v)))
void vsoxseg4ei16(int16_t *, vuint16mf2_t, vint16mf2_t, vint16mf2_t, vint16mf2_t, vint16mf2_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vsoxseg4ei16_v_m)))
void vsoxseg4ei16(vbool32_t, int16_t *, vuint16mf2_t, vint16mf2_t, vint16mf2_t, vint16mf2_t, vint16mf2_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vsoxseg4ei16_v)))
void vsoxseg4ei16(int16_t *, vuint16mf4_t, vint16mf4_t, vint16mf4_t, vint16mf4_t, vint16mf4_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vsoxseg4ei16_v_m)))
void vsoxseg4ei16(vbool64_t, int16_t *, vuint16mf4_t, vint16mf4_t, vint16mf4_t, vint16mf4_t, vint16mf4_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vsoxseg4ei16_v)))
void vsoxseg4ei16(uint16_t *, vuint16m1_t, vuint16m1_t, vuint16m1_t, vuint16m1_t, vuint16m1_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vsoxseg4ei16_v_m)))
void vsoxseg4ei16(vbool16_t, uint16_t *, vuint16m1_t, vuint16m1_t, vuint16m1_t, vuint16m1_t, vuint16m1_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vsoxseg4ei16_v)))
void vsoxseg4ei16(uint16_t *, vuint16m2_t, vuint16m2_t, vuint16m2_t, vuint16m2_t, vuint16m2_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vsoxseg4ei16_v_m)))
void vsoxseg4ei16(vbool8_t, uint16_t *, vuint16m2_t, vuint16m2_t, vuint16m2_t, vuint16m2_t, vuint16m2_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vsoxseg4ei16_v)))
void vsoxseg4ei16(uint16_t *, vuint16mf2_t, vuint16mf2_t, vuint16mf2_t, vuint16mf2_t, vuint16mf2_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vsoxseg4ei16_v_m)))
void vsoxseg4ei16(vbool32_t, uint16_t *, vuint16mf2_t, vuint16mf2_t, vuint16mf2_t, vuint16mf2_t, vuint16mf2_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vsoxseg4ei16_v)))
void vsoxseg4ei16(uint16_t *, vuint16mf4_t, vuint16mf4_t, vuint16mf4_t, vuint16mf4_t, vuint16mf4_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vsoxseg4ei16_v_m)))
void vsoxseg4ei16(vbool64_t, uint16_t *, vuint16mf4_t, vuint16mf4_t, vuint16mf4_t, vuint16mf4_t, vuint16mf4_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vsoxseg5ei16_v)))
void vsoxseg5ei16(int16_t *, vuint16m1_t, vint16m1_t, vint16m1_t, vint16m1_t, vint16m1_t, vint16m1_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vsoxseg5ei16_v_m)))
void vsoxseg5ei16(vbool16_t, int16_t *, vuint16m1_t, vint16m1_t, vint16m1_t, vint16m1_t, vint16m1_t, vint16m1_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vsoxseg5ei16_v)))
void vsoxseg5ei16(int16_t *, vuint16mf2_t, vint16mf2_t, vint16mf2_t, vint16mf2_t, vint16mf2_t, vint16mf2_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vsoxseg5ei16_v_m)))
void vsoxseg5ei16(vbool32_t, int16_t *, vuint16mf2_t, vint16mf2_t, vint16mf2_t, vint16mf2_t, vint16mf2_t, vint16mf2_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vsoxseg5ei16_v)))
void vsoxseg5ei16(int16_t *, vuint16mf4_t, vint16mf4_t, vint16mf4_t, vint16mf4_t, vint16mf4_t, vint16mf4_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vsoxseg5ei16_v_m)))
void vsoxseg5ei16(vbool64_t, int16_t *, vuint16mf4_t, vint16mf4_t, vint16mf4_t, vint16mf4_t, vint16mf4_t, vint16mf4_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vsoxseg5ei16_v)))
void vsoxseg5ei16(uint16_t *, vuint16m1_t, vuint16m1_t, vuint16m1_t, vuint16m1_t, vuint16m1_t, vuint16m1_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vsoxseg5ei16_v_m)))
void vsoxseg5ei16(vbool16_t, uint16_t *, vuint16m1_t, vuint16m1_t, vuint16m1_t, vuint16m1_t, vuint16m1_t, vuint16m1_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vsoxseg5ei16_v)))
void vsoxseg5ei16(uint16_t *, vuint16mf2_t, vuint16mf2_t, vuint16mf2_t, vuint16mf2_t, vuint16mf2_t, vuint16mf2_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vsoxseg5ei16_v_m)))
void vsoxseg5ei16(vbool32_t, uint16_t *, vuint16mf2_t, vuint16mf2_t, vuint16mf2_t, vuint16mf2_t, vuint16mf2_t, vuint16mf2_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vsoxseg5ei16_v)))
void vsoxseg5ei16(uint16_t *, vuint16mf4_t, vuint16mf4_t, vuint16mf4_t, vuint16mf4_t, vuint16mf4_t, vuint16mf4_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vsoxseg5ei16_v_m)))
void vsoxseg5ei16(vbool64_t, uint16_t *, vuint16mf4_t, vuint16mf4_t, vuint16mf4_t, vuint16mf4_t, vuint16mf4_t, vuint16mf4_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vsoxseg6ei16_v)))
void vsoxseg6ei16(int16_t *, vuint16m1_t, vint16m1_t, vint16m1_t, vint16m1_t, vint16m1_t, vint16m1_t, vint16m1_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vsoxseg6ei16_v_m)))
void vsoxseg6ei16(vbool16_t, int16_t *, vuint16m1_t, vint16m1_t, vint16m1_t, vint16m1_t, vint16m1_t, vint16m1_t, vint16m1_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vsoxseg6ei16_v)))
void vsoxseg6ei16(int16_t *, vuint16mf2_t, vint16mf2_t, vint16mf2_t, vint16mf2_t, vint16mf2_t, vint16mf2_t, vint16mf2_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vsoxseg6ei16_v_m)))
void vsoxseg6ei16(vbool32_t, int16_t *, vuint16mf2_t, vint16mf2_t, vint16mf2_t, vint16mf2_t, vint16mf2_t, vint16mf2_t, vint16mf2_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vsoxseg6ei16_v)))
void vsoxseg6ei16(int16_t *, vuint16mf4_t, vint16mf4_t, vint16mf4_t, vint16mf4_t, vint16mf4_t, vint16mf4_t, vint16mf4_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vsoxseg6ei16_v_m)))
void vsoxseg6ei16(vbool64_t, int16_t *, vuint16mf4_t, vint16mf4_t, vint16mf4_t, vint16mf4_t, vint16mf4_t, vint16mf4_t, vint16mf4_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vsoxseg6ei16_v)))
void vsoxseg6ei16(uint16_t *, vuint16m1_t, vuint16m1_t, vuint16m1_t, vuint16m1_t, vuint16m1_t, vuint16m1_t, vuint16m1_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vsoxseg6ei16_v_m)))
void vsoxseg6ei16(vbool16_t, uint16_t *, vuint16m1_t, vuint16m1_t, vuint16m1_t, vuint16m1_t, vuint16m1_t, vuint16m1_t, vuint16m1_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vsoxseg6ei16_v)))
void vsoxseg6ei16(uint16_t *, vuint16mf2_t, vuint16mf2_t, vuint16mf2_t, vuint16mf2_t, vuint16mf2_t, vuint16mf2_t, vuint16mf2_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vsoxseg6ei16_v_m)))
void vsoxseg6ei16(vbool32_t, uint16_t *, vuint16mf2_t, vuint16mf2_t, vuint16mf2_t, vuint16mf2_t, vuint16mf2_t, vuint16mf2_t, vuint16mf2_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vsoxseg6ei16_v)))
void vsoxseg6ei16(uint16_t *, vuint16mf4_t, vuint16mf4_t, vuint16mf4_t, vuint16mf4_t, vuint16mf4_t, vuint16mf4_t, vuint16mf4_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vsoxseg6ei16_v_m)))
void vsoxseg6ei16(vbool64_t, uint16_t *, vuint16mf4_t, vuint16mf4_t, vuint16mf4_t, vuint16mf4_t, vuint16mf4_t, vuint16mf4_t, vuint16mf4_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vsoxseg7ei16_v)))
void vsoxseg7ei16(int16_t *, vuint16m1_t, vint16m1_t, vint16m1_t, vint16m1_t, vint16m1_t, vint16m1_t, vint16m1_t, vint16m1_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vsoxseg7ei16_v_m)))
void vsoxseg7ei16(vbool16_t, int16_t *, vuint16m1_t, vint16m1_t, vint16m1_t, vint16m1_t, vint16m1_t, vint16m1_t, vint16m1_t, vint16m1_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vsoxseg7ei16_v)))
void vsoxseg7ei16(int16_t *, vuint16mf2_t, vint16mf2_t, vint16mf2_t, vint16mf2_t, vint16mf2_t, vint16mf2_t, vint16mf2_t, vint16mf2_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vsoxseg7ei16_v_m)))
void vsoxseg7ei16(vbool32_t, int16_t *, vuint16mf2_t, vint16mf2_t, vint16mf2_t, vint16mf2_t, vint16mf2_t, vint16mf2_t, vint16mf2_t, vint16mf2_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vsoxseg7ei16_v)))
void vsoxseg7ei16(int16_t *, vuint16mf4_t, vint16mf4_t, vint16mf4_t, vint16mf4_t, vint16mf4_t, vint16mf4_t, vint16mf4_t, vint16mf4_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vsoxseg7ei16_v_m)))
void vsoxseg7ei16(vbool64_t, int16_t *, vuint16mf4_t, vint16mf4_t, vint16mf4_t, vint16mf4_t, vint16mf4_t, vint16mf4_t, vint16mf4_t, vint16mf4_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vsoxseg7ei16_v)))
void vsoxseg7ei16(uint16_t *, vuint16m1_t, vuint16m1_t, vuint16m1_t, vuint16m1_t, vuint16m1_t, vuint16m1_t, vuint16m1_t, vuint16m1_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vsoxseg7ei16_v_m)))
void vsoxseg7ei16(vbool16_t, uint16_t *, vuint16m1_t, vuint16m1_t, vuint16m1_t, vuint16m1_t, vuint16m1_t, vuint16m1_t, vuint16m1_t, vuint16m1_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vsoxseg7ei16_v)))
void vsoxseg7ei16(uint16_t *, vuint16mf2_t, vuint16mf2_t, vuint16mf2_t, vuint16mf2_t, vuint16mf2_t, vuint16mf2_t, vuint16mf2_t, vuint16mf2_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vsoxseg7ei16_v_m)))
void vsoxseg7ei16(vbool32_t, uint16_t *, vuint16mf2_t, vuint16mf2_t, vuint16mf2_t, vuint16mf2_t, vuint16mf2_t, vuint16mf2_t, vuint16mf2_t, vuint16mf2_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vsoxseg7ei16_v)))
void vsoxseg7ei16(uint16_t *, vuint16mf4_t, vuint16mf4_t, vuint16mf4_t, vuint16mf4_t, vuint16mf4_t, vuint16mf4_t, vuint16mf4_t, vuint16mf4_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vsoxseg7ei16_v_m)))
void vsoxseg7ei16(vbool64_t, uint16_t *, vuint16mf4_t, vuint16mf4_t, vuint16mf4_t, vuint16mf4_t, vuint16mf4_t, vuint16mf4_t, vuint16mf4_t, vuint16mf4_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vloxei32_v)))
vuint16m1_t vloxei32(const uint16_t *, vuint32m2_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vloxei32_v_m)))
vuint16m1_t vloxei32(vbool16_t, vuint16m1_t, const uint16_t *, vuint32m2_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vloxei32_v)))
vuint16m2_t vloxei32(const uint16_t *, vuint32m4_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vloxei32_v_m)))
vuint16m2_t vloxei32(vbool8_t, vuint16m2_t, const uint16_t *, vuint32m4_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vloxei32_v)))
vuint16m4_t vloxei32(const uint16_t *, vuint32m8_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vloxei32_v_m)))
vuint16m4_t vloxei32(vbool4_t, vuint16m4_t, const uint16_t *, vuint32m8_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vloxei32_v)))
vuint16mf2_t vloxei32(const uint16_t *, vuint32m1_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vloxei32_v_m)))
vuint16mf2_t vloxei32(vbool32_t, vuint16mf2_t, const uint16_t *, vuint32m1_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vloxei32_v)))
vuint16mf4_t vloxei32(const uint16_t *, vuint32mf2_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vloxei32_v_m)))
vuint16mf4_t vloxei32(vbool64_t, vuint16mf4_t, const uint16_t *, vuint32mf2_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vsoxseg8ei16_v)))
void vsoxseg8ei16(int16_t *, vuint16m1_t, vint16m1_t, vint16m1_t, vint16m1_t, vint16m1_t, vint16m1_t, vint16m1_t, vint16m1_t, vint16m1_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vsoxseg8ei16_v_m)))
void vsoxseg8ei16(vbool16_t, int16_t *, vuint16m1_t, vint16m1_t, vint16m1_t, vint16m1_t, vint16m1_t, vint16m1_t, vint16m1_t, vint16m1_t, vint16m1_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vsoxseg8ei16_v)))
void vsoxseg8ei16(int16_t *, vuint16mf2_t, vint16mf2_t, vint16mf2_t, vint16mf2_t, vint16mf2_t, vint16mf2_t, vint16mf2_t, vint16mf2_t, vint16mf2_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vsoxseg8ei16_v_m)))
void vsoxseg8ei16(vbool32_t, int16_t *, vuint16mf2_t, vint16mf2_t, vint16mf2_t, vint16mf2_t, vint16mf2_t, vint16mf2_t, vint16mf2_t, vint16mf2_t, vint16mf2_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vsoxseg8ei16_v)))
void vsoxseg8ei16(int16_t *, vuint16mf4_t, vint16mf4_t, vint16mf4_t, vint16mf4_t, vint16mf4_t, vint16mf4_t, vint16mf4_t, vint16mf4_t, vint16mf4_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vsoxseg8ei16_v_m)))
void vsoxseg8ei16(vbool64_t, int16_t *, vuint16mf4_t, vint16mf4_t, vint16mf4_t, vint16mf4_t, vint16mf4_t, vint16mf4_t, vint16mf4_t, vint16mf4_t, vint16mf4_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vsoxseg8ei16_v)))
void vsoxseg8ei16(uint16_t *, vuint16m1_t, vuint16m1_t, vuint16m1_t, vuint16m1_t, vuint16m1_t, vuint16m1_t, vuint16m1_t, vuint16m1_t, vuint16m1_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vsoxseg8ei16_v_m)))
void vsoxseg8ei16(vbool16_t, uint16_t *, vuint16m1_t, vuint16m1_t, vuint16m1_t, vuint16m1_t, vuint16m1_t, vuint16m1_t, vuint16m1_t, vuint16m1_t, vuint16m1_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vsoxseg8ei16_v)))
void vsoxseg8ei16(uint16_t *, vuint16mf2_t, vuint16mf2_t, vuint16mf2_t, vuint16mf2_t, vuint16mf2_t, vuint16mf2_t, vuint16mf2_t, vuint16mf2_t, vuint16mf2_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vsoxseg8ei16_v_m)))
void vsoxseg8ei16(vbool32_t, uint16_t *, vuint16mf2_t, vuint16mf2_t, vuint16mf2_t, vuint16mf2_t, vuint16mf2_t, vuint16mf2_t, vuint16mf2_t, vuint16mf2_t, vuint16mf2_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vsoxseg8ei16_v)))
void vsoxseg8ei16(uint16_t *, vuint16mf4_t, vuint16mf4_t, vuint16mf4_t, vuint16mf4_t, vuint16mf4_t, vuint16mf4_t, vuint16mf4_t, vuint16mf4_t, vuint16mf4_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vsoxseg8ei16_v_m)))
void vsoxseg8ei16(vbool64_t, uint16_t *, vuint16mf4_t, vuint16mf4_t, vuint16mf4_t, vuint16mf4_t, vuint16mf4_t, vuint16mf4_t, vuint16mf4_t, vuint16mf4_t, vuint16mf4_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vsoxseg2ei32_v)))
void vsoxseg2ei32(int16_t *, vuint32m2_t, vint16m1_t, vint16m1_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vsoxseg2ei32_v_m)))
void vsoxseg2ei32(vbool16_t, int16_t *, vuint32m2_t, vint16m1_t, vint16m1_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vsoxseg2ei32_v)))
void vsoxseg2ei32(int16_t *, vuint32m4_t, vint16m2_t, vint16m2_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vsoxseg2ei32_v_m)))
void vsoxseg2ei32(vbool8_t, int16_t *, vuint32m4_t, vint16m2_t, vint16m2_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vsoxseg2ei32_v)))
void vsoxseg2ei32(int16_t *, vuint32m8_t, vint16m4_t, vint16m4_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vsoxseg2ei32_v_m)))
void vsoxseg2ei32(vbool4_t, int16_t *, vuint32m8_t, vint16m4_t, vint16m4_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vsoxseg2ei32_v)))
void vsoxseg2ei32(int16_t *, vuint32m1_t, vint16mf2_t, vint16mf2_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vsoxseg2ei32_v_m)))
void vsoxseg2ei32(vbool32_t, int16_t *, vuint32m1_t, vint16mf2_t, vint16mf2_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vsoxseg2ei32_v)))
void vsoxseg2ei32(int16_t *, vuint32mf2_t, vint16mf4_t, vint16mf4_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vsoxseg2ei32_v_m)))
void vsoxseg2ei32(vbool64_t, int16_t *, vuint32mf2_t, vint16mf4_t, vint16mf4_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vsoxseg2ei32_v)))
void vsoxseg2ei32(uint16_t *, vuint32m2_t, vuint16m1_t, vuint16m1_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vsoxseg2ei32_v_m)))
void vsoxseg2ei32(vbool16_t, uint16_t *, vuint32m2_t, vuint16m1_t, vuint16m1_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vsoxseg2ei32_v)))
void vsoxseg2ei32(uint16_t *, vuint32m4_t, vuint16m2_t, vuint16m2_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vsoxseg2ei32_v_m)))
void vsoxseg2ei32(vbool8_t, uint16_t *, vuint32m4_t, vuint16m2_t, vuint16m2_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vsoxseg2ei32_v)))
void vsoxseg2ei32(uint16_t *, vuint32m8_t, vuint16m4_t, vuint16m4_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vsoxseg2ei32_v_m)))
void vsoxseg2ei32(vbool4_t, uint16_t *, vuint32m8_t, vuint16m4_t, vuint16m4_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vsoxseg2ei32_v)))
void vsoxseg2ei32(uint16_t *, vuint32m1_t, vuint16mf2_t, vuint16mf2_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vsoxseg2ei32_v_m)))
void vsoxseg2ei32(vbool32_t, uint16_t *, vuint32m1_t, vuint16mf2_t, vuint16mf2_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vsoxseg2ei32_v)))
void vsoxseg2ei32(uint16_t *, vuint32mf2_t, vuint16mf4_t, vuint16mf4_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vsoxseg2ei32_v_m)))
void vsoxseg2ei32(vbool64_t, uint16_t *, vuint32mf2_t, vuint16mf4_t, vuint16mf4_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vsoxseg3ei32_v)))
void vsoxseg3ei32(int16_t *, vuint32m2_t, vint16m1_t, vint16m1_t, vint16m1_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vsoxseg3ei32_v_m)))
void vsoxseg3ei32(vbool16_t, int16_t *, vuint32m2_t, vint16m1_t, vint16m1_t, vint16m1_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vsoxseg3ei32_v)))
void vsoxseg3ei32(int16_t *, vuint32m4_t, vint16m2_t, vint16m2_t, vint16m2_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vsoxseg3ei32_v_m)))
void vsoxseg3ei32(vbool8_t, int16_t *, vuint32m4_t, vint16m2_t, vint16m2_t, vint16m2_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vsoxseg3ei32_v)))
void vsoxseg3ei32(int16_t *, vuint32m1_t, vint16mf2_t, vint16mf2_t, vint16mf2_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vsoxseg3ei32_v_m)))
void vsoxseg3ei32(vbool32_t, int16_t *, vuint32m1_t, vint16mf2_t, vint16mf2_t, vint16mf2_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vsoxseg3ei32_v)))
void vsoxseg3ei32(int16_t *, vuint32mf2_t, vint16mf4_t, vint16mf4_t, vint16mf4_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vsoxseg3ei32_v_m)))
void vsoxseg3ei32(vbool64_t, int16_t *, vuint32mf2_t, vint16mf4_t, vint16mf4_t, vint16mf4_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vsoxseg3ei32_v)))
void vsoxseg3ei32(uint16_t *, vuint32m2_t, vuint16m1_t, vuint16m1_t, vuint16m1_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vsoxseg3ei32_v_m)))
void vsoxseg3ei32(vbool16_t, uint16_t *, vuint32m2_t, vuint16m1_t, vuint16m1_t, vuint16m1_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vsoxseg3ei32_v)))
void vsoxseg3ei32(uint16_t *, vuint32m4_t, vuint16m2_t, vuint16m2_t, vuint16m2_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vsoxseg3ei32_v_m)))
void vsoxseg3ei32(vbool8_t, uint16_t *, vuint32m4_t, vuint16m2_t, vuint16m2_t, vuint16m2_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vsoxseg3ei32_v)))
void vsoxseg3ei32(uint16_t *, vuint32m1_t, vuint16mf2_t, vuint16mf2_t, vuint16mf2_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vsoxseg3ei32_v_m)))
void vsoxseg3ei32(vbool32_t, uint16_t *, vuint32m1_t, vuint16mf2_t, vuint16mf2_t, vuint16mf2_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vsoxseg3ei32_v)))
void vsoxseg3ei32(uint16_t *, vuint32mf2_t, vuint16mf4_t, vuint16mf4_t, vuint16mf4_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vsoxseg3ei32_v_m)))
void vsoxseg3ei32(vbool64_t, uint16_t *, vuint32mf2_t, vuint16mf4_t, vuint16mf4_t, vuint16mf4_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vsoxseg4ei32_v)))
void vsoxseg4ei32(int16_t *, vuint32m2_t, vint16m1_t, vint16m1_t, vint16m1_t, vint16m1_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vsoxseg4ei32_v_m)))
void vsoxseg4ei32(vbool16_t, int16_t *, vuint32m2_t, vint16m1_t, vint16m1_t, vint16m1_t, vint16m1_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vsoxseg4ei32_v)))
void vsoxseg4ei32(int16_t *, vuint32m4_t, vint16m2_t, vint16m2_t, vint16m2_t, vint16m2_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vsoxseg4ei32_v_m)))
void vsoxseg4ei32(vbool8_t, int16_t *, vuint32m4_t, vint16m2_t, vint16m2_t, vint16m2_t, vint16m2_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vsoxseg4ei32_v)))
void vsoxseg4ei32(int16_t *, vuint32m1_t, vint16mf2_t, vint16mf2_t, vint16mf2_t, vint16mf2_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vsoxseg4ei32_v_m)))
void vsoxseg4ei32(vbool32_t, int16_t *, vuint32m1_t, vint16mf2_t, vint16mf2_t, vint16mf2_t, vint16mf2_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vsoxseg4ei32_v)))
void vsoxseg4ei32(int16_t *, vuint32mf2_t, vint16mf4_t, vint16mf4_t, vint16mf4_t, vint16mf4_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vsoxseg4ei32_v_m)))
void vsoxseg4ei32(vbool64_t, int16_t *, vuint32mf2_t, vint16mf4_t, vint16mf4_t, vint16mf4_t, vint16mf4_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vsoxseg4ei32_v)))
void vsoxseg4ei32(uint16_t *, vuint32m2_t, vuint16m1_t, vuint16m1_t, vuint16m1_t, vuint16m1_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vsoxseg4ei32_v_m)))
void vsoxseg4ei32(vbool16_t, uint16_t *, vuint32m2_t, vuint16m1_t, vuint16m1_t, vuint16m1_t, vuint16m1_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vsoxseg4ei32_v)))
void vsoxseg4ei32(uint16_t *, vuint32m4_t, vuint16m2_t, vuint16m2_t, vuint16m2_t, vuint16m2_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vsoxseg4ei32_v_m)))
void vsoxseg4ei32(vbool8_t, uint16_t *, vuint32m4_t, vuint16m2_t, vuint16m2_t, vuint16m2_t, vuint16m2_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vsoxseg4ei32_v)))
void vsoxseg4ei32(uint16_t *, vuint32m1_t, vuint16mf2_t, vuint16mf2_t, vuint16mf2_t, vuint16mf2_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vsoxseg4ei32_v_m)))
void vsoxseg4ei32(vbool32_t, uint16_t *, vuint32m1_t, vuint16mf2_t, vuint16mf2_t, vuint16mf2_t, vuint16mf2_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vsoxseg4ei32_v)))
void vsoxseg4ei32(uint16_t *, vuint32mf2_t, vuint16mf4_t, vuint16mf4_t, vuint16mf4_t, vuint16mf4_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vsoxseg4ei32_v_m)))
void vsoxseg4ei32(vbool64_t, uint16_t *, vuint32mf2_t, vuint16mf4_t, vuint16mf4_t, vuint16mf4_t, vuint16mf4_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vsoxseg5ei32_v)))
void vsoxseg5ei32(int16_t *, vuint32m2_t, vint16m1_t, vint16m1_t, vint16m1_t, vint16m1_t, vint16m1_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vsoxseg5ei32_v_m)))
void vsoxseg5ei32(vbool16_t, int16_t *, vuint32m2_t, vint16m1_t, vint16m1_t, vint16m1_t, vint16m1_t, vint16m1_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vsoxseg5ei32_v)))
void vsoxseg5ei32(int16_t *, vuint32m1_t, vint16mf2_t, vint16mf2_t, vint16mf2_t, vint16mf2_t, vint16mf2_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vsoxseg5ei32_v_m)))
void vsoxseg5ei32(vbool32_t, int16_t *, vuint32m1_t, vint16mf2_t, vint16mf2_t, vint16mf2_t, vint16mf2_t, vint16mf2_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vsoxseg5ei32_v)))
void vsoxseg5ei32(int16_t *, vuint32mf2_t, vint16mf4_t, vint16mf4_t, vint16mf4_t, vint16mf4_t, vint16mf4_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vsoxseg5ei32_v_m)))
void vsoxseg5ei32(vbool64_t, int16_t *, vuint32mf2_t, vint16mf4_t, vint16mf4_t, vint16mf4_t, vint16mf4_t, vint16mf4_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vsoxseg5ei32_v)))
void vsoxseg5ei32(uint16_t *, vuint32m2_t, vuint16m1_t, vuint16m1_t, vuint16m1_t, vuint16m1_t, vuint16m1_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vsoxseg5ei32_v_m)))
void vsoxseg5ei32(vbool16_t, uint16_t *, vuint32m2_t, vuint16m1_t, vuint16m1_t, vuint16m1_t, vuint16m1_t, vuint16m1_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vsoxseg5ei32_v)))
void vsoxseg5ei32(uint16_t *, vuint32m1_t, vuint16mf2_t, vuint16mf2_t, vuint16mf2_t, vuint16mf2_t, vuint16mf2_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vsoxseg5ei32_v_m)))
void vsoxseg5ei32(vbool32_t, uint16_t *, vuint32m1_t, vuint16mf2_t, vuint16mf2_t, vuint16mf2_t, vuint16mf2_t, vuint16mf2_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vsoxseg5ei32_v)))
void vsoxseg5ei32(uint16_t *, vuint32mf2_t, vuint16mf4_t, vuint16mf4_t, vuint16mf4_t, vuint16mf4_t, vuint16mf4_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vsoxseg5ei32_v_m)))
void vsoxseg5ei32(vbool64_t, uint16_t *, vuint32mf2_t, vuint16mf4_t, vuint16mf4_t, vuint16mf4_t, vuint16mf4_t, vuint16mf4_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vsoxseg6ei32_v)))
void vsoxseg6ei32(int16_t *, vuint32m2_t, vint16m1_t, vint16m1_t, vint16m1_t, vint16m1_t, vint16m1_t, vint16m1_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vsoxseg6ei32_v_m)))
void vsoxseg6ei32(vbool16_t, int16_t *, vuint32m2_t, vint16m1_t, vint16m1_t, vint16m1_t, vint16m1_t, vint16m1_t, vint16m1_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vsoxseg6ei32_v)))
void vsoxseg6ei32(int16_t *, vuint32m1_t, vint16mf2_t, vint16mf2_t, vint16mf2_t, vint16mf2_t, vint16mf2_t, vint16mf2_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vsoxseg6ei32_v_m)))
void vsoxseg6ei32(vbool32_t, int16_t *, vuint32m1_t, vint16mf2_t, vint16mf2_t, vint16mf2_t, vint16mf2_t, vint16mf2_t, vint16mf2_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vsoxseg6ei32_v)))
void vsoxseg6ei32(int16_t *, vuint32mf2_t, vint16mf4_t, vint16mf4_t, vint16mf4_t, vint16mf4_t, vint16mf4_t, vint16mf4_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vsoxseg6ei32_v_m)))
void vsoxseg6ei32(vbool64_t, int16_t *, vuint32mf2_t, vint16mf4_t, vint16mf4_t, vint16mf4_t, vint16mf4_t, vint16mf4_t, vint16mf4_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vsoxseg6ei32_v)))
void vsoxseg6ei32(uint16_t *, vuint32m2_t, vuint16m1_t, vuint16m1_t, vuint16m1_t, vuint16m1_t, vuint16m1_t, vuint16m1_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vsoxseg6ei32_v_m)))
void vsoxseg6ei32(vbool16_t, uint16_t *, vuint32m2_t, vuint16m1_t, vuint16m1_t, vuint16m1_t, vuint16m1_t, vuint16m1_t, vuint16m1_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vsoxseg6ei32_v)))
void vsoxseg6ei32(uint16_t *, vuint32m1_t, vuint16mf2_t, vuint16mf2_t, vuint16mf2_t, vuint16mf2_t, vuint16mf2_t, vuint16mf2_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vsoxseg6ei32_v_m)))
void vsoxseg6ei32(vbool32_t, uint16_t *, vuint32m1_t, vuint16mf2_t, vuint16mf2_t, vuint16mf2_t, vuint16mf2_t, vuint16mf2_t, vuint16mf2_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vsoxseg6ei32_v)))
void vsoxseg6ei32(uint16_t *, vuint32mf2_t, vuint16mf4_t, vuint16mf4_t, vuint16mf4_t, vuint16mf4_t, vuint16mf4_t, vuint16mf4_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vsoxseg6ei32_v_m)))
void vsoxseg6ei32(vbool64_t, uint16_t *, vuint32mf2_t, vuint16mf4_t, vuint16mf4_t, vuint16mf4_t, vuint16mf4_t, vuint16mf4_t, vuint16mf4_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vsoxseg7ei32_v)))
void vsoxseg7ei32(int16_t *, vuint32m2_t, vint16m1_t, vint16m1_t, vint16m1_t, vint16m1_t, vint16m1_t, vint16m1_t, vint16m1_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vsoxseg7ei32_v_m)))
void vsoxseg7ei32(vbool16_t, int16_t *, vuint32m2_t, vint16m1_t, vint16m1_t, vint16m1_t, vint16m1_t, vint16m1_t, vint16m1_t, vint16m1_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vsoxseg7ei32_v)))
void vsoxseg7ei32(int16_t *, vuint32m1_t, vint16mf2_t, vint16mf2_t, vint16mf2_t, vint16mf2_t, vint16mf2_t, vint16mf2_t, vint16mf2_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vsoxseg7ei32_v_m)))
void vsoxseg7ei32(vbool32_t, int16_t *, vuint32m1_t, vint16mf2_t, vint16mf2_t, vint16mf2_t, vint16mf2_t, vint16mf2_t, vint16mf2_t, vint16mf2_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vsoxseg7ei32_v)))
void vsoxseg7ei32(int16_t *, vuint32mf2_t, vint16mf4_t, vint16mf4_t, vint16mf4_t, vint16mf4_t, vint16mf4_t, vint16mf4_t, vint16mf4_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vsoxseg7ei32_v_m)))
void vsoxseg7ei32(vbool64_t, int16_t *, vuint32mf2_t, vint16mf4_t, vint16mf4_t, vint16mf4_t, vint16mf4_t, vint16mf4_t, vint16mf4_t, vint16mf4_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vsoxseg7ei32_v)))
void vsoxseg7ei32(uint16_t *, vuint32m2_t, vuint16m1_t, vuint16m1_t, vuint16m1_t, vuint16m1_t, vuint16m1_t, vuint16m1_t, vuint16m1_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vsoxseg7ei32_v_m)))
void vsoxseg7ei32(vbool16_t, uint16_t *, vuint32m2_t, vuint16m1_t, vuint16m1_t, vuint16m1_t, vuint16m1_t, vuint16m1_t, vuint16m1_t, vuint16m1_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vsoxseg7ei32_v)))
void vsoxseg7ei32(uint16_t *, vuint32m1_t, vuint16mf2_t, vuint16mf2_t, vuint16mf2_t, vuint16mf2_t, vuint16mf2_t, vuint16mf2_t, vuint16mf2_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vsoxseg7ei32_v_m)))
void vsoxseg7ei32(vbool32_t, uint16_t *, vuint32m1_t, vuint16mf2_t, vuint16mf2_t, vuint16mf2_t, vuint16mf2_t, vuint16mf2_t, vuint16mf2_t, vuint16mf2_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vsoxseg7ei32_v)))
void vsoxseg7ei32(uint16_t *, vuint32mf2_t, vuint16mf4_t, vuint16mf4_t, vuint16mf4_t, vuint16mf4_t, vuint16mf4_t, vuint16mf4_t, vuint16mf4_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vsoxseg7ei32_v_m)))
void vsoxseg7ei32(vbool64_t, uint16_t *, vuint32mf2_t, vuint16mf4_t, vuint16mf4_t, vuint16mf4_t, vuint16mf4_t, vuint16mf4_t, vuint16mf4_t, vuint16mf4_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vsoxseg8ei32_v)))
void vsoxseg8ei32(int16_t *, vuint32m2_t, vint16m1_t, vint16m1_t, vint16m1_t, vint16m1_t, vint16m1_t, vint16m1_t, vint16m1_t, vint16m1_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vsoxseg8ei32_v_m)))
void vsoxseg8ei32(vbool16_t, int16_t *, vuint32m2_t, vint16m1_t, vint16m1_t, vint16m1_t, vint16m1_t, vint16m1_t, vint16m1_t, vint16m1_t, vint16m1_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vsoxseg8ei32_v)))
void vsoxseg8ei32(int16_t *, vuint32m1_t, vint16mf2_t, vint16mf2_t, vint16mf2_t, vint16mf2_t, vint16mf2_t, vint16mf2_t, vint16mf2_t, vint16mf2_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vsoxseg8ei32_v_m)))
void vsoxseg8ei32(vbool32_t, int16_t *, vuint32m1_t, vint16mf2_t, vint16mf2_t, vint16mf2_t, vint16mf2_t, vint16mf2_t, vint16mf2_t, vint16mf2_t, vint16mf2_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vsoxseg8ei32_v)))
void vsoxseg8ei32(int16_t *, vuint32mf2_t, vint16mf4_t, vint16mf4_t, vint16mf4_t, vint16mf4_t, vint16mf4_t, vint16mf4_t, vint16mf4_t, vint16mf4_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vsoxseg8ei32_v_m)))
void vsoxseg8ei32(vbool64_t, int16_t *, vuint32mf2_t, vint16mf4_t, vint16mf4_t, vint16mf4_t, vint16mf4_t, vint16mf4_t, vint16mf4_t, vint16mf4_t, vint16mf4_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vsoxseg8ei32_v)))
void vsoxseg8ei32(uint16_t *, vuint32m2_t, vuint16m1_t, vuint16m1_t, vuint16m1_t, vuint16m1_t, vuint16m1_t, vuint16m1_t, vuint16m1_t, vuint16m1_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vsoxseg8ei32_v_m)))
void vsoxseg8ei32(vbool16_t, uint16_t *, vuint32m2_t, vuint16m1_t, vuint16m1_t, vuint16m1_t, vuint16m1_t, vuint16m1_t, vuint16m1_t, vuint16m1_t, vuint16m1_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vsoxseg8ei32_v)))
void vsoxseg8ei32(uint16_t *, vuint32m1_t, vuint16mf2_t, vuint16mf2_t, vuint16mf2_t, vuint16mf2_t, vuint16mf2_t, vuint16mf2_t, vuint16mf2_t, vuint16mf2_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vsoxseg8ei32_v_m)))
void vsoxseg8ei32(vbool32_t, uint16_t *, vuint32m1_t, vuint16mf2_t, vuint16mf2_t, vuint16mf2_t, vuint16mf2_t, vuint16mf2_t, vuint16mf2_t, vuint16mf2_t, vuint16mf2_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vsoxseg8ei32_v)))
void vsoxseg8ei32(uint16_t *, vuint32mf2_t, vuint16mf4_t, vuint16mf4_t, vuint16mf4_t, vuint16mf4_t, vuint16mf4_t, vuint16mf4_t, vuint16mf4_t, vuint16mf4_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vsoxseg8ei32_v_m)))
void vsoxseg8ei32(vbool64_t, uint16_t *, vuint32mf2_t, vuint16mf4_t, vuint16mf4_t, vuint16mf4_t, vuint16mf4_t, vuint16mf4_t, vuint16mf4_t, vuint16mf4_t, vuint16mf4_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vloxei8_v)))
vint32m1_t vloxei8(const int32_t *, vuint8mf4_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vloxei8_v_m)))
vint32m1_t vloxei8(vbool32_t, vint32m1_t, const int32_t *, vuint8mf4_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vloxei8_v)))
vint32m2_t vloxei8(const int32_t *, vuint8mf2_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vloxei8_v_m)))
vint32m2_t vloxei8(vbool16_t, vint32m2_t, const int32_t *, vuint8mf2_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vloxei8_v)))
vint32m4_t vloxei8(const int32_t *, vuint8m1_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vloxei8_v_m)))
vint32m4_t vloxei8(vbool8_t, vint32m4_t, const int32_t *, vuint8m1_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vloxei8_v)))
vint32m8_t vloxei8(const int32_t *, vuint8m2_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vloxei8_v_m)))
vint32m8_t vloxei8(vbool4_t, vint32m8_t, const int32_t *, vuint8m2_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vloxei8_v)))
vint32mf2_t vloxei8(const int32_t *, vuint8mf8_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vloxei8_v_m)))
vint32mf2_t vloxei8(vbool64_t, vint32mf2_t, const int32_t *, vuint8mf8_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vsoxseg2ei8_v)))
void vsoxseg2ei8(int32_t *, vuint8mf4_t, vint32m1_t, vint32m1_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vsoxseg2ei8_v_m)))
void vsoxseg2ei8(vbool32_t, int32_t *, vuint8mf4_t, vint32m1_t, vint32m1_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vsoxseg2ei8_v)))
void vsoxseg2ei8(int32_t *, vuint8mf2_t, vint32m2_t, vint32m2_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vsoxseg2ei8_v_m)))
void vsoxseg2ei8(vbool16_t, int32_t *, vuint8mf2_t, vint32m2_t, vint32m2_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vsoxseg2ei8_v)))
void vsoxseg2ei8(int32_t *, vuint8m1_t, vint32m4_t, vint32m4_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vsoxseg2ei8_v_m)))
void vsoxseg2ei8(vbool8_t, int32_t *, vuint8m1_t, vint32m4_t, vint32m4_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vsoxseg2ei8_v)))
void vsoxseg2ei8(int32_t *, vuint8mf8_t, vint32mf2_t, vint32mf2_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vsoxseg2ei8_v_m)))
void vsoxseg2ei8(vbool64_t, int32_t *, vuint8mf8_t, vint32mf2_t, vint32mf2_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vsoxseg2ei8_v)))
void vsoxseg2ei8(uint32_t *, vuint8mf4_t, vuint32m1_t, vuint32m1_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vsoxseg2ei8_v_m)))
void vsoxseg2ei8(vbool32_t, uint32_t *, vuint8mf4_t, vuint32m1_t, vuint32m1_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vsoxseg2ei8_v)))
void vsoxseg2ei8(uint32_t *, vuint8mf2_t, vuint32m2_t, vuint32m2_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vsoxseg2ei8_v_m)))
void vsoxseg2ei8(vbool16_t, uint32_t *, vuint8mf2_t, vuint32m2_t, vuint32m2_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vsoxseg2ei8_v)))
void vsoxseg2ei8(uint32_t *, vuint8m1_t, vuint32m4_t, vuint32m4_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vsoxseg2ei8_v_m)))
void vsoxseg2ei8(vbool8_t, uint32_t *, vuint8m1_t, vuint32m4_t, vuint32m4_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vsoxseg2ei8_v)))
void vsoxseg2ei8(uint32_t *, vuint8mf8_t, vuint32mf2_t, vuint32mf2_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vsoxseg2ei8_v_m)))
void vsoxseg2ei8(vbool64_t, uint32_t *, vuint8mf8_t, vuint32mf2_t, vuint32mf2_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vsoxseg3ei8_v)))
void vsoxseg3ei8(int32_t *, vuint8mf4_t, vint32m1_t, vint32m1_t, vint32m1_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vsoxseg3ei8_v_m)))
void vsoxseg3ei8(vbool32_t, int32_t *, vuint8mf4_t, vint32m1_t, vint32m1_t, vint32m1_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vsoxseg3ei8_v)))
void vsoxseg3ei8(int32_t *, vuint8mf2_t, vint32m2_t, vint32m2_t, vint32m2_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vsoxseg3ei8_v_m)))
void vsoxseg3ei8(vbool16_t, int32_t *, vuint8mf2_t, vint32m2_t, vint32m2_t, vint32m2_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vsoxseg3ei8_v)))
void vsoxseg3ei8(int32_t *, vuint8mf8_t, vint32mf2_t, vint32mf2_t, vint32mf2_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vsoxseg3ei8_v_m)))
void vsoxseg3ei8(vbool64_t, int32_t *, vuint8mf8_t, vint32mf2_t, vint32mf2_t, vint32mf2_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vsoxseg3ei8_v)))
void vsoxseg3ei8(uint32_t *, vuint8mf4_t, vuint32m1_t, vuint32m1_t, vuint32m1_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vsoxseg3ei8_v_m)))
void vsoxseg3ei8(vbool32_t, uint32_t *, vuint8mf4_t, vuint32m1_t, vuint32m1_t, vuint32m1_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vsoxseg3ei8_v)))
void vsoxseg3ei8(uint32_t *, vuint8mf2_t, vuint32m2_t, vuint32m2_t, vuint32m2_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vsoxseg3ei8_v_m)))
void vsoxseg3ei8(vbool16_t, uint32_t *, vuint8mf2_t, vuint32m2_t, vuint32m2_t, vuint32m2_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vsoxseg3ei8_v)))
void vsoxseg3ei8(uint32_t *, vuint8mf8_t, vuint32mf2_t, vuint32mf2_t, vuint32mf2_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vsoxseg3ei8_v_m)))
void vsoxseg3ei8(vbool64_t, uint32_t *, vuint8mf8_t, vuint32mf2_t, vuint32mf2_t, vuint32mf2_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vsoxseg4ei8_v)))
void vsoxseg4ei8(int32_t *, vuint8mf4_t, vint32m1_t, vint32m1_t, vint32m1_t, vint32m1_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vsoxseg4ei8_v_m)))
void vsoxseg4ei8(vbool32_t, int32_t *, vuint8mf4_t, vint32m1_t, vint32m1_t, vint32m1_t, vint32m1_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vsoxseg4ei8_v)))
void vsoxseg4ei8(int32_t *, vuint8mf2_t, vint32m2_t, vint32m2_t, vint32m2_t, vint32m2_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vsoxseg4ei8_v_m)))
void vsoxseg4ei8(vbool16_t, int32_t *, vuint8mf2_t, vint32m2_t, vint32m2_t, vint32m2_t, vint32m2_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vsoxseg4ei8_v)))
void vsoxseg4ei8(int32_t *, vuint8mf8_t, vint32mf2_t, vint32mf2_t, vint32mf2_t, vint32mf2_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vsoxseg4ei8_v_m)))
void vsoxseg4ei8(vbool64_t, int32_t *, vuint8mf8_t, vint32mf2_t, vint32mf2_t, vint32mf2_t, vint32mf2_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vsoxseg4ei8_v)))
void vsoxseg4ei8(uint32_t *, vuint8mf4_t, vuint32m1_t, vuint32m1_t, vuint32m1_t, vuint32m1_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vsoxseg4ei8_v_m)))
void vsoxseg4ei8(vbool32_t, uint32_t *, vuint8mf4_t, vuint32m1_t, vuint32m1_t, vuint32m1_t, vuint32m1_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vsoxseg4ei8_v)))
void vsoxseg4ei8(uint32_t *, vuint8mf2_t, vuint32m2_t, vuint32m2_t, vuint32m2_t, vuint32m2_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vsoxseg4ei8_v_m)))
void vsoxseg4ei8(vbool16_t, uint32_t *, vuint8mf2_t, vuint32m2_t, vuint32m2_t, vuint32m2_t, vuint32m2_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vsoxseg4ei8_v)))
void vsoxseg4ei8(uint32_t *, vuint8mf8_t, vuint32mf2_t, vuint32mf2_t, vuint32mf2_t, vuint32mf2_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vsoxseg4ei8_v_m)))
void vsoxseg4ei8(vbool64_t, uint32_t *, vuint8mf8_t, vuint32mf2_t, vuint32mf2_t, vuint32mf2_t, vuint32mf2_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vsoxseg5ei8_v)))
void vsoxseg5ei8(int32_t *, vuint8mf4_t, vint32m1_t, vint32m1_t, vint32m1_t, vint32m1_t, vint32m1_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vsoxseg5ei8_v_m)))
void vsoxseg5ei8(vbool32_t, int32_t *, vuint8mf4_t, vint32m1_t, vint32m1_t, vint32m1_t, vint32m1_t, vint32m1_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vsoxseg5ei8_v)))
void vsoxseg5ei8(int32_t *, vuint8mf8_t, vint32mf2_t, vint32mf2_t, vint32mf2_t, vint32mf2_t, vint32mf2_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vsoxseg5ei8_v_m)))
void vsoxseg5ei8(vbool64_t, int32_t *, vuint8mf8_t, vint32mf2_t, vint32mf2_t, vint32mf2_t, vint32mf2_t, vint32mf2_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vsoxseg5ei8_v)))
void vsoxseg5ei8(uint32_t *, vuint8mf4_t, vuint32m1_t, vuint32m1_t, vuint32m1_t, vuint32m1_t, vuint32m1_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vsoxseg5ei8_v_m)))
void vsoxseg5ei8(vbool32_t, uint32_t *, vuint8mf4_t, vuint32m1_t, vuint32m1_t, vuint32m1_t, vuint32m1_t, vuint32m1_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vsoxseg5ei8_v)))
void vsoxseg5ei8(uint32_t *, vuint8mf8_t, vuint32mf2_t, vuint32mf2_t, vuint32mf2_t, vuint32mf2_t, vuint32mf2_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vsoxseg5ei8_v_m)))
void vsoxseg5ei8(vbool64_t, uint32_t *, vuint8mf8_t, vuint32mf2_t, vuint32mf2_t, vuint32mf2_t, vuint32mf2_t, vuint32mf2_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vsoxseg6ei8_v)))
void vsoxseg6ei8(int32_t *, vuint8mf4_t, vint32m1_t, vint32m1_t, vint32m1_t, vint32m1_t, vint32m1_t, vint32m1_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vsoxseg6ei8_v_m)))
void vsoxseg6ei8(vbool32_t, int32_t *, vuint8mf4_t, vint32m1_t, vint32m1_t, vint32m1_t, vint32m1_t, vint32m1_t, vint32m1_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vsoxseg6ei8_v)))
void vsoxseg6ei8(int32_t *, vuint8mf8_t, vint32mf2_t, vint32mf2_t, vint32mf2_t, vint32mf2_t, vint32mf2_t, vint32mf2_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vsoxseg6ei8_v_m)))
void vsoxseg6ei8(vbool64_t, int32_t *, vuint8mf8_t, vint32mf2_t, vint32mf2_t, vint32mf2_t, vint32mf2_t, vint32mf2_t, vint32mf2_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vsoxseg6ei8_v)))
void vsoxseg6ei8(uint32_t *, vuint8mf4_t, vuint32m1_t, vuint32m1_t, vuint32m1_t, vuint32m1_t, vuint32m1_t, vuint32m1_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vsoxseg6ei8_v_m)))
void vsoxseg6ei8(vbool32_t, uint32_t *, vuint8mf4_t, vuint32m1_t, vuint32m1_t, vuint32m1_t, vuint32m1_t, vuint32m1_t, vuint32m1_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vsoxseg6ei8_v)))
void vsoxseg6ei8(uint32_t *, vuint8mf8_t, vuint32mf2_t, vuint32mf2_t, vuint32mf2_t, vuint32mf2_t, vuint32mf2_t, vuint32mf2_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vsoxseg6ei8_v_m)))
void vsoxseg6ei8(vbool64_t, uint32_t *, vuint8mf8_t, vuint32mf2_t, vuint32mf2_t, vuint32mf2_t, vuint32mf2_t, vuint32mf2_t, vuint32mf2_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vloxei8_v)))
vuint32m1_t vloxei8(const uint32_t *, vuint8mf4_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vloxei8_v_m)))
vuint32m1_t vloxei8(vbool32_t, vuint32m1_t, const uint32_t *, vuint8mf4_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vloxei8_v)))
vuint32m2_t vloxei8(const uint32_t *, vuint8mf2_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vloxei8_v_m)))
vuint32m2_t vloxei8(vbool16_t, vuint32m2_t, const uint32_t *, vuint8mf2_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vloxei8_v)))
vuint32m4_t vloxei8(const uint32_t *, vuint8m1_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vloxei8_v_m)))
vuint32m4_t vloxei8(vbool8_t, vuint32m4_t, const uint32_t *, vuint8m1_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vloxei8_v)))
vuint32m8_t vloxei8(const uint32_t *, vuint8m2_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vloxei8_v_m)))
vuint32m8_t vloxei8(vbool4_t, vuint32m8_t, const uint32_t *, vuint8m2_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vloxei8_v)))
vuint32mf2_t vloxei8(const uint32_t *, vuint8mf8_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vloxei8_v_m)))
vuint32mf2_t vloxei8(vbool64_t, vuint32mf2_t, const uint32_t *, vuint8mf8_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vsoxseg7ei8_v)))
void vsoxseg7ei8(int32_t *, vuint8mf4_t, vint32m1_t, vint32m1_t, vint32m1_t, vint32m1_t, vint32m1_t, vint32m1_t, vint32m1_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vsoxseg7ei8_v_m)))
void vsoxseg7ei8(vbool32_t, int32_t *, vuint8mf4_t, vint32m1_t, vint32m1_t, vint32m1_t, vint32m1_t, vint32m1_t, vint32m1_t, vint32m1_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vsoxseg7ei8_v)))
void vsoxseg7ei8(int32_t *, vuint8mf8_t, vint32mf2_t, vint32mf2_t, vint32mf2_t, vint32mf2_t, vint32mf2_t, vint32mf2_t, vint32mf2_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vsoxseg7ei8_v_m)))
void vsoxseg7ei8(vbool64_t, int32_t *, vuint8mf8_t, vint32mf2_t, vint32mf2_t, vint32mf2_t, vint32mf2_t, vint32mf2_t, vint32mf2_t, vint32mf2_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vsoxseg7ei8_v)))
void vsoxseg7ei8(uint32_t *, vuint8mf4_t, vuint32m1_t, vuint32m1_t, vuint32m1_t, vuint32m1_t, vuint32m1_t, vuint32m1_t, vuint32m1_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vsoxseg7ei8_v_m)))
void vsoxseg7ei8(vbool32_t, uint32_t *, vuint8mf4_t, vuint32m1_t, vuint32m1_t, vuint32m1_t, vuint32m1_t, vuint32m1_t, vuint32m1_t, vuint32m1_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vsoxseg7ei8_v)))
void vsoxseg7ei8(uint32_t *, vuint8mf8_t, vuint32mf2_t, vuint32mf2_t, vuint32mf2_t, vuint32mf2_t, vuint32mf2_t, vuint32mf2_t, vuint32mf2_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vsoxseg7ei8_v_m)))
void vsoxseg7ei8(vbool64_t, uint32_t *, vuint8mf8_t, vuint32mf2_t, vuint32mf2_t, vuint32mf2_t, vuint32mf2_t, vuint32mf2_t, vuint32mf2_t, vuint32mf2_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vsoxseg8ei8_v)))
void vsoxseg8ei8(int32_t *, vuint8mf4_t, vint32m1_t, vint32m1_t, vint32m1_t, vint32m1_t, vint32m1_t, vint32m1_t, vint32m1_t, vint32m1_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vsoxseg8ei8_v_m)))
void vsoxseg8ei8(vbool32_t, int32_t *, vuint8mf4_t, vint32m1_t, vint32m1_t, vint32m1_t, vint32m1_t, vint32m1_t, vint32m1_t, vint32m1_t, vint32m1_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vsoxseg8ei8_v)))
void vsoxseg8ei8(int32_t *, vuint8mf8_t, vint32mf2_t, vint32mf2_t, vint32mf2_t, vint32mf2_t, vint32mf2_t, vint32mf2_t, vint32mf2_t, vint32mf2_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vsoxseg8ei8_v_m)))
void vsoxseg8ei8(vbool64_t, int32_t *, vuint8mf8_t, vint32mf2_t, vint32mf2_t, vint32mf2_t, vint32mf2_t, vint32mf2_t, vint32mf2_t, vint32mf2_t, vint32mf2_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vsoxseg8ei8_v)))
void vsoxseg8ei8(uint32_t *, vuint8mf4_t, vuint32m1_t, vuint32m1_t, vuint32m1_t, vuint32m1_t, vuint32m1_t, vuint32m1_t, vuint32m1_t, vuint32m1_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vsoxseg8ei8_v_m)))
void vsoxseg8ei8(vbool32_t, uint32_t *, vuint8mf4_t, vuint32m1_t, vuint32m1_t, vuint32m1_t, vuint32m1_t, vuint32m1_t, vuint32m1_t, vuint32m1_t, vuint32m1_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vsoxseg8ei8_v)))
void vsoxseg8ei8(uint32_t *, vuint8mf8_t, vuint32mf2_t, vuint32mf2_t, vuint32mf2_t, vuint32mf2_t, vuint32mf2_t, vuint32mf2_t, vuint32mf2_t, vuint32mf2_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vsoxseg8ei8_v_m)))
void vsoxseg8ei8(vbool64_t, uint32_t *, vuint8mf8_t, vuint32mf2_t, vuint32mf2_t, vuint32mf2_t, vuint32mf2_t, vuint32mf2_t, vuint32mf2_t, vuint32mf2_t, vuint32mf2_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vsoxseg2ei16_v)))
void vsoxseg2ei16(int32_t *, vuint16mf2_t, vint32m1_t, vint32m1_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vsoxseg2ei16_v_m)))
void vsoxseg2ei16(vbool32_t, int32_t *, vuint16mf2_t, vint32m1_t, vint32m1_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vsoxseg2ei16_v)))
void vsoxseg2ei16(int32_t *, vuint16m1_t, vint32m2_t, vint32m2_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vsoxseg2ei16_v_m)))
void vsoxseg2ei16(vbool16_t, int32_t *, vuint16m1_t, vint32m2_t, vint32m2_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vsoxseg2ei16_v)))
void vsoxseg2ei16(int32_t *, vuint16m2_t, vint32m4_t, vint32m4_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vsoxseg2ei16_v_m)))
void vsoxseg2ei16(vbool8_t, int32_t *, vuint16m2_t, vint32m4_t, vint32m4_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vsoxseg2ei16_v)))
void vsoxseg2ei16(int32_t *, vuint16mf4_t, vint32mf2_t, vint32mf2_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vsoxseg2ei16_v_m)))
void vsoxseg2ei16(vbool64_t, int32_t *, vuint16mf4_t, vint32mf2_t, vint32mf2_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vsoxseg2ei16_v)))
void vsoxseg2ei16(uint32_t *, vuint16mf2_t, vuint32m1_t, vuint32m1_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vsoxseg2ei16_v_m)))
void vsoxseg2ei16(vbool32_t, uint32_t *, vuint16mf2_t, vuint32m1_t, vuint32m1_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vsoxseg2ei16_v)))
void vsoxseg2ei16(uint32_t *, vuint16m1_t, vuint32m2_t, vuint32m2_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vsoxseg2ei16_v_m)))
void vsoxseg2ei16(vbool16_t, uint32_t *, vuint16m1_t, vuint32m2_t, vuint32m2_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vsoxseg2ei16_v)))
void vsoxseg2ei16(uint32_t *, vuint16m2_t, vuint32m4_t, vuint32m4_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vsoxseg2ei16_v_m)))
void vsoxseg2ei16(vbool8_t, uint32_t *, vuint16m2_t, vuint32m4_t, vuint32m4_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vsoxseg2ei16_v)))
void vsoxseg2ei16(uint32_t *, vuint16mf4_t, vuint32mf2_t, vuint32mf2_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vsoxseg2ei16_v_m)))
void vsoxseg2ei16(vbool64_t, uint32_t *, vuint16mf4_t, vuint32mf2_t, vuint32mf2_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vsoxseg3ei16_v)))
void vsoxseg3ei16(int32_t *, vuint16mf2_t, vint32m1_t, vint32m1_t, vint32m1_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vsoxseg3ei16_v_m)))
void vsoxseg3ei16(vbool32_t, int32_t *, vuint16mf2_t, vint32m1_t, vint32m1_t, vint32m1_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vsoxseg3ei16_v)))
void vsoxseg3ei16(int32_t *, vuint16m1_t, vint32m2_t, vint32m2_t, vint32m2_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vsoxseg3ei16_v_m)))
void vsoxseg3ei16(vbool16_t, int32_t *, vuint16m1_t, vint32m2_t, vint32m2_t, vint32m2_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vsoxseg3ei16_v)))
void vsoxseg3ei16(int32_t *, vuint16mf4_t, vint32mf2_t, vint32mf2_t, vint32mf2_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vsoxseg3ei16_v_m)))
void vsoxseg3ei16(vbool64_t, int32_t *, vuint16mf4_t, vint32mf2_t, vint32mf2_t, vint32mf2_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vsoxseg3ei16_v)))
void vsoxseg3ei16(uint32_t *, vuint16mf2_t, vuint32m1_t, vuint32m1_t, vuint32m1_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vsoxseg3ei16_v_m)))
void vsoxseg3ei16(vbool32_t, uint32_t *, vuint16mf2_t, vuint32m1_t, vuint32m1_t, vuint32m1_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vsoxseg3ei16_v)))
void vsoxseg3ei16(uint32_t *, vuint16m1_t, vuint32m2_t, vuint32m2_t, vuint32m2_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vsoxseg3ei16_v_m)))
void vsoxseg3ei16(vbool16_t, uint32_t *, vuint16m1_t, vuint32m2_t, vuint32m2_t, vuint32m2_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vsoxseg3ei16_v)))
void vsoxseg3ei16(uint32_t *, vuint16mf4_t, vuint32mf2_t, vuint32mf2_t, vuint32mf2_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vsoxseg3ei16_v_m)))
void vsoxseg3ei16(vbool64_t, uint32_t *, vuint16mf4_t, vuint32mf2_t, vuint32mf2_t, vuint32mf2_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vsoxseg4ei16_v)))
void vsoxseg4ei16(int32_t *, vuint16mf2_t, vint32m1_t, vint32m1_t, vint32m1_t, vint32m1_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vsoxseg4ei16_v_m)))
void vsoxseg4ei16(vbool32_t, int32_t *, vuint16mf2_t, vint32m1_t, vint32m1_t, vint32m1_t, vint32m1_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vsoxseg4ei16_v)))
void vsoxseg4ei16(int32_t *, vuint16m1_t, vint32m2_t, vint32m2_t, vint32m2_t, vint32m2_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vsoxseg4ei16_v_m)))
void vsoxseg4ei16(vbool16_t, int32_t *, vuint16m1_t, vint32m2_t, vint32m2_t, vint32m2_t, vint32m2_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vsoxseg4ei16_v)))
void vsoxseg4ei16(int32_t *, vuint16mf4_t, vint32mf2_t, vint32mf2_t, vint32mf2_t, vint32mf2_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vsoxseg4ei16_v_m)))
void vsoxseg4ei16(vbool64_t, int32_t *, vuint16mf4_t, vint32mf2_t, vint32mf2_t, vint32mf2_t, vint32mf2_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vsoxseg4ei16_v)))
void vsoxseg4ei16(uint32_t *, vuint16mf2_t, vuint32m1_t, vuint32m1_t, vuint32m1_t, vuint32m1_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vsoxseg4ei16_v_m)))
void vsoxseg4ei16(vbool32_t, uint32_t *, vuint16mf2_t, vuint32m1_t, vuint32m1_t, vuint32m1_t, vuint32m1_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vsoxseg4ei16_v)))
void vsoxseg4ei16(uint32_t *, vuint16m1_t, vuint32m2_t, vuint32m2_t, vuint32m2_t, vuint32m2_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vsoxseg4ei16_v_m)))
void vsoxseg4ei16(vbool16_t, uint32_t *, vuint16m1_t, vuint32m2_t, vuint32m2_t, vuint32m2_t, vuint32m2_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vsoxseg4ei16_v)))
void vsoxseg4ei16(uint32_t *, vuint16mf4_t, vuint32mf2_t, vuint32mf2_t, vuint32mf2_t, vuint32mf2_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vsoxseg4ei16_v_m)))
void vsoxseg4ei16(vbool64_t, uint32_t *, vuint16mf4_t, vuint32mf2_t, vuint32mf2_t, vuint32mf2_t, vuint32mf2_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vloxei16_v)))
vint32m1_t vloxei16(const int32_t *, vuint16mf2_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vloxei16_v_m)))
vint32m1_t vloxei16(vbool32_t, vint32m1_t, const int32_t *, vuint16mf2_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vloxei16_v)))
vint32m2_t vloxei16(const int32_t *, vuint16m1_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vloxei16_v_m)))
vint32m2_t vloxei16(vbool16_t, vint32m2_t, const int32_t *, vuint16m1_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vloxei16_v)))
vint32m4_t vloxei16(const int32_t *, vuint16m2_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vloxei16_v_m)))
vint32m4_t vloxei16(vbool8_t, vint32m4_t, const int32_t *, vuint16m2_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vloxei16_v)))
vint32m8_t vloxei16(const int32_t *, vuint16m4_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vloxei16_v_m)))
vint32m8_t vloxei16(vbool4_t, vint32m8_t, const int32_t *, vuint16m4_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vloxei16_v)))
vint32mf2_t vloxei16(const int32_t *, vuint16mf4_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vloxei16_v_m)))
vint32mf2_t vloxei16(vbool64_t, vint32mf2_t, const int32_t *, vuint16mf4_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vsoxseg5ei16_v)))
void vsoxseg5ei16(int32_t *, vuint16mf2_t, vint32m1_t, vint32m1_t, vint32m1_t, vint32m1_t, vint32m1_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vsoxseg5ei16_v_m)))
void vsoxseg5ei16(vbool32_t, int32_t *, vuint16mf2_t, vint32m1_t, vint32m1_t, vint32m1_t, vint32m1_t, vint32m1_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vsoxseg5ei16_v)))
void vsoxseg5ei16(int32_t *, vuint16mf4_t, vint32mf2_t, vint32mf2_t, vint32mf2_t, vint32mf2_t, vint32mf2_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vsoxseg5ei16_v_m)))
void vsoxseg5ei16(vbool64_t, int32_t *, vuint16mf4_t, vint32mf2_t, vint32mf2_t, vint32mf2_t, vint32mf2_t, vint32mf2_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vsoxseg5ei16_v)))
void vsoxseg5ei16(uint32_t *, vuint16mf2_t, vuint32m1_t, vuint32m1_t, vuint32m1_t, vuint32m1_t, vuint32m1_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vsoxseg5ei16_v_m)))
void vsoxseg5ei16(vbool32_t, uint32_t *, vuint16mf2_t, vuint32m1_t, vuint32m1_t, vuint32m1_t, vuint32m1_t, vuint32m1_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vsoxseg5ei16_v)))
void vsoxseg5ei16(uint32_t *, vuint16mf4_t, vuint32mf2_t, vuint32mf2_t, vuint32mf2_t, vuint32mf2_t, vuint32mf2_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vsoxseg5ei16_v_m)))
void vsoxseg5ei16(vbool64_t, uint32_t *, vuint16mf4_t, vuint32mf2_t, vuint32mf2_t, vuint32mf2_t, vuint32mf2_t, vuint32mf2_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vsoxseg6ei16_v)))
void vsoxseg6ei16(int32_t *, vuint16mf2_t, vint32m1_t, vint32m1_t, vint32m1_t, vint32m1_t, vint32m1_t, vint32m1_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vsoxseg6ei16_v_m)))
void vsoxseg6ei16(vbool32_t, int32_t *, vuint16mf2_t, vint32m1_t, vint32m1_t, vint32m1_t, vint32m1_t, vint32m1_t, vint32m1_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vsoxseg6ei16_v)))
void vsoxseg6ei16(int32_t *, vuint16mf4_t, vint32mf2_t, vint32mf2_t, vint32mf2_t, vint32mf2_t, vint32mf2_t, vint32mf2_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vsoxseg6ei16_v_m)))
void vsoxseg6ei16(vbool64_t, int32_t *, vuint16mf4_t, vint32mf2_t, vint32mf2_t, vint32mf2_t, vint32mf2_t, vint32mf2_t, vint32mf2_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vsoxseg6ei16_v)))
void vsoxseg6ei16(uint32_t *, vuint16mf2_t, vuint32m1_t, vuint32m1_t, vuint32m1_t, vuint32m1_t, vuint32m1_t, vuint32m1_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vsoxseg6ei16_v_m)))
void vsoxseg6ei16(vbool32_t, uint32_t *, vuint16mf2_t, vuint32m1_t, vuint32m1_t, vuint32m1_t, vuint32m1_t, vuint32m1_t, vuint32m1_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vsoxseg6ei16_v)))
void vsoxseg6ei16(uint32_t *, vuint16mf4_t, vuint32mf2_t, vuint32mf2_t, vuint32mf2_t, vuint32mf2_t, vuint32mf2_t, vuint32mf2_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vsoxseg6ei16_v_m)))
void vsoxseg6ei16(vbool64_t, uint32_t *, vuint16mf4_t, vuint32mf2_t, vuint32mf2_t, vuint32mf2_t, vuint32mf2_t, vuint32mf2_t, vuint32mf2_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vsoxseg7ei16_v)))
void vsoxseg7ei16(int32_t *, vuint16mf2_t, vint32m1_t, vint32m1_t, vint32m1_t, vint32m1_t, vint32m1_t, vint32m1_t, vint32m1_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vsoxseg7ei16_v_m)))
void vsoxseg7ei16(vbool32_t, int32_t *, vuint16mf2_t, vint32m1_t, vint32m1_t, vint32m1_t, vint32m1_t, vint32m1_t, vint32m1_t, vint32m1_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vsoxseg7ei16_v)))
void vsoxseg7ei16(int32_t *, vuint16mf4_t, vint32mf2_t, vint32mf2_t, vint32mf2_t, vint32mf2_t, vint32mf2_t, vint32mf2_t, vint32mf2_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vsoxseg7ei16_v_m)))
void vsoxseg7ei16(vbool64_t, int32_t *, vuint16mf4_t, vint32mf2_t, vint32mf2_t, vint32mf2_t, vint32mf2_t, vint32mf2_t, vint32mf2_t, vint32mf2_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vsoxseg7ei16_v)))
void vsoxseg7ei16(uint32_t *, vuint16mf2_t, vuint32m1_t, vuint32m1_t, vuint32m1_t, vuint32m1_t, vuint32m1_t, vuint32m1_t, vuint32m1_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vsoxseg7ei16_v_m)))
void vsoxseg7ei16(vbool32_t, uint32_t *, vuint16mf2_t, vuint32m1_t, vuint32m1_t, vuint32m1_t, vuint32m1_t, vuint32m1_t, vuint32m1_t, vuint32m1_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vsoxseg7ei16_v)))
void vsoxseg7ei16(uint32_t *, vuint16mf4_t, vuint32mf2_t, vuint32mf2_t, vuint32mf2_t, vuint32mf2_t, vuint32mf2_t, vuint32mf2_t, vuint32mf2_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vsoxseg7ei16_v_m)))
void vsoxseg7ei16(vbool64_t, uint32_t *, vuint16mf4_t, vuint32mf2_t, vuint32mf2_t, vuint32mf2_t, vuint32mf2_t, vuint32mf2_t, vuint32mf2_t, vuint32mf2_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vsoxseg8ei16_v)))
void vsoxseg8ei16(int32_t *, vuint16mf2_t, vint32m1_t, vint32m1_t, vint32m1_t, vint32m1_t, vint32m1_t, vint32m1_t, vint32m1_t, vint32m1_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vsoxseg8ei16_v_m)))
void vsoxseg8ei16(vbool32_t, int32_t *, vuint16mf2_t, vint32m1_t, vint32m1_t, vint32m1_t, vint32m1_t, vint32m1_t, vint32m1_t, vint32m1_t, vint32m1_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vsoxseg8ei16_v)))
void vsoxseg8ei16(int32_t *, vuint16mf4_t, vint32mf2_t, vint32mf2_t, vint32mf2_t, vint32mf2_t, vint32mf2_t, vint32mf2_t, vint32mf2_t, vint32mf2_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vsoxseg8ei16_v_m)))
void vsoxseg8ei16(vbool64_t, int32_t *, vuint16mf4_t, vint32mf2_t, vint32mf2_t, vint32mf2_t, vint32mf2_t, vint32mf2_t, vint32mf2_t, vint32mf2_t, vint32mf2_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vsoxseg8ei16_v)))
void vsoxseg8ei16(uint32_t *, vuint16mf2_t, vuint32m1_t, vuint32m1_t, vuint32m1_t, vuint32m1_t, vuint32m1_t, vuint32m1_t, vuint32m1_t, vuint32m1_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vsoxseg8ei16_v_m)))
void vsoxseg8ei16(vbool32_t, uint32_t *, vuint16mf2_t, vuint32m1_t, vuint32m1_t, vuint32m1_t, vuint32m1_t, vuint32m1_t, vuint32m1_t, vuint32m1_t, vuint32m1_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vsoxseg8ei16_v)))
void vsoxseg8ei16(uint32_t *, vuint16mf4_t, vuint32mf2_t, vuint32mf2_t, vuint32mf2_t, vuint32mf2_t, vuint32mf2_t, vuint32mf2_t, vuint32mf2_t, vuint32mf2_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vsoxseg8ei16_v_m)))
void vsoxseg8ei16(vbool64_t, uint32_t *, vuint16mf4_t, vuint32mf2_t, vuint32mf2_t, vuint32mf2_t, vuint32mf2_t, vuint32mf2_t, vuint32mf2_t, vuint32mf2_t, vuint32mf2_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vsoxseg2ei32_v)))
void vsoxseg2ei32(int32_t *, vuint32m1_t, vint32m1_t, vint32m1_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vsoxseg2ei32_v_m)))
void vsoxseg2ei32(vbool32_t, int32_t *, vuint32m1_t, vint32m1_t, vint32m1_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vsoxseg2ei32_v)))
void vsoxseg2ei32(int32_t *, vuint32m2_t, vint32m2_t, vint32m2_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vsoxseg2ei32_v_m)))
void vsoxseg2ei32(vbool16_t, int32_t *, vuint32m2_t, vint32m2_t, vint32m2_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vsoxseg2ei32_v)))
void vsoxseg2ei32(int32_t *, vuint32m4_t, vint32m4_t, vint32m4_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vsoxseg2ei32_v_m)))
void vsoxseg2ei32(vbool8_t, int32_t *, vuint32m4_t, vint32m4_t, vint32m4_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vsoxseg2ei32_v)))
void vsoxseg2ei32(int32_t *, vuint32mf2_t, vint32mf2_t, vint32mf2_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vsoxseg2ei32_v_m)))
void vsoxseg2ei32(vbool64_t, int32_t *, vuint32mf2_t, vint32mf2_t, vint32mf2_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vsoxseg2ei32_v)))
void vsoxseg2ei32(uint32_t *, vuint32m1_t, vuint32m1_t, vuint32m1_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vsoxseg2ei32_v_m)))
void vsoxseg2ei32(vbool32_t, uint32_t *, vuint32m1_t, vuint32m1_t, vuint32m1_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vsoxseg2ei32_v)))
void vsoxseg2ei32(uint32_t *, vuint32m2_t, vuint32m2_t, vuint32m2_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vsoxseg2ei32_v_m)))
void vsoxseg2ei32(vbool16_t, uint32_t *, vuint32m2_t, vuint32m2_t, vuint32m2_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vsoxseg2ei32_v)))
void vsoxseg2ei32(uint32_t *, vuint32m4_t, vuint32m4_t, vuint32m4_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vsoxseg2ei32_v_m)))
void vsoxseg2ei32(vbool8_t, uint32_t *, vuint32m4_t, vuint32m4_t, vuint32m4_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vsoxseg2ei32_v)))
void vsoxseg2ei32(uint32_t *, vuint32mf2_t, vuint32mf2_t, vuint32mf2_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vsoxseg2ei32_v_m)))
void vsoxseg2ei32(vbool64_t, uint32_t *, vuint32mf2_t, vuint32mf2_t, vuint32mf2_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vloxei16_v)))
vuint32m1_t vloxei16(const uint32_t *, vuint16mf2_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vloxei16_v_m)))
vuint32m1_t vloxei16(vbool32_t, vuint32m1_t, const uint32_t *, vuint16mf2_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vloxei16_v)))
vuint32m2_t vloxei16(const uint32_t *, vuint16m1_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vloxei16_v_m)))
vuint32m2_t vloxei16(vbool16_t, vuint32m2_t, const uint32_t *, vuint16m1_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vloxei16_v)))
vuint32m4_t vloxei16(const uint32_t *, vuint16m2_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vloxei16_v_m)))
vuint32m4_t vloxei16(vbool8_t, vuint32m4_t, const uint32_t *, vuint16m2_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vloxei16_v)))
vuint32m8_t vloxei16(const uint32_t *, vuint16m4_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vloxei16_v_m)))
vuint32m8_t vloxei16(vbool4_t, vuint32m8_t, const uint32_t *, vuint16m4_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vloxei16_v)))
vuint32mf2_t vloxei16(const uint32_t *, vuint16mf4_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vloxei16_v_m)))
vuint32mf2_t vloxei16(vbool64_t, vuint32mf2_t, const uint32_t *, vuint16mf4_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vsoxseg3ei32_v)))
void vsoxseg3ei32(int32_t *, vuint32m1_t, vint32m1_t, vint32m1_t, vint32m1_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vsoxseg3ei32_v_m)))
void vsoxseg3ei32(vbool32_t, int32_t *, vuint32m1_t, vint32m1_t, vint32m1_t, vint32m1_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vsoxseg3ei32_v)))
void vsoxseg3ei32(int32_t *, vuint32m2_t, vint32m2_t, vint32m2_t, vint32m2_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vsoxseg3ei32_v_m)))
void vsoxseg3ei32(vbool16_t, int32_t *, vuint32m2_t, vint32m2_t, vint32m2_t, vint32m2_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vsoxseg3ei32_v)))
void vsoxseg3ei32(int32_t *, vuint32mf2_t, vint32mf2_t, vint32mf2_t, vint32mf2_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vsoxseg3ei32_v_m)))
void vsoxseg3ei32(vbool64_t, int32_t *, vuint32mf2_t, vint32mf2_t, vint32mf2_t, vint32mf2_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vsoxseg3ei32_v)))
void vsoxseg3ei32(uint32_t *, vuint32m1_t, vuint32m1_t, vuint32m1_t, vuint32m1_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vsoxseg3ei32_v_m)))
void vsoxseg3ei32(vbool32_t, uint32_t *, vuint32m1_t, vuint32m1_t, vuint32m1_t, vuint32m1_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vsoxseg3ei32_v)))
void vsoxseg3ei32(uint32_t *, vuint32m2_t, vuint32m2_t, vuint32m2_t, vuint32m2_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vsoxseg3ei32_v_m)))
void vsoxseg3ei32(vbool16_t, uint32_t *, vuint32m2_t, vuint32m2_t, vuint32m2_t, vuint32m2_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vsoxseg3ei32_v)))
void vsoxseg3ei32(uint32_t *, vuint32mf2_t, vuint32mf2_t, vuint32mf2_t, vuint32mf2_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vsoxseg3ei32_v_m)))
void vsoxseg3ei32(vbool64_t, uint32_t *, vuint32mf2_t, vuint32mf2_t, vuint32mf2_t, vuint32mf2_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vsoxseg4ei32_v)))
void vsoxseg4ei32(int32_t *, vuint32m1_t, vint32m1_t, vint32m1_t, vint32m1_t, vint32m1_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vsoxseg4ei32_v_m)))
void vsoxseg4ei32(vbool32_t, int32_t *, vuint32m1_t, vint32m1_t, vint32m1_t, vint32m1_t, vint32m1_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vsoxseg4ei32_v)))
void vsoxseg4ei32(int32_t *, vuint32m2_t, vint32m2_t, vint32m2_t, vint32m2_t, vint32m2_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vsoxseg4ei32_v_m)))
void vsoxseg4ei32(vbool16_t, int32_t *, vuint32m2_t, vint32m2_t, vint32m2_t, vint32m2_t, vint32m2_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vsoxseg4ei32_v)))
void vsoxseg4ei32(int32_t *, vuint32mf2_t, vint32mf2_t, vint32mf2_t, vint32mf2_t, vint32mf2_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vsoxseg4ei32_v_m)))
void vsoxseg4ei32(vbool64_t, int32_t *, vuint32mf2_t, vint32mf2_t, vint32mf2_t, vint32mf2_t, vint32mf2_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vsoxseg4ei32_v)))
void vsoxseg4ei32(uint32_t *, vuint32m1_t, vuint32m1_t, vuint32m1_t, vuint32m1_t, vuint32m1_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vsoxseg4ei32_v_m)))
void vsoxseg4ei32(vbool32_t, uint32_t *, vuint32m1_t, vuint32m1_t, vuint32m1_t, vuint32m1_t, vuint32m1_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vsoxseg4ei32_v)))
void vsoxseg4ei32(uint32_t *, vuint32m2_t, vuint32m2_t, vuint32m2_t, vuint32m2_t, vuint32m2_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vsoxseg4ei32_v_m)))
void vsoxseg4ei32(vbool16_t, uint32_t *, vuint32m2_t, vuint32m2_t, vuint32m2_t, vuint32m2_t, vuint32m2_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vsoxseg4ei32_v)))
void vsoxseg4ei32(uint32_t *, vuint32mf2_t, vuint32mf2_t, vuint32mf2_t, vuint32mf2_t, vuint32mf2_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vsoxseg4ei32_v_m)))
void vsoxseg4ei32(vbool64_t, uint32_t *, vuint32mf2_t, vuint32mf2_t, vuint32mf2_t, vuint32mf2_t, vuint32mf2_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vsoxseg5ei32_v)))
void vsoxseg5ei32(int32_t *, vuint32m1_t, vint32m1_t, vint32m1_t, vint32m1_t, vint32m1_t, vint32m1_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vsoxseg5ei32_v_m)))
void vsoxseg5ei32(vbool32_t, int32_t *, vuint32m1_t, vint32m1_t, vint32m1_t, vint32m1_t, vint32m1_t, vint32m1_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vsoxseg5ei32_v)))
void vsoxseg5ei32(int32_t *, vuint32mf2_t, vint32mf2_t, vint32mf2_t, vint32mf2_t, vint32mf2_t, vint32mf2_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vsoxseg5ei32_v_m)))
void vsoxseg5ei32(vbool64_t, int32_t *, vuint32mf2_t, vint32mf2_t, vint32mf2_t, vint32mf2_t, vint32mf2_t, vint32mf2_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vsoxseg5ei32_v)))
void vsoxseg5ei32(uint32_t *, vuint32m1_t, vuint32m1_t, vuint32m1_t, vuint32m1_t, vuint32m1_t, vuint32m1_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vsoxseg5ei32_v_m)))
void vsoxseg5ei32(vbool32_t, uint32_t *, vuint32m1_t, vuint32m1_t, vuint32m1_t, vuint32m1_t, vuint32m1_t, vuint32m1_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vsoxseg5ei32_v)))
void vsoxseg5ei32(uint32_t *, vuint32mf2_t, vuint32mf2_t, vuint32mf2_t, vuint32mf2_t, vuint32mf2_t, vuint32mf2_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vsoxseg5ei32_v_m)))
void vsoxseg5ei32(vbool64_t, uint32_t *, vuint32mf2_t, vuint32mf2_t, vuint32mf2_t, vuint32mf2_t, vuint32mf2_t, vuint32mf2_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vsoxseg6ei32_v)))
void vsoxseg6ei32(int32_t *, vuint32m1_t, vint32m1_t, vint32m1_t, vint32m1_t, vint32m1_t, vint32m1_t, vint32m1_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vsoxseg6ei32_v_m)))
void vsoxseg6ei32(vbool32_t, int32_t *, vuint32m1_t, vint32m1_t, vint32m1_t, vint32m1_t, vint32m1_t, vint32m1_t, vint32m1_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vsoxseg6ei32_v)))
void vsoxseg6ei32(int32_t *, vuint32mf2_t, vint32mf2_t, vint32mf2_t, vint32mf2_t, vint32mf2_t, vint32mf2_t, vint32mf2_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vsoxseg6ei32_v_m)))
void vsoxseg6ei32(vbool64_t, int32_t *, vuint32mf2_t, vint32mf2_t, vint32mf2_t, vint32mf2_t, vint32mf2_t, vint32mf2_t, vint32mf2_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vsoxseg6ei32_v)))
void vsoxseg6ei32(uint32_t *, vuint32m1_t, vuint32m1_t, vuint32m1_t, vuint32m1_t, vuint32m1_t, vuint32m1_t, vuint32m1_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vsoxseg6ei32_v_m)))
void vsoxseg6ei32(vbool32_t, uint32_t *, vuint32m1_t, vuint32m1_t, vuint32m1_t, vuint32m1_t, vuint32m1_t, vuint32m1_t, vuint32m1_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vsoxseg6ei32_v)))
void vsoxseg6ei32(uint32_t *, vuint32mf2_t, vuint32mf2_t, vuint32mf2_t, vuint32mf2_t, vuint32mf2_t, vuint32mf2_t, vuint32mf2_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vsoxseg6ei32_v_m)))
void vsoxseg6ei32(vbool64_t, uint32_t *, vuint32mf2_t, vuint32mf2_t, vuint32mf2_t, vuint32mf2_t, vuint32mf2_t, vuint32mf2_t, vuint32mf2_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vsoxseg7ei32_v)))
void vsoxseg7ei32(int32_t *, vuint32m1_t, vint32m1_t, vint32m1_t, vint32m1_t, vint32m1_t, vint32m1_t, vint32m1_t, vint32m1_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vsoxseg7ei32_v_m)))
void vsoxseg7ei32(vbool32_t, int32_t *, vuint32m1_t, vint32m1_t, vint32m1_t, vint32m1_t, vint32m1_t, vint32m1_t, vint32m1_t, vint32m1_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vsoxseg7ei32_v)))
void vsoxseg7ei32(int32_t *, vuint32mf2_t, vint32mf2_t, vint32mf2_t, vint32mf2_t, vint32mf2_t, vint32mf2_t, vint32mf2_t, vint32mf2_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vsoxseg7ei32_v_m)))
void vsoxseg7ei32(vbool64_t, int32_t *, vuint32mf2_t, vint32mf2_t, vint32mf2_t, vint32mf2_t, vint32mf2_t, vint32mf2_t, vint32mf2_t, vint32mf2_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vsoxseg7ei32_v)))
void vsoxseg7ei32(uint32_t *, vuint32m1_t, vuint32m1_t, vuint32m1_t, vuint32m1_t, vuint32m1_t, vuint32m1_t, vuint32m1_t, vuint32m1_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vsoxseg7ei32_v_m)))
void vsoxseg7ei32(vbool32_t, uint32_t *, vuint32m1_t, vuint32m1_t, vuint32m1_t, vuint32m1_t, vuint32m1_t, vuint32m1_t, vuint32m1_t, vuint32m1_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vsoxseg7ei32_v)))
void vsoxseg7ei32(uint32_t *, vuint32mf2_t, vuint32mf2_t, vuint32mf2_t, vuint32mf2_t, vuint32mf2_t, vuint32mf2_t, vuint32mf2_t, vuint32mf2_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vsoxseg7ei32_v_m)))
void vsoxseg7ei32(vbool64_t, uint32_t *, vuint32mf2_t, vuint32mf2_t, vuint32mf2_t, vuint32mf2_t, vuint32mf2_t, vuint32mf2_t, vuint32mf2_t, vuint32mf2_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vloxei32_v)))
vint32m1_t vloxei32(const int32_t *, vuint32m1_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vloxei32_v_m)))
vint32m1_t vloxei32(vbool32_t, vint32m1_t, const int32_t *, vuint32m1_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vloxei32_v)))
vint32m2_t vloxei32(const int32_t *, vuint32m2_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vloxei32_v_m)))
vint32m2_t vloxei32(vbool16_t, vint32m2_t, const int32_t *, vuint32m2_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vloxei32_v)))
vint32m4_t vloxei32(const int32_t *, vuint32m4_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vloxei32_v_m)))
vint32m4_t vloxei32(vbool8_t, vint32m4_t, const int32_t *, vuint32m4_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vloxei32_v)))
vint32m8_t vloxei32(const int32_t *, vuint32m8_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vloxei32_v_m)))
vint32m8_t vloxei32(vbool4_t, vint32m8_t, const int32_t *, vuint32m8_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vloxei32_v)))
vint32mf2_t vloxei32(const int32_t *, vuint32mf2_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vloxei32_v_m)))
vint32mf2_t vloxei32(vbool64_t, vint32mf2_t, const int32_t *, vuint32mf2_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vsoxseg8ei32_v)))
void vsoxseg8ei32(int32_t *, vuint32m1_t, vint32m1_t, vint32m1_t, vint32m1_t, vint32m1_t, vint32m1_t, vint32m1_t, vint32m1_t, vint32m1_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vsoxseg8ei32_v_m)))
void vsoxseg8ei32(vbool32_t, int32_t *, vuint32m1_t, vint32m1_t, vint32m1_t, vint32m1_t, vint32m1_t, vint32m1_t, vint32m1_t, vint32m1_t, vint32m1_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vsoxseg8ei32_v)))
void vsoxseg8ei32(int32_t *, vuint32mf2_t, vint32mf2_t, vint32mf2_t, vint32mf2_t, vint32mf2_t, vint32mf2_t, vint32mf2_t, vint32mf2_t, vint32mf2_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vsoxseg8ei32_v_m)))
void vsoxseg8ei32(vbool64_t, int32_t *, vuint32mf2_t, vint32mf2_t, vint32mf2_t, vint32mf2_t, vint32mf2_t, vint32mf2_t, vint32mf2_t, vint32mf2_t, vint32mf2_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vsoxseg8ei32_v)))
void vsoxseg8ei32(uint32_t *, vuint32m1_t, vuint32m1_t, vuint32m1_t, vuint32m1_t, vuint32m1_t, vuint32m1_t, vuint32m1_t, vuint32m1_t, vuint32m1_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vsoxseg8ei32_v_m)))
void vsoxseg8ei32(vbool32_t, uint32_t *, vuint32m1_t, vuint32m1_t, vuint32m1_t, vuint32m1_t, vuint32m1_t, vuint32m1_t, vuint32m1_t, vuint32m1_t, vuint32m1_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vsoxseg8ei32_v)))
void vsoxseg8ei32(uint32_t *, vuint32mf2_t, vuint32mf2_t, vuint32mf2_t, vuint32mf2_t, vuint32mf2_t, vuint32mf2_t, vuint32mf2_t, vuint32mf2_t, vuint32mf2_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vsoxseg8ei32_v_m)))
void vsoxseg8ei32(vbool64_t, uint32_t *, vuint32mf2_t, vuint32mf2_t, vuint32mf2_t, vuint32mf2_t, vuint32mf2_t, vuint32mf2_t, vuint32mf2_t, vuint32mf2_t, vuint32mf2_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vloxei32_v)))
vuint32m1_t vloxei32(const uint32_t *, vuint32m1_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vloxei32_v_m)))
vuint32m1_t vloxei32(vbool32_t, vuint32m1_t, const uint32_t *, vuint32m1_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vloxei32_v)))
vuint32m2_t vloxei32(const uint32_t *, vuint32m2_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vloxei32_v_m)))
vuint32m2_t vloxei32(vbool16_t, vuint32m2_t, const uint32_t *, vuint32m2_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vloxei32_v)))
vuint32m4_t vloxei32(const uint32_t *, vuint32m4_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vloxei32_v_m)))
vuint32m4_t vloxei32(vbool8_t, vuint32m4_t, const uint32_t *, vuint32m4_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vloxei32_v)))
vuint32m8_t vloxei32(const uint32_t *, vuint32m8_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vloxei32_v_m)))
vuint32m8_t vloxei32(vbool4_t, vuint32m8_t, const uint32_t *, vuint32m8_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vloxei32_v)))
vuint32mf2_t vloxei32(const uint32_t *, vuint32mf2_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vloxei32_v_m)))
vuint32mf2_t vloxei32(vbool64_t, vuint32mf2_t, const uint32_t *, vuint32mf2_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vadd_vx)))
vint8m1_t vadd(vint8m1_t, int8_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vadd_vx_m)))
vint8m1_t vadd(vbool8_t, vint8m1_t, vint8m1_t, int8_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vadd_vx)))
vint8m2_t vadd(vint8m2_t, int8_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vadd_vx_m)))
vint8m2_t vadd(vbool4_t, vint8m2_t, vint8m2_t, int8_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vadd_vx)))
vint8m4_t vadd(vint8m4_t, int8_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vadd_vx_m)))
vint8m4_t vadd(vbool2_t, vint8m4_t, vint8m4_t, int8_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vadd_vx)))
vint8m8_t vadd(vint8m8_t, int8_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vadd_vx_m)))
vint8m8_t vadd(vbool1_t, vint8m8_t, vint8m8_t, int8_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vadd_vx)))
vint8mf2_t vadd(vint8mf2_t, int8_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vadd_vx_m)))
vint8mf2_t vadd(vbool16_t, vint8mf2_t, vint8mf2_t, int8_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vadd_vx)))
vint8mf4_t vadd(vint8mf4_t, int8_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vadd_vx_m)))
vint8mf4_t vadd(vbool32_t, vint8mf4_t, vint8mf4_t, int8_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vadd_vx)))
vint8mf8_t vadd(vint8mf8_t, int8_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vadd_vx_m)))
vint8mf8_t vadd(vbool64_t, vint8mf8_t, vint8mf8_t, int8_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vadd_vx)))
vint16m1_t vadd(vint16m1_t, int16_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vadd_vx_m)))
vint16m1_t vadd(vbool16_t, vint16m1_t, vint16m1_t, int16_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vadd_vx)))
vint16m2_t vadd(vint16m2_t, int16_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vadd_vx_m)))
vint16m2_t vadd(vbool8_t, vint16m2_t, vint16m2_t, int16_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vadd_vx)))
vint16m4_t vadd(vint16m4_t, int16_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vadd_vx_m)))
vint16m4_t vadd(vbool4_t, vint16m4_t, vint16m4_t, int16_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vadd_vx)))
vint16m8_t vadd(vint16m8_t, int16_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vadd_vx_m)))
vint16m8_t vadd(vbool2_t, vint16m8_t, vint16m8_t, int16_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vadd_vx)))
vint16mf2_t vadd(vint16mf2_t, int16_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vadd_vx_m)))
vint16mf2_t vadd(vbool32_t, vint16mf2_t, vint16mf2_t, int16_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vadd_vx)))
vint16mf4_t vadd(vint16mf4_t, int16_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vadd_vx_m)))
vint16mf4_t vadd(vbool64_t, vint16mf4_t, vint16mf4_t, int16_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vadd_vx)))
vint32m1_t vadd(vint32m1_t, int32_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vadd_vx_m)))
vint32m1_t vadd(vbool32_t, vint32m1_t, vint32m1_t, int32_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vadd_vx)))
vint32m2_t vadd(vint32m2_t, int32_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vadd_vx_m)))
vint32m2_t vadd(vbool16_t, vint32m2_t, vint32m2_t, int32_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vadd_vx)))
vint32m4_t vadd(vint32m4_t, int32_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vadd_vx_m)))
vint32m4_t vadd(vbool8_t, vint32m4_t, vint32m4_t, int32_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vadd_vx)))
vint32m8_t vadd(vint32m8_t, int32_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vadd_vx_m)))
vint32m8_t vadd(vbool4_t, vint32m8_t, vint32m8_t, int32_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vadd_vx)))
vint32mf2_t vadd(vint32mf2_t, int32_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vadd_vx_m)))
vint32mf2_t vadd(vbool64_t, vint32mf2_t, vint32mf2_t, int32_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vadd_vv)))
vuint8m1_t vadd(vuint8m1_t, vuint8m1_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vadd_vv_m)))
vuint8m1_t vadd(vbool8_t, vuint8m1_t, vuint8m1_t, vuint8m1_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vadd_vv)))
vuint8m2_t vadd(vuint8m2_t, vuint8m2_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vadd_vv_m)))
vuint8m2_t vadd(vbool4_t, vuint8m2_t, vuint8m2_t, vuint8m2_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vadd_vv)))
vuint8m4_t vadd(vuint8m4_t, vuint8m4_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vadd_vv_m)))
vuint8m4_t vadd(vbool2_t, vuint8m4_t, vuint8m4_t, vuint8m4_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vadd_vv)))
vuint8m8_t vadd(vuint8m8_t, vuint8m8_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vadd_vv_m)))
vuint8m8_t vadd(vbool1_t, vuint8m8_t, vuint8m8_t, vuint8m8_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vadd_vv)))
vuint8mf2_t vadd(vuint8mf2_t, vuint8mf2_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vadd_vv_m)))
vuint8mf2_t vadd(vbool16_t, vuint8mf2_t, vuint8mf2_t, vuint8mf2_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vadd_vv)))
vuint8mf4_t vadd(vuint8mf4_t, vuint8mf4_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vadd_vv_m)))
vuint8mf4_t vadd(vbool32_t, vuint8mf4_t, vuint8mf4_t, vuint8mf4_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vadd_vv)))
vuint8mf8_t vadd(vuint8mf8_t, vuint8mf8_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vadd_vv_m)))
vuint8mf8_t vadd(vbool64_t, vuint8mf8_t, vuint8mf8_t, vuint8mf8_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vadd_vv)))
vuint16m1_t vadd(vuint16m1_t, vuint16m1_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vadd_vv_m)))
vuint16m1_t vadd(vbool16_t, vuint16m1_t, vuint16m1_t, vuint16m1_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vadd_vv)))
vuint16m2_t vadd(vuint16m2_t, vuint16m2_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vadd_vv_m)))
vuint16m2_t vadd(vbool8_t, vuint16m2_t, vuint16m2_t, vuint16m2_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vadd_vv)))
vuint16m4_t vadd(vuint16m4_t, vuint16m4_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vadd_vv_m)))
vuint16m4_t vadd(vbool4_t, vuint16m4_t, vuint16m4_t, vuint16m4_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vadd_vv)))
vuint16m8_t vadd(vuint16m8_t, vuint16m8_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vadd_vv_m)))
vuint16m8_t vadd(vbool2_t, vuint16m8_t, vuint16m8_t, vuint16m8_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vadd_vv)))
vuint16mf2_t vadd(vuint16mf2_t, vuint16mf2_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vadd_vv_m)))
vuint16mf2_t vadd(vbool32_t, vuint16mf2_t, vuint16mf2_t, vuint16mf2_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vadd_vv)))
vuint16mf4_t vadd(vuint16mf4_t, vuint16mf4_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vadd_vv_m)))
vuint16mf4_t vadd(vbool64_t, vuint16mf4_t, vuint16mf4_t, vuint16mf4_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vadd_vv)))
vuint32m1_t vadd(vuint32m1_t, vuint32m1_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vadd_vv_m)))
vuint32m1_t vadd(vbool32_t, vuint32m1_t, vuint32m1_t, vuint32m1_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vadd_vv)))
vuint32m2_t vadd(vuint32m2_t, vuint32m2_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vadd_vv_m)))
vuint32m2_t vadd(vbool16_t, vuint32m2_t, vuint32m2_t, vuint32m2_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vadd_vv)))
vuint32m4_t vadd(vuint32m4_t, vuint32m4_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vadd_vv_m)))
vuint32m4_t vadd(vbool8_t, vuint32m4_t, vuint32m4_t, vuint32m4_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vadd_vv)))
vuint32m8_t vadd(vuint32m8_t, vuint32m8_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vadd_vv_m)))
vuint32m8_t vadd(vbool4_t, vuint32m8_t, vuint32m8_t, vuint32m8_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vadd_vv)))
vuint32mf2_t vadd(vuint32mf2_t, vuint32mf2_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vadd_vv_m)))
vuint32mf2_t vadd(vbool64_t, vuint32mf2_t, vuint32mf2_t, vuint32mf2_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vadd_vx)))
vuint8m1_t vadd(vuint8m1_t, uint8_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vadd_vx_m)))
vuint8m1_t vadd(vbool8_t, vuint8m1_t, vuint8m1_t, uint8_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vadd_vx)))
vuint8m2_t vadd(vuint8m2_t, uint8_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vadd_vx_m)))
vuint8m2_t vadd(vbool4_t, vuint8m2_t, vuint8m2_t, uint8_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vadd_vx)))
vuint8m4_t vadd(vuint8m4_t, uint8_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vadd_vx_m)))
vuint8m4_t vadd(vbool2_t, vuint8m4_t, vuint8m4_t, uint8_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vadd_vx)))
vuint8m8_t vadd(vuint8m8_t, uint8_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vadd_vx_m)))
vuint8m8_t vadd(vbool1_t, vuint8m8_t, vuint8m8_t, uint8_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vadd_vx)))
vuint8mf2_t vadd(vuint8mf2_t, uint8_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vadd_vx_m)))
vuint8mf2_t vadd(vbool16_t, vuint8mf2_t, vuint8mf2_t, uint8_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vadd_vx)))
vuint8mf4_t vadd(vuint8mf4_t, uint8_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vadd_vx_m)))
vuint8mf4_t vadd(vbool32_t, vuint8mf4_t, vuint8mf4_t, uint8_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vadd_vx)))
vuint8mf8_t vadd(vuint8mf8_t, uint8_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vadd_vx_m)))
vuint8mf8_t vadd(vbool64_t, vuint8mf8_t, vuint8mf8_t, uint8_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vadd_vx)))
vuint16m1_t vadd(vuint16m1_t, uint16_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vadd_vx_m)))
vuint16m1_t vadd(vbool16_t, vuint16m1_t, vuint16m1_t, uint16_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vadd_vx)))
vuint16m2_t vadd(vuint16m2_t, uint16_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vadd_vx_m)))
vuint16m2_t vadd(vbool8_t, vuint16m2_t, vuint16m2_t, uint16_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vadd_vx)))
vuint16m4_t vadd(vuint16m4_t, uint16_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vadd_vx_m)))
vuint16m4_t vadd(vbool4_t, vuint16m4_t, vuint16m4_t, uint16_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vadd_vx)))
vuint16m8_t vadd(vuint16m8_t, uint16_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vadd_vx_m)))
vuint16m8_t vadd(vbool2_t, vuint16m8_t, vuint16m8_t, uint16_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vadd_vx)))
vuint16mf2_t vadd(vuint16mf2_t, uint16_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vadd_vx_m)))
vuint16mf2_t vadd(vbool32_t, vuint16mf2_t, vuint16mf2_t, uint16_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vadd_vx)))
vuint16mf4_t vadd(vuint16mf4_t, uint16_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vadd_vx_m)))
vuint16mf4_t vadd(vbool64_t, vuint16mf4_t, vuint16mf4_t, uint16_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vadd_vx)))
vuint32m1_t vadd(vuint32m1_t, uint32_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vadd_vx_m)))
vuint32m1_t vadd(vbool32_t, vuint32m1_t, vuint32m1_t, uint32_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vadd_vx)))
vuint32m2_t vadd(vuint32m2_t, uint32_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vadd_vx_m)))
vuint32m2_t vadd(vbool16_t, vuint32m2_t, vuint32m2_t, uint32_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vadd_vx)))
vuint32m4_t vadd(vuint32m4_t, uint32_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vadd_vx_m)))
vuint32m4_t vadd(vbool8_t, vuint32m4_t, vuint32m4_t, uint32_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vadd_vx)))
vuint32m8_t vadd(vuint32m8_t, uint32_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vadd_vx_m)))
vuint32m8_t vadd(vbool4_t, vuint32m8_t, vuint32m8_t, uint32_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vadd_vx)))
vuint32mf2_t vadd(vuint32mf2_t, uint32_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vadd_vx_m)))
vuint32mf2_t vadd(vbool64_t, vuint32mf2_t, vuint32mf2_t, uint32_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vsub_vv)))
vint8m1_t vsub(vint8m1_t, vint8m1_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vsub_vv_m)))
vint8m1_t vsub(vbool8_t, vint8m1_t, vint8m1_t, vint8m1_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vsub_vv)))
vint8m2_t vsub(vint8m2_t, vint8m2_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vsub_vv_m)))
vint8m2_t vsub(vbool4_t, vint8m2_t, vint8m2_t, vint8m2_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vsub_vv)))
vint8m4_t vsub(vint8m4_t, vint8m4_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vsub_vv_m)))
vint8m4_t vsub(vbool2_t, vint8m4_t, vint8m4_t, vint8m4_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vsub_vv)))
vint8m8_t vsub(vint8m8_t, vint8m8_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vsub_vv_m)))
vint8m8_t vsub(vbool1_t, vint8m8_t, vint8m8_t, vint8m8_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vsub_vv)))
vint8mf2_t vsub(vint8mf2_t, vint8mf2_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vsub_vv_m)))
vint8mf2_t vsub(vbool16_t, vint8mf2_t, vint8mf2_t, vint8mf2_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vsub_vv)))
vint8mf4_t vsub(vint8mf4_t, vint8mf4_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vsub_vv_m)))
vint8mf4_t vsub(vbool32_t, vint8mf4_t, vint8mf4_t, vint8mf4_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vsub_vv)))
vint8mf8_t vsub(vint8mf8_t, vint8mf8_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vsub_vv_m)))
vint8mf8_t vsub(vbool64_t, vint8mf8_t, vint8mf8_t, vint8mf8_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vsub_vv)))
vint16m1_t vsub(vint16m1_t, vint16m1_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vsub_vv_m)))
vint16m1_t vsub(vbool16_t, vint16m1_t, vint16m1_t, vint16m1_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vsub_vv)))
vint16m2_t vsub(vint16m2_t, vint16m2_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vsub_vv_m)))
vint16m2_t vsub(vbool8_t, vint16m2_t, vint16m2_t, vint16m2_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vsub_vv)))
vint16m4_t vsub(vint16m4_t, vint16m4_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vsub_vv_m)))
vint16m4_t vsub(vbool4_t, vint16m4_t, vint16m4_t, vint16m4_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vsub_vv)))
vint16m8_t vsub(vint16m8_t, vint16m8_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vsub_vv_m)))
vint16m8_t vsub(vbool2_t, vint16m8_t, vint16m8_t, vint16m8_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vsub_vv)))
vint16mf2_t vsub(vint16mf2_t, vint16mf2_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vsub_vv_m)))
vint16mf2_t vsub(vbool32_t, vint16mf2_t, vint16mf2_t, vint16mf2_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vsub_vv)))
vint16mf4_t vsub(vint16mf4_t, vint16mf4_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vsub_vv_m)))
vint16mf4_t vsub(vbool64_t, vint16mf4_t, vint16mf4_t, vint16mf4_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vsub_vv)))
vint32m1_t vsub(vint32m1_t, vint32m1_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vsub_vv_m)))
vint32m1_t vsub(vbool32_t, vint32m1_t, vint32m1_t, vint32m1_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vsub_vv)))
vint32m2_t vsub(vint32m2_t, vint32m2_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vsub_vv_m)))
vint32m2_t vsub(vbool16_t, vint32m2_t, vint32m2_t, vint32m2_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vsub_vv)))
vint32m4_t vsub(vint32m4_t, vint32m4_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vsub_vv_m)))
vint32m4_t vsub(vbool8_t, vint32m4_t, vint32m4_t, vint32m4_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vsub_vv)))
vint32m8_t vsub(vint32m8_t, vint32m8_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vsub_vv_m)))
vint32m8_t vsub(vbool4_t, vint32m8_t, vint32m8_t, vint32m8_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vsub_vv)))
vint32mf2_t vsub(vint32mf2_t, vint32mf2_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vsub_vv_m)))
vint32mf2_t vsub(vbool64_t, vint32mf2_t, vint32mf2_t, vint32mf2_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vsub_vx)))
vint8m1_t vsub(vint8m1_t, int8_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vsub_vx_m)))
vint8m1_t vsub(vbool8_t, vint8m1_t, vint8m1_t, int8_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vsub_vx)))
vint8m2_t vsub(vint8m2_t, int8_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vsub_vx_m)))
vint8m2_t vsub(vbool4_t, vint8m2_t, vint8m2_t, int8_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vsub_vx)))
vint8m4_t vsub(vint8m4_t, int8_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vsub_vx_m)))
vint8m4_t vsub(vbool2_t, vint8m4_t, vint8m4_t, int8_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vsub_vx)))
vint8m8_t vsub(vint8m8_t, int8_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vsub_vx_m)))
vint8m8_t vsub(vbool1_t, vint8m8_t, vint8m8_t, int8_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vsub_vx)))
vint8mf2_t vsub(vint8mf2_t, int8_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vsub_vx_m)))
vint8mf2_t vsub(vbool16_t, vint8mf2_t, vint8mf2_t, int8_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vsub_vx)))
vint8mf4_t vsub(vint8mf4_t, int8_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vsub_vx_m)))
vint8mf4_t vsub(vbool32_t, vint8mf4_t, vint8mf4_t, int8_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vsub_vx)))
vint8mf8_t vsub(vint8mf8_t, int8_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vsub_vx_m)))
vint8mf8_t vsub(vbool64_t, vint8mf8_t, vint8mf8_t, int8_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vsub_vx)))
vint16m1_t vsub(vint16m1_t, int16_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vsub_vx_m)))
vint16m1_t vsub(vbool16_t, vint16m1_t, vint16m1_t, int16_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vsub_vx)))
vint16m2_t vsub(vint16m2_t, int16_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vsub_vx_m)))
vint16m2_t vsub(vbool8_t, vint16m2_t, vint16m2_t, int16_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vsub_vx)))
vint16m4_t vsub(vint16m4_t, int16_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vsub_vx_m)))
vint16m4_t vsub(vbool4_t, vint16m4_t, vint16m4_t, int16_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vsub_vx)))
vint16m8_t vsub(vint16m8_t, int16_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vsub_vx_m)))
vint16m8_t vsub(vbool2_t, vint16m8_t, vint16m8_t, int16_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vsub_vx)))
vint16mf2_t vsub(vint16mf2_t, int16_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vsub_vx_m)))
vint16mf2_t vsub(vbool32_t, vint16mf2_t, vint16mf2_t, int16_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vsub_vx)))
vint16mf4_t vsub(vint16mf4_t, int16_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vsub_vx_m)))
vint16mf4_t vsub(vbool64_t, vint16mf4_t, vint16mf4_t, int16_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vsub_vx)))
vint32m1_t vsub(vint32m1_t, int32_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vsub_vx_m)))
vint32m1_t vsub(vbool32_t, vint32m1_t, vint32m1_t, int32_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vsub_vx)))
vint32m2_t vsub(vint32m2_t, int32_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vsub_vx_m)))
vint32m2_t vsub(vbool16_t, vint32m2_t, vint32m2_t, int32_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vsub_vx)))
vint32m4_t vsub(vint32m4_t, int32_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vsub_vx_m)))
vint32m4_t vsub(vbool8_t, vint32m4_t, vint32m4_t, int32_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vsub_vx)))
vint32m8_t vsub(vint32m8_t, int32_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vsub_vx_m)))
vint32m8_t vsub(vbool4_t, vint32m8_t, vint32m8_t, int32_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vsub_vx)))
vint32mf2_t vsub(vint32mf2_t, int32_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vsub_vx_m)))
vint32mf2_t vsub(vbool64_t, vint32mf2_t, vint32mf2_t, int32_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vsub_vv)))
vuint8m1_t vsub(vuint8m1_t, vuint8m1_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vsub_vv_m)))
vuint8m1_t vsub(vbool8_t, vuint8m1_t, vuint8m1_t, vuint8m1_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vsub_vv)))
vuint8m2_t vsub(vuint8m2_t, vuint8m2_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vsub_vv_m)))
vuint8m2_t vsub(vbool4_t, vuint8m2_t, vuint8m2_t, vuint8m2_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vsub_vv)))
vuint8m4_t vsub(vuint8m4_t, vuint8m4_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vsub_vv_m)))
vuint8m4_t vsub(vbool2_t, vuint8m4_t, vuint8m4_t, vuint8m4_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vsub_vv)))
vuint8m8_t vsub(vuint8m8_t, vuint8m8_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vsub_vv_m)))
vuint8m8_t vsub(vbool1_t, vuint8m8_t, vuint8m8_t, vuint8m8_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vsub_vv)))
vuint8mf2_t vsub(vuint8mf2_t, vuint8mf2_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vsub_vv_m)))
vuint8mf2_t vsub(vbool16_t, vuint8mf2_t, vuint8mf2_t, vuint8mf2_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vsub_vv)))
vuint8mf4_t vsub(vuint8mf4_t, vuint8mf4_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vsub_vv_m)))
vuint8mf4_t vsub(vbool32_t, vuint8mf4_t, vuint8mf4_t, vuint8mf4_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vsub_vv)))
vuint8mf8_t vsub(vuint8mf8_t, vuint8mf8_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vsub_vv_m)))
vuint8mf8_t vsub(vbool64_t, vuint8mf8_t, vuint8mf8_t, vuint8mf8_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vsub_vv)))
vuint16m1_t vsub(vuint16m1_t, vuint16m1_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vsub_vv_m)))
vuint16m1_t vsub(vbool16_t, vuint16m1_t, vuint16m1_t, vuint16m1_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vsub_vv)))
vuint16m2_t vsub(vuint16m2_t, vuint16m2_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vsub_vv_m)))
vuint16m2_t vsub(vbool8_t, vuint16m2_t, vuint16m2_t, vuint16m2_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vsub_vv)))
vuint16m4_t vsub(vuint16m4_t, vuint16m4_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vsub_vv_m)))
vuint16m4_t vsub(vbool4_t, vuint16m4_t, vuint16m4_t, vuint16m4_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vsub_vv)))
vuint16m8_t vsub(vuint16m8_t, vuint16m8_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vsub_vv_m)))
vuint16m8_t vsub(vbool2_t, vuint16m8_t, vuint16m8_t, vuint16m8_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vsub_vv)))
vuint16mf2_t vsub(vuint16mf2_t, vuint16mf2_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vsub_vv_m)))
vuint16mf2_t vsub(vbool32_t, vuint16mf2_t, vuint16mf2_t, vuint16mf2_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vsub_vv)))
vuint16mf4_t vsub(vuint16mf4_t, vuint16mf4_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vsub_vv_m)))
vuint16mf4_t vsub(vbool64_t, vuint16mf4_t, vuint16mf4_t, vuint16mf4_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vsub_vv)))
vuint32m1_t vsub(vuint32m1_t, vuint32m1_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vsub_vv_m)))
vuint32m1_t vsub(vbool32_t, vuint32m1_t, vuint32m1_t, vuint32m1_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vsub_vv)))
vuint32m2_t vsub(vuint32m2_t, vuint32m2_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vsub_vv_m)))
vuint32m2_t vsub(vbool16_t, vuint32m2_t, vuint32m2_t, vuint32m2_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vsub_vv)))
vuint32m4_t vsub(vuint32m4_t, vuint32m4_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vsub_vv_m)))
vuint32m4_t vsub(vbool8_t, vuint32m4_t, vuint32m4_t, vuint32m4_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vsub_vv)))
vuint32m8_t vsub(vuint32m8_t, vuint32m8_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vsub_vv_m)))
vuint32m8_t vsub(vbool4_t, vuint32m8_t, vuint32m8_t, vuint32m8_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vsub_vv)))
vuint32mf2_t vsub(vuint32mf2_t, vuint32mf2_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vsub_vv_m)))
vuint32mf2_t vsub(vbool64_t, vuint32mf2_t, vuint32mf2_t, vuint32mf2_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vsub_vx)))
vuint8m1_t vsub(vuint8m1_t, uint8_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vsub_vx_m)))
vuint8m1_t vsub(vbool8_t, vuint8m1_t, vuint8m1_t, uint8_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vsub_vx)))
vuint8m2_t vsub(vuint8m2_t, uint8_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vsub_vx_m)))
vuint8m2_t vsub(vbool4_t, vuint8m2_t, vuint8m2_t, uint8_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vsub_vx)))
vuint8m4_t vsub(vuint8m4_t, uint8_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vsub_vx_m)))
vuint8m4_t vsub(vbool2_t, vuint8m4_t, vuint8m4_t, uint8_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vsub_vx)))
vuint8m8_t vsub(vuint8m8_t, uint8_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vsub_vx_m)))
vuint8m8_t vsub(vbool1_t, vuint8m8_t, vuint8m8_t, uint8_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vsub_vx)))
vuint8mf2_t vsub(vuint8mf2_t, uint8_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vsub_vx_m)))
vuint8mf2_t vsub(vbool16_t, vuint8mf2_t, vuint8mf2_t, uint8_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vsub_vx)))
vuint8mf4_t vsub(vuint8mf4_t, uint8_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vsub_vx_m)))
vuint8mf4_t vsub(vbool32_t, vuint8mf4_t, vuint8mf4_t, uint8_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vsub_vx)))
vuint8mf8_t vsub(vuint8mf8_t, uint8_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vsub_vx_m)))
vuint8mf8_t vsub(vbool64_t, vuint8mf8_t, vuint8mf8_t, uint8_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vsub_vx)))
vuint16m1_t vsub(vuint16m1_t, uint16_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vsub_vx_m)))
vuint16m1_t vsub(vbool16_t, vuint16m1_t, vuint16m1_t, uint16_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vsub_vx)))
vuint16m2_t vsub(vuint16m2_t, uint16_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vsub_vx_m)))
vuint16m2_t vsub(vbool8_t, vuint16m2_t, vuint16m2_t, uint16_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vsub_vx)))
vuint16m4_t vsub(vuint16m4_t, uint16_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vsub_vx_m)))
vuint16m4_t vsub(vbool4_t, vuint16m4_t, vuint16m4_t, uint16_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vsub_vx)))
vuint16m8_t vsub(vuint16m8_t, uint16_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vsub_vx_m)))
vuint16m8_t vsub(vbool2_t, vuint16m8_t, vuint16m8_t, uint16_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vsub_vx)))
vuint16mf2_t vsub(vuint16mf2_t, uint16_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vsub_vx_m)))
vuint16mf2_t vsub(vbool32_t, vuint16mf2_t, vuint16mf2_t, uint16_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vsub_vx)))
vuint16mf4_t vsub(vuint16mf4_t, uint16_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vsub_vx_m)))
vuint16mf4_t vsub(vbool64_t, vuint16mf4_t, vuint16mf4_t, uint16_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vsub_vx)))
vuint32m1_t vsub(vuint32m1_t, uint32_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vsub_vx_m)))
vuint32m1_t vsub(vbool32_t, vuint32m1_t, vuint32m1_t, uint32_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vsub_vx)))
vuint32m2_t vsub(vuint32m2_t, uint32_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vsub_vx_m)))
vuint32m2_t vsub(vbool16_t, vuint32m2_t, vuint32m2_t, uint32_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vsub_vx)))
vuint32m4_t vsub(vuint32m4_t, uint32_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vsub_vx_m)))
vuint32m4_t vsub(vbool8_t, vuint32m4_t, vuint32m4_t, uint32_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vsub_vx)))
vuint32m8_t vsub(vuint32m8_t, uint32_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vsub_vx_m)))
vuint32m8_t vsub(vbool4_t, vuint32m8_t, vuint32m8_t, uint32_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vsub_vx)))
vuint32mf2_t vsub(vuint32mf2_t, uint32_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vsub_vx_m)))
vuint32mf2_t vsub(vbool64_t, vuint32mf2_t, vuint32mf2_t, uint32_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vrsub_vx)))
vint8m1_t vrsub(vint8m1_t, int8_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vrsub_vx_m)))
vint8m1_t vrsub(vbool8_t, vint8m1_t, vint8m1_t, int8_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vrsub_vx)))
vint8m2_t vrsub(vint8m2_t, int8_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vrsub_vx_m)))
vint8m2_t vrsub(vbool4_t, vint8m2_t, vint8m2_t, int8_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vrsub_vx)))
vint8m4_t vrsub(vint8m4_t, int8_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vrsub_vx_m)))
vint8m4_t vrsub(vbool2_t, vint8m4_t, vint8m4_t, int8_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vrsub_vx)))
vint8m8_t vrsub(vint8m8_t, int8_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vrsub_vx_m)))
vint8m8_t vrsub(vbool1_t, vint8m8_t, vint8m8_t, int8_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vrsub_vx)))
vint8mf2_t vrsub(vint8mf2_t, int8_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vrsub_vx_m)))
vint8mf2_t vrsub(vbool16_t, vint8mf2_t, vint8mf2_t, int8_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vrsub_vx)))
vint8mf4_t vrsub(vint8mf4_t, int8_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vrsub_vx_m)))
vint8mf4_t vrsub(vbool32_t, vint8mf4_t, vint8mf4_t, int8_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vrsub_vx)))
vint8mf8_t vrsub(vint8mf8_t, int8_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vrsub_vx_m)))
vint8mf8_t vrsub(vbool64_t, vint8mf8_t, vint8mf8_t, int8_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vrsub_vx)))
vint16m1_t vrsub(vint16m1_t, int16_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vrsub_vx_m)))
vint16m1_t vrsub(vbool16_t, vint16m1_t, vint16m1_t, int16_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vrsub_vx)))
vint16m2_t vrsub(vint16m2_t, int16_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vrsub_vx_m)))
vint16m2_t vrsub(vbool8_t, vint16m2_t, vint16m2_t, int16_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vrsub_vx)))
vint16m4_t vrsub(vint16m4_t, int16_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vrsub_vx_m)))
vint16m4_t vrsub(vbool4_t, vint16m4_t, vint16m4_t, int16_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vrsub_vx)))
vint16m8_t vrsub(vint16m8_t, int16_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vrsub_vx_m)))
vint16m8_t vrsub(vbool2_t, vint16m8_t, vint16m8_t, int16_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vrsub_vx)))
vint16mf2_t vrsub(vint16mf2_t, int16_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vrsub_vx_m)))
vint16mf2_t vrsub(vbool32_t, vint16mf2_t, vint16mf2_t, int16_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vrsub_vx)))
vint16mf4_t vrsub(vint16mf4_t, int16_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vrsub_vx_m)))
vint16mf4_t vrsub(vbool64_t, vint16mf4_t, vint16mf4_t, int16_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vrsub_vx)))
vint32m1_t vrsub(vint32m1_t, int32_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vrsub_vx_m)))
vint32m1_t vrsub(vbool32_t, vint32m1_t, vint32m1_t, int32_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vrsub_vx)))
vint32m2_t vrsub(vint32m2_t, int32_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vrsub_vx_m)))
vint32m2_t vrsub(vbool16_t, vint32m2_t, vint32m2_t, int32_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vrsub_vx)))
vint32m4_t vrsub(vint32m4_t, int32_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vrsub_vx_m)))
vint32m4_t vrsub(vbool8_t, vint32m4_t, vint32m4_t, int32_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vrsub_vx)))
vint32m8_t vrsub(vint32m8_t, int32_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vrsub_vx_m)))
vint32m8_t vrsub(vbool4_t, vint32m8_t, vint32m8_t, int32_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vrsub_vx)))
vint32mf2_t vrsub(vint32mf2_t, int32_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vrsub_vx_m)))
vint32mf2_t vrsub(vbool64_t, vint32mf2_t, vint32mf2_t, int32_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vrsub_vx)))
vuint8m1_t vrsub(vuint8m1_t, uint8_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vrsub_vx_m)))
vuint8m1_t vrsub(vbool8_t, vuint8m1_t, vuint8m1_t, uint8_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vrsub_vx)))
vuint8m2_t vrsub(vuint8m2_t, uint8_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vrsub_vx_m)))
vuint8m2_t vrsub(vbool4_t, vuint8m2_t, vuint8m2_t, uint8_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vrsub_vx)))
vuint8m4_t vrsub(vuint8m4_t, uint8_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vrsub_vx_m)))
vuint8m4_t vrsub(vbool2_t, vuint8m4_t, vuint8m4_t, uint8_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vrsub_vx)))
vuint8m8_t vrsub(vuint8m8_t, uint8_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vrsub_vx_m)))
vuint8m8_t vrsub(vbool1_t, vuint8m8_t, vuint8m8_t, uint8_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vrsub_vx)))
vuint8mf2_t vrsub(vuint8mf2_t, uint8_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vrsub_vx_m)))
vuint8mf2_t vrsub(vbool16_t, vuint8mf2_t, vuint8mf2_t, uint8_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vrsub_vx)))
vuint8mf4_t vrsub(vuint8mf4_t, uint8_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vrsub_vx_m)))
vuint8mf4_t vrsub(vbool32_t, vuint8mf4_t, vuint8mf4_t, uint8_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vrsub_vx)))
vuint8mf8_t vrsub(vuint8mf8_t, uint8_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vrsub_vx_m)))
vuint8mf8_t vrsub(vbool64_t, vuint8mf8_t, vuint8mf8_t, uint8_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vrsub_vx)))
vuint16m1_t vrsub(vuint16m1_t, uint16_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vrsub_vx_m)))
vuint16m1_t vrsub(vbool16_t, vuint16m1_t, vuint16m1_t, uint16_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vrsub_vx)))
vuint16m2_t vrsub(vuint16m2_t, uint16_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vrsub_vx_m)))
vuint16m2_t vrsub(vbool8_t, vuint16m2_t, vuint16m2_t, uint16_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vrsub_vx)))
vuint16m4_t vrsub(vuint16m4_t, uint16_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vrsub_vx_m)))
vuint16m4_t vrsub(vbool4_t, vuint16m4_t, vuint16m4_t, uint16_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vrsub_vx)))
vuint16m8_t vrsub(vuint16m8_t, uint16_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vrsub_vx_m)))
vuint16m8_t vrsub(vbool2_t, vuint16m8_t, vuint16m8_t, uint16_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vrsub_vx)))
vuint16mf2_t vrsub(vuint16mf2_t, uint16_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vrsub_vx_m)))
vuint16mf2_t vrsub(vbool32_t, vuint16mf2_t, vuint16mf2_t, uint16_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vrsub_vx)))
vuint16mf4_t vrsub(vuint16mf4_t, uint16_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vrsub_vx_m)))
vuint16mf4_t vrsub(vbool64_t, vuint16mf4_t, vuint16mf4_t, uint16_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vrsub_vx)))
vuint32m1_t vrsub(vuint32m1_t, uint32_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vrsub_vx_m)))
vuint32m1_t vrsub(vbool32_t, vuint32m1_t, vuint32m1_t, uint32_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vrsub_vx)))
vuint32m2_t vrsub(vuint32m2_t, uint32_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vrsub_vx_m)))
vuint32m2_t vrsub(vbool16_t, vuint32m2_t, vuint32m2_t, uint32_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vrsub_vx)))
vuint32m4_t vrsub(vuint32m4_t, uint32_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vrsub_vx_m)))
vuint32m4_t vrsub(vbool8_t, vuint32m4_t, vuint32m4_t, uint32_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vrsub_vx)))
vuint32m8_t vrsub(vuint32m8_t, uint32_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vrsub_vx_m)))
vuint32m8_t vrsub(vbool4_t, vuint32m8_t, vuint32m8_t, uint32_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vrsub_vx)))
vuint32mf2_t vrsub(vuint32mf2_t, uint32_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vrsub_vx_m)))
vuint32mf2_t vrsub(vbool64_t, vuint32mf2_t, vuint32mf2_t, uint32_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vwaddu_vx)))
vuint16mf4_t vwaddu_vx(vuint8mf8_t, uint8_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vwaddu_vx_m)))
vuint16mf4_t vwaddu_vx(vbool64_t, vuint16mf4_t, vuint8mf8_t, uint8_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vwaddu_vx)))
vuint16mf2_t vwaddu_vx(vuint8mf4_t, uint8_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vwaddu_vx_m)))
vuint16mf2_t vwaddu_vx(vbool32_t, vuint16mf2_t, vuint8mf4_t, uint8_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vwaddu_vx)))
vuint16m1_t vwaddu_vx(vuint8mf2_t, uint8_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vwaddu_vx_m)))
vuint16m1_t vwaddu_vx(vbool16_t, vuint16m1_t, vuint8mf2_t, uint8_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vwaddu_vx)))
vuint16m2_t vwaddu_vx(vuint8m1_t, uint8_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vwaddu_vx_m)))
vuint16m2_t vwaddu_vx(vbool8_t, vuint16m2_t, vuint8m1_t, uint8_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vwaddu_vx)))
vuint16m4_t vwaddu_vx(vuint8m2_t, uint8_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vwaddu_vx_m)))
vuint16m4_t vwaddu_vx(vbool4_t, vuint16m4_t, vuint8m2_t, uint8_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vwaddu_vx)))
vuint16m8_t vwaddu_vx(vuint8m4_t, uint8_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vwaddu_vx_m)))
vuint16m8_t vwaddu_vx(vbool2_t, vuint16m8_t, vuint8m4_t, uint8_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vwaddu_vx)))
vuint32mf2_t vwaddu_vx(vuint16mf4_t, uint16_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vwaddu_vx_m)))
vuint32mf2_t vwaddu_vx(vbool64_t, vuint32mf2_t, vuint16mf4_t, uint16_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vwaddu_vx)))
vuint32m1_t vwaddu_vx(vuint16mf2_t, uint16_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vwaddu_vx_m)))
vuint32m1_t vwaddu_vx(vbool32_t, vuint32m1_t, vuint16mf2_t, uint16_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vwaddu_vx)))
vuint32m2_t vwaddu_vx(vuint16m1_t, uint16_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vwaddu_vx_m)))
vuint32m2_t vwaddu_vx(vbool16_t, vuint32m2_t, vuint16m1_t, uint16_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vwaddu_vx)))
vuint32m4_t vwaddu_vx(vuint16m2_t, uint16_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vwaddu_vx_m)))
vuint32m4_t vwaddu_vx(vbool8_t, vuint32m4_t, vuint16m2_t, uint16_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vwaddu_vx)))
vuint32m8_t vwaddu_vx(vuint16m4_t, uint16_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vwaddu_vx_m)))
vuint32m8_t vwaddu_vx(vbool4_t, vuint32m8_t, vuint16m4_t, uint16_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vwsubu_vv)))
vuint16mf4_t vwsubu_vv(vuint8mf8_t, vuint8mf8_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vwsubu_vv_m)))
vuint16mf4_t vwsubu_vv(vbool64_t, vuint16mf4_t, vuint8mf8_t, vuint8mf8_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vwsubu_vv)))
vuint16mf2_t vwsubu_vv(vuint8mf4_t, vuint8mf4_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vwsubu_vv_m)))
vuint16mf2_t vwsubu_vv(vbool32_t, vuint16mf2_t, vuint8mf4_t, vuint8mf4_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vwsubu_vv)))
vuint16m1_t vwsubu_vv(vuint8mf2_t, vuint8mf2_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vwsubu_vv_m)))
vuint16m1_t vwsubu_vv(vbool16_t, vuint16m1_t, vuint8mf2_t, vuint8mf2_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vwsubu_vv)))
vuint16m2_t vwsubu_vv(vuint8m1_t, vuint8m1_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vwsubu_vv_m)))
vuint16m2_t vwsubu_vv(vbool8_t, vuint16m2_t, vuint8m1_t, vuint8m1_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vwsubu_vv)))
vuint16m4_t vwsubu_vv(vuint8m2_t, vuint8m2_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vwsubu_vv_m)))
vuint16m4_t vwsubu_vv(vbool4_t, vuint16m4_t, vuint8m2_t, vuint8m2_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vwsubu_vv)))
vuint16m8_t vwsubu_vv(vuint8m4_t, vuint8m4_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vwsubu_vv_m)))
vuint16m8_t vwsubu_vv(vbool2_t, vuint16m8_t, vuint8m4_t, vuint8m4_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vwsubu_vv)))
vuint32mf2_t vwsubu_vv(vuint16mf4_t, vuint16mf4_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vwsubu_vv_m)))
vuint32mf2_t vwsubu_vv(vbool64_t, vuint32mf2_t, vuint16mf4_t, vuint16mf4_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vwsubu_vv)))
vuint32m1_t vwsubu_vv(vuint16mf2_t, vuint16mf2_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vwsubu_vv_m)))
vuint32m1_t vwsubu_vv(vbool32_t, vuint32m1_t, vuint16mf2_t, vuint16mf2_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vwsubu_vv)))
vuint32m2_t vwsubu_vv(vuint16m1_t, vuint16m1_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vwsubu_vv_m)))
vuint32m2_t vwsubu_vv(vbool16_t, vuint32m2_t, vuint16m1_t, vuint16m1_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vwsubu_vv)))
vuint32m4_t vwsubu_vv(vuint16m2_t, vuint16m2_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vwsubu_vv_m)))
vuint32m4_t vwsubu_vv(vbool8_t, vuint32m4_t, vuint16m2_t, vuint16m2_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vwsubu_vv)))
vuint32m8_t vwsubu_vv(vuint16m4_t, vuint16m4_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vwsubu_vv_m)))
vuint32m8_t vwsubu_vv(vbool4_t, vuint32m8_t, vuint16m4_t, vuint16m4_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vwsubu_vx)))
vuint16mf4_t vwsubu_vx(vuint8mf8_t, uint8_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vwsubu_vx_m)))
vuint16mf4_t vwsubu_vx(vbool64_t, vuint16mf4_t, vuint8mf8_t, uint8_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vwsubu_vx)))
vuint16mf2_t vwsubu_vx(vuint8mf4_t, uint8_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vwsubu_vx_m)))
vuint16mf2_t vwsubu_vx(vbool32_t, vuint16mf2_t, vuint8mf4_t, uint8_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vwsubu_vx)))
vuint16m1_t vwsubu_vx(vuint8mf2_t, uint8_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vwsubu_vx_m)))
vuint16m1_t vwsubu_vx(vbool16_t, vuint16m1_t, vuint8mf2_t, uint8_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vwsubu_vx)))
vuint16m2_t vwsubu_vx(vuint8m1_t, uint8_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vwsubu_vx_m)))
vuint16m2_t vwsubu_vx(vbool8_t, vuint16m2_t, vuint8m1_t, uint8_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vwsubu_vx)))
vuint16m4_t vwsubu_vx(vuint8m2_t, uint8_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vwsubu_vx_m)))
vuint16m4_t vwsubu_vx(vbool4_t, vuint16m4_t, vuint8m2_t, uint8_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vwsubu_vx)))
vuint16m8_t vwsubu_vx(vuint8m4_t, uint8_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vwsubu_vx_m)))
vuint16m8_t vwsubu_vx(vbool2_t, vuint16m8_t, vuint8m4_t, uint8_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vwsubu_vx)))
vuint32mf2_t vwsubu_vx(vuint16mf4_t, uint16_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vwsubu_vx_m)))
vuint32mf2_t vwsubu_vx(vbool64_t, vuint32mf2_t, vuint16mf4_t, uint16_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vwsubu_vx)))
vuint32m1_t vwsubu_vx(vuint16mf2_t, uint16_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vwsubu_vx_m)))
vuint32m1_t vwsubu_vx(vbool32_t, vuint32m1_t, vuint16mf2_t, uint16_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vwsubu_vx)))
vuint32m2_t vwsubu_vx(vuint16m1_t, uint16_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vwsubu_vx_m)))
vuint32m2_t vwsubu_vx(vbool16_t, vuint32m2_t, vuint16m1_t, uint16_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vwsubu_vx)))
vuint32m4_t vwsubu_vx(vuint16m2_t, uint16_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vwsubu_vx_m)))
vuint32m4_t vwsubu_vx(vbool8_t, vuint32m4_t, vuint16m2_t, uint16_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vwsubu_vx)))
vuint32m8_t vwsubu_vx(vuint16m4_t, uint16_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vwsubu_vx_m)))
vuint32m8_t vwsubu_vx(vbool4_t, vuint32m8_t, vuint16m4_t, uint16_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vwadd_vv)))
vint16mf4_t vwadd_vv(vint8mf8_t, vint8mf8_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vwadd_vv_m)))
vint16mf4_t vwadd_vv(vbool64_t, vint16mf4_t, vint8mf8_t, vint8mf8_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vwadd_vv)))
vint16mf2_t vwadd_vv(vint8mf4_t, vint8mf4_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vwadd_vv_m)))
vint16mf2_t vwadd_vv(vbool32_t, vint16mf2_t, vint8mf4_t, vint8mf4_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vwadd_vv)))
vint16m1_t vwadd_vv(vint8mf2_t, vint8mf2_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vwadd_vv_m)))
vint16m1_t vwadd_vv(vbool16_t, vint16m1_t, vint8mf2_t, vint8mf2_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vwadd_vv)))
vint16m2_t vwadd_vv(vint8m1_t, vint8m1_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vwadd_vv_m)))
vint16m2_t vwadd_vv(vbool8_t, vint16m2_t, vint8m1_t, vint8m1_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vwadd_vv)))
vint16m4_t vwadd_vv(vint8m2_t, vint8m2_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vwadd_vv_m)))
vint16m4_t vwadd_vv(vbool4_t, vint16m4_t, vint8m2_t, vint8m2_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vwadd_vv)))
vint16m8_t vwadd_vv(vint8m4_t, vint8m4_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vwadd_vv_m)))
vint16m8_t vwadd_vv(vbool2_t, vint16m8_t, vint8m4_t, vint8m4_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vwadd_vv)))
vint32mf2_t vwadd_vv(vint16mf4_t, vint16mf4_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vwadd_vv_m)))
vint32mf2_t vwadd_vv(vbool64_t, vint32mf2_t, vint16mf4_t, vint16mf4_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vwadd_vv)))
vint32m1_t vwadd_vv(vint16mf2_t, vint16mf2_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vwadd_vv_m)))
vint32m1_t vwadd_vv(vbool32_t, vint32m1_t, vint16mf2_t, vint16mf2_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vwadd_vv)))
vint32m2_t vwadd_vv(vint16m1_t, vint16m1_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vwadd_vv_m)))
vint32m2_t vwadd_vv(vbool16_t, vint32m2_t, vint16m1_t, vint16m1_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vwadd_vv)))
vint32m4_t vwadd_vv(vint16m2_t, vint16m2_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vwadd_vv_m)))
vint32m4_t vwadd_vv(vbool8_t, vint32m4_t, vint16m2_t, vint16m2_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vwadd_vv)))
vint32m8_t vwadd_vv(vint16m4_t, vint16m4_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vwadd_vv_m)))
vint32m8_t vwadd_vv(vbool4_t, vint32m8_t, vint16m4_t, vint16m4_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vwadd_vx)))
vint16mf4_t vwadd_vx(vint8mf8_t, int8_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vwadd_vx_m)))
vint16mf4_t vwadd_vx(vbool64_t, vint16mf4_t, vint8mf8_t, int8_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vwadd_vx)))
vint16mf2_t vwadd_vx(vint8mf4_t, int8_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vwadd_vx_m)))
vint16mf2_t vwadd_vx(vbool32_t, vint16mf2_t, vint8mf4_t, int8_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vwadd_vx)))
vint16m1_t vwadd_vx(vint8mf2_t, int8_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vwadd_vx_m)))
vint16m1_t vwadd_vx(vbool16_t, vint16m1_t, vint8mf2_t, int8_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vwadd_vx)))
vint16m2_t vwadd_vx(vint8m1_t, int8_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vwadd_vx_m)))
vint16m2_t vwadd_vx(vbool8_t, vint16m2_t, vint8m1_t, int8_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vwadd_vx)))
vint16m4_t vwadd_vx(vint8m2_t, int8_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vwadd_vx_m)))
vint16m4_t vwadd_vx(vbool4_t, vint16m4_t, vint8m2_t, int8_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vwadd_vx)))
vint16m8_t vwadd_vx(vint8m4_t, int8_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vwadd_vx_m)))
vint16m8_t vwadd_vx(vbool2_t, vint16m8_t, vint8m4_t, int8_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vwadd_vx)))
vint32mf2_t vwadd_vx(vint16mf4_t, int16_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vwadd_vx_m)))
vint32mf2_t vwadd_vx(vbool64_t, vint32mf2_t, vint16mf4_t, int16_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vwadd_vx)))
vint32m1_t vwadd_vx(vint16mf2_t, int16_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vwadd_vx_m)))
vint32m1_t vwadd_vx(vbool32_t, vint32m1_t, vint16mf2_t, int16_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vwadd_vx)))
vint32m2_t vwadd_vx(vint16m1_t, int16_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vwadd_vx_m)))
vint32m2_t vwadd_vx(vbool16_t, vint32m2_t, vint16m1_t, int16_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vwadd_vx)))
vint32m4_t vwadd_vx(vint16m2_t, int16_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vwadd_vx_m)))
vint32m4_t vwadd_vx(vbool8_t, vint32m4_t, vint16m2_t, int16_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vwadd_vx)))
vint32m8_t vwadd_vx(vint16m4_t, int16_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vwadd_vx_m)))
vint32m8_t vwadd_vx(vbool4_t, vint32m8_t, vint16m4_t, int16_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vwsub_vv)))
vint16mf4_t vwsub_vv(vint8mf8_t, vint8mf8_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vwsub_vv_m)))
vint16mf4_t vwsub_vv(vbool64_t, vint16mf4_t, vint8mf8_t, vint8mf8_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vwsub_vv)))
vint16mf2_t vwsub_vv(vint8mf4_t, vint8mf4_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vwsub_vv_m)))
vint16mf2_t vwsub_vv(vbool32_t, vint16mf2_t, vint8mf4_t, vint8mf4_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vwsub_vv)))
vint16m1_t vwsub_vv(vint8mf2_t, vint8mf2_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vwsub_vv_m)))
vint16m1_t vwsub_vv(vbool16_t, vint16m1_t, vint8mf2_t, vint8mf2_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vwsub_vv)))
vint16m2_t vwsub_vv(vint8m1_t, vint8m1_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vwsub_vv_m)))
vint16m2_t vwsub_vv(vbool8_t, vint16m2_t, vint8m1_t, vint8m1_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vwsub_vv)))
vint16m4_t vwsub_vv(vint8m2_t, vint8m2_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vwsub_vv_m)))
vint16m4_t vwsub_vv(vbool4_t, vint16m4_t, vint8m2_t, vint8m2_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vwsub_vv)))
vint16m8_t vwsub_vv(vint8m4_t, vint8m4_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vwsub_vv_m)))
vint16m8_t vwsub_vv(vbool2_t, vint16m8_t, vint8m4_t, vint8m4_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vwsub_vv)))
vint32mf2_t vwsub_vv(vint16mf4_t, vint16mf4_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vwsub_vv_m)))
vint32mf2_t vwsub_vv(vbool64_t, vint32mf2_t, vint16mf4_t, vint16mf4_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vwsub_vv)))
vint32m1_t vwsub_vv(vint16mf2_t, vint16mf2_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vwsub_vv_m)))
vint32m1_t vwsub_vv(vbool32_t, vint32m1_t, vint16mf2_t, vint16mf2_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vwsub_vv)))
vint32m2_t vwsub_vv(vint16m1_t, vint16m1_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vwsub_vv_m)))
vint32m2_t vwsub_vv(vbool16_t, vint32m2_t, vint16m1_t, vint16m1_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vwsub_vv)))
vint32m4_t vwsub_vv(vint16m2_t, vint16m2_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vwsub_vv_m)))
vint32m4_t vwsub_vv(vbool8_t, vint32m4_t, vint16m2_t, vint16m2_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vwsub_vv)))
vint32m8_t vwsub_vv(vint16m4_t, vint16m4_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vwsub_vv_m)))
vint32m8_t vwsub_vv(vbool4_t, vint32m8_t, vint16m4_t, vint16m4_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vwsub_vx)))
vint16mf4_t vwsub_vx(vint8mf8_t, int8_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vwsub_vx_m)))
vint16mf4_t vwsub_vx(vbool64_t, vint16mf4_t, vint8mf8_t, int8_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vwsub_vx)))
vint16mf2_t vwsub_vx(vint8mf4_t, int8_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vwsub_vx_m)))
vint16mf2_t vwsub_vx(vbool32_t, vint16mf2_t, vint8mf4_t, int8_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vwsub_vx)))
vint16m1_t vwsub_vx(vint8mf2_t, int8_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vwsub_vx_m)))
vint16m1_t vwsub_vx(vbool16_t, vint16m1_t, vint8mf2_t, int8_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vwsub_vx)))
vint16m2_t vwsub_vx(vint8m1_t, int8_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vwsub_vx_m)))
vint16m2_t vwsub_vx(vbool8_t, vint16m2_t, vint8m1_t, int8_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vwsub_vx)))
vint16m4_t vwsub_vx(vint8m2_t, int8_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vwsub_vx_m)))
vint16m4_t vwsub_vx(vbool4_t, vint16m4_t, vint8m2_t, int8_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vwsub_vx)))
vint16m8_t vwsub_vx(vint8m4_t, int8_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vwsub_vx_m)))
vint16m8_t vwsub_vx(vbool2_t, vint16m8_t, vint8m4_t, int8_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vwsub_vx)))
vint32mf2_t vwsub_vx(vint16mf4_t, int16_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vwsub_vx_m)))
vint32mf2_t vwsub_vx(vbool64_t, vint32mf2_t, vint16mf4_t, int16_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vwsub_vx)))
vint32m1_t vwsub_vx(vint16mf2_t, int16_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vwsub_vx_m)))
vint32m1_t vwsub_vx(vbool32_t, vint32m1_t, vint16mf2_t, int16_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vwsub_vx)))
vint32m2_t vwsub_vx(vint16m1_t, int16_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vwsub_vx_m)))
vint32m2_t vwsub_vx(vbool16_t, vint32m2_t, vint16m1_t, int16_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vwsub_vx)))
vint32m4_t vwsub_vx(vint16m2_t, int16_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vwsub_vx_m)))
vint32m4_t vwsub_vx(vbool8_t, vint32m4_t, vint16m2_t, int16_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vwsub_vx)))
vint32m8_t vwsub_vx(vint16m4_t, int16_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vwsub_vx_m)))
vint32m8_t vwsub_vx(vbool4_t, vint32m8_t, vint16m4_t, int16_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vwaddu_wx)))
vuint16mf4_t vwaddu_wx(vuint16mf4_t, uint8_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vwaddu_wx_m)))
vuint16mf4_t vwaddu_wx(vbool64_t, vuint16mf4_t, vuint16mf4_t, uint8_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vwaddu_wx)))
vuint16mf2_t vwaddu_wx(vuint16mf2_t, uint8_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vwaddu_wx_m)))
vuint16mf2_t vwaddu_wx(vbool32_t, vuint16mf2_t, vuint16mf2_t, uint8_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vwaddu_wx)))
vuint16m1_t vwaddu_wx(vuint16m1_t, uint8_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vwaddu_wx_m)))
vuint16m1_t vwaddu_wx(vbool16_t, vuint16m1_t, vuint16m1_t, uint8_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vwaddu_wx)))
vuint16m2_t vwaddu_wx(vuint16m2_t, uint8_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vwaddu_wx_m)))
vuint16m2_t vwaddu_wx(vbool8_t, vuint16m2_t, vuint16m2_t, uint8_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vwaddu_wx)))
vuint16m4_t vwaddu_wx(vuint16m4_t, uint8_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vwaddu_wx_m)))
vuint16m4_t vwaddu_wx(vbool4_t, vuint16m4_t, vuint16m4_t, uint8_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vwaddu_wx)))
vuint16m8_t vwaddu_wx(vuint16m8_t, uint8_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vwaddu_wx_m)))
vuint16m8_t vwaddu_wx(vbool2_t, vuint16m8_t, vuint16m8_t, uint8_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vwaddu_wx)))
vuint32mf2_t vwaddu_wx(vuint32mf2_t, uint16_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vwaddu_wx_m)))
vuint32mf2_t vwaddu_wx(vbool64_t, vuint32mf2_t, vuint32mf2_t, uint16_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vwaddu_wx)))
vuint32m1_t vwaddu_wx(vuint32m1_t, uint16_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vwaddu_wx_m)))
vuint32m1_t vwaddu_wx(vbool32_t, vuint32m1_t, vuint32m1_t, uint16_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vwaddu_wx)))
vuint32m2_t vwaddu_wx(vuint32m2_t, uint16_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vwaddu_wx_m)))
vuint32m2_t vwaddu_wx(vbool16_t, vuint32m2_t, vuint32m2_t, uint16_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vwaddu_wx)))
vuint32m4_t vwaddu_wx(vuint32m4_t, uint16_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vwaddu_wx_m)))
vuint32m4_t vwaddu_wx(vbool8_t, vuint32m4_t, vuint32m4_t, uint16_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vwaddu_wx)))
vuint32m8_t vwaddu_wx(vuint32m8_t, uint16_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vwaddu_wx_m)))
vuint32m8_t vwaddu_wx(vbool4_t, vuint32m8_t, vuint32m8_t, uint16_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vwsubu_wv)))
vuint16mf4_t vwsubu_wv(vuint16mf4_t, vuint8mf8_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vwsubu_wv_m)))
vuint16mf4_t vwsubu_wv(vbool64_t, vuint16mf4_t, vuint16mf4_t, vuint8mf8_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vwsubu_wv)))
vuint16mf2_t vwsubu_wv(vuint16mf2_t, vuint8mf4_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vwsubu_wv_m)))
vuint16mf2_t vwsubu_wv(vbool32_t, vuint16mf2_t, vuint16mf2_t, vuint8mf4_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vwsubu_wv)))
vuint16m1_t vwsubu_wv(vuint16m1_t, vuint8mf2_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vwsubu_wv_m)))
vuint16m1_t vwsubu_wv(vbool16_t, vuint16m1_t, vuint16m1_t, vuint8mf2_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vwsubu_wv)))
vuint16m2_t vwsubu_wv(vuint16m2_t, vuint8m1_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vwsubu_wv_m)))
vuint16m2_t vwsubu_wv(vbool8_t, vuint16m2_t, vuint16m2_t, vuint8m1_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vwsubu_wv)))
vuint16m4_t vwsubu_wv(vuint16m4_t, vuint8m2_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vwsubu_wv_m)))
vuint16m4_t vwsubu_wv(vbool4_t, vuint16m4_t, vuint16m4_t, vuint8m2_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vwsubu_wv)))
vuint16m8_t vwsubu_wv(vuint16m8_t, vuint8m4_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vwsubu_wv_m)))
vuint16m8_t vwsubu_wv(vbool2_t, vuint16m8_t, vuint16m8_t, vuint8m4_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vwsubu_wv)))
vuint32mf2_t vwsubu_wv(vuint32mf2_t, vuint16mf4_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vwsubu_wv_m)))
vuint32mf2_t vwsubu_wv(vbool64_t, vuint32mf2_t, vuint32mf2_t, vuint16mf4_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vwsubu_wv)))
vuint32m1_t vwsubu_wv(vuint32m1_t, vuint16mf2_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vwsubu_wv_m)))
vuint32m1_t vwsubu_wv(vbool32_t, vuint32m1_t, vuint32m1_t, vuint16mf2_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vwsubu_wv)))
vuint32m2_t vwsubu_wv(vuint32m2_t, vuint16m1_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vwsubu_wv_m)))
vuint32m2_t vwsubu_wv(vbool16_t, vuint32m2_t, vuint32m2_t, vuint16m1_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vwsubu_wv)))
vuint32m4_t vwsubu_wv(vuint32m4_t, vuint16m2_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vwsubu_wv_m)))
vuint32m4_t vwsubu_wv(vbool8_t, vuint32m4_t, vuint32m4_t, vuint16m2_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vwsubu_wv)))
vuint32m8_t vwsubu_wv(vuint32m8_t, vuint16m4_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vwsubu_wv_m)))
vuint32m8_t vwsubu_wv(vbool4_t, vuint32m8_t, vuint32m8_t, vuint16m4_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vwsubu_wx)))
vuint16mf4_t vwsubu_wx(vuint16mf4_t, uint8_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vwsubu_wx_m)))
vuint16mf4_t vwsubu_wx(vbool64_t, vuint16mf4_t, vuint16mf4_t, uint8_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vwsubu_wx)))
vuint16mf2_t vwsubu_wx(vuint16mf2_t, uint8_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vwsubu_wx_m)))
vuint16mf2_t vwsubu_wx(vbool32_t, vuint16mf2_t, vuint16mf2_t, uint8_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vwsubu_wx)))
vuint16m1_t vwsubu_wx(vuint16m1_t, uint8_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vwsubu_wx_m)))
vuint16m1_t vwsubu_wx(vbool16_t, vuint16m1_t, vuint16m1_t, uint8_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vwsubu_wx)))
vuint16m2_t vwsubu_wx(vuint16m2_t, uint8_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vwsubu_wx_m)))
vuint16m2_t vwsubu_wx(vbool8_t, vuint16m2_t, vuint16m2_t, uint8_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vwsubu_wx)))
vuint16m4_t vwsubu_wx(vuint16m4_t, uint8_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vwsubu_wx_m)))
vuint16m4_t vwsubu_wx(vbool4_t, vuint16m4_t, vuint16m4_t, uint8_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vwsubu_wx)))
vuint16m8_t vwsubu_wx(vuint16m8_t, uint8_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vwsubu_wx_m)))
vuint16m8_t vwsubu_wx(vbool2_t, vuint16m8_t, vuint16m8_t, uint8_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vwsubu_wx)))
vuint32mf2_t vwsubu_wx(vuint32mf2_t, uint16_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vwsubu_wx_m)))
vuint32mf2_t vwsubu_wx(vbool64_t, vuint32mf2_t, vuint32mf2_t, uint16_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vwsubu_wx)))
vuint32m1_t vwsubu_wx(vuint32m1_t, uint16_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vwsubu_wx_m)))
vuint32m1_t vwsubu_wx(vbool32_t, vuint32m1_t, vuint32m1_t, uint16_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vwsubu_wx)))
vuint32m2_t vwsubu_wx(vuint32m2_t, uint16_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vwsubu_wx_m)))
vuint32m2_t vwsubu_wx(vbool16_t, vuint32m2_t, vuint32m2_t, uint16_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vwsubu_wx)))
vuint32m4_t vwsubu_wx(vuint32m4_t, uint16_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vwsubu_wx_m)))
vuint32m4_t vwsubu_wx(vbool8_t, vuint32m4_t, vuint32m4_t, uint16_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vwsubu_wx)))
vuint32m8_t vwsubu_wx(vuint32m8_t, uint16_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vwsubu_wx_m)))
vuint32m8_t vwsubu_wx(vbool4_t, vuint32m8_t, vuint32m8_t, uint16_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vwadd_wv)))
vint16mf4_t vwadd_wv(vint16mf4_t, vint8mf8_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vwadd_wv_m)))
vint16mf4_t vwadd_wv(vbool64_t, vint16mf4_t, vint16mf4_t, vint8mf8_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vwadd_wv)))
vint16mf2_t vwadd_wv(vint16mf2_t, vint8mf4_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vwadd_wv_m)))
vint16mf2_t vwadd_wv(vbool32_t, vint16mf2_t, vint16mf2_t, vint8mf4_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vwadd_wv)))
vint16m1_t vwadd_wv(vint16m1_t, vint8mf2_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vwadd_wv_m)))
vint16m1_t vwadd_wv(vbool16_t, vint16m1_t, vint16m1_t, vint8mf2_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vwadd_wv)))
vint16m2_t vwadd_wv(vint16m2_t, vint8m1_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vwadd_wv_m)))
vint16m2_t vwadd_wv(vbool8_t, vint16m2_t, vint16m2_t, vint8m1_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vwadd_wv)))
vint16m4_t vwadd_wv(vint16m4_t, vint8m2_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vwadd_wv_m)))
vint16m4_t vwadd_wv(vbool4_t, vint16m4_t, vint16m4_t, vint8m2_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vwadd_wv)))
vint16m8_t vwadd_wv(vint16m8_t, vint8m4_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vwadd_wv_m)))
vint16m8_t vwadd_wv(vbool2_t, vint16m8_t, vint16m8_t, vint8m4_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vwadd_wv)))
vint32mf2_t vwadd_wv(vint32mf2_t, vint16mf4_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vwadd_wv_m)))
vint32mf2_t vwadd_wv(vbool64_t, vint32mf2_t, vint32mf2_t, vint16mf4_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vwadd_wv)))
vint32m1_t vwadd_wv(vint32m1_t, vint16mf2_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vwadd_wv_m)))
vint32m1_t vwadd_wv(vbool32_t, vint32m1_t, vint32m1_t, vint16mf2_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vwadd_wv)))
vint32m2_t vwadd_wv(vint32m2_t, vint16m1_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vwadd_wv_m)))
vint32m2_t vwadd_wv(vbool16_t, vint32m2_t, vint32m2_t, vint16m1_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vwadd_wv)))
vint32m4_t vwadd_wv(vint32m4_t, vint16m2_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vwadd_wv_m)))
vint32m4_t vwadd_wv(vbool8_t, vint32m4_t, vint32m4_t, vint16m2_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vwadd_wv)))
vint32m8_t vwadd_wv(vint32m8_t, vint16m4_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vwadd_wv_m)))
vint32m8_t vwadd_wv(vbool4_t, vint32m8_t, vint32m8_t, vint16m4_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vwadd_wx)))
vint16mf4_t vwadd_wx(vint16mf4_t, int8_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vwadd_wx_m)))
vint16mf4_t vwadd_wx(vbool64_t, vint16mf4_t, vint16mf4_t, int8_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vwadd_wx)))
vint16mf2_t vwadd_wx(vint16mf2_t, int8_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vwadd_wx_m)))
vint16mf2_t vwadd_wx(vbool32_t, vint16mf2_t, vint16mf2_t, int8_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vwadd_wx)))
vint16m1_t vwadd_wx(vint16m1_t, int8_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vwadd_wx_m)))
vint16m1_t vwadd_wx(vbool16_t, vint16m1_t, vint16m1_t, int8_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vwadd_wx)))
vint16m2_t vwadd_wx(vint16m2_t, int8_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vwadd_wx_m)))
vint16m2_t vwadd_wx(vbool8_t, vint16m2_t, vint16m2_t, int8_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vwadd_wx)))
vint16m4_t vwadd_wx(vint16m4_t, int8_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vwadd_wx_m)))
vint16m4_t vwadd_wx(vbool4_t, vint16m4_t, vint16m4_t, int8_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vwadd_wx)))
vint16m8_t vwadd_wx(vint16m8_t, int8_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vwadd_wx_m)))
vint16m8_t vwadd_wx(vbool2_t, vint16m8_t, vint16m8_t, int8_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vwadd_wx)))
vint32mf2_t vwadd_wx(vint32mf2_t, int16_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vwadd_wx_m)))
vint32mf2_t vwadd_wx(vbool64_t, vint32mf2_t, vint32mf2_t, int16_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vwadd_wx)))
vint32m1_t vwadd_wx(vint32m1_t, int16_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vwadd_wx_m)))
vint32m1_t vwadd_wx(vbool32_t, vint32m1_t, vint32m1_t, int16_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vwadd_wx)))
vint32m2_t vwadd_wx(vint32m2_t, int16_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vwadd_wx_m)))
vint32m2_t vwadd_wx(vbool16_t, vint32m2_t, vint32m2_t, int16_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vwadd_wx)))
vint32m4_t vwadd_wx(vint32m4_t, int16_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vwadd_wx_m)))
vint32m4_t vwadd_wx(vbool8_t, vint32m4_t, vint32m4_t, int16_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vwadd_wx)))
vint32m8_t vwadd_wx(vint32m8_t, int16_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vwadd_wx_m)))
vint32m8_t vwadd_wx(vbool4_t, vint32m8_t, vint32m8_t, int16_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vwsub_wv)))
vint16mf4_t vwsub_wv(vint16mf4_t, vint8mf8_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vwsub_wv_m)))
vint16mf4_t vwsub_wv(vbool64_t, vint16mf4_t, vint16mf4_t, vint8mf8_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vwsub_wv)))
vint16mf2_t vwsub_wv(vint16mf2_t, vint8mf4_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vwsub_wv_m)))
vint16mf2_t vwsub_wv(vbool32_t, vint16mf2_t, vint16mf2_t, vint8mf4_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vwsub_wv)))
vint16m1_t vwsub_wv(vint16m1_t, vint8mf2_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vwsub_wv_m)))
vint16m1_t vwsub_wv(vbool16_t, vint16m1_t, vint16m1_t, vint8mf2_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vwsub_wv)))
vint16m2_t vwsub_wv(vint16m2_t, vint8m1_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vwsub_wv_m)))
vint16m2_t vwsub_wv(vbool8_t, vint16m2_t, vint16m2_t, vint8m1_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vwsub_wv)))
vint16m4_t vwsub_wv(vint16m4_t, vint8m2_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vwsub_wv_m)))
vint16m4_t vwsub_wv(vbool4_t, vint16m4_t, vint16m4_t, vint8m2_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vwsub_wv)))
vint16m8_t vwsub_wv(vint16m8_t, vint8m4_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vwsub_wv_m)))
vint16m8_t vwsub_wv(vbool2_t, vint16m8_t, vint16m8_t, vint8m4_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vwsub_wv)))
vint32mf2_t vwsub_wv(vint32mf2_t, vint16mf4_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vwsub_wv_m)))
vint32mf2_t vwsub_wv(vbool64_t, vint32mf2_t, vint32mf2_t, vint16mf4_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vwsub_wv)))
vint32m1_t vwsub_wv(vint32m1_t, vint16mf2_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vwsub_wv_m)))
vint32m1_t vwsub_wv(vbool32_t, vint32m1_t, vint32m1_t, vint16mf2_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vwsub_wv)))
vint32m2_t vwsub_wv(vint32m2_t, vint16m1_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vwsub_wv_m)))
vint32m2_t vwsub_wv(vbool16_t, vint32m2_t, vint32m2_t, vint16m1_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vwsub_wv)))
vint32m4_t vwsub_wv(vint32m4_t, vint16m2_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vwsub_wv_m)))
vint32m4_t vwsub_wv(vbool8_t, vint32m4_t, vint32m4_t, vint16m2_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vwsub_wv)))
vint32m8_t vwsub_wv(vint32m8_t, vint16m4_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vwsub_wv_m)))
vint32m8_t vwsub_wv(vbool4_t, vint32m8_t, vint32m8_t, vint16m4_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vwsub_wx)))
vint16mf4_t vwsub_wx(vint16mf4_t, int8_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vwsub_wx_m)))
vint16mf4_t vwsub_wx(vbool64_t, vint16mf4_t, vint16mf4_t, int8_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vwsub_wx)))
vint16mf2_t vwsub_wx(vint16mf2_t, int8_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vwsub_wx_m)))
vint16mf2_t vwsub_wx(vbool32_t, vint16mf2_t, vint16mf2_t, int8_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vwsub_wx)))
vint16m1_t vwsub_wx(vint16m1_t, int8_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vwsub_wx_m)))
vint16m1_t vwsub_wx(vbool16_t, vint16m1_t, vint16m1_t, int8_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vwsub_wx)))
vint16m2_t vwsub_wx(vint16m2_t, int8_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vwsub_wx_m)))
vint16m2_t vwsub_wx(vbool8_t, vint16m2_t, vint16m2_t, int8_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vwsub_wx)))
vint16m4_t vwsub_wx(vint16m4_t, int8_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vwsub_wx_m)))
vint16m4_t vwsub_wx(vbool4_t, vint16m4_t, vint16m4_t, int8_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vwsub_wx)))
vint16m8_t vwsub_wx(vint16m8_t, int8_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vwsub_wx_m)))
vint16m8_t vwsub_wx(vbool2_t, vint16m8_t, vint16m8_t, int8_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vwsub_wx)))
vint32mf2_t vwsub_wx(vint32mf2_t, int16_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vwsub_wx_m)))
vint32mf2_t vwsub_wx(vbool64_t, vint32mf2_t, vint32mf2_t, int16_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vwsub_wx)))
vint32m1_t vwsub_wx(vint32m1_t, int16_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vwsub_wx_m)))
vint32m1_t vwsub_wx(vbool32_t, vint32m1_t, vint32m1_t, int16_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vwsub_wx)))
vint32m2_t vwsub_wx(vint32m2_t, int16_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vwsub_wx_m)))
vint32m2_t vwsub_wx(vbool16_t, vint32m2_t, vint32m2_t, int16_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vwsub_wx)))
vint32m4_t vwsub_wx(vint32m4_t, int16_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vwsub_wx_m)))
vint32m4_t vwsub_wx(vbool8_t, vint32m4_t, vint32m4_t, int16_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vwsub_wx)))
vint32m8_t vwsub_wx(vint32m8_t, int16_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vwsub_wx_m)))
vint32m8_t vwsub_wx(vbool4_t, vint32m8_t, vint32m8_t, int16_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vwcvt_x_x_v)))
vint16m2_t vwcvt_x(vint8m1_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vwcvt_x_x_v_m)))
vint16m2_t vwcvt_x(vbool8_t, vint16m2_t, vint8m1_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vwcvt_x_x_v)))
vint16m4_t vwcvt_x(vint8m2_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vwcvt_x_x_v_m)))
vint16m4_t vwcvt_x(vbool4_t, vint16m4_t, vint8m2_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vwcvt_x_x_v)))
vint16m8_t vwcvt_x(vint8m4_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vwcvt_x_x_v_m)))
vint16m8_t vwcvt_x(vbool2_t, vint16m8_t, vint8m4_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vwcvt_x_x_v)))
vint16m1_t vwcvt_x(vint8mf2_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vwcvt_x_x_v_m)))
vint16m1_t vwcvt_x(vbool16_t, vint16m1_t, vint8mf2_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vwcvt_x_x_v)))
vint16mf2_t vwcvt_x(vint8mf4_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vwcvt_x_x_v_m)))
vint16mf2_t vwcvt_x(vbool32_t, vint16mf2_t, vint8mf4_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vwcvt_x_x_v)))
vint16mf4_t vwcvt_x(vint8mf8_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vwcvt_x_x_v_m)))
vint16mf4_t vwcvt_x(vbool64_t, vint16mf4_t, vint8mf8_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vwcvt_x_x_v)))
vint32m2_t vwcvt_x(vint16m1_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vwcvt_x_x_v_m)))
vint32m2_t vwcvt_x(vbool16_t, vint32m2_t, vint16m1_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vwcvt_x_x_v)))
vint32m4_t vwcvt_x(vint16m2_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vwcvt_x_x_v_m)))
vint32m4_t vwcvt_x(vbool8_t, vint32m4_t, vint16m2_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vwcvt_x_x_v)))
vint32m8_t vwcvt_x(vint16m4_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vwcvt_x_x_v_m)))
vint32m8_t vwcvt_x(vbool4_t, vint32m8_t, vint16m4_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vwcvt_x_x_v)))
vint32m1_t vwcvt_x(vint16mf2_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vwcvt_x_x_v_m)))
vint32m1_t vwcvt_x(vbool32_t, vint32m1_t, vint16mf2_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vwcvt_x_x_v)))
vint32mf2_t vwcvt_x(vint16mf4_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vwcvt_x_x_v_m)))
vint32mf2_t vwcvt_x(vbool64_t, vint32mf2_t, vint16mf4_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vadc_vvm)))
vint8m1_t vadc(vint8m1_t, vint8m1_t, vbool8_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vadc_vvm)))
vint8m2_t vadc(vint8m2_t, vint8m2_t, vbool4_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vadc_vvm)))
vint8m4_t vadc(vint8m4_t, vint8m4_t, vbool2_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vadc_vvm)))
vint8m8_t vadc(vint8m8_t, vint8m8_t, vbool1_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vadc_vvm)))
vint8mf2_t vadc(vint8mf2_t, vint8mf2_t, vbool16_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vadc_vvm)))
vint8mf4_t vadc(vint8mf4_t, vint8mf4_t, vbool32_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vadc_vvm)))
vint8mf8_t vadc(vint8mf8_t, vint8mf8_t, vbool64_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vadc_vvm)))
vint16m1_t vadc(vint16m1_t, vint16m1_t, vbool16_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vadc_vvm)))
vint16m2_t vadc(vint16m2_t, vint16m2_t, vbool8_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vadc_vvm)))
vint16m4_t vadc(vint16m4_t, vint16m4_t, vbool4_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vadc_vvm)))
vint16m8_t vadc(vint16m8_t, vint16m8_t, vbool2_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vadc_vvm)))
vint16mf2_t vadc(vint16mf2_t, vint16mf2_t, vbool32_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vadc_vvm)))
vint16mf4_t vadc(vint16mf4_t, vint16mf4_t, vbool64_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vadc_vvm)))
vint32m1_t vadc(vint32m1_t, vint32m1_t, vbool32_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vadc_vvm)))
vint32m2_t vadc(vint32m2_t, vint32m2_t, vbool16_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vadc_vvm)))
vint32m4_t vadc(vint32m4_t, vint32m4_t, vbool8_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vadc_vvm)))
vint32m8_t vadc(vint32m8_t, vint32m8_t, vbool4_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vadc_vvm)))
vint32mf2_t vadc(vint32mf2_t, vint32mf2_t, vbool64_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vadc_vxm)))
vint8m1_t vadc(vint8m1_t, int8_t, vbool8_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vadc_vxm)))
vint8m2_t vadc(vint8m2_t, int8_t, vbool4_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vadc_vxm)))
vint8m4_t vadc(vint8m4_t, int8_t, vbool2_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vadc_vxm)))
vint8m8_t vadc(vint8m8_t, int8_t, vbool1_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vadc_vxm)))
vint8mf2_t vadc(vint8mf2_t, int8_t, vbool16_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vadc_vxm)))
vint8mf4_t vadc(vint8mf4_t, int8_t, vbool32_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vadc_vxm)))
vint8mf8_t vadc(vint8mf8_t, int8_t, vbool64_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vadc_vxm)))
vint16m1_t vadc(vint16m1_t, int16_t, vbool16_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vadc_vxm)))
vint16m2_t vadc(vint16m2_t, int16_t, vbool8_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vadc_vxm)))
vint16m4_t vadc(vint16m4_t, int16_t, vbool4_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vadc_vxm)))
vint16m8_t vadc(vint16m8_t, int16_t, vbool2_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vadc_vxm)))
vint16mf2_t vadc(vint16mf2_t, int16_t, vbool32_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vadc_vxm)))
vint16mf4_t vadc(vint16mf4_t, int16_t, vbool64_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vadc_vxm)))
vint32m1_t vadc(vint32m1_t, int32_t, vbool32_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vadc_vxm)))
vint32m2_t vadc(vint32m2_t, int32_t, vbool16_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vadc_vxm)))
vint32m4_t vadc(vint32m4_t, int32_t, vbool8_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vadc_vxm)))
vint32m8_t vadc(vint32m8_t, int32_t, vbool4_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vadc_vxm)))
vint32mf2_t vadc(vint32mf2_t, int32_t, vbool64_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vadc_vvm)))
vuint8m1_t vadc(vuint8m1_t, vuint8m1_t, vbool8_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vadc_vvm)))
vuint8m2_t vadc(vuint8m2_t, vuint8m2_t, vbool4_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vadc_vvm)))
vuint8m4_t vadc(vuint8m4_t, vuint8m4_t, vbool2_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vadc_vvm)))
vuint8m8_t vadc(vuint8m8_t, vuint8m8_t, vbool1_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vadc_vvm)))
vuint8mf2_t vadc(vuint8mf2_t, vuint8mf2_t, vbool16_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vadc_vvm)))
vuint8mf4_t vadc(vuint8mf4_t, vuint8mf4_t, vbool32_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vadc_vvm)))
vuint8mf8_t vadc(vuint8mf8_t, vuint8mf8_t, vbool64_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vadc_vvm)))
vuint16m1_t vadc(vuint16m1_t, vuint16m1_t, vbool16_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vadc_vvm)))
vuint16m2_t vadc(vuint16m2_t, vuint16m2_t, vbool8_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vadc_vvm)))
vuint16m4_t vadc(vuint16m4_t, vuint16m4_t, vbool4_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vadc_vvm)))
vuint16m8_t vadc(vuint16m8_t, vuint16m8_t, vbool2_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vadc_vvm)))
vuint16mf2_t vadc(vuint16mf2_t, vuint16mf2_t, vbool32_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vadc_vvm)))
vuint16mf4_t vadc(vuint16mf4_t, vuint16mf4_t, vbool64_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vadc_vvm)))
vuint32m1_t vadc(vuint32m1_t, vuint32m1_t, vbool32_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vadc_vvm)))
vuint32m2_t vadc(vuint32m2_t, vuint32m2_t, vbool16_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vadc_vvm)))
vuint32m4_t vadc(vuint32m4_t, vuint32m4_t, vbool8_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vadc_vvm)))
vuint32m8_t vadc(vuint32m8_t, vuint32m8_t, vbool4_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vadc_vvm)))
vuint32mf2_t vadc(vuint32mf2_t, vuint32mf2_t, vbool64_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vadc_vxm)))
vuint8m1_t vadc(vuint8m1_t, uint8_t, vbool8_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vadc_vxm)))
vuint8m2_t vadc(vuint8m2_t, uint8_t, vbool4_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vadc_vxm)))
vuint8m4_t vadc(vuint8m4_t, uint8_t, vbool2_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vadc_vxm)))
vuint8m8_t vadc(vuint8m8_t, uint8_t, vbool1_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vadc_vxm)))
vuint8mf2_t vadc(vuint8mf2_t, uint8_t, vbool16_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vadc_vxm)))
vuint8mf4_t vadc(vuint8mf4_t, uint8_t, vbool32_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vadc_vxm)))
vuint8mf8_t vadc(vuint8mf8_t, uint8_t, vbool64_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vadc_vxm)))
vuint16m1_t vadc(vuint16m1_t, uint16_t, vbool16_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vadc_vxm)))
vuint16m2_t vadc(vuint16m2_t, uint16_t, vbool8_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vadc_vxm)))
vuint16m4_t vadc(vuint16m4_t, uint16_t, vbool4_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vadc_vxm)))
vuint16m8_t vadc(vuint16m8_t, uint16_t, vbool2_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vadc_vxm)))
vuint16mf2_t vadc(vuint16mf2_t, uint16_t, vbool32_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vadc_vxm)))
vuint16mf4_t vadc(vuint16mf4_t, uint16_t, vbool64_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vadc_vxm)))
vuint32m1_t vadc(vuint32m1_t, uint32_t, vbool32_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vadc_vxm)))
vuint32m2_t vadc(vuint32m2_t, uint32_t, vbool16_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vadc_vxm)))
vuint32m4_t vadc(vuint32m4_t, uint32_t, vbool8_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vadc_vxm)))
vuint32m8_t vadc(vuint32m8_t, uint32_t, vbool4_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vadc_vxm)))
vuint32mf2_t vadc(vuint32mf2_t, uint32_t, vbool64_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vmadc_vvm)))
vbool8_t vmadc(vint8m1_t, vint8m1_t, vbool8_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vmadc_vvm)))
vbool4_t vmadc(vint8m2_t, vint8m2_t, vbool4_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vmadc_vvm)))
vbool2_t vmadc(vint8m4_t, vint8m4_t, vbool2_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vmadc_vvm)))
vbool1_t vmadc(vint8m8_t, vint8m8_t, vbool1_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vmadc_vvm)))
vbool16_t vmadc(vint8mf2_t, vint8mf2_t, vbool16_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vmadc_vvm)))
vbool32_t vmadc(vint8mf4_t, vint8mf4_t, vbool32_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vmadc_vvm)))
vbool64_t vmadc(vint8mf8_t, vint8mf8_t, vbool64_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vmadc_vvm)))
vbool16_t vmadc(vint16m1_t, vint16m1_t, vbool16_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vmadc_vvm)))
vbool8_t vmadc(vint16m2_t, vint16m2_t, vbool8_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vmadc_vvm)))
vbool4_t vmadc(vint16m4_t, vint16m4_t, vbool4_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vmadc_vvm)))
vbool2_t vmadc(vint16m8_t, vint16m8_t, vbool2_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vmadc_vvm)))
vbool32_t vmadc(vint16mf2_t, vint16mf2_t, vbool32_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vmadc_vvm)))
vbool64_t vmadc(vint16mf4_t, vint16mf4_t, vbool64_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vmadc_vvm)))
vbool32_t vmadc(vint32m1_t, vint32m1_t, vbool32_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vmadc_vvm)))
vbool16_t vmadc(vint32m2_t, vint32m2_t, vbool16_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vmadc_vvm)))
vbool8_t vmadc(vint32m4_t, vint32m4_t, vbool8_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vmadc_vvm)))
vbool4_t vmadc(vint32m8_t, vint32m8_t, vbool4_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vmadc_vvm)))
vbool64_t vmadc(vint32mf2_t, vint32mf2_t, vbool64_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vmadc_vxm)))
vbool8_t vmadc(vint8m1_t, int8_t, vbool8_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vmadc_vxm)))
vbool4_t vmadc(vint8m2_t, int8_t, vbool4_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vmadc_vxm)))
vbool2_t vmadc(vint8m4_t, int8_t, vbool2_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vmadc_vxm)))
vbool1_t vmadc(vint8m8_t, int8_t, vbool1_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vmadc_vxm)))
vbool16_t vmadc(vint8mf2_t, int8_t, vbool16_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vmadc_vxm)))
vbool32_t vmadc(vint8mf4_t, int8_t, vbool32_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vmadc_vxm)))
vbool64_t vmadc(vint8mf8_t, int8_t, vbool64_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vmadc_vxm)))
vbool16_t vmadc(vint16m1_t, int16_t, vbool16_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vmadc_vxm)))
vbool8_t vmadc(vint16m2_t, int16_t, vbool8_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vmadc_vxm)))
vbool4_t vmadc(vint16m4_t, int16_t, vbool4_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vmadc_vxm)))
vbool2_t vmadc(vint16m8_t, int16_t, vbool2_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vmadc_vxm)))
vbool32_t vmadc(vint16mf2_t, int16_t, vbool32_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vmadc_vxm)))
vbool64_t vmadc(vint16mf4_t, int16_t, vbool64_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vmadc_vxm)))
vbool32_t vmadc(vint32m1_t, int32_t, vbool32_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vmadc_vxm)))
vbool16_t vmadc(vint32m2_t, int32_t, vbool16_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vmadc_vxm)))
vbool8_t vmadc(vint32m4_t, int32_t, vbool8_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vmadc_vxm)))
vbool4_t vmadc(vint32m8_t, int32_t, vbool4_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vmadc_vxm)))
vbool64_t vmadc(vint32mf2_t, int32_t, vbool64_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vmadc_vvm)))
vbool8_t vmadc(vuint8m1_t, vuint8m1_t, vbool8_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vmadc_vvm)))
vbool4_t vmadc(vuint8m2_t, vuint8m2_t, vbool4_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vmadc_vvm)))
vbool2_t vmadc(vuint8m4_t, vuint8m4_t, vbool2_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vmadc_vvm)))
vbool1_t vmadc(vuint8m8_t, vuint8m8_t, vbool1_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vmadc_vvm)))
vbool16_t vmadc(vuint8mf2_t, vuint8mf2_t, vbool16_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vmadc_vvm)))
vbool32_t vmadc(vuint8mf4_t, vuint8mf4_t, vbool32_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vmadc_vvm)))
vbool64_t vmadc(vuint8mf8_t, vuint8mf8_t, vbool64_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vmadc_vvm)))
vbool16_t vmadc(vuint16m1_t, vuint16m1_t, vbool16_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vmadc_vvm)))
vbool8_t vmadc(vuint16m2_t, vuint16m2_t, vbool8_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vmadc_vvm)))
vbool4_t vmadc(vuint16m4_t, vuint16m4_t, vbool4_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vmadc_vvm)))
vbool2_t vmadc(vuint16m8_t, vuint16m8_t, vbool2_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vmadc_vvm)))
vbool32_t vmadc(vuint16mf2_t, vuint16mf2_t, vbool32_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vmadc_vvm)))
vbool64_t vmadc(vuint16mf4_t, vuint16mf4_t, vbool64_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vmadc_vvm)))
vbool32_t vmadc(vuint32m1_t, vuint32m1_t, vbool32_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vmadc_vvm)))
vbool16_t vmadc(vuint32m2_t, vuint32m2_t, vbool16_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vmadc_vvm)))
vbool8_t vmadc(vuint32m4_t, vuint32m4_t, vbool8_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vmadc_vvm)))
vbool4_t vmadc(vuint32m8_t, vuint32m8_t, vbool4_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vmadc_vvm)))
vbool64_t vmadc(vuint32mf2_t, vuint32mf2_t, vbool64_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vmadc_vxm)))
vbool8_t vmadc(vuint8m1_t, uint8_t, vbool8_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vmadc_vxm)))
vbool4_t vmadc(vuint8m2_t, uint8_t, vbool4_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vmadc_vxm)))
vbool2_t vmadc(vuint8m4_t, uint8_t, vbool2_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vmadc_vxm)))
vbool1_t vmadc(vuint8m8_t, uint8_t, vbool1_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vmadc_vxm)))
vbool16_t vmadc(vuint8mf2_t, uint8_t, vbool16_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vmadc_vxm)))
vbool32_t vmadc(vuint8mf4_t, uint8_t, vbool32_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vmadc_vxm)))
vbool64_t vmadc(vuint8mf8_t, uint8_t, vbool64_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vmadc_vxm)))
vbool16_t vmadc(vuint16m1_t, uint16_t, vbool16_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vmadc_vxm)))
vbool8_t vmadc(vuint16m2_t, uint16_t, vbool8_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vmadc_vxm)))
vbool4_t vmadc(vuint16m4_t, uint16_t, vbool4_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vmadc_vxm)))
vbool2_t vmadc(vuint16m8_t, uint16_t, vbool2_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vmadc_vxm)))
vbool32_t vmadc(vuint16mf2_t, uint16_t, vbool32_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vmadc_vxm)))
vbool64_t vmadc(vuint16mf4_t, uint16_t, vbool64_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vmadc_vxm)))
vbool32_t vmadc(vuint32m1_t, uint32_t, vbool32_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vmadc_vxm)))
vbool16_t vmadc(vuint32m2_t, uint32_t, vbool16_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vmadc_vxm)))
vbool8_t vmadc(vuint32m4_t, uint32_t, vbool8_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vmadc_vxm)))
vbool4_t vmadc(vuint32m8_t, uint32_t, vbool4_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vmadc_vxm)))
vbool64_t vmadc(vuint32mf2_t, uint32_t, vbool64_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vmadc_vv)))
vbool8_t vmadc(vint8m1_t, vint8m1_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vmadc_vv)))
vbool4_t vmadc(vint8m2_t, vint8m2_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vmadc_vv)))
vbool2_t vmadc(vint8m4_t, vint8m4_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vmadc_vv)))
vbool1_t vmadc(vint8m8_t, vint8m8_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vmadc_vv)))
vbool16_t vmadc(vint8mf2_t, vint8mf2_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vmadc_vv)))
vbool32_t vmadc(vint8mf4_t, vint8mf4_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vmadc_vv)))
vbool64_t vmadc(vint8mf8_t, vint8mf8_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vmadc_vv)))
vbool16_t vmadc(vint16m1_t, vint16m1_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vmadc_vv)))
vbool8_t vmadc(vint16m2_t, vint16m2_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vmadc_vv)))
vbool4_t vmadc(vint16m4_t, vint16m4_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vmadc_vv)))
vbool2_t vmadc(vint16m8_t, vint16m8_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vmadc_vv)))
vbool32_t vmadc(vint16mf2_t, vint16mf2_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vmadc_vv)))
vbool64_t vmadc(vint16mf4_t, vint16mf4_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vmadc_vv)))
vbool32_t vmadc(vint32m1_t, vint32m1_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vmadc_vv)))
vbool16_t vmadc(vint32m2_t, vint32m2_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vmadc_vv)))
vbool8_t vmadc(vint32m4_t, vint32m4_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vmadc_vv)))
vbool4_t vmadc(vint32m8_t, vint32m8_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vmadc_vv)))
vbool64_t vmadc(vint32mf2_t, vint32mf2_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vmadc_vx)))
vbool8_t vmadc(vint8m1_t, int8_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vmadc_vx)))
vbool4_t vmadc(vint8m2_t, int8_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vmadc_vx)))
vbool2_t vmadc(vint8m4_t, int8_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vmadc_vx)))
vbool1_t vmadc(vint8m8_t, int8_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vmadc_vx)))
vbool16_t vmadc(vint8mf2_t, int8_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vmadc_vx)))
vbool32_t vmadc(vint8mf4_t, int8_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vmadc_vx)))
vbool64_t vmadc(vint8mf8_t, int8_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vmadc_vx)))
vbool16_t vmadc(vint16m1_t, int16_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vmadc_vx)))
vbool8_t vmadc(vint16m2_t, int16_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vmadc_vx)))
vbool4_t vmadc(vint16m4_t, int16_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vmadc_vx)))
vbool2_t vmadc(vint16m8_t, int16_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vmadc_vx)))
vbool32_t vmadc(vint16mf2_t, int16_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vmadc_vx)))
vbool64_t vmadc(vint16mf4_t, int16_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vmadc_vx)))
vbool32_t vmadc(vint32m1_t, int32_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vmadc_vx)))
vbool16_t vmadc(vint32m2_t, int32_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vmadc_vx)))
vbool8_t vmadc(vint32m4_t, int32_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vmadc_vx)))
vbool4_t vmadc(vint32m8_t, int32_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vmadc_vx)))
vbool64_t vmadc(vint32mf2_t, int32_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vmadc_vv)))
vbool8_t vmadc(vuint8m1_t, vuint8m1_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vmadc_vv)))
vbool4_t vmadc(vuint8m2_t, vuint8m2_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vmadc_vv)))
vbool2_t vmadc(vuint8m4_t, vuint8m4_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vmadc_vv)))
vbool1_t vmadc(vuint8m8_t, vuint8m8_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vmadc_vv)))
vbool16_t vmadc(vuint8mf2_t, vuint8mf2_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vmadc_vv)))
vbool32_t vmadc(vuint8mf4_t, vuint8mf4_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vmadc_vv)))
vbool64_t vmadc(vuint8mf8_t, vuint8mf8_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vmadc_vv)))
vbool16_t vmadc(vuint16m1_t, vuint16m1_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vmadc_vv)))
vbool8_t vmadc(vuint16m2_t, vuint16m2_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vmadc_vv)))
vbool4_t vmadc(vuint16m4_t, vuint16m4_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vmadc_vv)))
vbool2_t vmadc(vuint16m8_t, vuint16m8_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vmadc_vv)))
vbool32_t vmadc(vuint16mf2_t, vuint16mf2_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vmadc_vv)))
vbool64_t vmadc(vuint16mf4_t, vuint16mf4_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vmadc_vv)))
vbool32_t vmadc(vuint32m1_t, vuint32m1_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vmadc_vv)))
vbool16_t vmadc(vuint32m2_t, vuint32m2_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vmadc_vv)))
vbool8_t vmadc(vuint32m4_t, vuint32m4_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vmadc_vv)))
vbool4_t vmadc(vuint32m8_t, vuint32m8_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vmadc_vv)))
vbool64_t vmadc(vuint32mf2_t, vuint32mf2_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vmadc_vx)))
vbool8_t vmadc(vuint8m1_t, uint8_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vmadc_vx)))
vbool4_t vmadc(vuint8m2_t, uint8_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vmadc_vx)))
vbool2_t vmadc(vuint8m4_t, uint8_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vmadc_vx)))
vbool1_t vmadc(vuint8m8_t, uint8_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vmadc_vx)))
vbool16_t vmadc(vuint8mf2_t, uint8_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vmadc_vx)))
vbool32_t vmadc(vuint8mf4_t, uint8_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vmadc_vx)))
vbool64_t vmadc(vuint8mf8_t, uint8_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vmadc_vx)))
vbool16_t vmadc(vuint16m1_t, uint16_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vmadc_vx)))
vbool8_t vmadc(vuint16m2_t, uint16_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vmadc_vx)))
vbool4_t vmadc(vuint16m4_t, uint16_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vmadc_vx)))
vbool2_t vmadc(vuint16m8_t, uint16_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vmadc_vx)))
vbool32_t vmadc(vuint16mf2_t, uint16_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vmadc_vx)))
vbool64_t vmadc(vuint16mf4_t, uint16_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vmadc_vx)))
vbool32_t vmadc(vuint32m1_t, uint32_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vmadc_vx)))
vbool16_t vmadc(vuint32m2_t, uint32_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vmadc_vx)))
vbool8_t vmadc(vuint32m4_t, uint32_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vmadc_vx)))
vbool4_t vmadc(vuint32m8_t, uint32_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vmadc_vx)))
vbool64_t vmadc(vuint32mf2_t, uint32_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vsbc_vvm)))
vint8m1_t vsbc(vint8m1_t, vint8m1_t, vbool8_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vsbc_vvm)))
vint8m2_t vsbc(vint8m2_t, vint8m2_t, vbool4_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vsbc_vvm)))
vint8m4_t vsbc(vint8m4_t, vint8m4_t, vbool2_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vsbc_vvm)))
vint8m8_t vsbc(vint8m8_t, vint8m8_t, vbool1_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vsbc_vvm)))
vint8mf2_t vsbc(vint8mf2_t, vint8mf2_t, vbool16_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vsbc_vvm)))
vint8mf4_t vsbc(vint8mf4_t, vint8mf4_t, vbool32_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vsbc_vvm)))
vint8mf8_t vsbc(vint8mf8_t, vint8mf8_t, vbool64_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vsbc_vvm)))
vint16m1_t vsbc(vint16m1_t, vint16m1_t, vbool16_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vsbc_vvm)))
vint16m2_t vsbc(vint16m2_t, vint16m2_t, vbool8_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vsbc_vvm)))
vint16m4_t vsbc(vint16m4_t, vint16m4_t, vbool4_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vsbc_vvm)))
vint16m8_t vsbc(vint16m8_t, vint16m8_t, vbool2_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vsbc_vvm)))
vint16mf2_t vsbc(vint16mf2_t, vint16mf2_t, vbool32_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vsbc_vvm)))
vint16mf4_t vsbc(vint16mf4_t, vint16mf4_t, vbool64_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vsbc_vvm)))
vint32m1_t vsbc(vint32m1_t, vint32m1_t, vbool32_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vsbc_vvm)))
vint32m2_t vsbc(vint32m2_t, vint32m2_t, vbool16_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vsbc_vvm)))
vint32m4_t vsbc(vint32m4_t, vint32m4_t, vbool8_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vsbc_vvm)))
vint32m8_t vsbc(vint32m8_t, vint32m8_t, vbool4_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vsbc_vvm)))
vint32mf2_t vsbc(vint32mf2_t, vint32mf2_t, vbool64_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vsbc_vxm)))
vint8m1_t vsbc(vint8m1_t, int8_t, vbool8_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vsbc_vxm)))
vint8m2_t vsbc(vint8m2_t, int8_t, vbool4_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vsbc_vxm)))
vint8m4_t vsbc(vint8m4_t, int8_t, vbool2_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vsbc_vxm)))
vint8m8_t vsbc(vint8m8_t, int8_t, vbool1_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vsbc_vxm)))
vint8mf2_t vsbc(vint8mf2_t, int8_t, vbool16_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vsbc_vxm)))
vint8mf4_t vsbc(vint8mf4_t, int8_t, vbool32_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vsbc_vxm)))
vint8mf8_t vsbc(vint8mf8_t, int8_t, vbool64_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vsbc_vxm)))
vint16m1_t vsbc(vint16m1_t, int16_t, vbool16_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vsbc_vxm)))
vint16m2_t vsbc(vint16m2_t, int16_t, vbool8_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vsbc_vxm)))
vint16m4_t vsbc(vint16m4_t, int16_t, vbool4_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vsbc_vxm)))
vint16m8_t vsbc(vint16m8_t, int16_t, vbool2_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vsbc_vxm)))
vint16mf2_t vsbc(vint16mf2_t, int16_t, vbool32_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vsbc_vxm)))
vint16mf4_t vsbc(vint16mf4_t, int16_t, vbool64_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vsbc_vxm)))
vint32m1_t vsbc(vint32m1_t, int32_t, vbool32_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vsbc_vxm)))
vint32m2_t vsbc(vint32m2_t, int32_t, vbool16_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vsbc_vxm)))
vint32m4_t vsbc(vint32m4_t, int32_t, vbool8_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vsbc_vxm)))
vint32m8_t vsbc(vint32m8_t, int32_t, vbool4_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vsbc_vxm)))
vint32mf2_t vsbc(vint32mf2_t, int32_t, vbool64_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vsbc_vvm)))
vuint8m1_t vsbc(vuint8m1_t, vuint8m1_t, vbool8_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vsbc_vvm)))
vuint8m2_t vsbc(vuint8m2_t, vuint8m2_t, vbool4_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vsbc_vvm)))
vuint8m4_t vsbc(vuint8m4_t, vuint8m4_t, vbool2_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vsbc_vvm)))
vuint8m8_t vsbc(vuint8m8_t, vuint8m8_t, vbool1_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vsbc_vvm)))
vuint8mf2_t vsbc(vuint8mf2_t, vuint8mf2_t, vbool16_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vsbc_vvm)))
vuint8mf4_t vsbc(vuint8mf4_t, vuint8mf4_t, vbool32_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vsbc_vvm)))
vuint8mf8_t vsbc(vuint8mf8_t, vuint8mf8_t, vbool64_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vsbc_vvm)))
vuint16m1_t vsbc(vuint16m1_t, vuint16m1_t, vbool16_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vsbc_vvm)))
vuint16m2_t vsbc(vuint16m2_t, vuint16m2_t, vbool8_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vsbc_vvm)))
vuint16m4_t vsbc(vuint16m4_t, vuint16m4_t, vbool4_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vsbc_vvm)))
vuint16m8_t vsbc(vuint16m8_t, vuint16m8_t, vbool2_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vsbc_vvm)))
vuint16mf2_t vsbc(vuint16mf2_t, vuint16mf2_t, vbool32_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vsbc_vvm)))
vuint16mf4_t vsbc(vuint16mf4_t, vuint16mf4_t, vbool64_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vsbc_vvm)))
vuint32m1_t vsbc(vuint32m1_t, vuint32m1_t, vbool32_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vsbc_vvm)))
vuint32m2_t vsbc(vuint32m2_t, vuint32m2_t, vbool16_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vsbc_vvm)))
vuint32m4_t vsbc(vuint32m4_t, vuint32m4_t, vbool8_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vsbc_vvm)))
vuint32m8_t vsbc(vuint32m8_t, vuint32m8_t, vbool4_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vsbc_vvm)))
vuint32mf2_t vsbc(vuint32mf2_t, vuint32mf2_t, vbool64_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vsbc_vxm)))
vuint8m1_t vsbc(vuint8m1_t, uint8_t, vbool8_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vsbc_vxm)))
vuint8m2_t vsbc(vuint8m2_t, uint8_t, vbool4_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vsbc_vxm)))
vuint8m4_t vsbc(vuint8m4_t, uint8_t, vbool2_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vsbc_vxm)))
vuint8m8_t vsbc(vuint8m8_t, uint8_t, vbool1_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vsbc_vxm)))
vuint8mf2_t vsbc(vuint8mf2_t, uint8_t, vbool16_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vsbc_vxm)))
vuint8mf4_t vsbc(vuint8mf4_t, uint8_t, vbool32_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vsbc_vxm)))
vuint8mf8_t vsbc(vuint8mf8_t, uint8_t, vbool64_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vsbc_vxm)))
vuint16m1_t vsbc(vuint16m1_t, uint16_t, vbool16_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vsbc_vxm)))
vuint16m2_t vsbc(vuint16m2_t, uint16_t, vbool8_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vsbc_vxm)))
vuint16m4_t vsbc(vuint16m4_t, uint16_t, vbool4_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vsbc_vxm)))
vuint16m8_t vsbc(vuint16m8_t, uint16_t, vbool2_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vsbc_vxm)))
vuint16mf2_t vsbc(vuint16mf2_t, uint16_t, vbool32_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vsbc_vxm)))
vuint16mf4_t vsbc(vuint16mf4_t, uint16_t, vbool64_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vsbc_vxm)))
vuint32m1_t vsbc(vuint32m1_t, uint32_t, vbool32_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vsbc_vxm)))
vuint32m2_t vsbc(vuint32m2_t, uint32_t, vbool16_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vsbc_vxm)))
vuint32m4_t vsbc(vuint32m4_t, uint32_t, vbool8_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vsbc_vxm)))
vuint32m8_t vsbc(vuint32m8_t, uint32_t, vbool4_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vsbc_vxm)))
vuint32mf2_t vsbc(vuint32mf2_t, uint32_t, vbool64_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vmsbc_vvm)))
vbool8_t vmsbc(vint8m1_t, vint8m1_t, vbool8_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vmsbc_vvm)))
vbool4_t vmsbc(vint8m2_t, vint8m2_t, vbool4_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vmsbc_vvm)))
vbool2_t vmsbc(vint8m4_t, vint8m4_t, vbool2_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vmsbc_vvm)))
vbool1_t vmsbc(vint8m8_t, vint8m8_t, vbool1_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vmsbc_vvm)))
vbool16_t vmsbc(vint8mf2_t, vint8mf2_t, vbool16_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vmsbc_vvm)))
vbool32_t vmsbc(vint8mf4_t, vint8mf4_t, vbool32_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vmsbc_vvm)))
vbool64_t vmsbc(vint8mf8_t, vint8mf8_t, vbool64_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vmsbc_vvm)))
vbool16_t vmsbc(vint16m1_t, vint16m1_t, vbool16_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vmsbc_vvm)))
vbool8_t vmsbc(vint16m2_t, vint16m2_t, vbool8_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vmsbc_vvm)))
vbool4_t vmsbc(vint16m4_t, vint16m4_t, vbool4_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vmsbc_vvm)))
vbool2_t vmsbc(vint16m8_t, vint16m8_t, vbool2_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vmsbc_vvm)))
vbool32_t vmsbc(vint16mf2_t, vint16mf2_t, vbool32_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vmsbc_vvm)))
vbool64_t vmsbc(vint16mf4_t, vint16mf4_t, vbool64_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vmsbc_vvm)))
vbool32_t vmsbc(vint32m1_t, vint32m1_t, vbool32_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vmsbc_vvm)))
vbool16_t vmsbc(vint32m2_t, vint32m2_t, vbool16_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vmsbc_vvm)))
vbool8_t vmsbc(vint32m4_t, vint32m4_t, vbool8_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vmsbc_vvm)))
vbool4_t vmsbc(vint32m8_t, vint32m8_t, vbool4_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vmsbc_vvm)))
vbool64_t vmsbc(vint32mf2_t, vint32mf2_t, vbool64_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vmsbc_vxm)))
vbool8_t vmsbc(vint8m1_t, int8_t, vbool8_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vmsbc_vxm)))
vbool4_t vmsbc(vint8m2_t, int8_t, vbool4_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vmsbc_vxm)))
vbool2_t vmsbc(vint8m4_t, int8_t, vbool2_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vmsbc_vxm)))
vbool1_t vmsbc(vint8m8_t, int8_t, vbool1_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vmsbc_vxm)))
vbool16_t vmsbc(vint8mf2_t, int8_t, vbool16_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vmsbc_vxm)))
vbool32_t vmsbc(vint8mf4_t, int8_t, vbool32_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vmsbc_vxm)))
vbool64_t vmsbc(vint8mf8_t, int8_t, vbool64_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vmsbc_vxm)))
vbool16_t vmsbc(vint16m1_t, int16_t, vbool16_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vmsbc_vxm)))
vbool8_t vmsbc(vint16m2_t, int16_t, vbool8_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vmsbc_vxm)))
vbool4_t vmsbc(vint16m4_t, int16_t, vbool4_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vmsbc_vxm)))
vbool2_t vmsbc(vint16m8_t, int16_t, vbool2_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vmsbc_vxm)))
vbool32_t vmsbc(vint16mf2_t, int16_t, vbool32_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vmsbc_vxm)))
vbool64_t vmsbc(vint16mf4_t, int16_t, vbool64_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vmsbc_vxm)))
vbool32_t vmsbc(vint32m1_t, int32_t, vbool32_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vmsbc_vxm)))
vbool16_t vmsbc(vint32m2_t, int32_t, vbool16_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vmsbc_vxm)))
vbool8_t vmsbc(vint32m4_t, int32_t, vbool8_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vmsbc_vxm)))
vbool4_t vmsbc(vint32m8_t, int32_t, vbool4_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vmsbc_vxm)))
vbool64_t vmsbc(vint32mf2_t, int32_t, vbool64_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vmsbc_vvm)))
vbool8_t vmsbc(vuint8m1_t, vuint8m1_t, vbool8_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vmsbc_vvm)))
vbool4_t vmsbc(vuint8m2_t, vuint8m2_t, vbool4_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vmsbc_vvm)))
vbool2_t vmsbc(vuint8m4_t, vuint8m4_t, vbool2_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vmsbc_vvm)))
vbool1_t vmsbc(vuint8m8_t, vuint8m8_t, vbool1_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vmsbc_vvm)))
vbool16_t vmsbc(vuint8mf2_t, vuint8mf2_t, vbool16_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vmsbc_vvm)))
vbool32_t vmsbc(vuint8mf4_t, vuint8mf4_t, vbool32_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vmsbc_vvm)))
vbool64_t vmsbc(vuint8mf8_t, vuint8mf8_t, vbool64_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vmsbc_vvm)))
vbool16_t vmsbc(vuint16m1_t, vuint16m1_t, vbool16_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vmsbc_vvm)))
vbool8_t vmsbc(vuint16m2_t, vuint16m2_t, vbool8_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vmsbc_vvm)))
vbool4_t vmsbc(vuint16m4_t, vuint16m4_t, vbool4_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vmsbc_vvm)))
vbool2_t vmsbc(vuint16m8_t, vuint16m8_t, vbool2_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vmsbc_vvm)))
vbool32_t vmsbc(vuint16mf2_t, vuint16mf2_t, vbool32_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vmsbc_vvm)))
vbool64_t vmsbc(vuint16mf4_t, vuint16mf4_t, vbool64_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vmsbc_vvm)))
vbool32_t vmsbc(vuint32m1_t, vuint32m1_t, vbool32_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vmsbc_vvm)))
vbool16_t vmsbc(vuint32m2_t, vuint32m2_t, vbool16_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vmsbc_vvm)))
vbool8_t vmsbc(vuint32m4_t, vuint32m4_t, vbool8_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vmsbc_vvm)))
vbool4_t vmsbc(vuint32m8_t, vuint32m8_t, vbool4_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vmsbc_vvm)))
vbool64_t vmsbc(vuint32mf2_t, vuint32mf2_t, vbool64_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vmsbc_vxm)))
vbool8_t vmsbc(vuint8m1_t, uint8_t, vbool8_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vmsbc_vxm)))
vbool4_t vmsbc(vuint8m2_t, uint8_t, vbool4_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vmsbc_vxm)))
vbool2_t vmsbc(vuint8m4_t, uint8_t, vbool2_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vmsbc_vxm)))
vbool1_t vmsbc(vuint8m8_t, uint8_t, vbool1_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vmsbc_vxm)))
vbool16_t vmsbc(vuint8mf2_t, uint8_t, vbool16_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vmsbc_vxm)))
vbool32_t vmsbc(vuint8mf4_t, uint8_t, vbool32_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vmsbc_vxm)))
vbool64_t vmsbc(vuint8mf8_t, uint8_t, vbool64_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vmsbc_vxm)))
vbool16_t vmsbc(vuint16m1_t, uint16_t, vbool16_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vmsbc_vxm)))
vbool8_t vmsbc(vuint16m2_t, uint16_t, vbool8_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vmsbc_vxm)))
vbool4_t vmsbc(vuint16m4_t, uint16_t, vbool4_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vmsbc_vxm)))
vbool2_t vmsbc(vuint16m8_t, uint16_t, vbool2_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vmsbc_vxm)))
vbool32_t vmsbc(vuint16mf2_t, uint16_t, vbool32_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vmsbc_vxm)))
vbool64_t vmsbc(vuint16mf4_t, uint16_t, vbool64_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vmsbc_vxm)))
vbool32_t vmsbc(vuint32m1_t, uint32_t, vbool32_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vmsbc_vxm)))
vbool16_t vmsbc(vuint32m2_t, uint32_t, vbool16_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vmsbc_vxm)))
vbool8_t vmsbc(vuint32m4_t, uint32_t, vbool8_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vmsbc_vxm)))
vbool4_t vmsbc(vuint32m8_t, uint32_t, vbool4_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vmsbc_vxm)))
vbool64_t vmsbc(vuint32mf2_t, uint32_t, vbool64_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vmsbc_vv)))
vbool8_t vmsbc(vint8m1_t, vint8m1_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vmsbc_vv)))
vbool4_t vmsbc(vint8m2_t, vint8m2_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vmsbc_vv)))
vbool2_t vmsbc(vint8m4_t, vint8m4_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vmsbc_vv)))
vbool1_t vmsbc(vint8m8_t, vint8m8_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vmsbc_vv)))
vbool16_t vmsbc(vint8mf2_t, vint8mf2_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vmsbc_vv)))
vbool32_t vmsbc(vint8mf4_t, vint8mf4_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vmsbc_vv)))
vbool64_t vmsbc(vint8mf8_t, vint8mf8_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vmsbc_vv)))
vbool16_t vmsbc(vint16m1_t, vint16m1_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vmsbc_vv)))
vbool8_t vmsbc(vint16m2_t, vint16m2_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vmsbc_vv)))
vbool4_t vmsbc(vint16m4_t, vint16m4_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vmsbc_vv)))
vbool2_t vmsbc(vint16m8_t, vint16m8_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vmsbc_vv)))
vbool32_t vmsbc(vint16mf2_t, vint16mf2_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vmsbc_vv)))
vbool64_t vmsbc(vint16mf4_t, vint16mf4_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vmsbc_vv)))
vbool32_t vmsbc(vint32m1_t, vint32m1_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vmsbc_vv)))
vbool16_t vmsbc(vint32m2_t, vint32m2_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vmsbc_vv)))
vbool8_t vmsbc(vint32m4_t, vint32m4_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vmsbc_vv)))
vbool4_t vmsbc(vint32m8_t, vint32m8_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vmsbc_vv)))
vbool64_t vmsbc(vint32mf2_t, vint32mf2_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vmsbc_vx)))
vbool8_t vmsbc(vint8m1_t, int8_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vmsbc_vx)))
vbool4_t vmsbc(vint8m2_t, int8_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vmsbc_vx)))
vbool2_t vmsbc(vint8m4_t, int8_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vmsbc_vx)))
vbool1_t vmsbc(vint8m8_t, int8_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vmsbc_vx)))
vbool16_t vmsbc(vint8mf2_t, int8_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vmsbc_vx)))
vbool32_t vmsbc(vint8mf4_t, int8_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vmsbc_vx)))
vbool64_t vmsbc(vint8mf8_t, int8_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vmsbc_vx)))
vbool16_t vmsbc(vint16m1_t, int16_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vmsbc_vx)))
vbool8_t vmsbc(vint16m2_t, int16_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vmsbc_vx)))
vbool4_t vmsbc(vint16m4_t, int16_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vmsbc_vx)))
vbool2_t vmsbc(vint16m8_t, int16_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vmsbc_vx)))
vbool32_t vmsbc(vint16mf2_t, int16_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vmsbc_vx)))
vbool64_t vmsbc(vint16mf4_t, int16_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vmsbc_vx)))
vbool32_t vmsbc(vint32m1_t, int32_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vmsbc_vx)))
vbool16_t vmsbc(vint32m2_t, int32_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vmsbc_vx)))
vbool8_t vmsbc(vint32m4_t, int32_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vmsbc_vx)))
vbool4_t vmsbc(vint32m8_t, int32_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vmsbc_vx)))
vbool64_t vmsbc(vint32mf2_t, int32_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vmsbc_vv)))
vbool8_t vmsbc(vuint8m1_t, vuint8m1_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vmsbc_vv)))
vbool4_t vmsbc(vuint8m2_t, vuint8m2_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vmsbc_vv)))
vbool2_t vmsbc(vuint8m4_t, vuint8m4_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vmsbc_vv)))
vbool1_t vmsbc(vuint8m8_t, vuint8m8_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vmsbc_vv)))
vbool16_t vmsbc(vuint8mf2_t, vuint8mf2_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vmsbc_vv)))
vbool32_t vmsbc(vuint8mf4_t, vuint8mf4_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vmsbc_vv)))
vbool64_t vmsbc(vuint8mf8_t, vuint8mf8_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vmsbc_vv)))
vbool16_t vmsbc(vuint16m1_t, vuint16m1_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vmsbc_vv)))
vbool8_t vmsbc(vuint16m2_t, vuint16m2_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vmsbc_vv)))
vbool4_t vmsbc(vuint16m4_t, vuint16m4_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vmsbc_vv)))
vbool2_t vmsbc(vuint16m8_t, vuint16m8_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vmsbc_vv)))
vbool32_t vmsbc(vuint16mf2_t, vuint16mf2_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vmsbc_vv)))
vbool64_t vmsbc(vuint16mf4_t, vuint16mf4_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vmsbc_vv)))
vbool32_t vmsbc(vuint32m1_t, vuint32m1_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vmsbc_vv)))
vbool16_t vmsbc(vuint32m2_t, vuint32m2_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vmsbc_vv)))
vbool8_t vmsbc(vuint32m4_t, vuint32m4_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vmsbc_vv)))
vbool4_t vmsbc(vuint32m8_t, vuint32m8_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vmsbc_vv)))
vbool64_t vmsbc(vuint32mf2_t, vuint32mf2_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vmsbc_vx)))
vbool8_t vmsbc(vuint8m1_t, uint8_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vmsbc_vx)))
vbool4_t vmsbc(vuint8m2_t, uint8_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vmsbc_vx)))
vbool2_t vmsbc(vuint8m4_t, uint8_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vmsbc_vx)))
vbool1_t vmsbc(vuint8m8_t, uint8_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vmsbc_vx)))
vbool16_t vmsbc(vuint8mf2_t, uint8_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vmsbc_vx)))
vbool32_t vmsbc(vuint8mf4_t, uint8_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vmsbc_vx)))
vbool64_t vmsbc(vuint8mf8_t, uint8_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vmsbc_vx)))
vbool16_t vmsbc(vuint16m1_t, uint16_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vmsbc_vx)))
vbool8_t vmsbc(vuint16m2_t, uint16_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vmsbc_vx)))
vbool4_t vmsbc(vuint16m4_t, uint16_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vmsbc_vx)))
vbool2_t vmsbc(vuint16m8_t, uint16_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vmsbc_vx)))
vbool32_t vmsbc(vuint16mf2_t, uint16_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vmsbc_vx)))
vbool64_t vmsbc(vuint16mf4_t, uint16_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vmsbc_vx)))
vbool32_t vmsbc(vuint32m1_t, uint32_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vmsbc_vx)))
vbool16_t vmsbc(vuint32m2_t, uint32_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vmsbc_vx)))
vbool8_t vmsbc(vuint32m4_t, uint32_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vmsbc_vx)))
vbool4_t vmsbc(vuint32m8_t, uint32_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vmsbc_vx)))
vbool64_t vmsbc(vuint32mf2_t, uint32_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vand_vv)))
vint8m1_t vand(vint8m1_t, vint8m1_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vand_vv_m)))
vint8m1_t vand(vbool8_t, vint8m1_t, vint8m1_t, vint8m1_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vand_vv)))
vint8m2_t vand(vint8m2_t, vint8m2_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vand_vv_m)))
vint8m2_t vand(vbool4_t, vint8m2_t, vint8m2_t, vint8m2_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vand_vv)))
vint8m4_t vand(vint8m4_t, vint8m4_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vand_vv_m)))
vint8m4_t vand(vbool2_t, vint8m4_t, vint8m4_t, vint8m4_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vand_vv)))
vint8m8_t vand(vint8m8_t, vint8m8_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vand_vv_m)))
vint8m8_t vand(vbool1_t, vint8m8_t, vint8m8_t, vint8m8_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vand_vv)))
vint8mf2_t vand(vint8mf2_t, vint8mf2_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vand_vv_m)))
vint8mf2_t vand(vbool16_t, vint8mf2_t, vint8mf2_t, vint8mf2_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vand_vv)))
vint8mf4_t vand(vint8mf4_t, vint8mf4_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vand_vv_m)))
vint8mf4_t vand(vbool32_t, vint8mf4_t, vint8mf4_t, vint8mf4_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vand_vv)))
vint8mf8_t vand(vint8mf8_t, vint8mf8_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vand_vv_m)))
vint8mf8_t vand(vbool64_t, vint8mf8_t, vint8mf8_t, vint8mf8_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vand_vv)))
vint16m1_t vand(vint16m1_t, vint16m1_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vand_vv_m)))
vint16m1_t vand(vbool16_t, vint16m1_t, vint16m1_t, vint16m1_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vand_vv)))
vint16m2_t vand(vint16m2_t, vint16m2_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vand_vv_m)))
vint16m2_t vand(vbool8_t, vint16m2_t, vint16m2_t, vint16m2_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vand_vv)))
vint16m4_t vand(vint16m4_t, vint16m4_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vand_vv_m)))
vint16m4_t vand(vbool4_t, vint16m4_t, vint16m4_t, vint16m4_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vand_vv)))
vint16m8_t vand(vint16m8_t, vint16m8_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vand_vv_m)))
vint16m8_t vand(vbool2_t, vint16m8_t, vint16m8_t, vint16m8_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vand_vv)))
vint16mf2_t vand(vint16mf2_t, vint16mf2_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vand_vv_m)))
vint16mf2_t vand(vbool32_t, vint16mf2_t, vint16mf2_t, vint16mf2_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vand_vv)))
vint16mf4_t vand(vint16mf4_t, vint16mf4_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vand_vv_m)))
vint16mf4_t vand(vbool64_t, vint16mf4_t, vint16mf4_t, vint16mf4_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vand_vv)))
vint32m1_t vand(vint32m1_t, vint32m1_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vand_vv_m)))
vint32m1_t vand(vbool32_t, vint32m1_t, vint32m1_t, vint32m1_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vand_vv)))
vint32m2_t vand(vint32m2_t, vint32m2_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vand_vv_m)))
vint32m2_t vand(vbool16_t, vint32m2_t, vint32m2_t, vint32m2_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vand_vv)))
vint32m4_t vand(vint32m4_t, vint32m4_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vand_vv_m)))
vint32m4_t vand(vbool8_t, vint32m4_t, vint32m4_t, vint32m4_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vand_vv)))
vint32m8_t vand(vint32m8_t, vint32m8_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vand_vv_m)))
vint32m8_t vand(vbool4_t, vint32m8_t, vint32m8_t, vint32m8_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vand_vv)))
vint32mf2_t vand(vint32mf2_t, vint32mf2_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vand_vv_m)))
vint32mf2_t vand(vbool64_t, vint32mf2_t, vint32mf2_t, vint32mf2_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vand_vx)))
vint8m1_t vand(vint8m1_t, int8_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vand_vx_m)))
vint8m1_t vand(vbool8_t, vint8m1_t, vint8m1_t, int8_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vand_vx)))
vint8m2_t vand(vint8m2_t, int8_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vand_vx_m)))
vint8m2_t vand(vbool4_t, vint8m2_t, vint8m2_t, int8_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vand_vx)))
vint8m4_t vand(vint8m4_t, int8_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vand_vx_m)))
vint8m4_t vand(vbool2_t, vint8m4_t, vint8m4_t, int8_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vand_vx)))
vint8m8_t vand(vint8m8_t, int8_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vand_vx_m)))
vint8m8_t vand(vbool1_t, vint8m8_t, vint8m8_t, int8_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vand_vx)))
vint8mf2_t vand(vint8mf2_t, int8_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vand_vx_m)))
vint8mf2_t vand(vbool16_t, vint8mf2_t, vint8mf2_t, int8_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vand_vx)))
vint8mf4_t vand(vint8mf4_t, int8_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vand_vx_m)))
vint8mf4_t vand(vbool32_t, vint8mf4_t, vint8mf4_t, int8_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vand_vx)))
vint8mf8_t vand(vint8mf8_t, int8_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vand_vx_m)))
vint8mf8_t vand(vbool64_t, vint8mf8_t, vint8mf8_t, int8_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vand_vx)))
vint16m1_t vand(vint16m1_t, int16_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vand_vx_m)))
vint16m1_t vand(vbool16_t, vint16m1_t, vint16m1_t, int16_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vand_vx)))
vint16m2_t vand(vint16m2_t, int16_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vand_vx_m)))
vint16m2_t vand(vbool8_t, vint16m2_t, vint16m2_t, int16_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vand_vx)))
vint16m4_t vand(vint16m4_t, int16_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vand_vx_m)))
vint16m4_t vand(vbool4_t, vint16m4_t, vint16m4_t, int16_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vand_vx)))
vint16m8_t vand(vint16m8_t, int16_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vand_vx_m)))
vint16m8_t vand(vbool2_t, vint16m8_t, vint16m8_t, int16_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vand_vx)))
vint16mf2_t vand(vint16mf2_t, int16_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vand_vx_m)))
vint16mf2_t vand(vbool32_t, vint16mf2_t, vint16mf2_t, int16_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vand_vx)))
vint16mf4_t vand(vint16mf4_t, int16_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vand_vx_m)))
vint16mf4_t vand(vbool64_t, vint16mf4_t, vint16mf4_t, int16_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vand_vx)))
vint32m1_t vand(vint32m1_t, int32_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vand_vx_m)))
vint32m1_t vand(vbool32_t, vint32m1_t, vint32m1_t, int32_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vand_vx)))
vint32m2_t vand(vint32m2_t, int32_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vand_vx_m)))
vint32m2_t vand(vbool16_t, vint32m2_t, vint32m2_t, int32_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vand_vx)))
vint32m4_t vand(vint32m4_t, int32_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vand_vx_m)))
vint32m4_t vand(vbool8_t, vint32m4_t, vint32m4_t, int32_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vand_vx)))
vint32m8_t vand(vint32m8_t, int32_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vand_vx_m)))
vint32m8_t vand(vbool4_t, vint32m8_t, vint32m8_t, int32_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vand_vx)))
vint32mf2_t vand(vint32mf2_t, int32_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vand_vx_m)))
vint32mf2_t vand(vbool64_t, vint32mf2_t, vint32mf2_t, int32_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vand_vv)))
vuint8m1_t vand(vuint8m1_t, vuint8m1_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vand_vv_m)))
vuint8m1_t vand(vbool8_t, vuint8m1_t, vuint8m1_t, vuint8m1_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vand_vv)))
vuint8m2_t vand(vuint8m2_t, vuint8m2_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vand_vv_m)))
vuint8m2_t vand(vbool4_t, vuint8m2_t, vuint8m2_t, vuint8m2_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vand_vv)))
vuint8m4_t vand(vuint8m4_t, vuint8m4_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vand_vv_m)))
vuint8m4_t vand(vbool2_t, vuint8m4_t, vuint8m4_t, vuint8m4_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vand_vv)))
vuint8m8_t vand(vuint8m8_t, vuint8m8_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vand_vv_m)))
vuint8m8_t vand(vbool1_t, vuint8m8_t, vuint8m8_t, vuint8m8_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vand_vv)))
vuint8mf2_t vand(vuint8mf2_t, vuint8mf2_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vand_vv_m)))
vuint8mf2_t vand(vbool16_t, vuint8mf2_t, vuint8mf2_t, vuint8mf2_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vand_vv)))
vuint8mf4_t vand(vuint8mf4_t, vuint8mf4_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vand_vv_m)))
vuint8mf4_t vand(vbool32_t, vuint8mf4_t, vuint8mf4_t, vuint8mf4_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vand_vv)))
vuint8mf8_t vand(vuint8mf8_t, vuint8mf8_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vand_vv_m)))
vuint8mf8_t vand(vbool64_t, vuint8mf8_t, vuint8mf8_t, vuint8mf8_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vand_vv)))
vuint16m1_t vand(vuint16m1_t, vuint16m1_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vand_vv_m)))
vuint16m1_t vand(vbool16_t, vuint16m1_t, vuint16m1_t, vuint16m1_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vand_vv)))
vuint16m2_t vand(vuint16m2_t, vuint16m2_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vand_vv_m)))
vuint16m2_t vand(vbool8_t, vuint16m2_t, vuint16m2_t, vuint16m2_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vand_vv)))
vuint16m4_t vand(vuint16m4_t, vuint16m4_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vand_vv_m)))
vuint16m4_t vand(vbool4_t, vuint16m4_t, vuint16m4_t, vuint16m4_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vand_vv)))
vuint16m8_t vand(vuint16m8_t, vuint16m8_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vand_vv_m)))
vuint16m8_t vand(vbool2_t, vuint16m8_t, vuint16m8_t, vuint16m8_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vand_vv)))
vuint16mf2_t vand(vuint16mf2_t, vuint16mf2_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vand_vv_m)))
vuint16mf2_t vand(vbool32_t, vuint16mf2_t, vuint16mf2_t, vuint16mf2_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vand_vv)))
vuint16mf4_t vand(vuint16mf4_t, vuint16mf4_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vand_vv_m)))
vuint16mf4_t vand(vbool64_t, vuint16mf4_t, vuint16mf4_t, vuint16mf4_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vand_vv)))
vuint32m1_t vand(vuint32m1_t, vuint32m1_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vand_vv_m)))
vuint32m1_t vand(vbool32_t, vuint32m1_t, vuint32m1_t, vuint32m1_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vand_vv)))
vuint32m2_t vand(vuint32m2_t, vuint32m2_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vand_vv_m)))
vuint32m2_t vand(vbool16_t, vuint32m2_t, vuint32m2_t, vuint32m2_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vand_vv)))
vuint32m4_t vand(vuint32m4_t, vuint32m4_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vand_vv_m)))
vuint32m4_t vand(vbool8_t, vuint32m4_t, vuint32m4_t, vuint32m4_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vand_vv)))
vuint32m8_t vand(vuint32m8_t, vuint32m8_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vand_vv_m)))
vuint32m8_t vand(vbool4_t, vuint32m8_t, vuint32m8_t, vuint32m8_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vand_vv)))
vuint32mf2_t vand(vuint32mf2_t, vuint32mf2_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vand_vv_m)))
vuint32mf2_t vand(vbool64_t, vuint32mf2_t, vuint32mf2_t, vuint32mf2_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vand_vx)))
vuint8m1_t vand(vuint8m1_t, uint8_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vand_vx_m)))
vuint8m1_t vand(vbool8_t, vuint8m1_t, vuint8m1_t, uint8_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vand_vx)))
vuint8m2_t vand(vuint8m2_t, uint8_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vand_vx_m)))
vuint8m2_t vand(vbool4_t, vuint8m2_t, vuint8m2_t, uint8_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vand_vx)))
vuint8m4_t vand(vuint8m4_t, uint8_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vand_vx_m)))
vuint8m4_t vand(vbool2_t, vuint8m4_t, vuint8m4_t, uint8_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vand_vx)))
vuint8m8_t vand(vuint8m8_t, uint8_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vand_vx_m)))
vuint8m8_t vand(vbool1_t, vuint8m8_t, vuint8m8_t, uint8_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vand_vx)))
vuint8mf2_t vand(vuint8mf2_t, uint8_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vand_vx_m)))
vuint8mf2_t vand(vbool16_t, vuint8mf2_t, vuint8mf2_t, uint8_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vand_vx)))
vuint8mf4_t vand(vuint8mf4_t, uint8_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vand_vx_m)))
vuint8mf4_t vand(vbool32_t, vuint8mf4_t, vuint8mf4_t, uint8_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vand_vx)))
vuint8mf8_t vand(vuint8mf8_t, uint8_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vand_vx_m)))
vuint8mf8_t vand(vbool64_t, vuint8mf8_t, vuint8mf8_t, uint8_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vand_vx)))
vuint16m1_t vand(vuint16m1_t, uint16_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vand_vx_m)))
vuint16m1_t vand(vbool16_t, vuint16m1_t, vuint16m1_t, uint16_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vand_vx)))
vuint16m2_t vand(vuint16m2_t, uint16_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vand_vx_m)))
vuint16m2_t vand(vbool8_t, vuint16m2_t, vuint16m2_t, uint16_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vand_vx)))
vuint16m4_t vand(vuint16m4_t, uint16_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vand_vx_m)))
vuint16m4_t vand(vbool4_t, vuint16m4_t, vuint16m4_t, uint16_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vand_vx)))
vuint16m8_t vand(vuint16m8_t, uint16_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vand_vx_m)))
vuint16m8_t vand(vbool2_t, vuint16m8_t, vuint16m8_t, uint16_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vand_vx)))
vuint16mf2_t vand(vuint16mf2_t, uint16_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vand_vx_m)))
vuint16mf2_t vand(vbool32_t, vuint16mf2_t, vuint16mf2_t, uint16_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vand_vx)))
vuint16mf4_t vand(vuint16mf4_t, uint16_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vand_vx_m)))
vuint16mf4_t vand(vbool64_t, vuint16mf4_t, vuint16mf4_t, uint16_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vand_vx)))
vuint32m1_t vand(vuint32m1_t, uint32_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vand_vx_m)))
vuint32m1_t vand(vbool32_t, vuint32m1_t, vuint32m1_t, uint32_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vand_vx)))
vuint32m2_t vand(vuint32m2_t, uint32_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vand_vx_m)))
vuint32m2_t vand(vbool16_t, vuint32m2_t, vuint32m2_t, uint32_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vand_vx)))
vuint32m4_t vand(vuint32m4_t, uint32_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vand_vx_m)))
vuint32m4_t vand(vbool8_t, vuint32m4_t, vuint32m4_t, uint32_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vand_vx)))
vuint32m8_t vand(vuint32m8_t, uint32_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vand_vx_m)))
vuint32m8_t vand(vbool4_t, vuint32m8_t, vuint32m8_t, uint32_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vand_vx)))
vuint32mf2_t vand(vuint32mf2_t, uint32_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vand_vx_m)))
vuint32mf2_t vand(vbool64_t, vuint32mf2_t, vuint32mf2_t, uint32_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vxor_vv)))
vint8m1_t vxor(vint8m1_t, vint8m1_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vxor_vv_m)))
vint8m1_t vxor(vbool8_t, vint8m1_t, vint8m1_t, vint8m1_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vxor_vv)))
vint8m2_t vxor(vint8m2_t, vint8m2_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vxor_vv_m)))
vint8m2_t vxor(vbool4_t, vint8m2_t, vint8m2_t, vint8m2_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vxor_vv)))
vint8m4_t vxor(vint8m4_t, vint8m4_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vxor_vv_m)))
vint8m4_t vxor(vbool2_t, vint8m4_t, vint8m4_t, vint8m4_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vxor_vv)))
vint8m8_t vxor(vint8m8_t, vint8m8_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vxor_vv_m)))
vint8m8_t vxor(vbool1_t, vint8m8_t, vint8m8_t, vint8m8_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vxor_vv)))
vint8mf2_t vxor(vint8mf2_t, vint8mf2_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vxor_vv_m)))
vint8mf2_t vxor(vbool16_t, vint8mf2_t, vint8mf2_t, vint8mf2_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vxor_vv)))
vint8mf4_t vxor(vint8mf4_t, vint8mf4_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vxor_vv_m)))
vint8mf4_t vxor(vbool32_t, vint8mf4_t, vint8mf4_t, vint8mf4_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vxor_vv)))
vint8mf8_t vxor(vint8mf8_t, vint8mf8_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vxor_vv_m)))
vint8mf8_t vxor(vbool64_t, vint8mf8_t, vint8mf8_t, vint8mf8_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vxor_vv)))
vint16m1_t vxor(vint16m1_t, vint16m1_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vxor_vv_m)))
vint16m1_t vxor(vbool16_t, vint16m1_t, vint16m1_t, vint16m1_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vxor_vv)))
vint16m2_t vxor(vint16m2_t, vint16m2_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vxor_vv_m)))
vint16m2_t vxor(vbool8_t, vint16m2_t, vint16m2_t, vint16m2_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vxor_vv)))
vint16m4_t vxor(vint16m4_t, vint16m4_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vxor_vv_m)))
vint16m4_t vxor(vbool4_t, vint16m4_t, vint16m4_t, vint16m4_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vxor_vv)))
vint16m8_t vxor(vint16m8_t, vint16m8_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vxor_vv_m)))
vint16m8_t vxor(vbool2_t, vint16m8_t, vint16m8_t, vint16m8_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vxor_vv)))
vint16mf2_t vxor(vint16mf2_t, vint16mf2_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vxor_vv_m)))
vint16mf2_t vxor(vbool32_t, vint16mf2_t, vint16mf2_t, vint16mf2_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vxor_vv)))
vint16mf4_t vxor(vint16mf4_t, vint16mf4_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vxor_vv_m)))
vint16mf4_t vxor(vbool64_t, vint16mf4_t, vint16mf4_t, vint16mf4_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vxor_vv)))
vint32m1_t vxor(vint32m1_t, vint32m1_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vxor_vv_m)))
vint32m1_t vxor(vbool32_t, vint32m1_t, vint32m1_t, vint32m1_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vxor_vv)))
vint32m2_t vxor(vint32m2_t, vint32m2_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vxor_vv_m)))
vint32m2_t vxor(vbool16_t, vint32m2_t, vint32m2_t, vint32m2_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vxor_vv)))
vint32m4_t vxor(vint32m4_t, vint32m4_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vxor_vv_m)))
vint32m4_t vxor(vbool8_t, vint32m4_t, vint32m4_t, vint32m4_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vxor_vv)))
vint32m8_t vxor(vint32m8_t, vint32m8_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vxor_vv_m)))
vint32m8_t vxor(vbool4_t, vint32m8_t, vint32m8_t, vint32m8_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vxor_vv)))
vint32mf2_t vxor(vint32mf2_t, vint32mf2_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vxor_vv_m)))
vint32mf2_t vxor(vbool64_t, vint32mf2_t, vint32mf2_t, vint32mf2_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vxor_vx)))
vint8m1_t vxor(vint8m1_t, int8_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vxor_vx_m)))
vint8m1_t vxor(vbool8_t, vint8m1_t, vint8m1_t, int8_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vxor_vx)))
vint8m2_t vxor(vint8m2_t, int8_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vxor_vx_m)))
vint8m2_t vxor(vbool4_t, vint8m2_t, vint8m2_t, int8_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vxor_vx)))
vint8m4_t vxor(vint8m4_t, int8_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vxor_vx_m)))
vint8m4_t vxor(vbool2_t, vint8m4_t, vint8m4_t, int8_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vxor_vx)))
vint8m8_t vxor(vint8m8_t, int8_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vxor_vx_m)))
vint8m8_t vxor(vbool1_t, vint8m8_t, vint8m8_t, int8_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vxor_vx)))
vint8mf2_t vxor(vint8mf2_t, int8_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vxor_vx_m)))
vint8mf2_t vxor(vbool16_t, vint8mf2_t, vint8mf2_t, int8_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vxor_vx)))
vint8mf4_t vxor(vint8mf4_t, int8_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vxor_vx_m)))
vint8mf4_t vxor(vbool32_t, vint8mf4_t, vint8mf4_t, int8_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vxor_vx)))
vint8mf8_t vxor(vint8mf8_t, int8_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vxor_vx_m)))
vint8mf8_t vxor(vbool64_t, vint8mf8_t, vint8mf8_t, int8_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vxor_vx)))
vint16m1_t vxor(vint16m1_t, int16_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vxor_vx_m)))
vint16m1_t vxor(vbool16_t, vint16m1_t, vint16m1_t, int16_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vxor_vx)))
vint16m2_t vxor(vint16m2_t, int16_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vxor_vx_m)))
vint16m2_t vxor(vbool8_t, vint16m2_t, vint16m2_t, int16_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vxor_vx)))
vint16m4_t vxor(vint16m4_t, int16_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vxor_vx_m)))
vint16m4_t vxor(vbool4_t, vint16m4_t, vint16m4_t, int16_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vxor_vx)))
vint16m8_t vxor(vint16m8_t, int16_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vxor_vx_m)))
vint16m8_t vxor(vbool2_t, vint16m8_t, vint16m8_t, int16_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vxor_vx)))
vint16mf2_t vxor(vint16mf2_t, int16_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vxor_vx_m)))
vint16mf2_t vxor(vbool32_t, vint16mf2_t, vint16mf2_t, int16_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vxor_vx)))
vint16mf4_t vxor(vint16mf4_t, int16_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vxor_vx_m)))
vint16mf4_t vxor(vbool64_t, vint16mf4_t, vint16mf4_t, int16_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vxor_vx)))
vint32m1_t vxor(vint32m1_t, int32_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vxor_vx_m)))
vint32m1_t vxor(vbool32_t, vint32m1_t, vint32m1_t, int32_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vxor_vx)))
vint32m2_t vxor(vint32m2_t, int32_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vxor_vx_m)))
vint32m2_t vxor(vbool16_t, vint32m2_t, vint32m2_t, int32_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vxor_vx)))
vint32m4_t vxor(vint32m4_t, int32_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vxor_vx_m)))
vint32m4_t vxor(vbool8_t, vint32m4_t, vint32m4_t, int32_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vxor_vx)))
vint32m8_t vxor(vint32m8_t, int32_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vxor_vx_m)))
vint32m8_t vxor(vbool4_t, vint32m8_t, vint32m8_t, int32_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vxor_vx)))
vint32mf2_t vxor(vint32mf2_t, int32_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vxor_vx_m)))
vint32mf2_t vxor(vbool64_t, vint32mf2_t, vint32mf2_t, int32_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vxor_vv)))
vuint8m1_t vxor(vuint8m1_t, vuint8m1_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vxor_vv_m)))
vuint8m1_t vxor(vbool8_t, vuint8m1_t, vuint8m1_t, vuint8m1_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vxor_vv)))
vuint8m2_t vxor(vuint8m2_t, vuint8m2_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vxor_vv_m)))
vuint8m2_t vxor(vbool4_t, vuint8m2_t, vuint8m2_t, vuint8m2_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vxor_vv)))
vuint8m4_t vxor(vuint8m4_t, vuint8m4_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vxor_vv_m)))
vuint8m4_t vxor(vbool2_t, vuint8m4_t, vuint8m4_t, vuint8m4_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vxor_vv)))
vuint8m8_t vxor(vuint8m8_t, vuint8m8_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vxor_vv_m)))
vuint8m8_t vxor(vbool1_t, vuint8m8_t, vuint8m8_t, vuint8m8_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vxor_vv)))
vuint8mf2_t vxor(vuint8mf2_t, vuint8mf2_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vxor_vv_m)))
vuint8mf2_t vxor(vbool16_t, vuint8mf2_t, vuint8mf2_t, vuint8mf2_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vxor_vv)))
vuint8mf4_t vxor(vuint8mf4_t, vuint8mf4_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vxor_vv_m)))
vuint8mf4_t vxor(vbool32_t, vuint8mf4_t, vuint8mf4_t, vuint8mf4_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vxor_vv)))
vuint8mf8_t vxor(vuint8mf8_t, vuint8mf8_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vxor_vv_m)))
vuint8mf8_t vxor(vbool64_t, vuint8mf8_t, vuint8mf8_t, vuint8mf8_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vxor_vv)))
vuint16m1_t vxor(vuint16m1_t, vuint16m1_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vxor_vv_m)))
vuint16m1_t vxor(vbool16_t, vuint16m1_t, vuint16m1_t, vuint16m1_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vxor_vv)))
vuint16m2_t vxor(vuint16m2_t, vuint16m2_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vxor_vv_m)))
vuint16m2_t vxor(vbool8_t, vuint16m2_t, vuint16m2_t, vuint16m2_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vxor_vv)))
vuint16m4_t vxor(vuint16m4_t, vuint16m4_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vxor_vv_m)))
vuint16m4_t vxor(vbool4_t, vuint16m4_t, vuint16m4_t, vuint16m4_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vxor_vv)))
vuint16m8_t vxor(vuint16m8_t, vuint16m8_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vxor_vv_m)))
vuint16m8_t vxor(vbool2_t, vuint16m8_t, vuint16m8_t, vuint16m8_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vxor_vv)))
vuint16mf2_t vxor(vuint16mf2_t, vuint16mf2_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vxor_vv_m)))
vuint16mf2_t vxor(vbool32_t, vuint16mf2_t, vuint16mf2_t, vuint16mf2_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vxor_vv)))
vuint16mf4_t vxor(vuint16mf4_t, vuint16mf4_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vxor_vv_m)))
vuint16mf4_t vxor(vbool64_t, vuint16mf4_t, vuint16mf4_t, vuint16mf4_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vxor_vv)))
vuint32m1_t vxor(vuint32m1_t, vuint32m1_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vxor_vv_m)))
vuint32m1_t vxor(vbool32_t, vuint32m1_t, vuint32m1_t, vuint32m1_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vxor_vv)))
vuint32m2_t vxor(vuint32m2_t, vuint32m2_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vxor_vv_m)))
vuint32m2_t vxor(vbool16_t, vuint32m2_t, vuint32m2_t, vuint32m2_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vxor_vv)))
vuint32m4_t vxor(vuint32m4_t, vuint32m4_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vxor_vv_m)))
vuint32m4_t vxor(vbool8_t, vuint32m4_t, vuint32m4_t, vuint32m4_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vxor_vv)))
vuint32m8_t vxor(vuint32m8_t, vuint32m8_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vxor_vv_m)))
vuint32m8_t vxor(vbool4_t, vuint32m8_t, vuint32m8_t, vuint32m8_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vxor_vv)))
vuint32mf2_t vxor(vuint32mf2_t, vuint32mf2_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vxor_vv_m)))
vuint32mf2_t vxor(vbool64_t, vuint32mf2_t, vuint32mf2_t, vuint32mf2_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vxor_vx)))
vuint8m1_t vxor(vuint8m1_t, uint8_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vxor_vx_m)))
vuint8m1_t vxor(vbool8_t, vuint8m1_t, vuint8m1_t, uint8_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vxor_vx)))
vuint8m2_t vxor(vuint8m2_t, uint8_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vxor_vx_m)))
vuint8m2_t vxor(vbool4_t, vuint8m2_t, vuint8m2_t, uint8_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vxor_vx)))
vuint8m4_t vxor(vuint8m4_t, uint8_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vxor_vx_m)))
vuint8m4_t vxor(vbool2_t, vuint8m4_t, vuint8m4_t, uint8_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vxor_vx)))
vuint8m8_t vxor(vuint8m8_t, uint8_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vxor_vx_m)))
vuint8m8_t vxor(vbool1_t, vuint8m8_t, vuint8m8_t, uint8_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vxor_vx)))
vuint8mf2_t vxor(vuint8mf2_t, uint8_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vxor_vx_m)))
vuint8mf2_t vxor(vbool16_t, vuint8mf2_t, vuint8mf2_t, uint8_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vxor_vx)))
vuint8mf4_t vxor(vuint8mf4_t, uint8_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vxor_vx_m)))
vuint8mf4_t vxor(vbool32_t, vuint8mf4_t, vuint8mf4_t, uint8_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vxor_vx)))
vuint8mf8_t vxor(vuint8mf8_t, uint8_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vxor_vx_m)))
vuint8mf8_t vxor(vbool64_t, vuint8mf8_t, vuint8mf8_t, uint8_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vxor_vx)))
vuint16m1_t vxor(vuint16m1_t, uint16_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vxor_vx_m)))
vuint16m1_t vxor(vbool16_t, vuint16m1_t, vuint16m1_t, uint16_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vxor_vx)))
vuint16m2_t vxor(vuint16m2_t, uint16_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vxor_vx_m)))
vuint16m2_t vxor(vbool8_t, vuint16m2_t, vuint16m2_t, uint16_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vxor_vx)))
vuint16m4_t vxor(vuint16m4_t, uint16_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vxor_vx_m)))
vuint16m4_t vxor(vbool4_t, vuint16m4_t, vuint16m4_t, uint16_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vxor_vx)))
vuint16m8_t vxor(vuint16m8_t, uint16_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vxor_vx_m)))
vuint16m8_t vxor(vbool2_t, vuint16m8_t, vuint16m8_t, uint16_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vxor_vx)))
vuint16mf2_t vxor(vuint16mf2_t, uint16_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vxor_vx_m)))
vuint16mf2_t vxor(vbool32_t, vuint16mf2_t, vuint16mf2_t, uint16_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vxor_vx)))
vuint16mf4_t vxor(vuint16mf4_t, uint16_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vxor_vx_m)))
vuint16mf4_t vxor(vbool64_t, vuint16mf4_t, vuint16mf4_t, uint16_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vxor_vx)))
vuint32m1_t vxor(vuint32m1_t, uint32_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vxor_vx_m)))
vuint32m1_t vxor(vbool32_t, vuint32m1_t, vuint32m1_t, uint32_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vxor_vx)))
vuint32m2_t vxor(vuint32m2_t, uint32_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vxor_vx_m)))
vuint32m2_t vxor(vbool16_t, vuint32m2_t, vuint32m2_t, uint32_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vxor_vx)))
vuint32m4_t vxor(vuint32m4_t, uint32_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vxor_vx_m)))
vuint32m4_t vxor(vbool8_t, vuint32m4_t, vuint32m4_t, uint32_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vxor_vx)))
vuint32m8_t vxor(vuint32m8_t, uint32_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vxor_vx_m)))
vuint32m8_t vxor(vbool4_t, vuint32m8_t, vuint32m8_t, uint32_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vxor_vx)))
vuint32mf2_t vxor(vuint32mf2_t, uint32_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vxor_vx_m)))
vuint32mf2_t vxor(vbool64_t, vuint32mf2_t, vuint32mf2_t, uint32_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vor_vv)))
vint8m1_t vor(vint8m1_t, vint8m1_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vor_vv_m)))
vint8m1_t vor(vbool8_t, vint8m1_t, vint8m1_t, vint8m1_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vor_vv)))
vint8m2_t vor(vint8m2_t, vint8m2_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vor_vv_m)))
vint8m2_t vor(vbool4_t, vint8m2_t, vint8m2_t, vint8m2_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vor_vv)))
vint8m4_t vor(vint8m4_t, vint8m4_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vor_vv_m)))
vint8m4_t vor(vbool2_t, vint8m4_t, vint8m4_t, vint8m4_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vor_vv)))
vint8m8_t vor(vint8m8_t, vint8m8_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vor_vv_m)))
vint8m8_t vor(vbool1_t, vint8m8_t, vint8m8_t, vint8m8_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vor_vv)))
vint8mf2_t vor(vint8mf2_t, vint8mf2_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vor_vv_m)))
vint8mf2_t vor(vbool16_t, vint8mf2_t, vint8mf2_t, vint8mf2_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vor_vv)))
vint8mf4_t vor(vint8mf4_t, vint8mf4_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vor_vv_m)))
vint8mf4_t vor(vbool32_t, vint8mf4_t, vint8mf4_t, vint8mf4_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vor_vv)))
vint8mf8_t vor(vint8mf8_t, vint8mf8_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vor_vv_m)))
vint8mf8_t vor(vbool64_t, vint8mf8_t, vint8mf8_t, vint8mf8_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vor_vv)))
vint16m1_t vor(vint16m1_t, vint16m1_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vor_vv_m)))
vint16m1_t vor(vbool16_t, vint16m1_t, vint16m1_t, vint16m1_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vor_vv)))
vint16m2_t vor(vint16m2_t, vint16m2_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vor_vv_m)))
vint16m2_t vor(vbool8_t, vint16m2_t, vint16m2_t, vint16m2_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vor_vv)))
vint16m4_t vor(vint16m4_t, vint16m4_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vor_vv_m)))
vint16m4_t vor(vbool4_t, vint16m4_t, vint16m4_t, vint16m4_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vor_vv)))
vint16m8_t vor(vint16m8_t, vint16m8_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vor_vv_m)))
vint16m8_t vor(vbool2_t, vint16m8_t, vint16m8_t, vint16m8_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vor_vv)))
vint16mf2_t vor(vint16mf2_t, vint16mf2_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vor_vv_m)))
vint16mf2_t vor(vbool32_t, vint16mf2_t, vint16mf2_t, vint16mf2_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vor_vv)))
vint16mf4_t vor(vint16mf4_t, vint16mf4_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vor_vv_m)))
vint16mf4_t vor(vbool64_t, vint16mf4_t, vint16mf4_t, vint16mf4_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vor_vv)))
vint32m1_t vor(vint32m1_t, vint32m1_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vor_vv_m)))
vint32m1_t vor(vbool32_t, vint32m1_t, vint32m1_t, vint32m1_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vor_vv)))
vint32m2_t vor(vint32m2_t, vint32m2_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vor_vv_m)))
vint32m2_t vor(vbool16_t, vint32m2_t, vint32m2_t, vint32m2_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vor_vv)))
vint32m4_t vor(vint32m4_t, vint32m4_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vor_vv_m)))
vint32m4_t vor(vbool8_t, vint32m4_t, vint32m4_t, vint32m4_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vor_vv)))
vint32m8_t vor(vint32m8_t, vint32m8_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vor_vv_m)))
vint32m8_t vor(vbool4_t, vint32m8_t, vint32m8_t, vint32m8_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vor_vv)))
vint32mf2_t vor(vint32mf2_t, vint32mf2_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vor_vv_m)))
vint32mf2_t vor(vbool64_t, vint32mf2_t, vint32mf2_t, vint32mf2_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vor_vx)))
vint8m1_t vor(vint8m1_t, int8_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vor_vx_m)))
vint8m1_t vor(vbool8_t, vint8m1_t, vint8m1_t, int8_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vor_vx)))
vint8m2_t vor(vint8m2_t, int8_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vor_vx_m)))
vint8m2_t vor(vbool4_t, vint8m2_t, vint8m2_t, int8_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vor_vx)))
vint8m4_t vor(vint8m4_t, int8_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vor_vx_m)))
vint8m4_t vor(vbool2_t, vint8m4_t, vint8m4_t, int8_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vor_vx)))
vint8m8_t vor(vint8m8_t, int8_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vor_vx_m)))
vint8m8_t vor(vbool1_t, vint8m8_t, vint8m8_t, int8_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vor_vx)))
vint8mf2_t vor(vint8mf2_t, int8_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vor_vx_m)))
vint8mf2_t vor(vbool16_t, vint8mf2_t, vint8mf2_t, int8_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vor_vx)))
vint8mf4_t vor(vint8mf4_t, int8_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vor_vx_m)))
vint8mf4_t vor(vbool32_t, vint8mf4_t, vint8mf4_t, int8_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vor_vx)))
vint8mf8_t vor(vint8mf8_t, int8_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vor_vx_m)))
vint8mf8_t vor(vbool64_t, vint8mf8_t, vint8mf8_t, int8_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vor_vx)))
vint16m1_t vor(vint16m1_t, int16_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vor_vx_m)))
vint16m1_t vor(vbool16_t, vint16m1_t, vint16m1_t, int16_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vor_vx)))
vint16m2_t vor(vint16m2_t, int16_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vor_vx_m)))
vint16m2_t vor(vbool8_t, vint16m2_t, vint16m2_t, int16_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vor_vx)))
vint16m4_t vor(vint16m4_t, int16_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vor_vx_m)))
vint16m4_t vor(vbool4_t, vint16m4_t, vint16m4_t, int16_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vor_vx)))
vint16m8_t vor(vint16m8_t, int16_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vor_vx_m)))
vint16m8_t vor(vbool2_t, vint16m8_t, vint16m8_t, int16_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vor_vx)))
vint16mf2_t vor(vint16mf2_t, int16_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vor_vx_m)))
vint16mf2_t vor(vbool32_t, vint16mf2_t, vint16mf2_t, int16_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vor_vx)))
vint16mf4_t vor(vint16mf4_t, int16_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vor_vx_m)))
vint16mf4_t vor(vbool64_t, vint16mf4_t, vint16mf4_t, int16_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vor_vx)))
vint32m1_t vor(vint32m1_t, int32_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vor_vx_m)))
vint32m1_t vor(vbool32_t, vint32m1_t, vint32m1_t, int32_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vor_vx)))
vint32m2_t vor(vint32m2_t, int32_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vor_vx_m)))
vint32m2_t vor(vbool16_t, vint32m2_t, vint32m2_t, int32_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vor_vx)))
vint32m4_t vor(vint32m4_t, int32_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vor_vx_m)))
vint32m4_t vor(vbool8_t, vint32m4_t, vint32m4_t, int32_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vor_vx)))
vint32m8_t vor(vint32m8_t, int32_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vor_vx_m)))
vint32m8_t vor(vbool4_t, vint32m8_t, vint32m8_t, int32_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vor_vx)))
vint32mf2_t vor(vint32mf2_t, int32_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vor_vx_m)))
vint32mf2_t vor(vbool64_t, vint32mf2_t, vint32mf2_t, int32_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vor_vv)))
vuint8m1_t vor(vuint8m1_t, vuint8m1_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vor_vv_m)))
vuint8m1_t vor(vbool8_t, vuint8m1_t, vuint8m1_t, vuint8m1_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vor_vv)))
vuint8m2_t vor(vuint8m2_t, vuint8m2_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vor_vv_m)))
vuint8m2_t vor(vbool4_t, vuint8m2_t, vuint8m2_t, vuint8m2_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vor_vv)))
vuint8m4_t vor(vuint8m4_t, vuint8m4_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vor_vv_m)))
vuint8m4_t vor(vbool2_t, vuint8m4_t, vuint8m4_t, vuint8m4_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vor_vv)))
vuint8m8_t vor(vuint8m8_t, vuint8m8_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vor_vv_m)))
vuint8m8_t vor(vbool1_t, vuint8m8_t, vuint8m8_t, vuint8m8_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vor_vv)))
vuint8mf2_t vor(vuint8mf2_t, vuint8mf2_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vor_vv_m)))
vuint8mf2_t vor(vbool16_t, vuint8mf2_t, vuint8mf2_t, vuint8mf2_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vor_vv)))
vuint8mf4_t vor(vuint8mf4_t, vuint8mf4_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vor_vv_m)))
vuint8mf4_t vor(vbool32_t, vuint8mf4_t, vuint8mf4_t, vuint8mf4_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vor_vv)))
vuint8mf8_t vor(vuint8mf8_t, vuint8mf8_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vor_vv_m)))
vuint8mf8_t vor(vbool64_t, vuint8mf8_t, vuint8mf8_t, vuint8mf8_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vor_vv)))
vuint16m1_t vor(vuint16m1_t, vuint16m1_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vor_vv_m)))
vuint16m1_t vor(vbool16_t, vuint16m1_t, vuint16m1_t, vuint16m1_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vor_vv)))
vuint16m2_t vor(vuint16m2_t, vuint16m2_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vor_vv_m)))
vuint16m2_t vor(vbool8_t, vuint16m2_t, vuint16m2_t, vuint16m2_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vor_vv)))
vuint16m4_t vor(vuint16m4_t, vuint16m4_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vor_vv_m)))
vuint16m4_t vor(vbool4_t, vuint16m4_t, vuint16m4_t, vuint16m4_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vor_vv)))
vuint16m8_t vor(vuint16m8_t, vuint16m8_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vor_vv_m)))
vuint16m8_t vor(vbool2_t, vuint16m8_t, vuint16m8_t, vuint16m8_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vor_vv)))
vuint16mf2_t vor(vuint16mf2_t, vuint16mf2_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vor_vv_m)))
vuint16mf2_t vor(vbool32_t, vuint16mf2_t, vuint16mf2_t, vuint16mf2_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vor_vv)))
vuint16mf4_t vor(vuint16mf4_t, vuint16mf4_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vor_vv_m)))
vuint16mf4_t vor(vbool64_t, vuint16mf4_t, vuint16mf4_t, vuint16mf4_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vor_vv)))
vuint32m1_t vor(vuint32m1_t, vuint32m1_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vor_vv_m)))
vuint32m1_t vor(vbool32_t, vuint32m1_t, vuint32m1_t, vuint32m1_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vor_vv)))
vuint32m2_t vor(vuint32m2_t, vuint32m2_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vor_vv_m)))
vuint32m2_t vor(vbool16_t, vuint32m2_t, vuint32m2_t, vuint32m2_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vor_vv)))
vuint32m4_t vor(vuint32m4_t, vuint32m4_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vor_vv_m)))
vuint32m4_t vor(vbool8_t, vuint32m4_t, vuint32m4_t, vuint32m4_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vor_vv)))
vuint32m8_t vor(vuint32m8_t, vuint32m8_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vor_vv_m)))
vuint32m8_t vor(vbool4_t, vuint32m8_t, vuint32m8_t, vuint32m8_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vor_vv)))
vuint32mf2_t vor(vuint32mf2_t, vuint32mf2_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vor_vv_m)))
vuint32mf2_t vor(vbool64_t, vuint32mf2_t, vuint32mf2_t, vuint32mf2_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vor_vx)))
vuint8m1_t vor(vuint8m1_t, uint8_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vor_vx_m)))
vuint8m1_t vor(vbool8_t, vuint8m1_t, vuint8m1_t, uint8_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vor_vx)))
vuint8m2_t vor(vuint8m2_t, uint8_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vor_vx_m)))
vuint8m2_t vor(vbool4_t, vuint8m2_t, vuint8m2_t, uint8_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vor_vx)))
vuint8m4_t vor(vuint8m4_t, uint8_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vor_vx_m)))
vuint8m4_t vor(vbool2_t, vuint8m4_t, vuint8m4_t, uint8_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vor_vx)))
vuint8m8_t vor(vuint8m8_t, uint8_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vor_vx_m)))
vuint8m8_t vor(vbool1_t, vuint8m8_t, vuint8m8_t, uint8_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vor_vx)))
vuint8mf2_t vor(vuint8mf2_t, uint8_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vor_vx_m)))
vuint8mf2_t vor(vbool16_t, vuint8mf2_t, vuint8mf2_t, uint8_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vor_vx)))
vuint8mf4_t vor(vuint8mf4_t, uint8_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vor_vx_m)))
vuint8mf4_t vor(vbool32_t, vuint8mf4_t, vuint8mf4_t, uint8_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vor_vx)))
vuint8mf8_t vor(vuint8mf8_t, uint8_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vor_vx_m)))
vuint8mf8_t vor(vbool64_t, vuint8mf8_t, vuint8mf8_t, uint8_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vor_vx)))
vuint16m1_t vor(vuint16m1_t, uint16_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vor_vx_m)))
vuint16m1_t vor(vbool16_t, vuint16m1_t, vuint16m1_t, uint16_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vor_vx)))
vuint16m2_t vor(vuint16m2_t, uint16_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vor_vx_m)))
vuint16m2_t vor(vbool8_t, vuint16m2_t, vuint16m2_t, uint16_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vor_vx)))
vuint16m4_t vor(vuint16m4_t, uint16_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vor_vx_m)))
vuint16m4_t vor(vbool4_t, vuint16m4_t, vuint16m4_t, uint16_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vor_vx)))
vuint16m8_t vor(vuint16m8_t, uint16_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vor_vx_m)))
vuint16m8_t vor(vbool2_t, vuint16m8_t, vuint16m8_t, uint16_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vor_vx)))
vuint16mf2_t vor(vuint16mf2_t, uint16_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vor_vx_m)))
vuint16mf2_t vor(vbool32_t, vuint16mf2_t, vuint16mf2_t, uint16_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vor_vx)))
vuint16mf4_t vor(vuint16mf4_t, uint16_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vor_vx_m)))
vuint16mf4_t vor(vbool64_t, vuint16mf4_t, vuint16mf4_t, uint16_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vor_vx)))
vuint32m1_t vor(vuint32m1_t, uint32_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vor_vx_m)))
vuint32m1_t vor(vbool32_t, vuint32m1_t, vuint32m1_t, uint32_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vor_vx)))
vuint32m2_t vor(vuint32m2_t, uint32_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vor_vx_m)))
vuint32m2_t vor(vbool16_t, vuint32m2_t, vuint32m2_t, uint32_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vor_vx)))
vuint32m4_t vor(vuint32m4_t, uint32_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vor_vx_m)))
vuint32m4_t vor(vbool8_t, vuint32m4_t, vuint32m4_t, uint32_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vor_vx)))
vuint32m8_t vor(vuint32m8_t, uint32_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vor_vx_m)))
vuint32m8_t vor(vbool4_t, vuint32m8_t, vuint32m8_t, uint32_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vor_vx)))
vuint32mf2_t vor(vuint32mf2_t, uint32_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vor_vx_m)))
vuint32mf2_t vor(vbool64_t, vuint32mf2_t, vuint32mf2_t, uint32_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vsll_vv)))
vint8m1_t vsll(vint8m1_t, vuint8m1_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vsll_vv_m)))
vint8m1_t vsll(vbool8_t, vint8m1_t, vint8m1_t, vuint8m1_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vsll_vv)))
vint8m2_t vsll(vint8m2_t, vuint8m2_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vsll_vv_m)))
vint8m2_t vsll(vbool4_t, vint8m2_t, vint8m2_t, vuint8m2_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vsll_vv)))
vint8m4_t vsll(vint8m4_t, vuint8m4_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vsll_vv_m)))
vint8m4_t vsll(vbool2_t, vint8m4_t, vint8m4_t, vuint8m4_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vsll_vv)))
vint8m8_t vsll(vint8m8_t, vuint8m8_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vsll_vv_m)))
vint8m8_t vsll(vbool1_t, vint8m8_t, vint8m8_t, vuint8m8_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vsll_vv)))
vint8mf2_t vsll(vint8mf2_t, vuint8mf2_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vsll_vv_m)))
vint8mf2_t vsll(vbool16_t, vint8mf2_t, vint8mf2_t, vuint8mf2_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vsll_vv)))
vint8mf4_t vsll(vint8mf4_t, vuint8mf4_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vsll_vv_m)))
vint8mf4_t vsll(vbool32_t, vint8mf4_t, vint8mf4_t, vuint8mf4_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vsll_vv)))
vint8mf8_t vsll(vint8mf8_t, vuint8mf8_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vsll_vv_m)))
vint8mf8_t vsll(vbool64_t, vint8mf8_t, vint8mf8_t, vuint8mf8_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vsll_vv)))
vint16m1_t vsll(vint16m1_t, vuint16m1_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vsll_vv_m)))
vint16m1_t vsll(vbool16_t, vint16m1_t, vint16m1_t, vuint16m1_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vsll_vv)))
vint16m2_t vsll(vint16m2_t, vuint16m2_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vsll_vv_m)))
vint16m2_t vsll(vbool8_t, vint16m2_t, vint16m2_t, vuint16m2_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vsll_vv)))
vint16m4_t vsll(vint16m4_t, vuint16m4_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vsll_vv_m)))
vint16m4_t vsll(vbool4_t, vint16m4_t, vint16m4_t, vuint16m4_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vsll_vv)))
vint16m8_t vsll(vint16m8_t, vuint16m8_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vsll_vv_m)))
vint16m8_t vsll(vbool2_t, vint16m8_t, vint16m8_t, vuint16m8_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vsll_vv)))
vint16mf2_t vsll(vint16mf2_t, vuint16mf2_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vsll_vv_m)))
vint16mf2_t vsll(vbool32_t, vint16mf2_t, vint16mf2_t, vuint16mf2_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vsll_vv)))
vint16mf4_t vsll(vint16mf4_t, vuint16mf4_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vsll_vv_m)))
vint16mf4_t vsll(vbool64_t, vint16mf4_t, vint16mf4_t, vuint16mf4_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vsll_vv)))
vint32m1_t vsll(vint32m1_t, vuint32m1_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vsll_vv_m)))
vint32m1_t vsll(vbool32_t, vint32m1_t, vint32m1_t, vuint32m1_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vsll_vv)))
vint32m2_t vsll(vint32m2_t, vuint32m2_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vsll_vv_m)))
vint32m2_t vsll(vbool16_t, vint32m2_t, vint32m2_t, vuint32m2_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vsll_vv)))
vint32m4_t vsll(vint32m4_t, vuint32m4_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vsll_vv_m)))
vint32m4_t vsll(vbool8_t, vint32m4_t, vint32m4_t, vuint32m4_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vsll_vv)))
vint32m8_t vsll(vint32m8_t, vuint32m8_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vsll_vv_m)))
vint32m8_t vsll(vbool4_t, vint32m8_t, vint32m8_t, vuint32m8_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vsll_vv)))
vint32mf2_t vsll(vint32mf2_t, vuint32mf2_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vsll_vv_m)))
vint32mf2_t vsll(vbool64_t, vint32mf2_t, vint32mf2_t, vuint32mf2_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vsll_vx)))
vint8m1_t vsll(vint8m1_t, size_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vsll_vx_m)))
vint8m1_t vsll(vbool8_t, vint8m1_t, vint8m1_t, size_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vsll_vx)))
vint8m2_t vsll(vint8m2_t, size_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vsll_vx_m)))
vint8m2_t vsll(vbool4_t, vint8m2_t, vint8m2_t, size_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vsll_vx)))
vint8m4_t vsll(vint8m4_t, size_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vsll_vx_m)))
vint8m4_t vsll(vbool2_t, vint8m4_t, vint8m4_t, size_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vsll_vx)))
vint8m8_t vsll(vint8m8_t, size_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vsll_vx_m)))
vint8m8_t vsll(vbool1_t, vint8m8_t, vint8m8_t, size_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vsll_vx)))
vint8mf2_t vsll(vint8mf2_t, size_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vsll_vx_m)))
vint8mf2_t vsll(vbool16_t, vint8mf2_t, vint8mf2_t, size_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vsll_vx)))
vint8mf4_t vsll(vint8mf4_t, size_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vsll_vx_m)))
vint8mf4_t vsll(vbool32_t, vint8mf4_t, vint8mf4_t, size_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vsll_vx)))
vint8mf8_t vsll(vint8mf8_t, size_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vsll_vx_m)))
vint8mf8_t vsll(vbool64_t, vint8mf8_t, vint8mf8_t, size_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vsll_vx)))
vint16m1_t vsll(vint16m1_t, size_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vsll_vx_m)))
vint16m1_t vsll(vbool16_t, vint16m1_t, vint16m1_t, size_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vsll_vx)))
vint16m2_t vsll(vint16m2_t, size_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vsll_vx_m)))
vint16m2_t vsll(vbool8_t, vint16m2_t, vint16m2_t, size_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vsll_vx)))
vint16m4_t vsll(vint16m4_t, size_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vsll_vx_m)))
vint16m4_t vsll(vbool4_t, vint16m4_t, vint16m4_t, size_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vsll_vx)))
vint16m8_t vsll(vint16m8_t, size_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vsll_vx_m)))
vint16m8_t vsll(vbool2_t, vint16m8_t, vint16m8_t, size_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vsll_vx)))
vint16mf2_t vsll(vint16mf2_t, size_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vsll_vx_m)))
vint16mf2_t vsll(vbool32_t, vint16mf2_t, vint16mf2_t, size_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vsll_vx)))
vint16mf4_t vsll(vint16mf4_t, size_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vsll_vx_m)))
vint16mf4_t vsll(vbool64_t, vint16mf4_t, vint16mf4_t, size_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vsll_vx)))
vint32m1_t vsll(vint32m1_t, size_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vsll_vx_m)))
vint32m1_t vsll(vbool32_t, vint32m1_t, vint32m1_t, size_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vsll_vx)))
vint32m2_t vsll(vint32m2_t, size_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vsll_vx_m)))
vint32m2_t vsll(vbool16_t, vint32m2_t, vint32m2_t, size_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vsll_vx)))
vint32m4_t vsll(vint32m4_t, size_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vsll_vx_m)))
vint32m4_t vsll(vbool8_t, vint32m4_t, vint32m4_t, size_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vsll_vx)))
vint32m8_t vsll(vint32m8_t, size_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vsll_vx_m)))
vint32m8_t vsll(vbool4_t, vint32m8_t, vint32m8_t, size_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vsll_vx)))
vint32mf2_t vsll(vint32mf2_t, size_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vsll_vx_m)))
vint32mf2_t vsll(vbool64_t, vint32mf2_t, vint32mf2_t, size_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vsll_vv)))
vuint8m1_t vsll(vuint8m1_t, vuint8m1_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vsll_vv_m)))
vuint8m1_t vsll(vbool8_t, vuint8m1_t, vuint8m1_t, vuint8m1_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vsll_vv)))
vuint8m2_t vsll(vuint8m2_t, vuint8m2_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vsll_vv_m)))
vuint8m2_t vsll(vbool4_t, vuint8m2_t, vuint8m2_t, vuint8m2_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vsll_vv)))
vuint8m4_t vsll(vuint8m4_t, vuint8m4_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vsll_vv_m)))
vuint8m4_t vsll(vbool2_t, vuint8m4_t, vuint8m4_t, vuint8m4_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vsll_vv)))
vuint8m8_t vsll(vuint8m8_t, vuint8m8_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vsll_vv_m)))
vuint8m8_t vsll(vbool1_t, vuint8m8_t, vuint8m8_t, vuint8m8_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vsll_vv)))
vuint8mf2_t vsll(vuint8mf2_t, vuint8mf2_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vsll_vv_m)))
vuint8mf2_t vsll(vbool16_t, vuint8mf2_t, vuint8mf2_t, vuint8mf2_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vsll_vv)))
vuint8mf4_t vsll(vuint8mf4_t, vuint8mf4_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vsll_vv_m)))
vuint8mf4_t vsll(vbool32_t, vuint8mf4_t, vuint8mf4_t, vuint8mf4_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vsll_vv)))
vuint8mf8_t vsll(vuint8mf8_t, vuint8mf8_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vsll_vv_m)))
vuint8mf8_t vsll(vbool64_t, vuint8mf8_t, vuint8mf8_t, vuint8mf8_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vsll_vv)))
vuint16m1_t vsll(vuint16m1_t, vuint16m1_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vsll_vv_m)))
vuint16m1_t vsll(vbool16_t, vuint16m1_t, vuint16m1_t, vuint16m1_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vsll_vv)))
vuint16m2_t vsll(vuint16m2_t, vuint16m2_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vsll_vv_m)))
vuint16m2_t vsll(vbool8_t, vuint16m2_t, vuint16m2_t, vuint16m2_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vsll_vv)))
vuint16m4_t vsll(vuint16m4_t, vuint16m4_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vsll_vv_m)))
vuint16m4_t vsll(vbool4_t, vuint16m4_t, vuint16m4_t, vuint16m4_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vsll_vv)))
vuint16m8_t vsll(vuint16m8_t, vuint16m8_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vsll_vv_m)))
vuint16m8_t vsll(vbool2_t, vuint16m8_t, vuint16m8_t, vuint16m8_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vsll_vv)))
vuint16mf2_t vsll(vuint16mf2_t, vuint16mf2_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vsll_vv_m)))
vuint16mf2_t vsll(vbool32_t, vuint16mf2_t, vuint16mf2_t, vuint16mf2_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vsll_vv)))
vuint16mf4_t vsll(vuint16mf4_t, vuint16mf4_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vsll_vv_m)))
vuint16mf4_t vsll(vbool64_t, vuint16mf4_t, vuint16mf4_t, vuint16mf4_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vsll_vv)))
vuint32m1_t vsll(vuint32m1_t, vuint32m1_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vsll_vv_m)))
vuint32m1_t vsll(vbool32_t, vuint32m1_t, vuint32m1_t, vuint32m1_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vsll_vv)))
vuint32m2_t vsll(vuint32m2_t, vuint32m2_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vsll_vv_m)))
vuint32m2_t vsll(vbool16_t, vuint32m2_t, vuint32m2_t, vuint32m2_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vsll_vv)))
vuint32m4_t vsll(vuint32m4_t, vuint32m4_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vsll_vv_m)))
vuint32m4_t vsll(vbool8_t, vuint32m4_t, vuint32m4_t, vuint32m4_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vsll_vv)))
vuint32m8_t vsll(vuint32m8_t, vuint32m8_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vsll_vv_m)))
vuint32m8_t vsll(vbool4_t, vuint32m8_t, vuint32m8_t, vuint32m8_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vsll_vv)))
vuint32mf2_t vsll(vuint32mf2_t, vuint32mf2_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vsll_vv_m)))
vuint32mf2_t vsll(vbool64_t, vuint32mf2_t, vuint32mf2_t, vuint32mf2_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vsll_vx)))
vuint8m1_t vsll(vuint8m1_t, size_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vsll_vx_m)))
vuint8m1_t vsll(vbool8_t, vuint8m1_t, vuint8m1_t, size_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vsll_vx)))
vuint8m2_t vsll(vuint8m2_t, size_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vsll_vx_m)))
vuint8m2_t vsll(vbool4_t, vuint8m2_t, vuint8m2_t, size_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vsll_vx)))
vuint8m4_t vsll(vuint8m4_t, size_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vsll_vx_m)))
vuint8m4_t vsll(vbool2_t, vuint8m4_t, vuint8m4_t, size_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vsll_vx)))
vuint8m8_t vsll(vuint8m8_t, size_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vsll_vx_m)))
vuint8m8_t vsll(vbool1_t, vuint8m8_t, vuint8m8_t, size_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vsll_vx)))
vuint8mf2_t vsll(vuint8mf2_t, size_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vsll_vx_m)))
vuint8mf2_t vsll(vbool16_t, vuint8mf2_t, vuint8mf2_t, size_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vsll_vx)))
vuint8mf4_t vsll(vuint8mf4_t, size_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vsll_vx_m)))
vuint8mf4_t vsll(vbool32_t, vuint8mf4_t, vuint8mf4_t, size_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vsll_vx)))
vuint8mf8_t vsll(vuint8mf8_t, size_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vsll_vx_m)))
vuint8mf8_t vsll(vbool64_t, vuint8mf8_t, vuint8mf8_t, size_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vsll_vx)))
vuint16m1_t vsll(vuint16m1_t, size_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vsll_vx_m)))
vuint16m1_t vsll(vbool16_t, vuint16m1_t, vuint16m1_t, size_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vsll_vx)))
vuint16m2_t vsll(vuint16m2_t, size_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vsll_vx_m)))
vuint16m2_t vsll(vbool8_t, vuint16m2_t, vuint16m2_t, size_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vsll_vx)))
vuint16m4_t vsll(vuint16m4_t, size_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vsll_vx_m)))
vuint16m4_t vsll(vbool4_t, vuint16m4_t, vuint16m4_t, size_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vsll_vx)))
vuint16m8_t vsll(vuint16m8_t, size_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vsll_vx_m)))
vuint16m8_t vsll(vbool2_t, vuint16m8_t, vuint16m8_t, size_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vsll_vx)))
vuint16mf2_t vsll(vuint16mf2_t, size_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vsll_vx_m)))
vuint16mf2_t vsll(vbool32_t, vuint16mf2_t, vuint16mf2_t, size_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vsll_vx)))
vuint16mf4_t vsll(vuint16mf4_t, size_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vsll_vx_m)))
vuint16mf4_t vsll(vbool64_t, vuint16mf4_t, vuint16mf4_t, size_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vsll_vx)))
vuint32m1_t vsll(vuint32m1_t, size_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vsll_vx_m)))
vuint32m1_t vsll(vbool32_t, vuint32m1_t, vuint32m1_t, size_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vsll_vx)))
vuint32m2_t vsll(vuint32m2_t, size_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vsll_vx_m)))
vuint32m2_t vsll(vbool16_t, vuint32m2_t, vuint32m2_t, size_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vsll_vx)))
vuint32m4_t vsll(vuint32m4_t, size_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vsll_vx_m)))
vuint32m4_t vsll(vbool8_t, vuint32m4_t, vuint32m4_t, size_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vsll_vx)))
vuint32m8_t vsll(vuint32m8_t, size_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vsll_vx_m)))
vuint32m8_t vsll(vbool4_t, vuint32m8_t, vuint32m8_t, size_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vsll_vx)))
vuint32mf2_t vsll(vuint32mf2_t, size_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vsll_vx_m)))
vuint32mf2_t vsll(vbool64_t, vuint32mf2_t, vuint32mf2_t, size_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vsrl_vv)))
vuint8m1_t vsrl(vuint8m1_t, vuint8m1_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vsrl_vv_m)))
vuint8m1_t vsrl(vbool8_t, vuint8m1_t, vuint8m1_t, vuint8m1_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vsrl_vv)))
vuint8m2_t vsrl(vuint8m2_t, vuint8m2_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vsrl_vv_m)))
vuint8m2_t vsrl(vbool4_t, vuint8m2_t, vuint8m2_t, vuint8m2_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vsrl_vv)))
vuint8m4_t vsrl(vuint8m4_t, vuint8m4_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vsrl_vv_m)))
vuint8m4_t vsrl(vbool2_t, vuint8m4_t, vuint8m4_t, vuint8m4_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vsrl_vv)))
vuint8m8_t vsrl(vuint8m8_t, vuint8m8_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vsrl_vv_m)))
vuint8m8_t vsrl(vbool1_t, vuint8m8_t, vuint8m8_t, vuint8m8_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vsrl_vv)))
vuint8mf2_t vsrl(vuint8mf2_t, vuint8mf2_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vsrl_vv_m)))
vuint8mf2_t vsrl(vbool16_t, vuint8mf2_t, vuint8mf2_t, vuint8mf2_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vsrl_vv)))
vuint8mf4_t vsrl(vuint8mf4_t, vuint8mf4_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vsrl_vv_m)))
vuint8mf4_t vsrl(vbool32_t, vuint8mf4_t, vuint8mf4_t, vuint8mf4_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vsrl_vv)))
vuint8mf8_t vsrl(vuint8mf8_t, vuint8mf8_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vsrl_vv_m)))
vuint8mf8_t vsrl(vbool64_t, vuint8mf8_t, vuint8mf8_t, vuint8mf8_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vsrl_vv)))
vuint16m1_t vsrl(vuint16m1_t, vuint16m1_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vsrl_vv_m)))
vuint16m1_t vsrl(vbool16_t, vuint16m1_t, vuint16m1_t, vuint16m1_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vsrl_vv)))
vuint16m2_t vsrl(vuint16m2_t, vuint16m2_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vsrl_vv_m)))
vuint16m2_t vsrl(vbool8_t, vuint16m2_t, vuint16m2_t, vuint16m2_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vsrl_vv)))
vuint16m4_t vsrl(vuint16m4_t, vuint16m4_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vsrl_vv_m)))
vuint16m4_t vsrl(vbool4_t, vuint16m4_t, vuint16m4_t, vuint16m4_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vsrl_vv)))
vuint16m8_t vsrl(vuint16m8_t, vuint16m8_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vsrl_vv_m)))
vuint16m8_t vsrl(vbool2_t, vuint16m8_t, vuint16m8_t, vuint16m8_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vsrl_vv)))
vuint16mf2_t vsrl(vuint16mf2_t, vuint16mf2_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vsrl_vv_m)))
vuint16mf2_t vsrl(vbool32_t, vuint16mf2_t, vuint16mf2_t, vuint16mf2_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vsrl_vv)))
vuint16mf4_t vsrl(vuint16mf4_t, vuint16mf4_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vsrl_vv_m)))
vuint16mf4_t vsrl(vbool64_t, vuint16mf4_t, vuint16mf4_t, vuint16mf4_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vsrl_vv)))
vuint32m1_t vsrl(vuint32m1_t, vuint32m1_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vsrl_vv_m)))
vuint32m1_t vsrl(vbool32_t, vuint32m1_t, vuint32m1_t, vuint32m1_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vsrl_vv)))
vuint32m2_t vsrl(vuint32m2_t, vuint32m2_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vsrl_vv_m)))
vuint32m2_t vsrl(vbool16_t, vuint32m2_t, vuint32m2_t, vuint32m2_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vsrl_vv)))
vuint32m4_t vsrl(vuint32m4_t, vuint32m4_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vsrl_vv_m)))
vuint32m4_t vsrl(vbool8_t, vuint32m4_t, vuint32m4_t, vuint32m4_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vsrl_vv)))
vuint32m8_t vsrl(vuint32m8_t, vuint32m8_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vsrl_vv_m)))
vuint32m8_t vsrl(vbool4_t, vuint32m8_t, vuint32m8_t, vuint32m8_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vsrl_vv)))
vuint32mf2_t vsrl(vuint32mf2_t, vuint32mf2_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vsrl_vv_m)))
vuint32mf2_t vsrl(vbool64_t, vuint32mf2_t, vuint32mf2_t, vuint32mf2_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vsrl_vx)))
vuint8m1_t vsrl(vuint8m1_t, size_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vsrl_vx_m)))
vuint8m1_t vsrl(vbool8_t, vuint8m1_t, vuint8m1_t, size_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vsrl_vx)))
vuint8m2_t vsrl(vuint8m2_t, size_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vsrl_vx_m)))
vuint8m2_t vsrl(vbool4_t, vuint8m2_t, vuint8m2_t, size_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vsrl_vx)))
vuint8m4_t vsrl(vuint8m4_t, size_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vsrl_vx_m)))
vuint8m4_t vsrl(vbool2_t, vuint8m4_t, vuint8m4_t, size_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vsrl_vx)))
vuint8m8_t vsrl(vuint8m8_t, size_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vsrl_vx_m)))
vuint8m8_t vsrl(vbool1_t, vuint8m8_t, vuint8m8_t, size_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vsrl_vx)))
vuint8mf2_t vsrl(vuint8mf2_t, size_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vsrl_vx_m)))
vuint8mf2_t vsrl(vbool16_t, vuint8mf2_t, vuint8mf2_t, size_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vsrl_vx)))
vuint8mf4_t vsrl(vuint8mf4_t, size_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vsrl_vx_m)))
vuint8mf4_t vsrl(vbool32_t, vuint8mf4_t, vuint8mf4_t, size_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vsrl_vx)))
vuint8mf8_t vsrl(vuint8mf8_t, size_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vsrl_vx_m)))
vuint8mf8_t vsrl(vbool64_t, vuint8mf8_t, vuint8mf8_t, size_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vsrl_vx)))
vuint16m1_t vsrl(vuint16m1_t, size_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vsrl_vx_m)))
vuint16m1_t vsrl(vbool16_t, vuint16m1_t, vuint16m1_t, size_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vsrl_vx)))
vuint16m2_t vsrl(vuint16m2_t, size_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vsrl_vx_m)))
vuint16m2_t vsrl(vbool8_t, vuint16m2_t, vuint16m2_t, size_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vsrl_vx)))
vuint16m4_t vsrl(vuint16m4_t, size_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vsrl_vx_m)))
vuint16m4_t vsrl(vbool4_t, vuint16m4_t, vuint16m4_t, size_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vsrl_vx)))
vuint16m8_t vsrl(vuint16m8_t, size_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vsrl_vx_m)))
vuint16m8_t vsrl(vbool2_t, vuint16m8_t, vuint16m8_t, size_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vsrl_vx)))
vuint16mf2_t vsrl(vuint16mf2_t, size_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vsrl_vx_m)))
vuint16mf2_t vsrl(vbool32_t, vuint16mf2_t, vuint16mf2_t, size_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vsrl_vx)))
vuint16mf4_t vsrl(vuint16mf4_t, size_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vsrl_vx_m)))
vuint16mf4_t vsrl(vbool64_t, vuint16mf4_t, vuint16mf4_t, size_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vsrl_vx)))
vuint32m1_t vsrl(vuint32m1_t, size_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vsrl_vx_m)))
vuint32m1_t vsrl(vbool32_t, vuint32m1_t, vuint32m1_t, size_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vsrl_vx)))
vuint32m2_t vsrl(vuint32m2_t, size_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vsrl_vx_m)))
vuint32m2_t vsrl(vbool16_t, vuint32m2_t, vuint32m2_t, size_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vsrl_vx)))
vuint32m4_t vsrl(vuint32m4_t, size_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vsrl_vx_m)))
vuint32m4_t vsrl(vbool8_t, vuint32m4_t, vuint32m4_t, size_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vsrl_vx)))
vuint32m8_t vsrl(vuint32m8_t, size_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vsrl_vx_m)))
vuint32m8_t vsrl(vbool4_t, vuint32m8_t, vuint32m8_t, size_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vsrl_vx)))
vuint32mf2_t vsrl(vuint32mf2_t, size_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vsrl_vx_m)))
vuint32mf2_t vsrl(vbool64_t, vuint32mf2_t, vuint32mf2_t, size_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vsra_vv)))
vint8m1_t vsra(vint8m1_t, vuint8m1_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vsra_vv_m)))
vint8m1_t vsra(vbool8_t, vint8m1_t, vint8m1_t, vuint8m1_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vsra_vv)))
vint8m2_t vsra(vint8m2_t, vuint8m2_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vsra_vv_m)))
vint8m2_t vsra(vbool4_t, vint8m2_t, vint8m2_t, vuint8m2_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vsra_vv)))
vint8m4_t vsra(vint8m4_t, vuint8m4_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vsra_vv_m)))
vint8m4_t vsra(vbool2_t, vint8m4_t, vint8m4_t, vuint8m4_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vsra_vv)))
vint8m8_t vsra(vint8m8_t, vuint8m8_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vsra_vv_m)))
vint8m8_t vsra(vbool1_t, vint8m8_t, vint8m8_t, vuint8m8_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vsra_vv)))
vint8mf2_t vsra(vint8mf2_t, vuint8mf2_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vsra_vv_m)))
vint8mf2_t vsra(vbool16_t, vint8mf2_t, vint8mf2_t, vuint8mf2_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vsra_vv)))
vint8mf4_t vsra(vint8mf4_t, vuint8mf4_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vsra_vv_m)))
vint8mf4_t vsra(vbool32_t, vint8mf4_t, vint8mf4_t, vuint8mf4_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vsra_vv)))
vint8mf8_t vsra(vint8mf8_t, vuint8mf8_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vsra_vv_m)))
vint8mf8_t vsra(vbool64_t, vint8mf8_t, vint8mf8_t, vuint8mf8_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vsra_vv)))
vint16m1_t vsra(vint16m1_t, vuint16m1_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vsra_vv_m)))
vint16m1_t vsra(vbool16_t, vint16m1_t, vint16m1_t, vuint16m1_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vsra_vv)))
vint16m2_t vsra(vint16m2_t, vuint16m2_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vsra_vv_m)))
vint16m2_t vsra(vbool8_t, vint16m2_t, vint16m2_t, vuint16m2_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vsra_vv)))
vint16m4_t vsra(vint16m4_t, vuint16m4_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vsra_vv_m)))
vint16m4_t vsra(vbool4_t, vint16m4_t, vint16m4_t, vuint16m4_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vsra_vv)))
vint16m8_t vsra(vint16m8_t, vuint16m8_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vsra_vv_m)))
vint16m8_t vsra(vbool2_t, vint16m8_t, vint16m8_t, vuint16m8_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vsra_vv)))
vint16mf2_t vsra(vint16mf2_t, vuint16mf2_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vsra_vv_m)))
vint16mf2_t vsra(vbool32_t, vint16mf2_t, vint16mf2_t, vuint16mf2_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vsra_vv)))
vint16mf4_t vsra(vint16mf4_t, vuint16mf4_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vsra_vv_m)))
vint16mf4_t vsra(vbool64_t, vint16mf4_t, vint16mf4_t, vuint16mf4_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vsra_vv)))
vint32m1_t vsra(vint32m1_t, vuint32m1_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vsra_vv_m)))
vint32m1_t vsra(vbool32_t, vint32m1_t, vint32m1_t, vuint32m1_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vsra_vv)))
vint32m2_t vsra(vint32m2_t, vuint32m2_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vsra_vv_m)))
vint32m2_t vsra(vbool16_t, vint32m2_t, vint32m2_t, vuint32m2_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vsra_vv)))
vint32m4_t vsra(vint32m4_t, vuint32m4_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vsra_vv_m)))
vint32m4_t vsra(vbool8_t, vint32m4_t, vint32m4_t, vuint32m4_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vsra_vv)))
vint32m8_t vsra(vint32m8_t, vuint32m8_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vsra_vv_m)))
vint32m8_t vsra(vbool4_t, vint32m8_t, vint32m8_t, vuint32m8_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vsra_vv)))
vint32mf2_t vsra(vint32mf2_t, vuint32mf2_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vsra_vv_m)))
vint32mf2_t vsra(vbool64_t, vint32mf2_t, vint32mf2_t, vuint32mf2_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vsra_vx)))
vint8m1_t vsra(vint8m1_t, size_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vsra_vx_m)))
vint8m1_t vsra(vbool8_t, vint8m1_t, vint8m1_t, size_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vsra_vx)))
vint8m2_t vsra(vint8m2_t, size_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vsra_vx_m)))
vint8m2_t vsra(vbool4_t, vint8m2_t, vint8m2_t, size_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vsra_vx)))
vint8m4_t vsra(vint8m4_t, size_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vsra_vx_m)))
vint8m4_t vsra(vbool2_t, vint8m4_t, vint8m4_t, size_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vsra_vx)))
vint8m8_t vsra(vint8m8_t, size_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vsra_vx_m)))
vint8m8_t vsra(vbool1_t, vint8m8_t, vint8m8_t, size_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vsra_vx)))
vint8mf2_t vsra(vint8mf2_t, size_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vsra_vx_m)))
vint8mf2_t vsra(vbool16_t, vint8mf2_t, vint8mf2_t, size_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vsra_vx)))
vint8mf4_t vsra(vint8mf4_t, size_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vsra_vx_m)))
vint8mf4_t vsra(vbool32_t, vint8mf4_t, vint8mf4_t, size_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vsra_vx)))
vint8mf8_t vsra(vint8mf8_t, size_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vsra_vx_m)))
vint8mf8_t vsra(vbool64_t, vint8mf8_t, vint8mf8_t, size_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vsra_vx)))
vint16m1_t vsra(vint16m1_t, size_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vsra_vx_m)))
vint16m1_t vsra(vbool16_t, vint16m1_t, vint16m1_t, size_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vsra_vx)))
vint16m2_t vsra(vint16m2_t, size_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vsra_vx_m)))
vint16m2_t vsra(vbool8_t, vint16m2_t, vint16m2_t, size_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vsra_vx)))
vint16m4_t vsra(vint16m4_t, size_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vsra_vx_m)))
vint16m4_t vsra(vbool4_t, vint16m4_t, vint16m4_t, size_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vsra_vx)))
vint16m8_t vsra(vint16m8_t, size_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vsra_vx_m)))
vint16m8_t vsra(vbool2_t, vint16m8_t, vint16m8_t, size_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vsra_vx)))
vint16mf2_t vsra(vint16mf2_t, size_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vsra_vx_m)))
vint16mf2_t vsra(vbool32_t, vint16mf2_t, vint16mf2_t, size_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vsra_vx)))
vint16mf4_t vsra(vint16mf4_t, size_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vsra_vx_m)))
vint16mf4_t vsra(vbool64_t, vint16mf4_t, vint16mf4_t, size_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vsra_vx)))
vint32m1_t vsra(vint32m1_t, size_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vsra_vx_m)))
vint32m1_t vsra(vbool32_t, vint32m1_t, vint32m1_t, size_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vsra_vx)))
vint32m2_t vsra(vint32m2_t, size_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vsra_vx_m)))
vint32m2_t vsra(vbool16_t, vint32m2_t, vint32m2_t, size_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vsra_vx)))
vint32m4_t vsra(vint32m4_t, size_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vsra_vx_m)))
vint32m4_t vsra(vbool8_t, vint32m4_t, vint32m4_t, size_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vsra_vx)))
vint32m8_t vsra(vint32m8_t, size_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vsra_vx_m)))
vint32m8_t vsra(vbool4_t, vint32m8_t, vint32m8_t, size_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vsra_vx)))
vint32mf2_t vsra(vint32mf2_t, size_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vsra_vx_m)))
vint32mf2_t vsra(vbool64_t, vint32mf2_t, vint32mf2_t, size_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vnsrl_wv)))
vuint8m1_t vnsrl(vuint16m2_t, vuint8m1_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vnsrl_wv_m)))
vuint8m1_t vnsrl(vbool8_t, vuint8m1_t, vuint16m2_t, vuint8m1_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vnsrl_wv)))
vuint8m2_t vnsrl(vuint16m4_t, vuint8m2_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vnsrl_wv_m)))
vuint8m2_t vnsrl(vbool4_t, vuint8m2_t, vuint16m4_t, vuint8m2_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vnsrl_wv)))
vuint8m4_t vnsrl(vuint16m8_t, vuint8m4_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vnsrl_wv_m)))
vuint8m4_t vnsrl(vbool2_t, vuint8m4_t, vuint16m8_t, vuint8m4_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vnsrl_wv)))
vuint8mf2_t vnsrl(vuint16m1_t, vuint8mf2_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vnsrl_wv_m)))
vuint8mf2_t vnsrl(vbool16_t, vuint8mf2_t, vuint16m1_t, vuint8mf2_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vnsrl_wv)))
vuint8mf4_t vnsrl(vuint16mf2_t, vuint8mf4_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vnsrl_wv_m)))
vuint8mf4_t vnsrl(vbool32_t, vuint8mf4_t, vuint16mf2_t, vuint8mf4_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vnsrl_wv)))
vuint8mf8_t vnsrl(vuint16mf4_t, vuint8mf8_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vnsrl_wv_m)))
vuint8mf8_t vnsrl(vbool64_t, vuint8mf8_t, vuint16mf4_t, vuint8mf8_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vnsrl_wv)))
vuint16m1_t vnsrl(vuint32m2_t, vuint16m1_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vnsrl_wv_m)))
vuint16m1_t vnsrl(vbool16_t, vuint16m1_t, vuint32m2_t, vuint16m1_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vnsrl_wv)))
vuint16m2_t vnsrl(vuint32m4_t, vuint16m2_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vnsrl_wv_m)))
vuint16m2_t vnsrl(vbool8_t, vuint16m2_t, vuint32m4_t, vuint16m2_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vnsrl_wv)))
vuint16m4_t vnsrl(vuint32m8_t, vuint16m4_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vnsrl_wv_m)))
vuint16m4_t vnsrl(vbool4_t, vuint16m4_t, vuint32m8_t, vuint16m4_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vnsrl_wv)))
vuint16mf2_t vnsrl(vuint32m1_t, vuint16mf2_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vnsrl_wv_m)))
vuint16mf2_t vnsrl(vbool32_t, vuint16mf2_t, vuint32m1_t, vuint16mf2_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vnsrl_wv)))
vuint16mf4_t vnsrl(vuint32mf2_t, vuint16mf4_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vnsrl_wv_m)))
vuint16mf4_t vnsrl(vbool64_t, vuint16mf4_t, vuint32mf2_t, vuint16mf4_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vnsrl_wx)))
vuint8m1_t vnsrl(vuint16m2_t, size_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vnsrl_wx_m)))
vuint8m1_t vnsrl(vbool8_t, vuint8m1_t, vuint16m2_t, size_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vnsrl_wx)))
vuint8m2_t vnsrl(vuint16m4_t, size_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vnsrl_wx_m)))
vuint8m2_t vnsrl(vbool4_t, vuint8m2_t, vuint16m4_t, size_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vnsrl_wx)))
vuint8m4_t vnsrl(vuint16m8_t, size_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vnsrl_wx_m)))
vuint8m4_t vnsrl(vbool2_t, vuint8m4_t, vuint16m8_t, size_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vnsrl_wx)))
vuint8mf2_t vnsrl(vuint16m1_t, size_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vnsrl_wx_m)))
vuint8mf2_t vnsrl(vbool16_t, vuint8mf2_t, vuint16m1_t, size_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vnsrl_wx)))
vuint8mf4_t vnsrl(vuint16mf2_t, size_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vnsrl_wx_m)))
vuint8mf4_t vnsrl(vbool32_t, vuint8mf4_t, vuint16mf2_t, size_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vnsrl_wx)))
vuint8mf8_t vnsrl(vuint16mf4_t, size_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vnsrl_wx_m)))
vuint8mf8_t vnsrl(vbool64_t, vuint8mf8_t, vuint16mf4_t, size_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vnsrl_wx)))
vuint16m1_t vnsrl(vuint32m2_t, size_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vnsrl_wx_m)))
vuint16m1_t vnsrl(vbool16_t, vuint16m1_t, vuint32m2_t, size_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vnsrl_wx)))
vuint16m2_t vnsrl(vuint32m4_t, size_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vnsrl_wx_m)))
vuint16m2_t vnsrl(vbool8_t, vuint16m2_t, vuint32m4_t, size_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vnsrl_wx)))
vuint16m4_t vnsrl(vuint32m8_t, size_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vnsrl_wx_m)))
vuint16m4_t vnsrl(vbool4_t, vuint16m4_t, vuint32m8_t, size_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vnsrl_wx)))
vuint16mf2_t vnsrl(vuint32m1_t, size_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vnsrl_wx_m)))
vuint16mf2_t vnsrl(vbool32_t, vuint16mf2_t, vuint32m1_t, size_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vnsrl_wx)))
vuint16mf4_t vnsrl(vuint32mf2_t, size_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vnsrl_wx_m)))
vuint16mf4_t vnsrl(vbool64_t, vuint16mf4_t, vuint32mf2_t, size_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vnsra_wv)))
vint8m1_t vnsra(vint16m2_t, vuint8m1_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vnsra_wv_m)))
vint8m1_t vnsra(vbool8_t, vint8m1_t, vint16m2_t, vuint8m1_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vnsra_wv)))
vint8m2_t vnsra(vint16m4_t, vuint8m2_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vnsra_wv_m)))
vint8m2_t vnsra(vbool4_t, vint8m2_t, vint16m4_t, vuint8m2_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vnsra_wv)))
vint8m4_t vnsra(vint16m8_t, vuint8m4_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vnsra_wv_m)))
vint8m4_t vnsra(vbool2_t, vint8m4_t, vint16m8_t, vuint8m4_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vnsra_wv)))
vint8mf2_t vnsra(vint16m1_t, vuint8mf2_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vnsra_wv_m)))
vint8mf2_t vnsra(vbool16_t, vint8mf2_t, vint16m1_t, vuint8mf2_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vnsra_wv)))
vint8mf4_t vnsra(vint16mf2_t, vuint8mf4_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vnsra_wv_m)))
vint8mf4_t vnsra(vbool32_t, vint8mf4_t, vint16mf2_t, vuint8mf4_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vnsra_wv)))
vint8mf8_t vnsra(vint16mf4_t, vuint8mf8_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vnsra_wv_m)))
vint8mf8_t vnsra(vbool64_t, vint8mf8_t, vint16mf4_t, vuint8mf8_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vnsra_wv)))
vint16m1_t vnsra(vint32m2_t, vuint16m1_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vnsra_wv_m)))
vint16m1_t vnsra(vbool16_t, vint16m1_t, vint32m2_t, vuint16m1_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vnsra_wv)))
vint16m2_t vnsra(vint32m4_t, vuint16m2_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vnsra_wv_m)))
vint16m2_t vnsra(vbool8_t, vint16m2_t, vint32m4_t, vuint16m2_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vnsra_wv)))
vint16m4_t vnsra(vint32m8_t, vuint16m4_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vnsra_wv_m)))
vint16m4_t vnsra(vbool4_t, vint16m4_t, vint32m8_t, vuint16m4_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vnsra_wv)))
vint16mf2_t vnsra(vint32m1_t, vuint16mf2_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vnsra_wv_m)))
vint16mf2_t vnsra(vbool32_t, vint16mf2_t, vint32m1_t, vuint16mf2_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vnsra_wv)))
vint16mf4_t vnsra(vint32mf2_t, vuint16mf4_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vnsra_wv_m)))
vint16mf4_t vnsra(vbool64_t, vint16mf4_t, vint32mf2_t, vuint16mf4_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vnsra_wx)))
vint8m1_t vnsra(vint16m2_t, size_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vnsra_wx_m)))
vint8m1_t vnsra(vbool8_t, vint8m1_t, vint16m2_t, size_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vnsra_wx)))
vint8m2_t vnsra(vint16m4_t, size_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vnsra_wx_m)))
vint8m2_t vnsra(vbool4_t, vint8m2_t, vint16m4_t, size_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vnsra_wx)))
vint8m4_t vnsra(vint16m8_t, size_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vnsra_wx_m)))
vint8m4_t vnsra(vbool2_t, vint8m4_t, vint16m8_t, size_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vnsra_wx)))
vint8mf2_t vnsra(vint16m1_t, size_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vnsra_wx_m)))
vint8mf2_t vnsra(vbool16_t, vint8mf2_t, vint16m1_t, size_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vnsra_wx)))
vint8mf4_t vnsra(vint16mf2_t, size_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vnsra_wx_m)))
vint8mf4_t vnsra(vbool32_t, vint8mf4_t, vint16mf2_t, size_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vnsra_wx)))
vint8mf8_t vnsra(vint16mf4_t, size_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vnsra_wx_m)))
vint8mf8_t vnsra(vbool64_t, vint8mf8_t, vint16mf4_t, size_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vnsra_wx)))
vint16m1_t vnsra(vint32m2_t, size_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vnsra_wx_m)))
vint16m1_t vnsra(vbool16_t, vint16m1_t, vint32m2_t, size_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vnsra_wx)))
vint16m2_t vnsra(vint32m4_t, size_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vnsra_wx_m)))
vint16m2_t vnsra(vbool8_t, vint16m2_t, vint32m4_t, size_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vnsra_wx)))
vint16m4_t vnsra(vint32m8_t, size_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vnsra_wx_m)))
vint16m4_t vnsra(vbool4_t, vint16m4_t, vint32m8_t, size_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vnsra_wx)))
vint16mf2_t vnsra(vint32m1_t, size_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vnsra_wx_m)))
vint16mf2_t vnsra(vbool32_t, vint16mf2_t, vint32m1_t, size_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vnsra_wx)))
vint16mf4_t vnsra(vint32mf2_t, size_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vnsra_wx_m)))
vint16mf4_t vnsra(vbool64_t, vint16mf4_t, vint32mf2_t, size_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vncvt_x_x_w)))
vuint8m1_t vncvt_x(vuint16m2_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vncvt_x_x_w_m)))
vuint8m1_t vncvt_x(vbool8_t, vuint8m1_t, vuint16m2_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vncvt_x_x_w)))
vuint8m2_t vncvt_x(vuint16m4_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vncvt_x_x_w_m)))
vuint8m2_t vncvt_x(vbool4_t, vuint8m2_t, vuint16m4_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vncvt_x_x_w)))
vuint8m4_t vncvt_x(vuint16m8_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vncvt_x_x_w_m)))
vuint8m4_t vncvt_x(vbool2_t, vuint8m4_t, vuint16m8_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vncvt_x_x_w)))
vuint8mf2_t vncvt_x(vuint16m1_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vncvt_x_x_w_m)))
vuint8mf2_t vncvt_x(vbool16_t, vuint8mf2_t, vuint16m1_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vncvt_x_x_w)))
vuint8mf4_t vncvt_x(vuint16mf2_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vncvt_x_x_w_m)))
vuint8mf4_t vncvt_x(vbool32_t, vuint8mf4_t, vuint16mf2_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vncvt_x_x_w)))
vuint8mf8_t vncvt_x(vuint16mf4_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vncvt_x_x_w_m)))
vuint8mf8_t vncvt_x(vbool64_t, vuint8mf8_t, vuint16mf4_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vncvt_x_x_w)))
vuint16m1_t vncvt_x(vuint32m2_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vncvt_x_x_w_m)))
vuint16m1_t vncvt_x(vbool16_t, vuint16m1_t, vuint32m2_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vncvt_x_x_w)))
vuint16m2_t vncvt_x(vuint32m4_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vncvt_x_x_w_m)))
vuint16m2_t vncvt_x(vbool8_t, vuint16m2_t, vuint32m4_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vncvt_x_x_w)))
vuint16m4_t vncvt_x(vuint32m8_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vncvt_x_x_w_m)))
vuint16m4_t vncvt_x(vbool4_t, vuint16m4_t, vuint32m8_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vncvt_x_x_w)))
vuint16mf2_t vncvt_x(vuint32m1_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vncvt_x_x_w_m)))
vuint16mf2_t vncvt_x(vbool32_t, vuint16mf2_t, vuint32m1_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vncvt_x_x_w)))
vuint16mf4_t vncvt_x(vuint32mf2_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vncvt_x_x_w_m)))
vuint16mf4_t vncvt_x(vbool64_t, vuint16mf4_t, vuint32mf2_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vmseq_vv)))
vbool8_t vmseq(vint8m1_t, vint8m1_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vmseq_vv_m)))
vbool8_t vmseq(vbool8_t, vbool8_t, vint8m1_t, vint8m1_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vmseq_vv)))
vbool4_t vmseq(vint8m2_t, vint8m2_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vmseq_vv_m)))
vbool4_t vmseq(vbool4_t, vbool4_t, vint8m2_t, vint8m2_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vmseq_vv)))
vbool2_t vmseq(vint8m4_t, vint8m4_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vmseq_vv_m)))
vbool2_t vmseq(vbool2_t, vbool2_t, vint8m4_t, vint8m4_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vmseq_vv)))
vbool1_t vmseq(vint8m8_t, vint8m8_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vmseq_vv_m)))
vbool1_t vmseq(vbool1_t, vbool1_t, vint8m8_t, vint8m8_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vmseq_vv)))
vbool16_t vmseq(vint8mf2_t, vint8mf2_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vmseq_vv_m)))
vbool16_t vmseq(vbool16_t, vbool16_t, vint8mf2_t, vint8mf2_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vmseq_vv)))
vbool32_t vmseq(vint8mf4_t, vint8mf4_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vmseq_vv_m)))
vbool32_t vmseq(vbool32_t, vbool32_t, vint8mf4_t, vint8mf4_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vmseq_vv)))
vbool64_t vmseq(vint8mf8_t, vint8mf8_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vmseq_vv_m)))
vbool64_t vmseq(vbool64_t, vbool64_t, vint8mf8_t, vint8mf8_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vmseq_vv)))
vbool16_t vmseq(vint16m1_t, vint16m1_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vmseq_vv_m)))
vbool16_t vmseq(vbool16_t, vbool16_t, vint16m1_t, vint16m1_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vmseq_vv)))
vbool8_t vmseq(vint16m2_t, vint16m2_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vmseq_vv_m)))
vbool8_t vmseq(vbool8_t, vbool8_t, vint16m2_t, vint16m2_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vmseq_vv)))
vbool4_t vmseq(vint16m4_t, vint16m4_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vmseq_vv_m)))
vbool4_t vmseq(vbool4_t, vbool4_t, vint16m4_t, vint16m4_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vmseq_vv)))
vbool2_t vmseq(vint16m8_t, vint16m8_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vmseq_vv_m)))
vbool2_t vmseq(vbool2_t, vbool2_t, vint16m8_t, vint16m8_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vmseq_vv)))
vbool32_t vmseq(vint16mf2_t, vint16mf2_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vmseq_vv_m)))
vbool32_t vmseq(vbool32_t, vbool32_t, vint16mf2_t, vint16mf2_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vmseq_vv)))
vbool64_t vmseq(vint16mf4_t, vint16mf4_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vmseq_vv_m)))
vbool64_t vmseq(vbool64_t, vbool64_t, vint16mf4_t, vint16mf4_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vmseq_vv)))
vbool32_t vmseq(vint32m1_t, vint32m1_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vmseq_vv_m)))
vbool32_t vmseq(vbool32_t, vbool32_t, vint32m1_t, vint32m1_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vmseq_vv)))
vbool16_t vmseq(vint32m2_t, vint32m2_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vmseq_vv_m)))
vbool16_t vmseq(vbool16_t, vbool16_t, vint32m2_t, vint32m2_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vmseq_vv)))
vbool8_t vmseq(vint32m4_t, vint32m4_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vmseq_vv_m)))
vbool8_t vmseq(vbool8_t, vbool8_t, vint32m4_t, vint32m4_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vmseq_vv)))
vbool4_t vmseq(vint32m8_t, vint32m8_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vmseq_vv_m)))
vbool4_t vmseq(vbool4_t, vbool4_t, vint32m8_t, vint32m8_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vmseq_vv)))
vbool64_t vmseq(vint32mf2_t, vint32mf2_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vmseq_vv_m)))
vbool64_t vmseq(vbool64_t, vbool64_t, vint32mf2_t, vint32mf2_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vmseq_vx)))
vbool8_t vmseq(vint8m1_t, int8_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vmseq_vx_m)))
vbool8_t vmseq(vbool8_t, vbool8_t, vint8m1_t, int8_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vmseq_vx)))
vbool4_t vmseq(vint8m2_t, int8_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vmseq_vx_m)))
vbool4_t vmseq(vbool4_t, vbool4_t, vint8m2_t, int8_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vmseq_vx)))
vbool2_t vmseq(vint8m4_t, int8_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vmseq_vx_m)))
vbool2_t vmseq(vbool2_t, vbool2_t, vint8m4_t, int8_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vmseq_vx)))
vbool1_t vmseq(vint8m8_t, int8_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vmseq_vx_m)))
vbool1_t vmseq(vbool1_t, vbool1_t, vint8m8_t, int8_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vmseq_vx)))
vbool16_t vmseq(vint8mf2_t, int8_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vmseq_vx_m)))
vbool16_t vmseq(vbool16_t, vbool16_t, vint8mf2_t, int8_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vmseq_vx)))
vbool32_t vmseq(vint8mf4_t, int8_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vmseq_vx_m)))
vbool32_t vmseq(vbool32_t, vbool32_t, vint8mf4_t, int8_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vmseq_vx)))
vbool64_t vmseq(vint8mf8_t, int8_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vmseq_vx_m)))
vbool64_t vmseq(vbool64_t, vbool64_t, vint8mf8_t, int8_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vmseq_vx)))
vbool16_t vmseq(vint16m1_t, int16_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vmseq_vx_m)))
vbool16_t vmseq(vbool16_t, vbool16_t, vint16m1_t, int16_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vmseq_vx)))
vbool8_t vmseq(vint16m2_t, int16_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vmseq_vx_m)))
vbool8_t vmseq(vbool8_t, vbool8_t, vint16m2_t, int16_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vmseq_vx)))
vbool4_t vmseq(vint16m4_t, int16_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vmseq_vx_m)))
vbool4_t vmseq(vbool4_t, vbool4_t, vint16m4_t, int16_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vmseq_vx)))
vbool2_t vmseq(vint16m8_t, int16_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vmseq_vx_m)))
vbool2_t vmseq(vbool2_t, vbool2_t, vint16m8_t, int16_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vmseq_vx)))
vbool32_t vmseq(vint16mf2_t, int16_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vmseq_vx_m)))
vbool32_t vmseq(vbool32_t, vbool32_t, vint16mf2_t, int16_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vmseq_vx)))
vbool64_t vmseq(vint16mf4_t, int16_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vmseq_vx_m)))
vbool64_t vmseq(vbool64_t, vbool64_t, vint16mf4_t, int16_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vmseq_vx)))
vbool32_t vmseq(vint32m1_t, int32_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vmseq_vx_m)))
vbool32_t vmseq(vbool32_t, vbool32_t, vint32m1_t, int32_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vmseq_vx)))
vbool16_t vmseq(vint32m2_t, int32_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vmseq_vx_m)))
vbool16_t vmseq(vbool16_t, vbool16_t, vint32m2_t, int32_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vmseq_vx)))
vbool8_t vmseq(vint32m4_t, int32_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vmseq_vx_m)))
vbool8_t vmseq(vbool8_t, vbool8_t, vint32m4_t, int32_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vmseq_vx)))
vbool4_t vmseq(vint32m8_t, int32_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vmseq_vx_m)))
vbool4_t vmseq(vbool4_t, vbool4_t, vint32m8_t, int32_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vmseq_vx)))
vbool64_t vmseq(vint32mf2_t, int32_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vmseq_vx_m)))
vbool64_t vmseq(vbool64_t, vbool64_t, vint32mf2_t, int32_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vmseq_vv)))
vbool8_t vmseq(vuint8m1_t, vuint8m1_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vmseq_vv_m)))
vbool8_t vmseq(vbool8_t, vbool8_t, vuint8m1_t, vuint8m1_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vmseq_vv)))
vbool4_t vmseq(vuint8m2_t, vuint8m2_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vmseq_vv_m)))
vbool4_t vmseq(vbool4_t, vbool4_t, vuint8m2_t, vuint8m2_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vmseq_vv)))
vbool2_t vmseq(vuint8m4_t, vuint8m4_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vmseq_vv_m)))
vbool2_t vmseq(vbool2_t, vbool2_t, vuint8m4_t, vuint8m4_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vmseq_vv)))
vbool1_t vmseq(vuint8m8_t, vuint8m8_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vmseq_vv_m)))
vbool1_t vmseq(vbool1_t, vbool1_t, vuint8m8_t, vuint8m8_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vmseq_vv)))
vbool16_t vmseq(vuint8mf2_t, vuint8mf2_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vmseq_vv_m)))
vbool16_t vmseq(vbool16_t, vbool16_t, vuint8mf2_t, vuint8mf2_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vmseq_vv)))
vbool32_t vmseq(vuint8mf4_t, vuint8mf4_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vmseq_vv_m)))
vbool32_t vmseq(vbool32_t, vbool32_t, vuint8mf4_t, vuint8mf4_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vmseq_vv)))
vbool64_t vmseq(vuint8mf8_t, vuint8mf8_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vmseq_vv_m)))
vbool64_t vmseq(vbool64_t, vbool64_t, vuint8mf8_t, vuint8mf8_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vmseq_vv)))
vbool16_t vmseq(vuint16m1_t, vuint16m1_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vmseq_vv_m)))
vbool16_t vmseq(vbool16_t, vbool16_t, vuint16m1_t, vuint16m1_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vmseq_vv)))
vbool8_t vmseq(vuint16m2_t, vuint16m2_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vmseq_vv_m)))
vbool8_t vmseq(vbool8_t, vbool8_t, vuint16m2_t, vuint16m2_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vmseq_vv)))
vbool4_t vmseq(vuint16m4_t, vuint16m4_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vmseq_vv_m)))
vbool4_t vmseq(vbool4_t, vbool4_t, vuint16m4_t, vuint16m4_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vmseq_vv)))
vbool2_t vmseq(vuint16m8_t, vuint16m8_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vmseq_vv_m)))
vbool2_t vmseq(vbool2_t, vbool2_t, vuint16m8_t, vuint16m8_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vmseq_vv)))
vbool32_t vmseq(vuint16mf2_t, vuint16mf2_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vmseq_vv_m)))
vbool32_t vmseq(vbool32_t, vbool32_t, vuint16mf2_t, vuint16mf2_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vmseq_vv)))
vbool64_t vmseq(vuint16mf4_t, vuint16mf4_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vmseq_vv_m)))
vbool64_t vmseq(vbool64_t, vbool64_t, vuint16mf4_t, vuint16mf4_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vmseq_vv)))
vbool32_t vmseq(vuint32m1_t, vuint32m1_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vmseq_vv_m)))
vbool32_t vmseq(vbool32_t, vbool32_t, vuint32m1_t, vuint32m1_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vmseq_vv)))
vbool16_t vmseq(vuint32m2_t, vuint32m2_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vmseq_vv_m)))
vbool16_t vmseq(vbool16_t, vbool16_t, vuint32m2_t, vuint32m2_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vmseq_vv)))
vbool8_t vmseq(vuint32m4_t, vuint32m4_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vmseq_vv_m)))
vbool8_t vmseq(vbool8_t, vbool8_t, vuint32m4_t, vuint32m4_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vmseq_vv)))
vbool4_t vmseq(vuint32m8_t, vuint32m8_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vmseq_vv_m)))
vbool4_t vmseq(vbool4_t, vbool4_t, vuint32m8_t, vuint32m8_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vmseq_vv)))
vbool64_t vmseq(vuint32mf2_t, vuint32mf2_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vmseq_vv_m)))
vbool64_t vmseq(vbool64_t, vbool64_t, vuint32mf2_t, vuint32mf2_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vmseq_vx)))
vbool8_t vmseq(vuint8m1_t, uint8_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vmseq_vx_m)))
vbool8_t vmseq(vbool8_t, vbool8_t, vuint8m1_t, uint8_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vmseq_vx)))
vbool4_t vmseq(vuint8m2_t, uint8_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vmseq_vx_m)))
vbool4_t vmseq(vbool4_t, vbool4_t, vuint8m2_t, uint8_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vmseq_vx)))
vbool2_t vmseq(vuint8m4_t, uint8_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vmseq_vx_m)))
vbool2_t vmseq(vbool2_t, vbool2_t, vuint8m4_t, uint8_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vmseq_vx)))
vbool1_t vmseq(vuint8m8_t, uint8_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vmseq_vx_m)))
vbool1_t vmseq(vbool1_t, vbool1_t, vuint8m8_t, uint8_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vmseq_vx)))
vbool16_t vmseq(vuint8mf2_t, uint8_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vmseq_vx_m)))
vbool16_t vmseq(vbool16_t, vbool16_t, vuint8mf2_t, uint8_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vmseq_vx)))
vbool32_t vmseq(vuint8mf4_t, uint8_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vmseq_vx_m)))
vbool32_t vmseq(vbool32_t, vbool32_t, vuint8mf4_t, uint8_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vmseq_vx)))
vbool64_t vmseq(vuint8mf8_t, uint8_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vmseq_vx_m)))
vbool64_t vmseq(vbool64_t, vbool64_t, vuint8mf8_t, uint8_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vmseq_vx)))
vbool16_t vmseq(vuint16m1_t, uint16_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vmseq_vx_m)))
vbool16_t vmseq(vbool16_t, vbool16_t, vuint16m1_t, uint16_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vmseq_vx)))
vbool8_t vmseq(vuint16m2_t, uint16_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vmseq_vx_m)))
vbool8_t vmseq(vbool8_t, vbool8_t, vuint16m2_t, uint16_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vmseq_vx)))
vbool4_t vmseq(vuint16m4_t, uint16_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vmseq_vx_m)))
vbool4_t vmseq(vbool4_t, vbool4_t, vuint16m4_t, uint16_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vmseq_vx)))
vbool2_t vmseq(vuint16m8_t, uint16_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vmseq_vx_m)))
vbool2_t vmseq(vbool2_t, vbool2_t, vuint16m8_t, uint16_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vmseq_vx)))
vbool32_t vmseq(vuint16mf2_t, uint16_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vmseq_vx_m)))
vbool32_t vmseq(vbool32_t, vbool32_t, vuint16mf2_t, uint16_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vmseq_vx)))
vbool64_t vmseq(vuint16mf4_t, uint16_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vmseq_vx_m)))
vbool64_t vmseq(vbool64_t, vbool64_t, vuint16mf4_t, uint16_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vmseq_vx)))
vbool32_t vmseq(vuint32m1_t, uint32_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vmseq_vx_m)))
vbool32_t vmseq(vbool32_t, vbool32_t, vuint32m1_t, uint32_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vmseq_vx)))
vbool16_t vmseq(vuint32m2_t, uint32_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vmseq_vx_m)))
vbool16_t vmseq(vbool16_t, vbool16_t, vuint32m2_t, uint32_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vmseq_vx)))
vbool8_t vmseq(vuint32m4_t, uint32_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vmseq_vx_m)))
vbool8_t vmseq(vbool8_t, vbool8_t, vuint32m4_t, uint32_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vmseq_vx)))
vbool4_t vmseq(vuint32m8_t, uint32_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vmseq_vx_m)))
vbool4_t vmseq(vbool4_t, vbool4_t, vuint32m8_t, uint32_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vmseq_vx)))
vbool64_t vmseq(vuint32mf2_t, uint32_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vmseq_vx_m)))
vbool64_t vmseq(vbool64_t, vbool64_t, vuint32mf2_t, uint32_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vmsne_vv)))
vbool8_t vmsne(vint8m1_t, vint8m1_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vmsne_vv_m)))
vbool8_t vmsne(vbool8_t, vbool8_t, vint8m1_t, vint8m1_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vmsne_vv)))
vbool4_t vmsne(vint8m2_t, vint8m2_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vmsne_vv_m)))
vbool4_t vmsne(vbool4_t, vbool4_t, vint8m2_t, vint8m2_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vmsne_vv)))
vbool2_t vmsne(vint8m4_t, vint8m4_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vmsne_vv_m)))
vbool2_t vmsne(vbool2_t, vbool2_t, vint8m4_t, vint8m4_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vmsne_vv)))
vbool1_t vmsne(vint8m8_t, vint8m8_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vmsne_vv_m)))
vbool1_t vmsne(vbool1_t, vbool1_t, vint8m8_t, vint8m8_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vmsne_vv)))
vbool16_t vmsne(vint8mf2_t, vint8mf2_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vmsne_vv_m)))
vbool16_t vmsne(vbool16_t, vbool16_t, vint8mf2_t, vint8mf2_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vmsne_vv)))
vbool32_t vmsne(vint8mf4_t, vint8mf4_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vmsne_vv_m)))
vbool32_t vmsne(vbool32_t, vbool32_t, vint8mf4_t, vint8mf4_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vmsne_vv)))
vbool64_t vmsne(vint8mf8_t, vint8mf8_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vmsne_vv_m)))
vbool64_t vmsne(vbool64_t, vbool64_t, vint8mf8_t, vint8mf8_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vmsne_vv)))
vbool16_t vmsne(vint16m1_t, vint16m1_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vmsne_vv_m)))
vbool16_t vmsne(vbool16_t, vbool16_t, vint16m1_t, vint16m1_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vmsne_vv)))
vbool8_t vmsne(vint16m2_t, vint16m2_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vmsne_vv_m)))
vbool8_t vmsne(vbool8_t, vbool8_t, vint16m2_t, vint16m2_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vmsne_vv)))
vbool4_t vmsne(vint16m4_t, vint16m4_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vmsne_vv_m)))
vbool4_t vmsne(vbool4_t, vbool4_t, vint16m4_t, vint16m4_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vmsne_vv)))
vbool2_t vmsne(vint16m8_t, vint16m8_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vmsne_vv_m)))
vbool2_t vmsne(vbool2_t, vbool2_t, vint16m8_t, vint16m8_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vmsne_vv)))
vbool32_t vmsne(vint16mf2_t, vint16mf2_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vmsne_vv_m)))
vbool32_t vmsne(vbool32_t, vbool32_t, vint16mf2_t, vint16mf2_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vmsne_vv)))
vbool64_t vmsne(vint16mf4_t, vint16mf4_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vmsne_vv_m)))
vbool64_t vmsne(vbool64_t, vbool64_t, vint16mf4_t, vint16mf4_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vmsne_vv)))
vbool32_t vmsne(vint32m1_t, vint32m1_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vmsne_vv_m)))
vbool32_t vmsne(vbool32_t, vbool32_t, vint32m1_t, vint32m1_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vmsne_vv)))
vbool16_t vmsne(vint32m2_t, vint32m2_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vmsne_vv_m)))
vbool16_t vmsne(vbool16_t, vbool16_t, vint32m2_t, vint32m2_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vmsne_vv)))
vbool8_t vmsne(vint32m4_t, vint32m4_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vmsne_vv_m)))
vbool8_t vmsne(vbool8_t, vbool8_t, vint32m4_t, vint32m4_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vmsne_vv)))
vbool4_t vmsne(vint32m8_t, vint32m8_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vmsne_vv_m)))
vbool4_t vmsne(vbool4_t, vbool4_t, vint32m8_t, vint32m8_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vmsne_vv)))
vbool64_t vmsne(vint32mf2_t, vint32mf2_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vmsne_vv_m)))
vbool64_t vmsne(vbool64_t, vbool64_t, vint32mf2_t, vint32mf2_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vmsne_vx)))
vbool8_t vmsne(vint8m1_t, int8_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vmsne_vx_m)))
vbool8_t vmsne(vbool8_t, vbool8_t, vint8m1_t, int8_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vmsne_vx)))
vbool4_t vmsne(vint8m2_t, int8_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vmsne_vx_m)))
vbool4_t vmsne(vbool4_t, vbool4_t, vint8m2_t, int8_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vmsne_vx)))
vbool2_t vmsne(vint8m4_t, int8_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vmsne_vx_m)))
vbool2_t vmsne(vbool2_t, vbool2_t, vint8m4_t, int8_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vmsne_vx)))
vbool1_t vmsne(vint8m8_t, int8_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vmsne_vx_m)))
vbool1_t vmsne(vbool1_t, vbool1_t, vint8m8_t, int8_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vmsne_vx)))
vbool16_t vmsne(vint8mf2_t, int8_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vmsne_vx_m)))
vbool16_t vmsne(vbool16_t, vbool16_t, vint8mf2_t, int8_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vmsne_vx)))
vbool32_t vmsne(vint8mf4_t, int8_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vmsne_vx_m)))
vbool32_t vmsne(vbool32_t, vbool32_t, vint8mf4_t, int8_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vmsne_vx)))
vbool64_t vmsne(vint8mf8_t, int8_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vmsne_vx_m)))
vbool64_t vmsne(vbool64_t, vbool64_t, vint8mf8_t, int8_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vmsne_vx)))
vbool16_t vmsne(vint16m1_t, int16_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vmsne_vx_m)))
vbool16_t vmsne(vbool16_t, vbool16_t, vint16m1_t, int16_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vmsne_vx)))
vbool8_t vmsne(vint16m2_t, int16_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vmsne_vx_m)))
vbool8_t vmsne(vbool8_t, vbool8_t, vint16m2_t, int16_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vmsne_vx)))
vbool4_t vmsne(vint16m4_t, int16_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vmsne_vx_m)))
vbool4_t vmsne(vbool4_t, vbool4_t, vint16m4_t, int16_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vmsne_vx)))
vbool2_t vmsne(vint16m8_t, int16_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vmsne_vx_m)))
vbool2_t vmsne(vbool2_t, vbool2_t, vint16m8_t, int16_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vmsne_vx)))
vbool32_t vmsne(vint16mf2_t, int16_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vmsne_vx_m)))
vbool32_t vmsne(vbool32_t, vbool32_t, vint16mf2_t, int16_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vmsne_vx)))
vbool64_t vmsne(vint16mf4_t, int16_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vmsne_vx_m)))
vbool64_t vmsne(vbool64_t, vbool64_t, vint16mf4_t, int16_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vmsne_vx)))
vbool32_t vmsne(vint32m1_t, int32_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vmsne_vx_m)))
vbool32_t vmsne(vbool32_t, vbool32_t, vint32m1_t, int32_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vmsne_vx)))
vbool16_t vmsne(vint32m2_t, int32_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vmsne_vx_m)))
vbool16_t vmsne(vbool16_t, vbool16_t, vint32m2_t, int32_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vmsne_vx)))
vbool8_t vmsne(vint32m4_t, int32_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vmsne_vx_m)))
vbool8_t vmsne(vbool8_t, vbool8_t, vint32m4_t, int32_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vmsne_vx)))
vbool4_t vmsne(vint32m8_t, int32_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vmsne_vx_m)))
vbool4_t vmsne(vbool4_t, vbool4_t, vint32m8_t, int32_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vmsne_vx)))
vbool64_t vmsne(vint32mf2_t, int32_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vmsne_vx_m)))
vbool64_t vmsne(vbool64_t, vbool64_t, vint32mf2_t, int32_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vmsne_vv)))
vbool8_t vmsne(vuint8m1_t, vuint8m1_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vmsne_vv_m)))
vbool8_t vmsne(vbool8_t, vbool8_t, vuint8m1_t, vuint8m1_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vmsne_vv)))
vbool4_t vmsne(vuint8m2_t, vuint8m2_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vmsne_vv_m)))
vbool4_t vmsne(vbool4_t, vbool4_t, vuint8m2_t, vuint8m2_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vmsne_vv)))
vbool2_t vmsne(vuint8m4_t, vuint8m4_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vmsne_vv_m)))
vbool2_t vmsne(vbool2_t, vbool2_t, vuint8m4_t, vuint8m4_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vmsne_vv)))
vbool1_t vmsne(vuint8m8_t, vuint8m8_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vmsne_vv_m)))
vbool1_t vmsne(vbool1_t, vbool1_t, vuint8m8_t, vuint8m8_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vmsne_vv)))
vbool16_t vmsne(vuint8mf2_t, vuint8mf2_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vmsne_vv_m)))
vbool16_t vmsne(vbool16_t, vbool16_t, vuint8mf2_t, vuint8mf2_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vmsne_vv)))
vbool32_t vmsne(vuint8mf4_t, vuint8mf4_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vmsne_vv_m)))
vbool32_t vmsne(vbool32_t, vbool32_t, vuint8mf4_t, vuint8mf4_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vmsne_vv)))
vbool64_t vmsne(vuint8mf8_t, vuint8mf8_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vmsne_vv_m)))
vbool64_t vmsne(vbool64_t, vbool64_t, vuint8mf8_t, vuint8mf8_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vmsne_vv)))
vbool16_t vmsne(vuint16m1_t, vuint16m1_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vmsne_vv_m)))
vbool16_t vmsne(vbool16_t, vbool16_t, vuint16m1_t, vuint16m1_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vmsne_vv)))
vbool8_t vmsne(vuint16m2_t, vuint16m2_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vmsne_vv_m)))
vbool8_t vmsne(vbool8_t, vbool8_t, vuint16m2_t, vuint16m2_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vmsne_vv)))
vbool4_t vmsne(vuint16m4_t, vuint16m4_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vmsne_vv_m)))
vbool4_t vmsne(vbool4_t, vbool4_t, vuint16m4_t, vuint16m4_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vmsne_vv)))
vbool2_t vmsne(vuint16m8_t, vuint16m8_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vmsne_vv_m)))
vbool2_t vmsne(vbool2_t, vbool2_t, vuint16m8_t, vuint16m8_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vmsne_vv)))
vbool32_t vmsne(vuint16mf2_t, vuint16mf2_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vmsne_vv_m)))
vbool32_t vmsne(vbool32_t, vbool32_t, vuint16mf2_t, vuint16mf2_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vmsne_vv)))
vbool64_t vmsne(vuint16mf4_t, vuint16mf4_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vmsne_vv_m)))
vbool64_t vmsne(vbool64_t, vbool64_t, vuint16mf4_t, vuint16mf4_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vmsne_vv)))
vbool32_t vmsne(vuint32m1_t, vuint32m1_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vmsne_vv_m)))
vbool32_t vmsne(vbool32_t, vbool32_t, vuint32m1_t, vuint32m1_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vmsne_vv)))
vbool16_t vmsne(vuint32m2_t, vuint32m2_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vmsne_vv_m)))
vbool16_t vmsne(vbool16_t, vbool16_t, vuint32m2_t, vuint32m2_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vmsne_vv)))
vbool8_t vmsne(vuint32m4_t, vuint32m4_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vmsne_vv_m)))
vbool8_t vmsne(vbool8_t, vbool8_t, vuint32m4_t, vuint32m4_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vmsne_vv)))
vbool4_t vmsne(vuint32m8_t, vuint32m8_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vmsne_vv_m)))
vbool4_t vmsne(vbool4_t, vbool4_t, vuint32m8_t, vuint32m8_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vmsne_vv)))
vbool64_t vmsne(vuint32mf2_t, vuint32mf2_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vmsne_vv_m)))
vbool64_t vmsne(vbool64_t, vbool64_t, vuint32mf2_t, vuint32mf2_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vmsne_vx)))
vbool8_t vmsne(vuint8m1_t, uint8_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vmsne_vx_m)))
vbool8_t vmsne(vbool8_t, vbool8_t, vuint8m1_t, uint8_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vmsne_vx)))
vbool4_t vmsne(vuint8m2_t, uint8_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vmsne_vx_m)))
vbool4_t vmsne(vbool4_t, vbool4_t, vuint8m2_t, uint8_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vmsne_vx)))
vbool2_t vmsne(vuint8m4_t, uint8_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vmsne_vx_m)))
vbool2_t vmsne(vbool2_t, vbool2_t, vuint8m4_t, uint8_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vmsne_vx)))
vbool1_t vmsne(vuint8m8_t, uint8_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vmsne_vx_m)))
vbool1_t vmsne(vbool1_t, vbool1_t, vuint8m8_t, uint8_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vmsne_vx)))
vbool16_t vmsne(vuint8mf2_t, uint8_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vmsne_vx_m)))
vbool16_t vmsne(vbool16_t, vbool16_t, vuint8mf2_t, uint8_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vmsne_vx)))
vbool32_t vmsne(vuint8mf4_t, uint8_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vmsne_vx_m)))
vbool32_t vmsne(vbool32_t, vbool32_t, vuint8mf4_t, uint8_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vmsne_vx)))
vbool64_t vmsne(vuint8mf8_t, uint8_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vmsne_vx_m)))
vbool64_t vmsne(vbool64_t, vbool64_t, vuint8mf8_t, uint8_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vmsne_vx)))
vbool16_t vmsne(vuint16m1_t, uint16_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vmsne_vx_m)))
vbool16_t vmsne(vbool16_t, vbool16_t, vuint16m1_t, uint16_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vmsne_vx)))
vbool8_t vmsne(vuint16m2_t, uint16_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vmsne_vx_m)))
vbool8_t vmsne(vbool8_t, vbool8_t, vuint16m2_t, uint16_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vmsne_vx)))
vbool4_t vmsne(vuint16m4_t, uint16_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vmsne_vx_m)))
vbool4_t vmsne(vbool4_t, vbool4_t, vuint16m4_t, uint16_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vmsne_vx)))
vbool2_t vmsne(vuint16m8_t, uint16_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vmsne_vx_m)))
vbool2_t vmsne(vbool2_t, vbool2_t, vuint16m8_t, uint16_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vmsne_vx)))
vbool32_t vmsne(vuint16mf2_t, uint16_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vmsne_vx_m)))
vbool32_t vmsne(vbool32_t, vbool32_t, vuint16mf2_t, uint16_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vmsne_vx)))
vbool64_t vmsne(vuint16mf4_t, uint16_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vmsne_vx_m)))
vbool64_t vmsne(vbool64_t, vbool64_t, vuint16mf4_t, uint16_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vmsne_vx)))
vbool32_t vmsne(vuint32m1_t, uint32_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vmsne_vx_m)))
vbool32_t vmsne(vbool32_t, vbool32_t, vuint32m1_t, uint32_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vmsne_vx)))
vbool16_t vmsne(vuint32m2_t, uint32_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vmsne_vx_m)))
vbool16_t vmsne(vbool16_t, vbool16_t, vuint32m2_t, uint32_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vmsne_vx)))
vbool8_t vmsne(vuint32m4_t, uint32_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vmsne_vx_m)))
vbool8_t vmsne(vbool8_t, vbool8_t, vuint32m4_t, uint32_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vmsne_vx)))
vbool4_t vmsne(vuint32m8_t, uint32_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vmsne_vx_m)))
vbool4_t vmsne(vbool4_t, vbool4_t, vuint32m8_t, uint32_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vmsne_vx)))
vbool64_t vmsne(vuint32mf2_t, uint32_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vmsne_vx_m)))
vbool64_t vmsne(vbool64_t, vbool64_t, vuint32mf2_t, uint32_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vmsltu_vv)))
vbool8_t vmsltu(vuint8m1_t, vuint8m1_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vmsltu_vv_m)))
vbool8_t vmsltu(vbool8_t, vbool8_t, vuint8m1_t, vuint8m1_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vmsltu_vv)))
vbool4_t vmsltu(vuint8m2_t, vuint8m2_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vmsltu_vv_m)))
vbool4_t vmsltu(vbool4_t, vbool4_t, vuint8m2_t, vuint8m2_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vmsltu_vv)))
vbool2_t vmsltu(vuint8m4_t, vuint8m4_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vmsltu_vv_m)))
vbool2_t vmsltu(vbool2_t, vbool2_t, vuint8m4_t, vuint8m4_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vmsltu_vv)))
vbool1_t vmsltu(vuint8m8_t, vuint8m8_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vmsltu_vv_m)))
vbool1_t vmsltu(vbool1_t, vbool1_t, vuint8m8_t, vuint8m8_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vmsltu_vv)))
vbool16_t vmsltu(vuint8mf2_t, vuint8mf2_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vmsltu_vv_m)))
vbool16_t vmsltu(vbool16_t, vbool16_t, vuint8mf2_t, vuint8mf2_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vmsltu_vv)))
vbool32_t vmsltu(vuint8mf4_t, vuint8mf4_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vmsltu_vv_m)))
vbool32_t vmsltu(vbool32_t, vbool32_t, vuint8mf4_t, vuint8mf4_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vmsltu_vv)))
vbool64_t vmsltu(vuint8mf8_t, vuint8mf8_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vmsltu_vv_m)))
vbool64_t vmsltu(vbool64_t, vbool64_t, vuint8mf8_t, vuint8mf8_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vmsltu_vv)))
vbool16_t vmsltu(vuint16m1_t, vuint16m1_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vmsltu_vv_m)))
vbool16_t vmsltu(vbool16_t, vbool16_t, vuint16m1_t, vuint16m1_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vmsltu_vv)))
vbool8_t vmsltu(vuint16m2_t, vuint16m2_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vmsltu_vv_m)))
vbool8_t vmsltu(vbool8_t, vbool8_t, vuint16m2_t, vuint16m2_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vmsltu_vv)))
vbool4_t vmsltu(vuint16m4_t, vuint16m4_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vmsltu_vv_m)))
vbool4_t vmsltu(vbool4_t, vbool4_t, vuint16m4_t, vuint16m4_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vmsltu_vv)))
vbool2_t vmsltu(vuint16m8_t, vuint16m8_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vmsltu_vv_m)))
vbool2_t vmsltu(vbool2_t, vbool2_t, vuint16m8_t, vuint16m8_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vmsltu_vv)))
vbool32_t vmsltu(vuint16mf2_t, vuint16mf2_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vmsltu_vv_m)))
vbool32_t vmsltu(vbool32_t, vbool32_t, vuint16mf2_t, vuint16mf2_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vmsltu_vv)))
vbool64_t vmsltu(vuint16mf4_t, vuint16mf4_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vmsltu_vv_m)))
vbool64_t vmsltu(vbool64_t, vbool64_t, vuint16mf4_t, vuint16mf4_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vmsltu_vv)))
vbool32_t vmsltu(vuint32m1_t, vuint32m1_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vmsltu_vv_m)))
vbool32_t vmsltu(vbool32_t, vbool32_t, vuint32m1_t, vuint32m1_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vmsltu_vv)))
vbool16_t vmsltu(vuint32m2_t, vuint32m2_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vmsltu_vv_m)))
vbool16_t vmsltu(vbool16_t, vbool16_t, vuint32m2_t, vuint32m2_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vmsltu_vv)))
vbool8_t vmsltu(vuint32m4_t, vuint32m4_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vmsltu_vv_m)))
vbool8_t vmsltu(vbool8_t, vbool8_t, vuint32m4_t, vuint32m4_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vmsltu_vv)))
vbool4_t vmsltu(vuint32m8_t, vuint32m8_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vmsltu_vv_m)))
vbool4_t vmsltu(vbool4_t, vbool4_t, vuint32m8_t, vuint32m8_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vmsltu_vv)))
vbool64_t vmsltu(vuint32mf2_t, vuint32mf2_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vmsltu_vv_m)))
vbool64_t vmsltu(vbool64_t, vbool64_t, vuint32mf2_t, vuint32mf2_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vmsltu_vx)))
vbool8_t vmsltu(vuint8m1_t, uint8_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vmsltu_vx_m)))
vbool8_t vmsltu(vbool8_t, vbool8_t, vuint8m1_t, uint8_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vmsltu_vx)))
vbool4_t vmsltu(vuint8m2_t, uint8_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vmsltu_vx_m)))
vbool4_t vmsltu(vbool4_t, vbool4_t, vuint8m2_t, uint8_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vmsltu_vx)))
vbool2_t vmsltu(vuint8m4_t, uint8_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vmsltu_vx_m)))
vbool2_t vmsltu(vbool2_t, vbool2_t, vuint8m4_t, uint8_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vmsltu_vx)))
vbool1_t vmsltu(vuint8m8_t, uint8_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vmsltu_vx_m)))
vbool1_t vmsltu(vbool1_t, vbool1_t, vuint8m8_t, uint8_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vmsltu_vx)))
vbool16_t vmsltu(vuint8mf2_t, uint8_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vmsltu_vx_m)))
vbool16_t vmsltu(vbool16_t, vbool16_t, vuint8mf2_t, uint8_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vmsltu_vx)))
vbool32_t vmsltu(vuint8mf4_t, uint8_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vmsltu_vx_m)))
vbool32_t vmsltu(vbool32_t, vbool32_t, vuint8mf4_t, uint8_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vmsltu_vx)))
vbool64_t vmsltu(vuint8mf8_t, uint8_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vmsltu_vx_m)))
vbool64_t vmsltu(vbool64_t, vbool64_t, vuint8mf8_t, uint8_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vmsltu_vx)))
vbool16_t vmsltu(vuint16m1_t, uint16_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vmsltu_vx_m)))
vbool16_t vmsltu(vbool16_t, vbool16_t, vuint16m1_t, uint16_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vmsltu_vx)))
vbool8_t vmsltu(vuint16m2_t, uint16_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vmsltu_vx_m)))
vbool8_t vmsltu(vbool8_t, vbool8_t, vuint16m2_t, uint16_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vmsltu_vx)))
vbool4_t vmsltu(vuint16m4_t, uint16_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vmsltu_vx_m)))
vbool4_t vmsltu(vbool4_t, vbool4_t, vuint16m4_t, uint16_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vmsltu_vx)))
vbool2_t vmsltu(vuint16m8_t, uint16_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vmsltu_vx_m)))
vbool2_t vmsltu(vbool2_t, vbool2_t, vuint16m8_t, uint16_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vmsltu_vx)))
vbool32_t vmsltu(vuint16mf2_t, uint16_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vmsltu_vx_m)))
vbool32_t vmsltu(vbool32_t, vbool32_t, vuint16mf2_t, uint16_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vmsltu_vx)))
vbool64_t vmsltu(vuint16mf4_t, uint16_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vmsltu_vx_m)))
vbool64_t vmsltu(vbool64_t, vbool64_t, vuint16mf4_t, uint16_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vmsltu_vx)))
vbool32_t vmsltu(vuint32m1_t, uint32_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vmsltu_vx_m)))
vbool32_t vmsltu(vbool32_t, vbool32_t, vuint32m1_t, uint32_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vmsltu_vx)))
vbool16_t vmsltu(vuint32m2_t, uint32_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vmsltu_vx_m)))
vbool16_t vmsltu(vbool16_t, vbool16_t, vuint32m2_t, uint32_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vmsltu_vx)))
vbool8_t vmsltu(vuint32m4_t, uint32_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vmsltu_vx_m)))
vbool8_t vmsltu(vbool8_t, vbool8_t, vuint32m4_t, uint32_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vmsltu_vx)))
vbool4_t vmsltu(vuint32m8_t, uint32_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vmsltu_vx_m)))
vbool4_t vmsltu(vbool4_t, vbool4_t, vuint32m8_t, uint32_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vmsltu_vx)))
vbool64_t vmsltu(vuint32mf2_t, uint32_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vmsltu_vx_m)))
vbool64_t vmsltu(vbool64_t, vbool64_t, vuint32mf2_t, uint32_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vmslt_vv)))
vbool8_t vmslt(vint8m1_t, vint8m1_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vmslt_vv_m)))
vbool8_t vmslt(vbool8_t, vbool8_t, vint8m1_t, vint8m1_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vmslt_vv)))
vbool4_t vmslt(vint8m2_t, vint8m2_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vmslt_vv_m)))
vbool4_t vmslt(vbool4_t, vbool4_t, vint8m2_t, vint8m2_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vmslt_vv)))
vbool2_t vmslt(vint8m4_t, vint8m4_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vmslt_vv_m)))
vbool2_t vmslt(vbool2_t, vbool2_t, vint8m4_t, vint8m4_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vmslt_vv)))
vbool1_t vmslt(vint8m8_t, vint8m8_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vmslt_vv_m)))
vbool1_t vmslt(vbool1_t, vbool1_t, vint8m8_t, vint8m8_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vmslt_vv)))
vbool16_t vmslt(vint8mf2_t, vint8mf2_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vmslt_vv_m)))
vbool16_t vmslt(vbool16_t, vbool16_t, vint8mf2_t, vint8mf2_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vmslt_vv)))
vbool32_t vmslt(vint8mf4_t, vint8mf4_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vmslt_vv_m)))
vbool32_t vmslt(vbool32_t, vbool32_t, vint8mf4_t, vint8mf4_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vmslt_vv)))
vbool64_t vmslt(vint8mf8_t, vint8mf8_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vmslt_vv_m)))
vbool64_t vmslt(vbool64_t, vbool64_t, vint8mf8_t, vint8mf8_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vmslt_vv)))
vbool16_t vmslt(vint16m1_t, vint16m1_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vmslt_vv_m)))
vbool16_t vmslt(vbool16_t, vbool16_t, vint16m1_t, vint16m1_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vmslt_vv)))
vbool8_t vmslt(vint16m2_t, vint16m2_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vmslt_vv_m)))
vbool8_t vmslt(vbool8_t, vbool8_t, vint16m2_t, vint16m2_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vmslt_vv)))
vbool4_t vmslt(vint16m4_t, vint16m4_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vmslt_vv_m)))
vbool4_t vmslt(vbool4_t, vbool4_t, vint16m4_t, vint16m4_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vmslt_vv)))
vbool2_t vmslt(vint16m8_t, vint16m8_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vmslt_vv_m)))
vbool2_t vmslt(vbool2_t, vbool2_t, vint16m8_t, vint16m8_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vmslt_vv)))
vbool32_t vmslt(vint16mf2_t, vint16mf2_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vmslt_vv_m)))
vbool32_t vmslt(vbool32_t, vbool32_t, vint16mf2_t, vint16mf2_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vmslt_vv)))
vbool64_t vmslt(vint16mf4_t, vint16mf4_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vmslt_vv_m)))
vbool64_t vmslt(vbool64_t, vbool64_t, vint16mf4_t, vint16mf4_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vmslt_vv)))
vbool32_t vmslt(vint32m1_t, vint32m1_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vmslt_vv_m)))
vbool32_t vmslt(vbool32_t, vbool32_t, vint32m1_t, vint32m1_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vmslt_vv)))
vbool16_t vmslt(vint32m2_t, vint32m2_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vmslt_vv_m)))
vbool16_t vmslt(vbool16_t, vbool16_t, vint32m2_t, vint32m2_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vmslt_vv)))
vbool8_t vmslt(vint32m4_t, vint32m4_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vmslt_vv_m)))
vbool8_t vmslt(vbool8_t, vbool8_t, vint32m4_t, vint32m4_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vmslt_vv)))
vbool4_t vmslt(vint32m8_t, vint32m8_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vmslt_vv_m)))
vbool4_t vmslt(vbool4_t, vbool4_t, vint32m8_t, vint32m8_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vmslt_vv)))
vbool64_t vmslt(vint32mf2_t, vint32mf2_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vmslt_vv_m)))
vbool64_t vmslt(vbool64_t, vbool64_t, vint32mf2_t, vint32mf2_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vmslt_vx)))
vbool8_t vmslt(vint8m1_t, int8_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vmslt_vx_m)))
vbool8_t vmslt(vbool8_t, vbool8_t, vint8m1_t, int8_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vmslt_vx)))
vbool4_t vmslt(vint8m2_t, int8_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vmslt_vx_m)))
vbool4_t vmslt(vbool4_t, vbool4_t, vint8m2_t, int8_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vmslt_vx)))
vbool2_t vmslt(vint8m4_t, int8_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vmslt_vx_m)))
vbool2_t vmslt(vbool2_t, vbool2_t, vint8m4_t, int8_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vmslt_vx)))
vbool1_t vmslt(vint8m8_t, int8_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vmslt_vx_m)))
vbool1_t vmslt(vbool1_t, vbool1_t, vint8m8_t, int8_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vmslt_vx)))
vbool16_t vmslt(vint8mf2_t, int8_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vmslt_vx_m)))
vbool16_t vmslt(vbool16_t, vbool16_t, vint8mf2_t, int8_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vmslt_vx)))
vbool32_t vmslt(vint8mf4_t, int8_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vmslt_vx_m)))
vbool32_t vmslt(vbool32_t, vbool32_t, vint8mf4_t, int8_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vmslt_vx)))
vbool64_t vmslt(vint8mf8_t, int8_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vmslt_vx_m)))
vbool64_t vmslt(vbool64_t, vbool64_t, vint8mf8_t, int8_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vmslt_vx)))
vbool16_t vmslt(vint16m1_t, int16_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vmslt_vx_m)))
vbool16_t vmslt(vbool16_t, vbool16_t, vint16m1_t, int16_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vmslt_vx)))
vbool8_t vmslt(vint16m2_t, int16_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vmslt_vx_m)))
vbool8_t vmslt(vbool8_t, vbool8_t, vint16m2_t, int16_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vmslt_vx)))
vbool4_t vmslt(vint16m4_t, int16_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vmslt_vx_m)))
vbool4_t vmslt(vbool4_t, vbool4_t, vint16m4_t, int16_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vmslt_vx)))
vbool2_t vmslt(vint16m8_t, int16_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vmslt_vx_m)))
vbool2_t vmslt(vbool2_t, vbool2_t, vint16m8_t, int16_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vmslt_vx)))
vbool32_t vmslt(vint16mf2_t, int16_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vmslt_vx_m)))
vbool32_t vmslt(vbool32_t, vbool32_t, vint16mf2_t, int16_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vmslt_vx)))
vbool64_t vmslt(vint16mf4_t, int16_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vmslt_vx_m)))
vbool64_t vmslt(vbool64_t, vbool64_t, vint16mf4_t, int16_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vmslt_vx)))
vbool32_t vmslt(vint32m1_t, int32_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vmslt_vx_m)))
vbool32_t vmslt(vbool32_t, vbool32_t, vint32m1_t, int32_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vmslt_vx)))
vbool16_t vmslt(vint32m2_t, int32_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vmslt_vx_m)))
vbool16_t vmslt(vbool16_t, vbool16_t, vint32m2_t, int32_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vmslt_vx)))
vbool8_t vmslt(vint32m4_t, int32_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vmslt_vx_m)))
vbool8_t vmslt(vbool8_t, vbool8_t, vint32m4_t, int32_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vmslt_vx)))
vbool4_t vmslt(vint32m8_t, int32_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vmslt_vx_m)))
vbool4_t vmslt(vbool4_t, vbool4_t, vint32m8_t, int32_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vmslt_vx)))
vbool64_t vmslt(vint32mf2_t, int32_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vmslt_vx_m)))
vbool64_t vmslt(vbool64_t, vbool64_t, vint32mf2_t, int32_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vmsleu_vv)))
vbool8_t vmsleu(vuint8m1_t, vuint8m1_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vmsleu_vv_m)))
vbool8_t vmsleu(vbool8_t, vbool8_t, vuint8m1_t, vuint8m1_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vmsleu_vv)))
vbool4_t vmsleu(vuint8m2_t, vuint8m2_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vmsleu_vv_m)))
vbool4_t vmsleu(vbool4_t, vbool4_t, vuint8m2_t, vuint8m2_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vmsleu_vv)))
vbool2_t vmsleu(vuint8m4_t, vuint8m4_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vmsleu_vv_m)))
vbool2_t vmsleu(vbool2_t, vbool2_t, vuint8m4_t, vuint8m4_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vmsleu_vv)))
vbool1_t vmsleu(vuint8m8_t, vuint8m8_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vmsleu_vv_m)))
vbool1_t vmsleu(vbool1_t, vbool1_t, vuint8m8_t, vuint8m8_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vmsleu_vv)))
vbool16_t vmsleu(vuint8mf2_t, vuint8mf2_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vmsleu_vv_m)))
vbool16_t vmsleu(vbool16_t, vbool16_t, vuint8mf2_t, vuint8mf2_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vmsleu_vv)))
vbool32_t vmsleu(vuint8mf4_t, vuint8mf4_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vmsleu_vv_m)))
vbool32_t vmsleu(vbool32_t, vbool32_t, vuint8mf4_t, vuint8mf4_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vmsleu_vv)))
vbool64_t vmsleu(vuint8mf8_t, vuint8mf8_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vmsleu_vv_m)))
vbool64_t vmsleu(vbool64_t, vbool64_t, vuint8mf8_t, vuint8mf8_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vmsleu_vv)))
vbool16_t vmsleu(vuint16m1_t, vuint16m1_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vmsleu_vv_m)))
vbool16_t vmsleu(vbool16_t, vbool16_t, vuint16m1_t, vuint16m1_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vmsleu_vv)))
vbool8_t vmsleu(vuint16m2_t, vuint16m2_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vmsleu_vv_m)))
vbool8_t vmsleu(vbool8_t, vbool8_t, vuint16m2_t, vuint16m2_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vmsleu_vv)))
vbool4_t vmsleu(vuint16m4_t, vuint16m4_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vmsleu_vv_m)))
vbool4_t vmsleu(vbool4_t, vbool4_t, vuint16m4_t, vuint16m4_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vmsleu_vv)))
vbool2_t vmsleu(vuint16m8_t, vuint16m8_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vmsleu_vv_m)))
vbool2_t vmsleu(vbool2_t, vbool2_t, vuint16m8_t, vuint16m8_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vmsleu_vv)))
vbool32_t vmsleu(vuint16mf2_t, vuint16mf2_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vmsleu_vv_m)))
vbool32_t vmsleu(vbool32_t, vbool32_t, vuint16mf2_t, vuint16mf2_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vmsleu_vv)))
vbool64_t vmsleu(vuint16mf4_t, vuint16mf4_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vmsleu_vv_m)))
vbool64_t vmsleu(vbool64_t, vbool64_t, vuint16mf4_t, vuint16mf4_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vmsleu_vv)))
vbool32_t vmsleu(vuint32m1_t, vuint32m1_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vmsleu_vv_m)))
vbool32_t vmsleu(vbool32_t, vbool32_t, vuint32m1_t, vuint32m1_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vmsleu_vv)))
vbool16_t vmsleu(vuint32m2_t, vuint32m2_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vmsleu_vv_m)))
vbool16_t vmsleu(vbool16_t, vbool16_t, vuint32m2_t, vuint32m2_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vmsleu_vv)))
vbool8_t vmsleu(vuint32m4_t, vuint32m4_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vmsleu_vv_m)))
vbool8_t vmsleu(vbool8_t, vbool8_t, vuint32m4_t, vuint32m4_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vmsleu_vv)))
vbool4_t vmsleu(vuint32m8_t, vuint32m8_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vmsleu_vv_m)))
vbool4_t vmsleu(vbool4_t, vbool4_t, vuint32m8_t, vuint32m8_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vmsleu_vv)))
vbool64_t vmsleu(vuint32mf2_t, vuint32mf2_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vmsleu_vv_m)))
vbool64_t vmsleu(vbool64_t, vbool64_t, vuint32mf2_t, vuint32mf2_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vmsleu_vx)))
vbool8_t vmsleu(vuint8m1_t, uint8_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vmsleu_vx_m)))
vbool8_t vmsleu(vbool8_t, vbool8_t, vuint8m1_t, uint8_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vmsleu_vx)))
vbool4_t vmsleu(vuint8m2_t, uint8_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vmsleu_vx_m)))
vbool4_t vmsleu(vbool4_t, vbool4_t, vuint8m2_t, uint8_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vmsleu_vx)))
vbool2_t vmsleu(vuint8m4_t, uint8_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vmsleu_vx_m)))
vbool2_t vmsleu(vbool2_t, vbool2_t, vuint8m4_t, uint8_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vmsleu_vx)))
vbool1_t vmsleu(vuint8m8_t, uint8_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vmsleu_vx_m)))
vbool1_t vmsleu(vbool1_t, vbool1_t, vuint8m8_t, uint8_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vmsleu_vx)))
vbool16_t vmsleu(vuint8mf2_t, uint8_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vmsleu_vx_m)))
vbool16_t vmsleu(vbool16_t, vbool16_t, vuint8mf2_t, uint8_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vmsleu_vx)))
vbool32_t vmsleu(vuint8mf4_t, uint8_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vmsleu_vx_m)))
vbool32_t vmsleu(vbool32_t, vbool32_t, vuint8mf4_t, uint8_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vmsleu_vx)))
vbool64_t vmsleu(vuint8mf8_t, uint8_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vmsleu_vx_m)))
vbool64_t vmsleu(vbool64_t, vbool64_t, vuint8mf8_t, uint8_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vmsleu_vx)))
vbool16_t vmsleu(vuint16m1_t, uint16_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vmsleu_vx_m)))
vbool16_t vmsleu(vbool16_t, vbool16_t, vuint16m1_t, uint16_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vmsleu_vx)))
vbool8_t vmsleu(vuint16m2_t, uint16_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vmsleu_vx_m)))
vbool8_t vmsleu(vbool8_t, vbool8_t, vuint16m2_t, uint16_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vmsleu_vx)))
vbool4_t vmsleu(vuint16m4_t, uint16_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vmsleu_vx_m)))
vbool4_t vmsleu(vbool4_t, vbool4_t, vuint16m4_t, uint16_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vmsleu_vx)))
vbool2_t vmsleu(vuint16m8_t, uint16_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vmsleu_vx_m)))
vbool2_t vmsleu(vbool2_t, vbool2_t, vuint16m8_t, uint16_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vmsleu_vx)))
vbool32_t vmsleu(vuint16mf2_t, uint16_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vmsleu_vx_m)))
vbool32_t vmsleu(vbool32_t, vbool32_t, vuint16mf2_t, uint16_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vmsleu_vx)))
vbool64_t vmsleu(vuint16mf4_t, uint16_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vmsleu_vx_m)))
vbool64_t vmsleu(vbool64_t, vbool64_t, vuint16mf4_t, uint16_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vmsleu_vx)))
vbool32_t vmsleu(vuint32m1_t, uint32_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vmsleu_vx_m)))
vbool32_t vmsleu(vbool32_t, vbool32_t, vuint32m1_t, uint32_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vmsleu_vx)))
vbool16_t vmsleu(vuint32m2_t, uint32_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vmsleu_vx_m)))
vbool16_t vmsleu(vbool16_t, vbool16_t, vuint32m2_t, uint32_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vmsleu_vx)))
vbool8_t vmsleu(vuint32m4_t, uint32_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vmsleu_vx_m)))
vbool8_t vmsleu(vbool8_t, vbool8_t, vuint32m4_t, uint32_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vmsleu_vx)))
vbool4_t vmsleu(vuint32m8_t, uint32_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vmsleu_vx_m)))
vbool4_t vmsleu(vbool4_t, vbool4_t, vuint32m8_t, uint32_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vmsleu_vx)))
vbool64_t vmsleu(vuint32mf2_t, uint32_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vmsleu_vx_m)))
vbool64_t vmsleu(vbool64_t, vbool64_t, vuint32mf2_t, uint32_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vmsle_vv)))
vbool8_t vmsle(vint8m1_t, vint8m1_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vmsle_vv_m)))
vbool8_t vmsle(vbool8_t, vbool8_t, vint8m1_t, vint8m1_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vmsle_vv)))
vbool4_t vmsle(vint8m2_t, vint8m2_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vmsle_vv_m)))
vbool4_t vmsle(vbool4_t, vbool4_t, vint8m2_t, vint8m2_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vmsle_vv)))
vbool2_t vmsle(vint8m4_t, vint8m4_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vmsle_vv_m)))
vbool2_t vmsle(vbool2_t, vbool2_t, vint8m4_t, vint8m4_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vmsle_vv)))
vbool1_t vmsle(vint8m8_t, vint8m8_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vmsle_vv_m)))
vbool1_t vmsle(vbool1_t, vbool1_t, vint8m8_t, vint8m8_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vmsle_vv)))
vbool16_t vmsle(vint8mf2_t, vint8mf2_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vmsle_vv_m)))
vbool16_t vmsle(vbool16_t, vbool16_t, vint8mf2_t, vint8mf2_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vmsle_vv)))
vbool32_t vmsle(vint8mf4_t, vint8mf4_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vmsle_vv_m)))
vbool32_t vmsle(vbool32_t, vbool32_t, vint8mf4_t, vint8mf4_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vmsle_vv)))
vbool64_t vmsle(vint8mf8_t, vint8mf8_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vmsle_vv_m)))
vbool64_t vmsle(vbool64_t, vbool64_t, vint8mf8_t, vint8mf8_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vmsle_vv)))
vbool16_t vmsle(vint16m1_t, vint16m1_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vmsle_vv_m)))
vbool16_t vmsle(vbool16_t, vbool16_t, vint16m1_t, vint16m1_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vmsle_vv)))
vbool8_t vmsle(vint16m2_t, vint16m2_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vmsle_vv_m)))
vbool8_t vmsle(vbool8_t, vbool8_t, vint16m2_t, vint16m2_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vmsle_vv)))
vbool4_t vmsle(vint16m4_t, vint16m4_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vmsle_vv_m)))
vbool4_t vmsle(vbool4_t, vbool4_t, vint16m4_t, vint16m4_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vmsle_vv)))
vbool2_t vmsle(vint16m8_t, vint16m8_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vmsle_vv_m)))
vbool2_t vmsle(vbool2_t, vbool2_t, vint16m8_t, vint16m8_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vmsle_vv)))
vbool32_t vmsle(vint16mf2_t, vint16mf2_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vmsle_vv_m)))
vbool32_t vmsle(vbool32_t, vbool32_t, vint16mf2_t, vint16mf2_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vmsle_vv)))
vbool64_t vmsle(vint16mf4_t, vint16mf4_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vmsle_vv_m)))
vbool64_t vmsle(vbool64_t, vbool64_t, vint16mf4_t, vint16mf4_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vmsle_vv)))
vbool32_t vmsle(vint32m1_t, vint32m1_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vmsle_vv_m)))
vbool32_t vmsle(vbool32_t, vbool32_t, vint32m1_t, vint32m1_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vmsle_vv)))
vbool16_t vmsle(vint32m2_t, vint32m2_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vmsle_vv_m)))
vbool16_t vmsle(vbool16_t, vbool16_t, vint32m2_t, vint32m2_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vmsle_vv)))
vbool8_t vmsle(vint32m4_t, vint32m4_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vmsle_vv_m)))
vbool8_t vmsle(vbool8_t, vbool8_t, vint32m4_t, vint32m4_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vmsle_vv)))
vbool4_t vmsle(vint32m8_t, vint32m8_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vmsle_vv_m)))
vbool4_t vmsle(vbool4_t, vbool4_t, vint32m8_t, vint32m8_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vmsle_vv)))
vbool64_t vmsle(vint32mf2_t, vint32mf2_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vmsle_vv_m)))
vbool64_t vmsle(vbool64_t, vbool64_t, vint32mf2_t, vint32mf2_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vmsle_vx)))
vbool8_t vmsle(vint8m1_t, int8_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vmsle_vx_m)))
vbool8_t vmsle(vbool8_t, vbool8_t, vint8m1_t, int8_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vmsle_vx)))
vbool4_t vmsle(vint8m2_t, int8_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vmsle_vx_m)))
vbool4_t vmsle(vbool4_t, vbool4_t, vint8m2_t, int8_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vmsle_vx)))
vbool2_t vmsle(vint8m4_t, int8_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vmsle_vx_m)))
vbool2_t vmsle(vbool2_t, vbool2_t, vint8m4_t, int8_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vmsle_vx)))
vbool1_t vmsle(vint8m8_t, int8_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vmsle_vx_m)))
vbool1_t vmsle(vbool1_t, vbool1_t, vint8m8_t, int8_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vmsle_vx)))
vbool16_t vmsle(vint8mf2_t, int8_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vmsle_vx_m)))
vbool16_t vmsle(vbool16_t, vbool16_t, vint8mf2_t, int8_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vmsle_vx)))
vbool32_t vmsle(vint8mf4_t, int8_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vmsle_vx_m)))
vbool32_t vmsle(vbool32_t, vbool32_t, vint8mf4_t, int8_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vmsle_vx)))
vbool64_t vmsle(vint8mf8_t, int8_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vmsle_vx_m)))
vbool64_t vmsle(vbool64_t, vbool64_t, vint8mf8_t, int8_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vmsle_vx)))
vbool16_t vmsle(vint16m1_t, int16_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vmsle_vx_m)))
vbool16_t vmsle(vbool16_t, vbool16_t, vint16m1_t, int16_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vmsle_vx)))
vbool8_t vmsle(vint16m2_t, int16_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vmsle_vx_m)))
vbool8_t vmsle(vbool8_t, vbool8_t, vint16m2_t, int16_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vmsle_vx)))
vbool4_t vmsle(vint16m4_t, int16_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vmsle_vx_m)))
vbool4_t vmsle(vbool4_t, vbool4_t, vint16m4_t, int16_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vmsle_vx)))
vbool2_t vmsle(vint16m8_t, int16_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vmsle_vx_m)))
vbool2_t vmsle(vbool2_t, vbool2_t, vint16m8_t, int16_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vmsle_vx)))
vbool32_t vmsle(vint16mf2_t, int16_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vmsle_vx_m)))
vbool32_t vmsle(vbool32_t, vbool32_t, vint16mf2_t, int16_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vmsle_vx)))
vbool64_t vmsle(vint16mf4_t, int16_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vmsle_vx_m)))
vbool64_t vmsle(vbool64_t, vbool64_t, vint16mf4_t, int16_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vmsle_vx)))
vbool32_t vmsle(vint32m1_t, int32_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vmsle_vx_m)))
vbool32_t vmsle(vbool32_t, vbool32_t, vint32m1_t, int32_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vmsle_vx)))
vbool16_t vmsle(vint32m2_t, int32_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vmsle_vx_m)))
vbool16_t vmsle(vbool16_t, vbool16_t, vint32m2_t, int32_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vmsle_vx)))
vbool8_t vmsle(vint32m4_t, int32_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vmsle_vx_m)))
vbool8_t vmsle(vbool8_t, vbool8_t, vint32m4_t, int32_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vmsle_vx)))
vbool4_t vmsle(vint32m8_t, int32_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vmsle_vx_m)))
vbool4_t vmsle(vbool4_t, vbool4_t, vint32m8_t, int32_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vmsle_vx)))
vbool64_t vmsle(vint32mf2_t, int32_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vmsle_vx_m)))
vbool64_t vmsle(vbool64_t, vbool64_t, vint32mf2_t, int32_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vmsgtu_vv)))
vbool8_t vmsgtu(vuint8m1_t, vuint8m1_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vmsgtu_vv_m)))
vbool8_t vmsgtu(vbool8_t, vbool8_t, vuint8m1_t, vuint8m1_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vmsgtu_vv)))
vbool4_t vmsgtu(vuint8m2_t, vuint8m2_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vmsgtu_vv_m)))
vbool4_t vmsgtu(vbool4_t, vbool4_t, vuint8m2_t, vuint8m2_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vmsgtu_vv)))
vbool2_t vmsgtu(vuint8m4_t, vuint8m4_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vmsgtu_vv_m)))
vbool2_t vmsgtu(vbool2_t, vbool2_t, vuint8m4_t, vuint8m4_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vmsgtu_vv)))
vbool1_t vmsgtu(vuint8m8_t, vuint8m8_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vmsgtu_vv_m)))
vbool1_t vmsgtu(vbool1_t, vbool1_t, vuint8m8_t, vuint8m8_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vmsgtu_vv)))
vbool16_t vmsgtu(vuint8mf2_t, vuint8mf2_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vmsgtu_vv_m)))
vbool16_t vmsgtu(vbool16_t, vbool16_t, vuint8mf2_t, vuint8mf2_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vmsgtu_vv)))
vbool32_t vmsgtu(vuint8mf4_t, vuint8mf4_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vmsgtu_vv_m)))
vbool32_t vmsgtu(vbool32_t, vbool32_t, vuint8mf4_t, vuint8mf4_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vmsgtu_vv)))
vbool64_t vmsgtu(vuint8mf8_t, vuint8mf8_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vmsgtu_vv_m)))
vbool64_t vmsgtu(vbool64_t, vbool64_t, vuint8mf8_t, vuint8mf8_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vmsgtu_vv)))
vbool16_t vmsgtu(vuint16m1_t, vuint16m1_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vmsgtu_vv_m)))
vbool16_t vmsgtu(vbool16_t, vbool16_t, vuint16m1_t, vuint16m1_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vmsgtu_vv)))
vbool8_t vmsgtu(vuint16m2_t, vuint16m2_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vmsgtu_vv_m)))
vbool8_t vmsgtu(vbool8_t, vbool8_t, vuint16m2_t, vuint16m2_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vmsgtu_vv)))
vbool4_t vmsgtu(vuint16m4_t, vuint16m4_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vmsgtu_vv_m)))
vbool4_t vmsgtu(vbool4_t, vbool4_t, vuint16m4_t, vuint16m4_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vmsgtu_vv)))
vbool2_t vmsgtu(vuint16m8_t, vuint16m8_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vmsgtu_vv_m)))
vbool2_t vmsgtu(vbool2_t, vbool2_t, vuint16m8_t, vuint16m8_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vmsgtu_vv)))
vbool32_t vmsgtu(vuint16mf2_t, vuint16mf2_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vmsgtu_vv_m)))
vbool32_t vmsgtu(vbool32_t, vbool32_t, vuint16mf2_t, vuint16mf2_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vmsgtu_vv)))
vbool64_t vmsgtu(vuint16mf4_t, vuint16mf4_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vmsgtu_vv_m)))
vbool64_t vmsgtu(vbool64_t, vbool64_t, vuint16mf4_t, vuint16mf4_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vmsgtu_vv)))
vbool32_t vmsgtu(vuint32m1_t, vuint32m1_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vmsgtu_vv_m)))
vbool32_t vmsgtu(vbool32_t, vbool32_t, vuint32m1_t, vuint32m1_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vmsgtu_vv)))
vbool16_t vmsgtu(vuint32m2_t, vuint32m2_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vmsgtu_vv_m)))
vbool16_t vmsgtu(vbool16_t, vbool16_t, vuint32m2_t, vuint32m2_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vmsgtu_vv)))
vbool8_t vmsgtu(vuint32m4_t, vuint32m4_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vmsgtu_vv_m)))
vbool8_t vmsgtu(vbool8_t, vbool8_t, vuint32m4_t, vuint32m4_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vmsgtu_vv)))
vbool4_t vmsgtu(vuint32m8_t, vuint32m8_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vmsgtu_vv_m)))
vbool4_t vmsgtu(vbool4_t, vbool4_t, vuint32m8_t, vuint32m8_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vmsgtu_vv)))
vbool64_t vmsgtu(vuint32mf2_t, vuint32mf2_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vmsgtu_vv_m)))
vbool64_t vmsgtu(vbool64_t, vbool64_t, vuint32mf2_t, vuint32mf2_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vmsgtu_vx)))
vbool8_t vmsgtu(vuint8m1_t, uint8_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vmsgtu_vx_m)))
vbool8_t vmsgtu(vbool8_t, vbool8_t, vuint8m1_t, uint8_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vmsgtu_vx)))
vbool4_t vmsgtu(vuint8m2_t, uint8_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vmsgtu_vx_m)))
vbool4_t vmsgtu(vbool4_t, vbool4_t, vuint8m2_t, uint8_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vmsgtu_vx)))
vbool2_t vmsgtu(vuint8m4_t, uint8_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vmsgtu_vx_m)))
vbool2_t vmsgtu(vbool2_t, vbool2_t, vuint8m4_t, uint8_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vmsgtu_vx)))
vbool1_t vmsgtu(vuint8m8_t, uint8_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vmsgtu_vx_m)))
vbool1_t vmsgtu(vbool1_t, vbool1_t, vuint8m8_t, uint8_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vmsgtu_vx)))
vbool16_t vmsgtu(vuint8mf2_t, uint8_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vmsgtu_vx_m)))
vbool16_t vmsgtu(vbool16_t, vbool16_t, vuint8mf2_t, uint8_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vmsgtu_vx)))
vbool32_t vmsgtu(vuint8mf4_t, uint8_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vmsgtu_vx_m)))
vbool32_t vmsgtu(vbool32_t, vbool32_t, vuint8mf4_t, uint8_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vmsgtu_vx)))
vbool64_t vmsgtu(vuint8mf8_t, uint8_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vmsgtu_vx_m)))
vbool64_t vmsgtu(vbool64_t, vbool64_t, vuint8mf8_t, uint8_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vmsgtu_vx)))
vbool16_t vmsgtu(vuint16m1_t, uint16_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vmsgtu_vx_m)))
vbool16_t vmsgtu(vbool16_t, vbool16_t, vuint16m1_t, uint16_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vmsgtu_vx)))
vbool8_t vmsgtu(vuint16m2_t, uint16_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vmsgtu_vx_m)))
vbool8_t vmsgtu(vbool8_t, vbool8_t, vuint16m2_t, uint16_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vmsgtu_vx)))
vbool4_t vmsgtu(vuint16m4_t, uint16_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vmsgtu_vx_m)))
vbool4_t vmsgtu(vbool4_t, vbool4_t, vuint16m4_t, uint16_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vmsgtu_vx)))
vbool2_t vmsgtu(vuint16m8_t, uint16_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vmsgtu_vx_m)))
vbool2_t vmsgtu(vbool2_t, vbool2_t, vuint16m8_t, uint16_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vmsgtu_vx)))
vbool32_t vmsgtu(vuint16mf2_t, uint16_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vmsgtu_vx_m)))
vbool32_t vmsgtu(vbool32_t, vbool32_t, vuint16mf2_t, uint16_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vmsgtu_vx)))
vbool64_t vmsgtu(vuint16mf4_t, uint16_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vmsgtu_vx_m)))
vbool64_t vmsgtu(vbool64_t, vbool64_t, vuint16mf4_t, uint16_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vmsgtu_vx)))
vbool32_t vmsgtu(vuint32m1_t, uint32_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vmsgtu_vx_m)))
vbool32_t vmsgtu(vbool32_t, vbool32_t, vuint32m1_t, uint32_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vmsgtu_vx)))
vbool16_t vmsgtu(vuint32m2_t, uint32_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vmsgtu_vx_m)))
vbool16_t vmsgtu(vbool16_t, vbool16_t, vuint32m2_t, uint32_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vmsgtu_vx)))
vbool8_t vmsgtu(vuint32m4_t, uint32_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vmsgtu_vx_m)))
vbool8_t vmsgtu(vbool8_t, vbool8_t, vuint32m4_t, uint32_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vmsgtu_vx)))
vbool4_t vmsgtu(vuint32m8_t, uint32_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vmsgtu_vx_m)))
vbool4_t vmsgtu(vbool4_t, vbool4_t, vuint32m8_t, uint32_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vmsgtu_vx)))
vbool64_t vmsgtu(vuint32mf2_t, uint32_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vmsgtu_vx_m)))
vbool64_t vmsgtu(vbool64_t, vbool64_t, vuint32mf2_t, uint32_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vmsgt_vv)))
vbool8_t vmsgt(vint8m1_t, vint8m1_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vmsgt_vv_m)))
vbool8_t vmsgt(vbool8_t, vbool8_t, vint8m1_t, vint8m1_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vmsgt_vv)))
vbool4_t vmsgt(vint8m2_t, vint8m2_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vmsgt_vv_m)))
vbool4_t vmsgt(vbool4_t, vbool4_t, vint8m2_t, vint8m2_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vmsgt_vv)))
vbool2_t vmsgt(vint8m4_t, vint8m4_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vmsgt_vv_m)))
vbool2_t vmsgt(vbool2_t, vbool2_t, vint8m4_t, vint8m4_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vmsgt_vv)))
vbool1_t vmsgt(vint8m8_t, vint8m8_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vmsgt_vv_m)))
vbool1_t vmsgt(vbool1_t, vbool1_t, vint8m8_t, vint8m8_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vmsgt_vv)))
vbool16_t vmsgt(vint8mf2_t, vint8mf2_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vmsgt_vv_m)))
vbool16_t vmsgt(vbool16_t, vbool16_t, vint8mf2_t, vint8mf2_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vmsgt_vv)))
vbool32_t vmsgt(vint8mf4_t, vint8mf4_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vmsgt_vv_m)))
vbool32_t vmsgt(vbool32_t, vbool32_t, vint8mf4_t, vint8mf4_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vmsgt_vv)))
vbool64_t vmsgt(vint8mf8_t, vint8mf8_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vmsgt_vv_m)))
vbool64_t vmsgt(vbool64_t, vbool64_t, vint8mf8_t, vint8mf8_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vmsgt_vv)))
vbool16_t vmsgt(vint16m1_t, vint16m1_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vmsgt_vv_m)))
vbool16_t vmsgt(vbool16_t, vbool16_t, vint16m1_t, vint16m1_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vmsgt_vv)))
vbool8_t vmsgt(vint16m2_t, vint16m2_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vmsgt_vv_m)))
vbool8_t vmsgt(vbool8_t, vbool8_t, vint16m2_t, vint16m2_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vmsgt_vv)))
vbool4_t vmsgt(vint16m4_t, vint16m4_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vmsgt_vv_m)))
vbool4_t vmsgt(vbool4_t, vbool4_t, vint16m4_t, vint16m4_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vmsgt_vv)))
vbool2_t vmsgt(vint16m8_t, vint16m8_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vmsgt_vv_m)))
vbool2_t vmsgt(vbool2_t, vbool2_t, vint16m8_t, vint16m8_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vmsgt_vv)))
vbool32_t vmsgt(vint16mf2_t, vint16mf2_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vmsgt_vv_m)))
vbool32_t vmsgt(vbool32_t, vbool32_t, vint16mf2_t, vint16mf2_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vmsgt_vv)))
vbool64_t vmsgt(vint16mf4_t, vint16mf4_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vmsgt_vv_m)))
vbool64_t vmsgt(vbool64_t, vbool64_t, vint16mf4_t, vint16mf4_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vmsgt_vv)))
vbool32_t vmsgt(vint32m1_t, vint32m1_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vmsgt_vv_m)))
vbool32_t vmsgt(vbool32_t, vbool32_t, vint32m1_t, vint32m1_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vmsgt_vv)))
vbool16_t vmsgt(vint32m2_t, vint32m2_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vmsgt_vv_m)))
vbool16_t vmsgt(vbool16_t, vbool16_t, vint32m2_t, vint32m2_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vmsgt_vv)))
vbool8_t vmsgt(vint32m4_t, vint32m4_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vmsgt_vv_m)))
vbool8_t vmsgt(vbool8_t, vbool8_t, vint32m4_t, vint32m4_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vmsgt_vv)))
vbool4_t vmsgt(vint32m8_t, vint32m8_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vmsgt_vv_m)))
vbool4_t vmsgt(vbool4_t, vbool4_t, vint32m8_t, vint32m8_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vmsgt_vv)))
vbool64_t vmsgt(vint32mf2_t, vint32mf2_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vmsgt_vv_m)))
vbool64_t vmsgt(vbool64_t, vbool64_t, vint32mf2_t, vint32mf2_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vmsgt_vx)))
vbool8_t vmsgt(vint8m1_t, int8_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vmsgt_vx_m)))
vbool8_t vmsgt(vbool8_t, vbool8_t, vint8m1_t, int8_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vmsgt_vx)))
vbool4_t vmsgt(vint8m2_t, int8_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vmsgt_vx_m)))
vbool4_t vmsgt(vbool4_t, vbool4_t, vint8m2_t, int8_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vmsgt_vx)))
vbool2_t vmsgt(vint8m4_t, int8_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vmsgt_vx_m)))
vbool2_t vmsgt(vbool2_t, vbool2_t, vint8m4_t, int8_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vmsgt_vx)))
vbool1_t vmsgt(vint8m8_t, int8_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vmsgt_vx_m)))
vbool1_t vmsgt(vbool1_t, vbool1_t, vint8m8_t, int8_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vmsgt_vx)))
vbool16_t vmsgt(vint8mf2_t, int8_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vmsgt_vx_m)))
vbool16_t vmsgt(vbool16_t, vbool16_t, vint8mf2_t, int8_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vmsgt_vx)))
vbool32_t vmsgt(vint8mf4_t, int8_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vmsgt_vx_m)))
vbool32_t vmsgt(vbool32_t, vbool32_t, vint8mf4_t, int8_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vmsgt_vx)))
vbool64_t vmsgt(vint8mf8_t, int8_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vmsgt_vx_m)))
vbool64_t vmsgt(vbool64_t, vbool64_t, vint8mf8_t, int8_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vmsgt_vx)))
vbool16_t vmsgt(vint16m1_t, int16_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vmsgt_vx_m)))
vbool16_t vmsgt(vbool16_t, vbool16_t, vint16m1_t, int16_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vmsgt_vx)))
vbool8_t vmsgt(vint16m2_t, int16_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vmsgt_vx_m)))
vbool8_t vmsgt(vbool8_t, vbool8_t, vint16m2_t, int16_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vmsgt_vx)))
vbool4_t vmsgt(vint16m4_t, int16_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vmsgt_vx_m)))
vbool4_t vmsgt(vbool4_t, vbool4_t, vint16m4_t, int16_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vmsgt_vx)))
vbool2_t vmsgt(vint16m8_t, int16_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vmsgt_vx_m)))
vbool2_t vmsgt(vbool2_t, vbool2_t, vint16m8_t, int16_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vmsgt_vx)))
vbool32_t vmsgt(vint16mf2_t, int16_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vmsgt_vx_m)))
vbool32_t vmsgt(vbool32_t, vbool32_t, vint16mf2_t, int16_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vmsgt_vx)))
vbool64_t vmsgt(vint16mf4_t, int16_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vmsgt_vx_m)))
vbool64_t vmsgt(vbool64_t, vbool64_t, vint16mf4_t, int16_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vmsgt_vx)))
vbool32_t vmsgt(vint32m1_t, int32_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vmsgt_vx_m)))
vbool32_t vmsgt(vbool32_t, vbool32_t, vint32m1_t, int32_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vmsgt_vx)))
vbool16_t vmsgt(vint32m2_t, int32_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vmsgt_vx_m)))
vbool16_t vmsgt(vbool16_t, vbool16_t, vint32m2_t, int32_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vmsgt_vx)))
vbool8_t vmsgt(vint32m4_t, int32_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vmsgt_vx_m)))
vbool8_t vmsgt(vbool8_t, vbool8_t, vint32m4_t, int32_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vmsgt_vx)))
vbool4_t vmsgt(vint32m8_t, int32_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vmsgt_vx_m)))
vbool4_t vmsgt(vbool4_t, vbool4_t, vint32m8_t, int32_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vmsgt_vx)))
vbool64_t vmsgt(vint32mf2_t, int32_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vmsgt_vx_m)))
vbool64_t vmsgt(vbool64_t, vbool64_t, vint32mf2_t, int32_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vmsgeu_vv)))
vbool8_t vmsgeu(vuint8m1_t, vuint8m1_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vmsgeu_vv_m)))
vbool8_t vmsgeu(vbool8_t, vbool8_t, vuint8m1_t, vuint8m1_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vmsgeu_vv)))
vbool4_t vmsgeu(vuint8m2_t, vuint8m2_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vmsgeu_vv_m)))
vbool4_t vmsgeu(vbool4_t, vbool4_t, vuint8m2_t, vuint8m2_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vmsgeu_vv)))
vbool2_t vmsgeu(vuint8m4_t, vuint8m4_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vmsgeu_vv_m)))
vbool2_t vmsgeu(vbool2_t, vbool2_t, vuint8m4_t, vuint8m4_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vmsgeu_vv)))
vbool1_t vmsgeu(vuint8m8_t, vuint8m8_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vmsgeu_vv_m)))
vbool1_t vmsgeu(vbool1_t, vbool1_t, vuint8m8_t, vuint8m8_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vmsgeu_vv)))
vbool16_t vmsgeu(vuint8mf2_t, vuint8mf2_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vmsgeu_vv_m)))
vbool16_t vmsgeu(vbool16_t, vbool16_t, vuint8mf2_t, vuint8mf2_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vmsgeu_vv)))
vbool32_t vmsgeu(vuint8mf4_t, vuint8mf4_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vmsgeu_vv_m)))
vbool32_t vmsgeu(vbool32_t, vbool32_t, vuint8mf4_t, vuint8mf4_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vmsgeu_vv)))
vbool64_t vmsgeu(vuint8mf8_t, vuint8mf8_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vmsgeu_vv_m)))
vbool64_t vmsgeu(vbool64_t, vbool64_t, vuint8mf8_t, vuint8mf8_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vmsgeu_vv)))
vbool16_t vmsgeu(vuint16m1_t, vuint16m1_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vmsgeu_vv_m)))
vbool16_t vmsgeu(vbool16_t, vbool16_t, vuint16m1_t, vuint16m1_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vmsgeu_vv)))
vbool8_t vmsgeu(vuint16m2_t, vuint16m2_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vmsgeu_vv_m)))
vbool8_t vmsgeu(vbool8_t, vbool8_t, vuint16m2_t, vuint16m2_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vmsgeu_vv)))
vbool4_t vmsgeu(vuint16m4_t, vuint16m4_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vmsgeu_vv_m)))
vbool4_t vmsgeu(vbool4_t, vbool4_t, vuint16m4_t, vuint16m4_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vmsgeu_vv)))
vbool2_t vmsgeu(vuint16m8_t, vuint16m8_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vmsgeu_vv_m)))
vbool2_t vmsgeu(vbool2_t, vbool2_t, vuint16m8_t, vuint16m8_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vmsgeu_vv)))
vbool32_t vmsgeu(vuint16mf2_t, vuint16mf2_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vmsgeu_vv_m)))
vbool32_t vmsgeu(vbool32_t, vbool32_t, vuint16mf2_t, vuint16mf2_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vmsgeu_vv)))
vbool64_t vmsgeu(vuint16mf4_t, vuint16mf4_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vmsgeu_vv_m)))
vbool64_t vmsgeu(vbool64_t, vbool64_t, vuint16mf4_t, vuint16mf4_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vmsgeu_vv)))
vbool32_t vmsgeu(vuint32m1_t, vuint32m1_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vmsgeu_vv_m)))
vbool32_t vmsgeu(vbool32_t, vbool32_t, vuint32m1_t, vuint32m1_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vmsgeu_vv)))
vbool16_t vmsgeu(vuint32m2_t, vuint32m2_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vmsgeu_vv_m)))
vbool16_t vmsgeu(vbool16_t, vbool16_t, vuint32m2_t, vuint32m2_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vmsgeu_vv)))
vbool8_t vmsgeu(vuint32m4_t, vuint32m4_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vmsgeu_vv_m)))
vbool8_t vmsgeu(vbool8_t, vbool8_t, vuint32m4_t, vuint32m4_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vmsgeu_vv)))
vbool4_t vmsgeu(vuint32m8_t, vuint32m8_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vmsgeu_vv_m)))
vbool4_t vmsgeu(vbool4_t, vbool4_t, vuint32m8_t, vuint32m8_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vmsgeu_vv)))
vbool64_t vmsgeu(vuint32mf2_t, vuint32mf2_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vmsgeu_vv_m)))
vbool64_t vmsgeu(vbool64_t, vbool64_t, vuint32mf2_t, vuint32mf2_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vwaddu_wv)))
vuint16mf4_t vwaddu_wv(vuint16mf4_t, vuint8mf8_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vwaddu_wv_m)))
vuint16mf4_t vwaddu_wv(vbool64_t, vuint16mf4_t, vuint16mf4_t, vuint8mf8_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vwaddu_wv)))
vuint16mf2_t vwaddu_wv(vuint16mf2_t, vuint8mf4_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vwaddu_wv_m)))
vuint16mf2_t vwaddu_wv(vbool32_t, vuint16mf2_t, vuint16mf2_t, vuint8mf4_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vwaddu_wv)))
vuint16m1_t vwaddu_wv(vuint16m1_t, vuint8mf2_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vwaddu_wv_m)))
vuint16m1_t vwaddu_wv(vbool16_t, vuint16m1_t, vuint16m1_t, vuint8mf2_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vwaddu_wv)))
vuint16m2_t vwaddu_wv(vuint16m2_t, vuint8m1_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vwaddu_wv_m)))
vuint16m2_t vwaddu_wv(vbool8_t, vuint16m2_t, vuint16m2_t, vuint8m1_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vwaddu_wv)))
vuint16m4_t vwaddu_wv(vuint16m4_t, vuint8m2_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vwaddu_wv_m)))
vuint16m4_t vwaddu_wv(vbool4_t, vuint16m4_t, vuint16m4_t, vuint8m2_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vwaddu_wv)))
vuint16m8_t vwaddu_wv(vuint16m8_t, vuint8m4_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vwaddu_wv_m)))
vuint16m8_t vwaddu_wv(vbool2_t, vuint16m8_t, vuint16m8_t, vuint8m4_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vwaddu_wv)))
vuint32mf2_t vwaddu_wv(vuint32mf2_t, vuint16mf4_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vwaddu_wv_m)))
vuint32mf2_t vwaddu_wv(vbool64_t, vuint32mf2_t, vuint32mf2_t, vuint16mf4_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vwaddu_wv)))
vuint32m1_t vwaddu_wv(vuint32m1_t, vuint16mf2_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vwaddu_wv_m)))
vuint32m1_t vwaddu_wv(vbool32_t, vuint32m1_t, vuint32m1_t, vuint16mf2_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vwaddu_wv)))
vuint32m2_t vwaddu_wv(vuint32m2_t, vuint16m1_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vwaddu_wv_m)))
vuint32m2_t vwaddu_wv(vbool16_t, vuint32m2_t, vuint32m2_t, vuint16m1_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vwaddu_wv)))
vuint32m4_t vwaddu_wv(vuint32m4_t, vuint16m2_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vwaddu_wv_m)))
vuint32m4_t vwaddu_wv(vbool8_t, vuint32m4_t, vuint32m4_t, vuint16m2_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vwaddu_wv)))
vuint32m8_t vwaddu_wv(vuint32m8_t, vuint16m4_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vwaddu_wv_m)))
vuint32m8_t vwaddu_wv(vbool4_t, vuint32m8_t, vuint32m8_t, vuint16m4_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vse8_v)))
void vse8(int8_t *, vint8m1_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vse8_v_m)))
void vse8(vbool8_t, int8_t *, vint8m1_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vse8_v)))
void vse8(int8_t *, vint8m2_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vse8_v_m)))
void vse8(vbool4_t, int8_t *, vint8m2_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vse8_v)))
void vse8(int8_t *, vint8m4_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vse8_v_m)))
void vse8(vbool2_t, int8_t *, vint8m4_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vse8_v)))
void vse8(int8_t *, vint8m8_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vse8_v_m)))
void vse8(vbool1_t, int8_t *, vint8m8_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vse8_v)))
void vse8(int8_t *, vint8mf2_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vse8_v_m)))
void vse8(vbool16_t, int8_t *, vint8mf2_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vse8_v)))
void vse8(int8_t *, vint8mf4_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vse8_v_m)))
void vse8(vbool32_t, int8_t *, vint8mf4_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vse8_v)))
void vse8(int8_t *, vint8mf8_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vse8_v_m)))
void vse8(vbool64_t, int8_t *, vint8mf8_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vsuxei16_v)))
void vsuxei16(int8_t *, vuint16m2_t, vint8m1_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vsuxei16_v_m)))
void vsuxei16(vbool8_t, int8_t *, vuint16m2_t, vint8m1_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vsuxei16_v)))
void vsuxei16(int8_t *, vuint16m4_t, vint8m2_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vsuxei16_v_m)))
void vsuxei16(vbool4_t, int8_t *, vuint16m4_t, vint8m2_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vsuxei16_v)))
void vsuxei16(int8_t *, vuint16m8_t, vint8m4_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vsuxei16_v_m)))
void vsuxei16(vbool2_t, int8_t *, vuint16m8_t, vint8m4_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vsuxei16_v)))
void vsuxei16(int8_t *, vuint16m1_t, vint8mf2_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vsuxei16_v_m)))
void vsuxei16(vbool16_t, int8_t *, vuint16m1_t, vint8mf2_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vsuxei16_v)))
void vsuxei16(int8_t *, vuint16mf2_t, vint8mf4_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vsuxei16_v_m)))
void vsuxei16(vbool32_t, int8_t *, vuint16mf2_t, vint8mf4_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vsuxei16_v)))
void vsuxei16(int8_t *, vuint16mf4_t, vint8mf8_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vsuxei16_v_m)))
void vsuxei16(vbool64_t, int8_t *, vuint16mf4_t, vint8mf8_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vmsgeu_vx)))
vbool8_t vmsgeu(vuint8m1_t, uint8_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vmsgeu_vx_m)))
vbool8_t vmsgeu(vbool8_t, vbool8_t, vuint8m1_t, uint8_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vmsgeu_vx)))
vbool4_t vmsgeu(vuint8m2_t, uint8_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vmsgeu_vx_m)))
vbool4_t vmsgeu(vbool4_t, vbool4_t, vuint8m2_t, uint8_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vmsgeu_vx)))
vbool2_t vmsgeu(vuint8m4_t, uint8_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vmsgeu_vx_m)))
vbool2_t vmsgeu(vbool2_t, vbool2_t, vuint8m4_t, uint8_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vmsgeu_vx)))
vbool1_t vmsgeu(vuint8m8_t, uint8_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vmsgeu_vx_m)))
vbool1_t vmsgeu(vbool1_t, vbool1_t, vuint8m8_t, uint8_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vmsgeu_vx)))
vbool16_t vmsgeu(vuint8mf2_t, uint8_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vmsgeu_vx_m)))
vbool16_t vmsgeu(vbool16_t, vbool16_t, vuint8mf2_t, uint8_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vmsgeu_vx)))
vbool32_t vmsgeu(vuint8mf4_t, uint8_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vmsgeu_vx_m)))
vbool32_t vmsgeu(vbool32_t, vbool32_t, vuint8mf4_t, uint8_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vmsgeu_vx)))
vbool64_t vmsgeu(vuint8mf8_t, uint8_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vmsgeu_vx_m)))
vbool64_t vmsgeu(vbool64_t, vbool64_t, vuint8mf8_t, uint8_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vmsgeu_vx)))
vbool16_t vmsgeu(vuint16m1_t, uint16_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vmsgeu_vx_m)))
vbool16_t vmsgeu(vbool16_t, vbool16_t, vuint16m1_t, uint16_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vmsgeu_vx)))
vbool8_t vmsgeu(vuint16m2_t, uint16_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vmsgeu_vx_m)))
vbool8_t vmsgeu(vbool8_t, vbool8_t, vuint16m2_t, uint16_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vmsgeu_vx)))
vbool4_t vmsgeu(vuint16m4_t, uint16_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vmsgeu_vx_m)))
vbool4_t vmsgeu(vbool4_t, vbool4_t, vuint16m4_t, uint16_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vmsgeu_vx)))
vbool2_t vmsgeu(vuint16m8_t, uint16_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vmsgeu_vx_m)))
vbool2_t vmsgeu(vbool2_t, vbool2_t, vuint16m8_t, uint16_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vmsgeu_vx)))
vbool32_t vmsgeu(vuint16mf2_t, uint16_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vmsgeu_vx_m)))
vbool32_t vmsgeu(vbool32_t, vbool32_t, vuint16mf2_t, uint16_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vmsgeu_vx)))
vbool64_t vmsgeu(vuint16mf4_t, uint16_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vmsgeu_vx_m)))
vbool64_t vmsgeu(vbool64_t, vbool64_t, vuint16mf4_t, uint16_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vmsgeu_vx)))
vbool32_t vmsgeu(vuint32m1_t, uint32_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vmsgeu_vx_m)))
vbool32_t vmsgeu(vbool32_t, vbool32_t, vuint32m1_t, uint32_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vmsgeu_vx)))
vbool16_t vmsgeu(vuint32m2_t, uint32_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vmsgeu_vx_m)))
vbool16_t vmsgeu(vbool16_t, vbool16_t, vuint32m2_t, uint32_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vmsgeu_vx)))
vbool8_t vmsgeu(vuint32m4_t, uint32_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vmsgeu_vx_m)))
vbool8_t vmsgeu(vbool8_t, vbool8_t, vuint32m4_t, uint32_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vmsgeu_vx)))
vbool4_t vmsgeu(vuint32m8_t, uint32_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vmsgeu_vx_m)))
vbool4_t vmsgeu(vbool4_t, vbool4_t, vuint32m8_t, uint32_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vmsgeu_vx)))
vbool64_t vmsgeu(vuint32mf2_t, uint32_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vmsgeu_vx_m)))
vbool64_t vmsgeu(vbool64_t, vbool64_t, vuint32mf2_t, uint32_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vmsge_vv)))
vbool8_t vmsge(vint8m1_t, vint8m1_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vmsge_vv_m)))
vbool8_t vmsge(vbool8_t, vbool8_t, vint8m1_t, vint8m1_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vmsge_vv)))
vbool4_t vmsge(vint8m2_t, vint8m2_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vmsge_vv_m)))
vbool4_t vmsge(vbool4_t, vbool4_t, vint8m2_t, vint8m2_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vmsge_vv)))
vbool2_t vmsge(vint8m4_t, vint8m4_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vmsge_vv_m)))
vbool2_t vmsge(vbool2_t, vbool2_t, vint8m4_t, vint8m4_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vmsge_vv)))
vbool1_t vmsge(vint8m8_t, vint8m8_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vmsge_vv_m)))
vbool1_t vmsge(vbool1_t, vbool1_t, vint8m8_t, vint8m8_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vmsge_vv)))
vbool16_t vmsge(vint8mf2_t, vint8mf2_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vmsge_vv_m)))
vbool16_t vmsge(vbool16_t, vbool16_t, vint8mf2_t, vint8mf2_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vmsge_vv)))
vbool32_t vmsge(vint8mf4_t, vint8mf4_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vmsge_vv_m)))
vbool32_t vmsge(vbool32_t, vbool32_t, vint8mf4_t, vint8mf4_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vmsge_vv)))
vbool64_t vmsge(vint8mf8_t, vint8mf8_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vmsge_vv_m)))
vbool64_t vmsge(vbool64_t, vbool64_t, vint8mf8_t, vint8mf8_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vmsge_vv)))
vbool16_t vmsge(vint16m1_t, vint16m1_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vmsge_vv_m)))
vbool16_t vmsge(vbool16_t, vbool16_t, vint16m1_t, vint16m1_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vmsge_vv)))
vbool8_t vmsge(vint16m2_t, vint16m2_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vmsge_vv_m)))
vbool8_t vmsge(vbool8_t, vbool8_t, vint16m2_t, vint16m2_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vmsge_vv)))
vbool4_t vmsge(vint16m4_t, vint16m4_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vmsge_vv_m)))
vbool4_t vmsge(vbool4_t, vbool4_t, vint16m4_t, vint16m4_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vmsge_vv)))
vbool2_t vmsge(vint16m8_t, vint16m8_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vmsge_vv_m)))
vbool2_t vmsge(vbool2_t, vbool2_t, vint16m8_t, vint16m8_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vmsge_vv)))
vbool32_t vmsge(vint16mf2_t, vint16mf2_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vmsge_vv_m)))
vbool32_t vmsge(vbool32_t, vbool32_t, vint16mf2_t, vint16mf2_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vmsge_vv)))
vbool64_t vmsge(vint16mf4_t, vint16mf4_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vmsge_vv_m)))
vbool64_t vmsge(vbool64_t, vbool64_t, vint16mf4_t, vint16mf4_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vmsge_vv)))
vbool32_t vmsge(vint32m1_t, vint32m1_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vmsge_vv_m)))
vbool32_t vmsge(vbool32_t, vbool32_t, vint32m1_t, vint32m1_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vmsge_vv)))
vbool16_t vmsge(vint32m2_t, vint32m2_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vmsge_vv_m)))
vbool16_t vmsge(vbool16_t, vbool16_t, vint32m2_t, vint32m2_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vmsge_vv)))
vbool8_t vmsge(vint32m4_t, vint32m4_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vmsge_vv_m)))
vbool8_t vmsge(vbool8_t, vbool8_t, vint32m4_t, vint32m4_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vmsge_vv)))
vbool4_t vmsge(vint32m8_t, vint32m8_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vmsge_vv_m)))
vbool4_t vmsge(vbool4_t, vbool4_t, vint32m8_t, vint32m8_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vmsge_vv)))
vbool64_t vmsge(vint32mf2_t, vint32mf2_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vmsge_vv_m)))
vbool64_t vmsge(vbool64_t, vbool64_t, vint32mf2_t, vint32mf2_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vmsge_vx)))
vbool8_t vmsge(vint8m1_t, int8_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vmsge_vx_m)))
vbool8_t vmsge(vbool8_t, vbool8_t, vint8m1_t, int8_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vmsge_vx)))
vbool4_t vmsge(vint8m2_t, int8_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vmsge_vx_m)))
vbool4_t vmsge(vbool4_t, vbool4_t, vint8m2_t, int8_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vmsge_vx)))
vbool2_t vmsge(vint8m4_t, int8_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vmsge_vx_m)))
vbool2_t vmsge(vbool2_t, vbool2_t, vint8m4_t, int8_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vmsge_vx)))
vbool1_t vmsge(vint8m8_t, int8_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vmsge_vx_m)))
vbool1_t vmsge(vbool1_t, vbool1_t, vint8m8_t, int8_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vmsge_vx)))
vbool16_t vmsge(vint8mf2_t, int8_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vmsge_vx_m)))
vbool16_t vmsge(vbool16_t, vbool16_t, vint8mf2_t, int8_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vmsge_vx)))
vbool32_t vmsge(vint8mf4_t, int8_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vmsge_vx_m)))
vbool32_t vmsge(vbool32_t, vbool32_t, vint8mf4_t, int8_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vmsge_vx)))
vbool64_t vmsge(vint8mf8_t, int8_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vmsge_vx_m)))
vbool64_t vmsge(vbool64_t, vbool64_t, vint8mf8_t, int8_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vmsge_vx)))
vbool16_t vmsge(vint16m1_t, int16_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vmsge_vx_m)))
vbool16_t vmsge(vbool16_t, vbool16_t, vint16m1_t, int16_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vmsge_vx)))
vbool8_t vmsge(vint16m2_t, int16_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vmsge_vx_m)))
vbool8_t vmsge(vbool8_t, vbool8_t, vint16m2_t, int16_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vmsge_vx)))
vbool4_t vmsge(vint16m4_t, int16_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vmsge_vx_m)))
vbool4_t vmsge(vbool4_t, vbool4_t, vint16m4_t, int16_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vmsge_vx)))
vbool2_t vmsge(vint16m8_t, int16_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vmsge_vx_m)))
vbool2_t vmsge(vbool2_t, vbool2_t, vint16m8_t, int16_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vmsge_vx)))
vbool32_t vmsge(vint16mf2_t, int16_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vmsge_vx_m)))
vbool32_t vmsge(vbool32_t, vbool32_t, vint16mf2_t, int16_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vmsge_vx)))
vbool64_t vmsge(vint16mf4_t, int16_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vmsge_vx_m)))
vbool64_t vmsge(vbool64_t, vbool64_t, vint16mf4_t, int16_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vmsge_vx)))
vbool32_t vmsge(vint32m1_t, int32_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vmsge_vx_m)))
vbool32_t vmsge(vbool32_t, vbool32_t, vint32m1_t, int32_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vmsge_vx)))
vbool16_t vmsge(vint32m2_t, int32_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vmsge_vx_m)))
vbool16_t vmsge(vbool16_t, vbool16_t, vint32m2_t, int32_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vmsge_vx)))
vbool8_t vmsge(vint32m4_t, int32_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vmsge_vx_m)))
vbool8_t vmsge(vbool8_t, vbool8_t, vint32m4_t, int32_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vmsge_vx)))
vbool4_t vmsge(vint32m8_t, int32_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vmsge_vx_m)))
vbool4_t vmsge(vbool4_t, vbool4_t, vint32m8_t, int32_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vmsge_vx)))
vbool64_t vmsge(vint32mf2_t, int32_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vmsge_vx_m)))
vbool64_t vmsge(vbool64_t, vbool64_t, vint32mf2_t, int32_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vminu_vv)))
vuint8m1_t vminu(vuint8m1_t, vuint8m1_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vminu_vv_m)))
vuint8m1_t vminu(vbool8_t, vuint8m1_t, vuint8m1_t, vuint8m1_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vminu_vv)))
vuint8m2_t vminu(vuint8m2_t, vuint8m2_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vminu_vv_m)))
vuint8m2_t vminu(vbool4_t, vuint8m2_t, vuint8m2_t, vuint8m2_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vminu_vv)))
vuint8m4_t vminu(vuint8m4_t, vuint8m4_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vminu_vv_m)))
vuint8m4_t vminu(vbool2_t, vuint8m4_t, vuint8m4_t, vuint8m4_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vminu_vv)))
vuint8m8_t vminu(vuint8m8_t, vuint8m8_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vminu_vv_m)))
vuint8m8_t vminu(vbool1_t, vuint8m8_t, vuint8m8_t, vuint8m8_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vminu_vv)))
vuint8mf2_t vminu(vuint8mf2_t, vuint8mf2_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vminu_vv_m)))
vuint8mf2_t vminu(vbool16_t, vuint8mf2_t, vuint8mf2_t, vuint8mf2_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vminu_vv)))
vuint8mf4_t vminu(vuint8mf4_t, vuint8mf4_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vminu_vv_m)))
vuint8mf4_t vminu(vbool32_t, vuint8mf4_t, vuint8mf4_t, vuint8mf4_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vminu_vv)))
vuint8mf8_t vminu(vuint8mf8_t, vuint8mf8_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vminu_vv_m)))
vuint8mf8_t vminu(vbool64_t, vuint8mf8_t, vuint8mf8_t, vuint8mf8_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vminu_vv)))
vuint16m1_t vminu(vuint16m1_t, vuint16m1_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vminu_vv_m)))
vuint16m1_t vminu(vbool16_t, vuint16m1_t, vuint16m1_t, vuint16m1_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vminu_vv)))
vuint16m2_t vminu(vuint16m2_t, vuint16m2_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vminu_vv_m)))
vuint16m2_t vminu(vbool8_t, vuint16m2_t, vuint16m2_t, vuint16m2_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vminu_vv)))
vuint16m4_t vminu(vuint16m4_t, vuint16m4_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vminu_vv_m)))
vuint16m4_t vminu(vbool4_t, vuint16m4_t, vuint16m4_t, vuint16m4_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vminu_vv)))
vuint16m8_t vminu(vuint16m8_t, vuint16m8_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vminu_vv_m)))
vuint16m8_t vminu(vbool2_t, vuint16m8_t, vuint16m8_t, vuint16m8_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vminu_vv)))
vuint16mf2_t vminu(vuint16mf2_t, vuint16mf2_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vminu_vv_m)))
vuint16mf2_t vminu(vbool32_t, vuint16mf2_t, vuint16mf2_t, vuint16mf2_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vminu_vv)))
vuint16mf4_t vminu(vuint16mf4_t, vuint16mf4_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vminu_vv_m)))
vuint16mf4_t vminu(vbool64_t, vuint16mf4_t, vuint16mf4_t, vuint16mf4_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vminu_vv)))
vuint32m1_t vminu(vuint32m1_t, vuint32m1_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vminu_vv_m)))
vuint32m1_t vminu(vbool32_t, vuint32m1_t, vuint32m1_t, vuint32m1_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vminu_vv)))
vuint32m2_t vminu(vuint32m2_t, vuint32m2_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vminu_vv_m)))
vuint32m2_t vminu(vbool16_t, vuint32m2_t, vuint32m2_t, vuint32m2_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vminu_vv)))
vuint32m4_t vminu(vuint32m4_t, vuint32m4_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vminu_vv_m)))
vuint32m4_t vminu(vbool8_t, vuint32m4_t, vuint32m4_t, vuint32m4_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vminu_vv)))
vuint32m8_t vminu(vuint32m8_t, vuint32m8_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vminu_vv_m)))
vuint32m8_t vminu(vbool4_t, vuint32m8_t, vuint32m8_t, vuint32m8_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vminu_vv)))
vuint32mf2_t vminu(vuint32mf2_t, vuint32mf2_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vminu_vv_m)))
vuint32mf2_t vminu(vbool64_t, vuint32mf2_t, vuint32mf2_t, vuint32mf2_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vminu_vx)))
vuint8m1_t vminu(vuint8m1_t, uint8_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vminu_vx_m)))
vuint8m1_t vminu(vbool8_t, vuint8m1_t, vuint8m1_t, uint8_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vminu_vx)))
vuint8m2_t vminu(vuint8m2_t, uint8_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vminu_vx_m)))
vuint8m2_t vminu(vbool4_t, vuint8m2_t, vuint8m2_t, uint8_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vminu_vx)))
vuint8m4_t vminu(vuint8m4_t, uint8_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vminu_vx_m)))
vuint8m4_t vminu(vbool2_t, vuint8m4_t, vuint8m4_t, uint8_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vminu_vx)))
vuint8m8_t vminu(vuint8m8_t, uint8_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vminu_vx_m)))
vuint8m8_t vminu(vbool1_t, vuint8m8_t, vuint8m8_t, uint8_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vminu_vx)))
vuint8mf2_t vminu(vuint8mf2_t, uint8_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vminu_vx_m)))
vuint8mf2_t vminu(vbool16_t, vuint8mf2_t, vuint8mf2_t, uint8_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vminu_vx)))
vuint8mf4_t vminu(vuint8mf4_t, uint8_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vminu_vx_m)))
vuint8mf4_t vminu(vbool32_t, vuint8mf4_t, vuint8mf4_t, uint8_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vminu_vx)))
vuint8mf8_t vminu(vuint8mf8_t, uint8_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vminu_vx_m)))
vuint8mf8_t vminu(vbool64_t, vuint8mf8_t, vuint8mf8_t, uint8_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vminu_vx)))
vuint16m1_t vminu(vuint16m1_t, uint16_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vminu_vx_m)))
vuint16m1_t vminu(vbool16_t, vuint16m1_t, vuint16m1_t, uint16_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vminu_vx)))
vuint16m2_t vminu(vuint16m2_t, uint16_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vminu_vx_m)))
vuint16m2_t vminu(vbool8_t, vuint16m2_t, vuint16m2_t, uint16_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vminu_vx)))
vuint16m4_t vminu(vuint16m4_t, uint16_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vminu_vx_m)))
vuint16m4_t vminu(vbool4_t, vuint16m4_t, vuint16m4_t, uint16_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vminu_vx)))
vuint16m8_t vminu(vuint16m8_t, uint16_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vminu_vx_m)))
vuint16m8_t vminu(vbool2_t, vuint16m8_t, vuint16m8_t, uint16_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vminu_vx)))
vuint16mf2_t vminu(vuint16mf2_t, uint16_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vminu_vx_m)))
vuint16mf2_t vminu(vbool32_t, vuint16mf2_t, vuint16mf2_t, uint16_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vminu_vx)))
vuint16mf4_t vminu(vuint16mf4_t, uint16_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vminu_vx_m)))
vuint16mf4_t vminu(vbool64_t, vuint16mf4_t, vuint16mf4_t, uint16_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vminu_vx)))
vuint32m1_t vminu(vuint32m1_t, uint32_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vminu_vx_m)))
vuint32m1_t vminu(vbool32_t, vuint32m1_t, vuint32m1_t, uint32_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vminu_vx)))
vuint32m2_t vminu(vuint32m2_t, uint32_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vminu_vx_m)))
vuint32m2_t vminu(vbool16_t, vuint32m2_t, vuint32m2_t, uint32_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vminu_vx)))
vuint32m4_t vminu(vuint32m4_t, uint32_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vminu_vx_m)))
vuint32m4_t vminu(vbool8_t, vuint32m4_t, vuint32m4_t, uint32_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vminu_vx)))
vuint32m8_t vminu(vuint32m8_t, uint32_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vminu_vx_m)))
vuint32m8_t vminu(vbool4_t, vuint32m8_t, vuint32m8_t, uint32_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vminu_vx)))
vuint32mf2_t vminu(vuint32mf2_t, uint32_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vminu_vx_m)))
vuint32mf2_t vminu(vbool64_t, vuint32mf2_t, vuint32mf2_t, uint32_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vmin_vv)))
vint8m1_t vmin(vint8m1_t, vint8m1_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vmin_vv_m)))
vint8m1_t vmin(vbool8_t, vint8m1_t, vint8m1_t, vint8m1_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vmin_vv)))
vint8m2_t vmin(vint8m2_t, vint8m2_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vmin_vv_m)))
vint8m2_t vmin(vbool4_t, vint8m2_t, vint8m2_t, vint8m2_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vmin_vv)))
vint8m4_t vmin(vint8m4_t, vint8m4_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vmin_vv_m)))
vint8m4_t vmin(vbool2_t, vint8m4_t, vint8m4_t, vint8m4_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vmin_vv)))
vint8m8_t vmin(vint8m8_t, vint8m8_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vmin_vv_m)))
vint8m8_t vmin(vbool1_t, vint8m8_t, vint8m8_t, vint8m8_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vmin_vv)))
vint8mf2_t vmin(vint8mf2_t, vint8mf2_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vmin_vv_m)))
vint8mf2_t vmin(vbool16_t, vint8mf2_t, vint8mf2_t, vint8mf2_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vmin_vv)))
vint8mf4_t vmin(vint8mf4_t, vint8mf4_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vmin_vv_m)))
vint8mf4_t vmin(vbool32_t, vint8mf4_t, vint8mf4_t, vint8mf4_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vmin_vv)))
vint8mf8_t vmin(vint8mf8_t, vint8mf8_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vmin_vv_m)))
vint8mf8_t vmin(vbool64_t, vint8mf8_t, vint8mf8_t, vint8mf8_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vmin_vv)))
vint16m1_t vmin(vint16m1_t, vint16m1_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vmin_vv_m)))
vint16m1_t vmin(vbool16_t, vint16m1_t, vint16m1_t, vint16m1_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vmin_vv)))
vint16m2_t vmin(vint16m2_t, vint16m2_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vmin_vv_m)))
vint16m2_t vmin(vbool8_t, vint16m2_t, vint16m2_t, vint16m2_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vmin_vv)))
vint16m4_t vmin(vint16m4_t, vint16m4_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vmin_vv_m)))
vint16m4_t vmin(vbool4_t, vint16m4_t, vint16m4_t, vint16m4_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vmin_vv)))
vint16m8_t vmin(vint16m8_t, vint16m8_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vmin_vv_m)))
vint16m8_t vmin(vbool2_t, vint16m8_t, vint16m8_t, vint16m8_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vmin_vv)))
vint16mf2_t vmin(vint16mf2_t, vint16mf2_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vmin_vv_m)))
vint16mf2_t vmin(vbool32_t, vint16mf2_t, vint16mf2_t, vint16mf2_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vmin_vv)))
vint16mf4_t vmin(vint16mf4_t, vint16mf4_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vmin_vv_m)))
vint16mf4_t vmin(vbool64_t, vint16mf4_t, vint16mf4_t, vint16mf4_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vmin_vv)))
vint32m1_t vmin(vint32m1_t, vint32m1_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vmin_vv_m)))
vint32m1_t vmin(vbool32_t, vint32m1_t, vint32m1_t, vint32m1_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vmin_vv)))
vint32m2_t vmin(vint32m2_t, vint32m2_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vmin_vv_m)))
vint32m2_t vmin(vbool16_t, vint32m2_t, vint32m2_t, vint32m2_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vmin_vv)))
vint32m4_t vmin(vint32m4_t, vint32m4_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vmin_vv_m)))
vint32m4_t vmin(vbool8_t, vint32m4_t, vint32m4_t, vint32m4_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vmin_vv)))
vint32m8_t vmin(vint32m8_t, vint32m8_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vmin_vv_m)))
vint32m8_t vmin(vbool4_t, vint32m8_t, vint32m8_t, vint32m8_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vmin_vv)))
vint32mf2_t vmin(vint32mf2_t, vint32mf2_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vmin_vv_m)))
vint32mf2_t vmin(vbool64_t, vint32mf2_t, vint32mf2_t, vint32mf2_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vmin_vx)))
vint8m1_t vmin(vint8m1_t, int8_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vmin_vx_m)))
vint8m1_t vmin(vbool8_t, vint8m1_t, vint8m1_t, int8_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vmin_vx)))
vint8m2_t vmin(vint8m2_t, int8_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vmin_vx_m)))
vint8m2_t vmin(vbool4_t, vint8m2_t, vint8m2_t, int8_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vmin_vx)))
vint8m4_t vmin(vint8m4_t, int8_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vmin_vx_m)))
vint8m4_t vmin(vbool2_t, vint8m4_t, vint8m4_t, int8_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vmin_vx)))
vint8m8_t vmin(vint8m8_t, int8_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vmin_vx_m)))
vint8m8_t vmin(vbool1_t, vint8m8_t, vint8m8_t, int8_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vmin_vx)))
vint8mf2_t vmin(vint8mf2_t, int8_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vmin_vx_m)))
vint8mf2_t vmin(vbool16_t, vint8mf2_t, vint8mf2_t, int8_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vmin_vx)))
vint8mf4_t vmin(vint8mf4_t, int8_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vmin_vx_m)))
vint8mf4_t vmin(vbool32_t, vint8mf4_t, vint8mf4_t, int8_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vmin_vx)))
vint8mf8_t vmin(vint8mf8_t, int8_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vmin_vx_m)))
vint8mf8_t vmin(vbool64_t, vint8mf8_t, vint8mf8_t, int8_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vmin_vx)))
vint16m1_t vmin(vint16m1_t, int16_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vmin_vx_m)))
vint16m1_t vmin(vbool16_t, vint16m1_t, vint16m1_t, int16_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vmin_vx)))
vint16m2_t vmin(vint16m2_t, int16_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vmin_vx_m)))
vint16m2_t vmin(vbool8_t, vint16m2_t, vint16m2_t, int16_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vmin_vx)))
vint16m4_t vmin(vint16m4_t, int16_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vmin_vx_m)))
vint16m4_t vmin(vbool4_t, vint16m4_t, vint16m4_t, int16_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vmin_vx)))
vint16m8_t vmin(vint16m8_t, int16_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vmin_vx_m)))
vint16m8_t vmin(vbool2_t, vint16m8_t, vint16m8_t, int16_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vmin_vx)))
vint16mf2_t vmin(vint16mf2_t, int16_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vmin_vx_m)))
vint16mf2_t vmin(vbool32_t, vint16mf2_t, vint16mf2_t, int16_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vmin_vx)))
vint16mf4_t vmin(vint16mf4_t, int16_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vmin_vx_m)))
vint16mf4_t vmin(vbool64_t, vint16mf4_t, vint16mf4_t, int16_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vmin_vx)))
vint32m1_t vmin(vint32m1_t, int32_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vmin_vx_m)))
vint32m1_t vmin(vbool32_t, vint32m1_t, vint32m1_t, int32_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vmin_vx)))
vint32m2_t vmin(vint32m2_t, int32_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vmin_vx_m)))
vint32m2_t vmin(vbool16_t, vint32m2_t, vint32m2_t, int32_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vmin_vx)))
vint32m4_t vmin(vint32m4_t, int32_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vmin_vx_m)))
vint32m4_t vmin(vbool8_t, vint32m4_t, vint32m4_t, int32_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vmin_vx)))
vint32m8_t vmin(vint32m8_t, int32_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vmin_vx_m)))
vint32m8_t vmin(vbool4_t, vint32m8_t, vint32m8_t, int32_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vmin_vx)))
vint32mf2_t vmin(vint32mf2_t, int32_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vmin_vx_m)))
vint32mf2_t vmin(vbool64_t, vint32mf2_t, vint32mf2_t, int32_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vmaxu_vv)))
vuint8m1_t vmaxu(vuint8m1_t, vuint8m1_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vmaxu_vv_m)))
vuint8m1_t vmaxu(vbool8_t, vuint8m1_t, vuint8m1_t, vuint8m1_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vmaxu_vv)))
vuint8m2_t vmaxu(vuint8m2_t, vuint8m2_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vmaxu_vv_m)))
vuint8m2_t vmaxu(vbool4_t, vuint8m2_t, vuint8m2_t, vuint8m2_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vmaxu_vv)))
vuint8m4_t vmaxu(vuint8m4_t, vuint8m4_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vmaxu_vv_m)))
vuint8m4_t vmaxu(vbool2_t, vuint8m4_t, vuint8m4_t, vuint8m4_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vmaxu_vv)))
vuint8m8_t vmaxu(vuint8m8_t, vuint8m8_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vmaxu_vv_m)))
vuint8m8_t vmaxu(vbool1_t, vuint8m8_t, vuint8m8_t, vuint8m8_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vmaxu_vv)))
vuint8mf2_t vmaxu(vuint8mf2_t, vuint8mf2_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vmaxu_vv_m)))
vuint8mf2_t vmaxu(vbool16_t, vuint8mf2_t, vuint8mf2_t, vuint8mf2_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vmaxu_vv)))
vuint8mf4_t vmaxu(vuint8mf4_t, vuint8mf4_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vmaxu_vv_m)))
vuint8mf4_t vmaxu(vbool32_t, vuint8mf4_t, vuint8mf4_t, vuint8mf4_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vmaxu_vv)))
vuint8mf8_t vmaxu(vuint8mf8_t, vuint8mf8_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vmaxu_vv_m)))
vuint8mf8_t vmaxu(vbool64_t, vuint8mf8_t, vuint8mf8_t, vuint8mf8_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vmaxu_vv)))
vuint16m1_t vmaxu(vuint16m1_t, vuint16m1_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vmaxu_vv_m)))
vuint16m1_t vmaxu(vbool16_t, vuint16m1_t, vuint16m1_t, vuint16m1_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vmaxu_vv)))
vuint16m2_t vmaxu(vuint16m2_t, vuint16m2_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vmaxu_vv_m)))
vuint16m2_t vmaxu(vbool8_t, vuint16m2_t, vuint16m2_t, vuint16m2_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vmaxu_vv)))
vuint16m4_t vmaxu(vuint16m4_t, vuint16m4_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vmaxu_vv_m)))
vuint16m4_t vmaxu(vbool4_t, vuint16m4_t, vuint16m4_t, vuint16m4_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vmaxu_vv)))
vuint16m8_t vmaxu(vuint16m8_t, vuint16m8_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vmaxu_vv_m)))
vuint16m8_t vmaxu(vbool2_t, vuint16m8_t, vuint16m8_t, vuint16m8_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vmaxu_vv)))
vuint16mf2_t vmaxu(vuint16mf2_t, vuint16mf2_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vmaxu_vv_m)))
vuint16mf2_t vmaxu(vbool32_t, vuint16mf2_t, vuint16mf2_t, vuint16mf2_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vmaxu_vv)))
vuint16mf4_t vmaxu(vuint16mf4_t, vuint16mf4_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vmaxu_vv_m)))
vuint16mf4_t vmaxu(vbool64_t, vuint16mf4_t, vuint16mf4_t, vuint16mf4_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vmaxu_vv)))
vuint32m1_t vmaxu(vuint32m1_t, vuint32m1_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vmaxu_vv_m)))
vuint32m1_t vmaxu(vbool32_t, vuint32m1_t, vuint32m1_t, vuint32m1_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vmaxu_vv)))
vuint32m2_t vmaxu(vuint32m2_t, vuint32m2_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vmaxu_vv_m)))
vuint32m2_t vmaxu(vbool16_t, vuint32m2_t, vuint32m2_t, vuint32m2_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vmaxu_vv)))
vuint32m4_t vmaxu(vuint32m4_t, vuint32m4_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vmaxu_vv_m)))
vuint32m4_t vmaxu(vbool8_t, vuint32m4_t, vuint32m4_t, vuint32m4_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vmaxu_vv)))
vuint32m8_t vmaxu(vuint32m8_t, vuint32m8_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vmaxu_vv_m)))
vuint32m8_t vmaxu(vbool4_t, vuint32m8_t, vuint32m8_t, vuint32m8_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vmaxu_vv)))
vuint32mf2_t vmaxu(vuint32mf2_t, vuint32mf2_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vmaxu_vv_m)))
vuint32mf2_t vmaxu(vbool64_t, vuint32mf2_t, vuint32mf2_t, vuint32mf2_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vmaxu_vx)))
vuint8m1_t vmaxu(vuint8m1_t, uint8_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vmaxu_vx_m)))
vuint8m1_t vmaxu(vbool8_t, vuint8m1_t, vuint8m1_t, uint8_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vmaxu_vx)))
vuint8m2_t vmaxu(vuint8m2_t, uint8_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vmaxu_vx_m)))
vuint8m2_t vmaxu(vbool4_t, vuint8m2_t, vuint8m2_t, uint8_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vmaxu_vx)))
vuint8m4_t vmaxu(vuint8m4_t, uint8_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vmaxu_vx_m)))
vuint8m4_t vmaxu(vbool2_t, vuint8m4_t, vuint8m4_t, uint8_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vmaxu_vx)))
vuint8m8_t vmaxu(vuint8m8_t, uint8_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vmaxu_vx_m)))
vuint8m8_t vmaxu(vbool1_t, vuint8m8_t, vuint8m8_t, uint8_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vmaxu_vx)))
vuint8mf2_t vmaxu(vuint8mf2_t, uint8_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vmaxu_vx_m)))
vuint8mf2_t vmaxu(vbool16_t, vuint8mf2_t, vuint8mf2_t, uint8_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vmaxu_vx)))
vuint8mf4_t vmaxu(vuint8mf4_t, uint8_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vmaxu_vx_m)))
vuint8mf4_t vmaxu(vbool32_t, vuint8mf4_t, vuint8mf4_t, uint8_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vmaxu_vx)))
vuint8mf8_t vmaxu(vuint8mf8_t, uint8_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vmaxu_vx_m)))
vuint8mf8_t vmaxu(vbool64_t, vuint8mf8_t, vuint8mf8_t, uint8_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vmaxu_vx)))
vuint16m1_t vmaxu(vuint16m1_t, uint16_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vmaxu_vx_m)))
vuint16m1_t vmaxu(vbool16_t, vuint16m1_t, vuint16m1_t, uint16_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vmaxu_vx)))
vuint16m2_t vmaxu(vuint16m2_t, uint16_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vmaxu_vx_m)))
vuint16m2_t vmaxu(vbool8_t, vuint16m2_t, vuint16m2_t, uint16_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vmaxu_vx)))
vuint16m4_t vmaxu(vuint16m4_t, uint16_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vmaxu_vx_m)))
vuint16m4_t vmaxu(vbool4_t, vuint16m4_t, vuint16m4_t, uint16_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vmaxu_vx)))
vuint16m8_t vmaxu(vuint16m8_t, uint16_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vmaxu_vx_m)))
vuint16m8_t vmaxu(vbool2_t, vuint16m8_t, vuint16m8_t, uint16_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vmaxu_vx)))
vuint16mf2_t vmaxu(vuint16mf2_t, uint16_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vmaxu_vx_m)))
vuint16mf2_t vmaxu(vbool32_t, vuint16mf2_t, vuint16mf2_t, uint16_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vmaxu_vx)))
vuint16mf4_t vmaxu(vuint16mf4_t, uint16_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vmaxu_vx_m)))
vuint16mf4_t vmaxu(vbool64_t, vuint16mf4_t, vuint16mf4_t, uint16_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vmaxu_vx)))
vuint32m1_t vmaxu(vuint32m1_t, uint32_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vmaxu_vx_m)))
vuint32m1_t vmaxu(vbool32_t, vuint32m1_t, vuint32m1_t, uint32_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vmaxu_vx)))
vuint32m2_t vmaxu(vuint32m2_t, uint32_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vmaxu_vx_m)))
vuint32m2_t vmaxu(vbool16_t, vuint32m2_t, vuint32m2_t, uint32_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vmaxu_vx)))
vuint32m4_t vmaxu(vuint32m4_t, uint32_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vmaxu_vx_m)))
vuint32m4_t vmaxu(vbool8_t, vuint32m4_t, vuint32m4_t, uint32_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vmaxu_vx)))
vuint32m8_t vmaxu(vuint32m8_t, uint32_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vmaxu_vx_m)))
vuint32m8_t vmaxu(vbool4_t, vuint32m8_t, vuint32m8_t, uint32_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vmaxu_vx)))
vuint32mf2_t vmaxu(vuint32mf2_t, uint32_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vmaxu_vx_m)))
vuint32mf2_t vmaxu(vbool64_t, vuint32mf2_t, vuint32mf2_t, uint32_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vmax_vv)))
vint8m1_t vmax(vint8m1_t, vint8m1_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vmax_vv_m)))
vint8m1_t vmax(vbool8_t, vint8m1_t, vint8m1_t, vint8m1_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vmax_vv)))
vint8m2_t vmax(vint8m2_t, vint8m2_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vmax_vv_m)))
vint8m2_t vmax(vbool4_t, vint8m2_t, vint8m2_t, vint8m2_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vmax_vv)))
vint8m4_t vmax(vint8m4_t, vint8m4_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vmax_vv_m)))
vint8m4_t vmax(vbool2_t, vint8m4_t, vint8m4_t, vint8m4_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vmax_vv)))
vint8m8_t vmax(vint8m8_t, vint8m8_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vmax_vv_m)))
vint8m8_t vmax(vbool1_t, vint8m8_t, vint8m8_t, vint8m8_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vmax_vv)))
vint8mf2_t vmax(vint8mf2_t, vint8mf2_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vmax_vv_m)))
vint8mf2_t vmax(vbool16_t, vint8mf2_t, vint8mf2_t, vint8mf2_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vmax_vv)))
vint8mf4_t vmax(vint8mf4_t, vint8mf4_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vmax_vv_m)))
vint8mf4_t vmax(vbool32_t, vint8mf4_t, vint8mf4_t, vint8mf4_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vmax_vv)))
vint8mf8_t vmax(vint8mf8_t, vint8mf8_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vmax_vv_m)))
vint8mf8_t vmax(vbool64_t, vint8mf8_t, vint8mf8_t, vint8mf8_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vmax_vv)))
vint16m1_t vmax(vint16m1_t, vint16m1_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vmax_vv_m)))
vint16m1_t vmax(vbool16_t, vint16m1_t, vint16m1_t, vint16m1_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vmax_vv)))
vint16m2_t vmax(vint16m2_t, vint16m2_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vmax_vv_m)))
vint16m2_t vmax(vbool8_t, vint16m2_t, vint16m2_t, vint16m2_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vmax_vv)))
vint16m4_t vmax(vint16m4_t, vint16m4_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vmax_vv_m)))
vint16m4_t vmax(vbool4_t, vint16m4_t, vint16m4_t, vint16m4_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vmax_vv)))
vint16m8_t vmax(vint16m8_t, vint16m8_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vmax_vv_m)))
vint16m8_t vmax(vbool2_t, vint16m8_t, vint16m8_t, vint16m8_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vmax_vv)))
vint16mf2_t vmax(vint16mf2_t, vint16mf2_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vmax_vv_m)))
vint16mf2_t vmax(vbool32_t, vint16mf2_t, vint16mf2_t, vint16mf2_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vmax_vv)))
vint16mf4_t vmax(vint16mf4_t, vint16mf4_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vmax_vv_m)))
vint16mf4_t vmax(vbool64_t, vint16mf4_t, vint16mf4_t, vint16mf4_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vmax_vv)))
vint32m1_t vmax(vint32m1_t, vint32m1_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vmax_vv_m)))
vint32m1_t vmax(vbool32_t, vint32m1_t, vint32m1_t, vint32m1_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vmax_vv)))
vint32m2_t vmax(vint32m2_t, vint32m2_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vmax_vv_m)))
vint32m2_t vmax(vbool16_t, vint32m2_t, vint32m2_t, vint32m2_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vmax_vv)))
vint32m4_t vmax(vint32m4_t, vint32m4_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vmax_vv_m)))
vint32m4_t vmax(vbool8_t, vint32m4_t, vint32m4_t, vint32m4_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vmax_vv)))
vint32m8_t vmax(vint32m8_t, vint32m8_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vmax_vv_m)))
vint32m8_t vmax(vbool4_t, vint32m8_t, vint32m8_t, vint32m8_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vmax_vv)))
vint32mf2_t vmax(vint32mf2_t, vint32mf2_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vmax_vv_m)))
vint32mf2_t vmax(vbool64_t, vint32mf2_t, vint32mf2_t, vint32mf2_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vsuxei16_v)))
void vsuxei16(uint8_t *, vuint16m2_t, vuint8m1_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vsuxei16_v_m)))
void vsuxei16(vbool8_t, uint8_t *, vuint16m2_t, vuint8m1_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vsuxei16_v)))
void vsuxei16(uint8_t *, vuint16m4_t, vuint8m2_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vsuxei16_v_m)))
void vsuxei16(vbool4_t, uint8_t *, vuint16m4_t, vuint8m2_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vsuxei16_v)))
void vsuxei16(uint8_t *, vuint16m8_t, vuint8m4_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vsuxei16_v_m)))
void vsuxei16(vbool2_t, uint8_t *, vuint16m8_t, vuint8m4_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vsuxei16_v)))
void vsuxei16(uint8_t *, vuint16m1_t, vuint8mf2_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vsuxei16_v_m)))
void vsuxei16(vbool16_t, uint8_t *, vuint16m1_t, vuint8mf2_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vsuxei16_v)))
void vsuxei16(uint8_t *, vuint16mf2_t, vuint8mf4_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vsuxei16_v_m)))
void vsuxei16(vbool32_t, uint8_t *, vuint16mf2_t, vuint8mf4_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vsuxei16_v)))
void vsuxei16(uint8_t *, vuint16mf4_t, vuint8mf8_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vsuxei16_v_m)))
void vsuxei16(vbool64_t, uint8_t *, vuint16mf4_t, vuint8mf8_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vmax_vx)))
vint8m1_t vmax(vint8m1_t, int8_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vmax_vx_m)))
vint8m1_t vmax(vbool8_t, vint8m1_t, vint8m1_t, int8_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vmax_vx)))
vint8m2_t vmax(vint8m2_t, int8_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vmax_vx_m)))
vint8m2_t vmax(vbool4_t, vint8m2_t, vint8m2_t, int8_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vmax_vx)))
vint8m4_t vmax(vint8m4_t, int8_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vmax_vx_m)))
vint8m4_t vmax(vbool2_t, vint8m4_t, vint8m4_t, int8_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vmax_vx)))
vint8m8_t vmax(vint8m8_t, int8_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vmax_vx_m)))
vint8m8_t vmax(vbool1_t, vint8m8_t, vint8m8_t, int8_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vmax_vx)))
vint8mf2_t vmax(vint8mf2_t, int8_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vmax_vx_m)))
vint8mf2_t vmax(vbool16_t, vint8mf2_t, vint8mf2_t, int8_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vmax_vx)))
vint8mf4_t vmax(vint8mf4_t, int8_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vmax_vx_m)))
vint8mf4_t vmax(vbool32_t, vint8mf4_t, vint8mf4_t, int8_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vmax_vx)))
vint8mf8_t vmax(vint8mf8_t, int8_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vmax_vx_m)))
vint8mf8_t vmax(vbool64_t, vint8mf8_t, vint8mf8_t, int8_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vmax_vx)))
vint16m1_t vmax(vint16m1_t, int16_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vmax_vx_m)))
vint16m1_t vmax(vbool16_t, vint16m1_t, vint16m1_t, int16_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vmax_vx)))
vint16m2_t vmax(vint16m2_t, int16_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vmax_vx_m)))
vint16m2_t vmax(vbool8_t, vint16m2_t, vint16m2_t, int16_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vmax_vx)))
vint16m4_t vmax(vint16m4_t, int16_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vmax_vx_m)))
vint16m4_t vmax(vbool4_t, vint16m4_t, vint16m4_t, int16_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vmax_vx)))
vint16m8_t vmax(vint16m8_t, int16_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vmax_vx_m)))
vint16m8_t vmax(vbool2_t, vint16m8_t, vint16m8_t, int16_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vmax_vx)))
vint16mf2_t vmax(vint16mf2_t, int16_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vmax_vx_m)))
vint16mf2_t vmax(vbool32_t, vint16mf2_t, vint16mf2_t, int16_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vmax_vx)))
vint16mf4_t vmax(vint16mf4_t, int16_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vmax_vx_m)))
vint16mf4_t vmax(vbool64_t, vint16mf4_t, vint16mf4_t, int16_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vmax_vx)))
vint32m1_t vmax(vint32m1_t, int32_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vmax_vx_m)))
vint32m1_t vmax(vbool32_t, vint32m1_t, vint32m1_t, int32_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vmax_vx)))
vint32m2_t vmax(vint32m2_t, int32_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vmax_vx_m)))
vint32m2_t vmax(vbool16_t, vint32m2_t, vint32m2_t, int32_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vmax_vx)))
vint32m4_t vmax(vint32m4_t, int32_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vmax_vx_m)))
vint32m4_t vmax(vbool8_t, vint32m4_t, vint32m4_t, int32_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vmax_vx)))
vint32m8_t vmax(vint32m8_t, int32_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vmax_vx_m)))
vint32m8_t vmax(vbool4_t, vint32m8_t, vint32m8_t, int32_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vmax_vx)))
vint32mf2_t vmax(vint32mf2_t, int32_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vmax_vx_m)))
vint32mf2_t vmax(vbool64_t, vint32mf2_t, vint32mf2_t, int32_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vmul_vv)))
vint8m1_t vmul(vint8m1_t, vint8m1_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vmul_vv_m)))
vint8m1_t vmul(vbool8_t, vint8m1_t, vint8m1_t, vint8m1_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vmul_vv)))
vint8m2_t vmul(vint8m2_t, vint8m2_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vmul_vv_m)))
vint8m2_t vmul(vbool4_t, vint8m2_t, vint8m2_t, vint8m2_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vmul_vv)))
vint8m4_t vmul(vint8m4_t, vint8m4_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vmul_vv_m)))
vint8m4_t vmul(vbool2_t, vint8m4_t, vint8m4_t, vint8m4_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vmul_vv)))
vint8m8_t vmul(vint8m8_t, vint8m8_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vmul_vv_m)))
vint8m8_t vmul(vbool1_t, vint8m8_t, vint8m8_t, vint8m8_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vmul_vv)))
vint8mf2_t vmul(vint8mf2_t, vint8mf2_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vmul_vv_m)))
vint8mf2_t vmul(vbool16_t, vint8mf2_t, vint8mf2_t, vint8mf2_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vmul_vv)))
vint8mf4_t vmul(vint8mf4_t, vint8mf4_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vmul_vv_m)))
vint8mf4_t vmul(vbool32_t, vint8mf4_t, vint8mf4_t, vint8mf4_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vmul_vv)))
vint8mf8_t vmul(vint8mf8_t, vint8mf8_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vmul_vv_m)))
vint8mf8_t vmul(vbool64_t, vint8mf8_t, vint8mf8_t, vint8mf8_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vmul_vv)))
vint16m1_t vmul(vint16m1_t, vint16m1_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vmul_vv_m)))
vint16m1_t vmul(vbool16_t, vint16m1_t, vint16m1_t, vint16m1_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vmul_vv)))
vint16m2_t vmul(vint16m2_t, vint16m2_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vmul_vv_m)))
vint16m2_t vmul(vbool8_t, vint16m2_t, vint16m2_t, vint16m2_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vmul_vv)))
vint16m4_t vmul(vint16m4_t, vint16m4_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vmul_vv_m)))
vint16m4_t vmul(vbool4_t, vint16m4_t, vint16m4_t, vint16m4_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vmul_vv)))
vint16m8_t vmul(vint16m8_t, vint16m8_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vmul_vv_m)))
vint16m8_t vmul(vbool2_t, vint16m8_t, vint16m8_t, vint16m8_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vmul_vv)))
vint16mf2_t vmul(vint16mf2_t, vint16mf2_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vmul_vv_m)))
vint16mf2_t vmul(vbool32_t, vint16mf2_t, vint16mf2_t, vint16mf2_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vmul_vv)))
vint16mf4_t vmul(vint16mf4_t, vint16mf4_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vmul_vv_m)))
vint16mf4_t vmul(vbool64_t, vint16mf4_t, vint16mf4_t, vint16mf4_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vmul_vv)))
vint32m1_t vmul(vint32m1_t, vint32m1_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vmul_vv_m)))
vint32m1_t vmul(vbool32_t, vint32m1_t, vint32m1_t, vint32m1_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vmul_vv)))
vint32m2_t vmul(vint32m2_t, vint32m2_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vmul_vv_m)))
vint32m2_t vmul(vbool16_t, vint32m2_t, vint32m2_t, vint32m2_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vmul_vv)))
vint32m4_t vmul(vint32m4_t, vint32m4_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vmul_vv_m)))
vint32m4_t vmul(vbool8_t, vint32m4_t, vint32m4_t, vint32m4_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vmul_vv)))
vint32m8_t vmul(vint32m8_t, vint32m8_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vmul_vv_m)))
vint32m8_t vmul(vbool4_t, vint32m8_t, vint32m8_t, vint32m8_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vmul_vv)))
vint32mf2_t vmul(vint32mf2_t, vint32mf2_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vmul_vv_m)))
vint32mf2_t vmul(vbool64_t, vint32mf2_t, vint32mf2_t, vint32mf2_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vmul_vx)))
vint8m1_t vmul(vint8m1_t, int8_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vmul_vx_m)))
vint8m1_t vmul(vbool8_t, vint8m1_t, vint8m1_t, int8_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vmul_vx)))
vint8m2_t vmul(vint8m2_t, int8_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vmul_vx_m)))
vint8m2_t vmul(vbool4_t, vint8m2_t, vint8m2_t, int8_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vmul_vx)))
vint8m4_t vmul(vint8m4_t, int8_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vmul_vx_m)))
vint8m4_t vmul(vbool2_t, vint8m4_t, vint8m4_t, int8_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vmul_vx)))
vint8m8_t vmul(vint8m8_t, int8_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vmul_vx_m)))
vint8m8_t vmul(vbool1_t, vint8m8_t, vint8m8_t, int8_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vmul_vx)))
vint8mf2_t vmul(vint8mf2_t, int8_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vmul_vx_m)))
vint8mf2_t vmul(vbool16_t, vint8mf2_t, vint8mf2_t, int8_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vmul_vx)))
vint8mf4_t vmul(vint8mf4_t, int8_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vmul_vx_m)))
vint8mf4_t vmul(vbool32_t, vint8mf4_t, vint8mf4_t, int8_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vmul_vx)))
vint8mf8_t vmul(vint8mf8_t, int8_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vmul_vx_m)))
vint8mf8_t vmul(vbool64_t, vint8mf8_t, vint8mf8_t, int8_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vmul_vx)))
vint16m1_t vmul(vint16m1_t, int16_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vmul_vx_m)))
vint16m1_t vmul(vbool16_t, vint16m1_t, vint16m1_t, int16_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vmul_vx)))
vint16m2_t vmul(vint16m2_t, int16_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vmul_vx_m)))
vint16m2_t vmul(vbool8_t, vint16m2_t, vint16m2_t, int16_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vmul_vx)))
vint16m4_t vmul(vint16m4_t, int16_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vmul_vx_m)))
vint16m4_t vmul(vbool4_t, vint16m4_t, vint16m4_t, int16_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vmul_vx)))
vint16m8_t vmul(vint16m8_t, int16_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vmul_vx_m)))
vint16m8_t vmul(vbool2_t, vint16m8_t, vint16m8_t, int16_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vmul_vx)))
vint16mf2_t vmul(vint16mf2_t, int16_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vmul_vx_m)))
vint16mf2_t vmul(vbool32_t, vint16mf2_t, vint16mf2_t, int16_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vmul_vx)))
vint16mf4_t vmul(vint16mf4_t, int16_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vmul_vx_m)))
vint16mf4_t vmul(vbool64_t, vint16mf4_t, vint16mf4_t, int16_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vmul_vx)))
vint32m1_t vmul(vint32m1_t, int32_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vmul_vx_m)))
vint32m1_t vmul(vbool32_t, vint32m1_t, vint32m1_t, int32_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vmul_vx)))
vint32m2_t vmul(vint32m2_t, int32_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vmul_vx_m)))
vint32m2_t vmul(vbool16_t, vint32m2_t, vint32m2_t, int32_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vmul_vx)))
vint32m4_t vmul(vint32m4_t, int32_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vmul_vx_m)))
vint32m4_t vmul(vbool8_t, vint32m4_t, vint32m4_t, int32_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vmul_vx)))
vint32m8_t vmul(vint32m8_t, int32_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vmul_vx_m)))
vint32m8_t vmul(vbool4_t, vint32m8_t, vint32m8_t, int32_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vmul_vx)))
vint32mf2_t vmul(vint32mf2_t, int32_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vmul_vx_m)))
vint32mf2_t vmul(vbool64_t, vint32mf2_t, vint32mf2_t, int32_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vmul_vv)))
vuint8m1_t vmul(vuint8m1_t, vuint8m1_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vmul_vv_m)))
vuint8m1_t vmul(vbool8_t, vuint8m1_t, vuint8m1_t, vuint8m1_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vmul_vv)))
vuint8m2_t vmul(vuint8m2_t, vuint8m2_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vmul_vv_m)))
vuint8m2_t vmul(vbool4_t, vuint8m2_t, vuint8m2_t, vuint8m2_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vmul_vv)))
vuint8m4_t vmul(vuint8m4_t, vuint8m4_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vmul_vv_m)))
vuint8m4_t vmul(vbool2_t, vuint8m4_t, vuint8m4_t, vuint8m4_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vmul_vv)))
vuint8m8_t vmul(vuint8m8_t, vuint8m8_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vmul_vv_m)))
vuint8m8_t vmul(vbool1_t, vuint8m8_t, vuint8m8_t, vuint8m8_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vmul_vv)))
vuint8mf2_t vmul(vuint8mf2_t, vuint8mf2_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vmul_vv_m)))
vuint8mf2_t vmul(vbool16_t, vuint8mf2_t, vuint8mf2_t, vuint8mf2_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vmul_vv)))
vuint8mf4_t vmul(vuint8mf4_t, vuint8mf4_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vmul_vv_m)))
vuint8mf4_t vmul(vbool32_t, vuint8mf4_t, vuint8mf4_t, vuint8mf4_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vmul_vv)))
vuint8mf8_t vmul(vuint8mf8_t, vuint8mf8_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vmul_vv_m)))
vuint8mf8_t vmul(vbool64_t, vuint8mf8_t, vuint8mf8_t, vuint8mf8_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vmul_vv)))
vuint16m1_t vmul(vuint16m1_t, vuint16m1_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vmul_vv_m)))
vuint16m1_t vmul(vbool16_t, vuint16m1_t, vuint16m1_t, vuint16m1_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vmul_vv)))
vuint16m2_t vmul(vuint16m2_t, vuint16m2_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vmul_vv_m)))
vuint16m2_t vmul(vbool8_t, vuint16m2_t, vuint16m2_t, vuint16m2_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vmul_vv)))
vuint16m4_t vmul(vuint16m4_t, vuint16m4_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vmul_vv_m)))
vuint16m4_t vmul(vbool4_t, vuint16m4_t, vuint16m4_t, vuint16m4_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vmul_vv)))
vuint16m8_t vmul(vuint16m8_t, vuint16m8_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vmul_vv_m)))
vuint16m8_t vmul(vbool2_t, vuint16m8_t, vuint16m8_t, vuint16m8_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vmul_vv)))
vuint16mf2_t vmul(vuint16mf2_t, vuint16mf2_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vmul_vv_m)))
vuint16mf2_t vmul(vbool32_t, vuint16mf2_t, vuint16mf2_t, vuint16mf2_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vmul_vv)))
vuint16mf4_t vmul(vuint16mf4_t, vuint16mf4_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vmul_vv_m)))
vuint16mf4_t vmul(vbool64_t, vuint16mf4_t, vuint16mf4_t, vuint16mf4_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vmul_vv)))
vuint32m1_t vmul(vuint32m1_t, vuint32m1_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vmul_vv_m)))
vuint32m1_t vmul(vbool32_t, vuint32m1_t, vuint32m1_t, vuint32m1_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vmul_vv)))
vuint32m2_t vmul(vuint32m2_t, vuint32m2_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vmul_vv_m)))
vuint32m2_t vmul(vbool16_t, vuint32m2_t, vuint32m2_t, vuint32m2_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vmul_vv)))
vuint32m4_t vmul(vuint32m4_t, vuint32m4_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vmul_vv_m)))
vuint32m4_t vmul(vbool8_t, vuint32m4_t, vuint32m4_t, vuint32m4_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vmul_vv)))
vuint32m8_t vmul(vuint32m8_t, vuint32m8_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vmul_vv_m)))
vuint32m8_t vmul(vbool4_t, vuint32m8_t, vuint32m8_t, vuint32m8_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vmul_vv)))
vuint32mf2_t vmul(vuint32mf2_t, vuint32mf2_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vmul_vv_m)))
vuint32mf2_t vmul(vbool64_t, vuint32mf2_t, vuint32mf2_t, vuint32mf2_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vmul_vx)))
vuint8m1_t vmul(vuint8m1_t, uint8_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vmul_vx_m)))
vuint8m1_t vmul(vbool8_t, vuint8m1_t, vuint8m1_t, uint8_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vmul_vx)))
vuint8m2_t vmul(vuint8m2_t, uint8_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vmul_vx_m)))
vuint8m2_t vmul(vbool4_t, vuint8m2_t, vuint8m2_t, uint8_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vmul_vx)))
vuint8m4_t vmul(vuint8m4_t, uint8_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vmul_vx_m)))
vuint8m4_t vmul(vbool2_t, vuint8m4_t, vuint8m4_t, uint8_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vmul_vx)))
vuint8m8_t vmul(vuint8m8_t, uint8_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vmul_vx_m)))
vuint8m8_t vmul(vbool1_t, vuint8m8_t, vuint8m8_t, uint8_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vmul_vx)))
vuint8mf2_t vmul(vuint8mf2_t, uint8_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vmul_vx_m)))
vuint8mf2_t vmul(vbool16_t, vuint8mf2_t, vuint8mf2_t, uint8_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vmul_vx)))
vuint8mf4_t vmul(vuint8mf4_t, uint8_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vmul_vx_m)))
vuint8mf4_t vmul(vbool32_t, vuint8mf4_t, vuint8mf4_t, uint8_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vmul_vx)))
vuint8mf8_t vmul(vuint8mf8_t, uint8_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vmul_vx_m)))
vuint8mf8_t vmul(vbool64_t, vuint8mf8_t, vuint8mf8_t, uint8_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vmul_vx)))
vuint16m1_t vmul(vuint16m1_t, uint16_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vmul_vx_m)))
vuint16m1_t vmul(vbool16_t, vuint16m1_t, vuint16m1_t, uint16_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vmul_vx)))
vuint16m2_t vmul(vuint16m2_t, uint16_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vmul_vx_m)))
vuint16m2_t vmul(vbool8_t, vuint16m2_t, vuint16m2_t, uint16_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vmul_vx)))
vuint16m4_t vmul(vuint16m4_t, uint16_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vmul_vx_m)))
vuint16m4_t vmul(vbool4_t, vuint16m4_t, vuint16m4_t, uint16_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vmul_vx)))
vuint16m8_t vmul(vuint16m8_t, uint16_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vmul_vx_m)))
vuint16m8_t vmul(vbool2_t, vuint16m8_t, vuint16m8_t, uint16_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vmul_vx)))
vuint16mf2_t vmul(vuint16mf2_t, uint16_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vmul_vx_m)))
vuint16mf2_t vmul(vbool32_t, vuint16mf2_t, vuint16mf2_t, uint16_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vmul_vx)))
vuint16mf4_t vmul(vuint16mf4_t, uint16_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vmul_vx_m)))
vuint16mf4_t vmul(vbool64_t, vuint16mf4_t, vuint16mf4_t, uint16_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vmul_vx)))
vuint32m1_t vmul(vuint32m1_t, uint32_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vmul_vx_m)))
vuint32m1_t vmul(vbool32_t, vuint32m1_t, vuint32m1_t, uint32_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vmul_vx)))
vuint32m2_t vmul(vuint32m2_t, uint32_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vmul_vx_m)))
vuint32m2_t vmul(vbool16_t, vuint32m2_t, vuint32m2_t, uint32_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vmul_vx)))
vuint32m4_t vmul(vuint32m4_t, uint32_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vmul_vx_m)))
vuint32m4_t vmul(vbool8_t, vuint32m4_t, vuint32m4_t, uint32_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vmul_vx)))
vuint32m8_t vmul(vuint32m8_t, uint32_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vmul_vx_m)))
vuint32m8_t vmul(vbool4_t, vuint32m8_t, vuint32m8_t, uint32_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vmul_vx)))
vuint32mf2_t vmul(vuint32mf2_t, uint32_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vmul_vx_m)))
vuint32mf2_t vmul(vbool64_t, vuint32mf2_t, vuint32mf2_t, uint32_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vmulh_vv)))
vint8m1_t vmulh(vint8m1_t, vint8m1_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vmulh_vv_m)))
vint8m1_t vmulh(vbool8_t, vint8m1_t, vint8m1_t, vint8m1_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vmulh_vv)))
vint8m2_t vmulh(vint8m2_t, vint8m2_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vmulh_vv_m)))
vint8m2_t vmulh(vbool4_t, vint8m2_t, vint8m2_t, vint8m2_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vmulh_vv)))
vint8m4_t vmulh(vint8m4_t, vint8m4_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vmulh_vv_m)))
vint8m4_t vmulh(vbool2_t, vint8m4_t, vint8m4_t, vint8m4_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vmulh_vv)))
vint8m8_t vmulh(vint8m8_t, vint8m8_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vmulh_vv_m)))
vint8m8_t vmulh(vbool1_t, vint8m8_t, vint8m8_t, vint8m8_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vmulh_vv)))
vint8mf2_t vmulh(vint8mf2_t, vint8mf2_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vmulh_vv_m)))
vint8mf2_t vmulh(vbool16_t, vint8mf2_t, vint8mf2_t, vint8mf2_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vmulh_vv)))
vint8mf4_t vmulh(vint8mf4_t, vint8mf4_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vmulh_vv_m)))
vint8mf4_t vmulh(vbool32_t, vint8mf4_t, vint8mf4_t, vint8mf4_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vmulh_vv)))
vint8mf8_t vmulh(vint8mf8_t, vint8mf8_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vmulh_vv_m)))
vint8mf8_t vmulh(vbool64_t, vint8mf8_t, vint8mf8_t, vint8mf8_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vmulh_vv)))
vint16m1_t vmulh(vint16m1_t, vint16m1_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vmulh_vv_m)))
vint16m1_t vmulh(vbool16_t, vint16m1_t, vint16m1_t, vint16m1_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vmulh_vv)))
vint16m2_t vmulh(vint16m2_t, vint16m2_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vmulh_vv_m)))
vint16m2_t vmulh(vbool8_t, vint16m2_t, vint16m2_t, vint16m2_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vmulh_vv)))
vint16m4_t vmulh(vint16m4_t, vint16m4_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vmulh_vv_m)))
vint16m4_t vmulh(vbool4_t, vint16m4_t, vint16m4_t, vint16m4_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vmulh_vv)))
vint16m8_t vmulh(vint16m8_t, vint16m8_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vmulh_vv_m)))
vint16m8_t vmulh(vbool2_t, vint16m8_t, vint16m8_t, vint16m8_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vmulh_vv)))
vint16mf2_t vmulh(vint16mf2_t, vint16mf2_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vmulh_vv_m)))
vint16mf2_t vmulh(vbool32_t, vint16mf2_t, vint16mf2_t, vint16mf2_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vmulh_vv)))
vint16mf4_t vmulh(vint16mf4_t, vint16mf4_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vmulh_vv_m)))
vint16mf4_t vmulh(vbool64_t, vint16mf4_t, vint16mf4_t, vint16mf4_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vmulh_vv)))
vint32m1_t vmulh(vint32m1_t, vint32m1_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vmulh_vv_m)))
vint32m1_t vmulh(vbool32_t, vint32m1_t, vint32m1_t, vint32m1_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vmulh_vv)))
vint32m2_t vmulh(vint32m2_t, vint32m2_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vmulh_vv_m)))
vint32m2_t vmulh(vbool16_t, vint32m2_t, vint32m2_t, vint32m2_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vmulh_vv)))
vint32m4_t vmulh(vint32m4_t, vint32m4_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vmulh_vv_m)))
vint32m4_t vmulh(vbool8_t, vint32m4_t, vint32m4_t, vint32m4_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vmulh_vv)))
vint32m8_t vmulh(vint32m8_t, vint32m8_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vmulh_vv_m)))
vint32m8_t vmulh(vbool4_t, vint32m8_t, vint32m8_t, vint32m8_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vmulh_vv)))
vint32mf2_t vmulh(vint32mf2_t, vint32mf2_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vmulh_vv_m)))
vint32mf2_t vmulh(vbool64_t, vint32mf2_t, vint32mf2_t, vint32mf2_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vmulh_vx)))
vint8m1_t vmulh(vint8m1_t, int8_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vmulh_vx_m)))
vint8m1_t vmulh(vbool8_t, vint8m1_t, vint8m1_t, int8_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vmulh_vx)))
vint8m2_t vmulh(vint8m2_t, int8_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vmulh_vx_m)))
vint8m2_t vmulh(vbool4_t, vint8m2_t, vint8m2_t, int8_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vmulh_vx)))
vint8m4_t vmulh(vint8m4_t, int8_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vmulh_vx_m)))
vint8m4_t vmulh(vbool2_t, vint8m4_t, vint8m4_t, int8_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vmulh_vx)))
vint8m8_t vmulh(vint8m8_t, int8_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vmulh_vx_m)))
vint8m8_t vmulh(vbool1_t, vint8m8_t, vint8m8_t, int8_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vmulh_vx)))
vint8mf2_t vmulh(vint8mf2_t, int8_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vmulh_vx_m)))
vint8mf2_t vmulh(vbool16_t, vint8mf2_t, vint8mf2_t, int8_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vmulh_vx)))
vint8mf4_t vmulh(vint8mf4_t, int8_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vmulh_vx_m)))
vint8mf4_t vmulh(vbool32_t, vint8mf4_t, vint8mf4_t, int8_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vmulh_vx)))
vint8mf8_t vmulh(vint8mf8_t, int8_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vmulh_vx_m)))
vint8mf8_t vmulh(vbool64_t, vint8mf8_t, vint8mf8_t, int8_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vmulh_vx)))
vint16m1_t vmulh(vint16m1_t, int16_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vmulh_vx_m)))
vint16m1_t vmulh(vbool16_t, vint16m1_t, vint16m1_t, int16_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vmulh_vx)))
vint16m2_t vmulh(vint16m2_t, int16_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vmulh_vx_m)))
vint16m2_t vmulh(vbool8_t, vint16m2_t, vint16m2_t, int16_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vmulh_vx)))
vint16m4_t vmulh(vint16m4_t, int16_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vmulh_vx_m)))
vint16m4_t vmulh(vbool4_t, vint16m4_t, vint16m4_t, int16_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vmulh_vx)))
vint16m8_t vmulh(vint16m8_t, int16_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vmulh_vx_m)))
vint16m8_t vmulh(vbool2_t, vint16m8_t, vint16m8_t, int16_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vmulh_vx)))
vint16mf2_t vmulh(vint16mf2_t, int16_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vmulh_vx_m)))
vint16mf2_t vmulh(vbool32_t, vint16mf2_t, vint16mf2_t, int16_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vmulh_vx)))
vint16mf4_t vmulh(vint16mf4_t, int16_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vmulh_vx_m)))
vint16mf4_t vmulh(vbool64_t, vint16mf4_t, vint16mf4_t, int16_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vmulh_vx)))
vint32m1_t vmulh(vint32m1_t, int32_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vmulh_vx_m)))
vint32m1_t vmulh(vbool32_t, vint32m1_t, vint32m1_t, int32_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vmulh_vx)))
vint32m2_t vmulh(vint32m2_t, int32_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vmulh_vx_m)))
vint32m2_t vmulh(vbool16_t, vint32m2_t, vint32m2_t, int32_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vmulh_vx)))
vint32m4_t vmulh(vint32m4_t, int32_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vmulh_vx_m)))
vint32m4_t vmulh(vbool8_t, vint32m4_t, vint32m4_t, int32_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vmulh_vx)))
vint32m8_t vmulh(vint32m8_t, int32_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vmulh_vx_m)))
vint32m8_t vmulh(vbool4_t, vint32m8_t, vint32m8_t, int32_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vmulh_vx)))
vint32mf2_t vmulh(vint32mf2_t, int32_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vmulh_vx_m)))
vint32mf2_t vmulh(vbool64_t, vint32mf2_t, vint32mf2_t, int32_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vmulhu_vv)))
vuint8m1_t vmulhu(vuint8m1_t, vuint8m1_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vmulhu_vv_m)))
vuint8m1_t vmulhu(vbool8_t, vuint8m1_t, vuint8m1_t, vuint8m1_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vmulhu_vv)))
vuint8m2_t vmulhu(vuint8m2_t, vuint8m2_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vmulhu_vv_m)))
vuint8m2_t vmulhu(vbool4_t, vuint8m2_t, vuint8m2_t, vuint8m2_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vmulhu_vv)))
vuint8m4_t vmulhu(vuint8m4_t, vuint8m4_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vmulhu_vv_m)))
vuint8m4_t vmulhu(vbool2_t, vuint8m4_t, vuint8m4_t, vuint8m4_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vmulhu_vv)))
vuint8m8_t vmulhu(vuint8m8_t, vuint8m8_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vmulhu_vv_m)))
vuint8m8_t vmulhu(vbool1_t, vuint8m8_t, vuint8m8_t, vuint8m8_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vmulhu_vv)))
vuint8mf2_t vmulhu(vuint8mf2_t, vuint8mf2_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vmulhu_vv_m)))
vuint8mf2_t vmulhu(vbool16_t, vuint8mf2_t, vuint8mf2_t, vuint8mf2_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vmulhu_vv)))
vuint8mf4_t vmulhu(vuint8mf4_t, vuint8mf4_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vmulhu_vv_m)))
vuint8mf4_t vmulhu(vbool32_t, vuint8mf4_t, vuint8mf4_t, vuint8mf4_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vmulhu_vv)))
vuint8mf8_t vmulhu(vuint8mf8_t, vuint8mf8_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vmulhu_vv_m)))
vuint8mf8_t vmulhu(vbool64_t, vuint8mf8_t, vuint8mf8_t, vuint8mf8_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vmulhu_vv)))
vuint16m1_t vmulhu(vuint16m1_t, vuint16m1_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vmulhu_vv_m)))
vuint16m1_t vmulhu(vbool16_t, vuint16m1_t, vuint16m1_t, vuint16m1_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vmulhu_vv)))
vuint16m2_t vmulhu(vuint16m2_t, vuint16m2_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vmulhu_vv_m)))
vuint16m2_t vmulhu(vbool8_t, vuint16m2_t, vuint16m2_t, vuint16m2_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vmulhu_vv)))
vuint16m4_t vmulhu(vuint16m4_t, vuint16m4_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vmulhu_vv_m)))
vuint16m4_t vmulhu(vbool4_t, vuint16m4_t, vuint16m4_t, vuint16m4_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vmulhu_vv)))
vuint16m8_t vmulhu(vuint16m8_t, vuint16m8_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vmulhu_vv_m)))
vuint16m8_t vmulhu(vbool2_t, vuint16m8_t, vuint16m8_t, vuint16m8_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vmulhu_vv)))
vuint16mf2_t vmulhu(vuint16mf2_t, vuint16mf2_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vmulhu_vv_m)))
vuint16mf2_t vmulhu(vbool32_t, vuint16mf2_t, vuint16mf2_t, vuint16mf2_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vmulhu_vv)))
vuint16mf4_t vmulhu(vuint16mf4_t, vuint16mf4_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vmulhu_vv_m)))
vuint16mf4_t vmulhu(vbool64_t, vuint16mf4_t, vuint16mf4_t, vuint16mf4_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vmulhu_vv)))
vuint32m1_t vmulhu(vuint32m1_t, vuint32m1_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vmulhu_vv_m)))
vuint32m1_t vmulhu(vbool32_t, vuint32m1_t, vuint32m1_t, vuint32m1_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vmulhu_vv)))
vuint32m2_t vmulhu(vuint32m2_t, vuint32m2_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vmulhu_vv_m)))
vuint32m2_t vmulhu(vbool16_t, vuint32m2_t, vuint32m2_t, vuint32m2_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vmulhu_vv)))
vuint32m4_t vmulhu(vuint32m4_t, vuint32m4_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vmulhu_vv_m)))
vuint32m4_t vmulhu(vbool8_t, vuint32m4_t, vuint32m4_t, vuint32m4_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vmulhu_vv)))
vuint32m8_t vmulhu(vuint32m8_t, vuint32m8_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vmulhu_vv_m)))
vuint32m8_t vmulhu(vbool4_t, vuint32m8_t, vuint32m8_t, vuint32m8_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vmulhu_vv)))
vuint32mf2_t vmulhu(vuint32mf2_t, vuint32mf2_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vmulhu_vv_m)))
vuint32mf2_t vmulhu(vbool64_t, vuint32mf2_t, vuint32mf2_t, vuint32mf2_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vmulhu_vx)))
vuint8m1_t vmulhu(vuint8m1_t, uint8_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vmulhu_vx_m)))
vuint8m1_t vmulhu(vbool8_t, vuint8m1_t, vuint8m1_t, uint8_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vmulhu_vx)))
vuint8m2_t vmulhu(vuint8m2_t, uint8_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vmulhu_vx_m)))
vuint8m2_t vmulhu(vbool4_t, vuint8m2_t, vuint8m2_t, uint8_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vmulhu_vx)))
vuint8m4_t vmulhu(vuint8m4_t, uint8_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vmulhu_vx_m)))
vuint8m4_t vmulhu(vbool2_t, vuint8m4_t, vuint8m4_t, uint8_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vmulhu_vx)))
vuint8m8_t vmulhu(vuint8m8_t, uint8_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vmulhu_vx_m)))
vuint8m8_t vmulhu(vbool1_t, vuint8m8_t, vuint8m8_t, uint8_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vmulhu_vx)))
vuint8mf2_t vmulhu(vuint8mf2_t, uint8_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vmulhu_vx_m)))
vuint8mf2_t vmulhu(vbool16_t, vuint8mf2_t, vuint8mf2_t, uint8_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vmulhu_vx)))
vuint8mf4_t vmulhu(vuint8mf4_t, uint8_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vmulhu_vx_m)))
vuint8mf4_t vmulhu(vbool32_t, vuint8mf4_t, vuint8mf4_t, uint8_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vmulhu_vx)))
vuint8mf8_t vmulhu(vuint8mf8_t, uint8_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vmulhu_vx_m)))
vuint8mf8_t vmulhu(vbool64_t, vuint8mf8_t, vuint8mf8_t, uint8_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vmulhu_vx)))
vuint16m1_t vmulhu(vuint16m1_t, uint16_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vmulhu_vx_m)))
vuint16m1_t vmulhu(vbool16_t, vuint16m1_t, vuint16m1_t, uint16_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vmulhu_vx)))
vuint16m2_t vmulhu(vuint16m2_t, uint16_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vmulhu_vx_m)))
vuint16m2_t vmulhu(vbool8_t, vuint16m2_t, vuint16m2_t, uint16_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vmulhu_vx)))
vuint16m4_t vmulhu(vuint16m4_t, uint16_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vmulhu_vx_m)))
vuint16m4_t vmulhu(vbool4_t, vuint16m4_t, vuint16m4_t, uint16_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vmulhu_vx)))
vuint16m8_t vmulhu(vuint16m8_t, uint16_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vmulhu_vx_m)))
vuint16m8_t vmulhu(vbool2_t, vuint16m8_t, vuint16m8_t, uint16_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vmulhu_vx)))
vuint16mf2_t vmulhu(vuint16mf2_t, uint16_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vmulhu_vx_m)))
vuint16mf2_t vmulhu(vbool32_t, vuint16mf2_t, vuint16mf2_t, uint16_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vmulhu_vx)))
vuint16mf4_t vmulhu(vuint16mf4_t, uint16_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vmulhu_vx_m)))
vuint16mf4_t vmulhu(vbool64_t, vuint16mf4_t, vuint16mf4_t, uint16_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vmulhu_vx)))
vuint32m1_t vmulhu(vuint32m1_t, uint32_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vmulhu_vx_m)))
vuint32m1_t vmulhu(vbool32_t, vuint32m1_t, vuint32m1_t, uint32_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vmulhu_vx)))
vuint32m2_t vmulhu(vuint32m2_t, uint32_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vmulhu_vx_m)))
vuint32m2_t vmulhu(vbool16_t, vuint32m2_t, vuint32m2_t, uint32_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vmulhu_vx)))
vuint32m4_t vmulhu(vuint32m4_t, uint32_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vmulhu_vx_m)))
vuint32m4_t vmulhu(vbool8_t, vuint32m4_t, vuint32m4_t, uint32_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vmulhu_vx)))
vuint32m8_t vmulhu(vuint32m8_t, uint32_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vmulhu_vx_m)))
vuint32m8_t vmulhu(vbool4_t, vuint32m8_t, vuint32m8_t, uint32_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vmulhu_vx)))
vuint32mf2_t vmulhu(vuint32mf2_t, uint32_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vmulhu_vx_m)))
vuint32mf2_t vmulhu(vbool64_t, vuint32mf2_t, vuint32mf2_t, uint32_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vmulhsu_vv)))
vint8m1_t vmulhsu(vint8m1_t, vuint8m1_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vmulhsu_vv_m)))
vint8m1_t vmulhsu(vbool8_t, vint8m1_t, vint8m1_t, vuint8m1_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vmulhsu_vv)))
vint8m2_t vmulhsu(vint8m2_t, vuint8m2_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vmulhsu_vv_m)))
vint8m2_t vmulhsu(vbool4_t, vint8m2_t, vint8m2_t, vuint8m2_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vmulhsu_vv)))
vint8m4_t vmulhsu(vint8m4_t, vuint8m4_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vmulhsu_vv_m)))
vint8m4_t vmulhsu(vbool2_t, vint8m4_t, vint8m4_t, vuint8m4_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vmulhsu_vv)))
vint8m8_t vmulhsu(vint8m8_t, vuint8m8_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vmulhsu_vv_m)))
vint8m8_t vmulhsu(vbool1_t, vint8m8_t, vint8m8_t, vuint8m8_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vmulhsu_vv)))
vint8mf2_t vmulhsu(vint8mf2_t, vuint8mf2_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vmulhsu_vv_m)))
vint8mf2_t vmulhsu(vbool16_t, vint8mf2_t, vint8mf2_t, vuint8mf2_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vmulhsu_vv)))
vint8mf4_t vmulhsu(vint8mf4_t, vuint8mf4_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vmulhsu_vv_m)))
vint8mf4_t vmulhsu(vbool32_t, vint8mf4_t, vint8mf4_t, vuint8mf4_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vmulhsu_vv)))
vint8mf8_t vmulhsu(vint8mf8_t, vuint8mf8_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vmulhsu_vv_m)))
vint8mf8_t vmulhsu(vbool64_t, vint8mf8_t, vint8mf8_t, vuint8mf8_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vmulhsu_vv)))
vint16m1_t vmulhsu(vint16m1_t, vuint16m1_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vmulhsu_vv_m)))
vint16m1_t vmulhsu(vbool16_t, vint16m1_t, vint16m1_t, vuint16m1_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vmulhsu_vv)))
vint16m2_t vmulhsu(vint16m2_t, vuint16m2_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vmulhsu_vv_m)))
vint16m2_t vmulhsu(vbool8_t, vint16m2_t, vint16m2_t, vuint16m2_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vmulhsu_vv)))
vint16m4_t vmulhsu(vint16m4_t, vuint16m4_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vmulhsu_vv_m)))
vint16m4_t vmulhsu(vbool4_t, vint16m4_t, vint16m4_t, vuint16m4_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vmulhsu_vv)))
vint16m8_t vmulhsu(vint16m8_t, vuint16m8_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vmulhsu_vv_m)))
vint16m8_t vmulhsu(vbool2_t, vint16m8_t, vint16m8_t, vuint16m8_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vmulhsu_vv)))
vint16mf2_t vmulhsu(vint16mf2_t, vuint16mf2_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vmulhsu_vv_m)))
vint16mf2_t vmulhsu(vbool32_t, vint16mf2_t, vint16mf2_t, vuint16mf2_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vmulhsu_vv)))
vint16mf4_t vmulhsu(vint16mf4_t, vuint16mf4_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vmulhsu_vv_m)))
vint16mf4_t vmulhsu(vbool64_t, vint16mf4_t, vint16mf4_t, vuint16mf4_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vmulhsu_vv)))
vint32m1_t vmulhsu(vint32m1_t, vuint32m1_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vmulhsu_vv_m)))
vint32m1_t vmulhsu(vbool32_t, vint32m1_t, vint32m1_t, vuint32m1_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vmulhsu_vv)))
vint32m2_t vmulhsu(vint32m2_t, vuint32m2_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vmulhsu_vv_m)))
vint32m2_t vmulhsu(vbool16_t, vint32m2_t, vint32m2_t, vuint32m2_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vmulhsu_vv)))
vint32m4_t vmulhsu(vint32m4_t, vuint32m4_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vmulhsu_vv_m)))
vint32m4_t vmulhsu(vbool8_t, vint32m4_t, vint32m4_t, vuint32m4_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vmulhsu_vv)))
vint32m8_t vmulhsu(vint32m8_t, vuint32m8_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vmulhsu_vv_m)))
vint32m8_t vmulhsu(vbool4_t, vint32m8_t, vint32m8_t, vuint32m8_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vmulhsu_vv)))
vint32mf2_t vmulhsu(vint32mf2_t, vuint32mf2_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vmulhsu_vv_m)))
vint32mf2_t vmulhsu(vbool64_t, vint32mf2_t, vint32mf2_t, vuint32mf2_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vsuxei32_v)))
void vsuxei32(int8_t *, vuint32m4_t, vint8m1_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vsuxei32_v_m)))
void vsuxei32(vbool8_t, int8_t *, vuint32m4_t, vint8m1_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vsuxei32_v)))
void vsuxei32(int8_t *, vuint32m8_t, vint8m2_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vsuxei32_v_m)))
void vsuxei32(vbool4_t, int8_t *, vuint32m8_t, vint8m2_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vsuxei32_v)))
void vsuxei32(int8_t *, vuint32m2_t, vint8mf2_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vsuxei32_v_m)))
void vsuxei32(vbool16_t, int8_t *, vuint32m2_t, vint8mf2_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vsuxei32_v)))
void vsuxei32(int8_t *, vuint32m1_t, vint8mf4_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vsuxei32_v_m)))
void vsuxei32(vbool32_t, int8_t *, vuint32m1_t, vint8mf4_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vsuxei32_v)))
void vsuxei32(int8_t *, vuint32mf2_t, vint8mf8_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vsuxei32_v_m)))
void vsuxei32(vbool64_t, int8_t *, vuint32mf2_t, vint8mf8_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vmulhsu_vx)))
vint8m1_t vmulhsu(vint8m1_t, uint8_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vmulhsu_vx_m)))
vint8m1_t vmulhsu(vbool8_t, vint8m1_t, vint8m1_t, uint8_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vmulhsu_vx)))
vint8m2_t vmulhsu(vint8m2_t, uint8_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vmulhsu_vx_m)))
vint8m2_t vmulhsu(vbool4_t, vint8m2_t, vint8m2_t, uint8_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vmulhsu_vx)))
vint8m4_t vmulhsu(vint8m4_t, uint8_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vmulhsu_vx_m)))
vint8m4_t vmulhsu(vbool2_t, vint8m4_t, vint8m4_t, uint8_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vmulhsu_vx)))
vint8m8_t vmulhsu(vint8m8_t, uint8_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vmulhsu_vx_m)))
vint8m8_t vmulhsu(vbool1_t, vint8m8_t, vint8m8_t, uint8_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vmulhsu_vx)))
vint8mf2_t vmulhsu(vint8mf2_t, uint8_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vmulhsu_vx_m)))
vint8mf2_t vmulhsu(vbool16_t, vint8mf2_t, vint8mf2_t, uint8_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vmulhsu_vx)))
vint8mf4_t vmulhsu(vint8mf4_t, uint8_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vmulhsu_vx_m)))
vint8mf4_t vmulhsu(vbool32_t, vint8mf4_t, vint8mf4_t, uint8_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vmulhsu_vx)))
vint8mf8_t vmulhsu(vint8mf8_t, uint8_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vmulhsu_vx_m)))
vint8mf8_t vmulhsu(vbool64_t, vint8mf8_t, vint8mf8_t, uint8_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vmulhsu_vx)))
vint16m1_t vmulhsu(vint16m1_t, uint16_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vmulhsu_vx_m)))
vint16m1_t vmulhsu(vbool16_t, vint16m1_t, vint16m1_t, uint16_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vmulhsu_vx)))
vint16m2_t vmulhsu(vint16m2_t, uint16_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vmulhsu_vx_m)))
vint16m2_t vmulhsu(vbool8_t, vint16m2_t, vint16m2_t, uint16_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vmulhsu_vx)))
vint16m4_t vmulhsu(vint16m4_t, uint16_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vmulhsu_vx_m)))
vint16m4_t vmulhsu(vbool4_t, vint16m4_t, vint16m4_t, uint16_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vmulhsu_vx)))
vint16m8_t vmulhsu(vint16m8_t, uint16_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vmulhsu_vx_m)))
vint16m8_t vmulhsu(vbool2_t, vint16m8_t, vint16m8_t, uint16_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vmulhsu_vx)))
vint16mf2_t vmulhsu(vint16mf2_t, uint16_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vmulhsu_vx_m)))
vint16mf2_t vmulhsu(vbool32_t, vint16mf2_t, vint16mf2_t, uint16_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vmulhsu_vx)))
vint16mf4_t vmulhsu(vint16mf4_t, uint16_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vmulhsu_vx_m)))
vint16mf4_t vmulhsu(vbool64_t, vint16mf4_t, vint16mf4_t, uint16_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vmulhsu_vx)))
vint32m1_t vmulhsu(vint32m1_t, uint32_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vmulhsu_vx_m)))
vint32m1_t vmulhsu(vbool32_t, vint32m1_t, vint32m1_t, uint32_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vmulhsu_vx)))
vint32m2_t vmulhsu(vint32m2_t, uint32_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vmulhsu_vx_m)))
vint32m2_t vmulhsu(vbool16_t, vint32m2_t, vint32m2_t, uint32_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vmulhsu_vx)))
vint32m4_t vmulhsu(vint32m4_t, uint32_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vmulhsu_vx_m)))
vint32m4_t vmulhsu(vbool8_t, vint32m4_t, vint32m4_t, uint32_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vmulhsu_vx)))
vint32m8_t vmulhsu(vint32m8_t, uint32_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vmulhsu_vx_m)))
vint32m8_t vmulhsu(vbool4_t, vint32m8_t, vint32m8_t, uint32_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vmulhsu_vx)))
vint32mf2_t vmulhsu(vint32mf2_t, uint32_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vmulhsu_vx_m)))
vint32mf2_t vmulhsu(vbool64_t, vint32mf2_t, vint32mf2_t, uint32_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vdivu_vv)))
vuint8m1_t vdivu(vuint8m1_t, vuint8m1_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vdivu_vv_m)))
vuint8m1_t vdivu(vbool8_t, vuint8m1_t, vuint8m1_t, vuint8m1_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vdivu_vv)))
vuint8m2_t vdivu(vuint8m2_t, vuint8m2_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vdivu_vv_m)))
vuint8m2_t vdivu(vbool4_t, vuint8m2_t, vuint8m2_t, vuint8m2_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vdivu_vv)))
vuint8m4_t vdivu(vuint8m4_t, vuint8m4_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vdivu_vv_m)))
vuint8m4_t vdivu(vbool2_t, vuint8m4_t, vuint8m4_t, vuint8m4_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vdivu_vv)))
vuint8m8_t vdivu(vuint8m8_t, vuint8m8_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vdivu_vv_m)))
vuint8m8_t vdivu(vbool1_t, vuint8m8_t, vuint8m8_t, vuint8m8_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vdivu_vv)))
vuint8mf2_t vdivu(vuint8mf2_t, vuint8mf2_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vdivu_vv_m)))
vuint8mf2_t vdivu(vbool16_t, vuint8mf2_t, vuint8mf2_t, vuint8mf2_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vdivu_vv)))
vuint8mf4_t vdivu(vuint8mf4_t, vuint8mf4_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vdivu_vv_m)))
vuint8mf4_t vdivu(vbool32_t, vuint8mf4_t, vuint8mf4_t, vuint8mf4_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vdivu_vv)))
vuint8mf8_t vdivu(vuint8mf8_t, vuint8mf8_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vdivu_vv_m)))
vuint8mf8_t vdivu(vbool64_t, vuint8mf8_t, vuint8mf8_t, vuint8mf8_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vdivu_vv)))
vuint16m1_t vdivu(vuint16m1_t, vuint16m1_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vdivu_vv_m)))
vuint16m1_t vdivu(vbool16_t, vuint16m1_t, vuint16m1_t, vuint16m1_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vdivu_vv)))
vuint16m2_t vdivu(vuint16m2_t, vuint16m2_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vdivu_vv_m)))
vuint16m2_t vdivu(vbool8_t, vuint16m2_t, vuint16m2_t, vuint16m2_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vdivu_vv)))
vuint16m4_t vdivu(vuint16m4_t, vuint16m4_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vdivu_vv_m)))
vuint16m4_t vdivu(vbool4_t, vuint16m4_t, vuint16m4_t, vuint16m4_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vdivu_vv)))
vuint16m8_t vdivu(vuint16m8_t, vuint16m8_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vdivu_vv_m)))
vuint16m8_t vdivu(vbool2_t, vuint16m8_t, vuint16m8_t, vuint16m8_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vdivu_vv)))
vuint16mf2_t vdivu(vuint16mf2_t, vuint16mf2_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vdivu_vv_m)))
vuint16mf2_t vdivu(vbool32_t, vuint16mf2_t, vuint16mf2_t, vuint16mf2_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vdivu_vv)))
vuint16mf4_t vdivu(vuint16mf4_t, vuint16mf4_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vdivu_vv_m)))
vuint16mf4_t vdivu(vbool64_t, vuint16mf4_t, vuint16mf4_t, vuint16mf4_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vdivu_vv)))
vuint32m1_t vdivu(vuint32m1_t, vuint32m1_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vdivu_vv_m)))
vuint32m1_t vdivu(vbool32_t, vuint32m1_t, vuint32m1_t, vuint32m1_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vdivu_vv)))
vuint32m2_t vdivu(vuint32m2_t, vuint32m2_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vdivu_vv_m)))
vuint32m2_t vdivu(vbool16_t, vuint32m2_t, vuint32m2_t, vuint32m2_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vdivu_vv)))
vuint32m4_t vdivu(vuint32m4_t, vuint32m4_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vdivu_vv_m)))
vuint32m4_t vdivu(vbool8_t, vuint32m4_t, vuint32m4_t, vuint32m4_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vdivu_vv)))
vuint32m8_t vdivu(vuint32m8_t, vuint32m8_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vdivu_vv_m)))
vuint32m8_t vdivu(vbool4_t, vuint32m8_t, vuint32m8_t, vuint32m8_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vdivu_vv)))
vuint32mf2_t vdivu(vuint32mf2_t, vuint32mf2_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vdivu_vv_m)))
vuint32mf2_t vdivu(vbool64_t, vuint32mf2_t, vuint32mf2_t, vuint32mf2_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vdivu_vx)))
vuint8m1_t vdivu(vuint8m1_t, uint8_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vdivu_vx_m)))
vuint8m1_t vdivu(vbool8_t, vuint8m1_t, vuint8m1_t, uint8_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vdivu_vx)))
vuint8m2_t vdivu(vuint8m2_t, uint8_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vdivu_vx_m)))
vuint8m2_t vdivu(vbool4_t, vuint8m2_t, vuint8m2_t, uint8_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vdivu_vx)))
vuint8m4_t vdivu(vuint8m4_t, uint8_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vdivu_vx_m)))
vuint8m4_t vdivu(vbool2_t, vuint8m4_t, vuint8m4_t, uint8_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vdivu_vx)))
vuint8m8_t vdivu(vuint8m8_t, uint8_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vdivu_vx_m)))
vuint8m8_t vdivu(vbool1_t, vuint8m8_t, vuint8m8_t, uint8_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vdivu_vx)))
vuint8mf2_t vdivu(vuint8mf2_t, uint8_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vdivu_vx_m)))
vuint8mf2_t vdivu(vbool16_t, vuint8mf2_t, vuint8mf2_t, uint8_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vdivu_vx)))
vuint8mf4_t vdivu(vuint8mf4_t, uint8_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vdivu_vx_m)))
vuint8mf4_t vdivu(vbool32_t, vuint8mf4_t, vuint8mf4_t, uint8_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vdivu_vx)))
vuint8mf8_t vdivu(vuint8mf8_t, uint8_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vdivu_vx_m)))
vuint8mf8_t vdivu(vbool64_t, vuint8mf8_t, vuint8mf8_t, uint8_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vdivu_vx)))
vuint16m1_t vdivu(vuint16m1_t, uint16_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vdivu_vx_m)))
vuint16m1_t vdivu(vbool16_t, vuint16m1_t, vuint16m1_t, uint16_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vdivu_vx)))
vuint16m2_t vdivu(vuint16m2_t, uint16_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vdivu_vx_m)))
vuint16m2_t vdivu(vbool8_t, vuint16m2_t, vuint16m2_t, uint16_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vdivu_vx)))
vuint16m4_t vdivu(vuint16m4_t, uint16_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vdivu_vx_m)))
vuint16m4_t vdivu(vbool4_t, vuint16m4_t, vuint16m4_t, uint16_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vdivu_vx)))
vuint16m8_t vdivu(vuint16m8_t, uint16_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vdivu_vx_m)))
vuint16m8_t vdivu(vbool2_t, vuint16m8_t, vuint16m8_t, uint16_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vdivu_vx)))
vuint16mf2_t vdivu(vuint16mf2_t, uint16_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vdivu_vx_m)))
vuint16mf2_t vdivu(vbool32_t, vuint16mf2_t, vuint16mf2_t, uint16_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vdivu_vx)))
vuint16mf4_t vdivu(vuint16mf4_t, uint16_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vdivu_vx_m)))
vuint16mf4_t vdivu(vbool64_t, vuint16mf4_t, vuint16mf4_t, uint16_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vdivu_vx)))
vuint32m1_t vdivu(vuint32m1_t, uint32_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vdivu_vx_m)))
vuint32m1_t vdivu(vbool32_t, vuint32m1_t, vuint32m1_t, uint32_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vdivu_vx)))
vuint32m2_t vdivu(vuint32m2_t, uint32_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vdivu_vx_m)))
vuint32m2_t vdivu(vbool16_t, vuint32m2_t, vuint32m2_t, uint32_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vdivu_vx)))
vuint32m4_t vdivu(vuint32m4_t, uint32_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vdivu_vx_m)))
vuint32m4_t vdivu(vbool8_t, vuint32m4_t, vuint32m4_t, uint32_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vdivu_vx)))
vuint32m8_t vdivu(vuint32m8_t, uint32_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vdivu_vx_m)))
vuint32m8_t vdivu(vbool4_t, vuint32m8_t, vuint32m8_t, uint32_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vdivu_vx)))
vuint32mf2_t vdivu(vuint32mf2_t, uint32_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vdivu_vx_m)))
vuint32mf2_t vdivu(vbool64_t, vuint32mf2_t, vuint32mf2_t, uint32_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vdiv_vv)))
vint8m1_t vdiv(vint8m1_t, vint8m1_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vdiv_vv_m)))
vint8m1_t vdiv(vbool8_t, vint8m1_t, vint8m1_t, vint8m1_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vdiv_vv)))
vint8m2_t vdiv(vint8m2_t, vint8m2_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vdiv_vv_m)))
vint8m2_t vdiv(vbool4_t, vint8m2_t, vint8m2_t, vint8m2_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vdiv_vv)))
vint8m4_t vdiv(vint8m4_t, vint8m4_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vdiv_vv_m)))
vint8m4_t vdiv(vbool2_t, vint8m4_t, vint8m4_t, vint8m4_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vdiv_vv)))
vint8m8_t vdiv(vint8m8_t, vint8m8_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vdiv_vv_m)))
vint8m8_t vdiv(vbool1_t, vint8m8_t, vint8m8_t, vint8m8_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vdiv_vv)))
vint8mf2_t vdiv(vint8mf2_t, vint8mf2_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vdiv_vv_m)))
vint8mf2_t vdiv(vbool16_t, vint8mf2_t, vint8mf2_t, vint8mf2_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vdiv_vv)))
vint8mf4_t vdiv(vint8mf4_t, vint8mf4_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vdiv_vv_m)))
vint8mf4_t vdiv(vbool32_t, vint8mf4_t, vint8mf4_t, vint8mf4_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vdiv_vv)))
vint8mf8_t vdiv(vint8mf8_t, vint8mf8_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vdiv_vv_m)))
vint8mf8_t vdiv(vbool64_t, vint8mf8_t, vint8mf8_t, vint8mf8_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vdiv_vv)))
vint16m1_t vdiv(vint16m1_t, vint16m1_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vdiv_vv_m)))
vint16m1_t vdiv(vbool16_t, vint16m1_t, vint16m1_t, vint16m1_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vdiv_vv)))
vint16m2_t vdiv(vint16m2_t, vint16m2_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vdiv_vv_m)))
vint16m2_t vdiv(vbool8_t, vint16m2_t, vint16m2_t, vint16m2_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vdiv_vv)))
vint16m4_t vdiv(vint16m4_t, vint16m4_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vdiv_vv_m)))
vint16m4_t vdiv(vbool4_t, vint16m4_t, vint16m4_t, vint16m4_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vdiv_vv)))
vint16m8_t vdiv(vint16m8_t, vint16m8_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vdiv_vv_m)))
vint16m8_t vdiv(vbool2_t, vint16m8_t, vint16m8_t, vint16m8_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vdiv_vv)))
vint16mf2_t vdiv(vint16mf2_t, vint16mf2_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vdiv_vv_m)))
vint16mf2_t vdiv(vbool32_t, vint16mf2_t, vint16mf2_t, vint16mf2_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vdiv_vv)))
vint16mf4_t vdiv(vint16mf4_t, vint16mf4_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vdiv_vv_m)))
vint16mf4_t vdiv(vbool64_t, vint16mf4_t, vint16mf4_t, vint16mf4_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vdiv_vv)))
vint32m1_t vdiv(vint32m1_t, vint32m1_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vdiv_vv_m)))
vint32m1_t vdiv(vbool32_t, vint32m1_t, vint32m1_t, vint32m1_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vdiv_vv)))
vint32m2_t vdiv(vint32m2_t, vint32m2_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vdiv_vv_m)))
vint32m2_t vdiv(vbool16_t, vint32m2_t, vint32m2_t, vint32m2_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vdiv_vv)))
vint32m4_t vdiv(vint32m4_t, vint32m4_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vdiv_vv_m)))
vint32m4_t vdiv(vbool8_t, vint32m4_t, vint32m4_t, vint32m4_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vdiv_vv)))
vint32m8_t vdiv(vint32m8_t, vint32m8_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vdiv_vv_m)))
vint32m8_t vdiv(vbool4_t, vint32m8_t, vint32m8_t, vint32m8_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vdiv_vv)))
vint32mf2_t vdiv(vint32mf2_t, vint32mf2_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vdiv_vv_m)))
vint32mf2_t vdiv(vbool64_t, vint32mf2_t, vint32mf2_t, vint32mf2_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vdiv_vx)))
vint8m1_t vdiv(vint8m1_t, int8_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vdiv_vx_m)))
vint8m1_t vdiv(vbool8_t, vint8m1_t, vint8m1_t, int8_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vdiv_vx)))
vint8m2_t vdiv(vint8m2_t, int8_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vdiv_vx_m)))
vint8m2_t vdiv(vbool4_t, vint8m2_t, vint8m2_t, int8_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vdiv_vx)))
vint8m4_t vdiv(vint8m4_t, int8_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vdiv_vx_m)))
vint8m4_t vdiv(vbool2_t, vint8m4_t, vint8m4_t, int8_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vdiv_vx)))
vint8m8_t vdiv(vint8m8_t, int8_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vdiv_vx_m)))
vint8m8_t vdiv(vbool1_t, vint8m8_t, vint8m8_t, int8_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vdiv_vx)))
vint8mf2_t vdiv(vint8mf2_t, int8_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vdiv_vx_m)))
vint8mf2_t vdiv(vbool16_t, vint8mf2_t, vint8mf2_t, int8_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vdiv_vx)))
vint8mf4_t vdiv(vint8mf4_t, int8_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vdiv_vx_m)))
vint8mf4_t vdiv(vbool32_t, vint8mf4_t, vint8mf4_t, int8_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vdiv_vx)))
vint8mf8_t vdiv(vint8mf8_t, int8_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vdiv_vx_m)))
vint8mf8_t vdiv(vbool64_t, vint8mf8_t, vint8mf8_t, int8_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vdiv_vx)))
vint16m1_t vdiv(vint16m1_t, int16_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vdiv_vx_m)))
vint16m1_t vdiv(vbool16_t, vint16m1_t, vint16m1_t, int16_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vdiv_vx)))
vint16m2_t vdiv(vint16m2_t, int16_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vdiv_vx_m)))
vint16m2_t vdiv(vbool8_t, vint16m2_t, vint16m2_t, int16_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vdiv_vx)))
vint16m4_t vdiv(vint16m4_t, int16_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vdiv_vx_m)))
vint16m4_t vdiv(vbool4_t, vint16m4_t, vint16m4_t, int16_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vdiv_vx)))
vint16m8_t vdiv(vint16m8_t, int16_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vdiv_vx_m)))
vint16m8_t vdiv(vbool2_t, vint16m8_t, vint16m8_t, int16_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vdiv_vx)))
vint16mf2_t vdiv(vint16mf2_t, int16_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vdiv_vx_m)))
vint16mf2_t vdiv(vbool32_t, vint16mf2_t, vint16mf2_t, int16_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vdiv_vx)))
vint16mf4_t vdiv(vint16mf4_t, int16_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vdiv_vx_m)))
vint16mf4_t vdiv(vbool64_t, vint16mf4_t, vint16mf4_t, int16_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vdiv_vx)))
vint32m1_t vdiv(vint32m1_t, int32_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vdiv_vx_m)))
vint32m1_t vdiv(vbool32_t, vint32m1_t, vint32m1_t, int32_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vdiv_vx)))
vint32m2_t vdiv(vint32m2_t, int32_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vdiv_vx_m)))
vint32m2_t vdiv(vbool16_t, vint32m2_t, vint32m2_t, int32_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vdiv_vx)))
vint32m4_t vdiv(vint32m4_t, int32_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vdiv_vx_m)))
vint32m4_t vdiv(vbool8_t, vint32m4_t, vint32m4_t, int32_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vdiv_vx)))
vint32m8_t vdiv(vint32m8_t, int32_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vdiv_vx_m)))
vint32m8_t vdiv(vbool4_t, vint32m8_t, vint32m8_t, int32_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vdiv_vx)))
vint32mf2_t vdiv(vint32mf2_t, int32_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vdiv_vx_m)))
vint32mf2_t vdiv(vbool64_t, vint32mf2_t, vint32mf2_t, int32_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vremu_vv)))
vuint8m1_t vremu(vuint8m1_t, vuint8m1_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vremu_vv_m)))
vuint8m1_t vremu(vbool8_t, vuint8m1_t, vuint8m1_t, vuint8m1_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vremu_vv)))
vuint8m2_t vremu(vuint8m2_t, vuint8m2_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vremu_vv_m)))
vuint8m2_t vremu(vbool4_t, vuint8m2_t, vuint8m2_t, vuint8m2_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vremu_vv)))
vuint8m4_t vremu(vuint8m4_t, vuint8m4_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vremu_vv_m)))
vuint8m4_t vremu(vbool2_t, vuint8m4_t, vuint8m4_t, vuint8m4_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vremu_vv)))
vuint8m8_t vremu(vuint8m8_t, vuint8m8_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vremu_vv_m)))
vuint8m8_t vremu(vbool1_t, vuint8m8_t, vuint8m8_t, vuint8m8_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vremu_vv)))
vuint8mf2_t vremu(vuint8mf2_t, vuint8mf2_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vremu_vv_m)))
vuint8mf2_t vremu(vbool16_t, vuint8mf2_t, vuint8mf2_t, vuint8mf2_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vremu_vv)))
vuint8mf4_t vremu(vuint8mf4_t, vuint8mf4_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vremu_vv_m)))
vuint8mf4_t vremu(vbool32_t, vuint8mf4_t, vuint8mf4_t, vuint8mf4_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vremu_vv)))
vuint8mf8_t vremu(vuint8mf8_t, vuint8mf8_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vremu_vv_m)))
vuint8mf8_t vremu(vbool64_t, vuint8mf8_t, vuint8mf8_t, vuint8mf8_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vremu_vv)))
vuint16m1_t vremu(vuint16m1_t, vuint16m1_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vremu_vv_m)))
vuint16m1_t vremu(vbool16_t, vuint16m1_t, vuint16m1_t, vuint16m1_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vremu_vv)))
vuint16m2_t vremu(vuint16m2_t, vuint16m2_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vremu_vv_m)))
vuint16m2_t vremu(vbool8_t, vuint16m2_t, vuint16m2_t, vuint16m2_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vremu_vv)))
vuint16m4_t vremu(vuint16m4_t, vuint16m4_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vremu_vv_m)))
vuint16m4_t vremu(vbool4_t, vuint16m4_t, vuint16m4_t, vuint16m4_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vremu_vv)))
vuint16m8_t vremu(vuint16m8_t, vuint16m8_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vremu_vv_m)))
vuint16m8_t vremu(vbool2_t, vuint16m8_t, vuint16m8_t, vuint16m8_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vremu_vv)))
vuint16mf2_t vremu(vuint16mf2_t, vuint16mf2_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vremu_vv_m)))
vuint16mf2_t vremu(vbool32_t, vuint16mf2_t, vuint16mf2_t, vuint16mf2_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vremu_vv)))
vuint16mf4_t vremu(vuint16mf4_t, vuint16mf4_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vremu_vv_m)))
vuint16mf4_t vremu(vbool64_t, vuint16mf4_t, vuint16mf4_t, vuint16mf4_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vremu_vv)))
vuint32m1_t vremu(vuint32m1_t, vuint32m1_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vremu_vv_m)))
vuint32m1_t vremu(vbool32_t, vuint32m1_t, vuint32m1_t, vuint32m1_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vremu_vv)))
vuint32m2_t vremu(vuint32m2_t, vuint32m2_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vremu_vv_m)))
vuint32m2_t vremu(vbool16_t, vuint32m2_t, vuint32m2_t, vuint32m2_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vremu_vv)))
vuint32m4_t vremu(vuint32m4_t, vuint32m4_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vremu_vv_m)))
vuint32m4_t vremu(vbool8_t, vuint32m4_t, vuint32m4_t, vuint32m4_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vremu_vv)))
vuint32m8_t vremu(vuint32m8_t, vuint32m8_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vremu_vv_m)))
vuint32m8_t vremu(vbool4_t, vuint32m8_t, vuint32m8_t, vuint32m8_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vremu_vv)))
vuint32mf2_t vremu(vuint32mf2_t, vuint32mf2_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vremu_vv_m)))
vuint32mf2_t vremu(vbool64_t, vuint32mf2_t, vuint32mf2_t, vuint32mf2_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vremu_vx)))
vuint8m1_t vremu(vuint8m1_t, uint8_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vremu_vx_m)))
vuint8m1_t vremu(vbool8_t, vuint8m1_t, vuint8m1_t, uint8_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vremu_vx)))
vuint8m2_t vremu(vuint8m2_t, uint8_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vremu_vx_m)))
vuint8m2_t vremu(vbool4_t, vuint8m2_t, vuint8m2_t, uint8_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vremu_vx)))
vuint8m4_t vremu(vuint8m4_t, uint8_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vremu_vx_m)))
vuint8m4_t vremu(vbool2_t, vuint8m4_t, vuint8m4_t, uint8_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vremu_vx)))
vuint8m8_t vremu(vuint8m8_t, uint8_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vremu_vx_m)))
vuint8m8_t vremu(vbool1_t, vuint8m8_t, vuint8m8_t, uint8_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vremu_vx)))
vuint8mf2_t vremu(vuint8mf2_t, uint8_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vremu_vx_m)))
vuint8mf2_t vremu(vbool16_t, vuint8mf2_t, vuint8mf2_t, uint8_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vremu_vx)))
vuint8mf4_t vremu(vuint8mf4_t, uint8_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vremu_vx_m)))
vuint8mf4_t vremu(vbool32_t, vuint8mf4_t, vuint8mf4_t, uint8_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vremu_vx)))
vuint8mf8_t vremu(vuint8mf8_t, uint8_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vremu_vx_m)))
vuint8mf8_t vremu(vbool64_t, vuint8mf8_t, vuint8mf8_t, uint8_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vremu_vx)))
vuint16m1_t vremu(vuint16m1_t, uint16_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vremu_vx_m)))
vuint16m1_t vremu(vbool16_t, vuint16m1_t, vuint16m1_t, uint16_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vremu_vx)))
vuint16m2_t vremu(vuint16m2_t, uint16_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vremu_vx_m)))
vuint16m2_t vremu(vbool8_t, vuint16m2_t, vuint16m2_t, uint16_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vremu_vx)))
vuint16m4_t vremu(vuint16m4_t, uint16_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vremu_vx_m)))
vuint16m4_t vremu(vbool4_t, vuint16m4_t, vuint16m4_t, uint16_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vremu_vx)))
vuint16m8_t vremu(vuint16m8_t, uint16_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vremu_vx_m)))
vuint16m8_t vremu(vbool2_t, vuint16m8_t, vuint16m8_t, uint16_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vremu_vx)))
vuint16mf2_t vremu(vuint16mf2_t, uint16_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vremu_vx_m)))
vuint16mf2_t vremu(vbool32_t, vuint16mf2_t, vuint16mf2_t, uint16_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vremu_vx)))
vuint16mf4_t vremu(vuint16mf4_t, uint16_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vremu_vx_m)))
vuint16mf4_t vremu(vbool64_t, vuint16mf4_t, vuint16mf4_t, uint16_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vremu_vx)))
vuint32m1_t vremu(vuint32m1_t, uint32_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vremu_vx_m)))
vuint32m1_t vremu(vbool32_t, vuint32m1_t, vuint32m1_t, uint32_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vremu_vx)))
vuint32m2_t vremu(vuint32m2_t, uint32_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vremu_vx_m)))
vuint32m2_t vremu(vbool16_t, vuint32m2_t, vuint32m2_t, uint32_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vremu_vx)))
vuint32m4_t vremu(vuint32m4_t, uint32_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vremu_vx_m)))
vuint32m4_t vremu(vbool8_t, vuint32m4_t, vuint32m4_t, uint32_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vremu_vx)))
vuint32m8_t vremu(vuint32m8_t, uint32_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vremu_vx_m)))
vuint32m8_t vremu(vbool4_t, vuint32m8_t, vuint32m8_t, uint32_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vremu_vx)))
vuint32mf2_t vremu(vuint32mf2_t, uint32_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vremu_vx_m)))
vuint32mf2_t vremu(vbool64_t, vuint32mf2_t, vuint32mf2_t, uint32_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vrem_vv)))
vint8m1_t vrem(vint8m1_t, vint8m1_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vrem_vv_m)))
vint8m1_t vrem(vbool8_t, vint8m1_t, vint8m1_t, vint8m1_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vrem_vv)))
vint8m2_t vrem(vint8m2_t, vint8m2_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vrem_vv_m)))
vint8m2_t vrem(vbool4_t, vint8m2_t, vint8m2_t, vint8m2_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vrem_vv)))
vint8m4_t vrem(vint8m4_t, vint8m4_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vrem_vv_m)))
vint8m4_t vrem(vbool2_t, vint8m4_t, vint8m4_t, vint8m4_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vrem_vv)))
vint8m8_t vrem(vint8m8_t, vint8m8_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vrem_vv_m)))
vint8m8_t vrem(vbool1_t, vint8m8_t, vint8m8_t, vint8m8_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vrem_vv)))
vint8mf2_t vrem(vint8mf2_t, vint8mf2_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vrem_vv_m)))
vint8mf2_t vrem(vbool16_t, vint8mf2_t, vint8mf2_t, vint8mf2_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vrem_vv)))
vint8mf4_t vrem(vint8mf4_t, vint8mf4_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vrem_vv_m)))
vint8mf4_t vrem(vbool32_t, vint8mf4_t, vint8mf4_t, vint8mf4_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vrem_vv)))
vint8mf8_t vrem(vint8mf8_t, vint8mf8_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vrem_vv_m)))
vint8mf8_t vrem(vbool64_t, vint8mf8_t, vint8mf8_t, vint8mf8_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vrem_vv)))
vint16m1_t vrem(vint16m1_t, vint16m1_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vrem_vv_m)))
vint16m1_t vrem(vbool16_t, vint16m1_t, vint16m1_t, vint16m1_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vrem_vv)))
vint16m2_t vrem(vint16m2_t, vint16m2_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vrem_vv_m)))
vint16m2_t vrem(vbool8_t, vint16m2_t, vint16m2_t, vint16m2_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vrem_vv)))
vint16m4_t vrem(vint16m4_t, vint16m4_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vrem_vv_m)))
vint16m4_t vrem(vbool4_t, vint16m4_t, vint16m4_t, vint16m4_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vrem_vv)))
vint16m8_t vrem(vint16m8_t, vint16m8_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vrem_vv_m)))
vint16m8_t vrem(vbool2_t, vint16m8_t, vint16m8_t, vint16m8_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vrem_vv)))
vint16mf2_t vrem(vint16mf2_t, vint16mf2_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vrem_vv_m)))
vint16mf2_t vrem(vbool32_t, vint16mf2_t, vint16mf2_t, vint16mf2_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vrem_vv)))
vint16mf4_t vrem(vint16mf4_t, vint16mf4_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vrem_vv_m)))
vint16mf4_t vrem(vbool64_t, vint16mf4_t, vint16mf4_t, vint16mf4_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vrem_vv)))
vint32m1_t vrem(vint32m1_t, vint32m1_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vrem_vv_m)))
vint32m1_t vrem(vbool32_t, vint32m1_t, vint32m1_t, vint32m1_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vrem_vv)))
vint32m2_t vrem(vint32m2_t, vint32m2_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vrem_vv_m)))
vint32m2_t vrem(vbool16_t, vint32m2_t, vint32m2_t, vint32m2_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vrem_vv)))
vint32m4_t vrem(vint32m4_t, vint32m4_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vrem_vv_m)))
vint32m4_t vrem(vbool8_t, vint32m4_t, vint32m4_t, vint32m4_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vrem_vv)))
vint32m8_t vrem(vint32m8_t, vint32m8_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vrem_vv_m)))
vint32m8_t vrem(vbool4_t, vint32m8_t, vint32m8_t, vint32m8_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vrem_vv)))
vint32mf2_t vrem(vint32mf2_t, vint32mf2_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vrem_vv_m)))
vint32mf2_t vrem(vbool64_t, vint32mf2_t, vint32mf2_t, vint32mf2_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vrem_vx)))
vint8m1_t vrem(vint8m1_t, int8_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vrem_vx_m)))
vint8m1_t vrem(vbool8_t, vint8m1_t, vint8m1_t, int8_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vrem_vx)))
vint8m2_t vrem(vint8m2_t, int8_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vrem_vx_m)))
vint8m2_t vrem(vbool4_t, vint8m2_t, vint8m2_t, int8_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vrem_vx)))
vint8m4_t vrem(vint8m4_t, int8_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vrem_vx_m)))
vint8m4_t vrem(vbool2_t, vint8m4_t, vint8m4_t, int8_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vrem_vx)))
vint8m8_t vrem(vint8m8_t, int8_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vrem_vx_m)))
vint8m8_t vrem(vbool1_t, vint8m8_t, vint8m8_t, int8_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vrem_vx)))
vint8mf2_t vrem(vint8mf2_t, int8_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vrem_vx_m)))
vint8mf2_t vrem(vbool16_t, vint8mf2_t, vint8mf2_t, int8_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vrem_vx)))
vint8mf4_t vrem(vint8mf4_t, int8_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vrem_vx_m)))
vint8mf4_t vrem(vbool32_t, vint8mf4_t, vint8mf4_t, int8_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vrem_vx)))
vint8mf8_t vrem(vint8mf8_t, int8_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vrem_vx_m)))
vint8mf8_t vrem(vbool64_t, vint8mf8_t, vint8mf8_t, int8_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vrem_vx)))
vint16m1_t vrem(vint16m1_t, int16_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vrem_vx_m)))
vint16m1_t vrem(vbool16_t, vint16m1_t, vint16m1_t, int16_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vrem_vx)))
vint16m2_t vrem(vint16m2_t, int16_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vrem_vx_m)))
vint16m2_t vrem(vbool8_t, vint16m2_t, vint16m2_t, int16_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vrem_vx)))
vint16m4_t vrem(vint16m4_t, int16_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vrem_vx_m)))
vint16m4_t vrem(vbool4_t, vint16m4_t, vint16m4_t, int16_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vrem_vx)))
vint16m8_t vrem(vint16m8_t, int16_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vrem_vx_m)))
vint16m8_t vrem(vbool2_t, vint16m8_t, vint16m8_t, int16_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vrem_vx)))
vint16mf2_t vrem(vint16mf2_t, int16_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vrem_vx_m)))
vint16mf2_t vrem(vbool32_t, vint16mf2_t, vint16mf2_t, int16_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vrem_vx)))
vint16mf4_t vrem(vint16mf4_t, int16_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vrem_vx_m)))
vint16mf4_t vrem(vbool64_t, vint16mf4_t, vint16mf4_t, int16_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vrem_vx)))
vint32m1_t vrem(vint32m1_t, int32_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vrem_vx_m)))
vint32m1_t vrem(vbool32_t, vint32m1_t, vint32m1_t, int32_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vrem_vx)))
vint32m2_t vrem(vint32m2_t, int32_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vrem_vx_m)))
vint32m2_t vrem(vbool16_t, vint32m2_t, vint32m2_t, int32_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vrem_vx)))
vint32m4_t vrem(vint32m4_t, int32_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vrem_vx_m)))
vint32m4_t vrem(vbool8_t, vint32m4_t, vint32m4_t, int32_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vrem_vx)))
vint32m8_t vrem(vint32m8_t, int32_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vrem_vx_m)))
vint32m8_t vrem(vbool4_t, vint32m8_t, vint32m8_t, int32_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vrem_vx)))
vint32mf2_t vrem(vint32mf2_t, int32_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vrem_vx_m)))
vint32mf2_t vrem(vbool64_t, vint32mf2_t, vint32mf2_t, int32_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vwmul_vv)))
vint16mf4_t vwmul(vint8mf8_t, vint8mf8_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vwmul_vv_m)))
vint16mf4_t vwmul(vbool64_t, vint16mf4_t, vint8mf8_t, vint8mf8_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vwmul_vv)))
vint16mf2_t vwmul(vint8mf4_t, vint8mf4_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vwmul_vv_m)))
vint16mf2_t vwmul(vbool32_t, vint16mf2_t, vint8mf4_t, vint8mf4_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vwmul_vv)))
vint16m1_t vwmul(vint8mf2_t, vint8mf2_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vwmul_vv_m)))
vint16m1_t vwmul(vbool16_t, vint16m1_t, vint8mf2_t, vint8mf2_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vwmul_vv)))
vint16m2_t vwmul(vint8m1_t, vint8m1_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vwmul_vv_m)))
vint16m2_t vwmul(vbool8_t, vint16m2_t, vint8m1_t, vint8m1_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vwmul_vv)))
vint16m4_t vwmul(vint8m2_t, vint8m2_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vwmul_vv_m)))
vint16m4_t vwmul(vbool4_t, vint16m4_t, vint8m2_t, vint8m2_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vwmul_vv)))
vint16m8_t vwmul(vint8m4_t, vint8m4_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vwmul_vv_m)))
vint16m8_t vwmul(vbool2_t, vint16m8_t, vint8m4_t, vint8m4_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vwmul_vv)))
vint32mf2_t vwmul(vint16mf4_t, vint16mf4_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vwmul_vv_m)))
vint32mf2_t vwmul(vbool64_t, vint32mf2_t, vint16mf4_t, vint16mf4_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vwmul_vv)))
vint32m1_t vwmul(vint16mf2_t, vint16mf2_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vwmul_vv_m)))
vint32m1_t vwmul(vbool32_t, vint32m1_t, vint16mf2_t, vint16mf2_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vwmul_vv)))
vint32m2_t vwmul(vint16m1_t, vint16m1_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vwmul_vv_m)))
vint32m2_t vwmul(vbool16_t, vint32m2_t, vint16m1_t, vint16m1_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vwmul_vv)))
vint32m4_t vwmul(vint16m2_t, vint16m2_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vwmul_vv_m)))
vint32m4_t vwmul(vbool8_t, vint32m4_t, vint16m2_t, vint16m2_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vwmul_vv)))
vint32m8_t vwmul(vint16m4_t, vint16m4_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vwmul_vv_m)))
vint32m8_t vwmul(vbool4_t, vint32m8_t, vint16m4_t, vint16m4_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vsuxei32_v)))
void vsuxei32(uint8_t *, vuint32m4_t, vuint8m1_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vsuxei32_v_m)))
void vsuxei32(vbool8_t, uint8_t *, vuint32m4_t, vuint8m1_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vsuxei32_v)))
void vsuxei32(uint8_t *, vuint32m8_t, vuint8m2_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vsuxei32_v_m)))
void vsuxei32(vbool4_t, uint8_t *, vuint32m8_t, vuint8m2_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vsuxei32_v)))
void vsuxei32(uint8_t *, vuint32m2_t, vuint8mf2_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vsuxei32_v_m)))
void vsuxei32(vbool16_t, uint8_t *, vuint32m2_t, vuint8mf2_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vsuxei32_v)))
void vsuxei32(uint8_t *, vuint32m1_t, vuint8mf4_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vsuxei32_v_m)))
void vsuxei32(vbool32_t, uint8_t *, vuint32m1_t, vuint8mf4_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vsuxei32_v)))
void vsuxei32(uint8_t *, vuint32mf2_t, vuint8mf8_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vsuxei32_v_m)))
void vsuxei32(vbool64_t, uint8_t *, vuint32mf2_t, vuint8mf8_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vwmul_vx)))
vint16mf4_t vwmul(vint8mf8_t, int8_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vwmul_vx_m)))
vint16mf4_t vwmul(vbool64_t, vint16mf4_t, vint8mf8_t, int8_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vwmul_vx)))
vint16mf2_t vwmul(vint8mf4_t, int8_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vwmul_vx_m)))
vint16mf2_t vwmul(vbool32_t, vint16mf2_t, vint8mf4_t, int8_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vwmul_vx)))
vint16m1_t vwmul(vint8mf2_t, int8_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vwmul_vx_m)))
vint16m1_t vwmul(vbool16_t, vint16m1_t, vint8mf2_t, int8_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vwmul_vx)))
vint16m2_t vwmul(vint8m1_t, int8_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vwmul_vx_m)))
vint16m2_t vwmul(vbool8_t, vint16m2_t, vint8m1_t, int8_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vwmul_vx)))
vint16m4_t vwmul(vint8m2_t, int8_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vwmul_vx_m)))
vint16m4_t vwmul(vbool4_t, vint16m4_t, vint8m2_t, int8_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vwmul_vx)))
vint16m8_t vwmul(vint8m4_t, int8_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vwmul_vx_m)))
vint16m8_t vwmul(vbool2_t, vint16m8_t, vint8m4_t, int8_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vwmul_vx)))
vint32mf2_t vwmul(vint16mf4_t, int16_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vwmul_vx_m)))
vint32mf2_t vwmul(vbool64_t, vint32mf2_t, vint16mf4_t, int16_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vwmul_vx)))
vint32m1_t vwmul(vint16mf2_t, int16_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vwmul_vx_m)))
vint32m1_t vwmul(vbool32_t, vint32m1_t, vint16mf2_t, int16_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vwmul_vx)))
vint32m2_t vwmul(vint16m1_t, int16_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vwmul_vx_m)))
vint32m2_t vwmul(vbool16_t, vint32m2_t, vint16m1_t, int16_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vwmul_vx)))
vint32m4_t vwmul(vint16m2_t, int16_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vwmul_vx_m)))
vint32m4_t vwmul(vbool8_t, vint32m4_t, vint16m2_t, int16_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vwmul_vx)))
vint32m8_t vwmul(vint16m4_t, int16_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vwmul_vx_m)))
vint32m8_t vwmul(vbool4_t, vint32m8_t, vint16m4_t, int16_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vwmulu_vv)))
vuint16mf4_t vwmulu(vuint8mf8_t, vuint8mf8_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vwmulu_vv_m)))
vuint16mf4_t vwmulu(vbool64_t, vuint16mf4_t, vuint8mf8_t, vuint8mf8_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vwmulu_vv)))
vuint16mf2_t vwmulu(vuint8mf4_t, vuint8mf4_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vwmulu_vv_m)))
vuint16mf2_t vwmulu(vbool32_t, vuint16mf2_t, vuint8mf4_t, vuint8mf4_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vwmulu_vv)))
vuint16m1_t vwmulu(vuint8mf2_t, vuint8mf2_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vwmulu_vv_m)))
vuint16m1_t vwmulu(vbool16_t, vuint16m1_t, vuint8mf2_t, vuint8mf2_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vwmulu_vv)))
vuint16m2_t vwmulu(vuint8m1_t, vuint8m1_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vwmulu_vv_m)))
vuint16m2_t vwmulu(vbool8_t, vuint16m2_t, vuint8m1_t, vuint8m1_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vwmulu_vv)))
vuint16m4_t vwmulu(vuint8m2_t, vuint8m2_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vwmulu_vv_m)))
vuint16m4_t vwmulu(vbool4_t, vuint16m4_t, vuint8m2_t, vuint8m2_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vwmulu_vv)))
vuint16m8_t vwmulu(vuint8m4_t, vuint8m4_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vwmulu_vv_m)))
vuint16m8_t vwmulu(vbool2_t, vuint16m8_t, vuint8m4_t, vuint8m4_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vwmulu_vv)))
vuint32mf2_t vwmulu(vuint16mf4_t, vuint16mf4_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vwmulu_vv_m)))
vuint32mf2_t vwmulu(vbool64_t, vuint32mf2_t, vuint16mf4_t, vuint16mf4_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vwmulu_vv)))
vuint32m1_t vwmulu(vuint16mf2_t, vuint16mf2_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vwmulu_vv_m)))
vuint32m1_t vwmulu(vbool32_t, vuint32m1_t, vuint16mf2_t, vuint16mf2_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vwmulu_vv)))
vuint32m2_t vwmulu(vuint16m1_t, vuint16m1_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vwmulu_vv_m)))
vuint32m2_t vwmulu(vbool16_t, vuint32m2_t, vuint16m1_t, vuint16m1_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vwmulu_vv)))
vuint32m4_t vwmulu(vuint16m2_t, vuint16m2_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vwmulu_vv_m)))
vuint32m4_t vwmulu(vbool8_t, vuint32m4_t, vuint16m2_t, vuint16m2_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vwmulu_vv)))
vuint32m8_t vwmulu(vuint16m4_t, vuint16m4_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vwmulu_vv_m)))
vuint32m8_t vwmulu(vbool4_t, vuint32m8_t, vuint16m4_t, vuint16m4_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vwmulu_vx)))
vuint16mf4_t vwmulu(vuint8mf8_t, uint8_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vwmulu_vx_m)))
vuint16mf4_t vwmulu(vbool64_t, vuint16mf4_t, vuint8mf8_t, uint8_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vwmulu_vx)))
vuint16mf2_t vwmulu(vuint8mf4_t, uint8_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vwmulu_vx_m)))
vuint16mf2_t vwmulu(vbool32_t, vuint16mf2_t, vuint8mf4_t, uint8_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vwmulu_vx)))
vuint16m1_t vwmulu(vuint8mf2_t, uint8_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vwmulu_vx_m)))
vuint16m1_t vwmulu(vbool16_t, vuint16m1_t, vuint8mf2_t, uint8_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vwmulu_vx)))
vuint16m2_t vwmulu(vuint8m1_t, uint8_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vwmulu_vx_m)))
vuint16m2_t vwmulu(vbool8_t, vuint16m2_t, vuint8m1_t, uint8_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vwmulu_vx)))
vuint16m4_t vwmulu(vuint8m2_t, uint8_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vwmulu_vx_m)))
vuint16m4_t vwmulu(vbool4_t, vuint16m4_t, vuint8m2_t, uint8_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vwmulu_vx)))
vuint16m8_t vwmulu(vuint8m4_t, uint8_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vwmulu_vx_m)))
vuint16m8_t vwmulu(vbool2_t, vuint16m8_t, vuint8m4_t, uint8_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vwmulu_vx)))
vuint32mf2_t vwmulu(vuint16mf4_t, uint16_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vwmulu_vx_m)))
vuint32mf2_t vwmulu(vbool64_t, vuint32mf2_t, vuint16mf4_t, uint16_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vwmulu_vx)))
vuint32m1_t vwmulu(vuint16mf2_t, uint16_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vwmulu_vx_m)))
vuint32m1_t vwmulu(vbool32_t, vuint32m1_t, vuint16mf2_t, uint16_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vwmulu_vx)))
vuint32m2_t vwmulu(vuint16m1_t, uint16_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vwmulu_vx_m)))
vuint32m2_t vwmulu(vbool16_t, vuint32m2_t, vuint16m1_t, uint16_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vwmulu_vx)))
vuint32m4_t vwmulu(vuint16m2_t, uint16_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vwmulu_vx_m)))
vuint32m4_t vwmulu(vbool8_t, vuint32m4_t, vuint16m2_t, uint16_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vwmulu_vx)))
vuint32m8_t vwmulu(vuint16m4_t, uint16_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vwmulu_vx_m)))
vuint32m8_t vwmulu(vbool4_t, vuint32m8_t, vuint16m4_t, uint16_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vwmulsu_vv)))
vint16mf4_t vwmulsu(vint8mf8_t, vuint8mf8_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vwmulsu_vv_m)))
vint16mf4_t vwmulsu(vbool64_t, vint16mf4_t, vint8mf8_t, vuint8mf8_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vwmulsu_vv)))
vint16mf2_t vwmulsu(vint8mf4_t, vuint8mf4_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vwmulsu_vv_m)))
vint16mf2_t vwmulsu(vbool32_t, vint16mf2_t, vint8mf4_t, vuint8mf4_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vwmulsu_vv)))
vint16m1_t vwmulsu(vint8mf2_t, vuint8mf2_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vwmulsu_vv_m)))
vint16m1_t vwmulsu(vbool16_t, vint16m1_t, vint8mf2_t, vuint8mf2_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vwmulsu_vv)))
vint16m2_t vwmulsu(vint8m1_t, vuint8m1_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vwmulsu_vv_m)))
vint16m2_t vwmulsu(vbool8_t, vint16m2_t, vint8m1_t, vuint8m1_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vwmulsu_vv)))
vint16m4_t vwmulsu(vint8m2_t, vuint8m2_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vwmulsu_vv_m)))
vint16m4_t vwmulsu(vbool4_t, vint16m4_t, vint8m2_t, vuint8m2_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vwmulsu_vv)))
vint16m8_t vwmulsu(vint8m4_t, vuint8m4_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vwmulsu_vv_m)))
vint16m8_t vwmulsu(vbool2_t, vint16m8_t, vint8m4_t, vuint8m4_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vwmulsu_vv)))
vint32mf2_t vwmulsu(vint16mf4_t, vuint16mf4_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vwmulsu_vv_m)))
vint32mf2_t vwmulsu(vbool64_t, vint32mf2_t, vint16mf4_t, vuint16mf4_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vwmulsu_vv)))
vint32m1_t vwmulsu(vint16mf2_t, vuint16mf2_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vwmulsu_vv_m)))
vint32m1_t vwmulsu(vbool32_t, vint32m1_t, vint16mf2_t, vuint16mf2_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vwmulsu_vv)))
vint32m2_t vwmulsu(vint16m1_t, vuint16m1_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vwmulsu_vv_m)))
vint32m2_t vwmulsu(vbool16_t, vint32m2_t, vint16m1_t, vuint16m1_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vwmulsu_vv)))
vint32m4_t vwmulsu(vint16m2_t, vuint16m2_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vwmulsu_vv_m)))
vint32m4_t vwmulsu(vbool8_t, vint32m4_t, vint16m2_t, vuint16m2_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vwmulsu_vv)))
vint32m8_t vwmulsu(vint16m4_t, vuint16m4_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vwmulsu_vv_m)))
vint32m8_t vwmulsu(vbool4_t, vint32m8_t, vint16m4_t, vuint16m4_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vwmulsu_vx)))
vint16mf4_t vwmulsu(vint8mf8_t, uint8_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vwmulsu_vx_m)))
vint16mf4_t vwmulsu(vbool64_t, vint16mf4_t, vint8mf8_t, uint8_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vwmulsu_vx)))
vint16mf2_t vwmulsu(vint8mf4_t, uint8_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vwmulsu_vx_m)))
vint16mf2_t vwmulsu(vbool32_t, vint16mf2_t, vint8mf4_t, uint8_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vwmulsu_vx)))
vint16m1_t vwmulsu(vint8mf2_t, uint8_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vwmulsu_vx_m)))
vint16m1_t vwmulsu(vbool16_t, vint16m1_t, vint8mf2_t, uint8_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vwmulsu_vx)))
vint16m2_t vwmulsu(vint8m1_t, uint8_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vwmulsu_vx_m)))
vint16m2_t vwmulsu(vbool8_t, vint16m2_t, vint8m1_t, uint8_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vwmulsu_vx)))
vint16m4_t vwmulsu(vint8m2_t, uint8_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vwmulsu_vx_m)))
vint16m4_t vwmulsu(vbool4_t, vint16m4_t, vint8m2_t, uint8_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vwmulsu_vx)))
vint16m8_t vwmulsu(vint8m4_t, uint8_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vwmulsu_vx_m)))
vint16m8_t vwmulsu(vbool2_t, vint16m8_t, vint8m4_t, uint8_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vwmulsu_vx)))
vint32mf2_t vwmulsu(vint16mf4_t, uint16_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vwmulsu_vx_m)))
vint32mf2_t vwmulsu(vbool64_t, vint32mf2_t, vint16mf4_t, uint16_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vwmulsu_vx)))
vint32m1_t vwmulsu(vint16mf2_t, uint16_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vwmulsu_vx_m)))
vint32m1_t vwmulsu(vbool32_t, vint32m1_t, vint16mf2_t, uint16_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vwmulsu_vx)))
vint32m2_t vwmulsu(vint16m1_t, uint16_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vwmulsu_vx_m)))
vint32m2_t vwmulsu(vbool16_t, vint32m2_t, vint16m1_t, uint16_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vwmulsu_vx)))
vint32m4_t vwmulsu(vint16m2_t, uint16_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vwmulsu_vx_m)))
vint32m4_t vwmulsu(vbool8_t, vint32m4_t, vint16m2_t, uint16_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vwmulsu_vx)))
vint32m8_t vwmulsu(vint16m4_t, uint16_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vwmulsu_vx_m)))
vint32m8_t vwmulsu(vbool4_t, vint32m8_t, vint16m4_t, uint16_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vmacc_vv)))
vint8m1_t vmacc(vint8m1_t, vint8m1_t, vint8m1_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vmacc_vv_m)))
vint8m1_t vmacc(vbool8_t, vint8m1_t, vint8m1_t, vint8m1_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vmacc_vv)))
vint8m2_t vmacc(vint8m2_t, vint8m2_t, vint8m2_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vmacc_vv_m)))
vint8m2_t vmacc(vbool4_t, vint8m2_t, vint8m2_t, vint8m2_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vmacc_vv)))
vint8m4_t vmacc(vint8m4_t, vint8m4_t, vint8m4_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vmacc_vv_m)))
vint8m4_t vmacc(vbool2_t, vint8m4_t, vint8m4_t, vint8m4_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vmacc_vv)))
vint8m8_t vmacc(vint8m8_t, vint8m8_t, vint8m8_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vmacc_vv_m)))
vint8m8_t vmacc(vbool1_t, vint8m8_t, vint8m8_t, vint8m8_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vmacc_vv)))
vint8mf2_t vmacc(vint8mf2_t, vint8mf2_t, vint8mf2_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vmacc_vv_m)))
vint8mf2_t vmacc(vbool16_t, vint8mf2_t, vint8mf2_t, vint8mf2_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vmacc_vv)))
vint8mf4_t vmacc(vint8mf4_t, vint8mf4_t, vint8mf4_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vmacc_vv_m)))
vint8mf4_t vmacc(vbool32_t, vint8mf4_t, vint8mf4_t, vint8mf4_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vmacc_vv)))
vint8mf8_t vmacc(vint8mf8_t, vint8mf8_t, vint8mf8_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vmacc_vv_m)))
vint8mf8_t vmacc(vbool64_t, vint8mf8_t, vint8mf8_t, vint8mf8_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vmacc_vv)))
vint16m1_t vmacc(vint16m1_t, vint16m1_t, vint16m1_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vmacc_vv_m)))
vint16m1_t vmacc(vbool16_t, vint16m1_t, vint16m1_t, vint16m1_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vmacc_vv)))
vint16m2_t vmacc(vint16m2_t, vint16m2_t, vint16m2_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vmacc_vv_m)))
vint16m2_t vmacc(vbool8_t, vint16m2_t, vint16m2_t, vint16m2_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vmacc_vv)))
vint16m4_t vmacc(vint16m4_t, vint16m4_t, vint16m4_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vmacc_vv_m)))
vint16m4_t vmacc(vbool4_t, vint16m4_t, vint16m4_t, vint16m4_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vmacc_vv)))
vint16m8_t vmacc(vint16m8_t, vint16m8_t, vint16m8_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vmacc_vv_m)))
vint16m8_t vmacc(vbool2_t, vint16m8_t, vint16m8_t, vint16m8_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vmacc_vv)))
vint16mf2_t vmacc(vint16mf2_t, vint16mf2_t, vint16mf2_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vmacc_vv_m)))
vint16mf2_t vmacc(vbool32_t, vint16mf2_t, vint16mf2_t, vint16mf2_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vmacc_vv)))
vint16mf4_t vmacc(vint16mf4_t, vint16mf4_t, vint16mf4_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vmacc_vv_m)))
vint16mf4_t vmacc(vbool64_t, vint16mf4_t, vint16mf4_t, vint16mf4_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vmacc_vv)))
vint32m1_t vmacc(vint32m1_t, vint32m1_t, vint32m1_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vmacc_vv_m)))
vint32m1_t vmacc(vbool32_t, vint32m1_t, vint32m1_t, vint32m1_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vmacc_vv)))
vint32m2_t vmacc(vint32m2_t, vint32m2_t, vint32m2_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vmacc_vv_m)))
vint32m2_t vmacc(vbool16_t, vint32m2_t, vint32m2_t, vint32m2_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vmacc_vv)))
vint32m4_t vmacc(vint32m4_t, vint32m4_t, vint32m4_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vmacc_vv_m)))
vint32m4_t vmacc(vbool8_t, vint32m4_t, vint32m4_t, vint32m4_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vmacc_vv)))
vint32m8_t vmacc(vint32m8_t, vint32m8_t, vint32m8_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vmacc_vv_m)))
vint32m8_t vmacc(vbool4_t, vint32m8_t, vint32m8_t, vint32m8_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vmacc_vv)))
vint32mf2_t vmacc(vint32mf2_t, vint32mf2_t, vint32mf2_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vmacc_vv_m)))
vint32mf2_t vmacc(vbool64_t, vint32mf2_t, vint32mf2_t, vint32mf2_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vmacc_vx)))
vint8m1_t vmacc(vint8m1_t, int8_t, vint8m1_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vmacc_vx_m)))
vint8m1_t vmacc(vbool8_t, vint8m1_t, int8_t, vint8m1_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vmacc_vx)))
vint8m2_t vmacc(vint8m2_t, int8_t, vint8m2_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vmacc_vx_m)))
vint8m2_t vmacc(vbool4_t, vint8m2_t, int8_t, vint8m2_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vmacc_vx)))
vint8m4_t vmacc(vint8m4_t, int8_t, vint8m4_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vmacc_vx_m)))
vint8m4_t vmacc(vbool2_t, vint8m4_t, int8_t, vint8m4_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vmacc_vx)))
vint8m8_t vmacc(vint8m8_t, int8_t, vint8m8_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vmacc_vx_m)))
vint8m8_t vmacc(vbool1_t, vint8m8_t, int8_t, vint8m8_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vmacc_vx)))
vint8mf2_t vmacc(vint8mf2_t, int8_t, vint8mf2_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vmacc_vx_m)))
vint8mf2_t vmacc(vbool16_t, vint8mf2_t, int8_t, vint8mf2_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vmacc_vx)))
vint8mf4_t vmacc(vint8mf4_t, int8_t, vint8mf4_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vmacc_vx_m)))
vint8mf4_t vmacc(vbool32_t, vint8mf4_t, int8_t, vint8mf4_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vmacc_vx)))
vint8mf8_t vmacc(vint8mf8_t, int8_t, vint8mf8_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vmacc_vx_m)))
vint8mf8_t vmacc(vbool64_t, vint8mf8_t, int8_t, vint8mf8_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vmacc_vx)))
vint16m1_t vmacc(vint16m1_t, int16_t, vint16m1_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vmacc_vx_m)))
vint16m1_t vmacc(vbool16_t, vint16m1_t, int16_t, vint16m1_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vmacc_vx)))
vint16m2_t vmacc(vint16m2_t, int16_t, vint16m2_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vmacc_vx_m)))
vint16m2_t vmacc(vbool8_t, vint16m2_t, int16_t, vint16m2_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vmacc_vx)))
vint16m4_t vmacc(vint16m4_t, int16_t, vint16m4_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vmacc_vx_m)))
vint16m4_t vmacc(vbool4_t, vint16m4_t, int16_t, vint16m4_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vmacc_vx)))
vint16m8_t vmacc(vint16m8_t, int16_t, vint16m8_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vmacc_vx_m)))
vint16m8_t vmacc(vbool2_t, vint16m8_t, int16_t, vint16m8_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vmacc_vx)))
vint16mf2_t vmacc(vint16mf2_t, int16_t, vint16mf2_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vmacc_vx_m)))
vint16mf2_t vmacc(vbool32_t, vint16mf2_t, int16_t, vint16mf2_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vmacc_vx)))
vint16mf4_t vmacc(vint16mf4_t, int16_t, vint16mf4_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vmacc_vx_m)))
vint16mf4_t vmacc(vbool64_t, vint16mf4_t, int16_t, vint16mf4_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vmacc_vx)))
vint32m1_t vmacc(vint32m1_t, int32_t, vint32m1_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vmacc_vx_m)))
vint32m1_t vmacc(vbool32_t, vint32m1_t, int32_t, vint32m1_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vmacc_vx)))
vint32m2_t vmacc(vint32m2_t, int32_t, vint32m2_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vmacc_vx_m)))
vint32m2_t vmacc(vbool16_t, vint32m2_t, int32_t, vint32m2_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vmacc_vx)))
vint32m4_t vmacc(vint32m4_t, int32_t, vint32m4_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vmacc_vx_m)))
vint32m4_t vmacc(vbool8_t, vint32m4_t, int32_t, vint32m4_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vmacc_vx)))
vint32m8_t vmacc(vint32m8_t, int32_t, vint32m8_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vmacc_vx_m)))
vint32m8_t vmacc(vbool4_t, vint32m8_t, int32_t, vint32m8_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vmacc_vx)))
vint32mf2_t vmacc(vint32mf2_t, int32_t, vint32mf2_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vmacc_vx_m)))
vint32mf2_t vmacc(vbool64_t, vint32mf2_t, int32_t, vint32mf2_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vmacc_vv)))
vuint8m1_t vmacc(vuint8m1_t, vuint8m1_t, vuint8m1_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vmacc_vv_m)))
vuint8m1_t vmacc(vbool8_t, vuint8m1_t, vuint8m1_t, vuint8m1_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vmacc_vv)))
vuint8m2_t vmacc(vuint8m2_t, vuint8m2_t, vuint8m2_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vmacc_vv_m)))
vuint8m2_t vmacc(vbool4_t, vuint8m2_t, vuint8m2_t, vuint8m2_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vmacc_vv)))
vuint8m4_t vmacc(vuint8m4_t, vuint8m4_t, vuint8m4_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vmacc_vv_m)))
vuint8m4_t vmacc(vbool2_t, vuint8m4_t, vuint8m4_t, vuint8m4_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vmacc_vv)))
vuint8m8_t vmacc(vuint8m8_t, vuint8m8_t, vuint8m8_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vmacc_vv_m)))
vuint8m8_t vmacc(vbool1_t, vuint8m8_t, vuint8m8_t, vuint8m8_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vmacc_vv)))
vuint8mf2_t vmacc(vuint8mf2_t, vuint8mf2_t, vuint8mf2_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vmacc_vv_m)))
vuint8mf2_t vmacc(vbool16_t, vuint8mf2_t, vuint8mf2_t, vuint8mf2_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vmacc_vv)))
vuint8mf4_t vmacc(vuint8mf4_t, vuint8mf4_t, vuint8mf4_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vmacc_vv_m)))
vuint8mf4_t vmacc(vbool32_t, vuint8mf4_t, vuint8mf4_t, vuint8mf4_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vmacc_vv)))
vuint8mf8_t vmacc(vuint8mf8_t, vuint8mf8_t, vuint8mf8_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vmacc_vv_m)))
vuint8mf8_t vmacc(vbool64_t, vuint8mf8_t, vuint8mf8_t, vuint8mf8_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vmacc_vv)))
vuint16m1_t vmacc(vuint16m1_t, vuint16m1_t, vuint16m1_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vmacc_vv_m)))
vuint16m1_t vmacc(vbool16_t, vuint16m1_t, vuint16m1_t, vuint16m1_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vmacc_vv)))
vuint16m2_t vmacc(vuint16m2_t, vuint16m2_t, vuint16m2_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vmacc_vv_m)))
vuint16m2_t vmacc(vbool8_t, vuint16m2_t, vuint16m2_t, vuint16m2_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vmacc_vv)))
vuint16m4_t vmacc(vuint16m4_t, vuint16m4_t, vuint16m4_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vmacc_vv_m)))
vuint16m4_t vmacc(vbool4_t, vuint16m4_t, vuint16m4_t, vuint16m4_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vmacc_vv)))
vuint16m8_t vmacc(vuint16m8_t, vuint16m8_t, vuint16m8_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vmacc_vv_m)))
vuint16m8_t vmacc(vbool2_t, vuint16m8_t, vuint16m8_t, vuint16m8_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vmacc_vv)))
vuint16mf2_t vmacc(vuint16mf2_t, vuint16mf2_t, vuint16mf2_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vmacc_vv_m)))
vuint16mf2_t vmacc(vbool32_t, vuint16mf2_t, vuint16mf2_t, vuint16mf2_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vmacc_vv)))
vuint16mf4_t vmacc(vuint16mf4_t, vuint16mf4_t, vuint16mf4_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vmacc_vv_m)))
vuint16mf4_t vmacc(vbool64_t, vuint16mf4_t, vuint16mf4_t, vuint16mf4_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vmacc_vv)))
vuint32m1_t vmacc(vuint32m1_t, vuint32m1_t, vuint32m1_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vmacc_vv_m)))
vuint32m1_t vmacc(vbool32_t, vuint32m1_t, vuint32m1_t, vuint32m1_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vmacc_vv)))
vuint32m2_t vmacc(vuint32m2_t, vuint32m2_t, vuint32m2_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vmacc_vv_m)))
vuint32m2_t vmacc(vbool16_t, vuint32m2_t, vuint32m2_t, vuint32m2_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vmacc_vv)))
vuint32m4_t vmacc(vuint32m4_t, vuint32m4_t, vuint32m4_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vmacc_vv_m)))
vuint32m4_t vmacc(vbool8_t, vuint32m4_t, vuint32m4_t, vuint32m4_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vmacc_vv)))
vuint32m8_t vmacc(vuint32m8_t, vuint32m8_t, vuint32m8_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vmacc_vv_m)))
vuint32m8_t vmacc(vbool4_t, vuint32m8_t, vuint32m8_t, vuint32m8_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vmacc_vv)))
vuint32mf2_t vmacc(vuint32mf2_t, vuint32mf2_t, vuint32mf2_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vmacc_vv_m)))
vuint32mf2_t vmacc(vbool64_t, vuint32mf2_t, vuint32mf2_t, vuint32mf2_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vmacc_vx)))
vuint8m1_t vmacc(vuint8m1_t, uint8_t, vuint8m1_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vmacc_vx_m)))
vuint8m1_t vmacc(vbool8_t, vuint8m1_t, uint8_t, vuint8m1_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vmacc_vx)))
vuint8m2_t vmacc(vuint8m2_t, uint8_t, vuint8m2_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vmacc_vx_m)))
vuint8m2_t vmacc(vbool4_t, vuint8m2_t, uint8_t, vuint8m2_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vmacc_vx)))
vuint8m4_t vmacc(vuint8m4_t, uint8_t, vuint8m4_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vmacc_vx_m)))
vuint8m4_t vmacc(vbool2_t, vuint8m4_t, uint8_t, vuint8m4_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vmacc_vx)))
vuint8m8_t vmacc(vuint8m8_t, uint8_t, vuint8m8_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vmacc_vx_m)))
vuint8m8_t vmacc(vbool1_t, vuint8m8_t, uint8_t, vuint8m8_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vmacc_vx)))
vuint8mf2_t vmacc(vuint8mf2_t, uint8_t, vuint8mf2_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vmacc_vx_m)))
vuint8mf2_t vmacc(vbool16_t, vuint8mf2_t, uint8_t, vuint8mf2_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vmacc_vx)))
vuint8mf4_t vmacc(vuint8mf4_t, uint8_t, vuint8mf4_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vmacc_vx_m)))
vuint8mf4_t vmacc(vbool32_t, vuint8mf4_t, uint8_t, vuint8mf4_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vmacc_vx)))
vuint8mf8_t vmacc(vuint8mf8_t, uint8_t, vuint8mf8_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vmacc_vx_m)))
vuint8mf8_t vmacc(vbool64_t, vuint8mf8_t, uint8_t, vuint8mf8_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vmacc_vx)))
vuint16m1_t vmacc(vuint16m1_t, uint16_t, vuint16m1_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vmacc_vx_m)))
vuint16m1_t vmacc(vbool16_t, vuint16m1_t, uint16_t, vuint16m1_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vmacc_vx)))
vuint16m2_t vmacc(vuint16m2_t, uint16_t, vuint16m2_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vmacc_vx_m)))
vuint16m2_t vmacc(vbool8_t, vuint16m2_t, uint16_t, vuint16m2_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vmacc_vx)))
vuint16m4_t vmacc(vuint16m4_t, uint16_t, vuint16m4_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vmacc_vx_m)))
vuint16m4_t vmacc(vbool4_t, vuint16m4_t, uint16_t, vuint16m4_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vmacc_vx)))
vuint16m8_t vmacc(vuint16m8_t, uint16_t, vuint16m8_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vmacc_vx_m)))
vuint16m8_t vmacc(vbool2_t, vuint16m8_t, uint16_t, vuint16m8_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vmacc_vx)))
vuint16mf2_t vmacc(vuint16mf2_t, uint16_t, vuint16mf2_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vmacc_vx_m)))
vuint16mf2_t vmacc(vbool32_t, vuint16mf2_t, uint16_t, vuint16mf2_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vmacc_vx)))
vuint16mf4_t vmacc(vuint16mf4_t, uint16_t, vuint16mf4_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vmacc_vx_m)))
vuint16mf4_t vmacc(vbool64_t, vuint16mf4_t, uint16_t, vuint16mf4_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vmacc_vx)))
vuint32m1_t vmacc(vuint32m1_t, uint32_t, vuint32m1_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vmacc_vx_m)))
vuint32m1_t vmacc(vbool32_t, vuint32m1_t, uint32_t, vuint32m1_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vmacc_vx)))
vuint32m2_t vmacc(vuint32m2_t, uint32_t, vuint32m2_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vmacc_vx_m)))
vuint32m2_t vmacc(vbool16_t, vuint32m2_t, uint32_t, vuint32m2_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vmacc_vx)))
vuint32m4_t vmacc(vuint32m4_t, uint32_t, vuint32m4_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vmacc_vx_m)))
vuint32m4_t vmacc(vbool8_t, vuint32m4_t, uint32_t, vuint32m4_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vmacc_vx)))
vuint32m8_t vmacc(vuint32m8_t, uint32_t, vuint32m8_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vmacc_vx_m)))
vuint32m8_t vmacc(vbool4_t, vuint32m8_t, uint32_t, vuint32m8_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vmacc_vx)))
vuint32mf2_t vmacc(vuint32mf2_t, uint32_t, vuint32mf2_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vmacc_vx_m)))
vuint32mf2_t vmacc(vbool64_t, vuint32mf2_t, uint32_t, vuint32mf2_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vnmsac_vv)))
vint8m1_t vnmsac(vint8m1_t, vint8m1_t, vint8m1_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vnmsac_vv_m)))
vint8m1_t vnmsac(vbool8_t, vint8m1_t, vint8m1_t, vint8m1_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vnmsac_vv)))
vint8m2_t vnmsac(vint8m2_t, vint8m2_t, vint8m2_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vnmsac_vv_m)))
vint8m2_t vnmsac(vbool4_t, vint8m2_t, vint8m2_t, vint8m2_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vnmsac_vv)))
vint8m4_t vnmsac(vint8m4_t, vint8m4_t, vint8m4_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vnmsac_vv_m)))
vint8m4_t vnmsac(vbool2_t, vint8m4_t, vint8m4_t, vint8m4_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vnmsac_vv)))
vint8m8_t vnmsac(vint8m8_t, vint8m8_t, vint8m8_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vnmsac_vv_m)))
vint8m8_t vnmsac(vbool1_t, vint8m8_t, vint8m8_t, vint8m8_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vnmsac_vv)))
vint8mf2_t vnmsac(vint8mf2_t, vint8mf2_t, vint8mf2_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vnmsac_vv_m)))
vint8mf2_t vnmsac(vbool16_t, vint8mf2_t, vint8mf2_t, vint8mf2_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vnmsac_vv)))
vint8mf4_t vnmsac(vint8mf4_t, vint8mf4_t, vint8mf4_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vnmsac_vv_m)))
vint8mf4_t vnmsac(vbool32_t, vint8mf4_t, vint8mf4_t, vint8mf4_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vnmsac_vv)))
vint8mf8_t vnmsac(vint8mf8_t, vint8mf8_t, vint8mf8_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vnmsac_vv_m)))
vint8mf8_t vnmsac(vbool64_t, vint8mf8_t, vint8mf8_t, vint8mf8_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vnmsac_vv)))
vint16m1_t vnmsac(vint16m1_t, vint16m1_t, vint16m1_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vnmsac_vv_m)))
vint16m1_t vnmsac(vbool16_t, vint16m1_t, vint16m1_t, vint16m1_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vnmsac_vv)))
vint16m2_t vnmsac(vint16m2_t, vint16m2_t, vint16m2_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vnmsac_vv_m)))
vint16m2_t vnmsac(vbool8_t, vint16m2_t, vint16m2_t, vint16m2_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vnmsac_vv)))
vint16m4_t vnmsac(vint16m4_t, vint16m4_t, vint16m4_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vnmsac_vv_m)))
vint16m4_t vnmsac(vbool4_t, vint16m4_t, vint16m4_t, vint16m4_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vnmsac_vv)))
vint16m8_t vnmsac(vint16m8_t, vint16m8_t, vint16m8_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vnmsac_vv_m)))
vint16m8_t vnmsac(vbool2_t, vint16m8_t, vint16m8_t, vint16m8_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vnmsac_vv)))
vint16mf2_t vnmsac(vint16mf2_t, vint16mf2_t, vint16mf2_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vnmsac_vv_m)))
vint16mf2_t vnmsac(vbool32_t, vint16mf2_t, vint16mf2_t, vint16mf2_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vnmsac_vv)))
vint16mf4_t vnmsac(vint16mf4_t, vint16mf4_t, vint16mf4_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vnmsac_vv_m)))
vint16mf4_t vnmsac(vbool64_t, vint16mf4_t, vint16mf4_t, vint16mf4_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vnmsac_vv)))
vint32m1_t vnmsac(vint32m1_t, vint32m1_t, vint32m1_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vnmsac_vv_m)))
vint32m1_t vnmsac(vbool32_t, vint32m1_t, vint32m1_t, vint32m1_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vnmsac_vv)))
vint32m2_t vnmsac(vint32m2_t, vint32m2_t, vint32m2_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vnmsac_vv_m)))
vint32m2_t vnmsac(vbool16_t, vint32m2_t, vint32m2_t, vint32m2_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vnmsac_vv)))
vint32m4_t vnmsac(vint32m4_t, vint32m4_t, vint32m4_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vnmsac_vv_m)))
vint32m4_t vnmsac(vbool8_t, vint32m4_t, vint32m4_t, vint32m4_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vnmsac_vv)))
vint32m8_t vnmsac(vint32m8_t, vint32m8_t, vint32m8_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vnmsac_vv_m)))
vint32m8_t vnmsac(vbool4_t, vint32m8_t, vint32m8_t, vint32m8_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vnmsac_vv)))
vint32mf2_t vnmsac(vint32mf2_t, vint32mf2_t, vint32mf2_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vnmsac_vv_m)))
vint32mf2_t vnmsac(vbool64_t, vint32mf2_t, vint32mf2_t, vint32mf2_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vsuxei8_v)))
void vsuxei8(int16_t *, vuint8mf2_t, vint16m1_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vsuxei8_v_m)))
void vsuxei8(vbool16_t, int16_t *, vuint8mf2_t, vint16m1_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vsuxei8_v)))
void vsuxei8(int16_t *, vuint8m1_t, vint16m2_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vsuxei8_v_m)))
void vsuxei8(vbool8_t, int16_t *, vuint8m1_t, vint16m2_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vsuxei8_v)))
void vsuxei8(int16_t *, vuint8m2_t, vint16m4_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vsuxei8_v_m)))
void vsuxei8(vbool4_t, int16_t *, vuint8m2_t, vint16m4_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vsuxei8_v)))
void vsuxei8(int16_t *, vuint8m4_t, vint16m8_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vsuxei8_v_m)))
void vsuxei8(vbool2_t, int16_t *, vuint8m4_t, vint16m8_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vsuxei8_v)))
void vsuxei8(int16_t *, vuint8mf4_t, vint16mf2_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vsuxei8_v_m)))
void vsuxei8(vbool32_t, int16_t *, vuint8mf4_t, vint16mf2_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vsuxei8_v)))
void vsuxei8(int16_t *, vuint8mf8_t, vint16mf4_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vsuxei8_v_m)))
void vsuxei8(vbool64_t, int16_t *, vuint8mf8_t, vint16mf4_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vnmsac_vx)))
vint8m1_t vnmsac(vint8m1_t, int8_t, vint8m1_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vnmsac_vx_m)))
vint8m1_t vnmsac(vbool8_t, vint8m1_t, int8_t, vint8m1_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vnmsac_vx)))
vint8m2_t vnmsac(vint8m2_t, int8_t, vint8m2_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vnmsac_vx_m)))
vint8m2_t vnmsac(vbool4_t, vint8m2_t, int8_t, vint8m2_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vnmsac_vx)))
vint8m4_t vnmsac(vint8m4_t, int8_t, vint8m4_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vnmsac_vx_m)))
vint8m4_t vnmsac(vbool2_t, vint8m4_t, int8_t, vint8m4_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vnmsac_vx)))
vint8m8_t vnmsac(vint8m8_t, int8_t, vint8m8_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vnmsac_vx_m)))
vint8m8_t vnmsac(vbool1_t, vint8m8_t, int8_t, vint8m8_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vnmsac_vx)))
vint8mf2_t vnmsac(vint8mf2_t, int8_t, vint8mf2_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vnmsac_vx_m)))
vint8mf2_t vnmsac(vbool16_t, vint8mf2_t, int8_t, vint8mf2_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vnmsac_vx)))
vint8mf4_t vnmsac(vint8mf4_t, int8_t, vint8mf4_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vnmsac_vx_m)))
vint8mf4_t vnmsac(vbool32_t, vint8mf4_t, int8_t, vint8mf4_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vnmsac_vx)))
vint8mf8_t vnmsac(vint8mf8_t, int8_t, vint8mf8_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vnmsac_vx_m)))
vint8mf8_t vnmsac(vbool64_t, vint8mf8_t, int8_t, vint8mf8_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vnmsac_vx)))
vint16m1_t vnmsac(vint16m1_t, int16_t, vint16m1_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vnmsac_vx_m)))
vint16m1_t vnmsac(vbool16_t, vint16m1_t, int16_t, vint16m1_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vnmsac_vx)))
vint16m2_t vnmsac(vint16m2_t, int16_t, vint16m2_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vnmsac_vx_m)))
vint16m2_t vnmsac(vbool8_t, vint16m2_t, int16_t, vint16m2_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vnmsac_vx)))
vint16m4_t vnmsac(vint16m4_t, int16_t, vint16m4_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vnmsac_vx_m)))
vint16m4_t vnmsac(vbool4_t, vint16m4_t, int16_t, vint16m4_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vnmsac_vx)))
vint16m8_t vnmsac(vint16m8_t, int16_t, vint16m8_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vnmsac_vx_m)))
vint16m8_t vnmsac(vbool2_t, vint16m8_t, int16_t, vint16m8_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vnmsac_vx)))
vint16mf2_t vnmsac(vint16mf2_t, int16_t, vint16mf2_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vnmsac_vx_m)))
vint16mf2_t vnmsac(vbool32_t, vint16mf2_t, int16_t, vint16mf2_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vnmsac_vx)))
vint16mf4_t vnmsac(vint16mf4_t, int16_t, vint16mf4_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vnmsac_vx_m)))
vint16mf4_t vnmsac(vbool64_t, vint16mf4_t, int16_t, vint16mf4_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vnmsac_vx)))
vint32m1_t vnmsac(vint32m1_t, int32_t, vint32m1_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vnmsac_vx_m)))
vint32m1_t vnmsac(vbool32_t, vint32m1_t, int32_t, vint32m1_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vnmsac_vx)))
vint32m2_t vnmsac(vint32m2_t, int32_t, vint32m2_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vnmsac_vx_m)))
vint32m2_t vnmsac(vbool16_t, vint32m2_t, int32_t, vint32m2_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vnmsac_vx)))
vint32m4_t vnmsac(vint32m4_t, int32_t, vint32m4_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vnmsac_vx_m)))
vint32m4_t vnmsac(vbool8_t, vint32m4_t, int32_t, vint32m4_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vnmsac_vx)))
vint32m8_t vnmsac(vint32m8_t, int32_t, vint32m8_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vnmsac_vx_m)))
vint32m8_t vnmsac(vbool4_t, vint32m8_t, int32_t, vint32m8_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vnmsac_vx)))
vint32mf2_t vnmsac(vint32mf2_t, int32_t, vint32mf2_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vnmsac_vx_m)))
vint32mf2_t vnmsac(vbool64_t, vint32mf2_t, int32_t, vint32mf2_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vnmsac_vv)))
vuint8m1_t vnmsac(vuint8m1_t, vuint8m1_t, vuint8m1_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vnmsac_vv_m)))
vuint8m1_t vnmsac(vbool8_t, vuint8m1_t, vuint8m1_t, vuint8m1_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vnmsac_vv)))
vuint8m2_t vnmsac(vuint8m2_t, vuint8m2_t, vuint8m2_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vnmsac_vv_m)))
vuint8m2_t vnmsac(vbool4_t, vuint8m2_t, vuint8m2_t, vuint8m2_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vnmsac_vv)))
vuint8m4_t vnmsac(vuint8m4_t, vuint8m4_t, vuint8m4_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vnmsac_vv_m)))
vuint8m4_t vnmsac(vbool2_t, vuint8m4_t, vuint8m4_t, vuint8m4_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vnmsac_vv)))
vuint8m8_t vnmsac(vuint8m8_t, vuint8m8_t, vuint8m8_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vnmsac_vv_m)))
vuint8m8_t vnmsac(vbool1_t, vuint8m8_t, vuint8m8_t, vuint8m8_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vnmsac_vv)))
vuint8mf2_t vnmsac(vuint8mf2_t, vuint8mf2_t, vuint8mf2_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vnmsac_vv_m)))
vuint8mf2_t vnmsac(vbool16_t, vuint8mf2_t, vuint8mf2_t, vuint8mf2_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vnmsac_vv)))
vuint8mf4_t vnmsac(vuint8mf4_t, vuint8mf4_t, vuint8mf4_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vnmsac_vv_m)))
vuint8mf4_t vnmsac(vbool32_t, vuint8mf4_t, vuint8mf4_t, vuint8mf4_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vnmsac_vv)))
vuint8mf8_t vnmsac(vuint8mf8_t, vuint8mf8_t, vuint8mf8_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vnmsac_vv_m)))
vuint8mf8_t vnmsac(vbool64_t, vuint8mf8_t, vuint8mf8_t, vuint8mf8_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vnmsac_vv)))
vuint16m1_t vnmsac(vuint16m1_t, vuint16m1_t, vuint16m1_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vnmsac_vv_m)))
vuint16m1_t vnmsac(vbool16_t, vuint16m1_t, vuint16m1_t, vuint16m1_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vnmsac_vv)))
vuint16m2_t vnmsac(vuint16m2_t, vuint16m2_t, vuint16m2_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vnmsac_vv_m)))
vuint16m2_t vnmsac(vbool8_t, vuint16m2_t, vuint16m2_t, vuint16m2_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vnmsac_vv)))
vuint16m4_t vnmsac(vuint16m4_t, vuint16m4_t, vuint16m4_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vnmsac_vv_m)))
vuint16m4_t vnmsac(vbool4_t, vuint16m4_t, vuint16m4_t, vuint16m4_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vnmsac_vv)))
vuint16m8_t vnmsac(vuint16m8_t, vuint16m8_t, vuint16m8_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vnmsac_vv_m)))
vuint16m8_t vnmsac(vbool2_t, vuint16m8_t, vuint16m8_t, vuint16m8_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vnmsac_vv)))
vuint16mf2_t vnmsac(vuint16mf2_t, vuint16mf2_t, vuint16mf2_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vnmsac_vv_m)))
vuint16mf2_t vnmsac(vbool32_t, vuint16mf2_t, vuint16mf2_t, vuint16mf2_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vnmsac_vv)))
vuint16mf4_t vnmsac(vuint16mf4_t, vuint16mf4_t, vuint16mf4_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vnmsac_vv_m)))
vuint16mf4_t vnmsac(vbool64_t, vuint16mf4_t, vuint16mf4_t, vuint16mf4_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vnmsac_vv)))
vuint32m1_t vnmsac(vuint32m1_t, vuint32m1_t, vuint32m1_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vnmsac_vv_m)))
vuint32m1_t vnmsac(vbool32_t, vuint32m1_t, vuint32m1_t, vuint32m1_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vnmsac_vv)))
vuint32m2_t vnmsac(vuint32m2_t, vuint32m2_t, vuint32m2_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vnmsac_vv_m)))
vuint32m2_t vnmsac(vbool16_t, vuint32m2_t, vuint32m2_t, vuint32m2_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vnmsac_vv)))
vuint32m4_t vnmsac(vuint32m4_t, vuint32m4_t, vuint32m4_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vnmsac_vv_m)))
vuint32m4_t vnmsac(vbool8_t, vuint32m4_t, vuint32m4_t, vuint32m4_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vnmsac_vv)))
vuint32m8_t vnmsac(vuint32m8_t, vuint32m8_t, vuint32m8_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vnmsac_vv_m)))
vuint32m8_t vnmsac(vbool4_t, vuint32m8_t, vuint32m8_t, vuint32m8_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vnmsac_vv)))
vuint32mf2_t vnmsac(vuint32mf2_t, vuint32mf2_t, vuint32mf2_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vnmsac_vv_m)))
vuint32mf2_t vnmsac(vbool64_t, vuint32mf2_t, vuint32mf2_t, vuint32mf2_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vnmsac_vx)))
vuint8m1_t vnmsac(vuint8m1_t, uint8_t, vuint8m1_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vnmsac_vx_m)))
vuint8m1_t vnmsac(vbool8_t, vuint8m1_t, uint8_t, vuint8m1_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vnmsac_vx)))
vuint8m2_t vnmsac(vuint8m2_t, uint8_t, vuint8m2_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vnmsac_vx_m)))
vuint8m2_t vnmsac(vbool4_t, vuint8m2_t, uint8_t, vuint8m2_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vnmsac_vx)))
vuint8m4_t vnmsac(vuint8m4_t, uint8_t, vuint8m4_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vnmsac_vx_m)))
vuint8m4_t vnmsac(vbool2_t, vuint8m4_t, uint8_t, vuint8m4_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vnmsac_vx)))
vuint8m8_t vnmsac(vuint8m8_t, uint8_t, vuint8m8_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vnmsac_vx_m)))
vuint8m8_t vnmsac(vbool1_t, vuint8m8_t, uint8_t, vuint8m8_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vnmsac_vx)))
vuint8mf2_t vnmsac(vuint8mf2_t, uint8_t, vuint8mf2_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vnmsac_vx_m)))
vuint8mf2_t vnmsac(vbool16_t, vuint8mf2_t, uint8_t, vuint8mf2_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vnmsac_vx)))
vuint8mf4_t vnmsac(vuint8mf4_t, uint8_t, vuint8mf4_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vnmsac_vx_m)))
vuint8mf4_t vnmsac(vbool32_t, vuint8mf4_t, uint8_t, vuint8mf4_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vnmsac_vx)))
vuint8mf8_t vnmsac(vuint8mf8_t, uint8_t, vuint8mf8_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vnmsac_vx_m)))
vuint8mf8_t vnmsac(vbool64_t, vuint8mf8_t, uint8_t, vuint8mf8_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vnmsac_vx)))
vuint16m1_t vnmsac(vuint16m1_t, uint16_t, vuint16m1_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vnmsac_vx_m)))
vuint16m1_t vnmsac(vbool16_t, vuint16m1_t, uint16_t, vuint16m1_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vnmsac_vx)))
vuint16m2_t vnmsac(vuint16m2_t, uint16_t, vuint16m2_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vnmsac_vx_m)))
vuint16m2_t vnmsac(vbool8_t, vuint16m2_t, uint16_t, vuint16m2_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vnmsac_vx)))
vuint16m4_t vnmsac(vuint16m4_t, uint16_t, vuint16m4_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vnmsac_vx_m)))
vuint16m4_t vnmsac(vbool4_t, vuint16m4_t, uint16_t, vuint16m4_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vnmsac_vx)))
vuint16m8_t vnmsac(vuint16m8_t, uint16_t, vuint16m8_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vnmsac_vx_m)))
vuint16m8_t vnmsac(vbool2_t, vuint16m8_t, uint16_t, vuint16m8_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vnmsac_vx)))
vuint16mf2_t vnmsac(vuint16mf2_t, uint16_t, vuint16mf2_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vnmsac_vx_m)))
vuint16mf2_t vnmsac(vbool32_t, vuint16mf2_t, uint16_t, vuint16mf2_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vnmsac_vx)))
vuint16mf4_t vnmsac(vuint16mf4_t, uint16_t, vuint16mf4_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vnmsac_vx_m)))
vuint16mf4_t vnmsac(vbool64_t, vuint16mf4_t, uint16_t, vuint16mf4_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vnmsac_vx)))
vuint32m1_t vnmsac(vuint32m1_t, uint32_t, vuint32m1_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vnmsac_vx_m)))
vuint32m1_t vnmsac(vbool32_t, vuint32m1_t, uint32_t, vuint32m1_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vnmsac_vx)))
vuint32m2_t vnmsac(vuint32m2_t, uint32_t, vuint32m2_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vnmsac_vx_m)))
vuint32m2_t vnmsac(vbool16_t, vuint32m2_t, uint32_t, vuint32m2_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vnmsac_vx)))
vuint32m4_t vnmsac(vuint32m4_t, uint32_t, vuint32m4_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vnmsac_vx_m)))
vuint32m4_t vnmsac(vbool8_t, vuint32m4_t, uint32_t, vuint32m4_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vnmsac_vx)))
vuint32m8_t vnmsac(vuint32m8_t, uint32_t, vuint32m8_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vnmsac_vx_m)))
vuint32m8_t vnmsac(vbool4_t, vuint32m8_t, uint32_t, vuint32m8_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vnmsac_vx)))
vuint32mf2_t vnmsac(vuint32mf2_t, uint32_t, vuint32mf2_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vnmsac_vx_m)))
vuint32mf2_t vnmsac(vbool64_t, vuint32mf2_t, uint32_t, vuint32mf2_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vmadd_vv)))
vint8m1_t vmadd(vint8m1_t, vint8m1_t, vint8m1_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vmadd_vv_m)))
vint8m1_t vmadd(vbool8_t, vint8m1_t, vint8m1_t, vint8m1_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vmadd_vv)))
vint8m2_t vmadd(vint8m2_t, vint8m2_t, vint8m2_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vmadd_vv_m)))
vint8m2_t vmadd(vbool4_t, vint8m2_t, vint8m2_t, vint8m2_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vmadd_vv)))
vint8m4_t vmadd(vint8m4_t, vint8m4_t, vint8m4_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vmadd_vv_m)))
vint8m4_t vmadd(vbool2_t, vint8m4_t, vint8m4_t, vint8m4_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vmadd_vv)))
vint8m8_t vmadd(vint8m8_t, vint8m8_t, vint8m8_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vmadd_vv_m)))
vint8m8_t vmadd(vbool1_t, vint8m8_t, vint8m8_t, vint8m8_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vmadd_vv)))
vint8mf2_t vmadd(vint8mf2_t, vint8mf2_t, vint8mf2_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vmadd_vv_m)))
vint8mf2_t vmadd(vbool16_t, vint8mf2_t, vint8mf2_t, vint8mf2_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vmadd_vv)))
vint8mf4_t vmadd(vint8mf4_t, vint8mf4_t, vint8mf4_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vmadd_vv_m)))
vint8mf4_t vmadd(vbool32_t, vint8mf4_t, vint8mf4_t, vint8mf4_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vmadd_vv)))
vint8mf8_t vmadd(vint8mf8_t, vint8mf8_t, vint8mf8_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vmadd_vv_m)))
vint8mf8_t vmadd(vbool64_t, vint8mf8_t, vint8mf8_t, vint8mf8_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vmadd_vv)))
vint16m1_t vmadd(vint16m1_t, vint16m1_t, vint16m1_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vmadd_vv_m)))
vint16m1_t vmadd(vbool16_t, vint16m1_t, vint16m1_t, vint16m1_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vmadd_vv)))
vint16m2_t vmadd(vint16m2_t, vint16m2_t, vint16m2_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vmadd_vv_m)))
vint16m2_t vmadd(vbool8_t, vint16m2_t, vint16m2_t, vint16m2_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vmadd_vv)))
vint16m4_t vmadd(vint16m4_t, vint16m4_t, vint16m4_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vmadd_vv_m)))
vint16m4_t vmadd(vbool4_t, vint16m4_t, vint16m4_t, vint16m4_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vmadd_vv)))
vint16m8_t vmadd(vint16m8_t, vint16m8_t, vint16m8_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vmadd_vv_m)))
vint16m8_t vmadd(vbool2_t, vint16m8_t, vint16m8_t, vint16m8_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vmadd_vv)))
vint16mf2_t vmadd(vint16mf2_t, vint16mf2_t, vint16mf2_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vmadd_vv_m)))
vint16mf2_t vmadd(vbool32_t, vint16mf2_t, vint16mf2_t, vint16mf2_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vmadd_vv)))
vint16mf4_t vmadd(vint16mf4_t, vint16mf4_t, vint16mf4_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vmadd_vv_m)))
vint16mf4_t vmadd(vbool64_t, vint16mf4_t, vint16mf4_t, vint16mf4_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vmadd_vv)))
vint32m1_t vmadd(vint32m1_t, vint32m1_t, vint32m1_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vmadd_vv_m)))
vint32m1_t vmadd(vbool32_t, vint32m1_t, vint32m1_t, vint32m1_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vmadd_vv)))
vint32m2_t vmadd(vint32m2_t, vint32m2_t, vint32m2_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vmadd_vv_m)))
vint32m2_t vmadd(vbool16_t, vint32m2_t, vint32m2_t, vint32m2_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vmadd_vv)))
vint32m4_t vmadd(vint32m4_t, vint32m4_t, vint32m4_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vmadd_vv_m)))
vint32m4_t vmadd(vbool8_t, vint32m4_t, vint32m4_t, vint32m4_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vmadd_vv)))
vint32m8_t vmadd(vint32m8_t, vint32m8_t, vint32m8_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vmadd_vv_m)))
vint32m8_t vmadd(vbool4_t, vint32m8_t, vint32m8_t, vint32m8_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vmadd_vv)))
vint32mf2_t vmadd(vint32mf2_t, vint32mf2_t, vint32mf2_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vmadd_vv_m)))
vint32mf2_t vmadd(vbool64_t, vint32mf2_t, vint32mf2_t, vint32mf2_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vmadd_vx)))
vint8m1_t vmadd(vint8m1_t, int8_t, vint8m1_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vmadd_vx_m)))
vint8m1_t vmadd(vbool8_t, vint8m1_t, int8_t, vint8m1_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vmadd_vx)))
vint8m2_t vmadd(vint8m2_t, int8_t, vint8m2_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vmadd_vx_m)))
vint8m2_t vmadd(vbool4_t, vint8m2_t, int8_t, vint8m2_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vmadd_vx)))
vint8m4_t vmadd(vint8m4_t, int8_t, vint8m4_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vmadd_vx_m)))
vint8m4_t vmadd(vbool2_t, vint8m4_t, int8_t, vint8m4_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vmadd_vx)))
vint8m8_t vmadd(vint8m8_t, int8_t, vint8m8_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vmadd_vx_m)))
vint8m8_t vmadd(vbool1_t, vint8m8_t, int8_t, vint8m8_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vmadd_vx)))
vint8mf2_t vmadd(vint8mf2_t, int8_t, vint8mf2_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vmadd_vx_m)))
vint8mf2_t vmadd(vbool16_t, vint8mf2_t, int8_t, vint8mf2_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vmadd_vx)))
vint8mf4_t vmadd(vint8mf4_t, int8_t, vint8mf4_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vmadd_vx_m)))
vint8mf4_t vmadd(vbool32_t, vint8mf4_t, int8_t, vint8mf4_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vmadd_vx)))
vint8mf8_t vmadd(vint8mf8_t, int8_t, vint8mf8_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vmadd_vx_m)))
vint8mf8_t vmadd(vbool64_t, vint8mf8_t, int8_t, vint8mf8_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vmadd_vx)))
vint16m1_t vmadd(vint16m1_t, int16_t, vint16m1_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vmadd_vx_m)))
vint16m1_t vmadd(vbool16_t, vint16m1_t, int16_t, vint16m1_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vmadd_vx)))
vint16m2_t vmadd(vint16m2_t, int16_t, vint16m2_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vmadd_vx_m)))
vint16m2_t vmadd(vbool8_t, vint16m2_t, int16_t, vint16m2_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vmadd_vx)))
vint16m4_t vmadd(vint16m4_t, int16_t, vint16m4_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vmadd_vx_m)))
vint16m4_t vmadd(vbool4_t, vint16m4_t, int16_t, vint16m4_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vmadd_vx)))
vint16m8_t vmadd(vint16m8_t, int16_t, vint16m8_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vmadd_vx_m)))
vint16m8_t vmadd(vbool2_t, vint16m8_t, int16_t, vint16m8_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vmadd_vx)))
vint16mf2_t vmadd(vint16mf2_t, int16_t, vint16mf2_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vmadd_vx_m)))
vint16mf2_t vmadd(vbool32_t, vint16mf2_t, int16_t, vint16mf2_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vmadd_vx)))
vint16mf4_t vmadd(vint16mf4_t, int16_t, vint16mf4_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vmadd_vx_m)))
vint16mf4_t vmadd(vbool64_t, vint16mf4_t, int16_t, vint16mf4_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vmadd_vx)))
vint32m1_t vmadd(vint32m1_t, int32_t, vint32m1_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vmadd_vx_m)))
vint32m1_t vmadd(vbool32_t, vint32m1_t, int32_t, vint32m1_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vmadd_vx)))
vint32m2_t vmadd(vint32m2_t, int32_t, vint32m2_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vmadd_vx_m)))
vint32m2_t vmadd(vbool16_t, vint32m2_t, int32_t, vint32m2_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vmadd_vx)))
vint32m4_t vmadd(vint32m4_t, int32_t, vint32m4_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vmadd_vx_m)))
vint32m4_t vmadd(vbool8_t, vint32m4_t, int32_t, vint32m4_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vmadd_vx)))
vint32m8_t vmadd(vint32m8_t, int32_t, vint32m8_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vmadd_vx_m)))
vint32m8_t vmadd(vbool4_t, vint32m8_t, int32_t, vint32m8_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vmadd_vx)))
vint32mf2_t vmadd(vint32mf2_t, int32_t, vint32mf2_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vmadd_vx_m)))
vint32mf2_t vmadd(vbool64_t, vint32mf2_t, int32_t, vint32mf2_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vmadd_vv)))
vuint8m1_t vmadd(vuint8m1_t, vuint8m1_t, vuint8m1_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vmadd_vv_m)))
vuint8m1_t vmadd(vbool8_t, vuint8m1_t, vuint8m1_t, vuint8m1_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vmadd_vv)))
vuint8m2_t vmadd(vuint8m2_t, vuint8m2_t, vuint8m2_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vmadd_vv_m)))
vuint8m2_t vmadd(vbool4_t, vuint8m2_t, vuint8m2_t, vuint8m2_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vmadd_vv)))
vuint8m4_t vmadd(vuint8m4_t, vuint8m4_t, vuint8m4_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vmadd_vv_m)))
vuint8m4_t vmadd(vbool2_t, vuint8m4_t, vuint8m4_t, vuint8m4_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vmadd_vv)))
vuint8m8_t vmadd(vuint8m8_t, vuint8m8_t, vuint8m8_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vmadd_vv_m)))
vuint8m8_t vmadd(vbool1_t, vuint8m8_t, vuint8m8_t, vuint8m8_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vmadd_vv)))
vuint8mf2_t vmadd(vuint8mf2_t, vuint8mf2_t, vuint8mf2_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vmadd_vv_m)))
vuint8mf2_t vmadd(vbool16_t, vuint8mf2_t, vuint8mf2_t, vuint8mf2_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vmadd_vv)))
vuint8mf4_t vmadd(vuint8mf4_t, vuint8mf4_t, vuint8mf4_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vmadd_vv_m)))
vuint8mf4_t vmadd(vbool32_t, vuint8mf4_t, vuint8mf4_t, vuint8mf4_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vmadd_vv)))
vuint8mf8_t vmadd(vuint8mf8_t, vuint8mf8_t, vuint8mf8_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vmadd_vv_m)))
vuint8mf8_t vmadd(vbool64_t, vuint8mf8_t, vuint8mf8_t, vuint8mf8_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vmadd_vv)))
vuint16m1_t vmadd(vuint16m1_t, vuint16m1_t, vuint16m1_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vmadd_vv_m)))
vuint16m1_t vmadd(vbool16_t, vuint16m1_t, vuint16m1_t, vuint16m1_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vmadd_vv)))
vuint16m2_t vmadd(vuint16m2_t, vuint16m2_t, vuint16m2_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vmadd_vv_m)))
vuint16m2_t vmadd(vbool8_t, vuint16m2_t, vuint16m2_t, vuint16m2_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vmadd_vv)))
vuint16m4_t vmadd(vuint16m4_t, vuint16m4_t, vuint16m4_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vmadd_vv_m)))
vuint16m4_t vmadd(vbool4_t, vuint16m4_t, vuint16m4_t, vuint16m4_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vmadd_vv)))
vuint16m8_t vmadd(vuint16m8_t, vuint16m8_t, vuint16m8_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vmadd_vv_m)))
vuint16m8_t vmadd(vbool2_t, vuint16m8_t, vuint16m8_t, vuint16m8_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vmadd_vv)))
vuint16mf2_t vmadd(vuint16mf2_t, vuint16mf2_t, vuint16mf2_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vmadd_vv_m)))
vuint16mf2_t vmadd(vbool32_t, vuint16mf2_t, vuint16mf2_t, vuint16mf2_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vmadd_vv)))
vuint16mf4_t vmadd(vuint16mf4_t, vuint16mf4_t, vuint16mf4_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vmadd_vv_m)))
vuint16mf4_t vmadd(vbool64_t, vuint16mf4_t, vuint16mf4_t, vuint16mf4_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vmadd_vv)))
vuint32m1_t vmadd(vuint32m1_t, vuint32m1_t, vuint32m1_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vmadd_vv_m)))
vuint32m1_t vmadd(vbool32_t, vuint32m1_t, vuint32m1_t, vuint32m1_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vmadd_vv)))
vuint32m2_t vmadd(vuint32m2_t, vuint32m2_t, vuint32m2_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vmadd_vv_m)))
vuint32m2_t vmadd(vbool16_t, vuint32m2_t, vuint32m2_t, vuint32m2_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vmadd_vv)))
vuint32m4_t vmadd(vuint32m4_t, vuint32m4_t, vuint32m4_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vmadd_vv_m)))
vuint32m4_t vmadd(vbool8_t, vuint32m4_t, vuint32m4_t, vuint32m4_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vmadd_vv)))
vuint32m8_t vmadd(vuint32m8_t, vuint32m8_t, vuint32m8_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vmadd_vv_m)))
vuint32m8_t vmadd(vbool4_t, vuint32m8_t, vuint32m8_t, vuint32m8_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vmadd_vv)))
vuint32mf2_t vmadd(vuint32mf2_t, vuint32mf2_t, vuint32mf2_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vmadd_vv_m)))
vuint32mf2_t vmadd(vbool64_t, vuint32mf2_t, vuint32mf2_t, vuint32mf2_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vmadd_vx)))
vuint8m1_t vmadd(vuint8m1_t, uint8_t, vuint8m1_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vmadd_vx_m)))
vuint8m1_t vmadd(vbool8_t, vuint8m1_t, uint8_t, vuint8m1_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vmadd_vx)))
vuint8m2_t vmadd(vuint8m2_t, uint8_t, vuint8m2_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vmadd_vx_m)))
vuint8m2_t vmadd(vbool4_t, vuint8m2_t, uint8_t, vuint8m2_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vmadd_vx)))
vuint8m4_t vmadd(vuint8m4_t, uint8_t, vuint8m4_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vmadd_vx_m)))
vuint8m4_t vmadd(vbool2_t, vuint8m4_t, uint8_t, vuint8m4_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vmadd_vx)))
vuint8m8_t vmadd(vuint8m8_t, uint8_t, vuint8m8_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vmadd_vx_m)))
vuint8m8_t vmadd(vbool1_t, vuint8m8_t, uint8_t, vuint8m8_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vmadd_vx)))
vuint8mf2_t vmadd(vuint8mf2_t, uint8_t, vuint8mf2_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vmadd_vx_m)))
vuint8mf2_t vmadd(vbool16_t, vuint8mf2_t, uint8_t, vuint8mf2_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vmadd_vx)))
vuint8mf4_t vmadd(vuint8mf4_t, uint8_t, vuint8mf4_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vmadd_vx_m)))
vuint8mf4_t vmadd(vbool32_t, vuint8mf4_t, uint8_t, vuint8mf4_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vmadd_vx)))
vuint8mf8_t vmadd(vuint8mf8_t, uint8_t, vuint8mf8_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vmadd_vx_m)))
vuint8mf8_t vmadd(vbool64_t, vuint8mf8_t, uint8_t, vuint8mf8_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vmadd_vx)))
vuint16m1_t vmadd(vuint16m1_t, uint16_t, vuint16m1_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vmadd_vx_m)))
vuint16m1_t vmadd(vbool16_t, vuint16m1_t, uint16_t, vuint16m1_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vmadd_vx)))
vuint16m2_t vmadd(vuint16m2_t, uint16_t, vuint16m2_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vmadd_vx_m)))
vuint16m2_t vmadd(vbool8_t, vuint16m2_t, uint16_t, vuint16m2_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vmadd_vx)))
vuint16m4_t vmadd(vuint16m4_t, uint16_t, vuint16m4_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vmadd_vx_m)))
vuint16m4_t vmadd(vbool4_t, vuint16m4_t, uint16_t, vuint16m4_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vmadd_vx)))
vuint16m8_t vmadd(vuint16m8_t, uint16_t, vuint16m8_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vmadd_vx_m)))
vuint16m8_t vmadd(vbool2_t, vuint16m8_t, uint16_t, vuint16m8_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vmadd_vx)))
vuint16mf2_t vmadd(vuint16mf2_t, uint16_t, vuint16mf2_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vmadd_vx_m)))
vuint16mf2_t vmadd(vbool32_t, vuint16mf2_t, uint16_t, vuint16mf2_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vmadd_vx)))
vuint16mf4_t vmadd(vuint16mf4_t, uint16_t, vuint16mf4_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vmadd_vx_m)))
vuint16mf4_t vmadd(vbool64_t, vuint16mf4_t, uint16_t, vuint16mf4_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vmadd_vx)))
vuint32m1_t vmadd(vuint32m1_t, uint32_t, vuint32m1_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vmadd_vx_m)))
vuint32m1_t vmadd(vbool32_t, vuint32m1_t, uint32_t, vuint32m1_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vmadd_vx)))
vuint32m2_t vmadd(vuint32m2_t, uint32_t, vuint32m2_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vmadd_vx_m)))
vuint32m2_t vmadd(vbool16_t, vuint32m2_t, uint32_t, vuint32m2_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vmadd_vx)))
vuint32m4_t vmadd(vuint32m4_t, uint32_t, vuint32m4_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vmadd_vx_m)))
vuint32m4_t vmadd(vbool8_t, vuint32m4_t, uint32_t, vuint32m4_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vmadd_vx)))
vuint32m8_t vmadd(vuint32m8_t, uint32_t, vuint32m8_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vmadd_vx_m)))
vuint32m8_t vmadd(vbool4_t, vuint32m8_t, uint32_t, vuint32m8_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vmadd_vx)))
vuint32mf2_t vmadd(vuint32mf2_t, uint32_t, vuint32mf2_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vmadd_vx_m)))
vuint32mf2_t vmadd(vbool64_t, vuint32mf2_t, uint32_t, vuint32mf2_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vnmsub_vv)))
vint8m1_t vnmsub(vint8m1_t, vint8m1_t, vint8m1_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vnmsub_vv_m)))
vint8m1_t vnmsub(vbool8_t, vint8m1_t, vint8m1_t, vint8m1_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vnmsub_vv)))
vint8m2_t vnmsub(vint8m2_t, vint8m2_t, vint8m2_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vnmsub_vv_m)))
vint8m2_t vnmsub(vbool4_t, vint8m2_t, vint8m2_t, vint8m2_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vnmsub_vv)))
vint8m4_t vnmsub(vint8m4_t, vint8m4_t, vint8m4_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vnmsub_vv_m)))
vint8m4_t vnmsub(vbool2_t, vint8m4_t, vint8m4_t, vint8m4_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vnmsub_vv)))
vint8m8_t vnmsub(vint8m8_t, vint8m8_t, vint8m8_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vnmsub_vv_m)))
vint8m8_t vnmsub(vbool1_t, vint8m8_t, vint8m8_t, vint8m8_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vnmsub_vv)))
vint8mf2_t vnmsub(vint8mf2_t, vint8mf2_t, vint8mf2_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vnmsub_vv_m)))
vint8mf2_t vnmsub(vbool16_t, vint8mf2_t, vint8mf2_t, vint8mf2_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vnmsub_vv)))
vint8mf4_t vnmsub(vint8mf4_t, vint8mf4_t, vint8mf4_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vnmsub_vv_m)))
vint8mf4_t vnmsub(vbool32_t, vint8mf4_t, vint8mf4_t, vint8mf4_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vnmsub_vv)))
vint8mf8_t vnmsub(vint8mf8_t, vint8mf8_t, vint8mf8_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vnmsub_vv_m)))
vint8mf8_t vnmsub(vbool64_t, vint8mf8_t, vint8mf8_t, vint8mf8_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vnmsub_vv)))
vint16m1_t vnmsub(vint16m1_t, vint16m1_t, vint16m1_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vnmsub_vv_m)))
vint16m1_t vnmsub(vbool16_t, vint16m1_t, vint16m1_t, vint16m1_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vnmsub_vv)))
vint16m2_t vnmsub(vint16m2_t, vint16m2_t, vint16m2_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vnmsub_vv_m)))
vint16m2_t vnmsub(vbool8_t, vint16m2_t, vint16m2_t, vint16m2_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vnmsub_vv)))
vint16m4_t vnmsub(vint16m4_t, vint16m4_t, vint16m4_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vnmsub_vv_m)))
vint16m4_t vnmsub(vbool4_t, vint16m4_t, vint16m4_t, vint16m4_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vnmsub_vv)))
vint16m8_t vnmsub(vint16m8_t, vint16m8_t, vint16m8_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vnmsub_vv_m)))
vint16m8_t vnmsub(vbool2_t, vint16m8_t, vint16m8_t, vint16m8_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vnmsub_vv)))
vint16mf2_t vnmsub(vint16mf2_t, vint16mf2_t, vint16mf2_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vnmsub_vv_m)))
vint16mf2_t vnmsub(vbool32_t, vint16mf2_t, vint16mf2_t, vint16mf2_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vnmsub_vv)))
vint16mf4_t vnmsub(vint16mf4_t, vint16mf4_t, vint16mf4_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vnmsub_vv_m)))
vint16mf4_t vnmsub(vbool64_t, vint16mf4_t, vint16mf4_t, vint16mf4_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vnmsub_vv)))
vint32m1_t vnmsub(vint32m1_t, vint32m1_t, vint32m1_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vnmsub_vv_m)))
vint32m1_t vnmsub(vbool32_t, vint32m1_t, vint32m1_t, vint32m1_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vnmsub_vv)))
vint32m2_t vnmsub(vint32m2_t, vint32m2_t, vint32m2_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vnmsub_vv_m)))
vint32m2_t vnmsub(vbool16_t, vint32m2_t, vint32m2_t, vint32m2_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vnmsub_vv)))
vint32m4_t vnmsub(vint32m4_t, vint32m4_t, vint32m4_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vnmsub_vv_m)))
vint32m4_t vnmsub(vbool8_t, vint32m4_t, vint32m4_t, vint32m4_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vnmsub_vv)))
vint32m8_t vnmsub(vint32m8_t, vint32m8_t, vint32m8_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vnmsub_vv_m)))
vint32m8_t vnmsub(vbool4_t, vint32m8_t, vint32m8_t, vint32m8_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vnmsub_vv)))
vint32mf2_t vnmsub(vint32mf2_t, vint32mf2_t, vint32mf2_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vnmsub_vv_m)))
vint32mf2_t vnmsub(vbool64_t, vint32mf2_t, vint32mf2_t, vint32mf2_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vnmsub_vx)))
vint8m1_t vnmsub(vint8m1_t, int8_t, vint8m1_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vnmsub_vx_m)))
vint8m1_t vnmsub(vbool8_t, vint8m1_t, int8_t, vint8m1_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vnmsub_vx)))
vint8m2_t vnmsub(vint8m2_t, int8_t, vint8m2_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vnmsub_vx_m)))
vint8m2_t vnmsub(vbool4_t, vint8m2_t, int8_t, vint8m2_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vnmsub_vx)))
vint8m4_t vnmsub(vint8m4_t, int8_t, vint8m4_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vnmsub_vx_m)))
vint8m4_t vnmsub(vbool2_t, vint8m4_t, int8_t, vint8m4_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vnmsub_vx)))
vint8m8_t vnmsub(vint8m8_t, int8_t, vint8m8_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vnmsub_vx_m)))
vint8m8_t vnmsub(vbool1_t, vint8m8_t, int8_t, vint8m8_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vnmsub_vx)))
vint8mf2_t vnmsub(vint8mf2_t, int8_t, vint8mf2_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vnmsub_vx_m)))
vint8mf2_t vnmsub(vbool16_t, vint8mf2_t, int8_t, vint8mf2_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vnmsub_vx)))
vint8mf4_t vnmsub(vint8mf4_t, int8_t, vint8mf4_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vnmsub_vx_m)))
vint8mf4_t vnmsub(vbool32_t, vint8mf4_t, int8_t, vint8mf4_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vnmsub_vx)))
vint8mf8_t vnmsub(vint8mf8_t, int8_t, vint8mf8_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vnmsub_vx_m)))
vint8mf8_t vnmsub(vbool64_t, vint8mf8_t, int8_t, vint8mf8_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vnmsub_vx)))
vint16m1_t vnmsub(vint16m1_t, int16_t, vint16m1_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vnmsub_vx_m)))
vint16m1_t vnmsub(vbool16_t, vint16m1_t, int16_t, vint16m1_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vnmsub_vx)))
vint16m2_t vnmsub(vint16m2_t, int16_t, vint16m2_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vnmsub_vx_m)))
vint16m2_t vnmsub(vbool8_t, vint16m2_t, int16_t, vint16m2_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vnmsub_vx)))
vint16m4_t vnmsub(vint16m4_t, int16_t, vint16m4_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vnmsub_vx_m)))
vint16m4_t vnmsub(vbool4_t, vint16m4_t, int16_t, vint16m4_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vnmsub_vx)))
vint16m8_t vnmsub(vint16m8_t, int16_t, vint16m8_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vnmsub_vx_m)))
vint16m8_t vnmsub(vbool2_t, vint16m8_t, int16_t, vint16m8_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vnmsub_vx)))
vint16mf2_t vnmsub(vint16mf2_t, int16_t, vint16mf2_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vnmsub_vx_m)))
vint16mf2_t vnmsub(vbool32_t, vint16mf2_t, int16_t, vint16mf2_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vnmsub_vx)))
vint16mf4_t vnmsub(vint16mf4_t, int16_t, vint16mf4_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vnmsub_vx_m)))
vint16mf4_t vnmsub(vbool64_t, vint16mf4_t, int16_t, vint16mf4_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vnmsub_vx)))
vint32m1_t vnmsub(vint32m1_t, int32_t, vint32m1_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vnmsub_vx_m)))
vint32m1_t vnmsub(vbool32_t, vint32m1_t, int32_t, vint32m1_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vnmsub_vx)))
vint32m2_t vnmsub(vint32m2_t, int32_t, vint32m2_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vnmsub_vx_m)))
vint32m2_t vnmsub(vbool16_t, vint32m2_t, int32_t, vint32m2_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vnmsub_vx)))
vint32m4_t vnmsub(vint32m4_t, int32_t, vint32m4_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vnmsub_vx_m)))
vint32m4_t vnmsub(vbool8_t, vint32m4_t, int32_t, vint32m4_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vnmsub_vx)))
vint32m8_t vnmsub(vint32m8_t, int32_t, vint32m8_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vnmsub_vx_m)))
vint32m8_t vnmsub(vbool4_t, vint32m8_t, int32_t, vint32m8_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vnmsub_vx)))
vint32mf2_t vnmsub(vint32mf2_t, int32_t, vint32mf2_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vnmsub_vx_m)))
vint32mf2_t vnmsub(vbool64_t, vint32mf2_t, int32_t, vint32mf2_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vnmsub_vv)))
vuint8m1_t vnmsub(vuint8m1_t, vuint8m1_t, vuint8m1_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vnmsub_vv_m)))
vuint8m1_t vnmsub(vbool8_t, vuint8m1_t, vuint8m1_t, vuint8m1_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vnmsub_vv)))
vuint8m2_t vnmsub(vuint8m2_t, vuint8m2_t, vuint8m2_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vnmsub_vv_m)))
vuint8m2_t vnmsub(vbool4_t, vuint8m2_t, vuint8m2_t, vuint8m2_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vnmsub_vv)))
vuint8m4_t vnmsub(vuint8m4_t, vuint8m4_t, vuint8m4_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vnmsub_vv_m)))
vuint8m4_t vnmsub(vbool2_t, vuint8m4_t, vuint8m4_t, vuint8m4_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vnmsub_vv)))
vuint8m8_t vnmsub(vuint8m8_t, vuint8m8_t, vuint8m8_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vnmsub_vv_m)))
vuint8m8_t vnmsub(vbool1_t, vuint8m8_t, vuint8m8_t, vuint8m8_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vnmsub_vv)))
vuint8mf2_t vnmsub(vuint8mf2_t, vuint8mf2_t, vuint8mf2_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vnmsub_vv_m)))
vuint8mf2_t vnmsub(vbool16_t, vuint8mf2_t, vuint8mf2_t, vuint8mf2_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vnmsub_vv)))
vuint8mf4_t vnmsub(vuint8mf4_t, vuint8mf4_t, vuint8mf4_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vnmsub_vv_m)))
vuint8mf4_t vnmsub(vbool32_t, vuint8mf4_t, vuint8mf4_t, vuint8mf4_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vnmsub_vv)))
vuint8mf8_t vnmsub(vuint8mf8_t, vuint8mf8_t, vuint8mf8_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vnmsub_vv_m)))
vuint8mf8_t vnmsub(vbool64_t, vuint8mf8_t, vuint8mf8_t, vuint8mf8_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vnmsub_vv)))
vuint16m1_t vnmsub(vuint16m1_t, vuint16m1_t, vuint16m1_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vnmsub_vv_m)))
vuint16m1_t vnmsub(vbool16_t, vuint16m1_t, vuint16m1_t, vuint16m1_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vnmsub_vv)))
vuint16m2_t vnmsub(vuint16m2_t, vuint16m2_t, vuint16m2_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vnmsub_vv_m)))
vuint16m2_t vnmsub(vbool8_t, vuint16m2_t, vuint16m2_t, vuint16m2_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vnmsub_vv)))
vuint16m4_t vnmsub(vuint16m4_t, vuint16m4_t, vuint16m4_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vnmsub_vv_m)))
vuint16m4_t vnmsub(vbool4_t, vuint16m4_t, vuint16m4_t, vuint16m4_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vnmsub_vv)))
vuint16m8_t vnmsub(vuint16m8_t, vuint16m8_t, vuint16m8_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vnmsub_vv_m)))
vuint16m8_t vnmsub(vbool2_t, vuint16m8_t, vuint16m8_t, vuint16m8_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vnmsub_vv)))
vuint16mf2_t vnmsub(vuint16mf2_t, vuint16mf2_t, vuint16mf2_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vnmsub_vv_m)))
vuint16mf2_t vnmsub(vbool32_t, vuint16mf2_t, vuint16mf2_t, vuint16mf2_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vnmsub_vv)))
vuint16mf4_t vnmsub(vuint16mf4_t, vuint16mf4_t, vuint16mf4_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vnmsub_vv_m)))
vuint16mf4_t vnmsub(vbool64_t, vuint16mf4_t, vuint16mf4_t, vuint16mf4_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vnmsub_vv)))
vuint32m1_t vnmsub(vuint32m1_t, vuint32m1_t, vuint32m1_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vnmsub_vv_m)))
vuint32m1_t vnmsub(vbool32_t, vuint32m1_t, vuint32m1_t, vuint32m1_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vnmsub_vv)))
vuint32m2_t vnmsub(vuint32m2_t, vuint32m2_t, vuint32m2_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vnmsub_vv_m)))
vuint32m2_t vnmsub(vbool16_t, vuint32m2_t, vuint32m2_t, vuint32m2_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vnmsub_vv)))
vuint32m4_t vnmsub(vuint32m4_t, vuint32m4_t, vuint32m4_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vnmsub_vv_m)))
vuint32m4_t vnmsub(vbool8_t, vuint32m4_t, vuint32m4_t, vuint32m4_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vnmsub_vv)))
vuint32m8_t vnmsub(vuint32m8_t, vuint32m8_t, vuint32m8_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vnmsub_vv_m)))
vuint32m8_t vnmsub(vbool4_t, vuint32m8_t, vuint32m8_t, vuint32m8_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vnmsub_vv)))
vuint32mf2_t vnmsub(vuint32mf2_t, vuint32mf2_t, vuint32mf2_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vnmsub_vv_m)))
vuint32mf2_t vnmsub(vbool64_t, vuint32mf2_t, vuint32mf2_t, vuint32mf2_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vsuxei8_v)))
void vsuxei8(uint16_t *, vuint8mf2_t, vuint16m1_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vsuxei8_v_m)))
void vsuxei8(vbool16_t, uint16_t *, vuint8mf2_t, vuint16m1_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vsuxei8_v)))
void vsuxei8(uint16_t *, vuint8m1_t, vuint16m2_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vsuxei8_v_m)))
void vsuxei8(vbool8_t, uint16_t *, vuint8m1_t, vuint16m2_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vsuxei8_v)))
void vsuxei8(uint16_t *, vuint8m2_t, vuint16m4_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vsuxei8_v_m)))
void vsuxei8(vbool4_t, uint16_t *, vuint8m2_t, vuint16m4_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vsuxei8_v)))
void vsuxei8(uint16_t *, vuint8m4_t, vuint16m8_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vsuxei8_v_m)))
void vsuxei8(vbool2_t, uint16_t *, vuint8m4_t, vuint16m8_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vsuxei8_v)))
void vsuxei8(uint16_t *, vuint8mf4_t, vuint16mf2_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vsuxei8_v_m)))
void vsuxei8(vbool32_t, uint16_t *, vuint8mf4_t, vuint16mf2_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vsuxei8_v)))
void vsuxei8(uint16_t *, vuint8mf8_t, vuint16mf4_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vsuxei8_v_m)))
void vsuxei8(vbool64_t, uint16_t *, vuint8mf8_t, vuint16mf4_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vnmsub_vx)))
vuint8m1_t vnmsub(vuint8m1_t, uint8_t, vuint8m1_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vnmsub_vx_m)))
vuint8m1_t vnmsub(vbool8_t, vuint8m1_t, uint8_t, vuint8m1_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vnmsub_vx)))
vuint8m2_t vnmsub(vuint8m2_t, uint8_t, vuint8m2_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vnmsub_vx_m)))
vuint8m2_t vnmsub(vbool4_t, vuint8m2_t, uint8_t, vuint8m2_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vnmsub_vx)))
vuint8m4_t vnmsub(vuint8m4_t, uint8_t, vuint8m4_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vnmsub_vx_m)))
vuint8m4_t vnmsub(vbool2_t, vuint8m4_t, uint8_t, vuint8m4_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vnmsub_vx)))
vuint8m8_t vnmsub(vuint8m8_t, uint8_t, vuint8m8_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vnmsub_vx_m)))
vuint8m8_t vnmsub(vbool1_t, vuint8m8_t, uint8_t, vuint8m8_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vnmsub_vx)))
vuint8mf2_t vnmsub(vuint8mf2_t, uint8_t, vuint8mf2_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vnmsub_vx_m)))
vuint8mf2_t vnmsub(vbool16_t, vuint8mf2_t, uint8_t, vuint8mf2_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vnmsub_vx)))
vuint8mf4_t vnmsub(vuint8mf4_t, uint8_t, vuint8mf4_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vnmsub_vx_m)))
vuint8mf4_t vnmsub(vbool32_t, vuint8mf4_t, uint8_t, vuint8mf4_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vnmsub_vx)))
vuint8mf8_t vnmsub(vuint8mf8_t, uint8_t, vuint8mf8_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vnmsub_vx_m)))
vuint8mf8_t vnmsub(vbool64_t, vuint8mf8_t, uint8_t, vuint8mf8_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vnmsub_vx)))
vuint16m1_t vnmsub(vuint16m1_t, uint16_t, vuint16m1_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vnmsub_vx_m)))
vuint16m1_t vnmsub(vbool16_t, vuint16m1_t, uint16_t, vuint16m1_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vnmsub_vx)))
vuint16m2_t vnmsub(vuint16m2_t, uint16_t, vuint16m2_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vnmsub_vx_m)))
vuint16m2_t vnmsub(vbool8_t, vuint16m2_t, uint16_t, vuint16m2_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vnmsub_vx)))
vuint16m4_t vnmsub(vuint16m4_t, uint16_t, vuint16m4_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vnmsub_vx_m)))
vuint16m4_t vnmsub(vbool4_t, vuint16m4_t, uint16_t, vuint16m4_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vnmsub_vx)))
vuint16m8_t vnmsub(vuint16m8_t, uint16_t, vuint16m8_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vnmsub_vx_m)))
vuint16m8_t vnmsub(vbool2_t, vuint16m8_t, uint16_t, vuint16m8_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vnmsub_vx)))
vuint16mf2_t vnmsub(vuint16mf2_t, uint16_t, vuint16mf2_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vnmsub_vx_m)))
vuint16mf2_t vnmsub(vbool32_t, vuint16mf2_t, uint16_t, vuint16mf2_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vnmsub_vx)))
vuint16mf4_t vnmsub(vuint16mf4_t, uint16_t, vuint16mf4_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vnmsub_vx_m)))
vuint16mf4_t vnmsub(vbool64_t, vuint16mf4_t, uint16_t, vuint16mf4_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vnmsub_vx)))
vuint32m1_t vnmsub(vuint32m1_t, uint32_t, vuint32m1_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vnmsub_vx_m)))
vuint32m1_t vnmsub(vbool32_t, vuint32m1_t, uint32_t, vuint32m1_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vnmsub_vx)))
vuint32m2_t vnmsub(vuint32m2_t, uint32_t, vuint32m2_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vnmsub_vx_m)))
vuint32m2_t vnmsub(vbool16_t, vuint32m2_t, uint32_t, vuint32m2_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vnmsub_vx)))
vuint32m4_t vnmsub(vuint32m4_t, uint32_t, vuint32m4_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vnmsub_vx_m)))
vuint32m4_t vnmsub(vbool8_t, vuint32m4_t, uint32_t, vuint32m4_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vnmsub_vx)))
vuint32m8_t vnmsub(vuint32m8_t, uint32_t, vuint32m8_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vnmsub_vx_m)))
vuint32m8_t vnmsub(vbool4_t, vuint32m8_t, uint32_t, vuint32m8_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vnmsub_vx)))
vuint32mf2_t vnmsub(vuint32mf2_t, uint32_t, vuint32mf2_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vnmsub_vx_m)))
vuint32mf2_t vnmsub(vbool64_t, vuint32mf2_t, uint32_t, vuint32mf2_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vwmaccu_vv)))
vuint16mf4_t vwmaccu(vuint16mf4_t, vuint8mf8_t, vuint8mf8_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vwmaccu_vv_m)))
vuint16mf4_t vwmaccu(vbool64_t, vuint16mf4_t, vuint8mf8_t, vuint8mf8_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vwmaccu_vv)))
vuint16mf2_t vwmaccu(vuint16mf2_t, vuint8mf4_t, vuint8mf4_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vwmaccu_vv_m)))
vuint16mf2_t vwmaccu(vbool32_t, vuint16mf2_t, vuint8mf4_t, vuint8mf4_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vwmaccu_vv)))
vuint16m1_t vwmaccu(vuint16m1_t, vuint8mf2_t, vuint8mf2_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vwmaccu_vv_m)))
vuint16m1_t vwmaccu(vbool16_t, vuint16m1_t, vuint8mf2_t, vuint8mf2_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vwmaccu_vv)))
vuint16m2_t vwmaccu(vuint16m2_t, vuint8m1_t, vuint8m1_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vwmaccu_vv_m)))
vuint16m2_t vwmaccu(vbool8_t, vuint16m2_t, vuint8m1_t, vuint8m1_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vwmaccu_vv)))
vuint16m4_t vwmaccu(vuint16m4_t, vuint8m2_t, vuint8m2_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vwmaccu_vv_m)))
vuint16m4_t vwmaccu(vbool4_t, vuint16m4_t, vuint8m2_t, vuint8m2_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vwmaccu_vv)))
vuint16m8_t vwmaccu(vuint16m8_t, vuint8m4_t, vuint8m4_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vwmaccu_vv_m)))
vuint16m8_t vwmaccu(vbool2_t, vuint16m8_t, vuint8m4_t, vuint8m4_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vwmaccu_vv)))
vuint32mf2_t vwmaccu(vuint32mf2_t, vuint16mf4_t, vuint16mf4_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vwmaccu_vv_m)))
vuint32mf2_t vwmaccu(vbool64_t, vuint32mf2_t, vuint16mf4_t, vuint16mf4_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vwmaccu_vv)))
vuint32m1_t vwmaccu(vuint32m1_t, vuint16mf2_t, vuint16mf2_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vwmaccu_vv_m)))
vuint32m1_t vwmaccu(vbool32_t, vuint32m1_t, vuint16mf2_t, vuint16mf2_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vwmaccu_vv)))
vuint32m2_t vwmaccu(vuint32m2_t, vuint16m1_t, vuint16m1_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vwmaccu_vv_m)))
vuint32m2_t vwmaccu(vbool16_t, vuint32m2_t, vuint16m1_t, vuint16m1_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vwmaccu_vv)))
vuint32m4_t vwmaccu(vuint32m4_t, vuint16m2_t, vuint16m2_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vwmaccu_vv_m)))
vuint32m4_t vwmaccu(vbool8_t, vuint32m4_t, vuint16m2_t, vuint16m2_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vwmaccu_vv)))
vuint32m8_t vwmaccu(vuint32m8_t, vuint16m4_t, vuint16m4_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vwmaccu_vv_m)))
vuint32m8_t vwmaccu(vbool4_t, vuint32m8_t, vuint16m4_t, vuint16m4_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vwmaccu_vx)))
vuint16mf4_t vwmaccu(vuint16mf4_t, uint8_t, vuint8mf8_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vwmaccu_vx_m)))
vuint16mf4_t vwmaccu(vbool64_t, vuint16mf4_t, uint8_t, vuint8mf8_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vwmaccu_vx)))
vuint16mf2_t vwmaccu(vuint16mf2_t, uint8_t, vuint8mf4_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vwmaccu_vx_m)))
vuint16mf2_t vwmaccu(vbool32_t, vuint16mf2_t, uint8_t, vuint8mf4_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vwmaccu_vx)))
vuint16m1_t vwmaccu(vuint16m1_t, uint8_t, vuint8mf2_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vwmaccu_vx_m)))
vuint16m1_t vwmaccu(vbool16_t, vuint16m1_t, uint8_t, vuint8mf2_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vwmaccu_vx)))
vuint16m2_t vwmaccu(vuint16m2_t, uint8_t, vuint8m1_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vwmaccu_vx_m)))
vuint16m2_t vwmaccu(vbool8_t, vuint16m2_t, uint8_t, vuint8m1_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vwmaccu_vx)))
vuint16m4_t vwmaccu(vuint16m4_t, uint8_t, vuint8m2_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vwmaccu_vx_m)))
vuint16m4_t vwmaccu(vbool4_t, vuint16m4_t, uint8_t, vuint8m2_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vwmaccu_vx)))
vuint16m8_t vwmaccu(vuint16m8_t, uint8_t, vuint8m4_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vwmaccu_vx_m)))
vuint16m8_t vwmaccu(vbool2_t, vuint16m8_t, uint8_t, vuint8m4_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vwmaccu_vx)))
vuint32mf2_t vwmaccu(vuint32mf2_t, uint16_t, vuint16mf4_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vwmaccu_vx_m)))
vuint32mf2_t vwmaccu(vbool64_t, vuint32mf2_t, uint16_t, vuint16mf4_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vwmaccu_vx)))
vuint32m1_t vwmaccu(vuint32m1_t, uint16_t, vuint16mf2_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vwmaccu_vx_m)))
vuint32m1_t vwmaccu(vbool32_t, vuint32m1_t, uint16_t, vuint16mf2_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vwmaccu_vx)))
vuint32m2_t vwmaccu(vuint32m2_t, uint16_t, vuint16m1_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vwmaccu_vx_m)))
vuint32m2_t vwmaccu(vbool16_t, vuint32m2_t, uint16_t, vuint16m1_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vwmaccu_vx)))
vuint32m4_t vwmaccu(vuint32m4_t, uint16_t, vuint16m2_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vwmaccu_vx_m)))
vuint32m4_t vwmaccu(vbool8_t, vuint32m4_t, uint16_t, vuint16m2_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vwmaccu_vx)))
vuint32m8_t vwmaccu(vuint32m8_t, uint16_t, vuint16m4_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vwmaccu_vx_m)))
vuint32m8_t vwmaccu(vbool4_t, vuint32m8_t, uint16_t, vuint16m4_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vwmacc_vv)))
vint16mf4_t vwmacc(vint16mf4_t, vint8mf8_t, vint8mf8_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vwmacc_vv_m)))
vint16mf4_t vwmacc(vbool64_t, vint16mf4_t, vint8mf8_t, vint8mf8_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vwmacc_vv)))
vint16mf2_t vwmacc(vint16mf2_t, vint8mf4_t, vint8mf4_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vwmacc_vv_m)))
vint16mf2_t vwmacc(vbool32_t, vint16mf2_t, vint8mf4_t, vint8mf4_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vwmacc_vv)))
vint16m1_t vwmacc(vint16m1_t, vint8mf2_t, vint8mf2_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vwmacc_vv_m)))
vint16m1_t vwmacc(vbool16_t, vint16m1_t, vint8mf2_t, vint8mf2_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vwmacc_vv)))
vint16m2_t vwmacc(vint16m2_t, vint8m1_t, vint8m1_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vwmacc_vv_m)))
vint16m2_t vwmacc(vbool8_t, vint16m2_t, vint8m1_t, vint8m1_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vwmacc_vv)))
vint16m4_t vwmacc(vint16m4_t, vint8m2_t, vint8m2_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vwmacc_vv_m)))
vint16m4_t vwmacc(vbool4_t, vint16m4_t, vint8m2_t, vint8m2_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vwmacc_vv)))
vint16m8_t vwmacc(vint16m8_t, vint8m4_t, vint8m4_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vwmacc_vv_m)))
vint16m8_t vwmacc(vbool2_t, vint16m8_t, vint8m4_t, vint8m4_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vwmacc_vv)))
vint32mf2_t vwmacc(vint32mf2_t, vint16mf4_t, vint16mf4_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vwmacc_vv_m)))
vint32mf2_t vwmacc(vbool64_t, vint32mf2_t, vint16mf4_t, vint16mf4_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vwmacc_vv)))
vint32m1_t vwmacc(vint32m1_t, vint16mf2_t, vint16mf2_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vwmacc_vv_m)))
vint32m1_t vwmacc(vbool32_t, vint32m1_t, vint16mf2_t, vint16mf2_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vwmacc_vv)))
vint32m2_t vwmacc(vint32m2_t, vint16m1_t, vint16m1_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vwmacc_vv_m)))
vint32m2_t vwmacc(vbool16_t, vint32m2_t, vint16m1_t, vint16m1_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vwmacc_vv)))
vint32m4_t vwmacc(vint32m4_t, vint16m2_t, vint16m2_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vwmacc_vv_m)))
vint32m4_t vwmacc(vbool8_t, vint32m4_t, vint16m2_t, vint16m2_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vwmacc_vv)))
vint32m8_t vwmacc(vint32m8_t, vint16m4_t, vint16m4_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vwmacc_vv_m)))
vint32m8_t vwmacc(vbool4_t, vint32m8_t, vint16m4_t, vint16m4_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vwmacc_vx)))
vint16mf4_t vwmacc(vint16mf4_t, int8_t, vint8mf8_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vwmacc_vx_m)))
vint16mf4_t vwmacc(vbool64_t, vint16mf4_t, int8_t, vint8mf8_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vwmacc_vx)))
vint16mf2_t vwmacc(vint16mf2_t, int8_t, vint8mf4_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vwmacc_vx_m)))
vint16mf2_t vwmacc(vbool32_t, vint16mf2_t, int8_t, vint8mf4_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vwmacc_vx)))
vint16m1_t vwmacc(vint16m1_t, int8_t, vint8mf2_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vwmacc_vx_m)))
vint16m1_t vwmacc(vbool16_t, vint16m1_t, int8_t, vint8mf2_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vwmacc_vx)))
vint16m2_t vwmacc(vint16m2_t, int8_t, vint8m1_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vwmacc_vx_m)))
vint16m2_t vwmacc(vbool8_t, vint16m2_t, int8_t, vint8m1_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vwmacc_vx)))
vint16m4_t vwmacc(vint16m4_t, int8_t, vint8m2_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vwmacc_vx_m)))
vint16m4_t vwmacc(vbool4_t, vint16m4_t, int8_t, vint8m2_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vwmacc_vx)))
vint16m8_t vwmacc(vint16m8_t, int8_t, vint8m4_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vwmacc_vx_m)))
vint16m8_t vwmacc(vbool2_t, vint16m8_t, int8_t, vint8m4_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vwmacc_vx)))
vint32mf2_t vwmacc(vint32mf2_t, int16_t, vint16mf4_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vwmacc_vx_m)))
vint32mf2_t vwmacc(vbool64_t, vint32mf2_t, int16_t, vint16mf4_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vwmacc_vx)))
vint32m1_t vwmacc(vint32m1_t, int16_t, vint16mf2_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vwmacc_vx_m)))
vint32m1_t vwmacc(vbool32_t, vint32m1_t, int16_t, vint16mf2_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vwmacc_vx)))
vint32m2_t vwmacc(vint32m2_t, int16_t, vint16m1_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vwmacc_vx_m)))
vint32m2_t vwmacc(vbool16_t, vint32m2_t, int16_t, vint16m1_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vwmacc_vx)))
vint32m4_t vwmacc(vint32m4_t, int16_t, vint16m2_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vwmacc_vx_m)))
vint32m4_t vwmacc(vbool8_t, vint32m4_t, int16_t, vint16m2_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vwmacc_vx)))
vint32m8_t vwmacc(vint32m8_t, int16_t, vint16m4_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vwmacc_vx_m)))
vint32m8_t vwmacc(vbool4_t, vint32m8_t, int16_t, vint16m4_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vwmaccsu_vv)))
vint16mf4_t vwmaccsu(vint16mf4_t, vint8mf8_t, vuint8mf8_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vwmaccsu_vv_m)))
vint16mf4_t vwmaccsu(vbool64_t, vint16mf4_t, vint8mf8_t, vuint8mf8_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vwmaccsu_vv)))
vint16mf2_t vwmaccsu(vint16mf2_t, vint8mf4_t, vuint8mf4_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vwmaccsu_vv_m)))
vint16mf2_t vwmaccsu(vbool32_t, vint16mf2_t, vint8mf4_t, vuint8mf4_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vwmaccsu_vv)))
vint16m1_t vwmaccsu(vint16m1_t, vint8mf2_t, vuint8mf2_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vwmaccsu_vv_m)))
vint16m1_t vwmaccsu(vbool16_t, vint16m1_t, vint8mf2_t, vuint8mf2_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vwmaccsu_vv)))
vint16m2_t vwmaccsu(vint16m2_t, vint8m1_t, vuint8m1_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vwmaccsu_vv_m)))
vint16m2_t vwmaccsu(vbool8_t, vint16m2_t, vint8m1_t, vuint8m1_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vwmaccsu_vv)))
vint16m4_t vwmaccsu(vint16m4_t, vint8m2_t, vuint8m2_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vwmaccsu_vv_m)))
vint16m4_t vwmaccsu(vbool4_t, vint16m4_t, vint8m2_t, vuint8m2_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vwmaccsu_vv)))
vint16m8_t vwmaccsu(vint16m8_t, vint8m4_t, vuint8m4_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vwmaccsu_vv_m)))
vint16m8_t vwmaccsu(vbool2_t, vint16m8_t, vint8m4_t, vuint8m4_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vwmaccsu_vv)))
vint32mf2_t vwmaccsu(vint32mf2_t, vint16mf4_t, vuint16mf4_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vwmaccsu_vv_m)))
vint32mf2_t vwmaccsu(vbool64_t, vint32mf2_t, vint16mf4_t, vuint16mf4_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vwmaccsu_vv)))
vint32m1_t vwmaccsu(vint32m1_t, vint16mf2_t, vuint16mf2_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vwmaccsu_vv_m)))
vint32m1_t vwmaccsu(vbool32_t, vint32m1_t, vint16mf2_t, vuint16mf2_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vwmaccsu_vv)))
vint32m2_t vwmaccsu(vint32m2_t, vint16m1_t, vuint16m1_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vwmaccsu_vv_m)))
vint32m2_t vwmaccsu(vbool16_t, vint32m2_t, vint16m1_t, vuint16m1_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vwmaccsu_vv)))
vint32m4_t vwmaccsu(vint32m4_t, vint16m2_t, vuint16m2_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vwmaccsu_vv_m)))
vint32m4_t vwmaccsu(vbool8_t, vint32m4_t, vint16m2_t, vuint16m2_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vwmaccsu_vv)))
vint32m8_t vwmaccsu(vint32m8_t, vint16m4_t, vuint16m4_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vwmaccsu_vv_m)))
vint32m8_t vwmaccsu(vbool4_t, vint32m8_t, vint16m4_t, vuint16m4_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vwmaccsu_vx)))
vint16mf4_t vwmaccsu(vint16mf4_t, int8_t, vuint8mf8_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vwmaccsu_vx_m)))
vint16mf4_t vwmaccsu(vbool64_t, vint16mf4_t, int8_t, vuint8mf8_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vwmaccsu_vx)))
vint16mf2_t vwmaccsu(vint16mf2_t, int8_t, vuint8mf4_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vwmaccsu_vx_m)))
vint16mf2_t vwmaccsu(vbool32_t, vint16mf2_t, int8_t, vuint8mf4_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vwmaccsu_vx)))
vint16m1_t vwmaccsu(vint16m1_t, int8_t, vuint8mf2_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vwmaccsu_vx_m)))
vint16m1_t vwmaccsu(vbool16_t, vint16m1_t, int8_t, vuint8mf2_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vwmaccsu_vx)))
vint16m2_t vwmaccsu(vint16m2_t, int8_t, vuint8m1_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vwmaccsu_vx_m)))
vint16m2_t vwmaccsu(vbool8_t, vint16m2_t, int8_t, vuint8m1_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vwmaccsu_vx)))
vint16m4_t vwmaccsu(vint16m4_t, int8_t, vuint8m2_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vwmaccsu_vx_m)))
vint16m4_t vwmaccsu(vbool4_t, vint16m4_t, int8_t, vuint8m2_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vwmaccsu_vx)))
vint16m8_t vwmaccsu(vint16m8_t, int8_t, vuint8m4_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vwmaccsu_vx_m)))
vint16m8_t vwmaccsu(vbool2_t, vint16m8_t, int8_t, vuint8m4_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vwmaccsu_vx)))
vint32mf2_t vwmaccsu(vint32mf2_t, int16_t, vuint16mf4_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vwmaccsu_vx_m)))
vint32mf2_t vwmaccsu(vbool64_t, vint32mf2_t, int16_t, vuint16mf4_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vwmaccsu_vx)))
vint32m1_t vwmaccsu(vint32m1_t, int16_t, vuint16mf2_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vwmaccsu_vx_m)))
vint32m1_t vwmaccsu(vbool32_t, vint32m1_t, int16_t, vuint16mf2_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vwmaccsu_vx)))
vint32m2_t vwmaccsu(vint32m2_t, int16_t, vuint16m1_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vwmaccsu_vx_m)))
vint32m2_t vwmaccsu(vbool16_t, vint32m2_t, int16_t, vuint16m1_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vwmaccsu_vx)))
vint32m4_t vwmaccsu(vint32m4_t, int16_t, vuint16m2_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vwmaccsu_vx_m)))
vint32m4_t vwmaccsu(vbool8_t, vint32m4_t, int16_t, vuint16m2_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vwmaccsu_vx)))
vint32m8_t vwmaccsu(vint32m8_t, int16_t, vuint16m4_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vwmaccsu_vx_m)))
vint32m8_t vwmaccsu(vbool4_t, vint32m8_t, int16_t, vuint16m4_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vwmaccus_vx)))
vint16mf4_t vwmaccus(vint16mf4_t, uint8_t, vint8mf8_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vwmaccus_vx_m)))
vint16mf4_t vwmaccus(vbool64_t, vint16mf4_t, uint8_t, vint8mf8_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vwmaccus_vx)))
vint16mf2_t vwmaccus(vint16mf2_t, uint8_t, vint8mf4_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vwmaccus_vx_m)))
vint16mf2_t vwmaccus(vbool32_t, vint16mf2_t, uint8_t, vint8mf4_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vwmaccus_vx)))
vint16m1_t vwmaccus(vint16m1_t, uint8_t, vint8mf2_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vwmaccus_vx_m)))
vint16m1_t vwmaccus(vbool16_t, vint16m1_t, uint8_t, vint8mf2_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vwmaccus_vx)))
vint16m2_t vwmaccus(vint16m2_t, uint8_t, vint8m1_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vwmaccus_vx_m)))
vint16m2_t vwmaccus(vbool8_t, vint16m2_t, uint8_t, vint8m1_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vwmaccus_vx)))
vint16m4_t vwmaccus(vint16m4_t, uint8_t, vint8m2_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vwmaccus_vx_m)))
vint16m4_t vwmaccus(vbool4_t, vint16m4_t, uint8_t, vint8m2_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vwmaccus_vx)))
vint16m8_t vwmaccus(vint16m8_t, uint8_t, vint8m4_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vwmaccus_vx_m)))
vint16m8_t vwmaccus(vbool2_t, vint16m8_t, uint8_t, vint8m4_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vwmaccus_vx)))
vint32mf2_t vwmaccus(vint32mf2_t, uint16_t, vint16mf4_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vwmaccus_vx_m)))
vint32mf2_t vwmaccus(vbool64_t, vint32mf2_t, uint16_t, vint16mf4_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vwmaccus_vx)))
vint32m1_t vwmaccus(vint32m1_t, uint16_t, vint16mf2_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vwmaccus_vx_m)))
vint32m1_t vwmaccus(vbool32_t, vint32m1_t, uint16_t, vint16mf2_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vwmaccus_vx)))
vint32m2_t vwmaccus(vint32m2_t, uint16_t, vint16m1_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vwmaccus_vx_m)))
vint32m2_t vwmaccus(vbool16_t, vint32m2_t, uint16_t, vint16m1_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vwmaccus_vx)))
vint32m4_t vwmaccus(vint32m4_t, uint16_t, vint16m2_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vwmaccus_vx_m)))
vint32m4_t vwmaccus(vbool8_t, vint32m4_t, uint16_t, vint16m2_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vwmaccus_vx)))
vint32m8_t vwmaccus(vint32m8_t, uint16_t, vint16m4_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vwmaccus_vx_m)))
vint32m8_t vwmaccus(vbool4_t, vint32m8_t, uint16_t, vint16m4_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vmerge_vvm)))
vint8m1_t vmerge(vbool8_t, vint8m1_t, vint8m1_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vmerge_vvm)))
vint8m2_t vmerge(vbool4_t, vint8m2_t, vint8m2_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vmerge_vvm)))
vint8m4_t vmerge(vbool2_t, vint8m4_t, vint8m4_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vmerge_vvm)))
vint8m8_t vmerge(vbool1_t, vint8m8_t, vint8m8_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vmerge_vvm)))
vint8mf2_t vmerge(vbool16_t, vint8mf2_t, vint8mf2_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vmerge_vvm)))
vint8mf4_t vmerge(vbool32_t, vint8mf4_t, vint8mf4_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vmerge_vvm)))
vint8mf8_t vmerge(vbool64_t, vint8mf8_t, vint8mf8_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vmerge_vvm)))
vint16m1_t vmerge(vbool16_t, vint16m1_t, vint16m1_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vmerge_vvm)))
vint16m2_t vmerge(vbool8_t, vint16m2_t, vint16m2_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vmerge_vvm)))
vint16m4_t vmerge(vbool4_t, vint16m4_t, vint16m4_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vmerge_vvm)))
vint16m8_t vmerge(vbool2_t, vint16m8_t, vint16m8_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vmerge_vvm)))
vint16mf2_t vmerge(vbool32_t, vint16mf2_t, vint16mf2_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vmerge_vvm)))
vint16mf4_t vmerge(vbool64_t, vint16mf4_t, vint16mf4_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vmerge_vvm)))
vint32m1_t vmerge(vbool32_t, vint32m1_t, vint32m1_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vmerge_vvm)))
vint32m2_t vmerge(vbool16_t, vint32m2_t, vint32m2_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vmerge_vvm)))
vint32m4_t vmerge(vbool8_t, vint32m4_t, vint32m4_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vmerge_vvm)))
vint32m8_t vmerge(vbool4_t, vint32m8_t, vint32m8_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vmerge_vvm)))
vint32mf2_t vmerge(vbool64_t, vint32mf2_t, vint32mf2_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vmerge_vxm)))
vint8m1_t vmerge(vbool8_t, vint8m1_t, int8_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vmerge_vxm)))
vint8m2_t vmerge(vbool4_t, vint8m2_t, int8_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vmerge_vxm)))
vint8m4_t vmerge(vbool2_t, vint8m4_t, int8_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vmerge_vxm)))
vint8m8_t vmerge(vbool1_t, vint8m8_t, int8_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vmerge_vxm)))
vint8mf2_t vmerge(vbool16_t, vint8mf2_t, int8_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vmerge_vxm)))
vint8mf4_t vmerge(vbool32_t, vint8mf4_t, int8_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vmerge_vxm)))
vint8mf8_t vmerge(vbool64_t, vint8mf8_t, int8_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vmerge_vxm)))
vint16m1_t vmerge(vbool16_t, vint16m1_t, int16_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vmerge_vxm)))
vint16m2_t vmerge(vbool8_t, vint16m2_t, int16_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vmerge_vxm)))
vint16m4_t vmerge(vbool4_t, vint16m4_t, int16_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vmerge_vxm)))
vint16m8_t vmerge(vbool2_t, vint16m8_t, int16_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vmerge_vxm)))
vint16mf2_t vmerge(vbool32_t, vint16mf2_t, int16_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vmerge_vxm)))
vint16mf4_t vmerge(vbool64_t, vint16mf4_t, int16_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vmerge_vxm)))
vint32m1_t vmerge(vbool32_t, vint32m1_t, int32_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vmerge_vxm)))
vint32m2_t vmerge(vbool16_t, vint32m2_t, int32_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vmerge_vxm)))
vint32m4_t vmerge(vbool8_t, vint32m4_t, int32_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vmerge_vxm)))
vint32m8_t vmerge(vbool4_t, vint32m8_t, int32_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vmerge_vxm)))
vint32mf2_t vmerge(vbool64_t, vint32mf2_t, int32_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vsuxei16_v)))
void vsuxei16(int16_t *, vuint16m1_t, vint16m1_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vsuxei16_v_m)))
void vsuxei16(vbool16_t, int16_t *, vuint16m1_t, vint16m1_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vsuxei16_v)))
void vsuxei16(int16_t *, vuint16m2_t, vint16m2_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vsuxei16_v_m)))
void vsuxei16(vbool8_t, int16_t *, vuint16m2_t, vint16m2_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vsuxei16_v)))
void vsuxei16(int16_t *, vuint16m4_t, vint16m4_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vsuxei16_v_m)))
void vsuxei16(vbool4_t, int16_t *, vuint16m4_t, vint16m4_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vsuxei16_v)))
void vsuxei16(int16_t *, vuint16m8_t, vint16m8_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vsuxei16_v_m)))
void vsuxei16(vbool2_t, int16_t *, vuint16m8_t, vint16m8_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vsuxei16_v)))
void vsuxei16(int16_t *, vuint16mf2_t, vint16mf2_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vsuxei16_v_m)))
void vsuxei16(vbool32_t, int16_t *, vuint16mf2_t, vint16mf2_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vsuxei16_v)))
void vsuxei16(int16_t *, vuint16mf4_t, vint16mf4_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vsuxei16_v_m)))
void vsuxei16(vbool64_t, int16_t *, vuint16mf4_t, vint16mf4_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vmerge_vvm)))
vuint8m1_t vmerge(vbool8_t, vuint8m1_t, vuint8m1_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vmerge_vvm)))
vuint8m2_t vmerge(vbool4_t, vuint8m2_t, vuint8m2_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vmerge_vvm)))
vuint8m4_t vmerge(vbool2_t, vuint8m4_t, vuint8m4_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vmerge_vvm)))
vuint8m8_t vmerge(vbool1_t, vuint8m8_t, vuint8m8_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vmerge_vvm)))
vuint8mf2_t vmerge(vbool16_t, vuint8mf2_t, vuint8mf2_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vmerge_vvm)))
vuint8mf4_t vmerge(vbool32_t, vuint8mf4_t, vuint8mf4_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vmerge_vvm)))
vuint8mf8_t vmerge(vbool64_t, vuint8mf8_t, vuint8mf8_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vmerge_vvm)))
vuint16m1_t vmerge(vbool16_t, vuint16m1_t, vuint16m1_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vmerge_vvm)))
vuint16m2_t vmerge(vbool8_t, vuint16m2_t, vuint16m2_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vmerge_vvm)))
vuint16m4_t vmerge(vbool4_t, vuint16m4_t, vuint16m4_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vmerge_vvm)))
vuint16m8_t vmerge(vbool2_t, vuint16m8_t, vuint16m8_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vmerge_vvm)))
vuint16mf2_t vmerge(vbool32_t, vuint16mf2_t, vuint16mf2_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vmerge_vvm)))
vuint16mf4_t vmerge(vbool64_t, vuint16mf4_t, vuint16mf4_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vmerge_vvm)))
vuint32m1_t vmerge(vbool32_t, vuint32m1_t, vuint32m1_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vmerge_vvm)))
vuint32m2_t vmerge(vbool16_t, vuint32m2_t, vuint32m2_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vmerge_vvm)))
vuint32m4_t vmerge(vbool8_t, vuint32m4_t, vuint32m4_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vmerge_vvm)))
vuint32m8_t vmerge(vbool4_t, vuint32m8_t, vuint32m8_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vmerge_vvm)))
vuint32mf2_t vmerge(vbool64_t, vuint32mf2_t, vuint32mf2_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vmerge_vxm)))
vuint8m1_t vmerge(vbool8_t, vuint8m1_t, uint8_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vmerge_vxm)))
vuint8m2_t vmerge(vbool4_t, vuint8m2_t, uint8_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vmerge_vxm)))
vuint8m4_t vmerge(vbool2_t, vuint8m4_t, uint8_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vmerge_vxm)))
vuint8m8_t vmerge(vbool1_t, vuint8m8_t, uint8_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vmerge_vxm)))
vuint8mf2_t vmerge(vbool16_t, vuint8mf2_t, uint8_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vmerge_vxm)))
vuint8mf4_t vmerge(vbool32_t, vuint8mf4_t, uint8_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vmerge_vxm)))
vuint8mf8_t vmerge(vbool64_t, vuint8mf8_t, uint8_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vmerge_vxm)))
vuint16m1_t vmerge(vbool16_t, vuint16m1_t, uint16_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vmerge_vxm)))
vuint16m2_t vmerge(vbool8_t, vuint16m2_t, uint16_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vmerge_vxm)))
vuint16m4_t vmerge(vbool4_t, vuint16m4_t, uint16_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vmerge_vxm)))
vuint16m8_t vmerge(vbool2_t, vuint16m8_t, uint16_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vmerge_vxm)))
vuint16mf2_t vmerge(vbool32_t, vuint16mf2_t, uint16_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vmerge_vxm)))
vuint16mf4_t vmerge(vbool64_t, vuint16mf4_t, uint16_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vmerge_vxm)))
vuint32m1_t vmerge(vbool32_t, vuint32m1_t, uint32_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vmerge_vxm)))
vuint32m2_t vmerge(vbool16_t, vuint32m2_t, uint32_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vmerge_vxm)))
vuint32m4_t vmerge(vbool8_t, vuint32m4_t, uint32_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vmerge_vxm)))
vuint32m8_t vmerge(vbool4_t, vuint32m8_t, uint32_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vmerge_vxm)))
vuint32mf2_t vmerge(vbool64_t, vuint32mf2_t, uint32_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vmv_v_v)))
vuint8m1_t vmv_v(vuint8m1_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vmv_v_v)))
vuint8m2_t vmv_v(vuint8m2_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vmv_v_v)))
vuint8m4_t vmv_v(vuint8m4_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vmv_v_v)))
vuint8m8_t vmv_v(vuint8m8_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vmv_v_v)))
vuint8mf2_t vmv_v(vuint8mf2_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vmv_v_v)))
vuint8mf4_t vmv_v(vuint8mf4_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vmv_v_v)))
vuint8mf8_t vmv_v(vuint8mf8_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vmv_v_v)))
vuint16m1_t vmv_v(vuint16m1_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vmv_v_v)))
vuint16m2_t vmv_v(vuint16m2_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vmv_v_v)))
vuint16m4_t vmv_v(vuint16m4_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vmv_v_v)))
vuint16m8_t vmv_v(vuint16m8_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vmv_v_v)))
vuint16mf2_t vmv_v(vuint16mf2_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vmv_v_v)))
vuint16mf4_t vmv_v(vuint16mf4_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vmv_v_v)))
vuint32m1_t vmv_v(vuint32m1_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vmv_v_v)))
vuint32m2_t vmv_v(vuint32m2_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vmv_v_v)))
vuint32m4_t vmv_v(vuint32m4_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vmv_v_v)))
vuint32m8_t vmv_v(vuint32m8_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vmv_v_v)))
vuint32mf2_t vmv_v(vuint32mf2_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vmv_v_v)))
vint8m1_t vmv_v(vint8m1_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vmv_v_v)))
vint8m2_t vmv_v(vint8m2_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vmv_v_v)))
vint8m4_t vmv_v(vint8m4_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vmv_v_v)))
vint8m8_t vmv_v(vint8m8_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vmv_v_v)))
vint8mf2_t vmv_v(vint8mf2_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vmv_v_v)))
vint8mf4_t vmv_v(vint8mf4_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vmv_v_v)))
vint8mf8_t vmv_v(vint8mf8_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vmv_v_v)))
vint16m1_t vmv_v(vint16m1_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vmv_v_v)))
vint16m2_t vmv_v(vint16m2_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vmv_v_v)))
vint16m4_t vmv_v(vint16m4_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vmv_v_v)))
vint16m8_t vmv_v(vint16m8_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vmv_v_v)))
vint16mf2_t vmv_v(vint16mf2_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vmv_v_v)))
vint16mf4_t vmv_v(vint16mf4_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vmv_v_v)))
vint32m1_t vmv_v(vint32m1_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vmv_v_v)))
vint32m2_t vmv_v(vint32m2_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vmv_v_v)))
vint32m4_t vmv_v(vint32m4_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vmv_v_v)))
vint32m8_t vmv_v(vint32m8_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vmv_v_v)))
vint32mf2_t vmv_v(vint32mf2_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vsaddu_vv)))
vuint8m1_t vsaddu(vuint8m1_t, vuint8m1_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vsaddu_vv_m)))
vuint8m1_t vsaddu(vbool8_t, vuint8m1_t, vuint8m1_t, vuint8m1_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vsaddu_vv)))
vuint8m2_t vsaddu(vuint8m2_t, vuint8m2_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vsaddu_vv_m)))
vuint8m2_t vsaddu(vbool4_t, vuint8m2_t, vuint8m2_t, vuint8m2_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vsaddu_vv)))
vuint8m4_t vsaddu(vuint8m4_t, vuint8m4_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vsaddu_vv_m)))
vuint8m4_t vsaddu(vbool2_t, vuint8m4_t, vuint8m4_t, vuint8m4_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vsaddu_vv)))
vuint8m8_t vsaddu(vuint8m8_t, vuint8m8_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vsaddu_vv_m)))
vuint8m8_t vsaddu(vbool1_t, vuint8m8_t, vuint8m8_t, vuint8m8_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vsaddu_vv)))
vuint8mf2_t vsaddu(vuint8mf2_t, vuint8mf2_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vsaddu_vv_m)))
vuint8mf2_t vsaddu(vbool16_t, vuint8mf2_t, vuint8mf2_t, vuint8mf2_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vsaddu_vv)))
vuint8mf4_t vsaddu(vuint8mf4_t, vuint8mf4_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vsaddu_vv_m)))
vuint8mf4_t vsaddu(vbool32_t, vuint8mf4_t, vuint8mf4_t, vuint8mf4_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vsaddu_vv)))
vuint8mf8_t vsaddu(vuint8mf8_t, vuint8mf8_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vsaddu_vv_m)))
vuint8mf8_t vsaddu(vbool64_t, vuint8mf8_t, vuint8mf8_t, vuint8mf8_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vsaddu_vv)))
vuint16m1_t vsaddu(vuint16m1_t, vuint16m1_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vsaddu_vv_m)))
vuint16m1_t vsaddu(vbool16_t, vuint16m1_t, vuint16m1_t, vuint16m1_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vsaddu_vv)))
vuint16m2_t vsaddu(vuint16m2_t, vuint16m2_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vsaddu_vv_m)))
vuint16m2_t vsaddu(vbool8_t, vuint16m2_t, vuint16m2_t, vuint16m2_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vsaddu_vv)))
vuint16m4_t vsaddu(vuint16m4_t, vuint16m4_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vsaddu_vv_m)))
vuint16m4_t vsaddu(vbool4_t, vuint16m4_t, vuint16m4_t, vuint16m4_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vsaddu_vv)))
vuint16m8_t vsaddu(vuint16m8_t, vuint16m8_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vsaddu_vv_m)))
vuint16m8_t vsaddu(vbool2_t, vuint16m8_t, vuint16m8_t, vuint16m8_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vsaddu_vv)))
vuint16mf2_t vsaddu(vuint16mf2_t, vuint16mf2_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vsaddu_vv_m)))
vuint16mf2_t vsaddu(vbool32_t, vuint16mf2_t, vuint16mf2_t, vuint16mf2_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vsaddu_vv)))
vuint16mf4_t vsaddu(vuint16mf4_t, vuint16mf4_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vsaddu_vv_m)))
vuint16mf4_t vsaddu(vbool64_t, vuint16mf4_t, vuint16mf4_t, vuint16mf4_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vsaddu_vv)))
vuint32m1_t vsaddu(vuint32m1_t, vuint32m1_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vsaddu_vv_m)))
vuint32m1_t vsaddu(vbool32_t, vuint32m1_t, vuint32m1_t, vuint32m1_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vsaddu_vv)))
vuint32m2_t vsaddu(vuint32m2_t, vuint32m2_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vsaddu_vv_m)))
vuint32m2_t vsaddu(vbool16_t, vuint32m2_t, vuint32m2_t, vuint32m2_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vsaddu_vv)))
vuint32m4_t vsaddu(vuint32m4_t, vuint32m4_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vsaddu_vv_m)))
vuint32m4_t vsaddu(vbool8_t, vuint32m4_t, vuint32m4_t, vuint32m4_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vsaddu_vv)))
vuint32m8_t vsaddu(vuint32m8_t, vuint32m8_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vsaddu_vv_m)))
vuint32m8_t vsaddu(vbool4_t, vuint32m8_t, vuint32m8_t, vuint32m8_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vsaddu_vv)))
vuint32mf2_t vsaddu(vuint32mf2_t, vuint32mf2_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vsaddu_vv_m)))
vuint32mf2_t vsaddu(vbool64_t, vuint32mf2_t, vuint32mf2_t, vuint32mf2_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vsaddu_vx)))
vuint8m1_t vsaddu(vuint8m1_t, uint8_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vsaddu_vx_m)))
vuint8m1_t vsaddu(vbool8_t, vuint8m1_t, vuint8m1_t, uint8_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vsaddu_vx)))
vuint8m2_t vsaddu(vuint8m2_t, uint8_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vsaddu_vx_m)))
vuint8m2_t vsaddu(vbool4_t, vuint8m2_t, vuint8m2_t, uint8_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vsaddu_vx)))
vuint8m4_t vsaddu(vuint8m4_t, uint8_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vsaddu_vx_m)))
vuint8m4_t vsaddu(vbool2_t, vuint8m4_t, vuint8m4_t, uint8_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vsaddu_vx)))
vuint8m8_t vsaddu(vuint8m8_t, uint8_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vsaddu_vx_m)))
vuint8m8_t vsaddu(vbool1_t, vuint8m8_t, vuint8m8_t, uint8_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vsaddu_vx)))
vuint8mf2_t vsaddu(vuint8mf2_t, uint8_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vsaddu_vx_m)))
vuint8mf2_t vsaddu(vbool16_t, vuint8mf2_t, vuint8mf2_t, uint8_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vsaddu_vx)))
vuint8mf4_t vsaddu(vuint8mf4_t, uint8_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vsaddu_vx_m)))
vuint8mf4_t vsaddu(vbool32_t, vuint8mf4_t, vuint8mf4_t, uint8_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vsaddu_vx)))
vuint8mf8_t vsaddu(vuint8mf8_t, uint8_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vsaddu_vx_m)))
vuint8mf8_t vsaddu(vbool64_t, vuint8mf8_t, vuint8mf8_t, uint8_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vsaddu_vx)))
vuint16m1_t vsaddu(vuint16m1_t, uint16_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vsaddu_vx_m)))
vuint16m1_t vsaddu(vbool16_t, vuint16m1_t, vuint16m1_t, uint16_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vsaddu_vx)))
vuint16m2_t vsaddu(vuint16m2_t, uint16_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vsaddu_vx_m)))
vuint16m2_t vsaddu(vbool8_t, vuint16m2_t, vuint16m2_t, uint16_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vsaddu_vx)))
vuint16m4_t vsaddu(vuint16m4_t, uint16_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vsaddu_vx_m)))
vuint16m4_t vsaddu(vbool4_t, vuint16m4_t, vuint16m4_t, uint16_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vsaddu_vx)))
vuint16m8_t vsaddu(vuint16m8_t, uint16_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vsaddu_vx_m)))
vuint16m8_t vsaddu(vbool2_t, vuint16m8_t, vuint16m8_t, uint16_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vsaddu_vx)))
vuint16mf2_t vsaddu(vuint16mf2_t, uint16_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vsaddu_vx_m)))
vuint16mf2_t vsaddu(vbool32_t, vuint16mf2_t, vuint16mf2_t, uint16_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vsaddu_vx)))
vuint16mf4_t vsaddu(vuint16mf4_t, uint16_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vsaddu_vx_m)))
vuint16mf4_t vsaddu(vbool64_t, vuint16mf4_t, vuint16mf4_t, uint16_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vsaddu_vx)))
vuint32m1_t vsaddu(vuint32m1_t, uint32_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vsaddu_vx_m)))
vuint32m1_t vsaddu(vbool32_t, vuint32m1_t, vuint32m1_t, uint32_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vsaddu_vx)))
vuint32m2_t vsaddu(vuint32m2_t, uint32_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vsaddu_vx_m)))
vuint32m2_t vsaddu(vbool16_t, vuint32m2_t, vuint32m2_t, uint32_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vsaddu_vx)))
vuint32m4_t vsaddu(vuint32m4_t, uint32_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vsaddu_vx_m)))
vuint32m4_t vsaddu(vbool8_t, vuint32m4_t, vuint32m4_t, uint32_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vsaddu_vx)))
vuint32m8_t vsaddu(vuint32m8_t, uint32_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vsaddu_vx_m)))
vuint32m8_t vsaddu(vbool4_t, vuint32m8_t, vuint32m8_t, uint32_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vsaddu_vx)))
vuint32mf2_t vsaddu(vuint32mf2_t, uint32_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vsaddu_vx_m)))
vuint32mf2_t vsaddu(vbool64_t, vuint32mf2_t, vuint32mf2_t, uint32_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vsadd_vv)))
vint8m1_t vsadd(vint8m1_t, vint8m1_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vsadd_vv_m)))
vint8m1_t vsadd(vbool8_t, vint8m1_t, vint8m1_t, vint8m1_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vsadd_vv)))
vint8m2_t vsadd(vint8m2_t, vint8m2_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vsadd_vv_m)))
vint8m2_t vsadd(vbool4_t, vint8m2_t, vint8m2_t, vint8m2_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vsadd_vv)))
vint8m4_t vsadd(vint8m4_t, vint8m4_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vsadd_vv_m)))
vint8m4_t vsadd(vbool2_t, vint8m4_t, vint8m4_t, vint8m4_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vsadd_vv)))
vint8m8_t vsadd(vint8m8_t, vint8m8_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vsadd_vv_m)))
vint8m8_t vsadd(vbool1_t, vint8m8_t, vint8m8_t, vint8m8_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vsadd_vv)))
vint8mf2_t vsadd(vint8mf2_t, vint8mf2_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vsadd_vv_m)))
vint8mf2_t vsadd(vbool16_t, vint8mf2_t, vint8mf2_t, vint8mf2_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vsadd_vv)))
vint8mf4_t vsadd(vint8mf4_t, vint8mf4_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vsadd_vv_m)))
vint8mf4_t vsadd(vbool32_t, vint8mf4_t, vint8mf4_t, vint8mf4_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vsadd_vv)))
vint8mf8_t vsadd(vint8mf8_t, vint8mf8_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vsadd_vv_m)))
vint8mf8_t vsadd(vbool64_t, vint8mf8_t, vint8mf8_t, vint8mf8_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vsadd_vv)))
vint16m1_t vsadd(vint16m1_t, vint16m1_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vsadd_vv_m)))
vint16m1_t vsadd(vbool16_t, vint16m1_t, vint16m1_t, vint16m1_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vsadd_vv)))
vint16m2_t vsadd(vint16m2_t, vint16m2_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vsadd_vv_m)))
vint16m2_t vsadd(vbool8_t, vint16m2_t, vint16m2_t, vint16m2_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vsadd_vv)))
vint16m4_t vsadd(vint16m4_t, vint16m4_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vsadd_vv_m)))
vint16m4_t vsadd(vbool4_t, vint16m4_t, vint16m4_t, vint16m4_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vsadd_vv)))
vint16m8_t vsadd(vint16m8_t, vint16m8_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vsadd_vv_m)))
vint16m8_t vsadd(vbool2_t, vint16m8_t, vint16m8_t, vint16m8_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vsadd_vv)))
vint16mf2_t vsadd(vint16mf2_t, vint16mf2_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vsadd_vv_m)))
vint16mf2_t vsadd(vbool32_t, vint16mf2_t, vint16mf2_t, vint16mf2_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vsadd_vv)))
vint16mf4_t vsadd(vint16mf4_t, vint16mf4_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vsadd_vv_m)))
vint16mf4_t vsadd(vbool64_t, vint16mf4_t, vint16mf4_t, vint16mf4_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vsadd_vv)))
vint32m1_t vsadd(vint32m1_t, vint32m1_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vsadd_vv_m)))
vint32m1_t vsadd(vbool32_t, vint32m1_t, vint32m1_t, vint32m1_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vsadd_vv)))
vint32m2_t vsadd(vint32m2_t, vint32m2_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vsadd_vv_m)))
vint32m2_t vsadd(vbool16_t, vint32m2_t, vint32m2_t, vint32m2_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vsadd_vv)))
vint32m4_t vsadd(vint32m4_t, vint32m4_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vsadd_vv_m)))
vint32m4_t vsadd(vbool8_t, vint32m4_t, vint32m4_t, vint32m4_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vsadd_vv)))
vint32m8_t vsadd(vint32m8_t, vint32m8_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vsadd_vv_m)))
vint32m8_t vsadd(vbool4_t, vint32m8_t, vint32m8_t, vint32m8_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vsadd_vv)))
vint32mf2_t vsadd(vint32mf2_t, vint32mf2_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vsadd_vv_m)))
vint32mf2_t vsadd(vbool64_t, vint32mf2_t, vint32mf2_t, vint32mf2_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vsadd_vx)))
vint8m1_t vsadd(vint8m1_t, int8_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vsadd_vx_m)))
vint8m1_t vsadd(vbool8_t, vint8m1_t, vint8m1_t, int8_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vsadd_vx)))
vint8m2_t vsadd(vint8m2_t, int8_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vsadd_vx_m)))
vint8m2_t vsadd(vbool4_t, vint8m2_t, vint8m2_t, int8_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vsadd_vx)))
vint8m4_t vsadd(vint8m4_t, int8_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vsadd_vx_m)))
vint8m4_t vsadd(vbool2_t, vint8m4_t, vint8m4_t, int8_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vsadd_vx)))
vint8m8_t vsadd(vint8m8_t, int8_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vsadd_vx_m)))
vint8m8_t vsadd(vbool1_t, vint8m8_t, vint8m8_t, int8_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vsadd_vx)))
vint8mf2_t vsadd(vint8mf2_t, int8_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vsadd_vx_m)))
vint8mf2_t vsadd(vbool16_t, vint8mf2_t, vint8mf2_t, int8_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vsadd_vx)))
vint8mf4_t vsadd(vint8mf4_t, int8_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vsadd_vx_m)))
vint8mf4_t vsadd(vbool32_t, vint8mf4_t, vint8mf4_t, int8_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vsadd_vx)))
vint8mf8_t vsadd(vint8mf8_t, int8_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vsadd_vx_m)))
vint8mf8_t vsadd(vbool64_t, vint8mf8_t, vint8mf8_t, int8_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vsadd_vx)))
vint16m1_t vsadd(vint16m1_t, int16_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vsadd_vx_m)))
vint16m1_t vsadd(vbool16_t, vint16m1_t, vint16m1_t, int16_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vsadd_vx)))
vint16m2_t vsadd(vint16m2_t, int16_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vsadd_vx_m)))
vint16m2_t vsadd(vbool8_t, vint16m2_t, vint16m2_t, int16_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vsadd_vx)))
vint16m4_t vsadd(vint16m4_t, int16_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vsadd_vx_m)))
vint16m4_t vsadd(vbool4_t, vint16m4_t, vint16m4_t, int16_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vsadd_vx)))
vint16m8_t vsadd(vint16m8_t, int16_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vsadd_vx_m)))
vint16m8_t vsadd(vbool2_t, vint16m8_t, vint16m8_t, int16_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vsadd_vx)))
vint16mf2_t vsadd(vint16mf2_t, int16_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vsadd_vx_m)))
vint16mf2_t vsadd(vbool32_t, vint16mf2_t, vint16mf2_t, int16_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vsadd_vx)))
vint16mf4_t vsadd(vint16mf4_t, int16_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vsadd_vx_m)))
vint16mf4_t vsadd(vbool64_t, vint16mf4_t, vint16mf4_t, int16_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vsadd_vx)))
vint32m1_t vsadd(vint32m1_t, int32_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vsadd_vx_m)))
vint32m1_t vsadd(vbool32_t, vint32m1_t, vint32m1_t, int32_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vsadd_vx)))
vint32m2_t vsadd(vint32m2_t, int32_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vsadd_vx_m)))
vint32m2_t vsadd(vbool16_t, vint32m2_t, vint32m2_t, int32_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vsadd_vx)))
vint32m4_t vsadd(vint32m4_t, int32_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vsadd_vx_m)))
vint32m4_t vsadd(vbool8_t, vint32m4_t, vint32m4_t, int32_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vsadd_vx)))
vint32m8_t vsadd(vint32m8_t, int32_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vsadd_vx_m)))
vint32m8_t vsadd(vbool4_t, vint32m8_t, vint32m8_t, int32_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vsadd_vx)))
vint32mf2_t vsadd(vint32mf2_t, int32_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vsadd_vx_m)))
vint32mf2_t vsadd(vbool64_t, vint32mf2_t, vint32mf2_t, int32_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vsuxei16_v)))
void vsuxei16(uint16_t *, vuint16m1_t, vuint16m1_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vsuxei16_v_m)))
void vsuxei16(vbool16_t, uint16_t *, vuint16m1_t, vuint16m1_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vsuxei16_v)))
void vsuxei16(uint16_t *, vuint16m2_t, vuint16m2_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vsuxei16_v_m)))
void vsuxei16(vbool8_t, uint16_t *, vuint16m2_t, vuint16m2_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vsuxei16_v)))
void vsuxei16(uint16_t *, vuint16m4_t, vuint16m4_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vsuxei16_v_m)))
void vsuxei16(vbool4_t, uint16_t *, vuint16m4_t, vuint16m4_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vsuxei16_v)))
void vsuxei16(uint16_t *, vuint16m8_t, vuint16m8_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vsuxei16_v_m)))
void vsuxei16(vbool2_t, uint16_t *, vuint16m8_t, vuint16m8_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vsuxei16_v)))
void vsuxei16(uint16_t *, vuint16mf2_t, vuint16mf2_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vsuxei16_v_m)))
void vsuxei16(vbool32_t, uint16_t *, vuint16mf2_t, vuint16mf2_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vsuxei16_v)))
void vsuxei16(uint16_t *, vuint16mf4_t, vuint16mf4_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vsuxei16_v_m)))
void vsuxei16(vbool64_t, uint16_t *, vuint16mf4_t, vuint16mf4_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vssubu_vv)))
vuint8m1_t vssubu(vuint8m1_t, vuint8m1_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vssubu_vv_m)))
vuint8m1_t vssubu(vbool8_t, vuint8m1_t, vuint8m1_t, vuint8m1_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vssubu_vv)))
vuint8m2_t vssubu(vuint8m2_t, vuint8m2_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vssubu_vv_m)))
vuint8m2_t vssubu(vbool4_t, vuint8m2_t, vuint8m2_t, vuint8m2_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vssubu_vv)))
vuint8m4_t vssubu(vuint8m4_t, vuint8m4_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vssubu_vv_m)))
vuint8m4_t vssubu(vbool2_t, vuint8m4_t, vuint8m4_t, vuint8m4_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vssubu_vv)))
vuint8m8_t vssubu(vuint8m8_t, vuint8m8_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vssubu_vv_m)))
vuint8m8_t vssubu(vbool1_t, vuint8m8_t, vuint8m8_t, vuint8m8_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vssubu_vv)))
vuint8mf2_t vssubu(vuint8mf2_t, vuint8mf2_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vssubu_vv_m)))
vuint8mf2_t vssubu(vbool16_t, vuint8mf2_t, vuint8mf2_t, vuint8mf2_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vssubu_vv)))
vuint8mf4_t vssubu(vuint8mf4_t, vuint8mf4_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vssubu_vv_m)))
vuint8mf4_t vssubu(vbool32_t, vuint8mf4_t, vuint8mf4_t, vuint8mf4_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vssubu_vv)))
vuint8mf8_t vssubu(vuint8mf8_t, vuint8mf8_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vssubu_vv_m)))
vuint8mf8_t vssubu(vbool64_t, vuint8mf8_t, vuint8mf8_t, vuint8mf8_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vssubu_vv)))
vuint16m1_t vssubu(vuint16m1_t, vuint16m1_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vssubu_vv_m)))
vuint16m1_t vssubu(vbool16_t, vuint16m1_t, vuint16m1_t, vuint16m1_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vssubu_vv)))
vuint16m2_t vssubu(vuint16m2_t, vuint16m2_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vssubu_vv_m)))
vuint16m2_t vssubu(vbool8_t, vuint16m2_t, vuint16m2_t, vuint16m2_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vssubu_vv)))
vuint16m4_t vssubu(vuint16m4_t, vuint16m4_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vssubu_vv_m)))
vuint16m4_t vssubu(vbool4_t, vuint16m4_t, vuint16m4_t, vuint16m4_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vssubu_vv)))
vuint16m8_t vssubu(vuint16m8_t, vuint16m8_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vssubu_vv_m)))
vuint16m8_t vssubu(vbool2_t, vuint16m8_t, vuint16m8_t, vuint16m8_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vssubu_vv)))
vuint16mf2_t vssubu(vuint16mf2_t, vuint16mf2_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vssubu_vv_m)))
vuint16mf2_t vssubu(vbool32_t, vuint16mf2_t, vuint16mf2_t, vuint16mf2_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vssubu_vv)))
vuint16mf4_t vssubu(vuint16mf4_t, vuint16mf4_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vssubu_vv_m)))
vuint16mf4_t vssubu(vbool64_t, vuint16mf4_t, vuint16mf4_t, vuint16mf4_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vssubu_vv)))
vuint32m1_t vssubu(vuint32m1_t, vuint32m1_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vssubu_vv_m)))
vuint32m1_t vssubu(vbool32_t, vuint32m1_t, vuint32m1_t, vuint32m1_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vssubu_vv)))
vuint32m2_t vssubu(vuint32m2_t, vuint32m2_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vssubu_vv_m)))
vuint32m2_t vssubu(vbool16_t, vuint32m2_t, vuint32m2_t, vuint32m2_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vssubu_vv)))
vuint32m4_t vssubu(vuint32m4_t, vuint32m4_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vssubu_vv_m)))
vuint32m4_t vssubu(vbool8_t, vuint32m4_t, vuint32m4_t, vuint32m4_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vssubu_vv)))
vuint32m8_t vssubu(vuint32m8_t, vuint32m8_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vssubu_vv_m)))
vuint32m8_t vssubu(vbool4_t, vuint32m8_t, vuint32m8_t, vuint32m8_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vssubu_vv)))
vuint32mf2_t vssubu(vuint32mf2_t, vuint32mf2_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vssubu_vv_m)))
vuint32mf2_t vssubu(vbool64_t, vuint32mf2_t, vuint32mf2_t, vuint32mf2_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vssubu_vx)))
vuint8m1_t vssubu(vuint8m1_t, uint8_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vssubu_vx_m)))
vuint8m1_t vssubu(vbool8_t, vuint8m1_t, vuint8m1_t, uint8_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vssubu_vx)))
vuint8m2_t vssubu(vuint8m2_t, uint8_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vssubu_vx_m)))
vuint8m2_t vssubu(vbool4_t, vuint8m2_t, vuint8m2_t, uint8_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vssubu_vx)))
vuint8m4_t vssubu(vuint8m4_t, uint8_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vssubu_vx_m)))
vuint8m4_t vssubu(vbool2_t, vuint8m4_t, vuint8m4_t, uint8_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vssubu_vx)))
vuint8m8_t vssubu(vuint8m8_t, uint8_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vssubu_vx_m)))
vuint8m8_t vssubu(vbool1_t, vuint8m8_t, vuint8m8_t, uint8_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vssubu_vx)))
vuint8mf2_t vssubu(vuint8mf2_t, uint8_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vssubu_vx_m)))
vuint8mf2_t vssubu(vbool16_t, vuint8mf2_t, vuint8mf2_t, uint8_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vssubu_vx)))
vuint8mf4_t vssubu(vuint8mf4_t, uint8_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vssubu_vx_m)))
vuint8mf4_t vssubu(vbool32_t, vuint8mf4_t, vuint8mf4_t, uint8_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vssubu_vx)))
vuint8mf8_t vssubu(vuint8mf8_t, uint8_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vssubu_vx_m)))
vuint8mf8_t vssubu(vbool64_t, vuint8mf8_t, vuint8mf8_t, uint8_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vssubu_vx)))
vuint16m1_t vssubu(vuint16m1_t, uint16_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vssubu_vx_m)))
vuint16m1_t vssubu(vbool16_t, vuint16m1_t, vuint16m1_t, uint16_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vssubu_vx)))
vuint16m2_t vssubu(vuint16m2_t, uint16_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vssubu_vx_m)))
vuint16m2_t vssubu(vbool8_t, vuint16m2_t, vuint16m2_t, uint16_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vssubu_vx)))
vuint16m4_t vssubu(vuint16m4_t, uint16_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vssubu_vx_m)))
vuint16m4_t vssubu(vbool4_t, vuint16m4_t, vuint16m4_t, uint16_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vssubu_vx)))
vuint16m8_t vssubu(vuint16m8_t, uint16_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vssubu_vx_m)))
vuint16m8_t vssubu(vbool2_t, vuint16m8_t, vuint16m8_t, uint16_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vssubu_vx)))
vuint16mf2_t vssubu(vuint16mf2_t, uint16_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vssubu_vx_m)))
vuint16mf2_t vssubu(vbool32_t, vuint16mf2_t, vuint16mf2_t, uint16_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vssubu_vx)))
vuint16mf4_t vssubu(vuint16mf4_t, uint16_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vssubu_vx_m)))
vuint16mf4_t vssubu(vbool64_t, vuint16mf4_t, vuint16mf4_t, uint16_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vssubu_vx)))
vuint32m1_t vssubu(vuint32m1_t, uint32_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vssubu_vx_m)))
vuint32m1_t vssubu(vbool32_t, vuint32m1_t, vuint32m1_t, uint32_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vssubu_vx)))
vuint32m2_t vssubu(vuint32m2_t, uint32_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vssubu_vx_m)))
vuint32m2_t vssubu(vbool16_t, vuint32m2_t, vuint32m2_t, uint32_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vssubu_vx)))
vuint32m4_t vssubu(vuint32m4_t, uint32_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vssubu_vx_m)))
vuint32m4_t vssubu(vbool8_t, vuint32m4_t, vuint32m4_t, uint32_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vssubu_vx)))
vuint32m8_t vssubu(vuint32m8_t, uint32_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vssubu_vx_m)))
vuint32m8_t vssubu(vbool4_t, vuint32m8_t, vuint32m8_t, uint32_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vssubu_vx)))
vuint32mf2_t vssubu(vuint32mf2_t, uint32_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vssubu_vx_m)))
vuint32mf2_t vssubu(vbool64_t, vuint32mf2_t, vuint32mf2_t, uint32_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vssub_vv)))
vint8m1_t vssub(vint8m1_t, vint8m1_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vssub_vv_m)))
vint8m1_t vssub(vbool8_t, vint8m1_t, vint8m1_t, vint8m1_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vssub_vv)))
vint8m2_t vssub(vint8m2_t, vint8m2_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vssub_vv_m)))
vint8m2_t vssub(vbool4_t, vint8m2_t, vint8m2_t, vint8m2_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vssub_vv)))
vint8m4_t vssub(vint8m4_t, vint8m4_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vssub_vv_m)))
vint8m4_t vssub(vbool2_t, vint8m4_t, vint8m4_t, vint8m4_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vssub_vv)))
vint8m8_t vssub(vint8m8_t, vint8m8_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vssub_vv_m)))
vint8m8_t vssub(vbool1_t, vint8m8_t, vint8m8_t, vint8m8_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vssub_vv)))
vint8mf2_t vssub(vint8mf2_t, vint8mf2_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vssub_vv_m)))
vint8mf2_t vssub(vbool16_t, vint8mf2_t, vint8mf2_t, vint8mf2_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vssub_vv)))
vint8mf4_t vssub(vint8mf4_t, vint8mf4_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vssub_vv_m)))
vint8mf4_t vssub(vbool32_t, vint8mf4_t, vint8mf4_t, vint8mf4_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vssub_vv)))
vint8mf8_t vssub(vint8mf8_t, vint8mf8_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vssub_vv_m)))
vint8mf8_t vssub(vbool64_t, vint8mf8_t, vint8mf8_t, vint8mf8_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vssub_vv)))
vint16m1_t vssub(vint16m1_t, vint16m1_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vssub_vv_m)))
vint16m1_t vssub(vbool16_t, vint16m1_t, vint16m1_t, vint16m1_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vssub_vv)))
vint16m2_t vssub(vint16m2_t, vint16m2_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vssub_vv_m)))
vint16m2_t vssub(vbool8_t, vint16m2_t, vint16m2_t, vint16m2_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vssub_vv)))
vint16m4_t vssub(vint16m4_t, vint16m4_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vssub_vv_m)))
vint16m4_t vssub(vbool4_t, vint16m4_t, vint16m4_t, vint16m4_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vssub_vv)))
vint16m8_t vssub(vint16m8_t, vint16m8_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vssub_vv_m)))
vint16m8_t vssub(vbool2_t, vint16m8_t, vint16m8_t, vint16m8_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vssub_vv)))
vint16mf2_t vssub(vint16mf2_t, vint16mf2_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vssub_vv_m)))
vint16mf2_t vssub(vbool32_t, vint16mf2_t, vint16mf2_t, vint16mf2_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vssub_vv)))
vint16mf4_t vssub(vint16mf4_t, vint16mf4_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vssub_vv_m)))
vint16mf4_t vssub(vbool64_t, vint16mf4_t, vint16mf4_t, vint16mf4_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vssub_vv)))
vint32m1_t vssub(vint32m1_t, vint32m1_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vssub_vv_m)))
vint32m1_t vssub(vbool32_t, vint32m1_t, vint32m1_t, vint32m1_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vssub_vv)))
vint32m2_t vssub(vint32m2_t, vint32m2_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vssub_vv_m)))
vint32m2_t vssub(vbool16_t, vint32m2_t, vint32m2_t, vint32m2_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vssub_vv)))
vint32m4_t vssub(vint32m4_t, vint32m4_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vssub_vv_m)))
vint32m4_t vssub(vbool8_t, vint32m4_t, vint32m4_t, vint32m4_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vssub_vv)))
vint32m8_t vssub(vint32m8_t, vint32m8_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vssub_vv_m)))
vint32m8_t vssub(vbool4_t, vint32m8_t, vint32m8_t, vint32m8_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vssub_vv)))
vint32mf2_t vssub(vint32mf2_t, vint32mf2_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vssub_vv_m)))
vint32mf2_t vssub(vbool64_t, vint32mf2_t, vint32mf2_t, vint32mf2_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vssub_vx)))
vint8m1_t vssub(vint8m1_t, int8_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vssub_vx_m)))
vint8m1_t vssub(vbool8_t, vint8m1_t, vint8m1_t, int8_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vssub_vx)))
vint8m2_t vssub(vint8m2_t, int8_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vssub_vx_m)))
vint8m2_t vssub(vbool4_t, vint8m2_t, vint8m2_t, int8_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vssub_vx)))
vint8m4_t vssub(vint8m4_t, int8_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vssub_vx_m)))
vint8m4_t vssub(vbool2_t, vint8m4_t, vint8m4_t, int8_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vssub_vx)))
vint8m8_t vssub(vint8m8_t, int8_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vssub_vx_m)))
vint8m8_t vssub(vbool1_t, vint8m8_t, vint8m8_t, int8_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vssub_vx)))
vint8mf2_t vssub(vint8mf2_t, int8_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vssub_vx_m)))
vint8mf2_t vssub(vbool16_t, vint8mf2_t, vint8mf2_t, int8_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vssub_vx)))
vint8mf4_t vssub(vint8mf4_t, int8_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vssub_vx_m)))
vint8mf4_t vssub(vbool32_t, vint8mf4_t, vint8mf4_t, int8_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vssub_vx)))
vint8mf8_t vssub(vint8mf8_t, int8_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vssub_vx_m)))
vint8mf8_t vssub(vbool64_t, vint8mf8_t, vint8mf8_t, int8_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vssub_vx)))
vint16m1_t vssub(vint16m1_t, int16_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vssub_vx_m)))
vint16m1_t vssub(vbool16_t, vint16m1_t, vint16m1_t, int16_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vssub_vx)))
vint16m2_t vssub(vint16m2_t, int16_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vssub_vx_m)))
vint16m2_t vssub(vbool8_t, vint16m2_t, vint16m2_t, int16_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vssub_vx)))
vint16m4_t vssub(vint16m4_t, int16_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vssub_vx_m)))
vint16m4_t vssub(vbool4_t, vint16m4_t, vint16m4_t, int16_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vssub_vx)))
vint16m8_t vssub(vint16m8_t, int16_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vssub_vx_m)))
vint16m8_t vssub(vbool2_t, vint16m8_t, vint16m8_t, int16_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vssub_vx)))
vint16mf2_t vssub(vint16mf2_t, int16_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vssub_vx_m)))
vint16mf2_t vssub(vbool32_t, vint16mf2_t, vint16mf2_t, int16_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vssub_vx)))
vint16mf4_t vssub(vint16mf4_t, int16_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vssub_vx_m)))
vint16mf4_t vssub(vbool64_t, vint16mf4_t, vint16mf4_t, int16_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vssub_vx)))
vint32m1_t vssub(vint32m1_t, int32_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vssub_vx_m)))
vint32m1_t vssub(vbool32_t, vint32m1_t, vint32m1_t, int32_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vssub_vx)))
vint32m2_t vssub(vint32m2_t, int32_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vssub_vx_m)))
vint32m2_t vssub(vbool16_t, vint32m2_t, vint32m2_t, int32_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vssub_vx)))
vint32m4_t vssub(vint32m4_t, int32_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vssub_vx_m)))
vint32m4_t vssub(vbool8_t, vint32m4_t, vint32m4_t, int32_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vssub_vx)))
vint32m8_t vssub(vint32m8_t, int32_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vssub_vx_m)))
vint32m8_t vssub(vbool4_t, vint32m8_t, vint32m8_t, int32_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vssub_vx)))
vint32mf2_t vssub(vint32mf2_t, int32_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vssub_vx_m)))
vint32mf2_t vssub(vbool64_t, vint32mf2_t, vint32mf2_t, int32_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vaaddu_vv)))
vuint8m1_t vaaddu(vuint8m1_t, vuint8m1_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vaaddu_vv_m)))
vuint8m1_t vaaddu(vbool8_t, vuint8m1_t, vuint8m1_t, vuint8m1_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vaaddu_vv)))
vuint8m2_t vaaddu(vuint8m2_t, vuint8m2_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vaaddu_vv_m)))
vuint8m2_t vaaddu(vbool4_t, vuint8m2_t, vuint8m2_t, vuint8m2_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vaaddu_vv)))
vuint8m4_t vaaddu(vuint8m4_t, vuint8m4_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vaaddu_vv_m)))
vuint8m4_t vaaddu(vbool2_t, vuint8m4_t, vuint8m4_t, vuint8m4_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vaaddu_vv)))
vuint8m8_t vaaddu(vuint8m8_t, vuint8m8_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vaaddu_vv_m)))
vuint8m8_t vaaddu(vbool1_t, vuint8m8_t, vuint8m8_t, vuint8m8_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vaaddu_vv)))
vuint8mf2_t vaaddu(vuint8mf2_t, vuint8mf2_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vaaddu_vv_m)))
vuint8mf2_t vaaddu(vbool16_t, vuint8mf2_t, vuint8mf2_t, vuint8mf2_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vaaddu_vv)))
vuint8mf4_t vaaddu(vuint8mf4_t, vuint8mf4_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vaaddu_vv_m)))
vuint8mf4_t vaaddu(vbool32_t, vuint8mf4_t, vuint8mf4_t, vuint8mf4_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vaaddu_vv)))
vuint8mf8_t vaaddu(vuint8mf8_t, vuint8mf8_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vaaddu_vv_m)))
vuint8mf8_t vaaddu(vbool64_t, vuint8mf8_t, vuint8mf8_t, vuint8mf8_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vaaddu_vv)))
vuint16m1_t vaaddu(vuint16m1_t, vuint16m1_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vaaddu_vv_m)))
vuint16m1_t vaaddu(vbool16_t, vuint16m1_t, vuint16m1_t, vuint16m1_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vaaddu_vv)))
vuint16m2_t vaaddu(vuint16m2_t, vuint16m2_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vaaddu_vv_m)))
vuint16m2_t vaaddu(vbool8_t, vuint16m2_t, vuint16m2_t, vuint16m2_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vaaddu_vv)))
vuint16m4_t vaaddu(vuint16m4_t, vuint16m4_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vaaddu_vv_m)))
vuint16m4_t vaaddu(vbool4_t, vuint16m4_t, vuint16m4_t, vuint16m4_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vaaddu_vv)))
vuint16m8_t vaaddu(vuint16m8_t, vuint16m8_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vaaddu_vv_m)))
vuint16m8_t vaaddu(vbool2_t, vuint16m8_t, vuint16m8_t, vuint16m8_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vaaddu_vv)))
vuint16mf2_t vaaddu(vuint16mf2_t, vuint16mf2_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vaaddu_vv_m)))
vuint16mf2_t vaaddu(vbool32_t, vuint16mf2_t, vuint16mf2_t, vuint16mf2_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vaaddu_vv)))
vuint16mf4_t vaaddu(vuint16mf4_t, vuint16mf4_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vaaddu_vv_m)))
vuint16mf4_t vaaddu(vbool64_t, vuint16mf4_t, vuint16mf4_t, vuint16mf4_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vaaddu_vv)))
vuint32m1_t vaaddu(vuint32m1_t, vuint32m1_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vaaddu_vv_m)))
vuint32m1_t vaaddu(vbool32_t, vuint32m1_t, vuint32m1_t, vuint32m1_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vaaddu_vv)))
vuint32m2_t vaaddu(vuint32m2_t, vuint32m2_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vaaddu_vv_m)))
vuint32m2_t vaaddu(vbool16_t, vuint32m2_t, vuint32m2_t, vuint32m2_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vaaddu_vv)))
vuint32m4_t vaaddu(vuint32m4_t, vuint32m4_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vaaddu_vv_m)))
vuint32m4_t vaaddu(vbool8_t, vuint32m4_t, vuint32m4_t, vuint32m4_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vaaddu_vv)))
vuint32m8_t vaaddu(vuint32m8_t, vuint32m8_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vaaddu_vv_m)))
vuint32m8_t vaaddu(vbool4_t, vuint32m8_t, vuint32m8_t, vuint32m8_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vaaddu_vv)))
vuint32mf2_t vaaddu(vuint32mf2_t, vuint32mf2_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vaaddu_vv_m)))
vuint32mf2_t vaaddu(vbool64_t, vuint32mf2_t, vuint32mf2_t, vuint32mf2_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vaaddu_vx)))
vuint8m1_t vaaddu(vuint8m1_t, uint8_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vaaddu_vx_m)))
vuint8m1_t vaaddu(vbool8_t, vuint8m1_t, vuint8m1_t, uint8_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vaaddu_vx)))
vuint8m2_t vaaddu(vuint8m2_t, uint8_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vaaddu_vx_m)))
vuint8m2_t vaaddu(vbool4_t, vuint8m2_t, vuint8m2_t, uint8_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vaaddu_vx)))
vuint8m4_t vaaddu(vuint8m4_t, uint8_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vaaddu_vx_m)))
vuint8m4_t vaaddu(vbool2_t, vuint8m4_t, vuint8m4_t, uint8_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vaaddu_vx)))
vuint8m8_t vaaddu(vuint8m8_t, uint8_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vaaddu_vx_m)))
vuint8m8_t vaaddu(vbool1_t, vuint8m8_t, vuint8m8_t, uint8_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vaaddu_vx)))
vuint8mf2_t vaaddu(vuint8mf2_t, uint8_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vaaddu_vx_m)))
vuint8mf2_t vaaddu(vbool16_t, vuint8mf2_t, vuint8mf2_t, uint8_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vaaddu_vx)))
vuint8mf4_t vaaddu(vuint8mf4_t, uint8_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vaaddu_vx_m)))
vuint8mf4_t vaaddu(vbool32_t, vuint8mf4_t, vuint8mf4_t, uint8_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vaaddu_vx)))
vuint8mf8_t vaaddu(vuint8mf8_t, uint8_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vaaddu_vx_m)))
vuint8mf8_t vaaddu(vbool64_t, vuint8mf8_t, vuint8mf8_t, uint8_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vaaddu_vx)))
vuint16m1_t vaaddu(vuint16m1_t, uint16_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vaaddu_vx_m)))
vuint16m1_t vaaddu(vbool16_t, vuint16m1_t, vuint16m1_t, uint16_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vaaddu_vx)))
vuint16m2_t vaaddu(vuint16m2_t, uint16_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vaaddu_vx_m)))
vuint16m2_t vaaddu(vbool8_t, vuint16m2_t, vuint16m2_t, uint16_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vaaddu_vx)))
vuint16m4_t vaaddu(vuint16m4_t, uint16_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vaaddu_vx_m)))
vuint16m4_t vaaddu(vbool4_t, vuint16m4_t, vuint16m4_t, uint16_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vaaddu_vx)))
vuint16m8_t vaaddu(vuint16m8_t, uint16_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vaaddu_vx_m)))
vuint16m8_t vaaddu(vbool2_t, vuint16m8_t, vuint16m8_t, uint16_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vaaddu_vx)))
vuint16mf2_t vaaddu(vuint16mf2_t, uint16_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vaaddu_vx_m)))
vuint16mf2_t vaaddu(vbool32_t, vuint16mf2_t, vuint16mf2_t, uint16_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vaaddu_vx)))
vuint16mf4_t vaaddu(vuint16mf4_t, uint16_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vaaddu_vx_m)))
vuint16mf4_t vaaddu(vbool64_t, vuint16mf4_t, vuint16mf4_t, uint16_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vaaddu_vx)))
vuint32m1_t vaaddu(vuint32m1_t, uint32_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vaaddu_vx_m)))
vuint32m1_t vaaddu(vbool32_t, vuint32m1_t, vuint32m1_t, uint32_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vaaddu_vx)))
vuint32m2_t vaaddu(vuint32m2_t, uint32_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vaaddu_vx_m)))
vuint32m2_t vaaddu(vbool16_t, vuint32m2_t, vuint32m2_t, uint32_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vaaddu_vx)))
vuint32m4_t vaaddu(vuint32m4_t, uint32_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vaaddu_vx_m)))
vuint32m4_t vaaddu(vbool8_t, vuint32m4_t, vuint32m4_t, uint32_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vaaddu_vx)))
vuint32m8_t vaaddu(vuint32m8_t, uint32_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vaaddu_vx_m)))
vuint32m8_t vaaddu(vbool4_t, vuint32m8_t, vuint32m8_t, uint32_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vaaddu_vx)))
vuint32mf2_t vaaddu(vuint32mf2_t, uint32_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vaaddu_vx_m)))
vuint32mf2_t vaaddu(vbool64_t, vuint32mf2_t, vuint32mf2_t, uint32_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vaadd_vv)))
vint8m1_t vaadd(vint8m1_t, vint8m1_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vaadd_vv_m)))
vint8m1_t vaadd(vbool8_t, vint8m1_t, vint8m1_t, vint8m1_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vaadd_vv)))
vint8m2_t vaadd(vint8m2_t, vint8m2_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vaadd_vv_m)))
vint8m2_t vaadd(vbool4_t, vint8m2_t, vint8m2_t, vint8m2_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vaadd_vv)))
vint8m4_t vaadd(vint8m4_t, vint8m4_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vaadd_vv_m)))
vint8m4_t vaadd(vbool2_t, vint8m4_t, vint8m4_t, vint8m4_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vaadd_vv)))
vint8m8_t vaadd(vint8m8_t, vint8m8_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vaadd_vv_m)))
vint8m8_t vaadd(vbool1_t, vint8m8_t, vint8m8_t, vint8m8_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vaadd_vv)))
vint8mf2_t vaadd(vint8mf2_t, vint8mf2_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vaadd_vv_m)))
vint8mf2_t vaadd(vbool16_t, vint8mf2_t, vint8mf2_t, vint8mf2_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vaadd_vv)))
vint8mf4_t vaadd(vint8mf4_t, vint8mf4_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vaadd_vv_m)))
vint8mf4_t vaadd(vbool32_t, vint8mf4_t, vint8mf4_t, vint8mf4_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vaadd_vv)))
vint8mf8_t vaadd(vint8mf8_t, vint8mf8_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vaadd_vv_m)))
vint8mf8_t vaadd(vbool64_t, vint8mf8_t, vint8mf8_t, vint8mf8_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vaadd_vv)))
vint16m1_t vaadd(vint16m1_t, vint16m1_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vaadd_vv_m)))
vint16m1_t vaadd(vbool16_t, vint16m1_t, vint16m1_t, vint16m1_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vaadd_vv)))
vint16m2_t vaadd(vint16m2_t, vint16m2_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vaadd_vv_m)))
vint16m2_t vaadd(vbool8_t, vint16m2_t, vint16m2_t, vint16m2_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vaadd_vv)))
vint16m4_t vaadd(vint16m4_t, vint16m4_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vaadd_vv_m)))
vint16m4_t vaadd(vbool4_t, vint16m4_t, vint16m4_t, vint16m4_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vaadd_vv)))
vint16m8_t vaadd(vint16m8_t, vint16m8_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vaadd_vv_m)))
vint16m8_t vaadd(vbool2_t, vint16m8_t, vint16m8_t, vint16m8_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vaadd_vv)))
vint16mf2_t vaadd(vint16mf2_t, vint16mf2_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vaadd_vv_m)))
vint16mf2_t vaadd(vbool32_t, vint16mf2_t, vint16mf2_t, vint16mf2_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vaadd_vv)))
vint16mf4_t vaadd(vint16mf4_t, vint16mf4_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vaadd_vv_m)))
vint16mf4_t vaadd(vbool64_t, vint16mf4_t, vint16mf4_t, vint16mf4_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vaadd_vv)))
vint32m1_t vaadd(vint32m1_t, vint32m1_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vaadd_vv_m)))
vint32m1_t vaadd(vbool32_t, vint32m1_t, vint32m1_t, vint32m1_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vaadd_vv)))
vint32m2_t vaadd(vint32m2_t, vint32m2_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vaadd_vv_m)))
vint32m2_t vaadd(vbool16_t, vint32m2_t, vint32m2_t, vint32m2_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vaadd_vv)))
vint32m4_t vaadd(vint32m4_t, vint32m4_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vaadd_vv_m)))
vint32m4_t vaadd(vbool8_t, vint32m4_t, vint32m4_t, vint32m4_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vaadd_vv)))
vint32m8_t vaadd(vint32m8_t, vint32m8_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vaadd_vv_m)))
vint32m8_t vaadd(vbool4_t, vint32m8_t, vint32m8_t, vint32m8_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vaadd_vv)))
vint32mf2_t vaadd(vint32mf2_t, vint32mf2_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vaadd_vv_m)))
vint32mf2_t vaadd(vbool64_t, vint32mf2_t, vint32mf2_t, vint32mf2_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vaadd_vx)))
vint8m1_t vaadd(vint8m1_t, int8_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vaadd_vx_m)))
vint8m1_t vaadd(vbool8_t, vint8m1_t, vint8m1_t, int8_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vaadd_vx)))
vint8m2_t vaadd(vint8m2_t, int8_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vaadd_vx_m)))
vint8m2_t vaadd(vbool4_t, vint8m2_t, vint8m2_t, int8_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vaadd_vx)))
vint8m4_t vaadd(vint8m4_t, int8_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vaadd_vx_m)))
vint8m4_t vaadd(vbool2_t, vint8m4_t, vint8m4_t, int8_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vaadd_vx)))
vint8m8_t vaadd(vint8m8_t, int8_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vaadd_vx_m)))
vint8m8_t vaadd(vbool1_t, vint8m8_t, vint8m8_t, int8_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vaadd_vx)))
vint8mf2_t vaadd(vint8mf2_t, int8_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vaadd_vx_m)))
vint8mf2_t vaadd(vbool16_t, vint8mf2_t, vint8mf2_t, int8_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vaadd_vx)))
vint8mf4_t vaadd(vint8mf4_t, int8_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vaadd_vx_m)))
vint8mf4_t vaadd(vbool32_t, vint8mf4_t, vint8mf4_t, int8_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vaadd_vx)))
vint8mf8_t vaadd(vint8mf8_t, int8_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vaadd_vx_m)))
vint8mf8_t vaadd(vbool64_t, vint8mf8_t, vint8mf8_t, int8_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vaadd_vx)))
vint16m1_t vaadd(vint16m1_t, int16_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vaadd_vx_m)))
vint16m1_t vaadd(vbool16_t, vint16m1_t, vint16m1_t, int16_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vaadd_vx)))
vint16m2_t vaadd(vint16m2_t, int16_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vaadd_vx_m)))
vint16m2_t vaadd(vbool8_t, vint16m2_t, vint16m2_t, int16_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vaadd_vx)))
vint16m4_t vaadd(vint16m4_t, int16_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vaadd_vx_m)))
vint16m4_t vaadd(vbool4_t, vint16m4_t, vint16m4_t, int16_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vaadd_vx)))
vint16m8_t vaadd(vint16m8_t, int16_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vaadd_vx_m)))
vint16m8_t vaadd(vbool2_t, vint16m8_t, vint16m8_t, int16_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vaadd_vx)))
vint16mf2_t vaadd(vint16mf2_t, int16_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vaadd_vx_m)))
vint16mf2_t vaadd(vbool32_t, vint16mf2_t, vint16mf2_t, int16_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vaadd_vx)))
vint16mf4_t vaadd(vint16mf4_t, int16_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vaadd_vx_m)))
vint16mf4_t vaadd(vbool64_t, vint16mf4_t, vint16mf4_t, int16_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vaadd_vx)))
vint32m1_t vaadd(vint32m1_t, int32_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vaadd_vx_m)))
vint32m1_t vaadd(vbool32_t, vint32m1_t, vint32m1_t, int32_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vaadd_vx)))
vint32m2_t vaadd(vint32m2_t, int32_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vaadd_vx_m)))
vint32m2_t vaadd(vbool16_t, vint32m2_t, vint32m2_t, int32_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vaadd_vx)))
vint32m4_t vaadd(vint32m4_t, int32_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vaadd_vx_m)))
vint32m4_t vaadd(vbool8_t, vint32m4_t, vint32m4_t, int32_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vaadd_vx)))
vint32m8_t vaadd(vint32m8_t, int32_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vaadd_vx_m)))
vint32m8_t vaadd(vbool4_t, vint32m8_t, vint32m8_t, int32_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vaadd_vx)))
vint32mf2_t vaadd(vint32mf2_t, int32_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vaadd_vx_m)))
vint32mf2_t vaadd(vbool64_t, vint32mf2_t, vint32mf2_t, int32_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vasubu_vv)))
vuint8m1_t vasubu(vuint8m1_t, vuint8m1_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vasubu_vv_m)))
vuint8m1_t vasubu(vbool8_t, vuint8m1_t, vuint8m1_t, vuint8m1_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vasubu_vv)))
vuint8m2_t vasubu(vuint8m2_t, vuint8m2_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vasubu_vv_m)))
vuint8m2_t vasubu(vbool4_t, vuint8m2_t, vuint8m2_t, vuint8m2_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vasubu_vv)))
vuint8m4_t vasubu(vuint8m4_t, vuint8m4_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vasubu_vv_m)))
vuint8m4_t vasubu(vbool2_t, vuint8m4_t, vuint8m4_t, vuint8m4_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vasubu_vv)))
vuint8m8_t vasubu(vuint8m8_t, vuint8m8_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vasubu_vv_m)))
vuint8m8_t vasubu(vbool1_t, vuint8m8_t, vuint8m8_t, vuint8m8_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vasubu_vv)))
vuint8mf2_t vasubu(vuint8mf2_t, vuint8mf2_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vasubu_vv_m)))
vuint8mf2_t vasubu(vbool16_t, vuint8mf2_t, vuint8mf2_t, vuint8mf2_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vasubu_vv)))
vuint8mf4_t vasubu(vuint8mf4_t, vuint8mf4_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vasubu_vv_m)))
vuint8mf4_t vasubu(vbool32_t, vuint8mf4_t, vuint8mf4_t, vuint8mf4_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vasubu_vv)))
vuint8mf8_t vasubu(vuint8mf8_t, vuint8mf8_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vasubu_vv_m)))
vuint8mf8_t vasubu(vbool64_t, vuint8mf8_t, vuint8mf8_t, vuint8mf8_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vasubu_vv)))
vuint16m1_t vasubu(vuint16m1_t, vuint16m1_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vasubu_vv_m)))
vuint16m1_t vasubu(vbool16_t, vuint16m1_t, vuint16m1_t, vuint16m1_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vasubu_vv)))
vuint16m2_t vasubu(vuint16m2_t, vuint16m2_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vasubu_vv_m)))
vuint16m2_t vasubu(vbool8_t, vuint16m2_t, vuint16m2_t, vuint16m2_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vasubu_vv)))
vuint16m4_t vasubu(vuint16m4_t, vuint16m4_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vasubu_vv_m)))
vuint16m4_t vasubu(vbool4_t, vuint16m4_t, vuint16m4_t, vuint16m4_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vasubu_vv)))
vuint16m8_t vasubu(vuint16m8_t, vuint16m8_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vasubu_vv_m)))
vuint16m8_t vasubu(vbool2_t, vuint16m8_t, vuint16m8_t, vuint16m8_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vasubu_vv)))
vuint16mf2_t vasubu(vuint16mf2_t, vuint16mf2_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vasubu_vv_m)))
vuint16mf2_t vasubu(vbool32_t, vuint16mf2_t, vuint16mf2_t, vuint16mf2_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vasubu_vv)))
vuint16mf4_t vasubu(vuint16mf4_t, vuint16mf4_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vasubu_vv_m)))
vuint16mf4_t vasubu(vbool64_t, vuint16mf4_t, vuint16mf4_t, vuint16mf4_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vasubu_vv)))
vuint32m1_t vasubu(vuint32m1_t, vuint32m1_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vasubu_vv_m)))
vuint32m1_t vasubu(vbool32_t, vuint32m1_t, vuint32m1_t, vuint32m1_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vasubu_vv)))
vuint32m2_t vasubu(vuint32m2_t, vuint32m2_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vasubu_vv_m)))
vuint32m2_t vasubu(vbool16_t, vuint32m2_t, vuint32m2_t, vuint32m2_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vasubu_vv)))
vuint32m4_t vasubu(vuint32m4_t, vuint32m4_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vasubu_vv_m)))
vuint32m4_t vasubu(vbool8_t, vuint32m4_t, vuint32m4_t, vuint32m4_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vasubu_vv)))
vuint32m8_t vasubu(vuint32m8_t, vuint32m8_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vasubu_vv_m)))
vuint32m8_t vasubu(vbool4_t, vuint32m8_t, vuint32m8_t, vuint32m8_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vasubu_vv)))
vuint32mf2_t vasubu(vuint32mf2_t, vuint32mf2_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vasubu_vv_m)))
vuint32mf2_t vasubu(vbool64_t, vuint32mf2_t, vuint32mf2_t, vuint32mf2_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vasubu_vx)))
vuint8m1_t vasubu(vuint8m1_t, uint8_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vasubu_vx_m)))
vuint8m1_t vasubu(vbool8_t, vuint8m1_t, vuint8m1_t, uint8_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vasubu_vx)))
vuint8m2_t vasubu(vuint8m2_t, uint8_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vasubu_vx_m)))
vuint8m2_t vasubu(vbool4_t, vuint8m2_t, vuint8m2_t, uint8_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vasubu_vx)))
vuint8m4_t vasubu(vuint8m4_t, uint8_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vasubu_vx_m)))
vuint8m4_t vasubu(vbool2_t, vuint8m4_t, vuint8m4_t, uint8_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vasubu_vx)))
vuint8m8_t vasubu(vuint8m8_t, uint8_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vasubu_vx_m)))
vuint8m8_t vasubu(vbool1_t, vuint8m8_t, vuint8m8_t, uint8_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vasubu_vx)))
vuint8mf2_t vasubu(vuint8mf2_t, uint8_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vasubu_vx_m)))
vuint8mf2_t vasubu(vbool16_t, vuint8mf2_t, vuint8mf2_t, uint8_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vasubu_vx)))
vuint8mf4_t vasubu(vuint8mf4_t, uint8_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vasubu_vx_m)))
vuint8mf4_t vasubu(vbool32_t, vuint8mf4_t, vuint8mf4_t, uint8_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vasubu_vx)))
vuint8mf8_t vasubu(vuint8mf8_t, uint8_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vasubu_vx_m)))
vuint8mf8_t vasubu(vbool64_t, vuint8mf8_t, vuint8mf8_t, uint8_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vasubu_vx)))
vuint16m1_t vasubu(vuint16m1_t, uint16_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vasubu_vx_m)))
vuint16m1_t vasubu(vbool16_t, vuint16m1_t, vuint16m1_t, uint16_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vasubu_vx)))
vuint16m2_t vasubu(vuint16m2_t, uint16_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vasubu_vx_m)))
vuint16m2_t vasubu(vbool8_t, vuint16m2_t, vuint16m2_t, uint16_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vasubu_vx)))
vuint16m4_t vasubu(vuint16m4_t, uint16_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vasubu_vx_m)))
vuint16m4_t vasubu(vbool4_t, vuint16m4_t, vuint16m4_t, uint16_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vasubu_vx)))
vuint16m8_t vasubu(vuint16m8_t, uint16_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vasubu_vx_m)))
vuint16m8_t vasubu(vbool2_t, vuint16m8_t, vuint16m8_t, uint16_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vasubu_vx)))
vuint16mf2_t vasubu(vuint16mf2_t, uint16_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vasubu_vx_m)))
vuint16mf2_t vasubu(vbool32_t, vuint16mf2_t, vuint16mf2_t, uint16_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vasubu_vx)))
vuint16mf4_t vasubu(vuint16mf4_t, uint16_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vasubu_vx_m)))
vuint16mf4_t vasubu(vbool64_t, vuint16mf4_t, vuint16mf4_t, uint16_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vasubu_vx)))
vuint32m1_t vasubu(vuint32m1_t, uint32_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vasubu_vx_m)))
vuint32m1_t vasubu(vbool32_t, vuint32m1_t, vuint32m1_t, uint32_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vasubu_vx)))
vuint32m2_t vasubu(vuint32m2_t, uint32_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vasubu_vx_m)))
vuint32m2_t vasubu(vbool16_t, vuint32m2_t, vuint32m2_t, uint32_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vasubu_vx)))
vuint32m4_t vasubu(vuint32m4_t, uint32_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vasubu_vx_m)))
vuint32m4_t vasubu(vbool8_t, vuint32m4_t, vuint32m4_t, uint32_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vasubu_vx)))
vuint32m8_t vasubu(vuint32m8_t, uint32_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vasubu_vx_m)))
vuint32m8_t vasubu(vbool4_t, vuint32m8_t, vuint32m8_t, uint32_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vasubu_vx)))
vuint32mf2_t vasubu(vuint32mf2_t, uint32_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vasubu_vx_m)))
vuint32mf2_t vasubu(vbool64_t, vuint32mf2_t, vuint32mf2_t, uint32_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vsuxei32_v)))
void vsuxei32(int16_t *, vuint32m2_t, vint16m1_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vsuxei32_v_m)))
void vsuxei32(vbool16_t, int16_t *, vuint32m2_t, vint16m1_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vsuxei32_v)))
void vsuxei32(int16_t *, vuint32m4_t, vint16m2_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vsuxei32_v_m)))
void vsuxei32(vbool8_t, int16_t *, vuint32m4_t, vint16m2_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vsuxei32_v)))
void vsuxei32(int16_t *, vuint32m8_t, vint16m4_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vsuxei32_v_m)))
void vsuxei32(vbool4_t, int16_t *, vuint32m8_t, vint16m4_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vsuxei32_v)))
void vsuxei32(int16_t *, vuint32m1_t, vint16mf2_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vsuxei32_v_m)))
void vsuxei32(vbool32_t, int16_t *, vuint32m1_t, vint16mf2_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vsuxei32_v)))
void vsuxei32(int16_t *, vuint32mf2_t, vint16mf4_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vsuxei32_v_m)))
void vsuxei32(vbool64_t, int16_t *, vuint32mf2_t, vint16mf4_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vasub_vv)))
vint8m1_t vasub(vint8m1_t, vint8m1_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vasub_vv_m)))
vint8m1_t vasub(vbool8_t, vint8m1_t, vint8m1_t, vint8m1_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vasub_vv)))
vint8m2_t vasub(vint8m2_t, vint8m2_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vasub_vv_m)))
vint8m2_t vasub(vbool4_t, vint8m2_t, vint8m2_t, vint8m2_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vasub_vv)))
vint8m4_t vasub(vint8m4_t, vint8m4_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vasub_vv_m)))
vint8m4_t vasub(vbool2_t, vint8m4_t, vint8m4_t, vint8m4_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vasub_vv)))
vint8m8_t vasub(vint8m8_t, vint8m8_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vasub_vv_m)))
vint8m8_t vasub(vbool1_t, vint8m8_t, vint8m8_t, vint8m8_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vasub_vv)))
vint8mf2_t vasub(vint8mf2_t, vint8mf2_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vasub_vv_m)))
vint8mf2_t vasub(vbool16_t, vint8mf2_t, vint8mf2_t, vint8mf2_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vasub_vv)))
vint8mf4_t vasub(vint8mf4_t, vint8mf4_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vasub_vv_m)))
vint8mf4_t vasub(vbool32_t, vint8mf4_t, vint8mf4_t, vint8mf4_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vasub_vv)))
vint8mf8_t vasub(vint8mf8_t, vint8mf8_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vasub_vv_m)))
vint8mf8_t vasub(vbool64_t, vint8mf8_t, vint8mf8_t, vint8mf8_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vasub_vv)))
vint16m1_t vasub(vint16m1_t, vint16m1_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vasub_vv_m)))
vint16m1_t vasub(vbool16_t, vint16m1_t, vint16m1_t, vint16m1_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vasub_vv)))
vint16m2_t vasub(vint16m2_t, vint16m2_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vasub_vv_m)))
vint16m2_t vasub(vbool8_t, vint16m2_t, vint16m2_t, vint16m2_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vasub_vv)))
vint16m4_t vasub(vint16m4_t, vint16m4_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vasub_vv_m)))
vint16m4_t vasub(vbool4_t, vint16m4_t, vint16m4_t, vint16m4_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vasub_vv)))
vint16m8_t vasub(vint16m8_t, vint16m8_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vasub_vv_m)))
vint16m8_t vasub(vbool2_t, vint16m8_t, vint16m8_t, vint16m8_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vasub_vv)))
vint16mf2_t vasub(vint16mf2_t, vint16mf2_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vasub_vv_m)))
vint16mf2_t vasub(vbool32_t, vint16mf2_t, vint16mf2_t, vint16mf2_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vasub_vv)))
vint16mf4_t vasub(vint16mf4_t, vint16mf4_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vasub_vv_m)))
vint16mf4_t vasub(vbool64_t, vint16mf4_t, vint16mf4_t, vint16mf4_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vasub_vv)))
vint32m1_t vasub(vint32m1_t, vint32m1_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vasub_vv_m)))
vint32m1_t vasub(vbool32_t, vint32m1_t, vint32m1_t, vint32m1_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vasub_vv)))
vint32m2_t vasub(vint32m2_t, vint32m2_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vasub_vv_m)))
vint32m2_t vasub(vbool16_t, vint32m2_t, vint32m2_t, vint32m2_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vasub_vv)))
vint32m4_t vasub(vint32m4_t, vint32m4_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vasub_vv_m)))
vint32m4_t vasub(vbool8_t, vint32m4_t, vint32m4_t, vint32m4_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vasub_vv)))
vint32m8_t vasub(vint32m8_t, vint32m8_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vasub_vv_m)))
vint32m8_t vasub(vbool4_t, vint32m8_t, vint32m8_t, vint32m8_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vasub_vv)))
vint32mf2_t vasub(vint32mf2_t, vint32mf2_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vasub_vv_m)))
vint32mf2_t vasub(vbool64_t, vint32mf2_t, vint32mf2_t, vint32mf2_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vasub_vx)))
vint8m1_t vasub(vint8m1_t, int8_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vasub_vx_m)))
vint8m1_t vasub(vbool8_t, vint8m1_t, vint8m1_t, int8_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vasub_vx)))
vint8m2_t vasub(vint8m2_t, int8_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vasub_vx_m)))
vint8m2_t vasub(vbool4_t, vint8m2_t, vint8m2_t, int8_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vasub_vx)))
vint8m4_t vasub(vint8m4_t, int8_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vasub_vx_m)))
vint8m4_t vasub(vbool2_t, vint8m4_t, vint8m4_t, int8_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vasub_vx)))
vint8m8_t vasub(vint8m8_t, int8_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vasub_vx_m)))
vint8m8_t vasub(vbool1_t, vint8m8_t, vint8m8_t, int8_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vasub_vx)))
vint8mf2_t vasub(vint8mf2_t, int8_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vasub_vx_m)))
vint8mf2_t vasub(vbool16_t, vint8mf2_t, vint8mf2_t, int8_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vasub_vx)))
vint8mf4_t vasub(vint8mf4_t, int8_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vasub_vx_m)))
vint8mf4_t vasub(vbool32_t, vint8mf4_t, vint8mf4_t, int8_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vasub_vx)))
vint8mf8_t vasub(vint8mf8_t, int8_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vasub_vx_m)))
vint8mf8_t vasub(vbool64_t, vint8mf8_t, vint8mf8_t, int8_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vasub_vx)))
vint16m1_t vasub(vint16m1_t, int16_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vasub_vx_m)))
vint16m1_t vasub(vbool16_t, vint16m1_t, vint16m1_t, int16_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vasub_vx)))
vint16m2_t vasub(vint16m2_t, int16_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vasub_vx_m)))
vint16m2_t vasub(vbool8_t, vint16m2_t, vint16m2_t, int16_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vasub_vx)))
vint16m4_t vasub(vint16m4_t, int16_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vasub_vx_m)))
vint16m4_t vasub(vbool4_t, vint16m4_t, vint16m4_t, int16_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vasub_vx)))
vint16m8_t vasub(vint16m8_t, int16_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vasub_vx_m)))
vint16m8_t vasub(vbool2_t, vint16m8_t, vint16m8_t, int16_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vasub_vx)))
vint16mf2_t vasub(vint16mf2_t, int16_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vasub_vx_m)))
vint16mf2_t vasub(vbool32_t, vint16mf2_t, vint16mf2_t, int16_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vasub_vx)))
vint16mf4_t vasub(vint16mf4_t, int16_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vasub_vx_m)))
vint16mf4_t vasub(vbool64_t, vint16mf4_t, vint16mf4_t, int16_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vasub_vx)))
vint32m1_t vasub(vint32m1_t, int32_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vasub_vx_m)))
vint32m1_t vasub(vbool32_t, vint32m1_t, vint32m1_t, int32_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vasub_vx)))
vint32m2_t vasub(vint32m2_t, int32_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vasub_vx_m)))
vint32m2_t vasub(vbool16_t, vint32m2_t, vint32m2_t, int32_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vasub_vx)))
vint32m4_t vasub(vint32m4_t, int32_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vasub_vx_m)))
vint32m4_t vasub(vbool8_t, vint32m4_t, vint32m4_t, int32_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vasub_vx)))
vint32m8_t vasub(vint32m8_t, int32_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vasub_vx_m)))
vint32m8_t vasub(vbool4_t, vint32m8_t, vint32m8_t, int32_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vasub_vx)))
vint32mf2_t vasub(vint32mf2_t, int32_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vasub_vx_m)))
vint32mf2_t vasub(vbool64_t, vint32mf2_t, vint32mf2_t, int32_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vsmul_vv)))
vint8m1_t vsmul(vint8m1_t, vint8m1_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vsmul_vv_m)))
vint8m1_t vsmul(vbool8_t, vint8m1_t, vint8m1_t, vint8m1_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vsmul_vv)))
vint8m2_t vsmul(vint8m2_t, vint8m2_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vsmul_vv_m)))
vint8m2_t vsmul(vbool4_t, vint8m2_t, vint8m2_t, vint8m2_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vsmul_vv)))
vint8m4_t vsmul(vint8m4_t, vint8m4_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vsmul_vv_m)))
vint8m4_t vsmul(vbool2_t, vint8m4_t, vint8m4_t, vint8m4_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vsmul_vv)))
vint8m8_t vsmul(vint8m8_t, vint8m8_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vsmul_vv_m)))
vint8m8_t vsmul(vbool1_t, vint8m8_t, vint8m8_t, vint8m8_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vsmul_vv)))
vint8mf2_t vsmul(vint8mf2_t, vint8mf2_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vsmul_vv_m)))
vint8mf2_t vsmul(vbool16_t, vint8mf2_t, vint8mf2_t, vint8mf2_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vsmul_vv)))
vint8mf4_t vsmul(vint8mf4_t, vint8mf4_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vsmul_vv_m)))
vint8mf4_t vsmul(vbool32_t, vint8mf4_t, vint8mf4_t, vint8mf4_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vsmul_vv)))
vint8mf8_t vsmul(vint8mf8_t, vint8mf8_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vsmul_vv_m)))
vint8mf8_t vsmul(vbool64_t, vint8mf8_t, vint8mf8_t, vint8mf8_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vsmul_vv)))
vint16m1_t vsmul(vint16m1_t, vint16m1_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vsmul_vv_m)))
vint16m1_t vsmul(vbool16_t, vint16m1_t, vint16m1_t, vint16m1_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vsmul_vv)))
vint16m2_t vsmul(vint16m2_t, vint16m2_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vsmul_vv_m)))
vint16m2_t vsmul(vbool8_t, vint16m2_t, vint16m2_t, vint16m2_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vsmul_vv)))
vint16m4_t vsmul(vint16m4_t, vint16m4_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vsmul_vv_m)))
vint16m4_t vsmul(vbool4_t, vint16m4_t, vint16m4_t, vint16m4_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vsmul_vv)))
vint16m8_t vsmul(vint16m8_t, vint16m8_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vsmul_vv_m)))
vint16m8_t vsmul(vbool2_t, vint16m8_t, vint16m8_t, vint16m8_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vsmul_vv)))
vint16mf2_t vsmul(vint16mf2_t, vint16mf2_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vsmul_vv_m)))
vint16mf2_t vsmul(vbool32_t, vint16mf2_t, vint16mf2_t, vint16mf2_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vsmul_vv)))
vint16mf4_t vsmul(vint16mf4_t, vint16mf4_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vsmul_vv_m)))
vint16mf4_t vsmul(vbool64_t, vint16mf4_t, vint16mf4_t, vint16mf4_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vsmul_vv)))
vint32m1_t vsmul(vint32m1_t, vint32m1_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vsmul_vv_m)))
vint32m1_t vsmul(vbool32_t, vint32m1_t, vint32m1_t, vint32m1_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vsmul_vv)))
vint32m2_t vsmul(vint32m2_t, vint32m2_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vsmul_vv_m)))
vint32m2_t vsmul(vbool16_t, vint32m2_t, vint32m2_t, vint32m2_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vsmul_vv)))
vint32m4_t vsmul(vint32m4_t, vint32m4_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vsmul_vv_m)))
vint32m4_t vsmul(vbool8_t, vint32m4_t, vint32m4_t, vint32m4_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vsmul_vv)))
vint32m8_t vsmul(vint32m8_t, vint32m8_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vsmul_vv_m)))
vint32m8_t vsmul(vbool4_t, vint32m8_t, vint32m8_t, vint32m8_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vsmul_vv)))
vint32mf2_t vsmul(vint32mf2_t, vint32mf2_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vsmul_vv_m)))
vint32mf2_t vsmul(vbool64_t, vint32mf2_t, vint32mf2_t, vint32mf2_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vsmul_vx)))
vint8m1_t vsmul(vint8m1_t, int8_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vsmul_vx_m)))
vint8m1_t vsmul(vbool8_t, vint8m1_t, vint8m1_t, int8_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vsmul_vx)))
vint8m2_t vsmul(vint8m2_t, int8_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vsmul_vx_m)))
vint8m2_t vsmul(vbool4_t, vint8m2_t, vint8m2_t, int8_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vsmul_vx)))
vint8m4_t vsmul(vint8m4_t, int8_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vsmul_vx_m)))
vint8m4_t vsmul(vbool2_t, vint8m4_t, vint8m4_t, int8_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vsmul_vx)))
vint8m8_t vsmul(vint8m8_t, int8_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vsmul_vx_m)))
vint8m8_t vsmul(vbool1_t, vint8m8_t, vint8m8_t, int8_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vsmul_vx)))
vint8mf2_t vsmul(vint8mf2_t, int8_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vsmul_vx_m)))
vint8mf2_t vsmul(vbool16_t, vint8mf2_t, vint8mf2_t, int8_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vsmul_vx)))
vint8mf4_t vsmul(vint8mf4_t, int8_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vsmul_vx_m)))
vint8mf4_t vsmul(vbool32_t, vint8mf4_t, vint8mf4_t, int8_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vsmul_vx)))
vint8mf8_t vsmul(vint8mf8_t, int8_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vsmul_vx_m)))
vint8mf8_t vsmul(vbool64_t, vint8mf8_t, vint8mf8_t, int8_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vsmul_vx)))
vint16m1_t vsmul(vint16m1_t, int16_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vsmul_vx_m)))
vint16m1_t vsmul(vbool16_t, vint16m1_t, vint16m1_t, int16_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vsmul_vx)))
vint16m2_t vsmul(vint16m2_t, int16_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vsmul_vx_m)))
vint16m2_t vsmul(vbool8_t, vint16m2_t, vint16m2_t, int16_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vsmul_vx)))
vint16m4_t vsmul(vint16m4_t, int16_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vsmul_vx_m)))
vint16m4_t vsmul(vbool4_t, vint16m4_t, vint16m4_t, int16_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vsmul_vx)))
vint16m8_t vsmul(vint16m8_t, int16_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vsmul_vx_m)))
vint16m8_t vsmul(vbool2_t, vint16m8_t, vint16m8_t, int16_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vsmul_vx)))
vint16mf2_t vsmul(vint16mf2_t, int16_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vsmul_vx_m)))
vint16mf2_t vsmul(vbool32_t, vint16mf2_t, vint16mf2_t, int16_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vsmul_vx)))
vint16mf4_t vsmul(vint16mf4_t, int16_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vsmul_vx_m)))
vint16mf4_t vsmul(vbool64_t, vint16mf4_t, vint16mf4_t, int16_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vsmul_vx)))
vint32m1_t vsmul(vint32m1_t, int32_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vsmul_vx_m)))
vint32m1_t vsmul(vbool32_t, vint32m1_t, vint32m1_t, int32_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vsmul_vx)))
vint32m2_t vsmul(vint32m2_t, int32_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vsmul_vx_m)))
vint32m2_t vsmul(vbool16_t, vint32m2_t, vint32m2_t, int32_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vsmul_vx)))
vint32m4_t vsmul(vint32m4_t, int32_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vsmul_vx_m)))
vint32m4_t vsmul(vbool8_t, vint32m4_t, vint32m4_t, int32_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vsmul_vx)))
vint32m8_t vsmul(vint32m8_t, int32_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vsmul_vx_m)))
vint32m8_t vsmul(vbool4_t, vint32m8_t, vint32m8_t, int32_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vsmul_vx)))
vint32mf2_t vsmul(vint32mf2_t, int32_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vsmul_vx_m)))
vint32mf2_t vsmul(vbool64_t, vint32mf2_t, vint32mf2_t, int32_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vssrl_vv)))
vuint8m1_t vssrl(vuint8m1_t, vuint8m1_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vssrl_vv_m)))
vuint8m1_t vssrl(vbool8_t, vuint8m1_t, vuint8m1_t, vuint8m1_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vssrl_vv)))
vuint8m2_t vssrl(vuint8m2_t, vuint8m2_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vssrl_vv_m)))
vuint8m2_t vssrl(vbool4_t, vuint8m2_t, vuint8m2_t, vuint8m2_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vssrl_vv)))
vuint8m4_t vssrl(vuint8m4_t, vuint8m4_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vssrl_vv_m)))
vuint8m4_t vssrl(vbool2_t, vuint8m4_t, vuint8m4_t, vuint8m4_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vssrl_vv)))
vuint8m8_t vssrl(vuint8m8_t, vuint8m8_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vssrl_vv_m)))
vuint8m8_t vssrl(vbool1_t, vuint8m8_t, vuint8m8_t, vuint8m8_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vssrl_vv)))
vuint8mf2_t vssrl(vuint8mf2_t, vuint8mf2_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vssrl_vv_m)))
vuint8mf2_t vssrl(vbool16_t, vuint8mf2_t, vuint8mf2_t, vuint8mf2_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vssrl_vv)))
vuint8mf4_t vssrl(vuint8mf4_t, vuint8mf4_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vssrl_vv_m)))
vuint8mf4_t vssrl(vbool32_t, vuint8mf4_t, vuint8mf4_t, vuint8mf4_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vssrl_vv)))
vuint8mf8_t vssrl(vuint8mf8_t, vuint8mf8_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vssrl_vv_m)))
vuint8mf8_t vssrl(vbool64_t, vuint8mf8_t, vuint8mf8_t, vuint8mf8_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vssrl_vv)))
vuint16m1_t vssrl(vuint16m1_t, vuint16m1_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vssrl_vv_m)))
vuint16m1_t vssrl(vbool16_t, vuint16m1_t, vuint16m1_t, vuint16m1_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vssrl_vv)))
vuint16m2_t vssrl(vuint16m2_t, vuint16m2_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vssrl_vv_m)))
vuint16m2_t vssrl(vbool8_t, vuint16m2_t, vuint16m2_t, vuint16m2_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vssrl_vv)))
vuint16m4_t vssrl(vuint16m4_t, vuint16m4_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vssrl_vv_m)))
vuint16m4_t vssrl(vbool4_t, vuint16m4_t, vuint16m4_t, vuint16m4_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vssrl_vv)))
vuint16m8_t vssrl(vuint16m8_t, vuint16m8_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vssrl_vv_m)))
vuint16m8_t vssrl(vbool2_t, vuint16m8_t, vuint16m8_t, vuint16m8_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vssrl_vv)))
vuint16mf2_t vssrl(vuint16mf2_t, vuint16mf2_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vssrl_vv_m)))
vuint16mf2_t vssrl(vbool32_t, vuint16mf2_t, vuint16mf2_t, vuint16mf2_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vssrl_vv)))
vuint16mf4_t vssrl(vuint16mf4_t, vuint16mf4_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vssrl_vv_m)))
vuint16mf4_t vssrl(vbool64_t, vuint16mf4_t, vuint16mf4_t, vuint16mf4_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vssrl_vv)))
vuint32m1_t vssrl(vuint32m1_t, vuint32m1_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vssrl_vv_m)))
vuint32m1_t vssrl(vbool32_t, vuint32m1_t, vuint32m1_t, vuint32m1_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vssrl_vv)))
vuint32m2_t vssrl(vuint32m2_t, vuint32m2_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vssrl_vv_m)))
vuint32m2_t vssrl(vbool16_t, vuint32m2_t, vuint32m2_t, vuint32m2_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vssrl_vv)))
vuint32m4_t vssrl(vuint32m4_t, vuint32m4_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vssrl_vv_m)))
vuint32m4_t vssrl(vbool8_t, vuint32m4_t, vuint32m4_t, vuint32m4_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vssrl_vv)))
vuint32m8_t vssrl(vuint32m8_t, vuint32m8_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vssrl_vv_m)))
vuint32m8_t vssrl(vbool4_t, vuint32m8_t, vuint32m8_t, vuint32m8_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vssrl_vv)))
vuint32mf2_t vssrl(vuint32mf2_t, vuint32mf2_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vssrl_vv_m)))
vuint32mf2_t vssrl(vbool64_t, vuint32mf2_t, vuint32mf2_t, vuint32mf2_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vssrl_vx)))
vuint8m1_t vssrl(vuint8m1_t, size_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vssrl_vx_m)))
vuint8m1_t vssrl(vbool8_t, vuint8m1_t, vuint8m1_t, size_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vssrl_vx)))
vuint8m2_t vssrl(vuint8m2_t, size_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vssrl_vx_m)))
vuint8m2_t vssrl(vbool4_t, vuint8m2_t, vuint8m2_t, size_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vssrl_vx)))
vuint8m4_t vssrl(vuint8m4_t, size_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vssrl_vx_m)))
vuint8m4_t vssrl(vbool2_t, vuint8m4_t, vuint8m4_t, size_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vssrl_vx)))
vuint8m8_t vssrl(vuint8m8_t, size_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vssrl_vx_m)))
vuint8m8_t vssrl(vbool1_t, vuint8m8_t, vuint8m8_t, size_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vssrl_vx)))
vuint8mf2_t vssrl(vuint8mf2_t, size_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vssrl_vx_m)))
vuint8mf2_t vssrl(vbool16_t, vuint8mf2_t, vuint8mf2_t, size_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vssrl_vx)))
vuint8mf4_t vssrl(vuint8mf4_t, size_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vssrl_vx_m)))
vuint8mf4_t vssrl(vbool32_t, vuint8mf4_t, vuint8mf4_t, size_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vssrl_vx)))
vuint8mf8_t vssrl(vuint8mf8_t, size_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vssrl_vx_m)))
vuint8mf8_t vssrl(vbool64_t, vuint8mf8_t, vuint8mf8_t, size_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vssrl_vx)))
vuint16m1_t vssrl(vuint16m1_t, size_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vssrl_vx_m)))
vuint16m1_t vssrl(vbool16_t, vuint16m1_t, vuint16m1_t, size_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vssrl_vx)))
vuint16m2_t vssrl(vuint16m2_t, size_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vssrl_vx_m)))
vuint16m2_t vssrl(vbool8_t, vuint16m2_t, vuint16m2_t, size_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vssrl_vx)))
vuint16m4_t vssrl(vuint16m4_t, size_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vssrl_vx_m)))
vuint16m4_t vssrl(vbool4_t, vuint16m4_t, vuint16m4_t, size_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vssrl_vx)))
vuint16m8_t vssrl(vuint16m8_t, size_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vssrl_vx_m)))
vuint16m8_t vssrl(vbool2_t, vuint16m8_t, vuint16m8_t, size_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vssrl_vx)))
vuint16mf2_t vssrl(vuint16mf2_t, size_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vssrl_vx_m)))
vuint16mf2_t vssrl(vbool32_t, vuint16mf2_t, vuint16mf2_t, size_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vssrl_vx)))
vuint16mf4_t vssrl(vuint16mf4_t, size_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vssrl_vx_m)))
vuint16mf4_t vssrl(vbool64_t, vuint16mf4_t, vuint16mf4_t, size_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vssrl_vx)))
vuint32m1_t vssrl(vuint32m1_t, size_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vssrl_vx_m)))
vuint32m1_t vssrl(vbool32_t, vuint32m1_t, vuint32m1_t, size_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vssrl_vx)))
vuint32m2_t vssrl(vuint32m2_t, size_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vssrl_vx_m)))
vuint32m2_t vssrl(vbool16_t, vuint32m2_t, vuint32m2_t, size_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vssrl_vx)))
vuint32m4_t vssrl(vuint32m4_t, size_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vssrl_vx_m)))
vuint32m4_t vssrl(vbool8_t, vuint32m4_t, vuint32m4_t, size_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vssrl_vx)))
vuint32m8_t vssrl(vuint32m8_t, size_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vssrl_vx_m)))
vuint32m8_t vssrl(vbool4_t, vuint32m8_t, vuint32m8_t, size_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vssrl_vx)))
vuint32mf2_t vssrl(vuint32mf2_t, size_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vssrl_vx_m)))
vuint32mf2_t vssrl(vbool64_t, vuint32mf2_t, vuint32mf2_t, size_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vssra_vv)))
vint8m1_t vssra(vint8m1_t, vuint8m1_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vssra_vv_m)))
vint8m1_t vssra(vbool8_t, vint8m1_t, vint8m1_t, vuint8m1_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vssra_vv)))
vint8m2_t vssra(vint8m2_t, vuint8m2_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vssra_vv_m)))
vint8m2_t vssra(vbool4_t, vint8m2_t, vint8m2_t, vuint8m2_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vssra_vv)))
vint8m4_t vssra(vint8m4_t, vuint8m4_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vssra_vv_m)))
vint8m4_t vssra(vbool2_t, vint8m4_t, vint8m4_t, vuint8m4_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vssra_vv)))
vint8m8_t vssra(vint8m8_t, vuint8m8_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vssra_vv_m)))
vint8m8_t vssra(vbool1_t, vint8m8_t, vint8m8_t, vuint8m8_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vssra_vv)))
vint8mf2_t vssra(vint8mf2_t, vuint8mf2_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vssra_vv_m)))
vint8mf2_t vssra(vbool16_t, vint8mf2_t, vint8mf2_t, vuint8mf2_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vssra_vv)))
vint8mf4_t vssra(vint8mf4_t, vuint8mf4_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vssra_vv_m)))
vint8mf4_t vssra(vbool32_t, vint8mf4_t, vint8mf4_t, vuint8mf4_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vssra_vv)))
vint8mf8_t vssra(vint8mf8_t, vuint8mf8_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vssra_vv_m)))
vint8mf8_t vssra(vbool64_t, vint8mf8_t, vint8mf8_t, vuint8mf8_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vssra_vv)))
vint16m1_t vssra(vint16m1_t, vuint16m1_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vssra_vv_m)))
vint16m1_t vssra(vbool16_t, vint16m1_t, vint16m1_t, vuint16m1_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vssra_vv)))
vint16m2_t vssra(vint16m2_t, vuint16m2_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vssra_vv_m)))
vint16m2_t vssra(vbool8_t, vint16m2_t, vint16m2_t, vuint16m2_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vssra_vv)))
vint16m4_t vssra(vint16m4_t, vuint16m4_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vssra_vv_m)))
vint16m4_t vssra(vbool4_t, vint16m4_t, vint16m4_t, vuint16m4_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vssra_vv)))
vint16m8_t vssra(vint16m8_t, vuint16m8_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vssra_vv_m)))
vint16m8_t vssra(vbool2_t, vint16m8_t, vint16m8_t, vuint16m8_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vssra_vv)))
vint16mf2_t vssra(vint16mf2_t, vuint16mf2_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vssra_vv_m)))
vint16mf2_t vssra(vbool32_t, vint16mf2_t, vint16mf2_t, vuint16mf2_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vssra_vv)))
vint16mf4_t vssra(vint16mf4_t, vuint16mf4_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vssra_vv_m)))
vint16mf4_t vssra(vbool64_t, vint16mf4_t, vint16mf4_t, vuint16mf4_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vssra_vv)))
vint32m1_t vssra(vint32m1_t, vuint32m1_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vssra_vv_m)))
vint32m1_t vssra(vbool32_t, vint32m1_t, vint32m1_t, vuint32m1_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vssra_vv)))
vint32m2_t vssra(vint32m2_t, vuint32m2_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vssra_vv_m)))
vint32m2_t vssra(vbool16_t, vint32m2_t, vint32m2_t, vuint32m2_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vssra_vv)))
vint32m4_t vssra(vint32m4_t, vuint32m4_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vssra_vv_m)))
vint32m4_t vssra(vbool8_t, vint32m4_t, vint32m4_t, vuint32m4_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vssra_vv)))
vint32m8_t vssra(vint32m8_t, vuint32m8_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vssra_vv_m)))
vint32m8_t vssra(vbool4_t, vint32m8_t, vint32m8_t, vuint32m8_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vssra_vv)))
vint32mf2_t vssra(vint32mf2_t, vuint32mf2_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vssra_vv_m)))
vint32mf2_t vssra(vbool64_t, vint32mf2_t, vint32mf2_t, vuint32mf2_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vssra_vx)))
vint8m1_t vssra(vint8m1_t, size_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vssra_vx_m)))
vint8m1_t vssra(vbool8_t, vint8m1_t, vint8m1_t, size_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vssra_vx)))
vint8m2_t vssra(vint8m2_t, size_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vssra_vx_m)))
vint8m2_t vssra(vbool4_t, vint8m2_t, vint8m2_t, size_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vssra_vx)))
vint8m4_t vssra(vint8m4_t, size_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vssra_vx_m)))
vint8m4_t vssra(vbool2_t, vint8m4_t, vint8m4_t, size_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vssra_vx)))
vint8m8_t vssra(vint8m8_t, size_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vssra_vx_m)))
vint8m8_t vssra(vbool1_t, vint8m8_t, vint8m8_t, size_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vssra_vx)))
vint8mf2_t vssra(vint8mf2_t, size_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vssra_vx_m)))
vint8mf2_t vssra(vbool16_t, vint8mf2_t, vint8mf2_t, size_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vssra_vx)))
vint8mf4_t vssra(vint8mf4_t, size_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vssra_vx_m)))
vint8mf4_t vssra(vbool32_t, vint8mf4_t, vint8mf4_t, size_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vssra_vx)))
vint8mf8_t vssra(vint8mf8_t, size_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vssra_vx_m)))
vint8mf8_t vssra(vbool64_t, vint8mf8_t, vint8mf8_t, size_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vssra_vx)))
vint16m1_t vssra(vint16m1_t, size_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vssra_vx_m)))
vint16m1_t vssra(vbool16_t, vint16m1_t, vint16m1_t, size_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vssra_vx)))
vint16m2_t vssra(vint16m2_t, size_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vssra_vx_m)))
vint16m2_t vssra(vbool8_t, vint16m2_t, vint16m2_t, size_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vssra_vx)))
vint16m4_t vssra(vint16m4_t, size_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vssra_vx_m)))
vint16m4_t vssra(vbool4_t, vint16m4_t, vint16m4_t, size_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vssra_vx)))
vint16m8_t vssra(vint16m8_t, size_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vssra_vx_m)))
vint16m8_t vssra(vbool2_t, vint16m8_t, vint16m8_t, size_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vssra_vx)))
vint16mf2_t vssra(vint16mf2_t, size_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vssra_vx_m)))
vint16mf2_t vssra(vbool32_t, vint16mf2_t, vint16mf2_t, size_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vssra_vx)))
vint16mf4_t vssra(vint16mf4_t, size_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vssra_vx_m)))
vint16mf4_t vssra(vbool64_t, vint16mf4_t, vint16mf4_t, size_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vssra_vx)))
vint32m1_t vssra(vint32m1_t, size_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vssra_vx_m)))
vint32m1_t vssra(vbool32_t, vint32m1_t, vint32m1_t, size_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vssra_vx)))
vint32m2_t vssra(vint32m2_t, size_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vssra_vx_m)))
vint32m2_t vssra(vbool16_t, vint32m2_t, vint32m2_t, size_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vssra_vx)))
vint32m4_t vssra(vint32m4_t, size_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vssra_vx_m)))
vint32m4_t vssra(vbool8_t, vint32m4_t, vint32m4_t, size_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vssra_vx)))
vint32m8_t vssra(vint32m8_t, size_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vssra_vx_m)))
vint32m8_t vssra(vbool4_t, vint32m8_t, vint32m8_t, size_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vssra_vx)))
vint32mf2_t vssra(vint32mf2_t, size_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vssra_vx_m)))
vint32mf2_t vssra(vbool64_t, vint32mf2_t, vint32mf2_t, size_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vnclipu_wv)))
vuint8m1_t vnclipu(vuint16m2_t, vuint8m1_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vnclipu_wv_m)))
vuint8m1_t vnclipu(vbool8_t, vuint8m1_t, vuint16m2_t, vuint8m1_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vnclipu_wv)))
vuint8m2_t vnclipu(vuint16m4_t, vuint8m2_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vnclipu_wv_m)))
vuint8m2_t vnclipu(vbool4_t, vuint8m2_t, vuint16m4_t, vuint8m2_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vnclipu_wv)))
vuint8m4_t vnclipu(vuint16m8_t, vuint8m4_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vnclipu_wv_m)))
vuint8m4_t vnclipu(vbool2_t, vuint8m4_t, vuint16m8_t, vuint8m4_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vnclipu_wv)))
vuint8mf2_t vnclipu(vuint16m1_t, vuint8mf2_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vnclipu_wv_m)))
vuint8mf2_t vnclipu(vbool16_t, vuint8mf2_t, vuint16m1_t, vuint8mf2_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vnclipu_wv)))
vuint8mf4_t vnclipu(vuint16mf2_t, vuint8mf4_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vnclipu_wv_m)))
vuint8mf4_t vnclipu(vbool32_t, vuint8mf4_t, vuint16mf2_t, vuint8mf4_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vnclipu_wv)))
vuint8mf8_t vnclipu(vuint16mf4_t, vuint8mf8_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vnclipu_wv_m)))
vuint8mf8_t vnclipu(vbool64_t, vuint8mf8_t, vuint16mf4_t, vuint8mf8_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vnclipu_wv)))
vuint16m1_t vnclipu(vuint32m2_t, vuint16m1_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vnclipu_wv_m)))
vuint16m1_t vnclipu(vbool16_t, vuint16m1_t, vuint32m2_t, vuint16m1_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vnclipu_wv)))
vuint16m2_t vnclipu(vuint32m4_t, vuint16m2_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vnclipu_wv_m)))
vuint16m2_t vnclipu(vbool8_t, vuint16m2_t, vuint32m4_t, vuint16m2_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vnclipu_wv)))
vuint16m4_t vnclipu(vuint32m8_t, vuint16m4_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vnclipu_wv_m)))
vuint16m4_t vnclipu(vbool4_t, vuint16m4_t, vuint32m8_t, vuint16m4_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vnclipu_wv)))
vuint16mf2_t vnclipu(vuint32m1_t, vuint16mf2_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vnclipu_wv_m)))
vuint16mf2_t vnclipu(vbool32_t, vuint16mf2_t, vuint32m1_t, vuint16mf2_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vnclipu_wv)))
vuint16mf4_t vnclipu(vuint32mf2_t, vuint16mf4_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vnclipu_wv_m)))
vuint16mf4_t vnclipu(vbool64_t, vuint16mf4_t, vuint32mf2_t, vuint16mf4_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vnclipu_wx)))
vuint8m1_t vnclipu(vuint16m2_t, size_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vnclipu_wx_m)))
vuint8m1_t vnclipu(vbool8_t, vuint8m1_t, vuint16m2_t, size_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vnclipu_wx)))
vuint8m2_t vnclipu(vuint16m4_t, size_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vnclipu_wx_m)))
vuint8m2_t vnclipu(vbool4_t, vuint8m2_t, vuint16m4_t, size_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vnclipu_wx)))
vuint8m4_t vnclipu(vuint16m8_t, size_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vnclipu_wx_m)))
vuint8m4_t vnclipu(vbool2_t, vuint8m4_t, vuint16m8_t, size_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vnclipu_wx)))
vuint8mf2_t vnclipu(vuint16m1_t, size_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vnclipu_wx_m)))
vuint8mf2_t vnclipu(vbool16_t, vuint8mf2_t, vuint16m1_t, size_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vnclipu_wx)))
vuint8mf4_t vnclipu(vuint16mf2_t, size_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vnclipu_wx_m)))
vuint8mf4_t vnclipu(vbool32_t, vuint8mf4_t, vuint16mf2_t, size_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vnclipu_wx)))
vuint8mf8_t vnclipu(vuint16mf4_t, size_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vnclipu_wx_m)))
vuint8mf8_t vnclipu(vbool64_t, vuint8mf8_t, vuint16mf4_t, size_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vnclipu_wx)))
vuint16m1_t vnclipu(vuint32m2_t, size_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vnclipu_wx_m)))
vuint16m1_t vnclipu(vbool16_t, vuint16m1_t, vuint32m2_t, size_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vnclipu_wx)))
vuint16m2_t vnclipu(vuint32m4_t, size_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vnclipu_wx_m)))
vuint16m2_t vnclipu(vbool8_t, vuint16m2_t, vuint32m4_t, size_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vnclipu_wx)))
vuint16m4_t vnclipu(vuint32m8_t, size_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vnclipu_wx_m)))
vuint16m4_t vnclipu(vbool4_t, vuint16m4_t, vuint32m8_t, size_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vnclipu_wx)))
vuint16mf2_t vnclipu(vuint32m1_t, size_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vnclipu_wx_m)))
vuint16mf2_t vnclipu(vbool32_t, vuint16mf2_t, vuint32m1_t, size_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vnclipu_wx)))
vuint16mf4_t vnclipu(vuint32mf2_t, size_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vnclipu_wx_m)))
vuint16mf4_t vnclipu(vbool64_t, vuint16mf4_t, vuint32mf2_t, size_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vsuxei32_v)))
void vsuxei32(uint16_t *, vuint32m2_t, vuint16m1_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vsuxei32_v_m)))
void vsuxei32(vbool16_t, uint16_t *, vuint32m2_t, vuint16m1_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vsuxei32_v)))
void vsuxei32(uint16_t *, vuint32m4_t, vuint16m2_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vsuxei32_v_m)))
void vsuxei32(vbool8_t, uint16_t *, vuint32m4_t, vuint16m2_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vsuxei32_v)))
void vsuxei32(uint16_t *, vuint32m8_t, vuint16m4_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vsuxei32_v_m)))
void vsuxei32(vbool4_t, uint16_t *, vuint32m8_t, vuint16m4_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vsuxei32_v)))
void vsuxei32(uint16_t *, vuint32m1_t, vuint16mf2_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vsuxei32_v_m)))
void vsuxei32(vbool32_t, uint16_t *, vuint32m1_t, vuint16mf2_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vsuxei32_v)))
void vsuxei32(uint16_t *, vuint32mf2_t, vuint16mf4_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vsuxei32_v_m)))
void vsuxei32(vbool64_t, uint16_t *, vuint32mf2_t, vuint16mf4_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vnclip_wv)))
vint8m1_t vnclip(vint16m2_t, vuint8m1_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vnclip_wv_m)))
vint8m1_t vnclip(vbool8_t, vint8m1_t, vint16m2_t, vuint8m1_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vnclip_wv)))
vint8m2_t vnclip(vint16m4_t, vuint8m2_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vnclip_wv_m)))
vint8m2_t vnclip(vbool4_t, vint8m2_t, vint16m4_t, vuint8m2_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vnclip_wv)))
vint8m4_t vnclip(vint16m8_t, vuint8m4_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vnclip_wv_m)))
vint8m4_t vnclip(vbool2_t, vint8m4_t, vint16m8_t, vuint8m4_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vnclip_wv)))
vint8mf2_t vnclip(vint16m1_t, vuint8mf2_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vnclip_wv_m)))
vint8mf2_t vnclip(vbool16_t, vint8mf2_t, vint16m1_t, vuint8mf2_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vnclip_wv)))
vint8mf4_t vnclip(vint16mf2_t, vuint8mf4_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vnclip_wv_m)))
vint8mf4_t vnclip(vbool32_t, vint8mf4_t, vint16mf2_t, vuint8mf4_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vnclip_wv)))
vint8mf8_t vnclip(vint16mf4_t, vuint8mf8_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vnclip_wv_m)))
vint8mf8_t vnclip(vbool64_t, vint8mf8_t, vint16mf4_t, vuint8mf8_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vnclip_wv)))
vint16m1_t vnclip(vint32m2_t, vuint16m1_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vnclip_wv_m)))
vint16m1_t vnclip(vbool16_t, vint16m1_t, vint32m2_t, vuint16m1_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vnclip_wv)))
vint16m2_t vnclip(vint32m4_t, vuint16m2_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vnclip_wv_m)))
vint16m2_t vnclip(vbool8_t, vint16m2_t, vint32m4_t, vuint16m2_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vnclip_wv)))
vint16m4_t vnclip(vint32m8_t, vuint16m4_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vnclip_wv_m)))
vint16m4_t vnclip(vbool4_t, vint16m4_t, vint32m8_t, vuint16m4_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vnclip_wv)))
vint16mf2_t vnclip(vint32m1_t, vuint16mf2_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vnclip_wv_m)))
vint16mf2_t vnclip(vbool32_t, vint16mf2_t, vint32m1_t, vuint16mf2_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vnclip_wv)))
vint16mf4_t vnclip(vint32mf2_t, vuint16mf4_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vnclip_wv_m)))
vint16mf4_t vnclip(vbool64_t, vint16mf4_t, vint32mf2_t, vuint16mf4_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vnclip_wx)))
vint8m1_t vnclip(vint16m2_t, size_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vnclip_wx_m)))
vint8m1_t vnclip(vbool8_t, vint8m1_t, vint16m2_t, size_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vnclip_wx)))
vint8m2_t vnclip(vint16m4_t, size_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vnclip_wx_m)))
vint8m2_t vnclip(vbool4_t, vint8m2_t, vint16m4_t, size_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vnclip_wx)))
vint8m4_t vnclip(vint16m8_t, size_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vnclip_wx_m)))
vint8m4_t vnclip(vbool2_t, vint8m4_t, vint16m8_t, size_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vnclip_wx)))
vint8mf2_t vnclip(vint16m1_t, size_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vnclip_wx_m)))
vint8mf2_t vnclip(vbool16_t, vint8mf2_t, vint16m1_t, size_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vnclip_wx)))
vint8mf4_t vnclip(vint16mf2_t, size_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vnclip_wx_m)))
vint8mf4_t vnclip(vbool32_t, vint8mf4_t, vint16mf2_t, size_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vnclip_wx)))
vint8mf8_t vnclip(vint16mf4_t, size_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vnclip_wx_m)))
vint8mf8_t vnclip(vbool64_t, vint8mf8_t, vint16mf4_t, size_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vnclip_wx)))
vint16m1_t vnclip(vint32m2_t, size_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vnclip_wx_m)))
vint16m1_t vnclip(vbool16_t, vint16m1_t, vint32m2_t, size_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vnclip_wx)))
vint16m2_t vnclip(vint32m4_t, size_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vnclip_wx_m)))
vint16m2_t vnclip(vbool8_t, vint16m2_t, vint32m4_t, size_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vnclip_wx)))
vint16m4_t vnclip(vint32m8_t, size_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vnclip_wx_m)))
vint16m4_t vnclip(vbool4_t, vint16m4_t, vint32m8_t, size_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vnclip_wx)))
vint16mf2_t vnclip(vint32m1_t, size_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vnclip_wx_m)))
vint16mf2_t vnclip(vbool32_t, vint16mf2_t, vint32m1_t, size_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vnclip_wx)))
vint16mf4_t vnclip(vint32mf2_t, size_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vnclip_wx_m)))
vint16mf4_t vnclip(vbool64_t, vint16mf4_t, vint32mf2_t, size_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vse8_v)))
void vse8(uint8_t *, vuint8m1_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vse8_v_m)))
void vse8(vbool8_t, uint8_t *, vuint8m1_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vse8_v)))
void vse8(uint8_t *, vuint8m2_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vse8_v_m)))
void vse8(vbool4_t, uint8_t *, vuint8m2_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vse8_v)))
void vse8(uint8_t *, vuint8m4_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vse8_v_m)))
void vse8(vbool2_t, uint8_t *, vuint8m4_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vse8_v)))
void vse8(uint8_t *, vuint8m8_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vse8_v_m)))
void vse8(vbool1_t, uint8_t *, vuint8m8_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vse8_v)))
void vse8(uint8_t *, vuint8mf2_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vse8_v_m)))
void vse8(vbool16_t, uint8_t *, vuint8mf2_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vse8_v)))
void vse8(uint8_t *, vuint8mf4_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vse8_v_m)))
void vse8(vbool32_t, uint8_t *, vuint8mf4_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vse8_v)))
void vse8(uint8_t *, vuint8mf8_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vse8_v_m)))
void vse8(vbool64_t, uint8_t *, vuint8mf8_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vsuxei8_v)))
void vsuxei8(int32_t *, vuint8mf4_t, vint32m1_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vsuxei8_v_m)))
void vsuxei8(vbool32_t, int32_t *, vuint8mf4_t, vint32m1_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vsuxei8_v)))
void vsuxei8(int32_t *, vuint8mf2_t, vint32m2_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vsuxei8_v_m)))
void vsuxei8(vbool16_t, int32_t *, vuint8mf2_t, vint32m2_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vsuxei8_v)))
void vsuxei8(int32_t *, vuint8m1_t, vint32m4_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vsuxei8_v_m)))
void vsuxei8(vbool8_t, int32_t *, vuint8m1_t, vint32m4_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vsuxei8_v)))
void vsuxei8(int32_t *, vuint8m2_t, vint32m8_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vsuxei8_v_m)))
void vsuxei8(vbool4_t, int32_t *, vuint8m2_t, vint32m8_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vsuxei8_v)))
void vsuxei8(int32_t *, vuint8mf8_t, vint32mf2_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vsuxei8_v_m)))
void vsuxei8(vbool64_t, int32_t *, vuint8mf8_t, vint32mf2_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vsuxei8_v)))
void vsuxei8(uint32_t *, vuint8mf4_t, vuint32m1_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vsuxei8_v_m)))
void vsuxei8(vbool32_t, uint32_t *, vuint8mf4_t, vuint32m1_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vsuxei8_v)))
void vsuxei8(uint32_t *, vuint8mf2_t, vuint32m2_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vsuxei8_v_m)))
void vsuxei8(vbool16_t, uint32_t *, vuint8mf2_t, vuint32m2_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vsuxei8_v)))
void vsuxei8(uint32_t *, vuint8m1_t, vuint32m4_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vsuxei8_v_m)))
void vsuxei8(vbool8_t, uint32_t *, vuint8m1_t, vuint32m4_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vsuxei8_v)))
void vsuxei8(uint32_t *, vuint8m2_t, vuint32m8_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vsuxei8_v_m)))
void vsuxei8(vbool4_t, uint32_t *, vuint8m2_t, vuint32m8_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vsuxei8_v)))
void vsuxei8(uint32_t *, vuint8mf8_t, vuint32mf2_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vsuxei8_v_m)))
void vsuxei8(vbool64_t, uint32_t *, vuint8mf8_t, vuint32mf2_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vsuxei16_v)))
void vsuxei16(int32_t *, vuint16mf2_t, vint32m1_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vsuxei16_v_m)))
void vsuxei16(vbool32_t, int32_t *, vuint16mf2_t, vint32m1_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vsuxei16_v)))
void vsuxei16(int32_t *, vuint16m1_t, vint32m2_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vsuxei16_v_m)))
void vsuxei16(vbool16_t, int32_t *, vuint16m1_t, vint32m2_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vsuxei16_v)))
void vsuxei16(int32_t *, vuint16m2_t, vint32m4_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vsuxei16_v_m)))
void vsuxei16(vbool8_t, int32_t *, vuint16m2_t, vint32m4_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vsuxei16_v)))
void vsuxei16(int32_t *, vuint16m4_t, vint32m8_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vsuxei16_v_m)))
void vsuxei16(vbool4_t, int32_t *, vuint16m4_t, vint32m8_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vsuxei16_v)))
void vsuxei16(int32_t *, vuint16mf4_t, vint32mf2_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vsuxei16_v_m)))
void vsuxei16(vbool64_t, int32_t *, vuint16mf4_t, vint32mf2_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vsuxei16_v)))
void vsuxei16(uint32_t *, vuint16mf2_t, vuint32m1_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vsuxei16_v_m)))
void vsuxei16(vbool32_t, uint32_t *, vuint16mf2_t, vuint32m1_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vsuxei16_v)))
void vsuxei16(uint32_t *, vuint16m1_t, vuint32m2_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vsuxei16_v_m)))
void vsuxei16(vbool16_t, uint32_t *, vuint16m1_t, vuint32m2_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vsuxei16_v)))
void vsuxei16(uint32_t *, vuint16m2_t, vuint32m4_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vsuxei16_v_m)))
void vsuxei16(vbool8_t, uint32_t *, vuint16m2_t, vuint32m4_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vsuxei16_v)))
void vsuxei16(uint32_t *, vuint16m4_t, vuint32m8_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vsuxei16_v_m)))
void vsuxei16(vbool4_t, uint32_t *, vuint16m4_t, vuint32m8_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vsuxei16_v)))
void vsuxei16(uint32_t *, vuint16mf4_t, vuint32mf2_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vsuxei16_v_m)))
void vsuxei16(vbool64_t, uint32_t *, vuint16mf4_t, vuint32mf2_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vsuxei32_v)))
void vsuxei32(int32_t *, vuint32m1_t, vint32m1_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vsuxei32_v_m)))
void vsuxei32(vbool32_t, int32_t *, vuint32m1_t, vint32m1_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vsuxei32_v)))
void vsuxei32(int32_t *, vuint32m2_t, vint32m2_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vsuxei32_v_m)))
void vsuxei32(vbool16_t, int32_t *, vuint32m2_t, vint32m2_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vsuxei32_v)))
void vsuxei32(int32_t *, vuint32m4_t, vint32m4_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vsuxei32_v_m)))
void vsuxei32(vbool8_t, int32_t *, vuint32m4_t, vint32m4_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vsuxei32_v)))
void vsuxei32(int32_t *, vuint32m8_t, vint32m8_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vsuxei32_v_m)))
void vsuxei32(vbool4_t, int32_t *, vuint32m8_t, vint32m8_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vsuxei32_v)))
void vsuxei32(int32_t *, vuint32mf2_t, vint32mf2_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vsuxei32_v_m)))
void vsuxei32(vbool64_t, int32_t *, vuint32mf2_t, vint32mf2_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vredsum_vs)))
vint8m1_t vredsum(vint8m1_t, vint8m1_t, vint8m1_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vredsum_vs_m)))
vint8m1_t vredsum(vbool8_t, vint8m1_t, vint8m1_t, vint8m1_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vredsum_vs)))
vint8m1_t vredsum(vint8m1_t, vint8m2_t, vint8m1_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vredsum_vs_m)))
vint8m1_t vredsum(vbool4_t, vint8m1_t, vint8m2_t, vint8m1_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vredsum_vs)))
vint8m1_t vredsum(vint8m1_t, vint8m4_t, vint8m1_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vredsum_vs_m)))
vint8m1_t vredsum(vbool2_t, vint8m1_t, vint8m4_t, vint8m1_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vredsum_vs)))
vint8m1_t vredsum(vint8m1_t, vint8m8_t, vint8m1_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vredsum_vs_m)))
vint8m1_t vredsum(vbool1_t, vint8m1_t, vint8m8_t, vint8m1_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vredsum_vs)))
vint8m1_t vredsum(vint8m1_t, vint8mf2_t, vint8m1_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vredsum_vs_m)))
vint8m1_t vredsum(vbool16_t, vint8m1_t, vint8mf2_t, vint8m1_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vredsum_vs)))
vint8m1_t vredsum(vint8m1_t, vint8mf4_t, vint8m1_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vredsum_vs_m)))
vint8m1_t vredsum(vbool32_t, vint8m1_t, vint8mf4_t, vint8m1_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vredsum_vs)))
vint8m1_t vredsum(vint8m1_t, vint8mf8_t, vint8m1_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vredsum_vs_m)))
vint8m1_t vredsum(vbool64_t, vint8m1_t, vint8mf8_t, vint8m1_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vredsum_vs)))
vint16m1_t vredsum(vint16m1_t, vint16m1_t, vint16m1_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vredsum_vs_m)))
vint16m1_t vredsum(vbool16_t, vint16m1_t, vint16m1_t, vint16m1_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vredsum_vs)))
vint16m1_t vredsum(vint16m1_t, vint16m2_t, vint16m1_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vredsum_vs_m)))
vint16m1_t vredsum(vbool8_t, vint16m1_t, vint16m2_t, vint16m1_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vredsum_vs)))
vint16m1_t vredsum(vint16m1_t, vint16m4_t, vint16m1_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vredsum_vs_m)))
vint16m1_t vredsum(vbool4_t, vint16m1_t, vint16m4_t, vint16m1_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vredsum_vs)))
vint16m1_t vredsum(vint16m1_t, vint16m8_t, vint16m1_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vredsum_vs_m)))
vint16m1_t vredsum(vbool2_t, vint16m1_t, vint16m8_t, vint16m1_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vredsum_vs)))
vint16m1_t vredsum(vint16m1_t, vint16mf2_t, vint16m1_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vredsum_vs_m)))
vint16m1_t vredsum(vbool32_t, vint16m1_t, vint16mf2_t, vint16m1_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vredsum_vs)))
vint16m1_t vredsum(vint16m1_t, vint16mf4_t, vint16m1_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vredsum_vs_m)))
vint16m1_t vredsum(vbool64_t, vint16m1_t, vint16mf4_t, vint16m1_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vredsum_vs)))
vint32m1_t vredsum(vint32m1_t, vint32m1_t, vint32m1_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vredsum_vs_m)))
vint32m1_t vredsum(vbool32_t, vint32m1_t, vint32m1_t, vint32m1_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vredsum_vs)))
vint32m1_t vredsum(vint32m1_t, vint32m2_t, vint32m1_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vredsum_vs_m)))
vint32m1_t vredsum(vbool16_t, vint32m1_t, vint32m2_t, vint32m1_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vredsum_vs)))
vint32m1_t vredsum(vint32m1_t, vint32m4_t, vint32m1_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vredsum_vs_m)))
vint32m1_t vredsum(vbool8_t, vint32m1_t, vint32m4_t, vint32m1_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vredsum_vs)))
vint32m1_t vredsum(vint32m1_t, vint32m8_t, vint32m1_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vredsum_vs_m)))
vint32m1_t vredsum(vbool4_t, vint32m1_t, vint32m8_t, vint32m1_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vredsum_vs)))
vint32m1_t vredsum(vint32m1_t, vint32mf2_t, vint32m1_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vredsum_vs_m)))
vint32m1_t vredsum(vbool64_t, vint32m1_t, vint32mf2_t, vint32m1_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vredsum_vs)))
vuint8m1_t vredsum(vuint8m1_t, vuint8m1_t, vuint8m1_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vredsum_vs_m)))
vuint8m1_t vredsum(vbool8_t, vuint8m1_t, vuint8m1_t, vuint8m1_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vredsum_vs)))
vuint8m1_t vredsum(vuint8m1_t, vuint8m2_t, vuint8m1_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vredsum_vs_m)))
vuint8m1_t vredsum(vbool4_t, vuint8m1_t, vuint8m2_t, vuint8m1_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vredsum_vs)))
vuint8m1_t vredsum(vuint8m1_t, vuint8m4_t, vuint8m1_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vredsum_vs_m)))
vuint8m1_t vredsum(vbool2_t, vuint8m1_t, vuint8m4_t, vuint8m1_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vredsum_vs)))
vuint8m1_t vredsum(vuint8m1_t, vuint8m8_t, vuint8m1_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vredsum_vs_m)))
vuint8m1_t vredsum(vbool1_t, vuint8m1_t, vuint8m8_t, vuint8m1_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vredsum_vs)))
vuint8m1_t vredsum(vuint8m1_t, vuint8mf2_t, vuint8m1_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vredsum_vs_m)))
vuint8m1_t vredsum(vbool16_t, vuint8m1_t, vuint8mf2_t, vuint8m1_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vredsum_vs)))
vuint8m1_t vredsum(vuint8m1_t, vuint8mf4_t, vuint8m1_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vredsum_vs_m)))
vuint8m1_t vredsum(vbool32_t, vuint8m1_t, vuint8mf4_t, vuint8m1_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vredsum_vs)))
vuint8m1_t vredsum(vuint8m1_t, vuint8mf8_t, vuint8m1_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vredsum_vs_m)))
vuint8m1_t vredsum(vbool64_t, vuint8m1_t, vuint8mf8_t, vuint8m1_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vredsum_vs)))
vuint16m1_t vredsum(vuint16m1_t, vuint16m1_t, vuint16m1_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vredsum_vs_m)))
vuint16m1_t vredsum(vbool16_t, vuint16m1_t, vuint16m1_t, vuint16m1_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vredsum_vs)))
vuint16m1_t vredsum(vuint16m1_t, vuint16m2_t, vuint16m1_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vredsum_vs_m)))
vuint16m1_t vredsum(vbool8_t, vuint16m1_t, vuint16m2_t, vuint16m1_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vredsum_vs)))
vuint16m1_t vredsum(vuint16m1_t, vuint16m4_t, vuint16m1_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vredsum_vs_m)))
vuint16m1_t vredsum(vbool4_t, vuint16m1_t, vuint16m4_t, vuint16m1_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vredsum_vs)))
vuint16m1_t vredsum(vuint16m1_t, vuint16m8_t, vuint16m1_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vredsum_vs_m)))
vuint16m1_t vredsum(vbool2_t, vuint16m1_t, vuint16m8_t, vuint16m1_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vredsum_vs)))
vuint16m1_t vredsum(vuint16m1_t, vuint16mf2_t, vuint16m1_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vredsum_vs_m)))
vuint16m1_t vredsum(vbool32_t, vuint16m1_t, vuint16mf2_t, vuint16m1_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vredsum_vs)))
vuint16m1_t vredsum(vuint16m1_t, vuint16mf4_t, vuint16m1_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vredsum_vs_m)))
vuint16m1_t vredsum(vbool64_t, vuint16m1_t, vuint16mf4_t, vuint16m1_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vredsum_vs)))
vuint32m1_t vredsum(vuint32m1_t, vuint32m1_t, vuint32m1_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vredsum_vs_m)))
vuint32m1_t vredsum(vbool32_t, vuint32m1_t, vuint32m1_t, vuint32m1_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vredsum_vs)))
vuint32m1_t vredsum(vuint32m1_t, vuint32m2_t, vuint32m1_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vredsum_vs_m)))
vuint32m1_t vredsum(vbool16_t, vuint32m1_t, vuint32m2_t, vuint32m1_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vredsum_vs)))
vuint32m1_t vredsum(vuint32m1_t, vuint32m4_t, vuint32m1_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vredsum_vs_m)))
vuint32m1_t vredsum(vbool8_t, vuint32m1_t, vuint32m4_t, vuint32m1_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vredsum_vs)))
vuint32m1_t vredsum(vuint32m1_t, vuint32m8_t, vuint32m1_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vredsum_vs_m)))
vuint32m1_t vredsum(vbool4_t, vuint32m1_t, vuint32m8_t, vuint32m1_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vredsum_vs)))
vuint32m1_t vredsum(vuint32m1_t, vuint32mf2_t, vuint32m1_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vredsum_vs_m)))
vuint32m1_t vredsum(vbool64_t, vuint32m1_t, vuint32mf2_t, vuint32m1_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vredmaxu_vs)))
vuint8m1_t vredmaxu(vuint8m1_t, vuint8m1_t, vuint8m1_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vredmaxu_vs_m)))
vuint8m1_t vredmaxu(vbool8_t, vuint8m1_t, vuint8m1_t, vuint8m1_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vredmaxu_vs)))
vuint8m1_t vredmaxu(vuint8m1_t, vuint8m2_t, vuint8m1_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vredmaxu_vs_m)))
vuint8m1_t vredmaxu(vbool4_t, vuint8m1_t, vuint8m2_t, vuint8m1_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vredmaxu_vs)))
vuint8m1_t vredmaxu(vuint8m1_t, vuint8m4_t, vuint8m1_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vredmaxu_vs_m)))
vuint8m1_t vredmaxu(vbool2_t, vuint8m1_t, vuint8m4_t, vuint8m1_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vredmaxu_vs)))
vuint8m1_t vredmaxu(vuint8m1_t, vuint8m8_t, vuint8m1_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vredmaxu_vs_m)))
vuint8m1_t vredmaxu(vbool1_t, vuint8m1_t, vuint8m8_t, vuint8m1_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vredmaxu_vs)))
vuint8m1_t vredmaxu(vuint8m1_t, vuint8mf2_t, vuint8m1_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vredmaxu_vs_m)))
vuint8m1_t vredmaxu(vbool16_t, vuint8m1_t, vuint8mf2_t, vuint8m1_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vredmaxu_vs)))
vuint8m1_t vredmaxu(vuint8m1_t, vuint8mf4_t, vuint8m1_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vredmaxu_vs_m)))
vuint8m1_t vredmaxu(vbool32_t, vuint8m1_t, vuint8mf4_t, vuint8m1_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vredmaxu_vs)))
vuint8m1_t vredmaxu(vuint8m1_t, vuint8mf8_t, vuint8m1_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vredmaxu_vs_m)))
vuint8m1_t vredmaxu(vbool64_t, vuint8m1_t, vuint8mf8_t, vuint8m1_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vredmaxu_vs)))
vuint16m1_t vredmaxu(vuint16m1_t, vuint16m1_t, vuint16m1_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vredmaxu_vs_m)))
vuint16m1_t vredmaxu(vbool16_t, vuint16m1_t, vuint16m1_t, vuint16m1_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vredmaxu_vs)))
vuint16m1_t vredmaxu(vuint16m1_t, vuint16m2_t, vuint16m1_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vredmaxu_vs_m)))
vuint16m1_t vredmaxu(vbool8_t, vuint16m1_t, vuint16m2_t, vuint16m1_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vredmaxu_vs)))
vuint16m1_t vredmaxu(vuint16m1_t, vuint16m4_t, vuint16m1_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vredmaxu_vs_m)))
vuint16m1_t vredmaxu(vbool4_t, vuint16m1_t, vuint16m4_t, vuint16m1_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vredmaxu_vs)))
vuint16m1_t vredmaxu(vuint16m1_t, vuint16m8_t, vuint16m1_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vredmaxu_vs_m)))
vuint16m1_t vredmaxu(vbool2_t, vuint16m1_t, vuint16m8_t, vuint16m1_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vredmaxu_vs)))
vuint16m1_t vredmaxu(vuint16m1_t, vuint16mf2_t, vuint16m1_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vredmaxu_vs_m)))
vuint16m1_t vredmaxu(vbool32_t, vuint16m1_t, vuint16mf2_t, vuint16m1_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vredmaxu_vs)))
vuint16m1_t vredmaxu(vuint16m1_t, vuint16mf4_t, vuint16m1_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vredmaxu_vs_m)))
vuint16m1_t vredmaxu(vbool64_t, vuint16m1_t, vuint16mf4_t, vuint16m1_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vredmaxu_vs)))
vuint32m1_t vredmaxu(vuint32m1_t, vuint32m1_t, vuint32m1_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vredmaxu_vs_m)))
vuint32m1_t vredmaxu(vbool32_t, vuint32m1_t, vuint32m1_t, vuint32m1_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vredmaxu_vs)))
vuint32m1_t vredmaxu(vuint32m1_t, vuint32m2_t, vuint32m1_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vredmaxu_vs_m)))
vuint32m1_t vredmaxu(vbool16_t, vuint32m1_t, vuint32m2_t, vuint32m1_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vredmaxu_vs)))
vuint32m1_t vredmaxu(vuint32m1_t, vuint32m4_t, vuint32m1_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vredmaxu_vs_m)))
vuint32m1_t vredmaxu(vbool8_t, vuint32m1_t, vuint32m4_t, vuint32m1_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vredmaxu_vs)))
vuint32m1_t vredmaxu(vuint32m1_t, vuint32m8_t, vuint32m1_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vredmaxu_vs_m)))
vuint32m1_t vredmaxu(vbool4_t, vuint32m1_t, vuint32m8_t, vuint32m1_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vredmaxu_vs)))
vuint32m1_t vredmaxu(vuint32m1_t, vuint32mf2_t, vuint32m1_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vredmaxu_vs_m)))
vuint32m1_t vredmaxu(vbool64_t, vuint32m1_t, vuint32mf2_t, vuint32m1_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vredmax_vs)))
vint8m1_t vredmax(vint8m1_t, vint8m1_t, vint8m1_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vredmax_vs_m)))
vint8m1_t vredmax(vbool8_t, vint8m1_t, vint8m1_t, vint8m1_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vredmax_vs)))
vint8m1_t vredmax(vint8m1_t, vint8m2_t, vint8m1_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vredmax_vs_m)))
vint8m1_t vredmax(vbool4_t, vint8m1_t, vint8m2_t, vint8m1_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vredmax_vs)))
vint8m1_t vredmax(vint8m1_t, vint8m4_t, vint8m1_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vredmax_vs_m)))
vint8m1_t vredmax(vbool2_t, vint8m1_t, vint8m4_t, vint8m1_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vredmax_vs)))
vint8m1_t vredmax(vint8m1_t, vint8m8_t, vint8m1_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vredmax_vs_m)))
vint8m1_t vredmax(vbool1_t, vint8m1_t, vint8m8_t, vint8m1_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vredmax_vs)))
vint8m1_t vredmax(vint8m1_t, vint8mf2_t, vint8m1_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vredmax_vs_m)))
vint8m1_t vredmax(vbool16_t, vint8m1_t, vint8mf2_t, vint8m1_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vredmax_vs)))
vint8m1_t vredmax(vint8m1_t, vint8mf4_t, vint8m1_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vredmax_vs_m)))
vint8m1_t vredmax(vbool32_t, vint8m1_t, vint8mf4_t, vint8m1_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vredmax_vs)))
vint8m1_t vredmax(vint8m1_t, vint8mf8_t, vint8m1_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vredmax_vs_m)))
vint8m1_t vredmax(vbool64_t, vint8m1_t, vint8mf8_t, vint8m1_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vredmax_vs)))
vint16m1_t vredmax(vint16m1_t, vint16m1_t, vint16m1_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vredmax_vs_m)))
vint16m1_t vredmax(vbool16_t, vint16m1_t, vint16m1_t, vint16m1_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vredmax_vs)))
vint16m1_t vredmax(vint16m1_t, vint16m2_t, vint16m1_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vredmax_vs_m)))
vint16m1_t vredmax(vbool8_t, vint16m1_t, vint16m2_t, vint16m1_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vredmax_vs)))
vint16m1_t vredmax(vint16m1_t, vint16m4_t, vint16m1_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vredmax_vs_m)))
vint16m1_t vredmax(vbool4_t, vint16m1_t, vint16m4_t, vint16m1_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vredmax_vs)))
vint16m1_t vredmax(vint16m1_t, vint16m8_t, vint16m1_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vredmax_vs_m)))
vint16m1_t vredmax(vbool2_t, vint16m1_t, vint16m8_t, vint16m1_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vredmax_vs)))
vint16m1_t vredmax(vint16m1_t, vint16mf2_t, vint16m1_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vredmax_vs_m)))
vint16m1_t vredmax(vbool32_t, vint16m1_t, vint16mf2_t, vint16m1_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vredmax_vs)))
vint16m1_t vredmax(vint16m1_t, vint16mf4_t, vint16m1_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vredmax_vs_m)))
vint16m1_t vredmax(vbool64_t, vint16m1_t, vint16mf4_t, vint16m1_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vredmax_vs)))
vint32m1_t vredmax(vint32m1_t, vint32m1_t, vint32m1_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vredmax_vs_m)))
vint32m1_t vredmax(vbool32_t, vint32m1_t, vint32m1_t, vint32m1_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vredmax_vs)))
vint32m1_t vredmax(vint32m1_t, vint32m2_t, vint32m1_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vredmax_vs_m)))
vint32m1_t vredmax(vbool16_t, vint32m1_t, vint32m2_t, vint32m1_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vredmax_vs)))
vint32m1_t vredmax(vint32m1_t, vint32m4_t, vint32m1_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vredmax_vs_m)))
vint32m1_t vredmax(vbool8_t, vint32m1_t, vint32m4_t, vint32m1_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vredmax_vs)))
vint32m1_t vredmax(vint32m1_t, vint32m8_t, vint32m1_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vredmax_vs_m)))
vint32m1_t vredmax(vbool4_t, vint32m1_t, vint32m8_t, vint32m1_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vredmax_vs)))
vint32m1_t vredmax(vint32m1_t, vint32mf2_t, vint32m1_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vredmax_vs_m)))
vint32m1_t vredmax(vbool64_t, vint32m1_t, vint32mf2_t, vint32m1_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vredminu_vs)))
vuint8m1_t vredminu(vuint8m1_t, vuint8m1_t, vuint8m1_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vredminu_vs_m)))
vuint8m1_t vredminu(vbool8_t, vuint8m1_t, vuint8m1_t, vuint8m1_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vredminu_vs)))
vuint8m1_t vredminu(vuint8m1_t, vuint8m2_t, vuint8m1_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vredminu_vs_m)))
vuint8m1_t vredminu(vbool4_t, vuint8m1_t, vuint8m2_t, vuint8m1_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vredminu_vs)))
vuint8m1_t vredminu(vuint8m1_t, vuint8m4_t, vuint8m1_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vredminu_vs_m)))
vuint8m1_t vredminu(vbool2_t, vuint8m1_t, vuint8m4_t, vuint8m1_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vredminu_vs)))
vuint8m1_t vredminu(vuint8m1_t, vuint8m8_t, vuint8m1_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vredminu_vs_m)))
vuint8m1_t vredminu(vbool1_t, vuint8m1_t, vuint8m8_t, vuint8m1_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vredminu_vs)))
vuint8m1_t vredminu(vuint8m1_t, vuint8mf2_t, vuint8m1_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vredminu_vs_m)))
vuint8m1_t vredminu(vbool16_t, vuint8m1_t, vuint8mf2_t, vuint8m1_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vredminu_vs)))
vuint8m1_t vredminu(vuint8m1_t, vuint8mf4_t, vuint8m1_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vredminu_vs_m)))
vuint8m1_t vredminu(vbool32_t, vuint8m1_t, vuint8mf4_t, vuint8m1_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vredminu_vs)))
vuint8m1_t vredminu(vuint8m1_t, vuint8mf8_t, vuint8m1_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vredminu_vs_m)))
vuint8m1_t vredminu(vbool64_t, vuint8m1_t, vuint8mf8_t, vuint8m1_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vredminu_vs)))
vuint16m1_t vredminu(vuint16m1_t, vuint16m1_t, vuint16m1_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vredminu_vs_m)))
vuint16m1_t vredminu(vbool16_t, vuint16m1_t, vuint16m1_t, vuint16m1_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vredminu_vs)))
vuint16m1_t vredminu(vuint16m1_t, vuint16m2_t, vuint16m1_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vredminu_vs_m)))
vuint16m1_t vredminu(vbool8_t, vuint16m1_t, vuint16m2_t, vuint16m1_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vredminu_vs)))
vuint16m1_t vredminu(vuint16m1_t, vuint16m4_t, vuint16m1_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vredminu_vs_m)))
vuint16m1_t vredminu(vbool4_t, vuint16m1_t, vuint16m4_t, vuint16m1_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vredminu_vs)))
vuint16m1_t vredminu(vuint16m1_t, vuint16m8_t, vuint16m1_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vredminu_vs_m)))
vuint16m1_t vredminu(vbool2_t, vuint16m1_t, vuint16m8_t, vuint16m1_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vredminu_vs)))
vuint16m1_t vredminu(vuint16m1_t, vuint16mf2_t, vuint16m1_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vredminu_vs_m)))
vuint16m1_t vredminu(vbool32_t, vuint16m1_t, vuint16mf2_t, vuint16m1_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vredminu_vs)))
vuint16m1_t vredminu(vuint16m1_t, vuint16mf4_t, vuint16m1_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vredminu_vs_m)))
vuint16m1_t vredminu(vbool64_t, vuint16m1_t, vuint16mf4_t, vuint16m1_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vredminu_vs)))
vuint32m1_t vredminu(vuint32m1_t, vuint32m1_t, vuint32m1_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vredminu_vs_m)))
vuint32m1_t vredminu(vbool32_t, vuint32m1_t, vuint32m1_t, vuint32m1_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vredminu_vs)))
vuint32m1_t vredminu(vuint32m1_t, vuint32m2_t, vuint32m1_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vredminu_vs_m)))
vuint32m1_t vredminu(vbool16_t, vuint32m1_t, vuint32m2_t, vuint32m1_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vredminu_vs)))
vuint32m1_t vredminu(vuint32m1_t, vuint32m4_t, vuint32m1_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vredminu_vs_m)))
vuint32m1_t vredminu(vbool8_t, vuint32m1_t, vuint32m4_t, vuint32m1_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vredminu_vs)))
vuint32m1_t vredminu(vuint32m1_t, vuint32m8_t, vuint32m1_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vredminu_vs_m)))
vuint32m1_t vredminu(vbool4_t, vuint32m1_t, vuint32m8_t, vuint32m1_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vredminu_vs)))
vuint32m1_t vredminu(vuint32m1_t, vuint32mf2_t, vuint32m1_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vredminu_vs_m)))
vuint32m1_t vredminu(vbool64_t, vuint32m1_t, vuint32mf2_t, vuint32m1_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vredmin_vs)))
vint8m1_t vredmin(vint8m1_t, vint8m1_t, vint8m1_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vredmin_vs_m)))
vint8m1_t vredmin(vbool8_t, vint8m1_t, vint8m1_t, vint8m1_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vredmin_vs)))
vint8m1_t vredmin(vint8m1_t, vint8m2_t, vint8m1_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vredmin_vs_m)))
vint8m1_t vredmin(vbool4_t, vint8m1_t, vint8m2_t, vint8m1_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vredmin_vs)))
vint8m1_t vredmin(vint8m1_t, vint8m4_t, vint8m1_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vredmin_vs_m)))
vint8m1_t vredmin(vbool2_t, vint8m1_t, vint8m4_t, vint8m1_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vredmin_vs)))
vint8m1_t vredmin(vint8m1_t, vint8m8_t, vint8m1_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vredmin_vs_m)))
vint8m1_t vredmin(vbool1_t, vint8m1_t, vint8m8_t, vint8m1_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vredmin_vs)))
vint8m1_t vredmin(vint8m1_t, vint8mf2_t, vint8m1_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vredmin_vs_m)))
vint8m1_t vredmin(vbool16_t, vint8m1_t, vint8mf2_t, vint8m1_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vredmin_vs)))
vint8m1_t vredmin(vint8m1_t, vint8mf4_t, vint8m1_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vredmin_vs_m)))
vint8m1_t vredmin(vbool32_t, vint8m1_t, vint8mf4_t, vint8m1_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vredmin_vs)))
vint8m1_t vredmin(vint8m1_t, vint8mf8_t, vint8m1_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vredmin_vs_m)))
vint8m1_t vredmin(vbool64_t, vint8m1_t, vint8mf8_t, vint8m1_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vredmin_vs)))
vint16m1_t vredmin(vint16m1_t, vint16m1_t, vint16m1_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vredmin_vs_m)))
vint16m1_t vredmin(vbool16_t, vint16m1_t, vint16m1_t, vint16m1_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vredmin_vs)))
vint16m1_t vredmin(vint16m1_t, vint16m2_t, vint16m1_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vredmin_vs_m)))
vint16m1_t vredmin(vbool8_t, vint16m1_t, vint16m2_t, vint16m1_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vredmin_vs)))
vint16m1_t vredmin(vint16m1_t, vint16m4_t, vint16m1_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vredmin_vs_m)))
vint16m1_t vredmin(vbool4_t, vint16m1_t, vint16m4_t, vint16m1_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vredmin_vs)))
vint16m1_t vredmin(vint16m1_t, vint16m8_t, vint16m1_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vredmin_vs_m)))
vint16m1_t vredmin(vbool2_t, vint16m1_t, vint16m8_t, vint16m1_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vredmin_vs)))
vint16m1_t vredmin(vint16m1_t, vint16mf2_t, vint16m1_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vredmin_vs_m)))
vint16m1_t vredmin(vbool32_t, vint16m1_t, vint16mf2_t, vint16m1_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vredmin_vs)))
vint16m1_t vredmin(vint16m1_t, vint16mf4_t, vint16m1_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vredmin_vs_m)))
vint16m1_t vredmin(vbool64_t, vint16m1_t, vint16mf4_t, vint16m1_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vredmin_vs)))
vint32m1_t vredmin(vint32m1_t, vint32m1_t, vint32m1_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vredmin_vs_m)))
vint32m1_t vredmin(vbool32_t, vint32m1_t, vint32m1_t, vint32m1_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vredmin_vs)))
vint32m1_t vredmin(vint32m1_t, vint32m2_t, vint32m1_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vredmin_vs_m)))
vint32m1_t vredmin(vbool16_t, vint32m1_t, vint32m2_t, vint32m1_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vredmin_vs)))
vint32m1_t vredmin(vint32m1_t, vint32m4_t, vint32m1_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vredmin_vs_m)))
vint32m1_t vredmin(vbool8_t, vint32m1_t, vint32m4_t, vint32m1_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vredmin_vs)))
vint32m1_t vredmin(vint32m1_t, vint32m8_t, vint32m1_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vredmin_vs_m)))
vint32m1_t vredmin(vbool4_t, vint32m1_t, vint32m8_t, vint32m1_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vredmin_vs)))
vint32m1_t vredmin(vint32m1_t, vint32mf2_t, vint32m1_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vredmin_vs_m)))
vint32m1_t vredmin(vbool64_t, vint32m1_t, vint32mf2_t, vint32m1_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vredand_vs)))
vint8m1_t vredand(vint8m1_t, vint8m1_t, vint8m1_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vredand_vs_m)))
vint8m1_t vredand(vbool8_t, vint8m1_t, vint8m1_t, vint8m1_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vredand_vs)))
vint8m1_t vredand(vint8m1_t, vint8m2_t, vint8m1_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vredand_vs_m)))
vint8m1_t vredand(vbool4_t, vint8m1_t, vint8m2_t, vint8m1_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vredand_vs)))
vint8m1_t vredand(vint8m1_t, vint8m4_t, vint8m1_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vredand_vs_m)))
vint8m1_t vredand(vbool2_t, vint8m1_t, vint8m4_t, vint8m1_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vredand_vs)))
vint8m1_t vredand(vint8m1_t, vint8m8_t, vint8m1_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vredand_vs_m)))
vint8m1_t vredand(vbool1_t, vint8m1_t, vint8m8_t, vint8m1_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vredand_vs)))
vint8m1_t vredand(vint8m1_t, vint8mf2_t, vint8m1_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vredand_vs_m)))
vint8m1_t vredand(vbool16_t, vint8m1_t, vint8mf2_t, vint8m1_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vredand_vs)))
vint8m1_t vredand(vint8m1_t, vint8mf4_t, vint8m1_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vredand_vs_m)))
vint8m1_t vredand(vbool32_t, vint8m1_t, vint8mf4_t, vint8m1_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vredand_vs)))
vint8m1_t vredand(vint8m1_t, vint8mf8_t, vint8m1_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vredand_vs_m)))
vint8m1_t vredand(vbool64_t, vint8m1_t, vint8mf8_t, vint8m1_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vredand_vs)))
vint16m1_t vredand(vint16m1_t, vint16m1_t, vint16m1_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vredand_vs_m)))
vint16m1_t vredand(vbool16_t, vint16m1_t, vint16m1_t, vint16m1_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vredand_vs)))
vint16m1_t vredand(vint16m1_t, vint16m2_t, vint16m1_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vredand_vs_m)))
vint16m1_t vredand(vbool8_t, vint16m1_t, vint16m2_t, vint16m1_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vredand_vs)))
vint16m1_t vredand(vint16m1_t, vint16m4_t, vint16m1_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vredand_vs_m)))
vint16m1_t vredand(vbool4_t, vint16m1_t, vint16m4_t, vint16m1_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vredand_vs)))
vint16m1_t vredand(vint16m1_t, vint16m8_t, vint16m1_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vredand_vs_m)))
vint16m1_t vredand(vbool2_t, vint16m1_t, vint16m8_t, vint16m1_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vredand_vs)))
vint16m1_t vredand(vint16m1_t, vint16mf2_t, vint16m1_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vredand_vs_m)))
vint16m1_t vredand(vbool32_t, vint16m1_t, vint16mf2_t, vint16m1_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vredand_vs)))
vint16m1_t vredand(vint16m1_t, vint16mf4_t, vint16m1_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vredand_vs_m)))
vint16m1_t vredand(vbool64_t, vint16m1_t, vint16mf4_t, vint16m1_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vredand_vs)))
vint32m1_t vredand(vint32m1_t, vint32m1_t, vint32m1_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vredand_vs_m)))
vint32m1_t vredand(vbool32_t, vint32m1_t, vint32m1_t, vint32m1_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vredand_vs)))
vint32m1_t vredand(vint32m1_t, vint32m2_t, vint32m1_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vredand_vs_m)))
vint32m1_t vredand(vbool16_t, vint32m1_t, vint32m2_t, vint32m1_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vredand_vs)))
vint32m1_t vredand(vint32m1_t, vint32m4_t, vint32m1_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vredand_vs_m)))
vint32m1_t vredand(vbool8_t, vint32m1_t, vint32m4_t, vint32m1_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vredand_vs)))
vint32m1_t vredand(vint32m1_t, vint32m8_t, vint32m1_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vredand_vs_m)))
vint32m1_t vredand(vbool4_t, vint32m1_t, vint32m8_t, vint32m1_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vredand_vs)))
vint32m1_t vredand(vint32m1_t, vint32mf2_t, vint32m1_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vredand_vs_m)))
vint32m1_t vredand(vbool64_t, vint32m1_t, vint32mf2_t, vint32m1_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vredand_vs)))
vuint8m1_t vredand(vuint8m1_t, vuint8m1_t, vuint8m1_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vredand_vs_m)))
vuint8m1_t vredand(vbool8_t, vuint8m1_t, vuint8m1_t, vuint8m1_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vredand_vs)))
vuint8m1_t vredand(vuint8m1_t, vuint8m2_t, vuint8m1_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vredand_vs_m)))
vuint8m1_t vredand(vbool4_t, vuint8m1_t, vuint8m2_t, vuint8m1_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vredand_vs)))
vuint8m1_t vredand(vuint8m1_t, vuint8m4_t, vuint8m1_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vredand_vs_m)))
vuint8m1_t vredand(vbool2_t, vuint8m1_t, vuint8m4_t, vuint8m1_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vredand_vs)))
vuint8m1_t vredand(vuint8m1_t, vuint8m8_t, vuint8m1_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vredand_vs_m)))
vuint8m1_t vredand(vbool1_t, vuint8m1_t, vuint8m8_t, vuint8m1_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vredand_vs)))
vuint8m1_t vredand(vuint8m1_t, vuint8mf2_t, vuint8m1_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vredand_vs_m)))
vuint8m1_t vredand(vbool16_t, vuint8m1_t, vuint8mf2_t, vuint8m1_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vredand_vs)))
vuint8m1_t vredand(vuint8m1_t, vuint8mf4_t, vuint8m1_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vredand_vs_m)))
vuint8m1_t vredand(vbool32_t, vuint8m1_t, vuint8mf4_t, vuint8m1_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vredand_vs)))
vuint8m1_t vredand(vuint8m1_t, vuint8mf8_t, vuint8m1_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vredand_vs_m)))
vuint8m1_t vredand(vbool64_t, vuint8m1_t, vuint8mf8_t, vuint8m1_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vredand_vs)))
vuint16m1_t vredand(vuint16m1_t, vuint16m1_t, vuint16m1_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vredand_vs_m)))
vuint16m1_t vredand(vbool16_t, vuint16m1_t, vuint16m1_t, vuint16m1_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vredand_vs)))
vuint16m1_t vredand(vuint16m1_t, vuint16m2_t, vuint16m1_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vredand_vs_m)))
vuint16m1_t vredand(vbool8_t, vuint16m1_t, vuint16m2_t, vuint16m1_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vredand_vs)))
vuint16m1_t vredand(vuint16m1_t, vuint16m4_t, vuint16m1_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vredand_vs_m)))
vuint16m1_t vredand(vbool4_t, vuint16m1_t, vuint16m4_t, vuint16m1_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vredand_vs)))
vuint16m1_t vredand(vuint16m1_t, vuint16m8_t, vuint16m1_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vredand_vs_m)))
vuint16m1_t vredand(vbool2_t, vuint16m1_t, vuint16m8_t, vuint16m1_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vredand_vs)))
vuint16m1_t vredand(vuint16m1_t, vuint16mf2_t, vuint16m1_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vredand_vs_m)))
vuint16m1_t vredand(vbool32_t, vuint16m1_t, vuint16mf2_t, vuint16m1_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vredand_vs)))
vuint16m1_t vredand(vuint16m1_t, vuint16mf4_t, vuint16m1_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vredand_vs_m)))
vuint16m1_t vredand(vbool64_t, vuint16m1_t, vuint16mf4_t, vuint16m1_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vredand_vs)))
vuint32m1_t vredand(vuint32m1_t, vuint32m1_t, vuint32m1_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vredand_vs_m)))
vuint32m1_t vredand(vbool32_t, vuint32m1_t, vuint32m1_t, vuint32m1_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vredand_vs)))
vuint32m1_t vredand(vuint32m1_t, vuint32m2_t, vuint32m1_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vredand_vs_m)))
vuint32m1_t vredand(vbool16_t, vuint32m1_t, vuint32m2_t, vuint32m1_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vredand_vs)))
vuint32m1_t vredand(vuint32m1_t, vuint32m4_t, vuint32m1_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vredand_vs_m)))
vuint32m1_t vredand(vbool8_t, vuint32m1_t, vuint32m4_t, vuint32m1_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vredand_vs)))
vuint32m1_t vredand(vuint32m1_t, vuint32m8_t, vuint32m1_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vredand_vs_m)))
vuint32m1_t vredand(vbool4_t, vuint32m1_t, vuint32m8_t, vuint32m1_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vredand_vs)))
vuint32m1_t vredand(vuint32m1_t, vuint32mf2_t, vuint32m1_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vredand_vs_m)))
vuint32m1_t vredand(vbool64_t, vuint32m1_t, vuint32mf2_t, vuint32m1_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vsuxei32_v)))
void vsuxei32(uint32_t *, vuint32m1_t, vuint32m1_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vsuxei32_v_m)))
void vsuxei32(vbool32_t, uint32_t *, vuint32m1_t, vuint32m1_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vsuxei32_v)))
void vsuxei32(uint32_t *, vuint32m2_t, vuint32m2_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vsuxei32_v_m)))
void vsuxei32(vbool16_t, uint32_t *, vuint32m2_t, vuint32m2_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vsuxei32_v)))
void vsuxei32(uint32_t *, vuint32m4_t, vuint32m4_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vsuxei32_v_m)))
void vsuxei32(vbool8_t, uint32_t *, vuint32m4_t, vuint32m4_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vsuxei32_v)))
void vsuxei32(uint32_t *, vuint32m8_t, vuint32m8_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vsuxei32_v_m)))
void vsuxei32(vbool4_t, uint32_t *, vuint32m8_t, vuint32m8_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vsuxei32_v)))
void vsuxei32(uint32_t *, vuint32mf2_t, vuint32mf2_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vsuxei32_v_m)))
void vsuxei32(vbool64_t, uint32_t *, vuint32mf2_t, vuint32mf2_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vredor_vs)))
vint8m1_t vredor(vint8m1_t, vint8m1_t, vint8m1_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vredor_vs_m)))
vint8m1_t vredor(vbool8_t, vint8m1_t, vint8m1_t, vint8m1_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vredor_vs)))
vint8m1_t vredor(vint8m1_t, vint8m2_t, vint8m1_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vredor_vs_m)))
vint8m1_t vredor(vbool4_t, vint8m1_t, vint8m2_t, vint8m1_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vredor_vs)))
vint8m1_t vredor(vint8m1_t, vint8m4_t, vint8m1_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vredor_vs_m)))
vint8m1_t vredor(vbool2_t, vint8m1_t, vint8m4_t, vint8m1_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vredor_vs)))
vint8m1_t vredor(vint8m1_t, vint8m8_t, vint8m1_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vredor_vs_m)))
vint8m1_t vredor(vbool1_t, vint8m1_t, vint8m8_t, vint8m1_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vredor_vs)))
vint8m1_t vredor(vint8m1_t, vint8mf2_t, vint8m1_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vredor_vs_m)))
vint8m1_t vredor(vbool16_t, vint8m1_t, vint8mf2_t, vint8m1_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vredor_vs)))
vint8m1_t vredor(vint8m1_t, vint8mf4_t, vint8m1_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vredor_vs_m)))
vint8m1_t vredor(vbool32_t, vint8m1_t, vint8mf4_t, vint8m1_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vredor_vs)))
vint8m1_t vredor(vint8m1_t, vint8mf8_t, vint8m1_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vredor_vs_m)))
vint8m1_t vredor(vbool64_t, vint8m1_t, vint8mf8_t, vint8m1_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vredor_vs)))
vint16m1_t vredor(vint16m1_t, vint16m1_t, vint16m1_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vredor_vs_m)))
vint16m1_t vredor(vbool16_t, vint16m1_t, vint16m1_t, vint16m1_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vredor_vs)))
vint16m1_t vredor(vint16m1_t, vint16m2_t, vint16m1_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vredor_vs_m)))
vint16m1_t vredor(vbool8_t, vint16m1_t, vint16m2_t, vint16m1_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vredor_vs)))
vint16m1_t vredor(vint16m1_t, vint16m4_t, vint16m1_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vredor_vs_m)))
vint16m1_t vredor(vbool4_t, vint16m1_t, vint16m4_t, vint16m1_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vredor_vs)))
vint16m1_t vredor(vint16m1_t, vint16m8_t, vint16m1_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vredor_vs_m)))
vint16m1_t vredor(vbool2_t, vint16m1_t, vint16m8_t, vint16m1_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vredor_vs)))
vint16m1_t vredor(vint16m1_t, vint16mf2_t, vint16m1_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vredor_vs_m)))
vint16m1_t vredor(vbool32_t, vint16m1_t, vint16mf2_t, vint16m1_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vredor_vs)))
vint16m1_t vredor(vint16m1_t, vint16mf4_t, vint16m1_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vredor_vs_m)))
vint16m1_t vredor(vbool64_t, vint16m1_t, vint16mf4_t, vint16m1_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vredor_vs)))
vint32m1_t vredor(vint32m1_t, vint32m1_t, vint32m1_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vredor_vs_m)))
vint32m1_t vredor(vbool32_t, vint32m1_t, vint32m1_t, vint32m1_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vredor_vs)))
vint32m1_t vredor(vint32m1_t, vint32m2_t, vint32m1_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vredor_vs_m)))
vint32m1_t vredor(vbool16_t, vint32m1_t, vint32m2_t, vint32m1_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vredor_vs)))
vint32m1_t vredor(vint32m1_t, vint32m4_t, vint32m1_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vredor_vs_m)))
vint32m1_t vredor(vbool8_t, vint32m1_t, vint32m4_t, vint32m1_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vredor_vs)))
vint32m1_t vredor(vint32m1_t, vint32m8_t, vint32m1_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vredor_vs_m)))
vint32m1_t vredor(vbool4_t, vint32m1_t, vint32m8_t, vint32m1_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vredor_vs)))
vint32m1_t vredor(vint32m1_t, vint32mf2_t, vint32m1_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vredor_vs_m)))
vint32m1_t vredor(vbool64_t, vint32m1_t, vint32mf2_t, vint32m1_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vredor_vs)))
vuint8m1_t vredor(vuint8m1_t, vuint8m1_t, vuint8m1_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vredor_vs_m)))
vuint8m1_t vredor(vbool8_t, vuint8m1_t, vuint8m1_t, vuint8m1_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vredor_vs)))
vuint8m1_t vredor(vuint8m1_t, vuint8m2_t, vuint8m1_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vredor_vs_m)))
vuint8m1_t vredor(vbool4_t, vuint8m1_t, vuint8m2_t, vuint8m1_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vredor_vs)))
vuint8m1_t vredor(vuint8m1_t, vuint8m4_t, vuint8m1_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vredor_vs_m)))
vuint8m1_t vredor(vbool2_t, vuint8m1_t, vuint8m4_t, vuint8m1_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vredor_vs)))
vuint8m1_t vredor(vuint8m1_t, vuint8m8_t, vuint8m1_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vredor_vs_m)))
vuint8m1_t vredor(vbool1_t, vuint8m1_t, vuint8m8_t, vuint8m1_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vredor_vs)))
vuint8m1_t vredor(vuint8m1_t, vuint8mf2_t, vuint8m1_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vredor_vs_m)))
vuint8m1_t vredor(vbool16_t, vuint8m1_t, vuint8mf2_t, vuint8m1_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vredor_vs)))
vuint8m1_t vredor(vuint8m1_t, vuint8mf4_t, vuint8m1_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vredor_vs_m)))
vuint8m1_t vredor(vbool32_t, vuint8m1_t, vuint8mf4_t, vuint8m1_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vredor_vs)))
vuint8m1_t vredor(vuint8m1_t, vuint8mf8_t, vuint8m1_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vredor_vs_m)))
vuint8m1_t vredor(vbool64_t, vuint8m1_t, vuint8mf8_t, vuint8m1_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vredor_vs)))
vuint16m1_t vredor(vuint16m1_t, vuint16m1_t, vuint16m1_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vredor_vs_m)))
vuint16m1_t vredor(vbool16_t, vuint16m1_t, vuint16m1_t, vuint16m1_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vredor_vs)))
vuint16m1_t vredor(vuint16m1_t, vuint16m2_t, vuint16m1_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vredor_vs_m)))
vuint16m1_t vredor(vbool8_t, vuint16m1_t, vuint16m2_t, vuint16m1_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vredor_vs)))
vuint16m1_t vredor(vuint16m1_t, vuint16m4_t, vuint16m1_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vredor_vs_m)))
vuint16m1_t vredor(vbool4_t, vuint16m1_t, vuint16m4_t, vuint16m1_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vredor_vs)))
vuint16m1_t vredor(vuint16m1_t, vuint16m8_t, vuint16m1_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vredor_vs_m)))
vuint16m1_t vredor(vbool2_t, vuint16m1_t, vuint16m8_t, vuint16m1_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vredor_vs)))
vuint16m1_t vredor(vuint16m1_t, vuint16mf2_t, vuint16m1_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vredor_vs_m)))
vuint16m1_t vredor(vbool32_t, vuint16m1_t, vuint16mf2_t, vuint16m1_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vredor_vs)))
vuint16m1_t vredor(vuint16m1_t, vuint16mf4_t, vuint16m1_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vredor_vs_m)))
vuint16m1_t vredor(vbool64_t, vuint16m1_t, vuint16mf4_t, vuint16m1_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vredor_vs)))
vuint32m1_t vredor(vuint32m1_t, vuint32m1_t, vuint32m1_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vredor_vs_m)))
vuint32m1_t vredor(vbool32_t, vuint32m1_t, vuint32m1_t, vuint32m1_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vredor_vs)))
vuint32m1_t vredor(vuint32m1_t, vuint32m2_t, vuint32m1_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vredor_vs_m)))
vuint32m1_t vredor(vbool16_t, vuint32m1_t, vuint32m2_t, vuint32m1_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vredor_vs)))
vuint32m1_t vredor(vuint32m1_t, vuint32m4_t, vuint32m1_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vredor_vs_m)))
vuint32m1_t vredor(vbool8_t, vuint32m1_t, vuint32m4_t, vuint32m1_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vredor_vs)))
vuint32m1_t vredor(vuint32m1_t, vuint32m8_t, vuint32m1_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vredor_vs_m)))
vuint32m1_t vredor(vbool4_t, vuint32m1_t, vuint32m8_t, vuint32m1_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vredor_vs)))
vuint32m1_t vredor(vuint32m1_t, vuint32mf2_t, vuint32m1_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vredor_vs_m)))
vuint32m1_t vredor(vbool64_t, vuint32m1_t, vuint32mf2_t, vuint32m1_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vredxor_vs)))
vint8m1_t vredxor(vint8m1_t, vint8m1_t, vint8m1_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vredxor_vs_m)))
vint8m1_t vredxor(vbool8_t, vint8m1_t, vint8m1_t, vint8m1_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vredxor_vs)))
vint8m1_t vredxor(vint8m1_t, vint8m2_t, vint8m1_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vredxor_vs_m)))
vint8m1_t vredxor(vbool4_t, vint8m1_t, vint8m2_t, vint8m1_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vredxor_vs)))
vint8m1_t vredxor(vint8m1_t, vint8m4_t, vint8m1_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vredxor_vs_m)))
vint8m1_t vredxor(vbool2_t, vint8m1_t, vint8m4_t, vint8m1_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vredxor_vs)))
vint8m1_t vredxor(vint8m1_t, vint8m8_t, vint8m1_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vredxor_vs_m)))
vint8m1_t vredxor(vbool1_t, vint8m1_t, vint8m8_t, vint8m1_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vredxor_vs)))
vint8m1_t vredxor(vint8m1_t, vint8mf2_t, vint8m1_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vredxor_vs_m)))
vint8m1_t vredxor(vbool16_t, vint8m1_t, vint8mf2_t, vint8m1_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vredxor_vs)))
vint8m1_t vredxor(vint8m1_t, vint8mf4_t, vint8m1_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vredxor_vs_m)))
vint8m1_t vredxor(vbool32_t, vint8m1_t, vint8mf4_t, vint8m1_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vredxor_vs)))
vint8m1_t vredxor(vint8m1_t, vint8mf8_t, vint8m1_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vredxor_vs_m)))
vint8m1_t vredxor(vbool64_t, vint8m1_t, vint8mf8_t, vint8m1_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vredxor_vs)))
vint16m1_t vredxor(vint16m1_t, vint16m1_t, vint16m1_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vredxor_vs_m)))
vint16m1_t vredxor(vbool16_t, vint16m1_t, vint16m1_t, vint16m1_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vredxor_vs)))
vint16m1_t vredxor(vint16m1_t, vint16m2_t, vint16m1_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vredxor_vs_m)))
vint16m1_t vredxor(vbool8_t, vint16m1_t, vint16m2_t, vint16m1_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vredxor_vs)))
vint16m1_t vredxor(vint16m1_t, vint16m4_t, vint16m1_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vredxor_vs_m)))
vint16m1_t vredxor(vbool4_t, vint16m1_t, vint16m4_t, vint16m1_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vredxor_vs)))
vint16m1_t vredxor(vint16m1_t, vint16m8_t, vint16m1_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vredxor_vs_m)))
vint16m1_t vredxor(vbool2_t, vint16m1_t, vint16m8_t, vint16m1_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vredxor_vs)))
vint16m1_t vredxor(vint16m1_t, vint16mf2_t, vint16m1_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vredxor_vs_m)))
vint16m1_t vredxor(vbool32_t, vint16m1_t, vint16mf2_t, vint16m1_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vredxor_vs)))
vint16m1_t vredxor(vint16m1_t, vint16mf4_t, vint16m1_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vredxor_vs_m)))
vint16m1_t vredxor(vbool64_t, vint16m1_t, vint16mf4_t, vint16m1_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vredxor_vs)))
vint32m1_t vredxor(vint32m1_t, vint32m1_t, vint32m1_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vredxor_vs_m)))
vint32m1_t vredxor(vbool32_t, vint32m1_t, vint32m1_t, vint32m1_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vredxor_vs)))
vint32m1_t vredxor(vint32m1_t, vint32m2_t, vint32m1_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vredxor_vs_m)))
vint32m1_t vredxor(vbool16_t, vint32m1_t, vint32m2_t, vint32m1_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vredxor_vs)))
vint32m1_t vredxor(vint32m1_t, vint32m4_t, vint32m1_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vredxor_vs_m)))
vint32m1_t vredxor(vbool8_t, vint32m1_t, vint32m4_t, vint32m1_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vredxor_vs)))
vint32m1_t vredxor(vint32m1_t, vint32m8_t, vint32m1_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vredxor_vs_m)))
vint32m1_t vredxor(vbool4_t, vint32m1_t, vint32m8_t, vint32m1_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vredxor_vs)))
vint32m1_t vredxor(vint32m1_t, vint32mf2_t, vint32m1_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vredxor_vs_m)))
vint32m1_t vredxor(vbool64_t, vint32m1_t, vint32mf2_t, vint32m1_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vredxor_vs)))
vuint8m1_t vredxor(vuint8m1_t, vuint8m1_t, vuint8m1_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vredxor_vs_m)))
vuint8m1_t vredxor(vbool8_t, vuint8m1_t, vuint8m1_t, vuint8m1_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vredxor_vs)))
vuint8m1_t vredxor(vuint8m1_t, vuint8m2_t, vuint8m1_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vredxor_vs_m)))
vuint8m1_t vredxor(vbool4_t, vuint8m1_t, vuint8m2_t, vuint8m1_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vredxor_vs)))
vuint8m1_t vredxor(vuint8m1_t, vuint8m4_t, vuint8m1_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vredxor_vs_m)))
vuint8m1_t vredxor(vbool2_t, vuint8m1_t, vuint8m4_t, vuint8m1_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vredxor_vs)))
vuint8m1_t vredxor(vuint8m1_t, vuint8m8_t, vuint8m1_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vredxor_vs_m)))
vuint8m1_t vredxor(vbool1_t, vuint8m1_t, vuint8m8_t, vuint8m1_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vredxor_vs)))
vuint8m1_t vredxor(vuint8m1_t, vuint8mf2_t, vuint8m1_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vredxor_vs_m)))
vuint8m1_t vredxor(vbool16_t, vuint8m1_t, vuint8mf2_t, vuint8m1_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vredxor_vs)))
vuint8m1_t vredxor(vuint8m1_t, vuint8mf4_t, vuint8m1_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vredxor_vs_m)))
vuint8m1_t vredxor(vbool32_t, vuint8m1_t, vuint8mf4_t, vuint8m1_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vredxor_vs)))
vuint8m1_t vredxor(vuint8m1_t, vuint8mf8_t, vuint8m1_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vredxor_vs_m)))
vuint8m1_t vredxor(vbool64_t, vuint8m1_t, vuint8mf8_t, vuint8m1_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vredxor_vs)))
vuint16m1_t vredxor(vuint16m1_t, vuint16m1_t, vuint16m1_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vredxor_vs_m)))
vuint16m1_t vredxor(vbool16_t, vuint16m1_t, vuint16m1_t, vuint16m1_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vredxor_vs)))
vuint16m1_t vredxor(vuint16m1_t, vuint16m2_t, vuint16m1_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vredxor_vs_m)))
vuint16m1_t vredxor(vbool8_t, vuint16m1_t, vuint16m2_t, vuint16m1_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vredxor_vs)))
vuint16m1_t vredxor(vuint16m1_t, vuint16m4_t, vuint16m1_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vredxor_vs_m)))
vuint16m1_t vredxor(vbool4_t, vuint16m1_t, vuint16m4_t, vuint16m1_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vredxor_vs)))
vuint16m1_t vredxor(vuint16m1_t, vuint16m8_t, vuint16m1_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vredxor_vs_m)))
vuint16m1_t vredxor(vbool2_t, vuint16m1_t, vuint16m8_t, vuint16m1_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vredxor_vs)))
vuint16m1_t vredxor(vuint16m1_t, vuint16mf2_t, vuint16m1_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vredxor_vs_m)))
vuint16m1_t vredxor(vbool32_t, vuint16m1_t, vuint16mf2_t, vuint16m1_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vredxor_vs)))
vuint16m1_t vredxor(vuint16m1_t, vuint16mf4_t, vuint16m1_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vredxor_vs_m)))
vuint16m1_t vredxor(vbool64_t, vuint16m1_t, vuint16mf4_t, vuint16m1_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vredxor_vs)))
vuint32m1_t vredxor(vuint32m1_t, vuint32m1_t, vuint32m1_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vredxor_vs_m)))
vuint32m1_t vredxor(vbool32_t, vuint32m1_t, vuint32m1_t, vuint32m1_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vredxor_vs)))
vuint32m1_t vredxor(vuint32m1_t, vuint32m2_t, vuint32m1_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vredxor_vs_m)))
vuint32m1_t vredxor(vbool16_t, vuint32m1_t, vuint32m2_t, vuint32m1_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vredxor_vs)))
vuint32m1_t vredxor(vuint32m1_t, vuint32m4_t, vuint32m1_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vredxor_vs_m)))
vuint32m1_t vredxor(vbool8_t, vuint32m1_t, vuint32m4_t, vuint32m1_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vredxor_vs)))
vuint32m1_t vredxor(vuint32m1_t, vuint32m8_t, vuint32m1_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vredxor_vs_m)))
vuint32m1_t vredxor(vbool4_t, vuint32m1_t, vuint32m8_t, vuint32m1_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vredxor_vs)))
vuint32m1_t vredxor(vuint32m1_t, vuint32mf2_t, vuint32m1_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vredxor_vs_m)))
vuint32m1_t vredxor(vbool64_t, vuint32m1_t, vuint32mf2_t, vuint32m1_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vwredsum_vs)))
vint16m1_t vwredsum(vint16m1_t, vint8m1_t, vint16m1_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vwredsum_vs_m)))
vint16m1_t vwredsum(vbool8_t, vint16m1_t, vint8m1_t, vint16m1_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vwredsum_vs)))
vint16m1_t vwredsum(vint16m1_t, vint8m2_t, vint16m1_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vwredsum_vs_m)))
vint16m1_t vwredsum(vbool4_t, vint16m1_t, vint8m2_t, vint16m1_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vwredsum_vs)))
vint16m1_t vwredsum(vint16m1_t, vint8m4_t, vint16m1_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vwredsum_vs_m)))
vint16m1_t vwredsum(vbool2_t, vint16m1_t, vint8m4_t, vint16m1_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vwredsum_vs)))
vint16m1_t vwredsum(vint16m1_t, vint8m8_t, vint16m1_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vwredsum_vs_m)))
vint16m1_t vwredsum(vbool1_t, vint16m1_t, vint8m8_t, vint16m1_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vwredsum_vs)))
vint16m1_t vwredsum(vint16m1_t, vint8mf2_t, vint16m1_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vwredsum_vs_m)))
vint16m1_t vwredsum(vbool16_t, vint16m1_t, vint8mf2_t, vint16m1_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vwredsum_vs)))
vint16m1_t vwredsum(vint16m1_t, vint8mf4_t, vint16m1_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vwredsum_vs_m)))
vint16m1_t vwredsum(vbool32_t, vint16m1_t, vint8mf4_t, vint16m1_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vwredsum_vs)))
vint16m1_t vwredsum(vint16m1_t, vint8mf8_t, vint16m1_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vwredsum_vs_m)))
vint16m1_t vwredsum(vbool64_t, vint16m1_t, vint8mf8_t, vint16m1_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vwredsum_vs)))
vint32m1_t vwredsum(vint32m1_t, vint16m1_t, vint32m1_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vwredsum_vs_m)))
vint32m1_t vwredsum(vbool16_t, vint32m1_t, vint16m1_t, vint32m1_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vwredsum_vs)))
vint32m1_t vwredsum(vint32m1_t, vint16m2_t, vint32m1_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vwredsum_vs_m)))
vint32m1_t vwredsum(vbool8_t, vint32m1_t, vint16m2_t, vint32m1_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vwredsum_vs)))
vint32m1_t vwredsum(vint32m1_t, vint16m4_t, vint32m1_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vwredsum_vs_m)))
vint32m1_t vwredsum(vbool4_t, vint32m1_t, vint16m4_t, vint32m1_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vwredsum_vs)))
vint32m1_t vwredsum(vint32m1_t, vint16m8_t, vint32m1_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vwredsum_vs_m)))
vint32m1_t vwredsum(vbool2_t, vint32m1_t, vint16m8_t, vint32m1_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vwredsum_vs)))
vint32m1_t vwredsum(vint32m1_t, vint16mf2_t, vint32m1_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vwredsum_vs_m)))
vint32m1_t vwredsum(vbool32_t, vint32m1_t, vint16mf2_t, vint32m1_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vwredsum_vs)))
vint32m1_t vwredsum(vint32m1_t, vint16mf4_t, vint32m1_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vwredsum_vs_m)))
vint32m1_t vwredsum(vbool64_t, vint32m1_t, vint16mf4_t, vint32m1_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vwredsumu_vs)))
vuint16m1_t vwredsumu(vuint16m1_t, vuint8m1_t, vuint16m1_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vwredsumu_vs_m)))
vuint16m1_t vwredsumu(vbool8_t, vuint16m1_t, vuint8m1_t, vuint16m1_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vwredsumu_vs)))
vuint16m1_t vwredsumu(vuint16m1_t, vuint8m2_t, vuint16m1_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vwredsumu_vs_m)))
vuint16m1_t vwredsumu(vbool4_t, vuint16m1_t, vuint8m2_t, vuint16m1_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vwredsumu_vs)))
vuint16m1_t vwredsumu(vuint16m1_t, vuint8m4_t, vuint16m1_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vwredsumu_vs_m)))
vuint16m1_t vwredsumu(vbool2_t, vuint16m1_t, vuint8m4_t, vuint16m1_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vwredsumu_vs)))
vuint16m1_t vwredsumu(vuint16m1_t, vuint8m8_t, vuint16m1_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vwredsumu_vs_m)))
vuint16m1_t vwredsumu(vbool1_t, vuint16m1_t, vuint8m8_t, vuint16m1_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vwredsumu_vs)))
vuint16m1_t vwredsumu(vuint16m1_t, vuint8mf2_t, vuint16m1_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vwredsumu_vs_m)))
vuint16m1_t vwredsumu(vbool16_t, vuint16m1_t, vuint8mf2_t, vuint16m1_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vwredsumu_vs)))
vuint16m1_t vwredsumu(vuint16m1_t, vuint8mf4_t, vuint16m1_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vwredsumu_vs_m)))
vuint16m1_t vwredsumu(vbool32_t, vuint16m1_t, vuint8mf4_t, vuint16m1_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vwredsumu_vs)))
vuint16m1_t vwredsumu(vuint16m1_t, vuint8mf8_t, vuint16m1_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vwredsumu_vs_m)))
vuint16m1_t vwredsumu(vbool64_t, vuint16m1_t, vuint8mf8_t, vuint16m1_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vwredsumu_vs)))
vuint32m1_t vwredsumu(vuint32m1_t, vuint16m1_t, vuint32m1_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vwredsumu_vs_m)))
vuint32m1_t vwredsumu(vbool16_t, vuint32m1_t, vuint16m1_t, vuint32m1_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vwredsumu_vs)))
vuint32m1_t vwredsumu(vuint32m1_t, vuint16m2_t, vuint32m1_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vwredsumu_vs_m)))
vuint32m1_t vwredsumu(vbool8_t, vuint32m1_t, vuint16m2_t, vuint32m1_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vwredsumu_vs)))
vuint32m1_t vwredsumu(vuint32m1_t, vuint16m4_t, vuint32m1_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vwredsumu_vs_m)))
vuint32m1_t vwredsumu(vbool4_t, vuint32m1_t, vuint16m4_t, vuint32m1_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vwredsumu_vs)))
vuint32m1_t vwredsumu(vuint32m1_t, vuint16m8_t, vuint32m1_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vwredsumu_vs_m)))
vuint32m1_t vwredsumu(vbool2_t, vuint32m1_t, vuint16m8_t, vuint32m1_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vwredsumu_vs)))
vuint32m1_t vwredsumu(vuint32m1_t, vuint16mf2_t, vuint32m1_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vwredsumu_vs_m)))
vuint32m1_t vwredsumu(vbool32_t, vuint32m1_t, vuint16mf2_t, vuint32m1_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vwredsumu_vs)))
vuint32m1_t vwredsumu(vuint32m1_t, vuint16mf4_t, vuint32m1_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vwredsumu_vs_m)))
vuint32m1_t vwredsumu(vbool64_t, vuint32m1_t, vuint16mf4_t, vuint32m1_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vmnot_m)))
vbool8_t vmnot(vbool8_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vmnot_m)))
vbool4_t vmnot(vbool4_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vmnot_m)))
vbool2_t vmnot(vbool2_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vmnot_m)))
vbool1_t vmnot(vbool1_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vmnot_m)))
vbool16_t vmnot(vbool16_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vmnot_m)))
vbool32_t vmnot(vbool32_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vmnot_m)))
vbool64_t vmnot(vbool64_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_viota_m_m)))
vuint8m1_t viota(vbool8_t, vuint8m1_t, vbool8_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_viota_m_m)))
vuint8m2_t viota(vbool4_t, vuint8m2_t, vbool4_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_viota_m_m)))
vuint8m4_t viota(vbool2_t, vuint8m4_t, vbool2_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_viota_m_m)))
vuint8m8_t viota(vbool1_t, vuint8m8_t, vbool1_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_viota_m_m)))
vuint8mf2_t viota(vbool16_t, vuint8mf2_t, vbool16_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_viota_m_m)))
vuint8mf4_t viota(vbool32_t, vuint8mf4_t, vbool32_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_viota_m_m)))
vuint8mf8_t viota(vbool64_t, vuint8mf8_t, vbool64_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_viota_m_m)))
vuint16m1_t viota(vbool16_t, vuint16m1_t, vbool16_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_viota_m_m)))
vuint16m2_t viota(vbool8_t, vuint16m2_t, vbool8_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_viota_m_m)))
vuint16m4_t viota(vbool4_t, vuint16m4_t, vbool4_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_viota_m_m)))
vuint16m8_t viota(vbool2_t, vuint16m8_t, vbool2_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_viota_m_m)))
vuint16mf2_t viota(vbool32_t, vuint16mf2_t, vbool32_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_viota_m_m)))
vuint16mf4_t viota(vbool64_t, vuint16mf4_t, vbool64_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_viota_m_m)))
vuint32m1_t viota(vbool32_t, vuint32m1_t, vbool32_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_viota_m_m)))
vuint32m2_t viota(vbool16_t, vuint32m2_t, vbool16_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_viota_m_m)))
vuint32m4_t viota(vbool8_t, vuint32m4_t, vbool8_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_viota_m_m)))
vuint32m8_t viota(vbool4_t, vuint32m8_t, vbool4_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_viota_m_m)))
vuint32mf2_t viota(vbool64_t, vuint32mf2_t, vbool64_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vid_v_m)))
vint8m1_t vid(vbool8_t, vint8m1_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vid_v_m)))
vint8m2_t vid(vbool4_t, vint8m2_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vid_v_m)))
vint8m4_t vid(vbool2_t, vint8m4_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vid_v_m)))
vint8m8_t vid(vbool1_t, vint8m8_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vid_v_m)))
vint8mf2_t vid(vbool16_t, vint8mf2_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vid_v_m)))
vint8mf4_t vid(vbool32_t, vint8mf4_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vid_v_m)))
vint8mf8_t vid(vbool64_t, vint8mf8_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vid_v_m)))
vint16m1_t vid(vbool16_t, vint16m1_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vid_v_m)))
vint16m2_t vid(vbool8_t, vint16m2_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vid_v_m)))
vint16m4_t vid(vbool4_t, vint16m4_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vid_v_m)))
vint16m8_t vid(vbool2_t, vint16m8_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vid_v_m)))
vint16mf2_t vid(vbool32_t, vint16mf2_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vid_v_m)))
vint16mf4_t vid(vbool64_t, vint16mf4_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vid_v_m)))
vint32m1_t vid(vbool32_t, vint32m1_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vid_v_m)))
vint32m2_t vid(vbool16_t, vint32m2_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vid_v_m)))
vint32m4_t vid(vbool8_t, vint32m4_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vid_v_m)))
vint32m8_t vid(vbool4_t, vint32m8_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vid_v_m)))
vint32mf2_t vid(vbool64_t, vint32mf2_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vid_v_m)))
vuint8m1_t vid(vbool8_t, vuint8m1_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vid_v_m)))
vuint8m2_t vid(vbool4_t, vuint8m2_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vid_v_m)))
vuint8m4_t vid(vbool2_t, vuint8m4_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vid_v_m)))
vuint8m8_t vid(vbool1_t, vuint8m8_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vid_v_m)))
vuint8mf2_t vid(vbool16_t, vuint8mf2_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vid_v_m)))
vuint8mf4_t vid(vbool32_t, vuint8mf4_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vid_v_m)))
vuint8mf8_t vid(vbool64_t, vuint8mf8_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vid_v_m)))
vuint16m1_t vid(vbool16_t, vuint16m1_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vid_v_m)))
vuint16m2_t vid(vbool8_t, vuint16m2_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vid_v_m)))
vuint16m4_t vid(vbool4_t, vuint16m4_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vid_v_m)))
vuint16m8_t vid(vbool2_t, vuint16m8_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vid_v_m)))
vuint16mf2_t vid(vbool32_t, vuint16mf2_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vid_v_m)))
vuint16mf4_t vid(vbool64_t, vuint16mf4_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vid_v_m)))
vuint32m1_t vid(vbool32_t, vuint32m1_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vid_v_m)))
vuint32m2_t vid(vbool16_t, vuint32m2_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vid_v_m)))
vuint32m4_t vid(vbool8_t, vuint32m4_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vid_v_m)))
vuint32m8_t vid(vbool4_t, vuint32m8_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vid_v_m)))
vuint32mf2_t vid(vbool64_t, vuint32mf2_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vmv_x_s)))
int8_t vmv_x(vint8m1_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vmv_x_s)))
int8_t vmv_x(vint8m2_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vmv_x_s)))
int8_t vmv_x(vint8m4_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vmv_x_s)))
int8_t vmv_x(vint8m8_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vmv_x_s)))
int8_t vmv_x(vint8mf2_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vmv_x_s)))
int8_t vmv_x(vint8mf4_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vmv_x_s)))
int8_t vmv_x(vint8mf8_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vmv_x_s)))
int16_t vmv_x(vint16m1_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vmv_x_s)))
int16_t vmv_x(vint16m2_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vmv_x_s)))
int16_t vmv_x(vint16m4_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vmv_x_s)))
int16_t vmv_x(vint16m8_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vmv_x_s)))
int16_t vmv_x(vint16mf2_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vmv_x_s)))
int16_t vmv_x(vint16mf4_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vmv_x_s)))
int32_t vmv_x(vint32m1_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vmv_x_s)))
int32_t vmv_x(vint32m2_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vmv_x_s)))
int32_t vmv_x(vint32m4_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vmv_x_s)))
int32_t vmv_x(vint32m8_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vmv_x_s)))
int32_t vmv_x(vint32mf2_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vmv_x_s)))
uint8_t vmv_x(vuint8m1_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vmv_x_s)))
uint8_t vmv_x(vuint8m2_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vmv_x_s)))
uint8_t vmv_x(vuint8m4_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vmv_x_s)))
uint8_t vmv_x(vuint8m8_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vmv_x_s)))
uint8_t vmv_x(vuint8mf2_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vmv_x_s)))
uint8_t vmv_x(vuint8mf4_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vmv_x_s)))
uint8_t vmv_x(vuint8mf8_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vmv_x_s)))
uint16_t vmv_x(vuint16m1_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vmv_x_s)))
uint16_t vmv_x(vuint16m2_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vmv_x_s)))
uint16_t vmv_x(vuint16m4_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vmv_x_s)))
uint16_t vmv_x(vuint16m8_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vmv_x_s)))
uint16_t vmv_x(vuint16mf2_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vmv_x_s)))
uint16_t vmv_x(vuint16mf4_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vmv_x_s)))
uint32_t vmv_x(vuint32m1_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vmv_x_s)))
uint32_t vmv_x(vuint32m2_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vmv_x_s)))
uint32_t vmv_x(vuint32m4_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vmv_x_s)))
uint32_t vmv_x(vuint32m8_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vmv_x_s)))
uint32_t vmv_x(vuint32mf2_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vmv_s_x)))
vint8m1_t vmv_s(vint8m1_t, int8_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vmv_s_x)))
vint8m2_t vmv_s(vint8m2_t, int8_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vmv_s_x)))
vint8m4_t vmv_s(vint8m4_t, int8_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vmv_s_x)))
vint8m8_t vmv_s(vint8m8_t, int8_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vmv_s_x)))
vint8mf2_t vmv_s(vint8mf2_t, int8_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vmv_s_x)))
vint8mf4_t vmv_s(vint8mf4_t, int8_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vmv_s_x)))
vint8mf8_t vmv_s(vint8mf8_t, int8_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vmv_s_x)))
vint16m1_t vmv_s(vint16m1_t, int16_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vmv_s_x)))
vint16m2_t vmv_s(vint16m2_t, int16_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vmv_s_x)))
vint16m4_t vmv_s(vint16m4_t, int16_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vmv_s_x)))
vint16m8_t vmv_s(vint16m8_t, int16_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vmv_s_x)))
vint16mf2_t vmv_s(vint16mf2_t, int16_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vmv_s_x)))
vint16mf4_t vmv_s(vint16mf4_t, int16_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vmv_s_x)))
vint32m1_t vmv_s(vint32m1_t, int32_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vmv_s_x)))
vint32m2_t vmv_s(vint32m2_t, int32_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vmv_s_x)))
vint32m4_t vmv_s(vint32m4_t, int32_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vmv_s_x)))
vint32m8_t vmv_s(vint32m8_t, int32_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vmv_s_x)))
vint32mf2_t vmv_s(vint32mf2_t, int32_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vmv_s_x)))
vuint8m1_t vmv_s(vuint8m1_t, uint8_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vmv_s_x)))
vuint8m2_t vmv_s(vuint8m2_t, uint8_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vmv_s_x)))
vuint8m4_t vmv_s(vuint8m4_t, uint8_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vmv_s_x)))
vuint8m8_t vmv_s(vuint8m8_t, uint8_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vmv_s_x)))
vuint8mf2_t vmv_s(vuint8mf2_t, uint8_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vmv_s_x)))
vuint8mf4_t vmv_s(vuint8mf4_t, uint8_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vmv_s_x)))
vuint8mf8_t vmv_s(vuint8mf8_t, uint8_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vmv_s_x)))
vuint16m1_t vmv_s(vuint16m1_t, uint16_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vmv_s_x)))
vuint16m2_t vmv_s(vuint16m2_t, uint16_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vmv_s_x)))
vuint16m4_t vmv_s(vuint16m4_t, uint16_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vmv_s_x)))
vuint16m8_t vmv_s(vuint16m8_t, uint16_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vmv_s_x)))
vuint16mf2_t vmv_s(vuint16mf2_t, uint16_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vmv_s_x)))
vuint16mf4_t vmv_s(vuint16mf4_t, uint16_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vmv_s_x)))
vuint32m1_t vmv_s(vuint32m1_t, uint32_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vmv_s_x)))
vuint32m2_t vmv_s(vuint32m2_t, uint32_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vmv_s_x)))
vuint32m4_t vmv_s(vuint32m4_t, uint32_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vmv_s_x)))
vuint32m8_t vmv_s(vuint32m8_t, uint32_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vmv_s_x)))
vuint32mf2_t vmv_s(vuint32mf2_t, uint32_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vfmv_s_x)))
vuint16m1_t vfmv_s(vuint16m1_t, uint16_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vfmv_s_x)))
vuint16m2_t vfmv_s(vuint16m2_t, uint16_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vfmv_s_x)))
vuint16m4_t vfmv_s(vuint16m4_t, uint16_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vfmv_s_x)))
vuint16m8_t vfmv_s(vuint16m8_t, uint16_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vfmv_s_x)))
vuint16mf2_t vfmv_s(vuint16mf2_t, uint16_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vfmv_s_x)))
vuint16mf4_t vfmv_s(vuint16mf4_t, uint16_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vfmv_s_x)))
vuint32m1_t vfmv_s(vuint32m1_t, uint32_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vfmv_s_x)))
vuint32m2_t vfmv_s(vuint32m2_t, uint32_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vfmv_s_x)))
vuint32m4_t vfmv_s(vuint32m4_t, uint32_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vfmv_s_x)))
vuint32m8_t vfmv_s(vuint32m8_t, uint32_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vfmv_s_x)))
vuint32mf2_t vfmv_s(vuint32mf2_t, uint32_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vslideup_vx)))
vint8m1_t vslideup(vint8m1_t, vint8m1_t, size_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vslideup_vx_m)))
vint8m1_t vslideup(vbool8_t, vint8m1_t, vint8m1_t, size_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vslideup_vx)))
vint8m2_t vslideup(vint8m2_t, vint8m2_t, size_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vslideup_vx_m)))
vint8m2_t vslideup(vbool4_t, vint8m2_t, vint8m2_t, size_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vslideup_vx)))
vint8m4_t vslideup(vint8m4_t, vint8m4_t, size_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vslideup_vx_m)))
vint8m4_t vslideup(vbool2_t, vint8m4_t, vint8m4_t, size_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vslideup_vx)))
vint8m8_t vslideup(vint8m8_t, vint8m8_t, size_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vslideup_vx_m)))
vint8m8_t vslideup(vbool1_t, vint8m8_t, vint8m8_t, size_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vslideup_vx)))
vint8mf2_t vslideup(vint8mf2_t, vint8mf2_t, size_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vslideup_vx_m)))
vint8mf2_t vslideup(vbool16_t, vint8mf2_t, vint8mf2_t, size_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vslideup_vx)))
vint8mf4_t vslideup(vint8mf4_t, vint8mf4_t, size_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vslideup_vx_m)))
vint8mf4_t vslideup(vbool32_t, vint8mf4_t, vint8mf4_t, size_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vslideup_vx)))
vint8mf8_t vslideup(vint8mf8_t, vint8mf8_t, size_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vslideup_vx_m)))
vint8mf8_t vslideup(vbool64_t, vint8mf8_t, vint8mf8_t, size_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vslideup_vx)))
vint16m1_t vslideup(vint16m1_t, vint16m1_t, size_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vslideup_vx_m)))
vint16m1_t vslideup(vbool16_t, vint16m1_t, vint16m1_t, size_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vslideup_vx)))
vint16m2_t vslideup(vint16m2_t, vint16m2_t, size_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vslideup_vx_m)))
vint16m2_t vslideup(vbool8_t, vint16m2_t, vint16m2_t, size_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vslideup_vx)))
vint16m4_t vslideup(vint16m4_t, vint16m4_t, size_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vslideup_vx_m)))
vint16m4_t vslideup(vbool4_t, vint16m4_t, vint16m4_t, size_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vslideup_vx)))
vint16m8_t vslideup(vint16m8_t, vint16m8_t, size_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vslideup_vx_m)))
vint16m8_t vslideup(vbool2_t, vint16m8_t, vint16m8_t, size_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vslideup_vx)))
vint16mf2_t vslideup(vint16mf2_t, vint16mf2_t, size_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vslideup_vx_m)))
vint16mf2_t vslideup(vbool32_t, vint16mf2_t, vint16mf2_t, size_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vslideup_vx)))
vint16mf4_t vslideup(vint16mf4_t, vint16mf4_t, size_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vslideup_vx_m)))
vint16mf4_t vslideup(vbool64_t, vint16mf4_t, vint16mf4_t, size_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vslideup_vx)))
vint32m1_t vslideup(vint32m1_t, vint32m1_t, size_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vslideup_vx_m)))
vint32m1_t vslideup(vbool32_t, vint32m1_t, vint32m1_t, size_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vslideup_vx)))
vint32m2_t vslideup(vint32m2_t, vint32m2_t, size_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vslideup_vx_m)))
vint32m2_t vslideup(vbool16_t, vint32m2_t, vint32m2_t, size_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vslideup_vx)))
vint32m4_t vslideup(vint32m4_t, vint32m4_t, size_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vslideup_vx_m)))
vint32m4_t vslideup(vbool8_t, vint32m4_t, vint32m4_t, size_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vslideup_vx)))
vint32m8_t vslideup(vint32m8_t, vint32m8_t, size_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vslideup_vx_m)))
vint32m8_t vslideup(vbool4_t, vint32m8_t, vint32m8_t, size_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vslideup_vx)))
vint32mf2_t vslideup(vint32mf2_t, vint32mf2_t, size_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vslideup_vx_m)))
vint32mf2_t vslideup(vbool64_t, vint32mf2_t, vint32mf2_t, size_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vslideup_vx)))
vuint8m1_t vslideup(vuint8m1_t, vuint8m1_t, size_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vslideup_vx_m)))
vuint8m1_t vslideup(vbool8_t, vuint8m1_t, vuint8m1_t, size_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vslideup_vx)))
vuint8m2_t vslideup(vuint8m2_t, vuint8m2_t, size_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vslideup_vx_m)))
vuint8m2_t vslideup(vbool4_t, vuint8m2_t, vuint8m2_t, size_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vslideup_vx)))
vuint8m4_t vslideup(vuint8m4_t, vuint8m4_t, size_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vslideup_vx_m)))
vuint8m4_t vslideup(vbool2_t, vuint8m4_t, vuint8m4_t, size_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vslideup_vx)))
vuint8m8_t vslideup(vuint8m8_t, vuint8m8_t, size_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vslideup_vx_m)))
vuint8m8_t vslideup(vbool1_t, vuint8m8_t, vuint8m8_t, size_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vslideup_vx)))
vuint8mf2_t vslideup(vuint8mf2_t, vuint8mf2_t, size_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vslideup_vx_m)))
vuint8mf2_t vslideup(vbool16_t, vuint8mf2_t, vuint8mf2_t, size_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vslideup_vx)))
vuint8mf4_t vslideup(vuint8mf4_t, vuint8mf4_t, size_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vslideup_vx_m)))
vuint8mf4_t vslideup(vbool32_t, vuint8mf4_t, vuint8mf4_t, size_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vslideup_vx)))
vuint8mf8_t vslideup(vuint8mf8_t, vuint8mf8_t, size_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vslideup_vx_m)))
vuint8mf8_t vslideup(vbool64_t, vuint8mf8_t, vuint8mf8_t, size_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vslideup_vx)))
vuint16m1_t vslideup(vuint16m1_t, vuint16m1_t, size_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vslideup_vx_m)))
vuint16m1_t vslideup(vbool16_t, vuint16m1_t, vuint16m1_t, size_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vslideup_vx)))
vuint16m2_t vslideup(vuint16m2_t, vuint16m2_t, size_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vslideup_vx_m)))
vuint16m2_t vslideup(vbool8_t, vuint16m2_t, vuint16m2_t, size_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vslideup_vx)))
vuint16m4_t vslideup(vuint16m4_t, vuint16m4_t, size_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vslideup_vx_m)))
vuint16m4_t vslideup(vbool4_t, vuint16m4_t, vuint16m4_t, size_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vslideup_vx)))
vuint16m8_t vslideup(vuint16m8_t, vuint16m8_t, size_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vslideup_vx_m)))
vuint16m8_t vslideup(vbool2_t, vuint16m8_t, vuint16m8_t, size_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vslideup_vx)))
vuint16mf2_t vslideup(vuint16mf2_t, vuint16mf2_t, size_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vslideup_vx_m)))
vuint16mf2_t vslideup(vbool32_t, vuint16mf2_t, vuint16mf2_t, size_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vslideup_vx)))
vuint16mf4_t vslideup(vuint16mf4_t, vuint16mf4_t, size_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vslideup_vx_m)))
vuint16mf4_t vslideup(vbool64_t, vuint16mf4_t, vuint16mf4_t, size_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vslideup_vx)))
vuint32m1_t vslideup(vuint32m1_t, vuint32m1_t, size_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vslideup_vx_m)))
vuint32m1_t vslideup(vbool32_t, vuint32m1_t, vuint32m1_t, size_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vslideup_vx)))
vuint32m2_t vslideup(vuint32m2_t, vuint32m2_t, size_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vslideup_vx_m)))
vuint32m2_t vslideup(vbool16_t, vuint32m2_t, vuint32m2_t, size_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vslideup_vx)))
vuint32m4_t vslideup(vuint32m4_t, vuint32m4_t, size_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vslideup_vx_m)))
vuint32m4_t vslideup(vbool8_t, vuint32m4_t, vuint32m4_t, size_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vslideup_vx)))
vuint32m8_t vslideup(vuint32m8_t, vuint32m8_t, size_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vslideup_vx_m)))
vuint32m8_t vslideup(vbool4_t, vuint32m8_t, vuint32m8_t, size_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vslideup_vx)))
vuint32mf2_t vslideup(vuint32mf2_t, vuint32mf2_t, size_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vslideup_vx_m)))
vuint32mf2_t vslideup(vbool64_t, vuint32mf2_t, vuint32mf2_t, size_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vslidedown_vx)))
vint8m1_t vslidedown(vint8m1_t, vint8m1_t, size_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vslidedown_vx_m)))
vint8m1_t vslidedown(vbool8_t, vint8m1_t, vint8m1_t, size_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vslidedown_vx)))
vint8m2_t vslidedown(vint8m2_t, vint8m2_t, size_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vslidedown_vx_m)))
vint8m2_t vslidedown(vbool4_t, vint8m2_t, vint8m2_t, size_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vslidedown_vx)))
vint8m4_t vslidedown(vint8m4_t, vint8m4_t, size_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vslidedown_vx_m)))
vint8m4_t vslidedown(vbool2_t, vint8m4_t, vint8m4_t, size_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vslidedown_vx)))
vint8m8_t vslidedown(vint8m8_t, vint8m8_t, size_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vslidedown_vx_m)))
vint8m8_t vslidedown(vbool1_t, vint8m8_t, vint8m8_t, size_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vslidedown_vx)))
vint8mf2_t vslidedown(vint8mf2_t, vint8mf2_t, size_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vslidedown_vx_m)))
vint8mf2_t vslidedown(vbool16_t, vint8mf2_t, vint8mf2_t, size_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vslidedown_vx)))
vint8mf4_t vslidedown(vint8mf4_t, vint8mf4_t, size_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vslidedown_vx_m)))
vint8mf4_t vslidedown(vbool32_t, vint8mf4_t, vint8mf4_t, size_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vslidedown_vx)))
vint8mf8_t vslidedown(vint8mf8_t, vint8mf8_t, size_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vslidedown_vx_m)))
vint8mf8_t vslidedown(vbool64_t, vint8mf8_t, vint8mf8_t, size_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vslidedown_vx)))
vint16m1_t vslidedown(vint16m1_t, vint16m1_t, size_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vslidedown_vx_m)))
vint16m1_t vslidedown(vbool16_t, vint16m1_t, vint16m1_t, size_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vslidedown_vx)))
vint16m2_t vslidedown(vint16m2_t, vint16m2_t, size_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vslidedown_vx_m)))
vint16m2_t vslidedown(vbool8_t, vint16m2_t, vint16m2_t, size_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vslidedown_vx)))
vint16m4_t vslidedown(vint16m4_t, vint16m4_t, size_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vslidedown_vx_m)))
vint16m4_t vslidedown(vbool4_t, vint16m4_t, vint16m4_t, size_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vslidedown_vx)))
vint16m8_t vslidedown(vint16m8_t, vint16m8_t, size_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vslidedown_vx_m)))
vint16m8_t vslidedown(vbool2_t, vint16m8_t, vint16m8_t, size_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vslidedown_vx)))
vint16mf2_t vslidedown(vint16mf2_t, vint16mf2_t, size_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vslidedown_vx_m)))
vint16mf2_t vslidedown(vbool32_t, vint16mf2_t, vint16mf2_t, size_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vslidedown_vx)))
vint16mf4_t vslidedown(vint16mf4_t, vint16mf4_t, size_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vslidedown_vx_m)))
vint16mf4_t vslidedown(vbool64_t, vint16mf4_t, vint16mf4_t, size_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vslidedown_vx)))
vint32m1_t vslidedown(vint32m1_t, vint32m1_t, size_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vslidedown_vx_m)))
vint32m1_t vslidedown(vbool32_t, vint32m1_t, vint32m1_t, size_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vslidedown_vx)))
vint32m2_t vslidedown(vint32m2_t, vint32m2_t, size_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vslidedown_vx_m)))
vint32m2_t vslidedown(vbool16_t, vint32m2_t, vint32m2_t, size_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vslidedown_vx)))
vint32m4_t vslidedown(vint32m4_t, vint32m4_t, size_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vslidedown_vx_m)))
vint32m4_t vslidedown(vbool8_t, vint32m4_t, vint32m4_t, size_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vslidedown_vx)))
vint32m8_t vslidedown(vint32m8_t, vint32m8_t, size_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vslidedown_vx_m)))
vint32m8_t vslidedown(vbool4_t, vint32m8_t, vint32m8_t, size_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vslidedown_vx)))
vint32mf2_t vslidedown(vint32mf2_t, vint32mf2_t, size_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vslidedown_vx_m)))
vint32mf2_t vslidedown(vbool64_t, vint32mf2_t, vint32mf2_t, size_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vslidedown_vx)))
vuint8m1_t vslidedown(vuint8m1_t, vuint8m1_t, size_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vslidedown_vx_m)))
vuint8m1_t vslidedown(vbool8_t, vuint8m1_t, vuint8m1_t, size_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vslidedown_vx)))
vuint8m2_t vslidedown(vuint8m2_t, vuint8m2_t, size_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vslidedown_vx_m)))
vuint8m2_t vslidedown(vbool4_t, vuint8m2_t, vuint8m2_t, size_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vslidedown_vx)))
vuint8m4_t vslidedown(vuint8m4_t, vuint8m4_t, size_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vslidedown_vx_m)))
vuint8m4_t vslidedown(vbool2_t, vuint8m4_t, vuint8m4_t, size_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vslidedown_vx)))
vuint8m8_t vslidedown(vuint8m8_t, vuint8m8_t, size_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vslidedown_vx_m)))
vuint8m8_t vslidedown(vbool1_t, vuint8m8_t, vuint8m8_t, size_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vslidedown_vx)))
vuint8mf2_t vslidedown(vuint8mf2_t, vuint8mf2_t, size_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vslidedown_vx_m)))
vuint8mf2_t vslidedown(vbool16_t, vuint8mf2_t, vuint8mf2_t, size_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vslidedown_vx)))
vuint8mf4_t vslidedown(vuint8mf4_t, vuint8mf4_t, size_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vslidedown_vx_m)))
vuint8mf4_t vslidedown(vbool32_t, vuint8mf4_t, vuint8mf4_t, size_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vslidedown_vx)))
vuint8mf8_t vslidedown(vuint8mf8_t, vuint8mf8_t, size_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vslidedown_vx_m)))
vuint8mf8_t vslidedown(vbool64_t, vuint8mf8_t, vuint8mf8_t, size_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vslidedown_vx)))
vuint16m1_t vslidedown(vuint16m1_t, vuint16m1_t, size_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vslidedown_vx_m)))
vuint16m1_t vslidedown(vbool16_t, vuint16m1_t, vuint16m1_t, size_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vslidedown_vx)))
vuint16m2_t vslidedown(vuint16m2_t, vuint16m2_t, size_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vslidedown_vx_m)))
vuint16m2_t vslidedown(vbool8_t, vuint16m2_t, vuint16m2_t, size_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vslidedown_vx)))
vuint16m4_t vslidedown(vuint16m4_t, vuint16m4_t, size_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vslidedown_vx_m)))
vuint16m4_t vslidedown(vbool4_t, vuint16m4_t, vuint16m4_t, size_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vslidedown_vx)))
vuint16m8_t vslidedown(vuint16m8_t, vuint16m8_t, size_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vslidedown_vx_m)))
vuint16m8_t vslidedown(vbool2_t, vuint16m8_t, vuint16m8_t, size_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vslidedown_vx)))
vuint16mf2_t vslidedown(vuint16mf2_t, vuint16mf2_t, size_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vslidedown_vx_m)))
vuint16mf2_t vslidedown(vbool32_t, vuint16mf2_t, vuint16mf2_t, size_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vslidedown_vx)))
vuint16mf4_t vslidedown(vuint16mf4_t, vuint16mf4_t, size_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vslidedown_vx_m)))
vuint16mf4_t vslidedown(vbool64_t, vuint16mf4_t, vuint16mf4_t, size_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vslidedown_vx)))
vuint32m1_t vslidedown(vuint32m1_t, vuint32m1_t, size_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vslidedown_vx_m)))
vuint32m1_t vslidedown(vbool32_t, vuint32m1_t, vuint32m1_t, size_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vslidedown_vx)))
vuint32m2_t vslidedown(vuint32m2_t, vuint32m2_t, size_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vslidedown_vx_m)))
vuint32m2_t vslidedown(vbool16_t, vuint32m2_t, vuint32m2_t, size_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vslidedown_vx)))
vuint32m4_t vslidedown(vuint32m4_t, vuint32m4_t, size_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vslidedown_vx_m)))
vuint32m4_t vslidedown(vbool8_t, vuint32m4_t, vuint32m4_t, size_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vslidedown_vx)))
vuint32m8_t vslidedown(vuint32m8_t, vuint32m8_t, size_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vslidedown_vx_m)))
vuint32m8_t vslidedown(vbool4_t, vuint32m8_t, vuint32m8_t, size_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vslidedown_vx)))
vuint32mf2_t vslidedown(vuint32mf2_t, vuint32mf2_t, size_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vslidedown_vx_m)))
vuint32mf2_t vslidedown(vbool64_t, vuint32mf2_t, vuint32mf2_t, size_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vslide1up_vx)))
vint8m1_t vslide1up(vint8m1_t, int8_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vslide1up_vx_m)))
vint8m1_t vslide1up(vbool8_t, vint8m1_t, vint8m1_t, int8_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vslide1up_vx)))
vint8m2_t vslide1up(vint8m2_t, int8_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vslide1up_vx_m)))
vint8m2_t vslide1up(vbool4_t, vint8m2_t, vint8m2_t, int8_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vslide1up_vx)))
vint8m4_t vslide1up(vint8m4_t, int8_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vslide1up_vx_m)))
vint8m4_t vslide1up(vbool2_t, vint8m4_t, vint8m4_t, int8_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vslide1up_vx)))
vint8m8_t vslide1up(vint8m8_t, int8_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vslide1up_vx_m)))
vint8m8_t vslide1up(vbool1_t, vint8m8_t, vint8m8_t, int8_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vslide1up_vx)))
vint8mf2_t vslide1up(vint8mf2_t, int8_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vslide1up_vx_m)))
vint8mf2_t vslide1up(vbool16_t, vint8mf2_t, vint8mf2_t, int8_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vslide1up_vx)))
vint8mf4_t vslide1up(vint8mf4_t, int8_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vslide1up_vx_m)))
vint8mf4_t vslide1up(vbool32_t, vint8mf4_t, vint8mf4_t, int8_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vslide1up_vx)))
vint8mf8_t vslide1up(vint8mf8_t, int8_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vslide1up_vx_m)))
vint8mf8_t vslide1up(vbool64_t, vint8mf8_t, vint8mf8_t, int8_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vslide1up_vx)))
vint16m1_t vslide1up(vint16m1_t, int16_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vslide1up_vx_m)))
vint16m1_t vslide1up(vbool16_t, vint16m1_t, vint16m1_t, int16_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vslide1up_vx)))
vint16m2_t vslide1up(vint16m2_t, int16_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vslide1up_vx_m)))
vint16m2_t vslide1up(vbool8_t, vint16m2_t, vint16m2_t, int16_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vslide1up_vx)))
vint16m4_t vslide1up(vint16m4_t, int16_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vslide1up_vx_m)))
vint16m4_t vslide1up(vbool4_t, vint16m4_t, vint16m4_t, int16_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vslide1up_vx)))
vint16m8_t vslide1up(vint16m8_t, int16_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vslide1up_vx_m)))
vint16m8_t vslide1up(vbool2_t, vint16m8_t, vint16m8_t, int16_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vslide1up_vx)))
vint16mf2_t vslide1up(vint16mf2_t, int16_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vslide1up_vx_m)))
vint16mf2_t vslide1up(vbool32_t, vint16mf2_t, vint16mf2_t, int16_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vslide1up_vx)))
vint16mf4_t vslide1up(vint16mf4_t, int16_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vslide1up_vx_m)))
vint16mf4_t vslide1up(vbool64_t, vint16mf4_t, vint16mf4_t, int16_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vslide1up_vx)))
vint32m1_t vslide1up(vint32m1_t, int32_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vslide1up_vx_m)))
vint32m1_t vslide1up(vbool32_t, vint32m1_t, vint32m1_t, int32_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vslide1up_vx)))
vint32m2_t vslide1up(vint32m2_t, int32_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vslide1up_vx_m)))
vint32m2_t vslide1up(vbool16_t, vint32m2_t, vint32m2_t, int32_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vslide1up_vx)))
vint32m4_t vslide1up(vint32m4_t, int32_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vslide1up_vx_m)))
vint32m4_t vslide1up(vbool8_t, vint32m4_t, vint32m4_t, int32_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vslide1up_vx)))
vint32m8_t vslide1up(vint32m8_t, int32_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vslide1up_vx_m)))
vint32m8_t vslide1up(vbool4_t, vint32m8_t, vint32m8_t, int32_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vslide1up_vx)))
vint32mf2_t vslide1up(vint32mf2_t, int32_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vslide1up_vx_m)))
vint32mf2_t vslide1up(vbool64_t, vint32mf2_t, vint32mf2_t, int32_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vslide1up_vx)))
vuint8m1_t vslide1up(vuint8m1_t, int8_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vslide1up_vx_m)))
vuint8m1_t vslide1up(vbool8_t, vuint8m1_t, vuint8m1_t, int8_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vslide1up_vx)))
vuint8m2_t vslide1up(vuint8m2_t, int8_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vslide1up_vx_m)))
vuint8m2_t vslide1up(vbool4_t, vuint8m2_t, vuint8m2_t, int8_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vslide1up_vx)))
vuint8m4_t vslide1up(vuint8m4_t, int8_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vslide1up_vx_m)))
vuint8m4_t vslide1up(vbool2_t, vuint8m4_t, vuint8m4_t, int8_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vslide1up_vx)))
vuint8m8_t vslide1up(vuint8m8_t, int8_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vslide1up_vx_m)))
vuint8m8_t vslide1up(vbool1_t, vuint8m8_t, vuint8m8_t, int8_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vslide1up_vx)))
vuint8mf2_t vslide1up(vuint8mf2_t, int8_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vslide1up_vx_m)))
vuint8mf2_t vslide1up(vbool16_t, vuint8mf2_t, vuint8mf2_t, int8_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vslide1up_vx)))
vuint8mf4_t vslide1up(vuint8mf4_t, int8_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vslide1up_vx_m)))
vuint8mf4_t vslide1up(vbool32_t, vuint8mf4_t, vuint8mf4_t, int8_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vslide1up_vx)))
vuint8mf8_t vslide1up(vuint8mf8_t, int8_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vslide1up_vx_m)))
vuint8mf8_t vslide1up(vbool64_t, vuint8mf8_t, vuint8mf8_t, int8_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vslide1up_vx)))
vuint16m1_t vslide1up(vuint16m1_t, int16_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vslide1up_vx_m)))
vuint16m1_t vslide1up(vbool16_t, vuint16m1_t, vuint16m1_t, int16_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vslide1up_vx)))
vuint16m2_t vslide1up(vuint16m2_t, int16_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vslide1up_vx_m)))
vuint16m2_t vslide1up(vbool8_t, vuint16m2_t, vuint16m2_t, int16_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vslide1up_vx)))
vuint16m4_t vslide1up(vuint16m4_t, int16_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vslide1up_vx_m)))
vuint16m4_t vslide1up(vbool4_t, vuint16m4_t, vuint16m4_t, int16_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vslide1up_vx)))
vuint16m8_t vslide1up(vuint16m8_t, int16_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vslide1up_vx_m)))
vuint16m8_t vslide1up(vbool2_t, vuint16m8_t, vuint16m8_t, int16_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vslide1up_vx)))
vuint16mf2_t vslide1up(vuint16mf2_t, int16_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vslide1up_vx_m)))
vuint16mf2_t vslide1up(vbool32_t, vuint16mf2_t, vuint16mf2_t, int16_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vslide1up_vx)))
vuint16mf4_t vslide1up(vuint16mf4_t, int16_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vslide1up_vx_m)))
vuint16mf4_t vslide1up(vbool64_t, vuint16mf4_t, vuint16mf4_t, int16_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vslide1up_vx)))
vuint32m1_t vslide1up(vuint32m1_t, int32_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vslide1up_vx_m)))
vuint32m1_t vslide1up(vbool32_t, vuint32m1_t, vuint32m1_t, int32_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vslide1up_vx)))
vuint32m2_t vslide1up(vuint32m2_t, int32_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vslide1up_vx_m)))
vuint32m2_t vslide1up(vbool16_t, vuint32m2_t, vuint32m2_t, int32_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vslide1up_vx)))
vuint32m4_t vslide1up(vuint32m4_t, int32_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vslide1up_vx_m)))
vuint32m4_t vslide1up(vbool8_t, vuint32m4_t, vuint32m4_t, int32_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vslide1up_vx)))
vuint32m8_t vslide1up(vuint32m8_t, int32_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vslide1up_vx_m)))
vuint32m8_t vslide1up(vbool4_t, vuint32m8_t, vuint32m8_t, int32_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vslide1up_vx)))
vuint32mf2_t vslide1up(vuint32mf2_t, int32_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vslide1up_vx_m)))
vuint32mf2_t vslide1up(vbool64_t, vuint32mf2_t, vuint32mf2_t, int32_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vsse8_v)))
void vsse8(int8_t *, ptrdiff_t, vint8m1_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vsse8_v_m)))
void vsse8(vbool8_t, int8_t *, ptrdiff_t, vint8m1_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vsse8_v)))
void vsse8(int8_t *, ptrdiff_t, vint8m2_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vsse8_v_m)))
void vsse8(vbool4_t, int8_t *, ptrdiff_t, vint8m2_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vsse8_v)))
void vsse8(int8_t *, ptrdiff_t, vint8m4_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vsse8_v_m)))
void vsse8(vbool2_t, int8_t *, ptrdiff_t, vint8m4_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vsse8_v)))
void vsse8(int8_t *, ptrdiff_t, vint8m8_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vsse8_v_m)))
void vsse8(vbool1_t, int8_t *, ptrdiff_t, vint8m8_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vsse8_v)))
void vsse8(int8_t *, ptrdiff_t, vint8mf2_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vsse8_v_m)))
void vsse8(vbool16_t, int8_t *, ptrdiff_t, vint8mf2_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vsse8_v)))
void vsse8(int8_t *, ptrdiff_t, vint8mf4_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vsse8_v_m)))
void vsse8(vbool32_t, int8_t *, ptrdiff_t, vint8mf4_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vsse8_v)))
void vsse8(int8_t *, ptrdiff_t, vint8mf8_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vsse8_v_m)))
void vsse8(vbool64_t, int8_t *, ptrdiff_t, vint8mf8_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vslide1down_vx)))
vint8m1_t vslide1down(vint8m1_t, int8_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vslide1down_vx_m)))
vint8m1_t vslide1down(vbool8_t, vint8m1_t, vint8m1_t, int8_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vslide1down_vx)))
vint8m2_t vslide1down(vint8m2_t, int8_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vslide1down_vx_m)))
vint8m2_t vslide1down(vbool4_t, vint8m2_t, vint8m2_t, int8_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vslide1down_vx)))
vint8m4_t vslide1down(vint8m4_t, int8_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vslide1down_vx_m)))
vint8m4_t vslide1down(vbool2_t, vint8m4_t, vint8m4_t, int8_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vslide1down_vx)))
vint8m8_t vslide1down(vint8m8_t, int8_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vslide1down_vx_m)))
vint8m8_t vslide1down(vbool1_t, vint8m8_t, vint8m8_t, int8_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vslide1down_vx)))
vint8mf2_t vslide1down(vint8mf2_t, int8_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vslide1down_vx_m)))
vint8mf2_t vslide1down(vbool16_t, vint8mf2_t, vint8mf2_t, int8_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vslide1down_vx)))
vint8mf4_t vslide1down(vint8mf4_t, int8_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vslide1down_vx_m)))
vint8mf4_t vslide1down(vbool32_t, vint8mf4_t, vint8mf4_t, int8_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vslide1down_vx)))
vint8mf8_t vslide1down(vint8mf8_t, int8_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vslide1down_vx_m)))
vint8mf8_t vslide1down(vbool64_t, vint8mf8_t, vint8mf8_t, int8_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vslide1down_vx)))
vint16m1_t vslide1down(vint16m1_t, int16_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vslide1down_vx_m)))
vint16m1_t vslide1down(vbool16_t, vint16m1_t, vint16m1_t, int16_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vslide1down_vx)))
vint16m2_t vslide1down(vint16m2_t, int16_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vslide1down_vx_m)))
vint16m2_t vslide1down(vbool8_t, vint16m2_t, vint16m2_t, int16_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vslide1down_vx)))
vint16m4_t vslide1down(vint16m4_t, int16_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vslide1down_vx_m)))
vint16m4_t vslide1down(vbool4_t, vint16m4_t, vint16m4_t, int16_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vslide1down_vx)))
vint16m8_t vslide1down(vint16m8_t, int16_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vslide1down_vx_m)))
vint16m8_t vslide1down(vbool2_t, vint16m8_t, vint16m8_t, int16_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vslide1down_vx)))
vint16mf2_t vslide1down(vint16mf2_t, int16_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vslide1down_vx_m)))
vint16mf2_t vslide1down(vbool32_t, vint16mf2_t, vint16mf2_t, int16_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vslide1down_vx)))
vint16mf4_t vslide1down(vint16mf4_t, int16_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vslide1down_vx_m)))
vint16mf4_t vslide1down(vbool64_t, vint16mf4_t, vint16mf4_t, int16_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vslide1down_vx)))
vint32m1_t vslide1down(vint32m1_t, int32_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vslide1down_vx_m)))
vint32m1_t vslide1down(vbool32_t, vint32m1_t, vint32m1_t, int32_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vslide1down_vx)))
vint32m2_t vslide1down(vint32m2_t, int32_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vslide1down_vx_m)))
vint32m2_t vslide1down(vbool16_t, vint32m2_t, vint32m2_t, int32_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vslide1down_vx)))
vint32m4_t vslide1down(vint32m4_t, int32_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vslide1down_vx_m)))
vint32m4_t vslide1down(vbool8_t, vint32m4_t, vint32m4_t, int32_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vslide1down_vx)))
vint32m8_t vslide1down(vint32m8_t, int32_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vslide1down_vx_m)))
vint32m8_t vslide1down(vbool4_t, vint32m8_t, vint32m8_t, int32_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vslide1down_vx)))
vint32mf2_t vslide1down(vint32mf2_t, int32_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vslide1down_vx_m)))
vint32mf2_t vslide1down(vbool64_t, vint32mf2_t, vint32mf2_t, int32_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vslide1down_vx)))
vuint8m1_t vslide1down(vuint8m1_t, int8_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vslide1down_vx_m)))
vuint8m1_t vslide1down(vbool8_t, vuint8m1_t, vuint8m1_t, int8_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vslide1down_vx)))
vuint8m2_t vslide1down(vuint8m2_t, int8_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vslide1down_vx_m)))
vuint8m2_t vslide1down(vbool4_t, vuint8m2_t, vuint8m2_t, int8_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vslide1down_vx)))
vuint8m4_t vslide1down(vuint8m4_t, int8_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vslide1down_vx_m)))
vuint8m4_t vslide1down(vbool2_t, vuint8m4_t, vuint8m4_t, int8_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vslide1down_vx)))
vuint8m8_t vslide1down(vuint8m8_t, int8_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vslide1down_vx_m)))
vuint8m8_t vslide1down(vbool1_t, vuint8m8_t, vuint8m8_t, int8_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vslide1down_vx)))
vuint8mf2_t vslide1down(vuint8mf2_t, int8_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vslide1down_vx_m)))
vuint8mf2_t vslide1down(vbool16_t, vuint8mf2_t, vuint8mf2_t, int8_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vslide1down_vx)))
vuint8mf4_t vslide1down(vuint8mf4_t, int8_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vslide1down_vx_m)))
vuint8mf4_t vslide1down(vbool32_t, vuint8mf4_t, vuint8mf4_t, int8_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vslide1down_vx)))
vuint8mf8_t vslide1down(vuint8mf8_t, int8_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vslide1down_vx_m)))
vuint8mf8_t vslide1down(vbool64_t, vuint8mf8_t, vuint8mf8_t, int8_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vslide1down_vx)))
vuint16m1_t vslide1down(vuint16m1_t, int16_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vslide1down_vx_m)))
vuint16m1_t vslide1down(vbool16_t, vuint16m1_t, vuint16m1_t, int16_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vslide1down_vx)))
vuint16m2_t vslide1down(vuint16m2_t, int16_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vslide1down_vx_m)))
vuint16m2_t vslide1down(vbool8_t, vuint16m2_t, vuint16m2_t, int16_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vslide1down_vx)))
vuint16m4_t vslide1down(vuint16m4_t, int16_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vslide1down_vx_m)))
vuint16m4_t vslide1down(vbool4_t, vuint16m4_t, vuint16m4_t, int16_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vslide1down_vx)))
vuint16m8_t vslide1down(vuint16m8_t, int16_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vslide1down_vx_m)))
vuint16m8_t vslide1down(vbool2_t, vuint16m8_t, vuint16m8_t, int16_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vslide1down_vx)))
vuint16mf2_t vslide1down(vuint16mf2_t, int16_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vslide1down_vx_m)))
vuint16mf2_t vslide1down(vbool32_t, vuint16mf2_t, vuint16mf2_t, int16_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vslide1down_vx)))
vuint16mf4_t vslide1down(vuint16mf4_t, int16_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vslide1down_vx_m)))
vuint16mf4_t vslide1down(vbool64_t, vuint16mf4_t, vuint16mf4_t, int16_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vslide1down_vx)))
vuint32m1_t vslide1down(vuint32m1_t, int32_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vslide1down_vx_m)))
vuint32m1_t vslide1down(vbool32_t, vuint32m1_t, vuint32m1_t, int32_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vslide1down_vx)))
vuint32m2_t vslide1down(vuint32m2_t, int32_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vslide1down_vx_m)))
vuint32m2_t vslide1down(vbool16_t, vuint32m2_t, vuint32m2_t, int32_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vslide1down_vx)))
vuint32m4_t vslide1down(vuint32m4_t, int32_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vslide1down_vx_m)))
vuint32m4_t vslide1down(vbool8_t, vuint32m4_t, vuint32m4_t, int32_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vslide1down_vx)))
vuint32m8_t vslide1down(vuint32m8_t, int32_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vslide1down_vx_m)))
vuint32m8_t vslide1down(vbool4_t, vuint32m8_t, vuint32m8_t, int32_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vslide1down_vx)))
vuint32mf2_t vslide1down(vuint32mf2_t, int32_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vslide1down_vx_m)))
vuint32mf2_t vslide1down(vbool64_t, vuint32mf2_t, vuint32mf2_t, int32_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vrgather_vv)))
vint8m1_t vrgather(vint8m1_t, vuint8m1_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vrgather_vv_m)))
vint8m1_t vrgather(vbool8_t, vint8m1_t, vint8m1_t, vuint8m1_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vrgather_vv)))
vint8m2_t vrgather(vint8m2_t, vuint8m2_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vrgather_vv_m)))
vint8m2_t vrgather(vbool4_t, vint8m2_t, vint8m2_t, vuint8m2_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vrgather_vv)))
vint8m4_t vrgather(vint8m4_t, vuint8m4_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vrgather_vv_m)))
vint8m4_t vrgather(vbool2_t, vint8m4_t, vint8m4_t, vuint8m4_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vrgather_vv)))
vint8m8_t vrgather(vint8m8_t, vuint8m8_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vrgather_vv_m)))
vint8m8_t vrgather(vbool1_t, vint8m8_t, vint8m8_t, vuint8m8_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vrgather_vv)))
vint8mf2_t vrgather(vint8mf2_t, vuint8mf2_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vrgather_vv_m)))
vint8mf2_t vrgather(vbool16_t, vint8mf2_t, vint8mf2_t, vuint8mf2_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vrgather_vv)))
vint8mf4_t vrgather(vint8mf4_t, vuint8mf4_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vrgather_vv_m)))
vint8mf4_t vrgather(vbool32_t, vint8mf4_t, vint8mf4_t, vuint8mf4_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vrgather_vv)))
vint8mf8_t vrgather(vint8mf8_t, vuint8mf8_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vrgather_vv_m)))
vint8mf8_t vrgather(vbool64_t, vint8mf8_t, vint8mf8_t, vuint8mf8_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vrgather_vv)))
vint16m1_t vrgather(vint16m1_t, vuint16m1_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vrgather_vv_m)))
vint16m1_t vrgather(vbool16_t, vint16m1_t, vint16m1_t, vuint16m1_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vrgather_vv)))
vint16m2_t vrgather(vint16m2_t, vuint16m2_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vrgather_vv_m)))
vint16m2_t vrgather(vbool8_t, vint16m2_t, vint16m2_t, vuint16m2_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vrgather_vv)))
vint16m4_t vrgather(vint16m4_t, vuint16m4_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vrgather_vv_m)))
vint16m4_t vrgather(vbool4_t, vint16m4_t, vint16m4_t, vuint16m4_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vrgather_vv)))
vint16m8_t vrgather(vint16m8_t, vuint16m8_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vrgather_vv_m)))
vint16m8_t vrgather(vbool2_t, vint16m8_t, vint16m8_t, vuint16m8_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vrgather_vv)))
vint16mf2_t vrgather(vint16mf2_t, vuint16mf2_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vrgather_vv_m)))
vint16mf2_t vrgather(vbool32_t, vint16mf2_t, vint16mf2_t, vuint16mf2_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vrgather_vv)))
vint16mf4_t vrgather(vint16mf4_t, vuint16mf4_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vrgather_vv_m)))
vint16mf4_t vrgather(vbool64_t, vint16mf4_t, vint16mf4_t, vuint16mf4_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vrgather_vv)))
vint32m1_t vrgather(vint32m1_t, vuint32m1_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vrgather_vv_m)))
vint32m1_t vrgather(vbool32_t, vint32m1_t, vint32m1_t, vuint32m1_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vrgather_vv)))
vint32m2_t vrgather(vint32m2_t, vuint32m2_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vrgather_vv_m)))
vint32m2_t vrgather(vbool16_t, vint32m2_t, vint32m2_t, vuint32m2_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vrgather_vv)))
vint32m4_t vrgather(vint32m4_t, vuint32m4_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vrgather_vv_m)))
vint32m4_t vrgather(vbool8_t, vint32m4_t, vint32m4_t, vuint32m4_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vrgather_vv)))
vint32m8_t vrgather(vint32m8_t, vuint32m8_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vrgather_vv_m)))
vint32m8_t vrgather(vbool4_t, vint32m8_t, vint32m8_t, vuint32m8_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vrgather_vv)))
vint32mf2_t vrgather(vint32mf2_t, vuint32mf2_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vrgather_vv_m)))
vint32mf2_t vrgather(vbool64_t, vint32mf2_t, vint32mf2_t, vuint32mf2_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vrgather_vx)))
vint8m1_t vrgather(vint8m1_t, size_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vrgather_vx_m)))
vint8m1_t vrgather(vbool8_t, vint8m1_t, vint8m1_t, size_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vrgather_vx)))
vint8m2_t vrgather(vint8m2_t, size_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vrgather_vx_m)))
vint8m2_t vrgather(vbool4_t, vint8m2_t, vint8m2_t, size_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vrgather_vx)))
vint8m4_t vrgather(vint8m4_t, size_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vrgather_vx_m)))
vint8m4_t vrgather(vbool2_t, vint8m4_t, vint8m4_t, size_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vrgather_vx)))
vint8m8_t vrgather(vint8m8_t, size_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vrgather_vx_m)))
vint8m8_t vrgather(vbool1_t, vint8m8_t, vint8m8_t, size_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vrgather_vx)))
vint8mf2_t vrgather(vint8mf2_t, size_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vrgather_vx_m)))
vint8mf2_t vrgather(vbool16_t, vint8mf2_t, vint8mf2_t, size_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vrgather_vx)))
vint8mf4_t vrgather(vint8mf4_t, size_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vrgather_vx_m)))
vint8mf4_t vrgather(vbool32_t, vint8mf4_t, vint8mf4_t, size_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vrgather_vx)))
vint8mf8_t vrgather(vint8mf8_t, size_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vrgather_vx_m)))
vint8mf8_t vrgather(vbool64_t, vint8mf8_t, vint8mf8_t, size_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vrgather_vx)))
vint16m1_t vrgather(vint16m1_t, size_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vrgather_vx_m)))
vint16m1_t vrgather(vbool16_t, vint16m1_t, vint16m1_t, size_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vrgather_vx)))
vint16m2_t vrgather(vint16m2_t, size_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vrgather_vx_m)))
vint16m2_t vrgather(vbool8_t, vint16m2_t, vint16m2_t, size_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vrgather_vx)))
vint16m4_t vrgather(vint16m4_t, size_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vrgather_vx_m)))
vint16m4_t vrgather(vbool4_t, vint16m4_t, vint16m4_t, size_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vrgather_vx)))
vint16m8_t vrgather(vint16m8_t, size_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vrgather_vx_m)))
vint16m8_t vrgather(vbool2_t, vint16m8_t, vint16m8_t, size_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vrgather_vx)))
vint16mf2_t vrgather(vint16mf2_t, size_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vrgather_vx_m)))
vint16mf2_t vrgather(vbool32_t, vint16mf2_t, vint16mf2_t, size_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vrgather_vx)))
vint16mf4_t vrgather(vint16mf4_t, size_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vrgather_vx_m)))
vint16mf4_t vrgather(vbool64_t, vint16mf4_t, vint16mf4_t, size_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vrgather_vx)))
vint32m1_t vrgather(vint32m1_t, size_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vrgather_vx_m)))
vint32m1_t vrgather(vbool32_t, vint32m1_t, vint32m1_t, size_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vrgather_vx)))
vint32m2_t vrgather(vint32m2_t, size_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vrgather_vx_m)))
vint32m2_t vrgather(vbool16_t, vint32m2_t, vint32m2_t, size_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vrgather_vx)))
vint32m4_t vrgather(vint32m4_t, size_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vrgather_vx_m)))
vint32m4_t vrgather(vbool8_t, vint32m4_t, vint32m4_t, size_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vrgather_vx)))
vint32m8_t vrgather(vint32m8_t, size_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vrgather_vx_m)))
vint32m8_t vrgather(vbool4_t, vint32m8_t, vint32m8_t, size_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vrgather_vx)))
vint32mf2_t vrgather(vint32mf2_t, size_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vrgather_vx_m)))
vint32mf2_t vrgather(vbool64_t, vint32mf2_t, vint32mf2_t, size_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vrgatherei16_vv)))
vint8m1_t vrgatherei16(vint8m1_t, vuint16m2_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vrgatherei16_vv_m)))
vint8m1_t vrgatherei16(vbool8_t, vint8m1_t, vint8m1_t, vuint16m2_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vrgatherei16_vv)))
vint8m2_t vrgatherei16(vint8m2_t, vuint16m4_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vrgatherei16_vv_m)))
vint8m2_t vrgatherei16(vbool4_t, vint8m2_t, vint8m2_t, vuint16m4_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vrgatherei16_vv)))
vint8m4_t vrgatherei16(vint8m4_t, vuint16m8_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vrgatherei16_vv_m)))
vint8m4_t vrgatherei16(vbool2_t, vint8m4_t, vint8m4_t, vuint16m8_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vrgatherei16_vv)))
vint8mf2_t vrgatherei16(vint8mf2_t, vuint16m1_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vrgatherei16_vv_m)))
vint8mf2_t vrgatherei16(vbool16_t, vint8mf2_t, vint8mf2_t, vuint16m1_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vrgatherei16_vv)))
vint8mf4_t vrgatherei16(vint8mf4_t, vuint16mf2_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vrgatherei16_vv_m)))
vint8mf4_t vrgatherei16(vbool32_t, vint8mf4_t, vint8mf4_t, vuint16mf2_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vrgatherei16_vv)))
vint8mf8_t vrgatherei16(vint8mf8_t, vuint16mf4_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vrgatherei16_vv_m)))
vint8mf8_t vrgatherei16(vbool64_t, vint8mf8_t, vint8mf8_t, vuint16mf4_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vrgatherei16_vv)))
vint16m1_t vrgatherei16(vint16m1_t, vuint16m1_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vrgatherei16_vv_m)))
vint16m1_t vrgatherei16(vbool16_t, vint16m1_t, vint16m1_t, vuint16m1_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vrgatherei16_vv)))
vint16m2_t vrgatherei16(vint16m2_t, vuint16m2_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vrgatherei16_vv_m)))
vint16m2_t vrgatherei16(vbool8_t, vint16m2_t, vint16m2_t, vuint16m2_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vrgatherei16_vv)))
vint16m4_t vrgatherei16(vint16m4_t, vuint16m4_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vrgatherei16_vv_m)))
vint16m4_t vrgatherei16(vbool4_t, vint16m4_t, vint16m4_t, vuint16m4_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vrgatherei16_vv)))
vint16m8_t vrgatherei16(vint16m8_t, vuint16m8_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vrgatherei16_vv_m)))
vint16m8_t vrgatherei16(vbool2_t, vint16m8_t, vint16m8_t, vuint16m8_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vrgatherei16_vv)))
vint16mf2_t vrgatherei16(vint16mf2_t, vuint16mf2_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vrgatherei16_vv_m)))
vint16mf2_t vrgatherei16(vbool32_t, vint16mf2_t, vint16mf2_t, vuint16mf2_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vrgatherei16_vv)))
vint16mf4_t vrgatherei16(vint16mf4_t, vuint16mf4_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vrgatherei16_vv_m)))
vint16mf4_t vrgatherei16(vbool64_t, vint16mf4_t, vint16mf4_t, vuint16mf4_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vrgatherei16_vv)))
vint32m1_t vrgatherei16(vint32m1_t, vuint16mf2_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vrgatherei16_vv_m)))
vint32m1_t vrgatherei16(vbool32_t, vint32m1_t, vint32m1_t, vuint16mf2_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vrgatherei16_vv)))
vint32m2_t vrgatherei16(vint32m2_t, vuint16m1_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vrgatherei16_vv_m)))
vint32m2_t vrgatherei16(vbool16_t, vint32m2_t, vint32m2_t, vuint16m1_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vrgatherei16_vv)))
vint32m4_t vrgatherei16(vint32m4_t, vuint16m2_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vrgatherei16_vv_m)))
vint32m4_t vrgatherei16(vbool8_t, vint32m4_t, vint32m4_t, vuint16m2_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vrgatherei16_vv)))
vint32m8_t vrgatherei16(vint32m8_t, vuint16m4_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vrgatherei16_vv_m)))
vint32m8_t vrgatherei16(vbool4_t, vint32m8_t, vint32m8_t, vuint16m4_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vrgatherei16_vv)))
vint32mf2_t vrgatherei16(vint32mf2_t, vuint16mf4_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vrgatherei16_vv_m)))
vint32mf2_t vrgatherei16(vbool64_t, vint32mf2_t, vint32mf2_t, vuint16mf4_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vrgather_vv)))
vuint8m1_t vrgather(vuint8m1_t, vuint8m1_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vrgather_vv_m)))
vuint8m1_t vrgather(vbool8_t, vuint8m1_t, vuint8m1_t, vuint8m1_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vrgather_vv)))
vuint8m2_t vrgather(vuint8m2_t, vuint8m2_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vrgather_vv_m)))
vuint8m2_t vrgather(vbool4_t, vuint8m2_t, vuint8m2_t, vuint8m2_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vrgather_vv)))
vuint8m4_t vrgather(vuint8m4_t, vuint8m4_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vrgather_vv_m)))
vuint8m4_t vrgather(vbool2_t, vuint8m4_t, vuint8m4_t, vuint8m4_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vrgather_vv)))
vuint8m8_t vrgather(vuint8m8_t, vuint8m8_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vrgather_vv_m)))
vuint8m8_t vrgather(vbool1_t, vuint8m8_t, vuint8m8_t, vuint8m8_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vrgather_vv)))
vuint8mf2_t vrgather(vuint8mf2_t, vuint8mf2_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vrgather_vv_m)))
vuint8mf2_t vrgather(vbool16_t, vuint8mf2_t, vuint8mf2_t, vuint8mf2_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vrgather_vv)))
vuint8mf4_t vrgather(vuint8mf4_t, vuint8mf4_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vrgather_vv_m)))
vuint8mf4_t vrgather(vbool32_t, vuint8mf4_t, vuint8mf4_t, vuint8mf4_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vrgather_vv)))
vuint8mf8_t vrgather(vuint8mf8_t, vuint8mf8_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vrgather_vv_m)))
vuint8mf8_t vrgather(vbool64_t, vuint8mf8_t, vuint8mf8_t, vuint8mf8_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vrgather_vv)))
vuint16m1_t vrgather(vuint16m1_t, vuint16m1_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vrgather_vv_m)))
vuint16m1_t vrgather(vbool16_t, vuint16m1_t, vuint16m1_t, vuint16m1_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vrgather_vv)))
vuint16m2_t vrgather(vuint16m2_t, vuint16m2_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vrgather_vv_m)))
vuint16m2_t vrgather(vbool8_t, vuint16m2_t, vuint16m2_t, vuint16m2_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vrgather_vv)))
vuint16m4_t vrgather(vuint16m4_t, vuint16m4_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vrgather_vv_m)))
vuint16m4_t vrgather(vbool4_t, vuint16m4_t, vuint16m4_t, vuint16m4_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vrgather_vv)))
vuint16m8_t vrgather(vuint16m8_t, vuint16m8_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vrgather_vv_m)))
vuint16m8_t vrgather(vbool2_t, vuint16m8_t, vuint16m8_t, vuint16m8_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vrgather_vv)))
vuint16mf2_t vrgather(vuint16mf2_t, vuint16mf2_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vrgather_vv_m)))
vuint16mf2_t vrgather(vbool32_t, vuint16mf2_t, vuint16mf2_t, vuint16mf2_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vrgather_vv)))
vuint16mf4_t vrgather(vuint16mf4_t, vuint16mf4_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vrgather_vv_m)))
vuint16mf4_t vrgather(vbool64_t, vuint16mf4_t, vuint16mf4_t, vuint16mf4_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vrgather_vv)))
vuint32m1_t vrgather(vuint32m1_t, vuint32m1_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vrgather_vv_m)))
vuint32m1_t vrgather(vbool32_t, vuint32m1_t, vuint32m1_t, vuint32m1_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vrgather_vv)))
vuint32m2_t vrgather(vuint32m2_t, vuint32m2_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vrgather_vv_m)))
vuint32m2_t vrgather(vbool16_t, vuint32m2_t, vuint32m2_t, vuint32m2_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vrgather_vv)))
vuint32m4_t vrgather(vuint32m4_t, vuint32m4_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vrgather_vv_m)))
vuint32m4_t vrgather(vbool8_t, vuint32m4_t, vuint32m4_t, vuint32m4_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vrgather_vv)))
vuint32m8_t vrgather(vuint32m8_t, vuint32m8_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vrgather_vv_m)))
vuint32m8_t vrgather(vbool4_t, vuint32m8_t, vuint32m8_t, vuint32m8_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vrgather_vv)))
vuint32mf2_t vrgather(vuint32mf2_t, vuint32mf2_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vrgather_vv_m)))
vuint32mf2_t vrgather(vbool64_t, vuint32mf2_t, vuint32mf2_t, vuint32mf2_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vrgather_vx)))
vuint8m1_t vrgather(vuint8m1_t, size_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vrgather_vx_m)))
vuint8m1_t vrgather(vbool8_t, vuint8m1_t, vuint8m1_t, size_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vrgather_vx)))
vuint8m2_t vrgather(vuint8m2_t, size_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vrgather_vx_m)))
vuint8m2_t vrgather(vbool4_t, vuint8m2_t, vuint8m2_t, size_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vrgather_vx)))
vuint8m4_t vrgather(vuint8m4_t, size_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vrgather_vx_m)))
vuint8m4_t vrgather(vbool2_t, vuint8m4_t, vuint8m4_t, size_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vrgather_vx)))
vuint8m8_t vrgather(vuint8m8_t, size_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vrgather_vx_m)))
vuint8m8_t vrgather(vbool1_t, vuint8m8_t, vuint8m8_t, size_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vrgather_vx)))
vuint8mf2_t vrgather(vuint8mf2_t, size_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vrgather_vx_m)))
vuint8mf2_t vrgather(vbool16_t, vuint8mf2_t, vuint8mf2_t, size_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vrgather_vx)))
vuint8mf4_t vrgather(vuint8mf4_t, size_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vrgather_vx_m)))
vuint8mf4_t vrgather(vbool32_t, vuint8mf4_t, vuint8mf4_t, size_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vrgather_vx)))
vuint8mf8_t vrgather(vuint8mf8_t, size_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vrgather_vx_m)))
vuint8mf8_t vrgather(vbool64_t, vuint8mf8_t, vuint8mf8_t, size_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vrgather_vx)))
vuint16m1_t vrgather(vuint16m1_t, size_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vrgather_vx_m)))
vuint16m1_t vrgather(vbool16_t, vuint16m1_t, vuint16m1_t, size_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vrgather_vx)))
vuint16m2_t vrgather(vuint16m2_t, size_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vrgather_vx_m)))
vuint16m2_t vrgather(vbool8_t, vuint16m2_t, vuint16m2_t, size_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vrgather_vx)))
vuint16m4_t vrgather(vuint16m4_t, size_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vrgather_vx_m)))
vuint16m4_t vrgather(vbool4_t, vuint16m4_t, vuint16m4_t, size_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vrgather_vx)))
vuint16m8_t vrgather(vuint16m8_t, size_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vrgather_vx_m)))
vuint16m8_t vrgather(vbool2_t, vuint16m8_t, vuint16m8_t, size_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vrgather_vx)))
vuint16mf2_t vrgather(vuint16mf2_t, size_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vrgather_vx_m)))
vuint16mf2_t vrgather(vbool32_t, vuint16mf2_t, vuint16mf2_t, size_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vrgather_vx)))
vuint16mf4_t vrgather(vuint16mf4_t, size_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vrgather_vx_m)))
vuint16mf4_t vrgather(vbool64_t, vuint16mf4_t, vuint16mf4_t, size_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vrgather_vx)))
vuint32m1_t vrgather(vuint32m1_t, size_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vrgather_vx_m)))
vuint32m1_t vrgather(vbool32_t, vuint32m1_t, vuint32m1_t, size_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vrgather_vx)))
vuint32m2_t vrgather(vuint32m2_t, size_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vrgather_vx_m)))
vuint32m2_t vrgather(vbool16_t, vuint32m2_t, vuint32m2_t, size_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vrgather_vx)))
vuint32m4_t vrgather(vuint32m4_t, size_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vrgather_vx_m)))
vuint32m4_t vrgather(vbool8_t, vuint32m4_t, vuint32m4_t, size_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vrgather_vx)))
vuint32m8_t vrgather(vuint32m8_t, size_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vrgather_vx_m)))
vuint32m8_t vrgather(vbool4_t, vuint32m8_t, vuint32m8_t, size_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vrgather_vx)))
vuint32mf2_t vrgather(vuint32mf2_t, size_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vrgather_vx_m)))
vuint32mf2_t vrgather(vbool64_t, vuint32mf2_t, vuint32mf2_t, size_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vrgatherei16_vv)))
vuint8m1_t vrgatherei16(vuint8m1_t, vuint16m2_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vrgatherei16_vv_m)))
vuint8m1_t vrgatherei16(vbool8_t, vuint8m1_t, vuint8m1_t, vuint16m2_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vrgatherei16_vv)))
vuint8m2_t vrgatherei16(vuint8m2_t, vuint16m4_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vrgatherei16_vv_m)))
vuint8m2_t vrgatherei16(vbool4_t, vuint8m2_t, vuint8m2_t, vuint16m4_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vrgatherei16_vv)))
vuint8m4_t vrgatherei16(vuint8m4_t, vuint16m8_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vrgatherei16_vv_m)))
vuint8m4_t vrgatherei16(vbool2_t, vuint8m4_t, vuint8m4_t, vuint16m8_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vrgatherei16_vv)))
vuint8mf2_t vrgatherei16(vuint8mf2_t, vuint16m1_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vrgatherei16_vv_m)))
vuint8mf2_t vrgatherei16(vbool16_t, vuint8mf2_t, vuint8mf2_t, vuint16m1_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vrgatherei16_vv)))
vuint8mf4_t vrgatherei16(vuint8mf4_t, vuint16mf2_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vrgatherei16_vv_m)))
vuint8mf4_t vrgatherei16(vbool32_t, vuint8mf4_t, vuint8mf4_t, vuint16mf2_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vrgatherei16_vv)))
vuint8mf8_t vrgatherei16(vuint8mf8_t, vuint16mf4_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vrgatherei16_vv_m)))
vuint8mf8_t vrgatherei16(vbool64_t, vuint8mf8_t, vuint8mf8_t, vuint16mf4_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vrgatherei16_vv)))
vuint16m1_t vrgatherei16(vuint16m1_t, vuint16m1_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vrgatherei16_vv_m)))
vuint16m1_t vrgatherei16(vbool16_t, vuint16m1_t, vuint16m1_t, vuint16m1_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vrgatherei16_vv)))
vuint16m2_t vrgatherei16(vuint16m2_t, vuint16m2_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vrgatherei16_vv_m)))
vuint16m2_t vrgatherei16(vbool8_t, vuint16m2_t, vuint16m2_t, vuint16m2_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vrgatherei16_vv)))
vuint16m4_t vrgatherei16(vuint16m4_t, vuint16m4_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vrgatherei16_vv_m)))
vuint16m4_t vrgatherei16(vbool4_t, vuint16m4_t, vuint16m4_t, vuint16m4_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vrgatherei16_vv)))
vuint16m8_t vrgatherei16(vuint16m8_t, vuint16m8_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vrgatherei16_vv_m)))
vuint16m8_t vrgatherei16(vbool2_t, vuint16m8_t, vuint16m8_t, vuint16m8_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vrgatherei16_vv)))
vuint16mf2_t vrgatherei16(vuint16mf2_t, vuint16mf2_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vrgatherei16_vv_m)))
vuint16mf2_t vrgatherei16(vbool32_t, vuint16mf2_t, vuint16mf2_t, vuint16mf2_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vrgatherei16_vv)))
vuint16mf4_t vrgatherei16(vuint16mf4_t, vuint16mf4_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vrgatherei16_vv_m)))
vuint16mf4_t vrgatherei16(vbool64_t, vuint16mf4_t, vuint16mf4_t, vuint16mf4_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vrgatherei16_vv)))
vuint32m1_t vrgatherei16(vuint32m1_t, vuint16mf2_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vrgatherei16_vv_m)))
vuint32m1_t vrgatherei16(vbool32_t, vuint32m1_t, vuint32m1_t, vuint16mf2_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vrgatherei16_vv)))
vuint32m2_t vrgatherei16(vuint32m2_t, vuint16m1_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vrgatherei16_vv_m)))
vuint32m2_t vrgatherei16(vbool16_t, vuint32m2_t, vuint32m2_t, vuint16m1_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vrgatherei16_vv)))
vuint32m4_t vrgatherei16(vuint32m4_t, vuint16m2_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vrgatherei16_vv_m)))
vuint32m4_t vrgatherei16(vbool8_t, vuint32m4_t, vuint32m4_t, vuint16m2_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vrgatherei16_vv)))
vuint32m8_t vrgatherei16(vuint32m8_t, vuint16m4_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vrgatherei16_vv_m)))
vuint32m8_t vrgatherei16(vbool4_t, vuint32m8_t, vuint32m8_t, vuint16m4_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vrgatherei16_vv)))
vuint32mf2_t vrgatherei16(vuint32mf2_t, vuint16mf4_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vrgatherei16_vv_m)))
vuint32mf2_t vrgatherei16(vbool64_t, vuint32mf2_t, vuint32mf2_t, vuint16mf4_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vcompress_vm)))
vint8m1_t vcompress(vbool8_t, vint8m1_t, vint8m1_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vcompress_vm)))
vint8m2_t vcompress(vbool4_t, vint8m2_t, vint8m2_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vcompress_vm)))
vint8m4_t vcompress(vbool2_t, vint8m4_t, vint8m4_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vcompress_vm)))
vint8m8_t vcompress(vbool1_t, vint8m8_t, vint8m8_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vcompress_vm)))
vint8mf2_t vcompress(vbool16_t, vint8mf2_t, vint8mf2_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vcompress_vm)))
vint8mf4_t vcompress(vbool32_t, vint8mf4_t, vint8mf4_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vcompress_vm)))
vint8mf8_t vcompress(vbool64_t, vint8mf8_t, vint8mf8_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vcompress_vm)))
vint16m1_t vcompress(vbool16_t, vint16m1_t, vint16m1_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vcompress_vm)))
vint16m2_t vcompress(vbool8_t, vint16m2_t, vint16m2_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vcompress_vm)))
vint16m4_t vcompress(vbool4_t, vint16m4_t, vint16m4_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vcompress_vm)))
vint16m8_t vcompress(vbool2_t, vint16m8_t, vint16m8_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vcompress_vm)))
vint16mf2_t vcompress(vbool32_t, vint16mf2_t, vint16mf2_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vcompress_vm)))
vint16mf4_t vcompress(vbool64_t, vint16mf4_t, vint16mf4_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vcompress_vm)))
vint32m1_t vcompress(vbool32_t, vint32m1_t, vint32m1_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vcompress_vm)))
vint32m2_t vcompress(vbool16_t, vint32m2_t, vint32m2_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vcompress_vm)))
vint32m4_t vcompress(vbool8_t, vint32m4_t, vint32m4_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vcompress_vm)))
vint32m8_t vcompress(vbool4_t, vint32m8_t, vint32m8_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vcompress_vm)))
vint32mf2_t vcompress(vbool64_t, vint32mf2_t, vint32mf2_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vcompress_vm)))
vuint8m1_t vcompress(vbool8_t, vuint8m1_t, vuint8m1_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vcompress_vm)))
vuint8m2_t vcompress(vbool4_t, vuint8m2_t, vuint8m2_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vcompress_vm)))
vuint8m4_t vcompress(vbool2_t, vuint8m4_t, vuint8m4_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vcompress_vm)))
vuint8m8_t vcompress(vbool1_t, vuint8m8_t, vuint8m8_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vcompress_vm)))
vuint8mf2_t vcompress(vbool16_t, vuint8mf2_t, vuint8mf2_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vcompress_vm)))
vuint8mf4_t vcompress(vbool32_t, vuint8mf4_t, vuint8mf4_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vcompress_vm)))
vuint8mf8_t vcompress(vbool64_t, vuint8mf8_t, vuint8mf8_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vcompress_vm)))
vuint16m1_t vcompress(vbool16_t, vuint16m1_t, vuint16m1_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vcompress_vm)))
vuint16m2_t vcompress(vbool8_t, vuint16m2_t, vuint16m2_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vcompress_vm)))
vuint16m4_t vcompress(vbool4_t, vuint16m4_t, vuint16m4_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vcompress_vm)))
vuint16m8_t vcompress(vbool2_t, vuint16m8_t, vuint16m8_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vcompress_vm)))
vuint16mf2_t vcompress(vbool32_t, vuint16mf2_t, vuint16mf2_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vcompress_vm)))
vuint16mf4_t vcompress(vbool64_t, vuint16mf4_t, vuint16mf4_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vcompress_vm)))
vuint32m1_t vcompress(vbool32_t, vuint32m1_t, vuint32m1_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vcompress_vm)))
vuint32m2_t vcompress(vbool16_t, vuint32m2_t, vuint32m2_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vcompress_vm)))
vuint32m4_t vcompress(vbool8_t, vuint32m4_t, vuint32m4_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vcompress_vm)))
vuint32m8_t vcompress(vbool4_t, vuint32m8_t, vuint32m8_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vcompress_vm)))
vuint32mf2_t vcompress(vbool64_t, vuint32mf2_t, vuint32mf2_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vget_v)))
vint8m1_t vget_i8m1(vint8m2_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vget_v)))
vint8m1_t vget_i8m1(vint8m4_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vget_v)))
vint8m1_t vget_i8m1(vint8m8_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vget_v)))
vint16m1_t vget_i16m1(vint16m2_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vget_v)))
vint16m1_t vget_i16m1(vint16m4_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vget_v)))
vint16m1_t vget_i16m1(vint16m8_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vget_v)))
vint32m1_t vget_i32m1(vint32m2_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vget_v)))
vint32m1_t vget_i32m1(vint32m4_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vget_v)))
vint32m1_t vget_i32m1(vint32m8_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vget_v)))
vuint8m1_t vget_u8m1(vuint8m2_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vget_v)))
vuint8m1_t vget_u8m1(vuint8m4_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vget_v)))
vuint8m1_t vget_u8m1(vuint8m8_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vget_v)))
vuint16m1_t vget_u16m1(vuint16m2_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vget_v)))
vuint16m1_t vget_u16m1(vuint16m4_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vget_v)))
vuint16m1_t vget_u16m1(vuint16m8_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vget_v)))
vuint32m1_t vget_u32m1(vuint32m2_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vget_v)))
vuint32m1_t vget_u32m1(vuint32m4_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vget_v)))
vuint32m1_t vget_u32m1(vuint32m8_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vget_v)))
vint8m2_t vget_i8m2(vint8m4_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vget_v)))
vint8m2_t vget_i8m2(vint8m8_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vget_v)))
vint16m2_t vget_i16m2(vint16m4_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vget_v)))
vint16m2_t vget_i16m2(vint16m8_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vget_v)))
vint32m2_t vget_i32m2(vint32m4_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vget_v)))
vint32m2_t vget_i32m2(vint32m8_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vget_v)))
vuint8m2_t vget_u8m2(vuint8m4_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vget_v)))
vuint8m2_t vget_u8m2(vuint8m8_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vget_v)))
vuint16m2_t vget_u16m2(vuint16m4_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vget_v)))
vuint16m2_t vget_u16m2(vuint16m8_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vget_v)))
vuint32m2_t vget_u32m2(vuint32m4_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vget_v)))
vuint32m2_t vget_u32m2(vuint32m8_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vget_v)))
vint8m4_t vget_i8m4(vint8m8_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vget_v)))
vint16m4_t vget_i16m4(vint16m8_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vget_v)))
vint32m4_t vget_i32m4(vint32m8_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vget_v)))
vuint8m4_t vget_u8m4(vuint8m8_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vget_v)))
vuint16m4_t vget_u16m4(vuint16m8_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vget_v)))
vuint32m4_t vget_u32m4(vuint32m8_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vset_v)))
vint8m2_t vset(vint8m2_t, size_t, vint8m1_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vset_v)))
vint16m2_t vset(vint16m2_t, size_t, vint16m1_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vset_v)))
vint32m2_t vset(vint32m2_t, size_t, vint32m1_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vset_v)))
vuint8m2_t vset(vuint8m2_t, size_t, vuint8m1_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vset_v)))
vuint16m2_t vset(vuint16m2_t, size_t, vuint16m1_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vset_v)))
vuint32m2_t vset(vuint32m2_t, size_t, vuint32m1_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vset_v)))
vint8m4_t vset(vint8m4_t, size_t, vint8m1_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vset_v)))
vint8m4_t vset(vint8m4_t, size_t, vint8m2_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vset_v)))
vint16m4_t vset(vint16m4_t, size_t, vint16m1_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vset_v)))
vint16m4_t vset(vint16m4_t, size_t, vint16m2_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vset_v)))
vint32m4_t vset(vint32m4_t, size_t, vint32m1_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vset_v)))
vint32m4_t vset(vint32m4_t, size_t, vint32m2_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vset_v)))
vuint8m4_t vset(vuint8m4_t, size_t, vuint8m1_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vset_v)))
vuint8m4_t vset(vuint8m4_t, size_t, vuint8m2_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vset_v)))
vuint16m4_t vset(vuint16m4_t, size_t, vuint16m1_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vset_v)))
vuint16m4_t vset(vuint16m4_t, size_t, vuint16m2_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vset_v)))
vuint32m4_t vset(vuint32m4_t, size_t, vuint32m1_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vset_v)))
vuint32m4_t vset(vuint32m4_t, size_t, vuint32m2_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vset_v)))
vint8m8_t vset(vint8m8_t, size_t, vint8m1_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vset_v)))
vint8m8_t vset(vint8m8_t, size_t, vint8m2_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vset_v)))
vint8m8_t vset(vint8m8_t, size_t, vint8m4_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vset_v)))
vint16m8_t vset(vint16m8_t, size_t, vint16m1_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vset_v)))
vint16m8_t vset(vint16m8_t, size_t, vint16m2_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vset_v)))
vint16m8_t vset(vint16m8_t, size_t, vint16m4_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vset_v)))
vint32m8_t vset(vint32m8_t, size_t, vint32m1_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vset_v)))
vint32m8_t vset(vint32m8_t, size_t, vint32m2_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vset_v)))
vint32m8_t vset(vint32m8_t, size_t, vint32m4_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vset_v)))
vuint8m8_t vset(vuint8m8_t, size_t, vuint8m1_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vset_v)))
vuint8m8_t vset(vuint8m8_t, size_t, vuint8m2_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vset_v)))
vuint8m8_t vset(vuint8m8_t, size_t, vuint8m4_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vset_v)))
vuint16m8_t vset(vuint16m8_t, size_t, vuint16m1_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vset_v)))
vuint16m8_t vset(vuint16m8_t, size_t, vuint16m2_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vset_v)))
vuint16m8_t vset(vuint16m8_t, size_t, vuint16m4_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vset_v)))
vuint32m8_t vset(vuint32m8_t, size_t, vuint32m1_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vset_v)))
vuint32m8_t vset(vuint32m8_t, size_t, vuint32m2_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vset_v)))
vuint32m8_t vset(vuint32m8_t, size_t, vuint32m4_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vsse8_v)))
void vsse8(uint8_t *, ptrdiff_t, vuint8m1_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vsse8_v_m)))
void vsse8(vbool8_t, uint8_t *, ptrdiff_t, vuint8m1_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vsse8_v)))
void vsse8(uint8_t *, ptrdiff_t, vuint8m2_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vsse8_v_m)))
void vsse8(vbool4_t, uint8_t *, ptrdiff_t, vuint8m2_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vsse8_v)))
void vsse8(uint8_t *, ptrdiff_t, vuint8m4_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vsse8_v_m)))
void vsse8(vbool2_t, uint8_t *, ptrdiff_t, vuint8m4_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vsse8_v)))
void vsse8(uint8_t *, ptrdiff_t, vuint8m8_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vsse8_v_m)))
void vsse8(vbool1_t, uint8_t *, ptrdiff_t, vuint8m8_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vsse8_v)))
void vsse8(uint8_t *, ptrdiff_t, vuint8mf2_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vsse8_v_m)))
void vsse8(vbool16_t, uint8_t *, ptrdiff_t, vuint8mf2_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vsse8_v)))
void vsse8(uint8_t *, ptrdiff_t, vuint8mf4_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vsse8_v_m)))
void vsse8(vbool32_t, uint8_t *, ptrdiff_t, vuint8mf4_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vsse8_v)))
void vsse8(uint8_t *, ptrdiff_t, vuint8mf8_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vsse8_v_m)))
void vsse8(vbool64_t, uint8_t *, ptrdiff_t, vuint8mf8_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vsuxei8_v)))
void vsuxei8(int8_t *, vuint8m1_t, vint8m1_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vsuxei8_v_m)))
void vsuxei8(vbool8_t, int8_t *, vuint8m1_t, vint8m1_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vsuxei8_v)))
void vsuxei8(int8_t *, vuint8m2_t, vint8m2_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vsuxei8_v_m)))
void vsuxei8(vbool4_t, int8_t *, vuint8m2_t, vint8m2_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vsuxei8_v)))
void vsuxei8(int8_t *, vuint8m4_t, vint8m4_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vsuxei8_v_m)))
void vsuxei8(vbool2_t, int8_t *, vuint8m4_t, vint8m4_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vsuxei8_v)))
void vsuxei8(int8_t *, vuint8m8_t, vint8m8_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vsuxei8_v_m)))
void vsuxei8(vbool1_t, int8_t *, vuint8m8_t, vint8m8_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vsuxei8_v)))
void vsuxei8(int8_t *, vuint8mf2_t, vint8mf2_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vsuxei8_v_m)))
void vsuxei8(vbool16_t, int8_t *, vuint8mf2_t, vint8mf2_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vsuxei8_v)))
void vsuxei8(int8_t *, vuint8mf4_t, vint8mf4_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vsuxei8_v_m)))
void vsuxei8(vbool32_t, int8_t *, vuint8mf4_t, vint8mf4_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vsuxei8_v)))
void vsuxei8(int8_t *, vuint8mf8_t, vint8mf8_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vsuxei8_v_m)))
void vsuxei8(vbool64_t, int8_t *, vuint8mf8_t, vint8mf8_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vsoxei8_v)))
void vsoxei8(int8_t *, vuint8m1_t, vint8m1_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vsoxei8_v_m)))
void vsoxei8(vbool8_t, int8_t *, vuint8m1_t, vint8m1_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vsoxei8_v)))
void vsoxei8(int8_t *, vuint8m2_t, vint8m2_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vsoxei8_v_m)))
void vsoxei8(vbool4_t, int8_t *, vuint8m2_t, vint8m2_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vsoxei8_v)))
void vsoxei8(int8_t *, vuint8m4_t, vint8m4_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vsoxei8_v_m)))
void vsoxei8(vbool2_t, int8_t *, vuint8m4_t, vint8m4_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vsoxei8_v)))
void vsoxei8(int8_t *, vuint8m8_t, vint8m8_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vsoxei8_v_m)))
void vsoxei8(vbool1_t, int8_t *, vuint8m8_t, vint8m8_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vsoxei8_v)))
void vsoxei8(int8_t *, vuint8mf2_t, vint8mf2_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vsoxei8_v_m)))
void vsoxei8(vbool16_t, int8_t *, vuint8mf2_t, vint8mf2_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vsoxei8_v)))
void vsoxei8(int8_t *, vuint8mf4_t, vint8mf4_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vsoxei8_v_m)))
void vsoxei8(vbool32_t, int8_t *, vuint8mf4_t, vint8mf4_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vsoxei8_v)))
void vsoxei8(int8_t *, vuint8mf8_t, vint8mf8_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vsoxei8_v_m)))
void vsoxei8(vbool64_t, int8_t *, vuint8mf8_t, vint8mf8_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vsoxei8_v)))
void vsoxei8(uint8_t *, vuint8m1_t, vuint8m1_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vsoxei8_v_m)))
void vsoxei8(vbool8_t, uint8_t *, vuint8m1_t, vuint8m1_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vsoxei8_v)))
void vsoxei8(uint8_t *, vuint8m2_t, vuint8m2_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vsoxei8_v_m)))
void vsoxei8(vbool4_t, uint8_t *, vuint8m2_t, vuint8m2_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vsoxei8_v)))
void vsoxei8(uint8_t *, vuint8m4_t, vuint8m4_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vsoxei8_v_m)))
void vsoxei8(vbool2_t, uint8_t *, vuint8m4_t, vuint8m4_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vsoxei8_v)))
void vsoxei8(uint8_t *, vuint8m8_t, vuint8m8_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vsoxei8_v_m)))
void vsoxei8(vbool1_t, uint8_t *, vuint8m8_t, vuint8m8_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vsoxei8_v)))
void vsoxei8(uint8_t *, vuint8mf2_t, vuint8mf2_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vsoxei8_v_m)))
void vsoxei8(vbool16_t, uint8_t *, vuint8mf2_t, vuint8mf2_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vsoxei8_v)))
void vsoxei8(uint8_t *, vuint8mf4_t, vuint8mf4_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vsoxei8_v_m)))
void vsoxei8(vbool32_t, uint8_t *, vuint8mf4_t, vuint8mf4_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vsoxei8_v)))
void vsoxei8(uint8_t *, vuint8mf8_t, vuint8mf8_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vsoxei8_v_m)))
void vsoxei8(vbool64_t, uint8_t *, vuint8mf8_t, vuint8mf8_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vsoxei16_v)))
void vsoxei16(int8_t *, vuint16m2_t, vint8m1_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vsoxei16_v_m)))
void vsoxei16(vbool8_t, int8_t *, vuint16m2_t, vint8m1_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vsoxei16_v)))
void vsoxei16(int8_t *, vuint16m4_t, vint8m2_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vsoxei16_v_m)))
void vsoxei16(vbool4_t, int8_t *, vuint16m4_t, vint8m2_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vsoxei16_v)))
void vsoxei16(int8_t *, vuint16m8_t, vint8m4_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vsoxei16_v_m)))
void vsoxei16(vbool2_t, int8_t *, vuint16m8_t, vint8m4_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vsoxei16_v)))
void vsoxei16(int8_t *, vuint16m1_t, vint8mf2_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vsoxei16_v_m)))
void vsoxei16(vbool16_t, int8_t *, vuint16m1_t, vint8mf2_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vsoxei16_v)))
void vsoxei16(int8_t *, vuint16mf2_t, vint8mf4_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vsoxei16_v_m)))
void vsoxei16(vbool32_t, int8_t *, vuint16mf2_t, vint8mf4_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vsoxei16_v)))
void vsoxei16(int8_t *, vuint16mf4_t, vint8mf8_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vsoxei16_v_m)))
void vsoxei16(vbool64_t, int8_t *, vuint16mf4_t, vint8mf8_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vsoxei16_v)))
void vsoxei16(uint8_t *, vuint16m2_t, vuint8m1_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vsoxei16_v_m)))
void vsoxei16(vbool8_t, uint8_t *, vuint16m2_t, vuint8m1_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vsoxei16_v)))
void vsoxei16(uint8_t *, vuint16m4_t, vuint8m2_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vsoxei16_v_m)))
void vsoxei16(vbool4_t, uint8_t *, vuint16m4_t, vuint8m2_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vsoxei16_v)))
void vsoxei16(uint8_t *, vuint16m8_t, vuint8m4_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vsoxei16_v_m)))
void vsoxei16(vbool2_t, uint8_t *, vuint16m8_t, vuint8m4_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vsoxei16_v)))
void vsoxei16(uint8_t *, vuint16m1_t, vuint8mf2_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vsoxei16_v_m)))
void vsoxei16(vbool16_t, uint8_t *, vuint16m1_t, vuint8mf2_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vsoxei16_v)))
void vsoxei16(uint8_t *, vuint16mf2_t, vuint8mf4_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vsoxei16_v_m)))
void vsoxei16(vbool32_t, uint8_t *, vuint16mf2_t, vuint8mf4_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vsoxei16_v)))
void vsoxei16(uint8_t *, vuint16mf4_t, vuint8mf8_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vsoxei16_v_m)))
void vsoxei16(vbool64_t, uint8_t *, vuint16mf4_t, vuint8mf8_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vsoxei32_v)))
void vsoxei32(int8_t *, vuint32m4_t, vint8m1_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vsoxei32_v_m)))
void vsoxei32(vbool8_t, int8_t *, vuint32m4_t, vint8m1_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vsoxei32_v)))
void vsoxei32(int8_t *, vuint32m8_t, vint8m2_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vsoxei32_v_m)))
void vsoxei32(vbool4_t, int8_t *, vuint32m8_t, vint8m2_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vsoxei32_v)))
void vsoxei32(int8_t *, vuint32m2_t, vint8mf2_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vsoxei32_v_m)))
void vsoxei32(vbool16_t, int8_t *, vuint32m2_t, vint8mf2_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vsoxei32_v)))
void vsoxei32(int8_t *, vuint32m1_t, vint8mf4_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vsoxei32_v_m)))
void vsoxei32(vbool32_t, int8_t *, vuint32m1_t, vint8mf4_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vsoxei32_v)))
void vsoxei32(int8_t *, vuint32mf2_t, vint8mf8_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vsoxei32_v_m)))
void vsoxei32(vbool64_t, int8_t *, vuint32mf2_t, vint8mf8_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vsoxei32_v)))
void vsoxei32(uint8_t *, vuint32m4_t, vuint8m1_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vsoxei32_v_m)))
void vsoxei32(vbool8_t, uint8_t *, vuint32m4_t, vuint8m1_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vsoxei32_v)))
void vsoxei32(uint8_t *, vuint32m8_t, vuint8m2_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vsoxei32_v_m)))
void vsoxei32(vbool4_t, uint8_t *, vuint32m8_t, vuint8m2_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vsoxei32_v)))
void vsoxei32(uint8_t *, vuint32m2_t, vuint8mf2_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vsoxei32_v_m)))
void vsoxei32(vbool16_t, uint8_t *, vuint32m2_t, vuint8mf2_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vsoxei32_v)))
void vsoxei32(uint8_t *, vuint32m1_t, vuint8mf4_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vsoxei32_v_m)))
void vsoxei32(vbool32_t, uint8_t *, vuint32m1_t, vuint8mf4_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vsoxei32_v)))
void vsoxei32(uint8_t *, vuint32mf2_t, vuint8mf8_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vsoxei32_v_m)))
void vsoxei32(vbool64_t, uint8_t *, vuint32mf2_t, vuint8mf8_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vsoxei8_v)))
void vsoxei8(int16_t *, vuint8mf2_t, vint16m1_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vsoxei8_v_m)))
void vsoxei8(vbool16_t, int16_t *, vuint8mf2_t, vint16m1_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vsoxei8_v)))
void vsoxei8(int16_t *, vuint8m1_t, vint16m2_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vsoxei8_v_m)))
void vsoxei8(vbool8_t, int16_t *, vuint8m1_t, vint16m2_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vsoxei8_v)))
void vsoxei8(int16_t *, vuint8m2_t, vint16m4_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vsoxei8_v_m)))
void vsoxei8(vbool4_t, int16_t *, vuint8m2_t, vint16m4_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vsoxei8_v)))
void vsoxei8(int16_t *, vuint8m4_t, vint16m8_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vsoxei8_v_m)))
void vsoxei8(vbool2_t, int16_t *, vuint8m4_t, vint16m8_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vsoxei8_v)))
void vsoxei8(int16_t *, vuint8mf4_t, vint16mf2_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vsoxei8_v_m)))
void vsoxei8(vbool32_t, int16_t *, vuint8mf4_t, vint16mf2_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vsoxei8_v)))
void vsoxei8(int16_t *, vuint8mf8_t, vint16mf4_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vsoxei8_v_m)))
void vsoxei8(vbool64_t, int16_t *, vuint8mf8_t, vint16mf4_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vsuxei8_v)))
void vsuxei8(uint8_t *, vuint8m1_t, vuint8m1_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vsuxei8_v_m)))
void vsuxei8(vbool8_t, uint8_t *, vuint8m1_t, vuint8m1_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vsuxei8_v)))
void vsuxei8(uint8_t *, vuint8m2_t, vuint8m2_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vsuxei8_v_m)))
void vsuxei8(vbool4_t, uint8_t *, vuint8m2_t, vuint8m2_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vsuxei8_v)))
void vsuxei8(uint8_t *, vuint8m4_t, vuint8m4_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vsuxei8_v_m)))
void vsuxei8(vbool2_t, uint8_t *, vuint8m4_t, vuint8m4_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vsuxei8_v)))
void vsuxei8(uint8_t *, vuint8m8_t, vuint8m8_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vsuxei8_v_m)))
void vsuxei8(vbool1_t, uint8_t *, vuint8m8_t, vuint8m8_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vsuxei8_v)))
void vsuxei8(uint8_t *, vuint8mf2_t, vuint8mf2_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vsuxei8_v_m)))
void vsuxei8(vbool16_t, uint8_t *, vuint8mf2_t, vuint8mf2_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vsuxei8_v)))
void vsuxei8(uint8_t *, vuint8mf4_t, vuint8mf4_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vsuxei8_v_m)))
void vsuxei8(vbool32_t, uint8_t *, vuint8mf4_t, vuint8mf4_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vsuxei8_v)))
void vsuxei8(uint8_t *, vuint8mf8_t, vuint8mf8_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vsuxei8_v_m)))
void vsuxei8(vbool64_t, uint8_t *, vuint8mf8_t, vuint8mf8_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vsoxei8_v)))
void vsoxei8(uint16_t *, vuint8mf2_t, vuint16m1_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vsoxei8_v_m)))
void vsoxei8(vbool16_t, uint16_t *, vuint8mf2_t, vuint16m1_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vsoxei8_v)))
void vsoxei8(uint16_t *, vuint8m1_t, vuint16m2_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vsoxei8_v_m)))
void vsoxei8(vbool8_t, uint16_t *, vuint8m1_t, vuint16m2_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vsoxei8_v)))
void vsoxei8(uint16_t *, vuint8m2_t, vuint16m4_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vsoxei8_v_m)))
void vsoxei8(vbool4_t, uint16_t *, vuint8m2_t, vuint16m4_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vsoxei8_v)))
void vsoxei8(uint16_t *, vuint8m4_t, vuint16m8_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vsoxei8_v_m)))
void vsoxei8(vbool2_t, uint16_t *, vuint8m4_t, vuint16m8_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vsoxei8_v)))
void vsoxei8(uint16_t *, vuint8mf4_t, vuint16mf2_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vsoxei8_v_m)))
void vsoxei8(vbool32_t, uint16_t *, vuint8mf4_t, vuint16mf2_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vsoxei8_v)))
void vsoxei8(uint16_t *, vuint8mf8_t, vuint16mf4_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vsoxei8_v_m)))
void vsoxei8(vbool64_t, uint16_t *, vuint8mf8_t, vuint16mf4_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vsoxei16_v)))
void vsoxei16(int16_t *, vuint16m1_t, vint16m1_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vsoxei16_v_m)))
void vsoxei16(vbool16_t, int16_t *, vuint16m1_t, vint16m1_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vsoxei16_v)))
void vsoxei16(int16_t *, vuint16m2_t, vint16m2_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vsoxei16_v_m)))
void vsoxei16(vbool8_t, int16_t *, vuint16m2_t, vint16m2_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vsoxei16_v)))
void vsoxei16(int16_t *, vuint16m4_t, vint16m4_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vsoxei16_v_m)))
void vsoxei16(vbool4_t, int16_t *, vuint16m4_t, vint16m4_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vsoxei16_v)))
void vsoxei16(int16_t *, vuint16m8_t, vint16m8_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vsoxei16_v_m)))
void vsoxei16(vbool2_t, int16_t *, vuint16m8_t, vint16m8_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vsoxei16_v)))
void vsoxei16(int16_t *, vuint16mf2_t, vint16mf2_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vsoxei16_v_m)))
void vsoxei16(vbool32_t, int16_t *, vuint16mf2_t, vint16mf2_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vsoxei16_v)))
void vsoxei16(int16_t *, vuint16mf4_t, vint16mf4_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vsoxei16_v_m)))
void vsoxei16(vbool64_t, int16_t *, vuint16mf4_t, vint16mf4_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vsoxei16_v)))
void vsoxei16(uint16_t *, vuint16m1_t, vuint16m1_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vsoxei16_v_m)))
void vsoxei16(vbool16_t, uint16_t *, vuint16m1_t, vuint16m1_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vsoxei16_v)))
void vsoxei16(uint16_t *, vuint16m2_t, vuint16m2_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vsoxei16_v_m)))
void vsoxei16(vbool8_t, uint16_t *, vuint16m2_t, vuint16m2_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vsoxei16_v)))
void vsoxei16(uint16_t *, vuint16m4_t, vuint16m4_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vsoxei16_v_m)))
void vsoxei16(vbool4_t, uint16_t *, vuint16m4_t, vuint16m4_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vsoxei16_v)))
void vsoxei16(uint16_t *, vuint16m8_t, vuint16m8_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vsoxei16_v_m)))
void vsoxei16(vbool2_t, uint16_t *, vuint16m8_t, vuint16m8_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vsoxei16_v)))
void vsoxei16(uint16_t *, vuint16mf2_t, vuint16mf2_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vsoxei16_v_m)))
void vsoxei16(vbool32_t, uint16_t *, vuint16mf2_t, vuint16mf2_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vsoxei16_v)))
void vsoxei16(uint16_t *, vuint16mf4_t, vuint16mf4_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vsoxei16_v_m)))
void vsoxei16(vbool64_t, uint16_t *, vuint16mf4_t, vuint16mf4_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vsoxei32_v)))
void vsoxei32(int16_t *, vuint32m2_t, vint16m1_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vsoxei32_v_m)))
void vsoxei32(vbool16_t, int16_t *, vuint32m2_t, vint16m1_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vsoxei32_v)))
void vsoxei32(int16_t *, vuint32m4_t, vint16m2_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vsoxei32_v_m)))
void vsoxei32(vbool8_t, int16_t *, vuint32m4_t, vint16m2_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vsoxei32_v)))
void vsoxei32(int16_t *, vuint32m8_t, vint16m4_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vsoxei32_v_m)))
void vsoxei32(vbool4_t, int16_t *, vuint32m8_t, vint16m4_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vsoxei32_v)))
void vsoxei32(int16_t *, vuint32m1_t, vint16mf2_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vsoxei32_v_m)))
void vsoxei32(vbool32_t, int16_t *, vuint32m1_t, vint16mf2_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vsoxei32_v)))
void vsoxei32(int16_t *, vuint32mf2_t, vint16mf4_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vsoxei32_v_m)))
void vsoxei32(vbool64_t, int16_t *, vuint32mf2_t, vint16mf4_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vsoxei32_v)))
void vsoxei32(uint16_t *, vuint32m2_t, vuint16m1_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vsoxei32_v_m)))
void vsoxei32(vbool16_t, uint16_t *, vuint32m2_t, vuint16m1_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vsoxei32_v)))
void vsoxei32(uint16_t *, vuint32m4_t, vuint16m2_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vsoxei32_v_m)))
void vsoxei32(vbool8_t, uint16_t *, vuint32m4_t, vuint16m2_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vsoxei32_v)))
void vsoxei32(uint16_t *, vuint32m8_t, vuint16m4_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vsoxei32_v_m)))
void vsoxei32(vbool4_t, uint16_t *, vuint32m8_t, vuint16m4_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vsoxei32_v)))
void vsoxei32(uint16_t *, vuint32m1_t, vuint16mf2_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vsoxei32_v_m)))
void vsoxei32(vbool32_t, uint16_t *, vuint32m1_t, vuint16mf2_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vsoxei32_v)))
void vsoxei32(uint16_t *, vuint32mf2_t, vuint16mf4_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vsoxei32_v_m)))
void vsoxei32(vbool64_t, uint16_t *, vuint32mf2_t, vuint16mf4_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vsoxei8_v)))
void vsoxei8(int32_t *, vuint8mf4_t, vint32m1_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vsoxei8_v_m)))
void vsoxei8(vbool32_t, int32_t *, vuint8mf4_t, vint32m1_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vsoxei8_v)))
void vsoxei8(int32_t *, vuint8mf2_t, vint32m2_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vsoxei8_v_m)))
void vsoxei8(vbool16_t, int32_t *, vuint8mf2_t, vint32m2_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vsoxei8_v)))
void vsoxei8(int32_t *, vuint8m1_t, vint32m4_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vsoxei8_v_m)))
void vsoxei8(vbool8_t, int32_t *, vuint8m1_t, vint32m4_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vsoxei8_v)))
void vsoxei8(int32_t *, vuint8m2_t, vint32m8_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vsoxei8_v_m)))
void vsoxei8(vbool4_t, int32_t *, vuint8m2_t, vint32m8_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vsoxei8_v)))
void vsoxei8(int32_t *, vuint8mf8_t, vint32mf2_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vsoxei8_v_m)))
void vsoxei8(vbool64_t, int32_t *, vuint8mf8_t, vint32mf2_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vsoxei8_v)))
void vsoxei8(uint32_t *, vuint8mf4_t, vuint32m1_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vsoxei8_v_m)))
void vsoxei8(vbool32_t, uint32_t *, vuint8mf4_t, vuint32m1_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vsoxei8_v)))
void vsoxei8(uint32_t *, vuint8mf2_t, vuint32m2_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vsoxei8_v_m)))
void vsoxei8(vbool16_t, uint32_t *, vuint8mf2_t, vuint32m2_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vsoxei8_v)))
void vsoxei8(uint32_t *, vuint8m1_t, vuint32m4_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vsoxei8_v_m)))
void vsoxei8(vbool8_t, uint32_t *, vuint8m1_t, vuint32m4_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vsoxei8_v)))
void vsoxei8(uint32_t *, vuint8m2_t, vuint32m8_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vsoxei8_v_m)))
void vsoxei8(vbool4_t, uint32_t *, vuint8m2_t, vuint32m8_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vsoxei8_v)))
void vsoxei8(uint32_t *, vuint8mf8_t, vuint32mf2_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vsoxei8_v_m)))
void vsoxei8(vbool64_t, uint32_t *, vuint8mf8_t, vuint32mf2_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vsoxei16_v)))
void vsoxei16(int32_t *, vuint16mf2_t, vint32m1_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vsoxei16_v_m)))
void vsoxei16(vbool32_t, int32_t *, vuint16mf2_t, vint32m1_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vsoxei16_v)))
void vsoxei16(int32_t *, vuint16m1_t, vint32m2_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vsoxei16_v_m)))
void vsoxei16(vbool16_t, int32_t *, vuint16m1_t, vint32m2_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vsoxei16_v)))
void vsoxei16(int32_t *, vuint16m2_t, vint32m4_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vsoxei16_v_m)))
void vsoxei16(vbool8_t, int32_t *, vuint16m2_t, vint32m4_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vsoxei16_v)))
void vsoxei16(int32_t *, vuint16m4_t, vint32m8_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vsoxei16_v_m)))
void vsoxei16(vbool4_t, int32_t *, vuint16m4_t, vint32m8_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vsoxei16_v)))
void vsoxei16(int32_t *, vuint16mf4_t, vint32mf2_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vsoxei16_v_m)))
void vsoxei16(vbool64_t, int32_t *, vuint16mf4_t, vint32mf2_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vsoxei16_v)))
void vsoxei16(uint32_t *, vuint16mf2_t, vuint32m1_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vsoxei16_v_m)))
void vsoxei16(vbool32_t, uint32_t *, vuint16mf2_t, vuint32m1_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vsoxei16_v)))
void vsoxei16(uint32_t *, vuint16m1_t, vuint32m2_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vsoxei16_v_m)))
void vsoxei16(vbool16_t, uint32_t *, vuint16m1_t, vuint32m2_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vsoxei16_v)))
void vsoxei16(uint32_t *, vuint16m2_t, vuint32m4_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vsoxei16_v_m)))
void vsoxei16(vbool8_t, uint32_t *, vuint16m2_t, vuint32m4_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vsoxei16_v)))
void vsoxei16(uint32_t *, vuint16m4_t, vuint32m8_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vsoxei16_v_m)))
void vsoxei16(vbool4_t, uint32_t *, vuint16m4_t, vuint32m8_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vsoxei16_v)))
void vsoxei16(uint32_t *, vuint16mf4_t, vuint32mf2_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vsoxei16_v_m)))
void vsoxei16(vbool64_t, uint32_t *, vuint16mf4_t, vuint32mf2_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vsoxei32_v)))
void vsoxei32(int32_t *, vuint32m1_t, vint32m1_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vsoxei32_v_m)))
void vsoxei32(vbool32_t, int32_t *, vuint32m1_t, vint32m1_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vsoxei32_v)))
void vsoxei32(int32_t *, vuint32m2_t, vint32m2_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vsoxei32_v_m)))
void vsoxei32(vbool16_t, int32_t *, vuint32m2_t, vint32m2_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vsoxei32_v)))
void vsoxei32(int32_t *, vuint32m4_t, vint32m4_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vsoxei32_v_m)))
void vsoxei32(vbool8_t, int32_t *, vuint32m4_t, vint32m4_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vsoxei32_v)))
void vsoxei32(int32_t *, vuint32m8_t, vint32m8_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vsoxei32_v_m)))
void vsoxei32(vbool4_t, int32_t *, vuint32m8_t, vint32m8_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vsoxei32_v)))
void vsoxei32(int32_t *, vuint32mf2_t, vint32mf2_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vsoxei32_v_m)))
void vsoxei32(vbool64_t, int32_t *, vuint32mf2_t, vint32mf2_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vsoxei32_v)))
void vsoxei32(uint32_t *, vuint32m1_t, vuint32m1_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vsoxei32_v_m)))
void vsoxei32(vbool32_t, uint32_t *, vuint32m1_t, vuint32m1_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vsoxei32_v)))
void vsoxei32(uint32_t *, vuint32m2_t, vuint32m2_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vsoxei32_v_m)))
void vsoxei32(vbool16_t, uint32_t *, vuint32m2_t, vuint32m2_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vsoxei32_v)))
void vsoxei32(uint32_t *, vuint32m4_t, vuint32m4_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vsoxei32_v_m)))
void vsoxei32(vbool8_t, uint32_t *, vuint32m4_t, vuint32m4_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vsoxei32_v)))
void vsoxei32(uint32_t *, vuint32m8_t, vuint32m8_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vsoxei32_v_m)))
void vsoxei32(vbool4_t, uint32_t *, vuint32m8_t, vuint32m8_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vsoxei32_v)))
void vsoxei32(uint32_t *, vuint32mf2_t, vuint32mf2_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vsoxei32_v_m)))
void vsoxei32(vbool64_t, uint32_t *, vuint32mf2_t, vuint32mf2_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vlseg2e8_v_m)))
void vlseg2e8(vint8m1_t *, vint8m1_t *, vbool8_t, vint8m1_t, vint8m1_t, const int8_t *, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vlseg2e8_v_m)))
void vlseg2e8(vint8m2_t *, vint8m2_t *, vbool4_t, vint8m2_t, vint8m2_t, const int8_t *, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vlseg2e8_v_m)))
void vlseg2e8(vint8m4_t *, vint8m4_t *, vbool2_t, vint8m4_t, vint8m4_t, const int8_t *, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vlseg2e8_v_m)))
void vlseg2e8(vint8mf2_t *, vint8mf2_t *, vbool16_t, vint8mf2_t, vint8mf2_t, const int8_t *, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vlseg2e8_v_m)))
void vlseg2e8(vint8mf4_t *, vint8mf4_t *, vbool32_t, vint8mf4_t, vint8mf4_t, const int8_t *, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vlseg2e8_v_m)))
void vlseg2e8(vint8mf8_t *, vint8mf8_t *, vbool64_t, vint8mf8_t, vint8mf8_t, const int8_t *, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vle16ff_v_m)))
vint16m1_t vle16ff(vbool16_t, vint16m1_t, const int16_t *, size_t *, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vle16ff_v_m)))
vint16m2_t vle16ff(vbool8_t, vint16m2_t, const int16_t *, size_t *, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vle16ff_v_m)))
vint16m4_t vle16ff(vbool4_t, vint16m4_t, const int16_t *, size_t *, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vle16ff_v_m)))
vint16m8_t vle16ff(vbool2_t, vint16m8_t, const int16_t *, size_t *, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vle16ff_v_m)))
vint16mf2_t vle16ff(vbool32_t, vint16mf2_t, const int16_t *, size_t *, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vle16ff_v_m)))
vint16mf4_t vle16ff(vbool64_t, vint16mf4_t, const int16_t *, size_t *, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vle16ff_v_m)))
vuint16m1_t vle16ff(vbool16_t, vuint16m1_t, const uint16_t *, size_t *, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vle16ff_v_m)))
vuint16m2_t vle16ff(vbool8_t, vuint16m2_t, const uint16_t *, size_t *, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vle16ff_v_m)))
vuint16m4_t vle16ff(vbool4_t, vuint16m4_t, const uint16_t *, size_t *, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vle16ff_v_m)))
vuint16m8_t vle16ff(vbool2_t, vuint16m8_t, const uint16_t *, size_t *, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vle16ff_v_m)))
vuint16mf2_t vle16ff(vbool32_t, vuint16mf2_t, const uint16_t *, size_t *, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vle16ff_v_m)))
vuint16mf4_t vle16ff(vbool64_t, vuint16mf4_t, const uint16_t *, size_t *, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vle32ff_v_m)))
vint32m1_t vle32ff(vbool32_t, vint32m1_t, const int32_t *, size_t *, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vle32ff_v_m)))
vint32m2_t vle32ff(vbool16_t, vint32m2_t, const int32_t *, size_t *, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vle32ff_v_m)))
vint32m4_t vle32ff(vbool8_t, vint32m4_t, const int32_t *, size_t *, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vle32ff_v_m)))
vint32m8_t vle32ff(vbool4_t, vint32m8_t, const int32_t *, size_t *, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vle32ff_v_m)))
vint32mf2_t vle32ff(vbool64_t, vint32mf2_t, const int32_t *, size_t *, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vle32ff_v_m)))
vuint32m1_t vle32ff(vbool32_t, vuint32m1_t, const uint32_t *, size_t *, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vle32ff_v_m)))
vuint32m2_t vle32ff(vbool16_t, vuint32m2_t, const uint32_t *, size_t *, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vle32ff_v_m)))
vuint32m4_t vle32ff(vbool8_t, vuint32m4_t, const uint32_t *, size_t *, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vle32ff_v_m)))
vuint32m8_t vle32ff(vbool4_t, vuint32m8_t, const uint32_t *, size_t *, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vle32ff_v_m)))
vuint32mf2_t vle32ff(vbool64_t, vuint32mf2_t, const uint32_t *, size_t *, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vlseg2e8_v_m)))
void vlseg2e8(vuint8m1_t *, vuint8m1_t *, vbool8_t, vuint8m1_t, vuint8m1_t, const uint8_t *, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vlseg2e8_v_m)))
void vlseg2e8(vuint8m2_t *, vuint8m2_t *, vbool4_t, vuint8m2_t, vuint8m2_t, const uint8_t *, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vlseg2e8_v_m)))
void vlseg2e8(vuint8m4_t *, vuint8m4_t *, vbool2_t, vuint8m4_t, vuint8m4_t, const uint8_t *, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vlseg2e8_v_m)))
void vlseg2e8(vuint8mf2_t *, vuint8mf2_t *, vbool16_t, vuint8mf2_t, vuint8mf2_t, const uint8_t *, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vlseg2e8_v_m)))
void vlseg2e8(vuint8mf4_t *, vuint8mf4_t *, vbool32_t, vuint8mf4_t, vuint8mf4_t, const uint8_t *, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vlseg2e8_v_m)))
void vlseg2e8(vuint8mf8_t *, vuint8mf8_t *, vbool64_t, vuint8mf8_t, vuint8mf8_t, const uint8_t *, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vlseg3e8_v_m)))
void vlseg3e8(vint8m1_t *, vint8m1_t *, vint8m1_t *, vbool8_t, vint8m1_t, vint8m1_t, vint8m1_t, const int8_t *, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vlseg3e8_v_m)))
void vlseg3e8(vint8m2_t *, vint8m2_t *, vint8m2_t *, vbool4_t, vint8m2_t, vint8m2_t, vint8m2_t, const int8_t *, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vlseg3e8_v_m)))
void vlseg3e8(vint8mf2_t *, vint8mf2_t *, vint8mf2_t *, vbool16_t, vint8mf2_t, vint8mf2_t, vint8mf2_t, const int8_t *, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vlseg3e8_v_m)))
void vlseg3e8(vint8mf4_t *, vint8mf4_t *, vint8mf4_t *, vbool32_t, vint8mf4_t, vint8mf4_t, vint8mf4_t, const int8_t *, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vlseg3e8_v_m)))
void vlseg3e8(vint8mf8_t *, vint8mf8_t *, vint8mf8_t *, vbool64_t, vint8mf8_t, vint8mf8_t, vint8mf8_t, const int8_t *, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vlseg3e8_v_m)))
void vlseg3e8(vuint8m1_t *, vuint8m1_t *, vuint8m1_t *, vbool8_t, vuint8m1_t, vuint8m1_t, vuint8m1_t, const uint8_t *, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vlseg3e8_v_m)))
void vlseg3e8(vuint8m2_t *, vuint8m2_t *, vuint8m2_t *, vbool4_t, vuint8m2_t, vuint8m2_t, vuint8m2_t, const uint8_t *, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vlseg3e8_v_m)))
void vlseg3e8(vuint8mf2_t *, vuint8mf2_t *, vuint8mf2_t *, vbool16_t, vuint8mf2_t, vuint8mf2_t, vuint8mf2_t, const uint8_t *, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vlseg3e8_v_m)))
void vlseg3e8(vuint8mf4_t *, vuint8mf4_t *, vuint8mf4_t *, vbool32_t, vuint8mf4_t, vuint8mf4_t, vuint8mf4_t, const uint8_t *, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vlseg3e8_v_m)))
void vlseg3e8(vuint8mf8_t *, vuint8mf8_t *, vuint8mf8_t *, vbool64_t, vuint8mf8_t, vuint8mf8_t, vuint8mf8_t, const uint8_t *, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vlseg4e8_v_m)))
void vlseg4e8(vint8m1_t *, vint8m1_t *, vint8m1_t *, vint8m1_t *, vbool8_t, vint8m1_t, vint8m1_t, vint8m1_t, vint8m1_t, const int8_t *, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vlseg4e8_v_m)))
void vlseg4e8(vint8m2_t *, vint8m2_t *, vint8m2_t *, vint8m2_t *, vbool4_t, vint8m2_t, vint8m2_t, vint8m2_t, vint8m2_t, const int8_t *, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vlseg4e8_v_m)))
void vlseg4e8(vint8mf2_t *, vint8mf2_t *, vint8mf2_t *, vint8mf2_t *, vbool16_t, vint8mf2_t, vint8mf2_t, vint8mf2_t, vint8mf2_t, const int8_t *, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vlseg4e8_v_m)))
void vlseg4e8(vint8mf4_t *, vint8mf4_t *, vint8mf4_t *, vint8mf4_t *, vbool32_t, vint8mf4_t, vint8mf4_t, vint8mf4_t, vint8mf4_t, const int8_t *, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vlseg4e8_v_m)))
void vlseg4e8(vint8mf8_t *, vint8mf8_t *, vint8mf8_t *, vint8mf8_t *, vbool64_t, vint8mf8_t, vint8mf8_t, vint8mf8_t, vint8mf8_t, const int8_t *, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vlseg4e8_v_m)))
void vlseg4e8(vuint8m1_t *, vuint8m1_t *, vuint8m1_t *, vuint8m1_t *, vbool8_t, vuint8m1_t, vuint8m1_t, vuint8m1_t, vuint8m1_t, const uint8_t *, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vlseg4e8_v_m)))
void vlseg4e8(vuint8m2_t *, vuint8m2_t *, vuint8m2_t *, vuint8m2_t *, vbool4_t, vuint8m2_t, vuint8m2_t, vuint8m2_t, vuint8m2_t, const uint8_t *, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vlseg4e8_v_m)))
void vlseg4e8(vuint8mf2_t *, vuint8mf2_t *, vuint8mf2_t *, vuint8mf2_t *, vbool16_t, vuint8mf2_t, vuint8mf2_t, vuint8mf2_t, vuint8mf2_t, const uint8_t *, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vlseg4e8_v_m)))
void vlseg4e8(vuint8mf4_t *, vuint8mf4_t *, vuint8mf4_t *, vuint8mf4_t *, vbool32_t, vuint8mf4_t, vuint8mf4_t, vuint8mf4_t, vuint8mf4_t, const uint8_t *, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vlseg4e8_v_m)))
void vlseg4e8(vuint8mf8_t *, vuint8mf8_t *, vuint8mf8_t *, vuint8mf8_t *, vbool64_t, vuint8mf8_t, vuint8mf8_t, vuint8mf8_t, vuint8mf8_t, const uint8_t *, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vlseg5e8_v_m)))
void vlseg5e8(vint8m1_t *, vint8m1_t *, vint8m1_t *, vint8m1_t *, vint8m1_t *, vbool8_t, vint8m1_t, vint8m1_t, vint8m1_t, vint8m1_t, vint8m1_t, const int8_t *, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vlseg5e8_v_m)))
void vlseg5e8(vint8mf2_t *, vint8mf2_t *, vint8mf2_t *, vint8mf2_t *, vint8mf2_t *, vbool16_t, vint8mf2_t, vint8mf2_t, vint8mf2_t, vint8mf2_t, vint8mf2_t, const int8_t *, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vlseg5e8_v_m)))
void vlseg5e8(vint8mf4_t *, vint8mf4_t *, vint8mf4_t *, vint8mf4_t *, vint8mf4_t *, vbool32_t, vint8mf4_t, vint8mf4_t, vint8mf4_t, vint8mf4_t, vint8mf4_t, const int8_t *, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vlseg5e8_v_m)))
void vlseg5e8(vint8mf8_t *, vint8mf8_t *, vint8mf8_t *, vint8mf8_t *, vint8mf8_t *, vbool64_t, vint8mf8_t, vint8mf8_t, vint8mf8_t, vint8mf8_t, vint8mf8_t, const int8_t *, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vle8_v_m)))
vint8m1_t vle8(vbool8_t, vint8m1_t, const int8_t *, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vle8_v_m)))
vint8m2_t vle8(vbool4_t, vint8m2_t, const int8_t *, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vle8_v_m)))
vint8m4_t vle8(vbool2_t, vint8m4_t, const int8_t *, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vle8_v_m)))
vint8m8_t vle8(vbool1_t, vint8m8_t, const int8_t *, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vle8_v_m)))
vint8mf2_t vle8(vbool16_t, vint8mf2_t, const int8_t *, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vle8_v_m)))
vint8mf4_t vle8(vbool32_t, vint8mf4_t, const int8_t *, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vle8_v_m)))
vint8mf8_t vle8(vbool64_t, vint8mf8_t, const int8_t *, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vlseg5e8_v_m)))
void vlseg5e8(vuint8m1_t *, vuint8m1_t *, vuint8m1_t *, vuint8m1_t *, vuint8m1_t *, vbool8_t, vuint8m1_t, vuint8m1_t, vuint8m1_t, vuint8m1_t, vuint8m1_t, const uint8_t *, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vlseg5e8_v_m)))
void vlseg5e8(vuint8mf2_t *, vuint8mf2_t *, vuint8mf2_t *, vuint8mf2_t *, vuint8mf2_t *, vbool16_t, vuint8mf2_t, vuint8mf2_t, vuint8mf2_t, vuint8mf2_t, vuint8mf2_t, const uint8_t *, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vlseg5e8_v_m)))
void vlseg5e8(vuint8mf4_t *, vuint8mf4_t *, vuint8mf4_t *, vuint8mf4_t *, vuint8mf4_t *, vbool32_t, vuint8mf4_t, vuint8mf4_t, vuint8mf4_t, vuint8mf4_t, vuint8mf4_t, const uint8_t *, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vlseg5e8_v_m)))
void vlseg5e8(vuint8mf8_t *, vuint8mf8_t *, vuint8mf8_t *, vuint8mf8_t *, vuint8mf8_t *, vbool64_t, vuint8mf8_t, vuint8mf8_t, vuint8mf8_t, vuint8mf8_t, vuint8mf8_t, const uint8_t *, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vlseg6e8_v_m)))
void vlseg6e8(vint8m1_t *, vint8m1_t *, vint8m1_t *, vint8m1_t *, vint8m1_t *, vint8m1_t *, vbool8_t, vint8m1_t, vint8m1_t, vint8m1_t, vint8m1_t, vint8m1_t, vint8m1_t, const int8_t *, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vlseg6e8_v_m)))
void vlseg6e8(vint8mf2_t *, vint8mf2_t *, vint8mf2_t *, vint8mf2_t *, vint8mf2_t *, vint8mf2_t *, vbool16_t, vint8mf2_t, vint8mf2_t, vint8mf2_t, vint8mf2_t, vint8mf2_t, vint8mf2_t, const int8_t *, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vlseg6e8_v_m)))
void vlseg6e8(vint8mf4_t *, vint8mf4_t *, vint8mf4_t *, vint8mf4_t *, vint8mf4_t *, vint8mf4_t *, vbool32_t, vint8mf4_t, vint8mf4_t, vint8mf4_t, vint8mf4_t, vint8mf4_t, vint8mf4_t, const int8_t *, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vlseg6e8_v_m)))
void vlseg6e8(vint8mf8_t *, vint8mf8_t *, vint8mf8_t *, vint8mf8_t *, vint8mf8_t *, vint8mf8_t *, vbool64_t, vint8mf8_t, vint8mf8_t, vint8mf8_t, vint8mf8_t, vint8mf8_t, vint8mf8_t, const int8_t *, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vlseg6e8_v_m)))
void vlseg6e8(vuint8m1_t *, vuint8m1_t *, vuint8m1_t *, vuint8m1_t *, vuint8m1_t *, vuint8m1_t *, vbool8_t, vuint8m1_t, vuint8m1_t, vuint8m1_t, vuint8m1_t, vuint8m1_t, vuint8m1_t, const uint8_t *, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vlseg6e8_v_m)))
void vlseg6e8(vuint8mf2_t *, vuint8mf2_t *, vuint8mf2_t *, vuint8mf2_t *, vuint8mf2_t *, vuint8mf2_t *, vbool16_t, vuint8mf2_t, vuint8mf2_t, vuint8mf2_t, vuint8mf2_t, vuint8mf2_t, vuint8mf2_t, const uint8_t *, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vlseg6e8_v_m)))
void vlseg6e8(vuint8mf4_t *, vuint8mf4_t *, vuint8mf4_t *, vuint8mf4_t *, vuint8mf4_t *, vuint8mf4_t *, vbool32_t, vuint8mf4_t, vuint8mf4_t, vuint8mf4_t, vuint8mf4_t, vuint8mf4_t, vuint8mf4_t, const uint8_t *, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vlseg6e8_v_m)))
void vlseg6e8(vuint8mf8_t *, vuint8mf8_t *, vuint8mf8_t *, vuint8mf8_t *, vuint8mf8_t *, vuint8mf8_t *, vbool64_t, vuint8mf8_t, vuint8mf8_t, vuint8mf8_t, vuint8mf8_t, vuint8mf8_t, vuint8mf8_t, const uint8_t *, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vlseg7e8_v_m)))
void vlseg7e8(vint8m1_t *, vint8m1_t *, vint8m1_t *, vint8m1_t *, vint8m1_t *, vint8m1_t *, vint8m1_t *, vbool8_t, vint8m1_t, vint8m1_t, vint8m1_t, vint8m1_t, vint8m1_t, vint8m1_t, vint8m1_t, const int8_t *, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vlseg7e8_v_m)))
void vlseg7e8(vint8mf2_t *, vint8mf2_t *, vint8mf2_t *, vint8mf2_t *, vint8mf2_t *, vint8mf2_t *, vint8mf2_t *, vbool16_t, vint8mf2_t, vint8mf2_t, vint8mf2_t, vint8mf2_t, vint8mf2_t, vint8mf2_t, vint8mf2_t, const int8_t *, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vlseg7e8_v_m)))
void vlseg7e8(vint8mf4_t *, vint8mf4_t *, vint8mf4_t *, vint8mf4_t *, vint8mf4_t *, vint8mf4_t *, vint8mf4_t *, vbool32_t, vint8mf4_t, vint8mf4_t, vint8mf4_t, vint8mf4_t, vint8mf4_t, vint8mf4_t, vint8mf4_t, const int8_t *, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vlseg7e8_v_m)))
void vlseg7e8(vint8mf8_t *, vint8mf8_t *, vint8mf8_t *, vint8mf8_t *, vint8mf8_t *, vint8mf8_t *, vint8mf8_t *, vbool64_t, vint8mf8_t, vint8mf8_t, vint8mf8_t, vint8mf8_t, vint8mf8_t, vint8mf8_t, vint8mf8_t, const int8_t *, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vlseg7e8_v_m)))
void vlseg7e8(vuint8m1_t *, vuint8m1_t *, vuint8m1_t *, vuint8m1_t *, vuint8m1_t *, vuint8m1_t *, vuint8m1_t *, vbool8_t, vuint8m1_t, vuint8m1_t, vuint8m1_t, vuint8m1_t, vuint8m1_t, vuint8m1_t, vuint8m1_t, const uint8_t *, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vlseg7e8_v_m)))
void vlseg7e8(vuint8mf2_t *, vuint8mf2_t *, vuint8mf2_t *, vuint8mf2_t *, vuint8mf2_t *, vuint8mf2_t *, vuint8mf2_t *, vbool16_t, vuint8mf2_t, vuint8mf2_t, vuint8mf2_t, vuint8mf2_t, vuint8mf2_t, vuint8mf2_t, vuint8mf2_t, const uint8_t *, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vlseg7e8_v_m)))
void vlseg7e8(vuint8mf4_t *, vuint8mf4_t *, vuint8mf4_t *, vuint8mf4_t *, vuint8mf4_t *, vuint8mf4_t *, vuint8mf4_t *, vbool32_t, vuint8mf4_t, vuint8mf4_t, vuint8mf4_t, vuint8mf4_t, vuint8mf4_t, vuint8mf4_t, vuint8mf4_t, const uint8_t *, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vlseg7e8_v_m)))
void vlseg7e8(vuint8mf8_t *, vuint8mf8_t *, vuint8mf8_t *, vuint8mf8_t *, vuint8mf8_t *, vuint8mf8_t *, vuint8mf8_t *, vbool64_t, vuint8mf8_t, vuint8mf8_t, vuint8mf8_t, vuint8mf8_t, vuint8mf8_t, vuint8mf8_t, vuint8mf8_t, const uint8_t *, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vlseg8e8_v_m)))
void vlseg8e8(vint8m1_t *, vint8m1_t *, vint8m1_t *, vint8m1_t *, vint8m1_t *, vint8m1_t *, vint8m1_t *, vint8m1_t *, vbool8_t, vint8m1_t, vint8m1_t, vint8m1_t, vint8m1_t, vint8m1_t, vint8m1_t, vint8m1_t, vint8m1_t, const int8_t *, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vlseg8e8_v_m)))
void vlseg8e8(vint8mf2_t *, vint8mf2_t *, vint8mf2_t *, vint8mf2_t *, vint8mf2_t *, vint8mf2_t *, vint8mf2_t *, vint8mf2_t *, vbool16_t, vint8mf2_t, vint8mf2_t, vint8mf2_t, vint8mf2_t, vint8mf2_t, vint8mf2_t, vint8mf2_t, vint8mf2_t, const int8_t *, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vlseg8e8_v_m)))
void vlseg8e8(vint8mf4_t *, vint8mf4_t *, vint8mf4_t *, vint8mf4_t *, vint8mf4_t *, vint8mf4_t *, vint8mf4_t *, vint8mf4_t *, vbool32_t, vint8mf4_t, vint8mf4_t, vint8mf4_t, vint8mf4_t, vint8mf4_t, vint8mf4_t, vint8mf4_t, vint8mf4_t, const int8_t *, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vlseg8e8_v_m)))
void vlseg8e8(vint8mf8_t *, vint8mf8_t *, vint8mf8_t *, vint8mf8_t *, vint8mf8_t *, vint8mf8_t *, vint8mf8_t *, vint8mf8_t *, vbool64_t, vint8mf8_t, vint8mf8_t, vint8mf8_t, vint8mf8_t, vint8mf8_t, vint8mf8_t, vint8mf8_t, vint8mf8_t, const int8_t *, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vlseg8e8_v_m)))
void vlseg8e8(vuint8m1_t *, vuint8m1_t *, vuint8m1_t *, vuint8m1_t *, vuint8m1_t *, vuint8m1_t *, vuint8m1_t *, vuint8m1_t *, vbool8_t, vuint8m1_t, vuint8m1_t, vuint8m1_t, vuint8m1_t, vuint8m1_t, vuint8m1_t, vuint8m1_t, vuint8m1_t, const uint8_t *, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vlseg8e8_v_m)))
void vlseg8e8(vuint8mf2_t *, vuint8mf2_t *, vuint8mf2_t *, vuint8mf2_t *, vuint8mf2_t *, vuint8mf2_t *, vuint8mf2_t *, vuint8mf2_t *, vbool16_t, vuint8mf2_t, vuint8mf2_t, vuint8mf2_t, vuint8mf2_t, vuint8mf2_t, vuint8mf2_t, vuint8mf2_t, vuint8mf2_t, const uint8_t *, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vlseg8e8_v_m)))
void vlseg8e8(vuint8mf4_t *, vuint8mf4_t *, vuint8mf4_t *, vuint8mf4_t *, vuint8mf4_t *, vuint8mf4_t *, vuint8mf4_t *, vuint8mf4_t *, vbool32_t, vuint8mf4_t, vuint8mf4_t, vuint8mf4_t, vuint8mf4_t, vuint8mf4_t, vuint8mf4_t, vuint8mf4_t, vuint8mf4_t, const uint8_t *, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vlseg8e8_v_m)))
void vlseg8e8(vuint8mf8_t *, vuint8mf8_t *, vuint8mf8_t *, vuint8mf8_t *, vuint8mf8_t *, vuint8mf8_t *, vuint8mf8_t *, vuint8mf8_t *, vbool64_t, vuint8mf8_t, vuint8mf8_t, vuint8mf8_t, vuint8mf8_t, vuint8mf8_t, vuint8mf8_t, vuint8mf8_t, vuint8mf8_t, const uint8_t *, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vlseg2e16_v_m)))
void vlseg2e16(vint16m1_t *, vint16m1_t *, vbool16_t, vint16m1_t, vint16m1_t, const int16_t *, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vlseg2e16_v_m)))
void vlseg2e16(vint16m2_t *, vint16m2_t *, vbool8_t, vint16m2_t, vint16m2_t, const int16_t *, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vlseg2e16_v_m)))
void vlseg2e16(vint16m4_t *, vint16m4_t *, vbool4_t, vint16m4_t, vint16m4_t, const int16_t *, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vlseg2e16_v_m)))
void vlseg2e16(vint16mf2_t *, vint16mf2_t *, vbool32_t, vint16mf2_t, vint16mf2_t, const int16_t *, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vlseg2e16_v_m)))
void vlseg2e16(vint16mf4_t *, vint16mf4_t *, vbool64_t, vint16mf4_t, vint16mf4_t, const int16_t *, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vlseg2e16_v_m)))
void vlseg2e16(vuint16m1_t *, vuint16m1_t *, vbool16_t, vuint16m1_t, vuint16m1_t, const uint16_t *, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vlseg2e16_v_m)))
void vlseg2e16(vuint16m2_t *, vuint16m2_t *, vbool8_t, vuint16m2_t, vuint16m2_t, const uint16_t *, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vlseg2e16_v_m)))
void vlseg2e16(vuint16m4_t *, vuint16m4_t *, vbool4_t, vuint16m4_t, vuint16m4_t, const uint16_t *, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vlseg2e16_v_m)))
void vlseg2e16(vuint16mf2_t *, vuint16mf2_t *, vbool32_t, vuint16mf2_t, vuint16mf2_t, const uint16_t *, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vlseg2e16_v_m)))
void vlseg2e16(vuint16mf4_t *, vuint16mf4_t *, vbool64_t, vuint16mf4_t, vuint16mf4_t, const uint16_t *, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vlseg3e16_v_m)))
void vlseg3e16(vint16m1_t *, vint16m1_t *, vint16m1_t *, vbool16_t, vint16m1_t, vint16m1_t, vint16m1_t, const int16_t *, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vlseg3e16_v_m)))
void vlseg3e16(vint16m2_t *, vint16m2_t *, vint16m2_t *, vbool8_t, vint16m2_t, vint16m2_t, vint16m2_t, const int16_t *, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vlseg3e16_v_m)))
void vlseg3e16(vint16mf2_t *, vint16mf2_t *, vint16mf2_t *, vbool32_t, vint16mf2_t, vint16mf2_t, vint16mf2_t, const int16_t *, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vlseg3e16_v_m)))
void vlseg3e16(vint16mf4_t *, vint16mf4_t *, vint16mf4_t *, vbool64_t, vint16mf4_t, vint16mf4_t, vint16mf4_t, const int16_t *, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vlseg3e16_v_m)))
void vlseg3e16(vuint16m1_t *, vuint16m1_t *, vuint16m1_t *, vbool16_t, vuint16m1_t, vuint16m1_t, vuint16m1_t, const uint16_t *, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vlseg3e16_v_m)))
void vlseg3e16(vuint16m2_t *, vuint16m2_t *, vuint16m2_t *, vbool8_t, vuint16m2_t, vuint16m2_t, vuint16m2_t, const uint16_t *, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vlseg3e16_v_m)))
void vlseg3e16(vuint16mf2_t *, vuint16mf2_t *, vuint16mf2_t *, vbool32_t, vuint16mf2_t, vuint16mf2_t, vuint16mf2_t, const uint16_t *, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vlseg3e16_v_m)))
void vlseg3e16(vuint16mf4_t *, vuint16mf4_t *, vuint16mf4_t *, vbool64_t, vuint16mf4_t, vuint16mf4_t, vuint16mf4_t, const uint16_t *, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vlseg4e16_v_m)))
void vlseg4e16(vint16m1_t *, vint16m1_t *, vint16m1_t *, vint16m1_t *, vbool16_t, vint16m1_t, vint16m1_t, vint16m1_t, vint16m1_t, const int16_t *, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vlseg4e16_v_m)))
void vlseg4e16(vint16m2_t *, vint16m2_t *, vint16m2_t *, vint16m2_t *, vbool8_t, vint16m2_t, vint16m2_t, vint16m2_t, vint16m2_t, const int16_t *, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vlseg4e16_v_m)))
void vlseg4e16(vint16mf2_t *, vint16mf2_t *, vint16mf2_t *, vint16mf2_t *, vbool32_t, vint16mf2_t, vint16mf2_t, vint16mf2_t, vint16mf2_t, const int16_t *, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vlseg4e16_v_m)))
void vlseg4e16(vint16mf4_t *, vint16mf4_t *, vint16mf4_t *, vint16mf4_t *, vbool64_t, vint16mf4_t, vint16mf4_t, vint16mf4_t, vint16mf4_t, const int16_t *, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vlseg4e16_v_m)))
void vlseg4e16(vuint16m1_t *, vuint16m1_t *, vuint16m1_t *, vuint16m1_t *, vbool16_t, vuint16m1_t, vuint16m1_t, vuint16m1_t, vuint16m1_t, const uint16_t *, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vlseg4e16_v_m)))
void vlseg4e16(vuint16m2_t *, vuint16m2_t *, vuint16m2_t *, vuint16m2_t *, vbool8_t, vuint16m2_t, vuint16m2_t, vuint16m2_t, vuint16m2_t, const uint16_t *, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vlseg4e16_v_m)))
void vlseg4e16(vuint16mf2_t *, vuint16mf2_t *, vuint16mf2_t *, vuint16mf2_t *, vbool32_t, vuint16mf2_t, vuint16mf2_t, vuint16mf2_t, vuint16mf2_t, const uint16_t *, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vlseg4e16_v_m)))
void vlseg4e16(vuint16mf4_t *, vuint16mf4_t *, vuint16mf4_t *, vuint16mf4_t *, vbool64_t, vuint16mf4_t, vuint16mf4_t, vuint16mf4_t, vuint16mf4_t, const uint16_t *, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vlseg5e16_v_m)))
void vlseg5e16(vint16m1_t *, vint16m1_t *, vint16m1_t *, vint16m1_t *, vint16m1_t *, vbool16_t, vint16m1_t, vint16m1_t, vint16m1_t, vint16m1_t, vint16m1_t, const int16_t *, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vlseg5e16_v_m)))
void vlseg5e16(vint16mf2_t *, vint16mf2_t *, vint16mf2_t *, vint16mf2_t *, vint16mf2_t *, vbool32_t, vint16mf2_t, vint16mf2_t, vint16mf2_t, vint16mf2_t, vint16mf2_t, const int16_t *, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vlseg5e16_v_m)))
void vlseg5e16(vint16mf4_t *, vint16mf4_t *, vint16mf4_t *, vint16mf4_t *, vint16mf4_t *, vbool64_t, vint16mf4_t, vint16mf4_t, vint16mf4_t, vint16mf4_t, vint16mf4_t, const int16_t *, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vlseg5e16_v_m)))
void vlseg5e16(vuint16m1_t *, vuint16m1_t *, vuint16m1_t *, vuint16m1_t *, vuint16m1_t *, vbool16_t, vuint16m1_t, vuint16m1_t, vuint16m1_t, vuint16m1_t, vuint16m1_t, const uint16_t *, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vlseg5e16_v_m)))
void vlseg5e16(vuint16mf2_t *, vuint16mf2_t *, vuint16mf2_t *, vuint16mf2_t *, vuint16mf2_t *, vbool32_t, vuint16mf2_t, vuint16mf2_t, vuint16mf2_t, vuint16mf2_t, vuint16mf2_t, const uint16_t *, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vlseg5e16_v_m)))
void vlseg5e16(vuint16mf4_t *, vuint16mf4_t *, vuint16mf4_t *, vuint16mf4_t *, vuint16mf4_t *, vbool64_t, vuint16mf4_t, vuint16mf4_t, vuint16mf4_t, vuint16mf4_t, vuint16mf4_t, const uint16_t *, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vlseg6e16_v_m)))
void vlseg6e16(vint16m1_t *, vint16m1_t *, vint16m1_t *, vint16m1_t *, vint16m1_t *, vint16m1_t *, vbool16_t, vint16m1_t, vint16m1_t, vint16m1_t, vint16m1_t, vint16m1_t, vint16m1_t, const int16_t *, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vlseg6e16_v_m)))
void vlseg6e16(vint16mf2_t *, vint16mf2_t *, vint16mf2_t *, vint16mf2_t *, vint16mf2_t *, vint16mf2_t *, vbool32_t, vint16mf2_t, vint16mf2_t, vint16mf2_t, vint16mf2_t, vint16mf2_t, vint16mf2_t, const int16_t *, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vlseg6e16_v_m)))
void vlseg6e16(vint16mf4_t *, vint16mf4_t *, vint16mf4_t *, vint16mf4_t *, vint16mf4_t *, vint16mf4_t *, vbool64_t, vint16mf4_t, vint16mf4_t, vint16mf4_t, vint16mf4_t, vint16mf4_t, vint16mf4_t, const int16_t *, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vlseg6e16_v_m)))
void vlseg6e16(vuint16m1_t *, vuint16m1_t *, vuint16m1_t *, vuint16m1_t *, vuint16m1_t *, vuint16m1_t *, vbool16_t, vuint16m1_t, vuint16m1_t, vuint16m1_t, vuint16m1_t, vuint16m1_t, vuint16m1_t, const uint16_t *, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vlseg6e16_v_m)))
void vlseg6e16(vuint16mf2_t *, vuint16mf2_t *, vuint16mf2_t *, vuint16mf2_t *, vuint16mf2_t *, vuint16mf2_t *, vbool32_t, vuint16mf2_t, vuint16mf2_t, vuint16mf2_t, vuint16mf2_t, vuint16mf2_t, vuint16mf2_t, const uint16_t *, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vlseg6e16_v_m)))
void vlseg6e16(vuint16mf4_t *, vuint16mf4_t *, vuint16mf4_t *, vuint16mf4_t *, vuint16mf4_t *, vuint16mf4_t *, vbool64_t, vuint16mf4_t, vuint16mf4_t, vuint16mf4_t, vuint16mf4_t, vuint16mf4_t, vuint16mf4_t, const uint16_t *, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vlseg7e16_v_m)))
void vlseg7e16(vint16m1_t *, vint16m1_t *, vint16m1_t *, vint16m1_t *, vint16m1_t *, vint16m1_t *, vint16m1_t *, vbool16_t, vint16m1_t, vint16m1_t, vint16m1_t, vint16m1_t, vint16m1_t, vint16m1_t, vint16m1_t, const int16_t *, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vlseg7e16_v_m)))
void vlseg7e16(vint16mf2_t *, vint16mf2_t *, vint16mf2_t *, vint16mf2_t *, vint16mf2_t *, vint16mf2_t *, vint16mf2_t *, vbool32_t, vint16mf2_t, vint16mf2_t, vint16mf2_t, vint16mf2_t, vint16mf2_t, vint16mf2_t, vint16mf2_t, const int16_t *, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vlseg7e16_v_m)))
void vlseg7e16(vint16mf4_t *, vint16mf4_t *, vint16mf4_t *, vint16mf4_t *, vint16mf4_t *, vint16mf4_t *, vint16mf4_t *, vbool64_t, vint16mf4_t, vint16mf4_t, vint16mf4_t, vint16mf4_t, vint16mf4_t, vint16mf4_t, vint16mf4_t, const int16_t *, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vlseg7e16_v_m)))
void vlseg7e16(vuint16m1_t *, vuint16m1_t *, vuint16m1_t *, vuint16m1_t *, vuint16m1_t *, vuint16m1_t *, vuint16m1_t *, vbool16_t, vuint16m1_t, vuint16m1_t, vuint16m1_t, vuint16m1_t, vuint16m1_t, vuint16m1_t, vuint16m1_t, const uint16_t *, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vlseg7e16_v_m)))
void vlseg7e16(vuint16mf2_t *, vuint16mf2_t *, vuint16mf2_t *, vuint16mf2_t *, vuint16mf2_t *, vuint16mf2_t *, vuint16mf2_t *, vbool32_t, vuint16mf2_t, vuint16mf2_t, vuint16mf2_t, vuint16mf2_t, vuint16mf2_t, vuint16mf2_t, vuint16mf2_t, const uint16_t *, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vlseg7e16_v_m)))
void vlseg7e16(vuint16mf4_t *, vuint16mf4_t *, vuint16mf4_t *, vuint16mf4_t *, vuint16mf4_t *, vuint16mf4_t *, vuint16mf4_t *, vbool64_t, vuint16mf4_t, vuint16mf4_t, vuint16mf4_t, vuint16mf4_t, vuint16mf4_t, vuint16mf4_t, vuint16mf4_t, const uint16_t *, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vlseg8e16_v_m)))
void vlseg8e16(vint16m1_t *, vint16m1_t *, vint16m1_t *, vint16m1_t *, vint16m1_t *, vint16m1_t *, vint16m1_t *, vint16m1_t *, vbool16_t, vint16m1_t, vint16m1_t, vint16m1_t, vint16m1_t, vint16m1_t, vint16m1_t, vint16m1_t, vint16m1_t, const int16_t *, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vlseg8e16_v_m)))
void vlseg8e16(vint16mf2_t *, vint16mf2_t *, vint16mf2_t *, vint16mf2_t *, vint16mf2_t *, vint16mf2_t *, vint16mf2_t *, vint16mf2_t *, vbool32_t, vint16mf2_t, vint16mf2_t, vint16mf2_t, vint16mf2_t, vint16mf2_t, vint16mf2_t, vint16mf2_t, vint16mf2_t, const int16_t *, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vlseg8e16_v_m)))
void vlseg8e16(vint16mf4_t *, vint16mf4_t *, vint16mf4_t *, vint16mf4_t *, vint16mf4_t *, vint16mf4_t *, vint16mf4_t *, vint16mf4_t *, vbool64_t, vint16mf4_t, vint16mf4_t, vint16mf4_t, vint16mf4_t, vint16mf4_t, vint16mf4_t, vint16mf4_t, vint16mf4_t, const int16_t *, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vlseg8e16_v_m)))
void vlseg8e16(vuint16m1_t *, vuint16m1_t *, vuint16m1_t *, vuint16m1_t *, vuint16m1_t *, vuint16m1_t *, vuint16m1_t *, vuint16m1_t *, vbool16_t, vuint16m1_t, vuint16m1_t, vuint16m1_t, vuint16m1_t, vuint16m1_t, vuint16m1_t, vuint16m1_t, vuint16m1_t, const uint16_t *, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vlseg8e16_v_m)))
void vlseg8e16(vuint16mf2_t *, vuint16mf2_t *, vuint16mf2_t *, vuint16mf2_t *, vuint16mf2_t *, vuint16mf2_t *, vuint16mf2_t *, vuint16mf2_t *, vbool32_t, vuint16mf2_t, vuint16mf2_t, vuint16mf2_t, vuint16mf2_t, vuint16mf2_t, vuint16mf2_t, vuint16mf2_t, vuint16mf2_t, const uint16_t *, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vlseg8e16_v_m)))
void vlseg8e16(vuint16mf4_t *, vuint16mf4_t *, vuint16mf4_t *, vuint16mf4_t *, vuint16mf4_t *, vuint16mf4_t *, vuint16mf4_t *, vuint16mf4_t *, vbool64_t, vuint16mf4_t, vuint16mf4_t, vuint16mf4_t, vuint16mf4_t, vuint16mf4_t, vuint16mf4_t, vuint16mf4_t, vuint16mf4_t, const uint16_t *, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vlseg2e32_v_m)))
void vlseg2e32(vint32m1_t *, vint32m1_t *, vbool32_t, vint32m1_t, vint32m1_t, const int32_t *, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vlseg2e32_v_m)))
void vlseg2e32(vint32m2_t *, vint32m2_t *, vbool16_t, vint32m2_t, vint32m2_t, const int32_t *, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vlseg2e32_v_m)))
void vlseg2e32(vint32m4_t *, vint32m4_t *, vbool8_t, vint32m4_t, vint32m4_t, const int32_t *, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vlseg2e32_v_m)))
void vlseg2e32(vint32mf2_t *, vint32mf2_t *, vbool64_t, vint32mf2_t, vint32mf2_t, const int32_t *, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vlseg2e32_v_m)))
void vlseg2e32(vuint32m1_t *, vuint32m1_t *, vbool32_t, vuint32m1_t, vuint32m1_t, const uint32_t *, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vlseg2e32_v_m)))
void vlseg2e32(vuint32m2_t *, vuint32m2_t *, vbool16_t, vuint32m2_t, vuint32m2_t, const uint32_t *, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vlseg2e32_v_m)))
void vlseg2e32(vuint32m4_t *, vuint32m4_t *, vbool8_t, vuint32m4_t, vuint32m4_t, const uint32_t *, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vlseg2e32_v_m)))
void vlseg2e32(vuint32mf2_t *, vuint32mf2_t *, vbool64_t, vuint32mf2_t, vuint32mf2_t, const uint32_t *, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vlseg3e32_v_m)))
void vlseg3e32(vint32m1_t *, vint32m1_t *, vint32m1_t *, vbool32_t, vint32m1_t, vint32m1_t, vint32m1_t, const int32_t *, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vlseg3e32_v_m)))
void vlseg3e32(vint32m2_t *, vint32m2_t *, vint32m2_t *, vbool16_t, vint32m2_t, vint32m2_t, vint32m2_t, const int32_t *, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vlseg3e32_v_m)))
void vlseg3e32(vint32mf2_t *, vint32mf2_t *, vint32mf2_t *, vbool64_t, vint32mf2_t, vint32mf2_t, vint32mf2_t, const int32_t *, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vlseg3e32_v_m)))
void vlseg3e32(vuint32m1_t *, vuint32m1_t *, vuint32m1_t *, vbool32_t, vuint32m1_t, vuint32m1_t, vuint32m1_t, const uint32_t *, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vlseg3e32_v_m)))
void vlseg3e32(vuint32m2_t *, vuint32m2_t *, vuint32m2_t *, vbool16_t, vuint32m2_t, vuint32m2_t, vuint32m2_t, const uint32_t *, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vlseg3e32_v_m)))
void vlseg3e32(vuint32mf2_t *, vuint32mf2_t *, vuint32mf2_t *, vbool64_t, vuint32mf2_t, vuint32mf2_t, vuint32mf2_t, const uint32_t *, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vlseg4e32_v_m)))
void vlseg4e32(vint32m1_t *, vint32m1_t *, vint32m1_t *, vint32m1_t *, vbool32_t, vint32m1_t, vint32m1_t, vint32m1_t, vint32m1_t, const int32_t *, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vlseg4e32_v_m)))
void vlseg4e32(vint32m2_t *, vint32m2_t *, vint32m2_t *, vint32m2_t *, vbool16_t, vint32m2_t, vint32m2_t, vint32m2_t, vint32m2_t, const int32_t *, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vlseg4e32_v_m)))
void vlseg4e32(vint32mf2_t *, vint32mf2_t *, vint32mf2_t *, vint32mf2_t *, vbool64_t, vint32mf2_t, vint32mf2_t, vint32mf2_t, vint32mf2_t, const int32_t *, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vlseg4e32_v_m)))
void vlseg4e32(vuint32m1_t *, vuint32m1_t *, vuint32m1_t *, vuint32m1_t *, vbool32_t, vuint32m1_t, vuint32m1_t, vuint32m1_t, vuint32m1_t, const uint32_t *, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vlseg4e32_v_m)))
void vlseg4e32(vuint32m2_t *, vuint32m2_t *, vuint32m2_t *, vuint32m2_t *, vbool16_t, vuint32m2_t, vuint32m2_t, vuint32m2_t, vuint32m2_t, const uint32_t *, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vlseg4e32_v_m)))
void vlseg4e32(vuint32mf2_t *, vuint32mf2_t *, vuint32mf2_t *, vuint32mf2_t *, vbool64_t, vuint32mf2_t, vuint32mf2_t, vuint32mf2_t, vuint32mf2_t, const uint32_t *, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vlseg5e32_v_m)))
void vlseg5e32(vint32m1_t *, vint32m1_t *, vint32m1_t *, vint32m1_t *, vint32m1_t *, vbool32_t, vint32m1_t, vint32m1_t, vint32m1_t, vint32m1_t, vint32m1_t, const int32_t *, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vlseg5e32_v_m)))
void vlseg5e32(vint32mf2_t *, vint32mf2_t *, vint32mf2_t *, vint32mf2_t *, vint32mf2_t *, vbool64_t, vint32mf2_t, vint32mf2_t, vint32mf2_t, vint32mf2_t, vint32mf2_t, const int32_t *, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vlseg5e32_v_m)))
void vlseg5e32(vuint32m1_t *, vuint32m1_t *, vuint32m1_t *, vuint32m1_t *, vuint32m1_t *, vbool32_t, vuint32m1_t, vuint32m1_t, vuint32m1_t, vuint32m1_t, vuint32m1_t, const uint32_t *, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vlseg5e32_v_m)))
void vlseg5e32(vuint32mf2_t *, vuint32mf2_t *, vuint32mf2_t *, vuint32mf2_t *, vuint32mf2_t *, vbool64_t, vuint32mf2_t, vuint32mf2_t, vuint32mf2_t, vuint32mf2_t, vuint32mf2_t, const uint32_t *, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vlseg6e32_v_m)))
void vlseg6e32(vint32m1_t *, vint32m1_t *, vint32m1_t *, vint32m1_t *, vint32m1_t *, vint32m1_t *, vbool32_t, vint32m1_t, vint32m1_t, vint32m1_t, vint32m1_t, vint32m1_t, vint32m1_t, const int32_t *, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vlseg6e32_v_m)))
void vlseg6e32(vint32mf2_t *, vint32mf2_t *, vint32mf2_t *, vint32mf2_t *, vint32mf2_t *, vint32mf2_t *, vbool64_t, vint32mf2_t, vint32mf2_t, vint32mf2_t, vint32mf2_t, vint32mf2_t, vint32mf2_t, const int32_t *, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vlseg6e32_v_m)))
void vlseg6e32(vuint32m1_t *, vuint32m1_t *, vuint32m1_t *, vuint32m1_t *, vuint32m1_t *, vuint32m1_t *, vbool32_t, vuint32m1_t, vuint32m1_t, vuint32m1_t, vuint32m1_t, vuint32m1_t, vuint32m1_t, const uint32_t *, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vlseg6e32_v_m)))
void vlseg6e32(vuint32mf2_t *, vuint32mf2_t *, vuint32mf2_t *, vuint32mf2_t *, vuint32mf2_t *, vuint32mf2_t *, vbool64_t, vuint32mf2_t, vuint32mf2_t, vuint32mf2_t, vuint32mf2_t, vuint32mf2_t, vuint32mf2_t, const uint32_t *, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vlseg7e32_v_m)))
void vlseg7e32(vint32m1_t *, vint32m1_t *, vint32m1_t *, vint32m1_t *, vint32m1_t *, vint32m1_t *, vint32m1_t *, vbool32_t, vint32m1_t, vint32m1_t, vint32m1_t, vint32m1_t, vint32m1_t, vint32m1_t, vint32m1_t, const int32_t *, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vlseg7e32_v_m)))
void vlseg7e32(vint32mf2_t *, vint32mf2_t *, vint32mf2_t *, vint32mf2_t *, vint32mf2_t *, vint32mf2_t *, vint32mf2_t *, vbool64_t, vint32mf2_t, vint32mf2_t, vint32mf2_t, vint32mf2_t, vint32mf2_t, vint32mf2_t, vint32mf2_t, const int32_t *, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vlseg7e32_v_m)))
void vlseg7e32(vuint32m1_t *, vuint32m1_t *, vuint32m1_t *, vuint32m1_t *, vuint32m1_t *, vuint32m1_t *, vuint32m1_t *, vbool32_t, vuint32m1_t, vuint32m1_t, vuint32m1_t, vuint32m1_t, vuint32m1_t, vuint32m1_t, vuint32m1_t, const uint32_t *, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vlseg7e32_v_m)))
void vlseg7e32(vuint32mf2_t *, vuint32mf2_t *, vuint32mf2_t *, vuint32mf2_t *, vuint32mf2_t *, vuint32mf2_t *, vuint32mf2_t *, vbool64_t, vuint32mf2_t, vuint32mf2_t, vuint32mf2_t, vuint32mf2_t, vuint32mf2_t, vuint32mf2_t, vuint32mf2_t, const uint32_t *, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vlseg8e32_v_m)))
void vlseg8e32(vint32m1_t *, vint32m1_t *, vint32m1_t *, vint32m1_t *, vint32m1_t *, vint32m1_t *, vint32m1_t *, vint32m1_t *, vbool32_t, vint32m1_t, vint32m1_t, vint32m1_t, vint32m1_t, vint32m1_t, vint32m1_t, vint32m1_t, vint32m1_t, const int32_t *, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vlseg8e32_v_m)))
void vlseg8e32(vint32mf2_t *, vint32mf2_t *, vint32mf2_t *, vint32mf2_t *, vint32mf2_t *, vint32mf2_t *, vint32mf2_t *, vint32mf2_t *, vbool64_t, vint32mf2_t, vint32mf2_t, vint32mf2_t, vint32mf2_t, vint32mf2_t, vint32mf2_t, vint32mf2_t, vint32mf2_t, const int32_t *, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vlseg8e32_v_m)))
void vlseg8e32(vuint32m1_t *, vuint32m1_t *, vuint32m1_t *, vuint32m1_t *, vuint32m1_t *, vuint32m1_t *, vuint32m1_t *, vuint32m1_t *, vbool32_t, vuint32m1_t, vuint32m1_t, vuint32m1_t, vuint32m1_t, vuint32m1_t, vuint32m1_t, vuint32m1_t, vuint32m1_t, const uint32_t *, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vlseg8e32_v_m)))
void vlseg8e32(vuint32mf2_t *, vuint32mf2_t *, vuint32mf2_t *, vuint32mf2_t *, vuint32mf2_t *, vuint32mf2_t *, vuint32mf2_t *, vuint32mf2_t *, vbool64_t, vuint32mf2_t, vuint32mf2_t, vuint32mf2_t, vuint32mf2_t, vuint32mf2_t, vuint32mf2_t, vuint32mf2_t, vuint32mf2_t, const uint32_t *, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vlseg3e8ff_v_m)))
void vlseg3e8ff(vint8m1_t *, vint8m1_t *, vint8m1_t *, vbool8_t, vint8m1_t, vint8m1_t, vint8m1_t, const int8_t *, size_t *, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vlseg3e8ff_v_m)))
void vlseg3e8ff(vint8m2_t *, vint8m2_t *, vint8m2_t *, vbool4_t, vint8m2_t, vint8m2_t, vint8m2_t, const int8_t *, size_t *, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vlseg3e8ff_v_m)))
void vlseg3e8ff(vint8mf2_t *, vint8mf2_t *, vint8mf2_t *, vbool16_t, vint8mf2_t, vint8mf2_t, vint8mf2_t, const int8_t *, size_t *, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vlseg3e8ff_v_m)))
void vlseg3e8ff(vint8mf4_t *, vint8mf4_t *, vint8mf4_t *, vbool32_t, vint8mf4_t, vint8mf4_t, vint8mf4_t, const int8_t *, size_t *, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vlseg3e8ff_v_m)))
void vlseg3e8ff(vint8mf8_t *, vint8mf8_t *, vint8mf8_t *, vbool64_t, vint8mf8_t, vint8mf8_t, vint8mf8_t, const int8_t *, size_t *, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vlseg3e8ff_v_m)))
void vlseg3e8ff(vuint8m1_t *, vuint8m1_t *, vuint8m1_t *, vbool8_t, vuint8m1_t, vuint8m1_t, vuint8m1_t, const uint8_t *, size_t *, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vlseg3e8ff_v_m)))
void vlseg3e8ff(vuint8m2_t *, vuint8m2_t *, vuint8m2_t *, vbool4_t, vuint8m2_t, vuint8m2_t, vuint8m2_t, const uint8_t *, size_t *, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vlseg3e8ff_v_m)))
void vlseg3e8ff(vuint8mf2_t *, vuint8mf2_t *, vuint8mf2_t *, vbool16_t, vuint8mf2_t, vuint8mf2_t, vuint8mf2_t, const uint8_t *, size_t *, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vlseg3e8ff_v_m)))
void vlseg3e8ff(vuint8mf4_t *, vuint8mf4_t *, vuint8mf4_t *, vbool32_t, vuint8mf4_t, vuint8mf4_t, vuint8mf4_t, const uint8_t *, size_t *, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vlseg3e8ff_v_m)))
void vlseg3e8ff(vuint8mf8_t *, vuint8mf8_t *, vuint8mf8_t *, vbool64_t, vuint8mf8_t, vuint8mf8_t, vuint8mf8_t, const uint8_t *, size_t *, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vlseg4e8ff_v_m)))
void vlseg4e8ff(vint8m1_t *, vint8m1_t *, vint8m1_t *, vint8m1_t *, vbool8_t, vint8m1_t, vint8m1_t, vint8m1_t, vint8m1_t, const int8_t *, size_t *, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vlseg4e8ff_v_m)))
void vlseg4e8ff(vint8m2_t *, vint8m2_t *, vint8m2_t *, vint8m2_t *, vbool4_t, vint8m2_t, vint8m2_t, vint8m2_t, vint8m2_t, const int8_t *, size_t *, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vlseg4e8ff_v_m)))
void vlseg4e8ff(vint8mf2_t *, vint8mf2_t *, vint8mf2_t *, vint8mf2_t *, vbool16_t, vint8mf2_t, vint8mf2_t, vint8mf2_t, vint8mf2_t, const int8_t *, size_t *, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vlseg4e8ff_v_m)))
void vlseg4e8ff(vint8mf4_t *, vint8mf4_t *, vint8mf4_t *, vint8mf4_t *, vbool32_t, vint8mf4_t, vint8mf4_t, vint8mf4_t, vint8mf4_t, const int8_t *, size_t *, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vlseg4e8ff_v_m)))
void vlseg4e8ff(vint8mf8_t *, vint8mf8_t *, vint8mf8_t *, vint8mf8_t *, vbool64_t, vint8mf8_t, vint8mf8_t, vint8mf8_t, vint8mf8_t, const int8_t *, size_t *, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vlseg4e8ff_v_m)))
void vlseg4e8ff(vuint8m1_t *, vuint8m1_t *, vuint8m1_t *, vuint8m1_t *, vbool8_t, vuint8m1_t, vuint8m1_t, vuint8m1_t, vuint8m1_t, const uint8_t *, size_t *, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vlseg4e8ff_v_m)))
void vlseg4e8ff(vuint8m2_t *, vuint8m2_t *, vuint8m2_t *, vuint8m2_t *, vbool4_t, vuint8m2_t, vuint8m2_t, vuint8m2_t, vuint8m2_t, const uint8_t *, size_t *, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vlseg4e8ff_v_m)))
void vlseg4e8ff(vuint8mf2_t *, vuint8mf2_t *, vuint8mf2_t *, vuint8mf2_t *, vbool16_t, vuint8mf2_t, vuint8mf2_t, vuint8mf2_t, vuint8mf2_t, const uint8_t *, size_t *, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vlseg4e8ff_v_m)))
void vlseg4e8ff(vuint8mf4_t *, vuint8mf4_t *, vuint8mf4_t *, vuint8mf4_t *, vbool32_t, vuint8mf4_t, vuint8mf4_t, vuint8mf4_t, vuint8mf4_t, const uint8_t *, size_t *, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vlseg4e8ff_v_m)))
void vlseg4e8ff(vuint8mf8_t *, vuint8mf8_t *, vuint8mf8_t *, vuint8mf8_t *, vbool64_t, vuint8mf8_t, vuint8mf8_t, vuint8mf8_t, vuint8mf8_t, const uint8_t *, size_t *, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vlseg5e8ff_v_m)))
void vlseg5e8ff(vint8m1_t *, vint8m1_t *, vint8m1_t *, vint8m1_t *, vint8m1_t *, vbool8_t, vint8m1_t, vint8m1_t, vint8m1_t, vint8m1_t, vint8m1_t, const int8_t *, size_t *, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vlseg5e8ff_v_m)))
void vlseg5e8ff(vint8mf2_t *, vint8mf2_t *, vint8mf2_t *, vint8mf2_t *, vint8mf2_t *, vbool16_t, vint8mf2_t, vint8mf2_t, vint8mf2_t, vint8mf2_t, vint8mf2_t, const int8_t *, size_t *, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vlseg5e8ff_v_m)))
void vlseg5e8ff(vint8mf4_t *, vint8mf4_t *, vint8mf4_t *, vint8mf4_t *, vint8mf4_t *, vbool32_t, vint8mf4_t, vint8mf4_t, vint8mf4_t, vint8mf4_t, vint8mf4_t, const int8_t *, size_t *, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vlseg5e8ff_v_m)))
void vlseg5e8ff(vint8mf8_t *, vint8mf8_t *, vint8mf8_t *, vint8mf8_t *, vint8mf8_t *, vbool64_t, vint8mf8_t, vint8mf8_t, vint8mf8_t, vint8mf8_t, vint8mf8_t, const int8_t *, size_t *, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vlseg5e8ff_v_m)))
void vlseg5e8ff(vuint8m1_t *, vuint8m1_t *, vuint8m1_t *, vuint8m1_t *, vuint8m1_t *, vbool8_t, vuint8m1_t, vuint8m1_t, vuint8m1_t, vuint8m1_t, vuint8m1_t, const uint8_t *, size_t *, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vlseg5e8ff_v_m)))
void vlseg5e8ff(vuint8mf2_t *, vuint8mf2_t *, vuint8mf2_t *, vuint8mf2_t *, vuint8mf2_t *, vbool16_t, vuint8mf2_t, vuint8mf2_t, vuint8mf2_t, vuint8mf2_t, vuint8mf2_t, const uint8_t *, size_t *, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vlseg5e8ff_v_m)))
void vlseg5e8ff(vuint8mf4_t *, vuint8mf4_t *, vuint8mf4_t *, vuint8mf4_t *, vuint8mf4_t *, vbool32_t, vuint8mf4_t, vuint8mf4_t, vuint8mf4_t, vuint8mf4_t, vuint8mf4_t, const uint8_t *, size_t *, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vlseg5e8ff_v_m)))
void vlseg5e8ff(vuint8mf8_t *, vuint8mf8_t *, vuint8mf8_t *, vuint8mf8_t *, vuint8mf8_t *, vbool64_t, vuint8mf8_t, vuint8mf8_t, vuint8mf8_t, vuint8mf8_t, vuint8mf8_t, const uint8_t *, size_t *, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vlseg6e8ff_v_m)))
void vlseg6e8ff(vint8m1_t *, vint8m1_t *, vint8m1_t *, vint8m1_t *, vint8m1_t *, vint8m1_t *, vbool8_t, vint8m1_t, vint8m1_t, vint8m1_t, vint8m1_t, vint8m1_t, vint8m1_t, const int8_t *, size_t *, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vlseg6e8ff_v_m)))
void vlseg6e8ff(vint8mf2_t *, vint8mf2_t *, vint8mf2_t *, vint8mf2_t *, vint8mf2_t *, vint8mf2_t *, vbool16_t, vint8mf2_t, vint8mf2_t, vint8mf2_t, vint8mf2_t, vint8mf2_t, vint8mf2_t, const int8_t *, size_t *, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vlseg6e8ff_v_m)))
void vlseg6e8ff(vint8mf4_t *, vint8mf4_t *, vint8mf4_t *, vint8mf4_t *, vint8mf4_t *, vint8mf4_t *, vbool32_t, vint8mf4_t, vint8mf4_t, vint8mf4_t, vint8mf4_t, vint8mf4_t, vint8mf4_t, const int8_t *, size_t *, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vlseg6e8ff_v_m)))
void vlseg6e8ff(vint8mf8_t *, vint8mf8_t *, vint8mf8_t *, vint8mf8_t *, vint8mf8_t *, vint8mf8_t *, vbool64_t, vint8mf8_t, vint8mf8_t, vint8mf8_t, vint8mf8_t, vint8mf8_t, vint8mf8_t, const int8_t *, size_t *, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vlseg6e8ff_v_m)))
void vlseg6e8ff(vuint8m1_t *, vuint8m1_t *, vuint8m1_t *, vuint8m1_t *, vuint8m1_t *, vuint8m1_t *, vbool8_t, vuint8m1_t, vuint8m1_t, vuint8m1_t, vuint8m1_t, vuint8m1_t, vuint8m1_t, const uint8_t *, size_t *, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vlseg6e8ff_v_m)))
void vlseg6e8ff(vuint8mf2_t *, vuint8mf2_t *, vuint8mf2_t *, vuint8mf2_t *, vuint8mf2_t *, vuint8mf2_t *, vbool16_t, vuint8mf2_t, vuint8mf2_t, vuint8mf2_t, vuint8mf2_t, vuint8mf2_t, vuint8mf2_t, const uint8_t *, size_t *, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vlseg6e8ff_v_m)))
void vlseg6e8ff(vuint8mf4_t *, vuint8mf4_t *, vuint8mf4_t *, vuint8mf4_t *, vuint8mf4_t *, vuint8mf4_t *, vbool32_t, vuint8mf4_t, vuint8mf4_t, vuint8mf4_t, vuint8mf4_t, vuint8mf4_t, vuint8mf4_t, const uint8_t *, size_t *, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vlseg6e8ff_v_m)))
void vlseg6e8ff(vuint8mf8_t *, vuint8mf8_t *, vuint8mf8_t *, vuint8mf8_t *, vuint8mf8_t *, vuint8mf8_t *, vbool64_t, vuint8mf8_t, vuint8mf8_t, vuint8mf8_t, vuint8mf8_t, vuint8mf8_t, vuint8mf8_t, const uint8_t *, size_t *, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vlseg7e8ff_v_m)))
void vlseg7e8ff(vint8m1_t *, vint8m1_t *, vint8m1_t *, vint8m1_t *, vint8m1_t *, vint8m1_t *, vint8m1_t *, vbool8_t, vint8m1_t, vint8m1_t, vint8m1_t, vint8m1_t, vint8m1_t, vint8m1_t, vint8m1_t, const int8_t *, size_t *, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vlseg7e8ff_v_m)))
void vlseg7e8ff(vint8mf2_t *, vint8mf2_t *, vint8mf2_t *, vint8mf2_t *, vint8mf2_t *, vint8mf2_t *, vint8mf2_t *, vbool16_t, vint8mf2_t, vint8mf2_t, vint8mf2_t, vint8mf2_t, vint8mf2_t, vint8mf2_t, vint8mf2_t, const int8_t *, size_t *, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vlseg7e8ff_v_m)))
void vlseg7e8ff(vint8mf4_t *, vint8mf4_t *, vint8mf4_t *, vint8mf4_t *, vint8mf4_t *, vint8mf4_t *, vint8mf4_t *, vbool32_t, vint8mf4_t, vint8mf4_t, vint8mf4_t, vint8mf4_t, vint8mf4_t, vint8mf4_t, vint8mf4_t, const int8_t *, size_t *, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vlseg7e8ff_v_m)))
void vlseg7e8ff(vint8mf8_t *, vint8mf8_t *, vint8mf8_t *, vint8mf8_t *, vint8mf8_t *, vint8mf8_t *, vint8mf8_t *, vbool64_t, vint8mf8_t, vint8mf8_t, vint8mf8_t, vint8mf8_t, vint8mf8_t, vint8mf8_t, vint8mf8_t, const int8_t *, size_t *, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vlseg7e8ff_v_m)))
void vlseg7e8ff(vuint8m1_t *, vuint8m1_t *, vuint8m1_t *, vuint8m1_t *, vuint8m1_t *, vuint8m1_t *, vuint8m1_t *, vbool8_t, vuint8m1_t, vuint8m1_t, vuint8m1_t, vuint8m1_t, vuint8m1_t, vuint8m1_t, vuint8m1_t, const uint8_t *, size_t *, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vlseg7e8ff_v_m)))
void vlseg7e8ff(vuint8mf2_t *, vuint8mf2_t *, vuint8mf2_t *, vuint8mf2_t *, vuint8mf2_t *, vuint8mf2_t *, vuint8mf2_t *, vbool16_t, vuint8mf2_t, vuint8mf2_t, vuint8mf2_t, vuint8mf2_t, vuint8mf2_t, vuint8mf2_t, vuint8mf2_t, const uint8_t *, size_t *, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vlseg7e8ff_v_m)))
void vlseg7e8ff(vuint8mf4_t *, vuint8mf4_t *, vuint8mf4_t *, vuint8mf4_t *, vuint8mf4_t *, vuint8mf4_t *, vuint8mf4_t *, vbool32_t, vuint8mf4_t, vuint8mf4_t, vuint8mf4_t, vuint8mf4_t, vuint8mf4_t, vuint8mf4_t, vuint8mf4_t, const uint8_t *, size_t *, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vlseg7e8ff_v_m)))
void vlseg7e8ff(vuint8mf8_t *, vuint8mf8_t *, vuint8mf8_t *, vuint8mf8_t *, vuint8mf8_t *, vuint8mf8_t *, vuint8mf8_t *, vbool64_t, vuint8mf8_t, vuint8mf8_t, vuint8mf8_t, vuint8mf8_t, vuint8mf8_t, vuint8mf8_t, vuint8mf8_t, const uint8_t *, size_t *, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vlseg8e8ff_v_m)))
void vlseg8e8ff(vint8m1_t *, vint8m1_t *, vint8m1_t *, vint8m1_t *, vint8m1_t *, vint8m1_t *, vint8m1_t *, vint8m1_t *, vbool8_t, vint8m1_t, vint8m1_t, vint8m1_t, vint8m1_t, vint8m1_t, vint8m1_t, vint8m1_t, vint8m1_t, const int8_t *, size_t *, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vlseg8e8ff_v_m)))
void vlseg8e8ff(vint8mf2_t *, vint8mf2_t *, vint8mf2_t *, vint8mf2_t *, vint8mf2_t *, vint8mf2_t *, vint8mf2_t *, vint8mf2_t *, vbool16_t, vint8mf2_t, vint8mf2_t, vint8mf2_t, vint8mf2_t, vint8mf2_t, vint8mf2_t, vint8mf2_t, vint8mf2_t, const int8_t *, size_t *, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vlseg8e8ff_v_m)))
void vlseg8e8ff(vint8mf4_t *, vint8mf4_t *, vint8mf4_t *, vint8mf4_t *, vint8mf4_t *, vint8mf4_t *, vint8mf4_t *, vint8mf4_t *, vbool32_t, vint8mf4_t, vint8mf4_t, vint8mf4_t, vint8mf4_t, vint8mf4_t, vint8mf4_t, vint8mf4_t, vint8mf4_t, const int8_t *, size_t *, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vlseg8e8ff_v_m)))
void vlseg8e8ff(vint8mf8_t *, vint8mf8_t *, vint8mf8_t *, vint8mf8_t *, vint8mf8_t *, vint8mf8_t *, vint8mf8_t *, vint8mf8_t *, vbool64_t, vint8mf8_t, vint8mf8_t, vint8mf8_t, vint8mf8_t, vint8mf8_t, vint8mf8_t, vint8mf8_t, vint8mf8_t, const int8_t *, size_t *, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vlseg8e8ff_v_m)))
void vlseg8e8ff(vuint8m1_t *, vuint8m1_t *, vuint8m1_t *, vuint8m1_t *, vuint8m1_t *, vuint8m1_t *, vuint8m1_t *, vuint8m1_t *, vbool8_t, vuint8m1_t, vuint8m1_t, vuint8m1_t, vuint8m1_t, vuint8m1_t, vuint8m1_t, vuint8m1_t, vuint8m1_t, const uint8_t *, size_t *, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vlseg8e8ff_v_m)))
void vlseg8e8ff(vuint8mf2_t *, vuint8mf2_t *, vuint8mf2_t *, vuint8mf2_t *, vuint8mf2_t *, vuint8mf2_t *, vuint8mf2_t *, vuint8mf2_t *, vbool16_t, vuint8mf2_t, vuint8mf2_t, vuint8mf2_t, vuint8mf2_t, vuint8mf2_t, vuint8mf2_t, vuint8mf2_t, vuint8mf2_t, const uint8_t *, size_t *, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vlseg8e8ff_v_m)))
void vlseg8e8ff(vuint8mf4_t *, vuint8mf4_t *, vuint8mf4_t *, vuint8mf4_t *, vuint8mf4_t *, vuint8mf4_t *, vuint8mf4_t *, vuint8mf4_t *, vbool32_t, vuint8mf4_t, vuint8mf4_t, vuint8mf4_t, vuint8mf4_t, vuint8mf4_t, vuint8mf4_t, vuint8mf4_t, vuint8mf4_t, const uint8_t *, size_t *, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vlseg8e8ff_v_m)))
void vlseg8e8ff(vuint8mf8_t *, vuint8mf8_t *, vuint8mf8_t *, vuint8mf8_t *, vuint8mf8_t *, vuint8mf8_t *, vuint8mf8_t *, vuint8mf8_t *, vbool64_t, vuint8mf8_t, vuint8mf8_t, vuint8mf8_t, vuint8mf8_t, vuint8mf8_t, vuint8mf8_t, vuint8mf8_t, vuint8mf8_t, const uint8_t *, size_t *, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vlseg2e16ff_v_m)))
void vlseg2e16ff(vint16m1_t *, vint16m1_t *, vbool16_t, vint16m1_t, vint16m1_t, const int16_t *, size_t *, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vlseg2e16ff_v_m)))
void vlseg2e16ff(vint16m2_t *, vint16m2_t *, vbool8_t, vint16m2_t, vint16m2_t, const int16_t *, size_t *, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vlseg2e16ff_v_m)))
void vlseg2e16ff(vint16m4_t *, vint16m4_t *, vbool4_t, vint16m4_t, vint16m4_t, const int16_t *, size_t *, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vlseg2e16ff_v_m)))
void vlseg2e16ff(vint16mf2_t *, vint16mf2_t *, vbool32_t, vint16mf2_t, vint16mf2_t, const int16_t *, size_t *, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vlseg2e16ff_v_m)))
void vlseg2e16ff(vint16mf4_t *, vint16mf4_t *, vbool64_t, vint16mf4_t, vint16mf4_t, const int16_t *, size_t *, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vlseg2e16ff_v_m)))
void vlseg2e16ff(vuint16m1_t *, vuint16m1_t *, vbool16_t, vuint16m1_t, vuint16m1_t, const uint16_t *, size_t *, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vlseg2e16ff_v_m)))
void vlseg2e16ff(vuint16m2_t *, vuint16m2_t *, vbool8_t, vuint16m2_t, vuint16m2_t, const uint16_t *, size_t *, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vlseg2e16ff_v_m)))
void vlseg2e16ff(vuint16m4_t *, vuint16m4_t *, vbool4_t, vuint16m4_t, vuint16m4_t, const uint16_t *, size_t *, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vlseg2e16ff_v_m)))
void vlseg2e16ff(vuint16mf2_t *, vuint16mf2_t *, vbool32_t, vuint16mf2_t, vuint16mf2_t, const uint16_t *, size_t *, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vlseg2e16ff_v_m)))
void vlseg2e16ff(vuint16mf4_t *, vuint16mf4_t *, vbool64_t, vuint16mf4_t, vuint16mf4_t, const uint16_t *, size_t *, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vlseg3e16ff_v_m)))
void vlseg3e16ff(vint16m1_t *, vint16m1_t *, vint16m1_t *, vbool16_t, vint16m1_t, vint16m1_t, vint16m1_t, const int16_t *, size_t *, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vlseg3e16ff_v_m)))
void vlseg3e16ff(vint16m2_t *, vint16m2_t *, vint16m2_t *, vbool8_t, vint16m2_t, vint16m2_t, vint16m2_t, const int16_t *, size_t *, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vlseg3e16ff_v_m)))
void vlseg3e16ff(vint16mf2_t *, vint16mf2_t *, vint16mf2_t *, vbool32_t, vint16mf2_t, vint16mf2_t, vint16mf2_t, const int16_t *, size_t *, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vlseg3e16ff_v_m)))
void vlseg3e16ff(vint16mf4_t *, vint16mf4_t *, vint16mf4_t *, vbool64_t, vint16mf4_t, vint16mf4_t, vint16mf4_t, const int16_t *, size_t *, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vlseg3e16ff_v_m)))
void vlseg3e16ff(vuint16m1_t *, vuint16m1_t *, vuint16m1_t *, vbool16_t, vuint16m1_t, vuint16m1_t, vuint16m1_t, const uint16_t *, size_t *, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vlseg3e16ff_v_m)))
void vlseg3e16ff(vuint16m2_t *, vuint16m2_t *, vuint16m2_t *, vbool8_t, vuint16m2_t, vuint16m2_t, vuint16m2_t, const uint16_t *, size_t *, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vlseg3e16ff_v_m)))
void vlseg3e16ff(vuint16mf2_t *, vuint16mf2_t *, vuint16mf2_t *, vbool32_t, vuint16mf2_t, vuint16mf2_t, vuint16mf2_t, const uint16_t *, size_t *, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vlseg3e16ff_v_m)))
void vlseg3e16ff(vuint16mf4_t *, vuint16mf4_t *, vuint16mf4_t *, vbool64_t, vuint16mf4_t, vuint16mf4_t, vuint16mf4_t, const uint16_t *, size_t *, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vlseg4e16ff_v_m)))
void vlseg4e16ff(vint16m1_t *, vint16m1_t *, vint16m1_t *, vint16m1_t *, vbool16_t, vint16m1_t, vint16m1_t, vint16m1_t, vint16m1_t, const int16_t *, size_t *, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vlseg4e16ff_v_m)))
void vlseg4e16ff(vint16m2_t *, vint16m2_t *, vint16m2_t *, vint16m2_t *, vbool8_t, vint16m2_t, vint16m2_t, vint16m2_t, vint16m2_t, const int16_t *, size_t *, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vlseg4e16ff_v_m)))
void vlseg4e16ff(vint16mf2_t *, vint16mf2_t *, vint16mf2_t *, vint16mf2_t *, vbool32_t, vint16mf2_t, vint16mf2_t, vint16mf2_t, vint16mf2_t, const int16_t *, size_t *, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vlseg4e16ff_v_m)))
void vlseg4e16ff(vint16mf4_t *, vint16mf4_t *, vint16mf4_t *, vint16mf4_t *, vbool64_t, vint16mf4_t, vint16mf4_t, vint16mf4_t, vint16mf4_t, const int16_t *, size_t *, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vlseg4e16ff_v_m)))
void vlseg4e16ff(vuint16m1_t *, vuint16m1_t *, vuint16m1_t *, vuint16m1_t *, vbool16_t, vuint16m1_t, vuint16m1_t, vuint16m1_t, vuint16m1_t, const uint16_t *, size_t *, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vlseg4e16ff_v_m)))
void vlseg4e16ff(vuint16m2_t *, vuint16m2_t *, vuint16m2_t *, vuint16m2_t *, vbool8_t, vuint16m2_t, vuint16m2_t, vuint16m2_t, vuint16m2_t, const uint16_t *, size_t *, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vlseg4e16ff_v_m)))
void vlseg4e16ff(vuint16mf2_t *, vuint16mf2_t *, vuint16mf2_t *, vuint16mf2_t *, vbool32_t, vuint16mf2_t, vuint16mf2_t, vuint16mf2_t, vuint16mf2_t, const uint16_t *, size_t *, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vlseg4e16ff_v_m)))
void vlseg4e16ff(vuint16mf4_t *, vuint16mf4_t *, vuint16mf4_t *, vuint16mf4_t *, vbool64_t, vuint16mf4_t, vuint16mf4_t, vuint16mf4_t, vuint16mf4_t, const uint16_t *, size_t *, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vlseg5e16ff_v_m)))
void vlseg5e16ff(vint16m1_t *, vint16m1_t *, vint16m1_t *, vint16m1_t *, vint16m1_t *, vbool16_t, vint16m1_t, vint16m1_t, vint16m1_t, vint16m1_t, vint16m1_t, const int16_t *, size_t *, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vlseg5e16ff_v_m)))
void vlseg5e16ff(vint16mf2_t *, vint16mf2_t *, vint16mf2_t *, vint16mf2_t *, vint16mf2_t *, vbool32_t, vint16mf2_t, vint16mf2_t, vint16mf2_t, vint16mf2_t, vint16mf2_t, const int16_t *, size_t *, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vlseg5e16ff_v_m)))
void vlseg5e16ff(vint16mf4_t *, vint16mf4_t *, vint16mf4_t *, vint16mf4_t *, vint16mf4_t *, vbool64_t, vint16mf4_t, vint16mf4_t, vint16mf4_t, vint16mf4_t, vint16mf4_t, const int16_t *, size_t *, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vlseg5e16ff_v_m)))
void vlseg5e16ff(vuint16m1_t *, vuint16m1_t *, vuint16m1_t *, vuint16m1_t *, vuint16m1_t *, vbool16_t, vuint16m1_t, vuint16m1_t, vuint16m1_t, vuint16m1_t, vuint16m1_t, const uint16_t *, size_t *, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vlseg5e16ff_v_m)))
void vlseg5e16ff(vuint16mf2_t *, vuint16mf2_t *, vuint16mf2_t *, vuint16mf2_t *, vuint16mf2_t *, vbool32_t, vuint16mf2_t, vuint16mf2_t, vuint16mf2_t, vuint16mf2_t, vuint16mf2_t, const uint16_t *, size_t *, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vlseg5e16ff_v_m)))
void vlseg5e16ff(vuint16mf4_t *, vuint16mf4_t *, vuint16mf4_t *, vuint16mf4_t *, vuint16mf4_t *, vbool64_t, vuint16mf4_t, vuint16mf4_t, vuint16mf4_t, vuint16mf4_t, vuint16mf4_t, const uint16_t *, size_t *, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vlseg6e16ff_v_m)))
void vlseg6e16ff(vint16m1_t *, vint16m1_t *, vint16m1_t *, vint16m1_t *, vint16m1_t *, vint16m1_t *, vbool16_t, vint16m1_t, vint16m1_t, vint16m1_t, vint16m1_t, vint16m1_t, vint16m1_t, const int16_t *, size_t *, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vlseg6e16ff_v_m)))
void vlseg6e16ff(vint16mf2_t *, vint16mf2_t *, vint16mf2_t *, vint16mf2_t *, vint16mf2_t *, vint16mf2_t *, vbool32_t, vint16mf2_t, vint16mf2_t, vint16mf2_t, vint16mf2_t, vint16mf2_t, vint16mf2_t, const int16_t *, size_t *, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vlseg6e16ff_v_m)))
void vlseg6e16ff(vint16mf4_t *, vint16mf4_t *, vint16mf4_t *, vint16mf4_t *, vint16mf4_t *, vint16mf4_t *, vbool64_t, vint16mf4_t, vint16mf4_t, vint16mf4_t, vint16mf4_t, vint16mf4_t, vint16mf4_t, const int16_t *, size_t *, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vlseg6e16ff_v_m)))
void vlseg6e16ff(vuint16m1_t *, vuint16m1_t *, vuint16m1_t *, vuint16m1_t *, vuint16m1_t *, vuint16m1_t *, vbool16_t, vuint16m1_t, vuint16m1_t, vuint16m1_t, vuint16m1_t, vuint16m1_t, vuint16m1_t, const uint16_t *, size_t *, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vlseg6e16ff_v_m)))
void vlseg6e16ff(vuint16mf2_t *, vuint16mf2_t *, vuint16mf2_t *, vuint16mf2_t *, vuint16mf2_t *, vuint16mf2_t *, vbool32_t, vuint16mf2_t, vuint16mf2_t, vuint16mf2_t, vuint16mf2_t, vuint16mf2_t, vuint16mf2_t, const uint16_t *, size_t *, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vlseg6e16ff_v_m)))
void vlseg6e16ff(vuint16mf4_t *, vuint16mf4_t *, vuint16mf4_t *, vuint16mf4_t *, vuint16mf4_t *, vuint16mf4_t *, vbool64_t, vuint16mf4_t, vuint16mf4_t, vuint16mf4_t, vuint16mf4_t, vuint16mf4_t, vuint16mf4_t, const uint16_t *, size_t *, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vlseg7e16ff_v_m)))
void vlseg7e16ff(vint16m1_t *, vint16m1_t *, vint16m1_t *, vint16m1_t *, vint16m1_t *, vint16m1_t *, vint16m1_t *, vbool16_t, vint16m1_t, vint16m1_t, vint16m1_t, vint16m1_t, vint16m1_t, vint16m1_t, vint16m1_t, const int16_t *, size_t *, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vlseg7e16ff_v_m)))
void vlseg7e16ff(vint16mf2_t *, vint16mf2_t *, vint16mf2_t *, vint16mf2_t *, vint16mf2_t *, vint16mf2_t *, vint16mf2_t *, vbool32_t, vint16mf2_t, vint16mf2_t, vint16mf2_t, vint16mf2_t, vint16mf2_t, vint16mf2_t, vint16mf2_t, const int16_t *, size_t *, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vlseg7e16ff_v_m)))
void vlseg7e16ff(vint16mf4_t *, vint16mf4_t *, vint16mf4_t *, vint16mf4_t *, vint16mf4_t *, vint16mf4_t *, vint16mf4_t *, vbool64_t, vint16mf4_t, vint16mf4_t, vint16mf4_t, vint16mf4_t, vint16mf4_t, vint16mf4_t, vint16mf4_t, const int16_t *, size_t *, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vlseg7e16ff_v_m)))
void vlseg7e16ff(vuint16m1_t *, vuint16m1_t *, vuint16m1_t *, vuint16m1_t *, vuint16m1_t *, vuint16m1_t *, vuint16m1_t *, vbool16_t, vuint16m1_t, vuint16m1_t, vuint16m1_t, vuint16m1_t, vuint16m1_t, vuint16m1_t, vuint16m1_t, const uint16_t *, size_t *, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vlseg7e16ff_v_m)))
void vlseg7e16ff(vuint16mf2_t *, vuint16mf2_t *, vuint16mf2_t *, vuint16mf2_t *, vuint16mf2_t *, vuint16mf2_t *, vuint16mf2_t *, vbool32_t, vuint16mf2_t, vuint16mf2_t, vuint16mf2_t, vuint16mf2_t, vuint16mf2_t, vuint16mf2_t, vuint16mf2_t, const uint16_t *, size_t *, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vlseg7e16ff_v_m)))
void vlseg7e16ff(vuint16mf4_t *, vuint16mf4_t *, vuint16mf4_t *, vuint16mf4_t *, vuint16mf4_t *, vuint16mf4_t *, vuint16mf4_t *, vbool64_t, vuint16mf4_t, vuint16mf4_t, vuint16mf4_t, vuint16mf4_t, vuint16mf4_t, vuint16mf4_t, vuint16mf4_t, const uint16_t *, size_t *, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vlseg8e16ff_v_m)))
void vlseg8e16ff(vint16m1_t *, vint16m1_t *, vint16m1_t *, vint16m1_t *, vint16m1_t *, vint16m1_t *, vint16m1_t *, vint16m1_t *, vbool16_t, vint16m1_t, vint16m1_t, vint16m1_t, vint16m1_t, vint16m1_t, vint16m1_t, vint16m1_t, vint16m1_t, const int16_t *, size_t *, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vlseg8e16ff_v_m)))
void vlseg8e16ff(vint16mf2_t *, vint16mf2_t *, vint16mf2_t *, vint16mf2_t *, vint16mf2_t *, vint16mf2_t *, vint16mf2_t *, vint16mf2_t *, vbool32_t, vint16mf2_t, vint16mf2_t, vint16mf2_t, vint16mf2_t, vint16mf2_t, vint16mf2_t, vint16mf2_t, vint16mf2_t, const int16_t *, size_t *, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vlseg8e16ff_v_m)))
void vlseg8e16ff(vint16mf4_t *, vint16mf4_t *, vint16mf4_t *, vint16mf4_t *, vint16mf4_t *, vint16mf4_t *, vint16mf4_t *, vint16mf4_t *, vbool64_t, vint16mf4_t, vint16mf4_t, vint16mf4_t, vint16mf4_t, vint16mf4_t, vint16mf4_t, vint16mf4_t, vint16mf4_t, const int16_t *, size_t *, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vlseg8e16ff_v_m)))
void vlseg8e16ff(vuint16m1_t *, vuint16m1_t *, vuint16m1_t *, vuint16m1_t *, vuint16m1_t *, vuint16m1_t *, vuint16m1_t *, vuint16m1_t *, vbool16_t, vuint16m1_t, vuint16m1_t, vuint16m1_t, vuint16m1_t, vuint16m1_t, vuint16m1_t, vuint16m1_t, vuint16m1_t, const uint16_t *, size_t *, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vlseg8e16ff_v_m)))
void vlseg8e16ff(vuint16mf2_t *, vuint16mf2_t *, vuint16mf2_t *, vuint16mf2_t *, vuint16mf2_t *, vuint16mf2_t *, vuint16mf2_t *, vuint16mf2_t *, vbool32_t, vuint16mf2_t, vuint16mf2_t, vuint16mf2_t, vuint16mf2_t, vuint16mf2_t, vuint16mf2_t, vuint16mf2_t, vuint16mf2_t, const uint16_t *, size_t *, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vlseg8e16ff_v_m)))
void vlseg8e16ff(vuint16mf4_t *, vuint16mf4_t *, vuint16mf4_t *, vuint16mf4_t *, vuint16mf4_t *, vuint16mf4_t *, vuint16mf4_t *, vuint16mf4_t *, vbool64_t, vuint16mf4_t, vuint16mf4_t, vuint16mf4_t, vuint16mf4_t, vuint16mf4_t, vuint16mf4_t, vuint16mf4_t, vuint16mf4_t, const uint16_t *, size_t *, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vlseg2e32ff_v_m)))
void vlseg2e32ff(vint32m1_t *, vint32m1_t *, vbool32_t, vint32m1_t, vint32m1_t, const int32_t *, size_t *, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vlseg2e32ff_v_m)))
void vlseg2e32ff(vint32m2_t *, vint32m2_t *, vbool16_t, vint32m2_t, vint32m2_t, const int32_t *, size_t *, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vlseg2e32ff_v_m)))
void vlseg2e32ff(vint32m4_t *, vint32m4_t *, vbool8_t, vint32m4_t, vint32m4_t, const int32_t *, size_t *, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vlseg2e32ff_v_m)))
void vlseg2e32ff(vint32mf2_t *, vint32mf2_t *, vbool64_t, vint32mf2_t, vint32mf2_t, const int32_t *, size_t *, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vlseg2e32ff_v_m)))
void vlseg2e32ff(vuint32m1_t *, vuint32m1_t *, vbool32_t, vuint32m1_t, vuint32m1_t, const uint32_t *, size_t *, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vlseg2e32ff_v_m)))
void vlseg2e32ff(vuint32m2_t *, vuint32m2_t *, vbool16_t, vuint32m2_t, vuint32m2_t, const uint32_t *, size_t *, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vlseg2e32ff_v_m)))
void vlseg2e32ff(vuint32m4_t *, vuint32m4_t *, vbool8_t, vuint32m4_t, vuint32m4_t, const uint32_t *, size_t *, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vlseg2e32ff_v_m)))
void vlseg2e32ff(vuint32mf2_t *, vuint32mf2_t *, vbool64_t, vuint32mf2_t, vuint32mf2_t, const uint32_t *, size_t *, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vlseg3e32ff_v_m)))
void vlseg3e32ff(vint32m1_t *, vint32m1_t *, vint32m1_t *, vbool32_t, vint32m1_t, vint32m1_t, vint32m1_t, const int32_t *, size_t *, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vlseg3e32ff_v_m)))
void vlseg3e32ff(vint32m2_t *, vint32m2_t *, vint32m2_t *, vbool16_t, vint32m2_t, vint32m2_t, vint32m2_t, const int32_t *, size_t *, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vlseg3e32ff_v_m)))
void vlseg3e32ff(vint32mf2_t *, vint32mf2_t *, vint32mf2_t *, vbool64_t, vint32mf2_t, vint32mf2_t, vint32mf2_t, const int32_t *, size_t *, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vle8_v_m)))
vuint8m1_t vle8(vbool8_t, vuint8m1_t, const uint8_t *, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vle8_v_m)))
vuint8m2_t vle8(vbool4_t, vuint8m2_t, const uint8_t *, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vle8_v_m)))
vuint8m4_t vle8(vbool2_t, vuint8m4_t, const uint8_t *, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vle8_v_m)))
vuint8m8_t vle8(vbool1_t, vuint8m8_t, const uint8_t *, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vle8_v_m)))
vuint8mf2_t vle8(vbool16_t, vuint8mf2_t, const uint8_t *, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vle8_v_m)))
vuint8mf4_t vle8(vbool32_t, vuint8mf4_t, const uint8_t *, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vle8_v_m)))
vuint8mf8_t vle8(vbool64_t, vuint8mf8_t, const uint8_t *, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vlseg3e32ff_v_m)))
void vlseg3e32ff(vuint32m1_t *, vuint32m1_t *, vuint32m1_t *, vbool32_t, vuint32m1_t, vuint32m1_t, vuint32m1_t, const uint32_t *, size_t *, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vlseg3e32ff_v_m)))
void vlseg3e32ff(vuint32m2_t *, vuint32m2_t *, vuint32m2_t *, vbool16_t, vuint32m2_t, vuint32m2_t, vuint32m2_t, const uint32_t *, size_t *, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vlseg3e32ff_v_m)))
void vlseg3e32ff(vuint32mf2_t *, vuint32mf2_t *, vuint32mf2_t *, vbool64_t, vuint32mf2_t, vuint32mf2_t, vuint32mf2_t, const uint32_t *, size_t *, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vlseg4e32ff_v_m)))
void vlseg4e32ff(vint32m1_t *, vint32m1_t *, vint32m1_t *, vint32m1_t *, vbool32_t, vint32m1_t, vint32m1_t, vint32m1_t, vint32m1_t, const int32_t *, size_t *, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vlseg4e32ff_v_m)))
void vlseg4e32ff(vint32m2_t *, vint32m2_t *, vint32m2_t *, vint32m2_t *, vbool16_t, vint32m2_t, vint32m2_t, vint32m2_t, vint32m2_t, const int32_t *, size_t *, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vlseg4e32ff_v_m)))
void vlseg4e32ff(vint32mf2_t *, vint32mf2_t *, vint32mf2_t *, vint32mf2_t *, vbool64_t, vint32mf2_t, vint32mf2_t, vint32mf2_t, vint32mf2_t, const int32_t *, size_t *, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vlseg4e32ff_v_m)))
void vlseg4e32ff(vuint32m1_t *, vuint32m1_t *, vuint32m1_t *, vuint32m1_t *, vbool32_t, vuint32m1_t, vuint32m1_t, vuint32m1_t, vuint32m1_t, const uint32_t *, size_t *, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vlseg4e32ff_v_m)))
void vlseg4e32ff(vuint32m2_t *, vuint32m2_t *, vuint32m2_t *, vuint32m2_t *, vbool16_t, vuint32m2_t, vuint32m2_t, vuint32m2_t, vuint32m2_t, const uint32_t *, size_t *, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vlseg4e32ff_v_m)))
void vlseg4e32ff(vuint32mf2_t *, vuint32mf2_t *, vuint32mf2_t *, vuint32mf2_t *, vbool64_t, vuint32mf2_t, vuint32mf2_t, vuint32mf2_t, vuint32mf2_t, const uint32_t *, size_t *, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vlseg5e32ff_v_m)))
void vlseg5e32ff(vint32m1_t *, vint32m1_t *, vint32m1_t *, vint32m1_t *, vint32m1_t *, vbool32_t, vint32m1_t, vint32m1_t, vint32m1_t, vint32m1_t, vint32m1_t, const int32_t *, size_t *, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vlseg5e32ff_v_m)))
void vlseg5e32ff(vint32mf2_t *, vint32mf2_t *, vint32mf2_t *, vint32mf2_t *, vint32mf2_t *, vbool64_t, vint32mf2_t, vint32mf2_t, vint32mf2_t, vint32mf2_t, vint32mf2_t, const int32_t *, size_t *, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vlseg5e32ff_v_m)))
void vlseg5e32ff(vuint32m1_t *, vuint32m1_t *, vuint32m1_t *, vuint32m1_t *, vuint32m1_t *, vbool32_t, vuint32m1_t, vuint32m1_t, vuint32m1_t, vuint32m1_t, vuint32m1_t, const uint32_t *, size_t *, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vlseg5e32ff_v_m)))
void vlseg5e32ff(vuint32mf2_t *, vuint32mf2_t *, vuint32mf2_t *, vuint32mf2_t *, vuint32mf2_t *, vbool64_t, vuint32mf2_t, vuint32mf2_t, vuint32mf2_t, vuint32mf2_t, vuint32mf2_t, const uint32_t *, size_t *, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vlseg6e32ff_v_m)))
void vlseg6e32ff(vint32m1_t *, vint32m1_t *, vint32m1_t *, vint32m1_t *, vint32m1_t *, vint32m1_t *, vbool32_t, vint32m1_t, vint32m1_t, vint32m1_t, vint32m1_t, vint32m1_t, vint32m1_t, const int32_t *, size_t *, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vlseg6e32ff_v_m)))
void vlseg6e32ff(vint32mf2_t *, vint32mf2_t *, vint32mf2_t *, vint32mf2_t *, vint32mf2_t *, vint32mf2_t *, vbool64_t, vint32mf2_t, vint32mf2_t, vint32mf2_t, vint32mf2_t, vint32mf2_t, vint32mf2_t, const int32_t *, size_t *, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vlseg6e32ff_v_m)))
void vlseg6e32ff(vuint32m1_t *, vuint32m1_t *, vuint32m1_t *, vuint32m1_t *, vuint32m1_t *, vuint32m1_t *, vbool32_t, vuint32m1_t, vuint32m1_t, vuint32m1_t, vuint32m1_t, vuint32m1_t, vuint32m1_t, const uint32_t *, size_t *, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vlseg6e32ff_v_m)))
void vlseg6e32ff(vuint32mf2_t *, vuint32mf2_t *, vuint32mf2_t *, vuint32mf2_t *, vuint32mf2_t *, vuint32mf2_t *, vbool64_t, vuint32mf2_t, vuint32mf2_t, vuint32mf2_t, vuint32mf2_t, vuint32mf2_t, vuint32mf2_t, const uint32_t *, size_t *, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vlseg7e32ff_v_m)))
void vlseg7e32ff(vint32m1_t *, vint32m1_t *, vint32m1_t *, vint32m1_t *, vint32m1_t *, vint32m1_t *, vint32m1_t *, vbool32_t, vint32m1_t, vint32m1_t, vint32m1_t, vint32m1_t, vint32m1_t, vint32m1_t, vint32m1_t, const int32_t *, size_t *, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vlseg7e32ff_v_m)))
void vlseg7e32ff(vint32mf2_t *, vint32mf2_t *, vint32mf2_t *, vint32mf2_t *, vint32mf2_t *, vint32mf2_t *, vint32mf2_t *, vbool64_t, vint32mf2_t, vint32mf2_t, vint32mf2_t, vint32mf2_t, vint32mf2_t, vint32mf2_t, vint32mf2_t, const int32_t *, size_t *, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vlseg7e32ff_v_m)))
void vlseg7e32ff(vuint32m1_t *, vuint32m1_t *, vuint32m1_t *, vuint32m1_t *, vuint32m1_t *, vuint32m1_t *, vuint32m1_t *, vbool32_t, vuint32m1_t, vuint32m1_t, vuint32m1_t, vuint32m1_t, vuint32m1_t, vuint32m1_t, vuint32m1_t, const uint32_t *, size_t *, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vlseg7e32ff_v_m)))
void vlseg7e32ff(vuint32mf2_t *, vuint32mf2_t *, vuint32mf2_t *, vuint32mf2_t *, vuint32mf2_t *, vuint32mf2_t *, vuint32mf2_t *, vbool64_t, vuint32mf2_t, vuint32mf2_t, vuint32mf2_t, vuint32mf2_t, vuint32mf2_t, vuint32mf2_t, vuint32mf2_t, const uint32_t *, size_t *, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vlseg8e32ff_v_m)))
void vlseg8e32ff(vint32m1_t *, vint32m1_t *, vint32m1_t *, vint32m1_t *, vint32m1_t *, vint32m1_t *, vint32m1_t *, vint32m1_t *, vbool32_t, vint32m1_t, vint32m1_t, vint32m1_t, vint32m1_t, vint32m1_t, vint32m1_t, vint32m1_t, vint32m1_t, const int32_t *, size_t *, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vlseg8e32ff_v_m)))
void vlseg8e32ff(vint32mf2_t *, vint32mf2_t *, vint32mf2_t *, vint32mf2_t *, vint32mf2_t *, vint32mf2_t *, vint32mf2_t *, vint32mf2_t *, vbool64_t, vint32mf2_t, vint32mf2_t, vint32mf2_t, vint32mf2_t, vint32mf2_t, vint32mf2_t, vint32mf2_t, vint32mf2_t, const int32_t *, size_t *, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vlseg8e32ff_v_m)))
void vlseg8e32ff(vuint32m1_t *, vuint32m1_t *, vuint32m1_t *, vuint32m1_t *, vuint32m1_t *, vuint32m1_t *, vuint32m1_t *, vuint32m1_t *, vbool32_t, vuint32m1_t, vuint32m1_t, vuint32m1_t, vuint32m1_t, vuint32m1_t, vuint32m1_t, vuint32m1_t, vuint32m1_t, const uint32_t *, size_t *, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vlseg8e32ff_v_m)))
void vlseg8e32ff(vuint32mf2_t *, vuint32mf2_t *, vuint32mf2_t *, vuint32mf2_t *, vuint32mf2_t *, vuint32mf2_t *, vuint32mf2_t *, vuint32mf2_t *, vbool64_t, vuint32mf2_t, vuint32mf2_t, vuint32mf2_t, vuint32mf2_t, vuint32mf2_t, vuint32mf2_t, vuint32mf2_t, vuint32mf2_t, const uint32_t *, size_t *, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vlseg2e8ff_v_m)))
void vlseg2e8ff(vint8m1_t *, vint8m1_t *, vbool8_t, vint8m1_t, vint8m1_t, const int8_t *, size_t *, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vlseg2e8ff_v_m)))
void vlseg2e8ff(vint8m2_t *, vint8m2_t *, vbool4_t, vint8m2_t, vint8m2_t, const int8_t *, size_t *, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vlseg2e8ff_v_m)))
void vlseg2e8ff(vint8m4_t *, vint8m4_t *, vbool2_t, vint8m4_t, vint8m4_t, const int8_t *, size_t *, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vlseg2e8ff_v_m)))
void vlseg2e8ff(vint8mf2_t *, vint8mf2_t *, vbool16_t, vint8mf2_t, vint8mf2_t, const int8_t *, size_t *, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vlseg2e8ff_v_m)))
void vlseg2e8ff(vint8mf4_t *, vint8mf4_t *, vbool32_t, vint8mf4_t, vint8mf4_t, const int8_t *, size_t *, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vlseg2e8ff_v_m)))
void vlseg2e8ff(vint8mf8_t *, vint8mf8_t *, vbool64_t, vint8mf8_t, vint8mf8_t, const int8_t *, size_t *, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vlsseg3e8_v_m)))
void vlsseg3e8(vint8m1_t *, vint8m1_t *, vint8m1_t *, vbool8_t, vint8m1_t, vint8m1_t, vint8m1_t, const int8_t *, ptrdiff_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vlsseg3e8_v_m)))
void vlsseg3e8(vint8m2_t *, vint8m2_t *, vint8m2_t *, vbool4_t, vint8m2_t, vint8m2_t, vint8m2_t, const int8_t *, ptrdiff_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vlsseg3e8_v_m)))
void vlsseg3e8(vint8mf2_t *, vint8mf2_t *, vint8mf2_t *, vbool16_t, vint8mf2_t, vint8mf2_t, vint8mf2_t, const int8_t *, ptrdiff_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vlsseg3e8_v_m)))
void vlsseg3e8(vint8mf4_t *, vint8mf4_t *, vint8mf4_t *, vbool32_t, vint8mf4_t, vint8mf4_t, vint8mf4_t, const int8_t *, ptrdiff_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vlsseg3e8_v_m)))
void vlsseg3e8(vint8mf8_t *, vint8mf8_t *, vint8mf8_t *, vbool64_t, vint8mf8_t, vint8mf8_t, vint8mf8_t, const int8_t *, ptrdiff_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vlsseg3e8_v_m)))
void vlsseg3e8(vuint8m1_t *, vuint8m1_t *, vuint8m1_t *, vbool8_t, vuint8m1_t, vuint8m1_t, vuint8m1_t, const uint8_t *, ptrdiff_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vlsseg3e8_v_m)))
void vlsseg3e8(vuint8m2_t *, vuint8m2_t *, vuint8m2_t *, vbool4_t, vuint8m2_t, vuint8m2_t, vuint8m2_t, const uint8_t *, ptrdiff_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vlsseg3e8_v_m)))
void vlsseg3e8(vuint8mf2_t *, vuint8mf2_t *, vuint8mf2_t *, vbool16_t, vuint8mf2_t, vuint8mf2_t, vuint8mf2_t, const uint8_t *, ptrdiff_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vlsseg3e8_v_m)))
void vlsseg3e8(vuint8mf4_t *, vuint8mf4_t *, vuint8mf4_t *, vbool32_t, vuint8mf4_t, vuint8mf4_t, vuint8mf4_t, const uint8_t *, ptrdiff_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vlsseg3e8_v_m)))
void vlsseg3e8(vuint8mf8_t *, vuint8mf8_t *, vuint8mf8_t *, vbool64_t, vuint8mf8_t, vuint8mf8_t, vuint8mf8_t, const uint8_t *, ptrdiff_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vlsseg4e8_v_m)))
void vlsseg4e8(vint8m1_t *, vint8m1_t *, vint8m1_t *, vint8m1_t *, vbool8_t, vint8m1_t, vint8m1_t, vint8m1_t, vint8m1_t, const int8_t *, ptrdiff_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vlsseg4e8_v_m)))
void vlsseg4e8(vint8m2_t *, vint8m2_t *, vint8m2_t *, vint8m2_t *, vbool4_t, vint8m2_t, vint8m2_t, vint8m2_t, vint8m2_t, const int8_t *, ptrdiff_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vlsseg4e8_v_m)))
void vlsseg4e8(vint8mf2_t *, vint8mf2_t *, vint8mf2_t *, vint8mf2_t *, vbool16_t, vint8mf2_t, vint8mf2_t, vint8mf2_t, vint8mf2_t, const int8_t *, ptrdiff_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vlsseg4e8_v_m)))
void vlsseg4e8(vint8mf4_t *, vint8mf4_t *, vint8mf4_t *, vint8mf4_t *, vbool32_t, vint8mf4_t, vint8mf4_t, vint8mf4_t, vint8mf4_t, const int8_t *, ptrdiff_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vlsseg4e8_v_m)))
void vlsseg4e8(vint8mf8_t *, vint8mf8_t *, vint8mf8_t *, vint8mf8_t *, vbool64_t, vint8mf8_t, vint8mf8_t, vint8mf8_t, vint8mf8_t, const int8_t *, ptrdiff_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vlseg2e8ff_v_m)))
void vlseg2e8ff(vuint8m1_t *, vuint8m1_t *, vbool8_t, vuint8m1_t, vuint8m1_t, const uint8_t *, size_t *, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vlseg2e8ff_v_m)))
void vlseg2e8ff(vuint8m2_t *, vuint8m2_t *, vbool4_t, vuint8m2_t, vuint8m2_t, const uint8_t *, size_t *, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vlseg2e8ff_v_m)))
void vlseg2e8ff(vuint8m4_t *, vuint8m4_t *, vbool2_t, vuint8m4_t, vuint8m4_t, const uint8_t *, size_t *, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vlseg2e8ff_v_m)))
void vlseg2e8ff(vuint8mf2_t *, vuint8mf2_t *, vbool16_t, vuint8mf2_t, vuint8mf2_t, const uint8_t *, size_t *, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vlseg2e8ff_v_m)))
void vlseg2e8ff(vuint8mf4_t *, vuint8mf4_t *, vbool32_t, vuint8mf4_t, vuint8mf4_t, const uint8_t *, size_t *, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vlseg2e8ff_v_m)))
void vlseg2e8ff(vuint8mf8_t *, vuint8mf8_t *, vbool64_t, vuint8mf8_t, vuint8mf8_t, const uint8_t *, size_t *, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vlsseg4e8_v_m)))
void vlsseg4e8(vuint8m1_t *, vuint8m1_t *, vuint8m1_t *, vuint8m1_t *, vbool8_t, vuint8m1_t, vuint8m1_t, vuint8m1_t, vuint8m1_t, const uint8_t *, ptrdiff_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vlsseg4e8_v_m)))
void vlsseg4e8(vuint8m2_t *, vuint8m2_t *, vuint8m2_t *, vuint8m2_t *, vbool4_t, vuint8m2_t, vuint8m2_t, vuint8m2_t, vuint8m2_t, const uint8_t *, ptrdiff_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vlsseg4e8_v_m)))
void vlsseg4e8(vuint8mf2_t *, vuint8mf2_t *, vuint8mf2_t *, vuint8mf2_t *, vbool16_t, vuint8mf2_t, vuint8mf2_t, vuint8mf2_t, vuint8mf2_t, const uint8_t *, ptrdiff_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vlsseg4e8_v_m)))
void vlsseg4e8(vuint8mf4_t *, vuint8mf4_t *, vuint8mf4_t *, vuint8mf4_t *, vbool32_t, vuint8mf4_t, vuint8mf4_t, vuint8mf4_t, vuint8mf4_t, const uint8_t *, ptrdiff_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vlsseg4e8_v_m)))
void vlsseg4e8(vuint8mf8_t *, vuint8mf8_t *, vuint8mf8_t *, vuint8mf8_t *, vbool64_t, vuint8mf8_t, vuint8mf8_t, vuint8mf8_t, vuint8mf8_t, const uint8_t *, ptrdiff_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vlsseg5e8_v_m)))
void vlsseg5e8(vint8m1_t *, vint8m1_t *, vint8m1_t *, vint8m1_t *, vint8m1_t *, vbool8_t, vint8m1_t, vint8m1_t, vint8m1_t, vint8m1_t, vint8m1_t, const int8_t *, ptrdiff_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vlsseg5e8_v_m)))
void vlsseg5e8(vint8mf2_t *, vint8mf2_t *, vint8mf2_t *, vint8mf2_t *, vint8mf2_t *, vbool16_t, vint8mf2_t, vint8mf2_t, vint8mf2_t, vint8mf2_t, vint8mf2_t, const int8_t *, ptrdiff_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vlsseg5e8_v_m)))
void vlsseg5e8(vint8mf4_t *, vint8mf4_t *, vint8mf4_t *, vint8mf4_t *, vint8mf4_t *, vbool32_t, vint8mf4_t, vint8mf4_t, vint8mf4_t, vint8mf4_t, vint8mf4_t, const int8_t *, ptrdiff_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vlsseg5e8_v_m)))
void vlsseg5e8(vint8mf8_t *, vint8mf8_t *, vint8mf8_t *, vint8mf8_t *, vint8mf8_t *, vbool64_t, vint8mf8_t, vint8mf8_t, vint8mf8_t, vint8mf8_t, vint8mf8_t, const int8_t *, ptrdiff_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vlsseg5e8_v_m)))
void vlsseg5e8(vuint8m1_t *, vuint8m1_t *, vuint8m1_t *, vuint8m1_t *, vuint8m1_t *, vbool8_t, vuint8m1_t, vuint8m1_t, vuint8m1_t, vuint8m1_t, vuint8m1_t, const uint8_t *, ptrdiff_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vlsseg5e8_v_m)))
void vlsseg5e8(vuint8mf2_t *, vuint8mf2_t *, vuint8mf2_t *, vuint8mf2_t *, vuint8mf2_t *, vbool16_t, vuint8mf2_t, vuint8mf2_t, vuint8mf2_t, vuint8mf2_t, vuint8mf2_t, const uint8_t *, ptrdiff_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vlsseg5e8_v_m)))
void vlsseg5e8(vuint8mf4_t *, vuint8mf4_t *, vuint8mf4_t *, vuint8mf4_t *, vuint8mf4_t *, vbool32_t, vuint8mf4_t, vuint8mf4_t, vuint8mf4_t, vuint8mf4_t, vuint8mf4_t, const uint8_t *, ptrdiff_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vlsseg5e8_v_m)))
void vlsseg5e8(vuint8mf8_t *, vuint8mf8_t *, vuint8mf8_t *, vuint8mf8_t *, vuint8mf8_t *, vbool64_t, vuint8mf8_t, vuint8mf8_t, vuint8mf8_t, vuint8mf8_t, vuint8mf8_t, const uint8_t *, ptrdiff_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vlsseg6e8_v_m)))
void vlsseg6e8(vint8m1_t *, vint8m1_t *, vint8m1_t *, vint8m1_t *, vint8m1_t *, vint8m1_t *, vbool8_t, vint8m1_t, vint8m1_t, vint8m1_t, vint8m1_t, vint8m1_t, vint8m1_t, const int8_t *, ptrdiff_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vlsseg6e8_v_m)))
void vlsseg6e8(vint8mf2_t *, vint8mf2_t *, vint8mf2_t *, vint8mf2_t *, vint8mf2_t *, vint8mf2_t *, vbool16_t, vint8mf2_t, vint8mf2_t, vint8mf2_t, vint8mf2_t, vint8mf2_t, vint8mf2_t, const int8_t *, ptrdiff_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vlsseg6e8_v_m)))
void vlsseg6e8(vint8mf4_t *, vint8mf4_t *, vint8mf4_t *, vint8mf4_t *, vint8mf4_t *, vint8mf4_t *, vbool32_t, vint8mf4_t, vint8mf4_t, vint8mf4_t, vint8mf4_t, vint8mf4_t, vint8mf4_t, const int8_t *, ptrdiff_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vlsseg6e8_v_m)))
void vlsseg6e8(vint8mf8_t *, vint8mf8_t *, vint8mf8_t *, vint8mf8_t *, vint8mf8_t *, vint8mf8_t *, vbool64_t, vint8mf8_t, vint8mf8_t, vint8mf8_t, vint8mf8_t, vint8mf8_t, vint8mf8_t, const int8_t *, ptrdiff_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vlsseg6e8_v_m)))
void vlsseg6e8(vuint8m1_t *, vuint8m1_t *, vuint8m1_t *, vuint8m1_t *, vuint8m1_t *, vuint8m1_t *, vbool8_t, vuint8m1_t, vuint8m1_t, vuint8m1_t, vuint8m1_t, vuint8m1_t, vuint8m1_t, const uint8_t *, ptrdiff_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vlsseg6e8_v_m)))
void vlsseg6e8(vuint8mf2_t *, vuint8mf2_t *, vuint8mf2_t *, vuint8mf2_t *, vuint8mf2_t *, vuint8mf2_t *, vbool16_t, vuint8mf2_t, vuint8mf2_t, vuint8mf2_t, vuint8mf2_t, vuint8mf2_t, vuint8mf2_t, const uint8_t *, ptrdiff_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vlsseg6e8_v_m)))
void vlsseg6e8(vuint8mf4_t *, vuint8mf4_t *, vuint8mf4_t *, vuint8mf4_t *, vuint8mf4_t *, vuint8mf4_t *, vbool32_t, vuint8mf4_t, vuint8mf4_t, vuint8mf4_t, vuint8mf4_t, vuint8mf4_t, vuint8mf4_t, const uint8_t *, ptrdiff_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vlsseg6e8_v_m)))
void vlsseg6e8(vuint8mf8_t *, vuint8mf8_t *, vuint8mf8_t *, vuint8mf8_t *, vuint8mf8_t *, vuint8mf8_t *, vbool64_t, vuint8mf8_t, vuint8mf8_t, vuint8mf8_t, vuint8mf8_t, vuint8mf8_t, vuint8mf8_t, const uint8_t *, ptrdiff_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vlsseg7e8_v_m)))
void vlsseg7e8(vint8m1_t *, vint8m1_t *, vint8m1_t *, vint8m1_t *, vint8m1_t *, vint8m1_t *, vint8m1_t *, vbool8_t, vint8m1_t, vint8m1_t, vint8m1_t, vint8m1_t, vint8m1_t, vint8m1_t, vint8m1_t, const int8_t *, ptrdiff_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vlsseg7e8_v_m)))
void vlsseg7e8(vint8mf2_t *, vint8mf2_t *, vint8mf2_t *, vint8mf2_t *, vint8mf2_t *, vint8mf2_t *, vint8mf2_t *, vbool16_t, vint8mf2_t, vint8mf2_t, vint8mf2_t, vint8mf2_t, vint8mf2_t, vint8mf2_t, vint8mf2_t, const int8_t *, ptrdiff_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vlsseg7e8_v_m)))
void vlsseg7e8(vint8mf4_t *, vint8mf4_t *, vint8mf4_t *, vint8mf4_t *, vint8mf4_t *, vint8mf4_t *, vint8mf4_t *, vbool32_t, vint8mf4_t, vint8mf4_t, vint8mf4_t, vint8mf4_t, vint8mf4_t, vint8mf4_t, vint8mf4_t, const int8_t *, ptrdiff_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vlsseg7e8_v_m)))
void vlsseg7e8(vint8mf8_t *, vint8mf8_t *, vint8mf8_t *, vint8mf8_t *, vint8mf8_t *, vint8mf8_t *, vint8mf8_t *, vbool64_t, vint8mf8_t, vint8mf8_t, vint8mf8_t, vint8mf8_t, vint8mf8_t, vint8mf8_t, vint8mf8_t, const int8_t *, ptrdiff_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vlsseg7e8_v_m)))
void vlsseg7e8(vuint8m1_t *, vuint8m1_t *, vuint8m1_t *, vuint8m1_t *, vuint8m1_t *, vuint8m1_t *, vuint8m1_t *, vbool8_t, vuint8m1_t, vuint8m1_t, vuint8m1_t, vuint8m1_t, vuint8m1_t, vuint8m1_t, vuint8m1_t, const uint8_t *, ptrdiff_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vlsseg7e8_v_m)))
void vlsseg7e8(vuint8mf2_t *, vuint8mf2_t *, vuint8mf2_t *, vuint8mf2_t *, vuint8mf2_t *, vuint8mf2_t *, vuint8mf2_t *, vbool16_t, vuint8mf2_t, vuint8mf2_t, vuint8mf2_t, vuint8mf2_t, vuint8mf2_t, vuint8mf2_t, vuint8mf2_t, const uint8_t *, ptrdiff_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vlsseg7e8_v_m)))
void vlsseg7e8(vuint8mf4_t *, vuint8mf4_t *, vuint8mf4_t *, vuint8mf4_t *, vuint8mf4_t *, vuint8mf4_t *, vuint8mf4_t *, vbool32_t, vuint8mf4_t, vuint8mf4_t, vuint8mf4_t, vuint8mf4_t, vuint8mf4_t, vuint8mf4_t, vuint8mf4_t, const uint8_t *, ptrdiff_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vlsseg7e8_v_m)))
void vlsseg7e8(vuint8mf8_t *, vuint8mf8_t *, vuint8mf8_t *, vuint8mf8_t *, vuint8mf8_t *, vuint8mf8_t *, vuint8mf8_t *, vbool64_t, vuint8mf8_t, vuint8mf8_t, vuint8mf8_t, vuint8mf8_t, vuint8mf8_t, vuint8mf8_t, vuint8mf8_t, const uint8_t *, ptrdiff_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vlsseg8e8_v_m)))
void vlsseg8e8(vint8m1_t *, vint8m1_t *, vint8m1_t *, vint8m1_t *, vint8m1_t *, vint8m1_t *, vint8m1_t *, vint8m1_t *, vbool8_t, vint8m1_t, vint8m1_t, vint8m1_t, vint8m1_t, vint8m1_t, vint8m1_t, vint8m1_t, vint8m1_t, const int8_t *, ptrdiff_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vlsseg8e8_v_m)))
void vlsseg8e8(vint8mf2_t *, vint8mf2_t *, vint8mf2_t *, vint8mf2_t *, vint8mf2_t *, vint8mf2_t *, vint8mf2_t *, vint8mf2_t *, vbool16_t, vint8mf2_t, vint8mf2_t, vint8mf2_t, vint8mf2_t, vint8mf2_t, vint8mf2_t, vint8mf2_t, vint8mf2_t, const int8_t *, ptrdiff_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vlsseg8e8_v_m)))
void vlsseg8e8(vint8mf4_t *, vint8mf4_t *, vint8mf4_t *, vint8mf4_t *, vint8mf4_t *, vint8mf4_t *, vint8mf4_t *, vint8mf4_t *, vbool32_t, vint8mf4_t, vint8mf4_t, vint8mf4_t, vint8mf4_t, vint8mf4_t, vint8mf4_t, vint8mf4_t, vint8mf4_t, const int8_t *, ptrdiff_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vlsseg8e8_v_m)))
void vlsseg8e8(vint8mf8_t *, vint8mf8_t *, vint8mf8_t *, vint8mf8_t *, vint8mf8_t *, vint8mf8_t *, vint8mf8_t *, vint8mf8_t *, vbool64_t, vint8mf8_t, vint8mf8_t, vint8mf8_t, vint8mf8_t, vint8mf8_t, vint8mf8_t, vint8mf8_t, vint8mf8_t, const int8_t *, ptrdiff_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vlsseg8e8_v_m)))
void vlsseg8e8(vuint8m1_t *, vuint8m1_t *, vuint8m1_t *, vuint8m1_t *, vuint8m1_t *, vuint8m1_t *, vuint8m1_t *, vuint8m1_t *, vbool8_t, vuint8m1_t, vuint8m1_t, vuint8m1_t, vuint8m1_t, vuint8m1_t, vuint8m1_t, vuint8m1_t, vuint8m1_t, const uint8_t *, ptrdiff_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vlsseg8e8_v_m)))
void vlsseg8e8(vuint8mf2_t *, vuint8mf2_t *, vuint8mf2_t *, vuint8mf2_t *, vuint8mf2_t *, vuint8mf2_t *, vuint8mf2_t *, vuint8mf2_t *, vbool16_t, vuint8mf2_t, vuint8mf2_t, vuint8mf2_t, vuint8mf2_t, vuint8mf2_t, vuint8mf2_t, vuint8mf2_t, vuint8mf2_t, const uint8_t *, ptrdiff_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vlsseg8e8_v_m)))
void vlsseg8e8(vuint8mf4_t *, vuint8mf4_t *, vuint8mf4_t *, vuint8mf4_t *, vuint8mf4_t *, vuint8mf4_t *, vuint8mf4_t *, vuint8mf4_t *, vbool32_t, vuint8mf4_t, vuint8mf4_t, vuint8mf4_t, vuint8mf4_t, vuint8mf4_t, vuint8mf4_t, vuint8mf4_t, vuint8mf4_t, const uint8_t *, ptrdiff_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vlsseg8e8_v_m)))
void vlsseg8e8(vuint8mf8_t *, vuint8mf8_t *, vuint8mf8_t *, vuint8mf8_t *, vuint8mf8_t *, vuint8mf8_t *, vuint8mf8_t *, vuint8mf8_t *, vbool64_t, vuint8mf8_t, vuint8mf8_t, vuint8mf8_t, vuint8mf8_t, vuint8mf8_t, vuint8mf8_t, vuint8mf8_t, vuint8mf8_t, const uint8_t *, ptrdiff_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vlsseg2e16_v_m)))
void vlsseg2e16(vint16m1_t *, vint16m1_t *, vbool16_t, vint16m1_t, vint16m1_t, const int16_t *, ptrdiff_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vlsseg2e16_v_m)))
void vlsseg2e16(vint16m2_t *, vint16m2_t *, vbool8_t, vint16m2_t, vint16m2_t, const int16_t *, ptrdiff_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vlsseg2e16_v_m)))
void vlsseg2e16(vint16m4_t *, vint16m4_t *, vbool4_t, vint16m4_t, vint16m4_t, const int16_t *, ptrdiff_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vlsseg2e16_v_m)))
void vlsseg2e16(vint16mf2_t *, vint16mf2_t *, vbool32_t, vint16mf2_t, vint16mf2_t, const int16_t *, ptrdiff_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vlsseg2e16_v_m)))
void vlsseg2e16(vint16mf4_t *, vint16mf4_t *, vbool64_t, vint16mf4_t, vint16mf4_t, const int16_t *, ptrdiff_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vlsseg2e8_v_m)))
void vlsseg2e8(vint8m1_t *, vint8m1_t *, vbool8_t, vint8m1_t, vint8m1_t, const int8_t *, ptrdiff_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vlsseg2e8_v_m)))
void vlsseg2e8(vint8m2_t *, vint8m2_t *, vbool4_t, vint8m2_t, vint8m2_t, const int8_t *, ptrdiff_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vlsseg2e8_v_m)))
void vlsseg2e8(vint8m4_t *, vint8m4_t *, vbool2_t, vint8m4_t, vint8m4_t, const int8_t *, ptrdiff_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vlsseg2e8_v_m)))
void vlsseg2e8(vint8mf2_t *, vint8mf2_t *, vbool16_t, vint8mf2_t, vint8mf2_t, const int8_t *, ptrdiff_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vlsseg2e8_v_m)))
void vlsseg2e8(vint8mf4_t *, vint8mf4_t *, vbool32_t, vint8mf4_t, vint8mf4_t, const int8_t *, ptrdiff_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vlsseg2e8_v_m)))
void vlsseg2e8(vint8mf8_t *, vint8mf8_t *, vbool64_t, vint8mf8_t, vint8mf8_t, const int8_t *, ptrdiff_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vlsseg2e16_v_m)))
void vlsseg2e16(vuint16m1_t *, vuint16m1_t *, vbool16_t, vuint16m1_t, vuint16m1_t, const uint16_t *, ptrdiff_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vlsseg2e16_v_m)))
void vlsseg2e16(vuint16m2_t *, vuint16m2_t *, vbool8_t, vuint16m2_t, vuint16m2_t, const uint16_t *, ptrdiff_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vlsseg2e16_v_m)))
void vlsseg2e16(vuint16m4_t *, vuint16m4_t *, vbool4_t, vuint16m4_t, vuint16m4_t, const uint16_t *, ptrdiff_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vlsseg2e16_v_m)))
void vlsseg2e16(vuint16mf2_t *, vuint16mf2_t *, vbool32_t, vuint16mf2_t, vuint16mf2_t, const uint16_t *, ptrdiff_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vlsseg2e16_v_m)))
void vlsseg2e16(vuint16mf4_t *, vuint16mf4_t *, vbool64_t, vuint16mf4_t, vuint16mf4_t, const uint16_t *, ptrdiff_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vlsseg3e16_v_m)))
void vlsseg3e16(vint16m1_t *, vint16m1_t *, vint16m1_t *, vbool16_t, vint16m1_t, vint16m1_t, vint16m1_t, const int16_t *, ptrdiff_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vlsseg3e16_v_m)))
void vlsseg3e16(vint16m2_t *, vint16m2_t *, vint16m2_t *, vbool8_t, vint16m2_t, vint16m2_t, vint16m2_t, const int16_t *, ptrdiff_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vlsseg3e16_v_m)))
void vlsseg3e16(vint16mf2_t *, vint16mf2_t *, vint16mf2_t *, vbool32_t, vint16mf2_t, vint16mf2_t, vint16mf2_t, const int16_t *, ptrdiff_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vlsseg3e16_v_m)))
void vlsseg3e16(vint16mf4_t *, vint16mf4_t *, vint16mf4_t *, vbool64_t, vint16mf4_t, vint16mf4_t, vint16mf4_t, const int16_t *, ptrdiff_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vlsseg3e16_v_m)))
void vlsseg3e16(vuint16m1_t *, vuint16m1_t *, vuint16m1_t *, vbool16_t, vuint16m1_t, vuint16m1_t, vuint16m1_t, const uint16_t *, ptrdiff_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vlsseg3e16_v_m)))
void vlsseg3e16(vuint16m2_t *, vuint16m2_t *, vuint16m2_t *, vbool8_t, vuint16m2_t, vuint16m2_t, vuint16m2_t, const uint16_t *, ptrdiff_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vlsseg3e16_v_m)))
void vlsseg3e16(vuint16mf2_t *, vuint16mf2_t *, vuint16mf2_t *, vbool32_t, vuint16mf2_t, vuint16mf2_t, vuint16mf2_t, const uint16_t *, ptrdiff_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vlsseg3e16_v_m)))
void vlsseg3e16(vuint16mf4_t *, vuint16mf4_t *, vuint16mf4_t *, vbool64_t, vuint16mf4_t, vuint16mf4_t, vuint16mf4_t, const uint16_t *, ptrdiff_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vlsseg4e16_v_m)))
void vlsseg4e16(vint16m1_t *, vint16m1_t *, vint16m1_t *, vint16m1_t *, vbool16_t, vint16m1_t, vint16m1_t, vint16m1_t, vint16m1_t, const int16_t *, ptrdiff_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vlsseg4e16_v_m)))
void vlsseg4e16(vint16m2_t *, vint16m2_t *, vint16m2_t *, vint16m2_t *, vbool8_t, vint16m2_t, vint16m2_t, vint16m2_t, vint16m2_t, const int16_t *, ptrdiff_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vlsseg4e16_v_m)))
void vlsseg4e16(vint16mf2_t *, vint16mf2_t *, vint16mf2_t *, vint16mf2_t *, vbool32_t, vint16mf2_t, vint16mf2_t, vint16mf2_t, vint16mf2_t, const int16_t *, ptrdiff_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vlsseg4e16_v_m)))
void vlsseg4e16(vint16mf4_t *, vint16mf4_t *, vint16mf4_t *, vint16mf4_t *, vbool64_t, vint16mf4_t, vint16mf4_t, vint16mf4_t, vint16mf4_t, const int16_t *, ptrdiff_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vlsseg4e16_v_m)))
void vlsseg4e16(vuint16m1_t *, vuint16m1_t *, vuint16m1_t *, vuint16m1_t *, vbool16_t, vuint16m1_t, vuint16m1_t, vuint16m1_t, vuint16m1_t, const uint16_t *, ptrdiff_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vlsseg4e16_v_m)))
void vlsseg4e16(vuint16m2_t *, vuint16m2_t *, vuint16m2_t *, vuint16m2_t *, vbool8_t, vuint16m2_t, vuint16m2_t, vuint16m2_t, vuint16m2_t, const uint16_t *, ptrdiff_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vlsseg4e16_v_m)))
void vlsseg4e16(vuint16mf2_t *, vuint16mf2_t *, vuint16mf2_t *, vuint16mf2_t *, vbool32_t, vuint16mf2_t, vuint16mf2_t, vuint16mf2_t, vuint16mf2_t, const uint16_t *, ptrdiff_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vlsseg4e16_v_m)))
void vlsseg4e16(vuint16mf4_t *, vuint16mf4_t *, vuint16mf4_t *, vuint16mf4_t *, vbool64_t, vuint16mf4_t, vuint16mf4_t, vuint16mf4_t, vuint16mf4_t, const uint16_t *, ptrdiff_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vlsseg5e16_v_m)))
void vlsseg5e16(vint16m1_t *, vint16m1_t *, vint16m1_t *, vint16m1_t *, vint16m1_t *, vbool16_t, vint16m1_t, vint16m1_t, vint16m1_t, vint16m1_t, vint16m1_t, const int16_t *, ptrdiff_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vlsseg5e16_v_m)))
void vlsseg5e16(vint16mf2_t *, vint16mf2_t *, vint16mf2_t *, vint16mf2_t *, vint16mf2_t *, vbool32_t, vint16mf2_t, vint16mf2_t, vint16mf2_t, vint16mf2_t, vint16mf2_t, const int16_t *, ptrdiff_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vlsseg5e16_v_m)))
void vlsseg5e16(vint16mf4_t *, vint16mf4_t *, vint16mf4_t *, vint16mf4_t *, vint16mf4_t *, vbool64_t, vint16mf4_t, vint16mf4_t, vint16mf4_t, vint16mf4_t, vint16mf4_t, const int16_t *, ptrdiff_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vlsseg5e16_v_m)))
void vlsseg5e16(vuint16m1_t *, vuint16m1_t *, vuint16m1_t *, vuint16m1_t *, vuint16m1_t *, vbool16_t, vuint16m1_t, vuint16m1_t, vuint16m1_t, vuint16m1_t, vuint16m1_t, const uint16_t *, ptrdiff_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vlsseg5e16_v_m)))
void vlsseg5e16(vuint16mf2_t *, vuint16mf2_t *, vuint16mf2_t *, vuint16mf2_t *, vuint16mf2_t *, vbool32_t, vuint16mf2_t, vuint16mf2_t, vuint16mf2_t, vuint16mf2_t, vuint16mf2_t, const uint16_t *, ptrdiff_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vlsseg5e16_v_m)))
void vlsseg5e16(vuint16mf4_t *, vuint16mf4_t *, vuint16mf4_t *, vuint16mf4_t *, vuint16mf4_t *, vbool64_t, vuint16mf4_t, vuint16mf4_t, vuint16mf4_t, vuint16mf4_t, vuint16mf4_t, const uint16_t *, ptrdiff_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vlsseg6e16_v_m)))
void vlsseg6e16(vint16m1_t *, vint16m1_t *, vint16m1_t *, vint16m1_t *, vint16m1_t *, vint16m1_t *, vbool16_t, vint16m1_t, vint16m1_t, vint16m1_t, vint16m1_t, vint16m1_t, vint16m1_t, const int16_t *, ptrdiff_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vlsseg6e16_v_m)))
void vlsseg6e16(vint16mf2_t *, vint16mf2_t *, vint16mf2_t *, vint16mf2_t *, vint16mf2_t *, vint16mf2_t *, vbool32_t, vint16mf2_t, vint16mf2_t, vint16mf2_t, vint16mf2_t, vint16mf2_t, vint16mf2_t, const int16_t *, ptrdiff_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vlsseg6e16_v_m)))
void vlsseg6e16(vint16mf4_t *, vint16mf4_t *, vint16mf4_t *, vint16mf4_t *, vint16mf4_t *, vint16mf4_t *, vbool64_t, vint16mf4_t, vint16mf4_t, vint16mf4_t, vint16mf4_t, vint16mf4_t, vint16mf4_t, const int16_t *, ptrdiff_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vlsseg6e16_v_m)))
void vlsseg6e16(vuint16m1_t *, vuint16m1_t *, vuint16m1_t *, vuint16m1_t *, vuint16m1_t *, vuint16m1_t *, vbool16_t, vuint16m1_t, vuint16m1_t, vuint16m1_t, vuint16m1_t, vuint16m1_t, vuint16m1_t, const uint16_t *, ptrdiff_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vlsseg6e16_v_m)))
void vlsseg6e16(vuint16mf2_t *, vuint16mf2_t *, vuint16mf2_t *, vuint16mf2_t *, vuint16mf2_t *, vuint16mf2_t *, vbool32_t, vuint16mf2_t, vuint16mf2_t, vuint16mf2_t, vuint16mf2_t, vuint16mf2_t, vuint16mf2_t, const uint16_t *, ptrdiff_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vlsseg6e16_v_m)))
void vlsseg6e16(vuint16mf4_t *, vuint16mf4_t *, vuint16mf4_t *, vuint16mf4_t *, vuint16mf4_t *, vuint16mf4_t *, vbool64_t, vuint16mf4_t, vuint16mf4_t, vuint16mf4_t, vuint16mf4_t, vuint16mf4_t, vuint16mf4_t, const uint16_t *, ptrdiff_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vlsseg7e16_v_m)))
void vlsseg7e16(vint16m1_t *, vint16m1_t *, vint16m1_t *, vint16m1_t *, vint16m1_t *, vint16m1_t *, vint16m1_t *, vbool16_t, vint16m1_t, vint16m1_t, vint16m1_t, vint16m1_t, vint16m1_t, vint16m1_t, vint16m1_t, const int16_t *, ptrdiff_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vlsseg7e16_v_m)))
void vlsseg7e16(vint16mf2_t *, vint16mf2_t *, vint16mf2_t *, vint16mf2_t *, vint16mf2_t *, vint16mf2_t *, vint16mf2_t *, vbool32_t, vint16mf2_t, vint16mf2_t, vint16mf2_t, vint16mf2_t, vint16mf2_t, vint16mf2_t, vint16mf2_t, const int16_t *, ptrdiff_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vlsseg7e16_v_m)))
void vlsseg7e16(vint16mf4_t *, vint16mf4_t *, vint16mf4_t *, vint16mf4_t *, vint16mf4_t *, vint16mf4_t *, vint16mf4_t *, vbool64_t, vint16mf4_t, vint16mf4_t, vint16mf4_t, vint16mf4_t, vint16mf4_t, vint16mf4_t, vint16mf4_t, const int16_t *, ptrdiff_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vlsseg2e8_v_m)))
void vlsseg2e8(vuint8m1_t *, vuint8m1_t *, vbool8_t, vuint8m1_t, vuint8m1_t, const uint8_t *, ptrdiff_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vlsseg2e8_v_m)))
void vlsseg2e8(vuint8m2_t *, vuint8m2_t *, vbool4_t, vuint8m2_t, vuint8m2_t, const uint8_t *, ptrdiff_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vlsseg2e8_v_m)))
void vlsseg2e8(vuint8m4_t *, vuint8m4_t *, vbool2_t, vuint8m4_t, vuint8m4_t, const uint8_t *, ptrdiff_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vlsseg2e8_v_m)))
void vlsseg2e8(vuint8mf2_t *, vuint8mf2_t *, vbool16_t, vuint8mf2_t, vuint8mf2_t, const uint8_t *, ptrdiff_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vlsseg2e8_v_m)))
void vlsseg2e8(vuint8mf4_t *, vuint8mf4_t *, vbool32_t, vuint8mf4_t, vuint8mf4_t, const uint8_t *, ptrdiff_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vlsseg2e8_v_m)))
void vlsseg2e8(vuint8mf8_t *, vuint8mf8_t *, vbool64_t, vuint8mf8_t, vuint8mf8_t, const uint8_t *, ptrdiff_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vlsseg7e16_v_m)))
void vlsseg7e16(vuint16m1_t *, vuint16m1_t *, vuint16m1_t *, vuint16m1_t *, vuint16m1_t *, vuint16m1_t *, vuint16m1_t *, vbool16_t, vuint16m1_t, vuint16m1_t, vuint16m1_t, vuint16m1_t, vuint16m1_t, vuint16m1_t, vuint16m1_t, const uint16_t *, ptrdiff_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vlsseg7e16_v_m)))
void vlsseg7e16(vuint16mf2_t *, vuint16mf2_t *, vuint16mf2_t *, vuint16mf2_t *, vuint16mf2_t *, vuint16mf2_t *, vuint16mf2_t *, vbool32_t, vuint16mf2_t, vuint16mf2_t, vuint16mf2_t, vuint16mf2_t, vuint16mf2_t, vuint16mf2_t, vuint16mf2_t, const uint16_t *, ptrdiff_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vlsseg7e16_v_m)))
void vlsseg7e16(vuint16mf4_t *, vuint16mf4_t *, vuint16mf4_t *, vuint16mf4_t *, vuint16mf4_t *, vuint16mf4_t *, vuint16mf4_t *, vbool64_t, vuint16mf4_t, vuint16mf4_t, vuint16mf4_t, vuint16mf4_t, vuint16mf4_t, vuint16mf4_t, vuint16mf4_t, const uint16_t *, ptrdiff_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vlsseg8e16_v_m)))
void vlsseg8e16(vint16m1_t *, vint16m1_t *, vint16m1_t *, vint16m1_t *, vint16m1_t *, vint16m1_t *, vint16m1_t *, vint16m1_t *, vbool16_t, vint16m1_t, vint16m1_t, vint16m1_t, vint16m1_t, vint16m1_t, vint16m1_t, vint16m1_t, vint16m1_t, const int16_t *, ptrdiff_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vlsseg8e16_v_m)))
void vlsseg8e16(vint16mf2_t *, vint16mf2_t *, vint16mf2_t *, vint16mf2_t *, vint16mf2_t *, vint16mf2_t *, vint16mf2_t *, vint16mf2_t *, vbool32_t, vint16mf2_t, vint16mf2_t, vint16mf2_t, vint16mf2_t, vint16mf2_t, vint16mf2_t, vint16mf2_t, vint16mf2_t, const int16_t *, ptrdiff_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vlsseg8e16_v_m)))
void vlsseg8e16(vint16mf4_t *, vint16mf4_t *, vint16mf4_t *, vint16mf4_t *, vint16mf4_t *, vint16mf4_t *, vint16mf4_t *, vint16mf4_t *, vbool64_t, vint16mf4_t, vint16mf4_t, vint16mf4_t, vint16mf4_t, vint16mf4_t, vint16mf4_t, vint16mf4_t, vint16mf4_t, const int16_t *, ptrdiff_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vlsseg8e16_v_m)))
void vlsseg8e16(vuint16m1_t *, vuint16m1_t *, vuint16m1_t *, vuint16m1_t *, vuint16m1_t *, vuint16m1_t *, vuint16m1_t *, vuint16m1_t *, vbool16_t, vuint16m1_t, vuint16m1_t, vuint16m1_t, vuint16m1_t, vuint16m1_t, vuint16m1_t, vuint16m1_t, vuint16m1_t, const uint16_t *, ptrdiff_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vlsseg8e16_v_m)))
void vlsseg8e16(vuint16mf2_t *, vuint16mf2_t *, vuint16mf2_t *, vuint16mf2_t *, vuint16mf2_t *, vuint16mf2_t *, vuint16mf2_t *, vuint16mf2_t *, vbool32_t, vuint16mf2_t, vuint16mf2_t, vuint16mf2_t, vuint16mf2_t, vuint16mf2_t, vuint16mf2_t, vuint16mf2_t, vuint16mf2_t, const uint16_t *, ptrdiff_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vlsseg8e16_v_m)))
void vlsseg8e16(vuint16mf4_t *, vuint16mf4_t *, vuint16mf4_t *, vuint16mf4_t *, vuint16mf4_t *, vuint16mf4_t *, vuint16mf4_t *, vuint16mf4_t *, vbool64_t, vuint16mf4_t, vuint16mf4_t, vuint16mf4_t, vuint16mf4_t, vuint16mf4_t, vuint16mf4_t, vuint16mf4_t, vuint16mf4_t, const uint16_t *, ptrdiff_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vlsseg2e32_v_m)))
void vlsseg2e32(vint32m1_t *, vint32m1_t *, vbool32_t, vint32m1_t, vint32m1_t, const int32_t *, ptrdiff_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vlsseg2e32_v_m)))
void vlsseg2e32(vint32m2_t *, vint32m2_t *, vbool16_t, vint32m2_t, vint32m2_t, const int32_t *, ptrdiff_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vlsseg2e32_v_m)))
void vlsseg2e32(vint32m4_t *, vint32m4_t *, vbool8_t, vint32m4_t, vint32m4_t, const int32_t *, ptrdiff_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vlsseg2e32_v_m)))
void vlsseg2e32(vint32mf2_t *, vint32mf2_t *, vbool64_t, vint32mf2_t, vint32mf2_t, const int32_t *, ptrdiff_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vlsseg2e32_v_m)))
void vlsseg2e32(vuint32m1_t *, vuint32m1_t *, vbool32_t, vuint32m1_t, vuint32m1_t, const uint32_t *, ptrdiff_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vlsseg2e32_v_m)))
void vlsseg2e32(vuint32m2_t *, vuint32m2_t *, vbool16_t, vuint32m2_t, vuint32m2_t, const uint32_t *, ptrdiff_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vlsseg2e32_v_m)))
void vlsseg2e32(vuint32m4_t *, vuint32m4_t *, vbool8_t, vuint32m4_t, vuint32m4_t, const uint32_t *, ptrdiff_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vlsseg2e32_v_m)))
void vlsseg2e32(vuint32mf2_t *, vuint32mf2_t *, vbool64_t, vuint32mf2_t, vuint32mf2_t, const uint32_t *, ptrdiff_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vlsseg3e32_v_m)))
void vlsseg3e32(vint32m1_t *, vint32m1_t *, vint32m1_t *, vbool32_t, vint32m1_t, vint32m1_t, vint32m1_t, const int32_t *, ptrdiff_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vlsseg3e32_v_m)))
void vlsseg3e32(vint32m2_t *, vint32m2_t *, vint32m2_t *, vbool16_t, vint32m2_t, vint32m2_t, vint32m2_t, const int32_t *, ptrdiff_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vlsseg3e32_v_m)))
void vlsseg3e32(vint32mf2_t *, vint32mf2_t *, vint32mf2_t *, vbool64_t, vint32mf2_t, vint32mf2_t, vint32mf2_t, const int32_t *, ptrdiff_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vlsseg3e32_v_m)))
void vlsseg3e32(vuint32m1_t *, vuint32m1_t *, vuint32m1_t *, vbool32_t, vuint32m1_t, vuint32m1_t, vuint32m1_t, const uint32_t *, ptrdiff_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vlsseg3e32_v_m)))
void vlsseg3e32(vuint32m2_t *, vuint32m2_t *, vuint32m2_t *, vbool16_t, vuint32m2_t, vuint32m2_t, vuint32m2_t, const uint32_t *, ptrdiff_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vlsseg3e32_v_m)))
void vlsseg3e32(vuint32mf2_t *, vuint32mf2_t *, vuint32mf2_t *, vbool64_t, vuint32mf2_t, vuint32mf2_t, vuint32mf2_t, const uint32_t *, ptrdiff_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vlsseg4e32_v_m)))
void vlsseg4e32(vint32m1_t *, vint32m1_t *, vint32m1_t *, vint32m1_t *, vbool32_t, vint32m1_t, vint32m1_t, vint32m1_t, vint32m1_t, const int32_t *, ptrdiff_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vlsseg4e32_v_m)))
void vlsseg4e32(vint32m2_t *, vint32m2_t *, vint32m2_t *, vint32m2_t *, vbool16_t, vint32m2_t, vint32m2_t, vint32m2_t, vint32m2_t, const int32_t *, ptrdiff_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vlsseg4e32_v_m)))
void vlsseg4e32(vint32mf2_t *, vint32mf2_t *, vint32mf2_t *, vint32mf2_t *, vbool64_t, vint32mf2_t, vint32mf2_t, vint32mf2_t, vint32mf2_t, const int32_t *, ptrdiff_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vlsseg4e32_v_m)))
void vlsseg4e32(vuint32m1_t *, vuint32m1_t *, vuint32m1_t *, vuint32m1_t *, vbool32_t, vuint32m1_t, vuint32m1_t, vuint32m1_t, vuint32m1_t, const uint32_t *, ptrdiff_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vlsseg4e32_v_m)))
void vlsseg4e32(vuint32m2_t *, vuint32m2_t *, vuint32m2_t *, vuint32m2_t *, vbool16_t, vuint32m2_t, vuint32m2_t, vuint32m2_t, vuint32m2_t, const uint32_t *, ptrdiff_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vlsseg4e32_v_m)))
void vlsseg4e32(vuint32mf2_t *, vuint32mf2_t *, vuint32mf2_t *, vuint32mf2_t *, vbool64_t, vuint32mf2_t, vuint32mf2_t, vuint32mf2_t, vuint32mf2_t, const uint32_t *, ptrdiff_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vlsseg5e32_v_m)))
void vlsseg5e32(vint32m1_t *, vint32m1_t *, vint32m1_t *, vint32m1_t *, vint32m1_t *, vbool32_t, vint32m1_t, vint32m1_t, vint32m1_t, vint32m1_t, vint32m1_t, const int32_t *, ptrdiff_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vlsseg5e32_v_m)))
void vlsseg5e32(vint32mf2_t *, vint32mf2_t *, vint32mf2_t *, vint32mf2_t *, vint32mf2_t *, vbool64_t, vint32mf2_t, vint32mf2_t, vint32mf2_t, vint32mf2_t, vint32mf2_t, const int32_t *, ptrdiff_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vluxseg2ei8_v)))
void vluxseg2ei8(vint8m1_t *, vint8m1_t *, const int8_t *, vuint8m1_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vluxseg2ei8_v_m)))
void vluxseg2ei8(vint8m1_t *, vint8m1_t *, vbool8_t, vint8m1_t, vint8m1_t, const int8_t *, vuint8m1_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vluxseg2ei8_v)))
void vluxseg2ei8(vint8m2_t *, vint8m2_t *, const int8_t *, vuint8m2_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vluxseg2ei8_v_m)))
void vluxseg2ei8(vint8m2_t *, vint8m2_t *, vbool4_t, vint8m2_t, vint8m2_t, const int8_t *, vuint8m2_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vluxseg2ei8_v)))
void vluxseg2ei8(vint8m4_t *, vint8m4_t *, const int8_t *, vuint8m4_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vluxseg2ei8_v_m)))
void vluxseg2ei8(vint8m4_t *, vint8m4_t *, vbool2_t, vint8m4_t, vint8m4_t, const int8_t *, vuint8m4_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vluxseg2ei8_v)))
void vluxseg2ei8(vint8mf2_t *, vint8mf2_t *, const int8_t *, vuint8mf2_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vluxseg2ei8_v_m)))
void vluxseg2ei8(vint8mf2_t *, vint8mf2_t *, vbool16_t, vint8mf2_t, vint8mf2_t, const int8_t *, vuint8mf2_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vluxseg2ei8_v)))
void vluxseg2ei8(vint8mf4_t *, vint8mf4_t *, const int8_t *, vuint8mf4_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vluxseg2ei8_v_m)))
void vluxseg2ei8(vint8mf4_t *, vint8mf4_t *, vbool32_t, vint8mf4_t, vint8mf4_t, const int8_t *, vuint8mf4_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vluxseg2ei8_v)))
void vluxseg2ei8(vint8mf8_t *, vint8mf8_t *, const int8_t *, vuint8mf8_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vluxseg2ei8_v_m)))
void vluxseg2ei8(vint8mf8_t *, vint8mf8_t *, vbool64_t, vint8mf8_t, vint8mf8_t, const int8_t *, vuint8mf8_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vlsseg5e32_v_m)))
void vlsseg5e32(vuint32m1_t *, vuint32m1_t *, vuint32m1_t *, vuint32m1_t *, vuint32m1_t *, vbool32_t, vuint32m1_t, vuint32m1_t, vuint32m1_t, vuint32m1_t, vuint32m1_t, const uint32_t *, ptrdiff_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vlsseg5e32_v_m)))
void vlsseg5e32(vuint32mf2_t *, vuint32mf2_t *, vuint32mf2_t *, vuint32mf2_t *, vuint32mf2_t *, vbool64_t, vuint32mf2_t, vuint32mf2_t, vuint32mf2_t, vuint32mf2_t, vuint32mf2_t, const uint32_t *, ptrdiff_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vlsseg6e32_v_m)))
void vlsseg6e32(vint32m1_t *, vint32m1_t *, vint32m1_t *, vint32m1_t *, vint32m1_t *, vint32m1_t *, vbool32_t, vint32m1_t, vint32m1_t, vint32m1_t, vint32m1_t, vint32m1_t, vint32m1_t, const int32_t *, ptrdiff_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vlsseg6e32_v_m)))
void vlsseg6e32(vint32mf2_t *, vint32mf2_t *, vint32mf2_t *, vint32mf2_t *, vint32mf2_t *, vint32mf2_t *, vbool64_t, vint32mf2_t, vint32mf2_t, vint32mf2_t, vint32mf2_t, vint32mf2_t, vint32mf2_t, const int32_t *, ptrdiff_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vlsseg6e32_v_m)))
void vlsseg6e32(vuint32m1_t *, vuint32m1_t *, vuint32m1_t *, vuint32m1_t *, vuint32m1_t *, vuint32m1_t *, vbool32_t, vuint32m1_t, vuint32m1_t, vuint32m1_t, vuint32m1_t, vuint32m1_t, vuint32m1_t, const uint32_t *, ptrdiff_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vlsseg6e32_v_m)))
void vlsseg6e32(vuint32mf2_t *, vuint32mf2_t *, vuint32mf2_t *, vuint32mf2_t *, vuint32mf2_t *, vuint32mf2_t *, vbool64_t, vuint32mf2_t, vuint32mf2_t, vuint32mf2_t, vuint32mf2_t, vuint32mf2_t, vuint32mf2_t, const uint32_t *, ptrdiff_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vlsseg7e32_v_m)))
void vlsseg7e32(vint32m1_t *, vint32m1_t *, vint32m1_t *, vint32m1_t *, vint32m1_t *, vint32m1_t *, vint32m1_t *, vbool32_t, vint32m1_t, vint32m1_t, vint32m1_t, vint32m1_t, vint32m1_t, vint32m1_t, vint32m1_t, const int32_t *, ptrdiff_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vlsseg7e32_v_m)))
void vlsseg7e32(vint32mf2_t *, vint32mf2_t *, vint32mf2_t *, vint32mf2_t *, vint32mf2_t *, vint32mf2_t *, vint32mf2_t *, vbool64_t, vint32mf2_t, vint32mf2_t, vint32mf2_t, vint32mf2_t, vint32mf2_t, vint32mf2_t, vint32mf2_t, const int32_t *, ptrdiff_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vlsseg7e32_v_m)))
void vlsseg7e32(vuint32m1_t *, vuint32m1_t *, vuint32m1_t *, vuint32m1_t *, vuint32m1_t *, vuint32m1_t *, vuint32m1_t *, vbool32_t, vuint32m1_t, vuint32m1_t, vuint32m1_t, vuint32m1_t, vuint32m1_t, vuint32m1_t, vuint32m1_t, const uint32_t *, ptrdiff_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vlsseg7e32_v_m)))
void vlsseg7e32(vuint32mf2_t *, vuint32mf2_t *, vuint32mf2_t *, vuint32mf2_t *, vuint32mf2_t *, vuint32mf2_t *, vuint32mf2_t *, vbool64_t, vuint32mf2_t, vuint32mf2_t, vuint32mf2_t, vuint32mf2_t, vuint32mf2_t, vuint32mf2_t, vuint32mf2_t, const uint32_t *, ptrdiff_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vlsseg8e32_v_m)))
void vlsseg8e32(vint32m1_t *, vint32m1_t *, vint32m1_t *, vint32m1_t *, vint32m1_t *, vint32m1_t *, vint32m1_t *, vint32m1_t *, vbool32_t, vint32m1_t, vint32m1_t, vint32m1_t, vint32m1_t, vint32m1_t, vint32m1_t, vint32m1_t, vint32m1_t, const int32_t *, ptrdiff_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vlsseg8e32_v_m)))
void vlsseg8e32(vint32mf2_t *, vint32mf2_t *, vint32mf2_t *, vint32mf2_t *, vint32mf2_t *, vint32mf2_t *, vint32mf2_t *, vint32mf2_t *, vbool64_t, vint32mf2_t, vint32mf2_t, vint32mf2_t, vint32mf2_t, vint32mf2_t, vint32mf2_t, vint32mf2_t, vint32mf2_t, const int32_t *, ptrdiff_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vlsseg8e32_v_m)))
void vlsseg8e32(vuint32m1_t *, vuint32m1_t *, vuint32m1_t *, vuint32m1_t *, vuint32m1_t *, vuint32m1_t *, vuint32m1_t *, vuint32m1_t *, vbool32_t, vuint32m1_t, vuint32m1_t, vuint32m1_t, vuint32m1_t, vuint32m1_t, vuint32m1_t, vuint32m1_t, vuint32m1_t, const uint32_t *, ptrdiff_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vlsseg8e32_v_m)))
void vlsseg8e32(vuint32mf2_t *, vuint32mf2_t *, vuint32mf2_t *, vuint32mf2_t *, vuint32mf2_t *, vuint32mf2_t *, vuint32mf2_t *, vuint32mf2_t *, vbool64_t, vuint32mf2_t, vuint32mf2_t, vuint32mf2_t, vuint32mf2_t, vuint32mf2_t, vuint32mf2_t, vuint32mf2_t, vuint32mf2_t, const uint32_t *, ptrdiff_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vluxseg2ei8_v)))
void vluxseg2ei8(vuint8m1_t *, vuint8m1_t *, const uint8_t *, vuint8m1_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vluxseg2ei8_v_m)))
void vluxseg2ei8(vuint8m1_t *, vuint8m1_t *, vbool8_t, vuint8m1_t, vuint8m1_t, const uint8_t *, vuint8m1_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vluxseg2ei8_v)))
void vluxseg2ei8(vuint8m2_t *, vuint8m2_t *, const uint8_t *, vuint8m2_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vluxseg2ei8_v_m)))
void vluxseg2ei8(vuint8m2_t *, vuint8m2_t *, vbool4_t, vuint8m2_t, vuint8m2_t, const uint8_t *, vuint8m2_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vluxseg2ei8_v)))
void vluxseg2ei8(vuint8m4_t *, vuint8m4_t *, const uint8_t *, vuint8m4_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vluxseg2ei8_v_m)))
void vluxseg2ei8(vuint8m4_t *, vuint8m4_t *, vbool2_t, vuint8m4_t, vuint8m4_t, const uint8_t *, vuint8m4_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vluxseg2ei8_v)))
void vluxseg2ei8(vuint8mf2_t *, vuint8mf2_t *, const uint8_t *, vuint8mf2_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vluxseg2ei8_v_m)))
void vluxseg2ei8(vuint8mf2_t *, vuint8mf2_t *, vbool16_t, vuint8mf2_t, vuint8mf2_t, const uint8_t *, vuint8mf2_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vluxseg2ei8_v)))
void vluxseg2ei8(vuint8mf4_t *, vuint8mf4_t *, const uint8_t *, vuint8mf4_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vluxseg2ei8_v_m)))
void vluxseg2ei8(vuint8mf4_t *, vuint8mf4_t *, vbool32_t, vuint8mf4_t, vuint8mf4_t, const uint8_t *, vuint8mf4_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vluxseg2ei8_v)))
void vluxseg2ei8(vuint8mf8_t *, vuint8mf8_t *, const uint8_t *, vuint8mf8_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vluxseg2ei8_v_m)))
void vluxseg2ei8(vuint8mf8_t *, vuint8mf8_t *, vbool64_t, vuint8mf8_t, vuint8mf8_t, const uint8_t *, vuint8mf8_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vle8ff_v_m)))
vint8m1_t vle8ff(vbool8_t, vint8m1_t, const int8_t *, size_t *, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vle8ff_v_m)))
vint8m2_t vle8ff(vbool4_t, vint8m2_t, const int8_t *, size_t *, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vle8ff_v_m)))
vint8m4_t vle8ff(vbool2_t, vint8m4_t, const int8_t *, size_t *, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vle8ff_v_m)))
vint8m8_t vle8ff(vbool1_t, vint8m8_t, const int8_t *, size_t *, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vle8ff_v_m)))
vint8mf2_t vle8ff(vbool16_t, vint8mf2_t, const int8_t *, size_t *, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vle8ff_v_m)))
vint8mf4_t vle8ff(vbool32_t, vint8mf4_t, const int8_t *, size_t *, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vle8ff_v_m)))
vint8mf8_t vle8ff(vbool64_t, vint8mf8_t, const int8_t *, size_t *, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vsseg2e8_v)))
void vsseg2e8(int8_t *, vint8m1_t, vint8m1_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vsseg2e8_v_m)))
void vsseg2e8(vbool8_t, int8_t *, vint8m1_t, vint8m1_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vsseg2e8_v)))
void vsseg2e8(int8_t *, vint8m2_t, vint8m2_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vsseg2e8_v_m)))
void vsseg2e8(vbool4_t, int8_t *, vint8m2_t, vint8m2_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vsseg2e8_v)))
void vsseg2e8(int8_t *, vint8m4_t, vint8m4_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vsseg2e8_v_m)))
void vsseg2e8(vbool2_t, int8_t *, vint8m4_t, vint8m4_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vsseg2e8_v)))
void vsseg2e8(int8_t *, vint8mf2_t, vint8mf2_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vsseg2e8_v_m)))
void vsseg2e8(vbool16_t, int8_t *, vint8mf2_t, vint8mf2_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vsseg2e8_v)))
void vsseg2e8(int8_t *, vint8mf4_t, vint8mf4_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vsseg2e8_v_m)))
void vsseg2e8(vbool32_t, int8_t *, vint8mf4_t, vint8mf4_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vsseg2e8_v)))
void vsseg2e8(int8_t *, vint8mf8_t, vint8mf8_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vsseg2e8_v_m)))
void vsseg2e8(vbool64_t, int8_t *, vint8mf8_t, vint8mf8_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vsseg2e8_v)))
void vsseg2e8(uint8_t *, vuint8m1_t, vuint8m1_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vsseg2e8_v_m)))
void vsseg2e8(vbool8_t, uint8_t *, vuint8m1_t, vuint8m1_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vsseg2e8_v)))
void vsseg2e8(uint8_t *, vuint8m2_t, vuint8m2_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vsseg2e8_v_m)))
void vsseg2e8(vbool4_t, uint8_t *, vuint8m2_t, vuint8m2_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vsseg2e8_v)))
void vsseg2e8(uint8_t *, vuint8m4_t, vuint8m4_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vsseg2e8_v_m)))
void vsseg2e8(vbool2_t, uint8_t *, vuint8m4_t, vuint8m4_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vsseg2e8_v)))
void vsseg2e8(uint8_t *, vuint8mf2_t, vuint8mf2_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vsseg2e8_v_m)))
void vsseg2e8(vbool16_t, uint8_t *, vuint8mf2_t, vuint8mf2_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vsseg2e8_v)))
void vsseg2e8(uint8_t *, vuint8mf4_t, vuint8mf4_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vsseg2e8_v_m)))
void vsseg2e8(vbool32_t, uint8_t *, vuint8mf4_t, vuint8mf4_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vsseg2e8_v)))
void vsseg2e8(uint8_t *, vuint8mf8_t, vuint8mf8_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vsseg2e8_v_m)))
void vsseg2e8(vbool64_t, uint8_t *, vuint8mf8_t, vuint8mf8_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vluxseg3ei8_v)))
void vluxseg3ei8(vint8m1_t *, vint8m1_t *, vint8m1_t *, const int8_t *, vuint8m1_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vluxseg3ei8_v_m)))
void vluxseg3ei8(vint8m1_t *, vint8m1_t *, vint8m1_t *, vbool8_t, vint8m1_t, vint8m1_t, vint8m1_t, const int8_t *, vuint8m1_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vluxseg3ei8_v)))
void vluxseg3ei8(vint8m2_t *, vint8m2_t *, vint8m2_t *, const int8_t *, vuint8m2_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vluxseg3ei8_v_m)))
void vluxseg3ei8(vint8m2_t *, vint8m2_t *, vint8m2_t *, vbool4_t, vint8m2_t, vint8m2_t, vint8m2_t, const int8_t *, vuint8m2_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vluxseg3ei8_v)))
void vluxseg3ei8(vint8mf2_t *, vint8mf2_t *, vint8mf2_t *, const int8_t *, vuint8mf2_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vluxseg3ei8_v_m)))
void vluxseg3ei8(vint8mf2_t *, vint8mf2_t *, vint8mf2_t *, vbool16_t, vint8mf2_t, vint8mf2_t, vint8mf2_t, const int8_t *, vuint8mf2_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vluxseg3ei8_v)))
void vluxseg3ei8(vint8mf4_t *, vint8mf4_t *, vint8mf4_t *, const int8_t *, vuint8mf4_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vluxseg3ei8_v_m)))
void vluxseg3ei8(vint8mf4_t *, vint8mf4_t *, vint8mf4_t *, vbool32_t, vint8mf4_t, vint8mf4_t, vint8mf4_t, const int8_t *, vuint8mf4_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vluxseg3ei8_v)))
void vluxseg3ei8(vint8mf8_t *, vint8mf8_t *, vint8mf8_t *, const int8_t *, vuint8mf8_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vluxseg3ei8_v_m)))
void vluxseg3ei8(vint8mf8_t *, vint8mf8_t *, vint8mf8_t *, vbool64_t, vint8mf8_t, vint8mf8_t, vint8mf8_t, const int8_t *, vuint8mf8_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vluxseg3ei8_v)))
void vluxseg3ei8(vuint8m1_t *, vuint8m1_t *, vuint8m1_t *, const uint8_t *, vuint8m1_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vluxseg3ei8_v_m)))
void vluxseg3ei8(vuint8m1_t *, vuint8m1_t *, vuint8m1_t *, vbool8_t, vuint8m1_t, vuint8m1_t, vuint8m1_t, const uint8_t *, vuint8m1_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vluxseg3ei8_v)))
void vluxseg3ei8(vuint8m2_t *, vuint8m2_t *, vuint8m2_t *, const uint8_t *, vuint8m2_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vluxseg3ei8_v_m)))
void vluxseg3ei8(vuint8m2_t *, vuint8m2_t *, vuint8m2_t *, vbool4_t, vuint8m2_t, vuint8m2_t, vuint8m2_t, const uint8_t *, vuint8m2_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vluxseg3ei8_v)))
void vluxseg3ei8(vuint8mf2_t *, vuint8mf2_t *, vuint8mf2_t *, const uint8_t *, vuint8mf2_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vluxseg3ei8_v_m)))
void vluxseg3ei8(vuint8mf2_t *, vuint8mf2_t *, vuint8mf2_t *, vbool16_t, vuint8mf2_t, vuint8mf2_t, vuint8mf2_t, const uint8_t *, vuint8mf2_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vluxseg3ei8_v)))
void vluxseg3ei8(vuint8mf4_t *, vuint8mf4_t *, vuint8mf4_t *, const uint8_t *, vuint8mf4_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vluxseg3ei8_v_m)))
void vluxseg3ei8(vuint8mf4_t *, vuint8mf4_t *, vuint8mf4_t *, vbool32_t, vuint8mf4_t, vuint8mf4_t, vuint8mf4_t, const uint8_t *, vuint8mf4_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vluxseg3ei8_v)))
void vluxseg3ei8(vuint8mf8_t *, vuint8mf8_t *, vuint8mf8_t *, const uint8_t *, vuint8mf8_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vluxseg3ei8_v_m)))
void vluxseg3ei8(vuint8mf8_t *, vuint8mf8_t *, vuint8mf8_t *, vbool64_t, vuint8mf8_t, vuint8mf8_t, vuint8mf8_t, const uint8_t *, vuint8mf8_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vluxseg4ei8_v)))
void vluxseg4ei8(vint8m1_t *, vint8m1_t *, vint8m1_t *, vint8m1_t *, const int8_t *, vuint8m1_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vluxseg4ei8_v_m)))
void vluxseg4ei8(vint8m1_t *, vint8m1_t *, vint8m1_t *, vint8m1_t *, vbool8_t, vint8m1_t, vint8m1_t, vint8m1_t, vint8m1_t, const int8_t *, vuint8m1_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vluxseg4ei8_v)))
void vluxseg4ei8(vint8m2_t *, vint8m2_t *, vint8m2_t *, vint8m2_t *, const int8_t *, vuint8m2_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vluxseg4ei8_v_m)))
void vluxseg4ei8(vint8m2_t *, vint8m2_t *, vint8m2_t *, vint8m2_t *, vbool4_t, vint8m2_t, vint8m2_t, vint8m2_t, vint8m2_t, const int8_t *, vuint8m2_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vluxseg4ei8_v)))
void vluxseg4ei8(vint8mf2_t *, vint8mf2_t *, vint8mf2_t *, vint8mf2_t *, const int8_t *, vuint8mf2_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vluxseg4ei8_v_m)))
void vluxseg4ei8(vint8mf2_t *, vint8mf2_t *, vint8mf2_t *, vint8mf2_t *, vbool16_t, vint8mf2_t, vint8mf2_t, vint8mf2_t, vint8mf2_t, const int8_t *, vuint8mf2_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vluxseg4ei8_v)))
void vluxseg4ei8(vint8mf4_t *, vint8mf4_t *, vint8mf4_t *, vint8mf4_t *, const int8_t *, vuint8mf4_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vluxseg4ei8_v_m)))
void vluxseg4ei8(vint8mf4_t *, vint8mf4_t *, vint8mf4_t *, vint8mf4_t *, vbool32_t, vint8mf4_t, vint8mf4_t, vint8mf4_t, vint8mf4_t, const int8_t *, vuint8mf4_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vluxseg4ei8_v)))
void vluxseg4ei8(vint8mf8_t *, vint8mf8_t *, vint8mf8_t *, vint8mf8_t *, const int8_t *, vuint8mf8_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vluxseg4ei8_v_m)))
void vluxseg4ei8(vint8mf8_t *, vint8mf8_t *, vint8mf8_t *, vint8mf8_t *, vbool64_t, vint8mf8_t, vint8mf8_t, vint8mf8_t, vint8mf8_t, const int8_t *, vuint8mf8_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vluxseg4ei8_v)))
void vluxseg4ei8(vuint8m1_t *, vuint8m1_t *, vuint8m1_t *, vuint8m1_t *, const uint8_t *, vuint8m1_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vluxseg4ei8_v_m)))
void vluxseg4ei8(vuint8m1_t *, vuint8m1_t *, vuint8m1_t *, vuint8m1_t *, vbool8_t, vuint8m1_t, vuint8m1_t, vuint8m1_t, vuint8m1_t, const uint8_t *, vuint8m1_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vluxseg4ei8_v)))
void vluxseg4ei8(vuint8m2_t *, vuint8m2_t *, vuint8m2_t *, vuint8m2_t *, const uint8_t *, vuint8m2_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vluxseg4ei8_v_m)))
void vluxseg4ei8(vuint8m2_t *, vuint8m2_t *, vuint8m2_t *, vuint8m2_t *, vbool4_t, vuint8m2_t, vuint8m2_t, vuint8m2_t, vuint8m2_t, const uint8_t *, vuint8m2_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vluxseg4ei8_v)))
void vluxseg4ei8(vuint8mf2_t *, vuint8mf2_t *, vuint8mf2_t *, vuint8mf2_t *, const uint8_t *, vuint8mf2_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vluxseg4ei8_v_m)))
void vluxseg4ei8(vuint8mf2_t *, vuint8mf2_t *, vuint8mf2_t *, vuint8mf2_t *, vbool16_t, vuint8mf2_t, vuint8mf2_t, vuint8mf2_t, vuint8mf2_t, const uint8_t *, vuint8mf2_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vluxseg4ei8_v)))
void vluxseg4ei8(vuint8mf4_t *, vuint8mf4_t *, vuint8mf4_t *, vuint8mf4_t *, const uint8_t *, vuint8mf4_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vluxseg4ei8_v_m)))
void vluxseg4ei8(vuint8mf4_t *, vuint8mf4_t *, vuint8mf4_t *, vuint8mf4_t *, vbool32_t, vuint8mf4_t, vuint8mf4_t, vuint8mf4_t, vuint8mf4_t, const uint8_t *, vuint8mf4_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vluxseg4ei8_v)))
void vluxseg4ei8(vuint8mf8_t *, vuint8mf8_t *, vuint8mf8_t *, vuint8mf8_t *, const uint8_t *, vuint8mf8_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vluxseg4ei8_v_m)))
void vluxseg4ei8(vuint8mf8_t *, vuint8mf8_t *, vuint8mf8_t *, vuint8mf8_t *, vbool64_t, vuint8mf8_t, vuint8mf8_t, vuint8mf8_t, vuint8mf8_t, const uint8_t *, vuint8mf8_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vluxseg5ei8_v)))
void vluxseg5ei8(vint8m1_t *, vint8m1_t *, vint8m1_t *, vint8m1_t *, vint8m1_t *, const int8_t *, vuint8m1_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vluxseg5ei8_v_m)))
void vluxseg5ei8(vint8m1_t *, vint8m1_t *, vint8m1_t *, vint8m1_t *, vint8m1_t *, vbool8_t, vint8m1_t, vint8m1_t, vint8m1_t, vint8m1_t, vint8m1_t, const int8_t *, vuint8m1_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vluxseg5ei8_v)))
void vluxseg5ei8(vint8mf2_t *, vint8mf2_t *, vint8mf2_t *, vint8mf2_t *, vint8mf2_t *, const int8_t *, vuint8mf2_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vluxseg5ei8_v_m)))
void vluxseg5ei8(vint8mf2_t *, vint8mf2_t *, vint8mf2_t *, vint8mf2_t *, vint8mf2_t *, vbool16_t, vint8mf2_t, vint8mf2_t, vint8mf2_t, vint8mf2_t, vint8mf2_t, const int8_t *, vuint8mf2_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vluxseg5ei8_v)))
void vluxseg5ei8(vint8mf4_t *, vint8mf4_t *, vint8mf4_t *, vint8mf4_t *, vint8mf4_t *, const int8_t *, vuint8mf4_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vluxseg5ei8_v_m)))
void vluxseg5ei8(vint8mf4_t *, vint8mf4_t *, vint8mf4_t *, vint8mf4_t *, vint8mf4_t *, vbool32_t, vint8mf4_t, vint8mf4_t, vint8mf4_t, vint8mf4_t, vint8mf4_t, const int8_t *, vuint8mf4_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vluxseg5ei8_v)))
void vluxseg5ei8(vint8mf8_t *, vint8mf8_t *, vint8mf8_t *, vint8mf8_t *, vint8mf8_t *, const int8_t *, vuint8mf8_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vluxseg5ei8_v_m)))
void vluxseg5ei8(vint8mf8_t *, vint8mf8_t *, vint8mf8_t *, vint8mf8_t *, vint8mf8_t *, vbool64_t, vint8mf8_t, vint8mf8_t, vint8mf8_t, vint8mf8_t, vint8mf8_t, const int8_t *, vuint8mf8_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vluxseg5ei8_v)))
void vluxseg5ei8(vuint8m1_t *, vuint8m1_t *, vuint8m1_t *, vuint8m1_t *, vuint8m1_t *, const uint8_t *, vuint8m1_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vluxseg5ei8_v_m)))
void vluxseg5ei8(vuint8m1_t *, vuint8m1_t *, vuint8m1_t *, vuint8m1_t *, vuint8m1_t *, vbool8_t, vuint8m1_t, vuint8m1_t, vuint8m1_t, vuint8m1_t, vuint8m1_t, const uint8_t *, vuint8m1_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vluxseg5ei8_v)))
void vluxseg5ei8(vuint8mf2_t *, vuint8mf2_t *, vuint8mf2_t *, vuint8mf2_t *, vuint8mf2_t *, const uint8_t *, vuint8mf2_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vluxseg5ei8_v_m)))
void vluxseg5ei8(vuint8mf2_t *, vuint8mf2_t *, vuint8mf2_t *, vuint8mf2_t *, vuint8mf2_t *, vbool16_t, vuint8mf2_t, vuint8mf2_t, vuint8mf2_t, vuint8mf2_t, vuint8mf2_t, const uint8_t *, vuint8mf2_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vluxseg5ei8_v)))
void vluxseg5ei8(vuint8mf4_t *, vuint8mf4_t *, vuint8mf4_t *, vuint8mf4_t *, vuint8mf4_t *, const uint8_t *, vuint8mf4_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vluxseg5ei8_v_m)))
void vluxseg5ei8(vuint8mf4_t *, vuint8mf4_t *, vuint8mf4_t *, vuint8mf4_t *, vuint8mf4_t *, vbool32_t, vuint8mf4_t, vuint8mf4_t, vuint8mf4_t, vuint8mf4_t, vuint8mf4_t, const uint8_t *, vuint8mf4_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vluxseg5ei8_v)))
void vluxseg5ei8(vuint8mf8_t *, vuint8mf8_t *, vuint8mf8_t *, vuint8mf8_t *, vuint8mf8_t *, const uint8_t *, vuint8mf8_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vluxseg5ei8_v_m)))
void vluxseg5ei8(vuint8mf8_t *, vuint8mf8_t *, vuint8mf8_t *, vuint8mf8_t *, vuint8mf8_t *, vbool64_t, vuint8mf8_t, vuint8mf8_t, vuint8mf8_t, vuint8mf8_t, vuint8mf8_t, const uint8_t *, vuint8mf8_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vluxseg6ei8_v)))
void vluxseg6ei8(vint8m1_t *, vint8m1_t *, vint8m1_t *, vint8m1_t *, vint8m1_t *, vint8m1_t *, const int8_t *, vuint8m1_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vluxseg6ei8_v_m)))
void vluxseg6ei8(vint8m1_t *, vint8m1_t *, vint8m1_t *, vint8m1_t *, vint8m1_t *, vint8m1_t *, vbool8_t, vint8m1_t, vint8m1_t, vint8m1_t, vint8m1_t, vint8m1_t, vint8m1_t, const int8_t *, vuint8m1_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vluxseg6ei8_v)))
void vluxseg6ei8(vint8mf2_t *, vint8mf2_t *, vint8mf2_t *, vint8mf2_t *, vint8mf2_t *, vint8mf2_t *, const int8_t *, vuint8mf2_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vluxseg6ei8_v_m)))
void vluxseg6ei8(vint8mf2_t *, vint8mf2_t *, vint8mf2_t *, vint8mf2_t *, vint8mf2_t *, vint8mf2_t *, vbool16_t, vint8mf2_t, vint8mf2_t, vint8mf2_t, vint8mf2_t, vint8mf2_t, vint8mf2_t, const int8_t *, vuint8mf2_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vluxseg6ei8_v)))
void vluxseg6ei8(vint8mf4_t *, vint8mf4_t *, vint8mf4_t *, vint8mf4_t *, vint8mf4_t *, vint8mf4_t *, const int8_t *, vuint8mf4_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vluxseg6ei8_v_m)))
void vluxseg6ei8(vint8mf4_t *, vint8mf4_t *, vint8mf4_t *, vint8mf4_t *, vint8mf4_t *, vint8mf4_t *, vbool32_t, vint8mf4_t, vint8mf4_t, vint8mf4_t, vint8mf4_t, vint8mf4_t, vint8mf4_t, const int8_t *, vuint8mf4_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vluxseg6ei8_v)))
void vluxseg6ei8(vint8mf8_t *, vint8mf8_t *, vint8mf8_t *, vint8mf8_t *, vint8mf8_t *, vint8mf8_t *, const int8_t *, vuint8mf8_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vluxseg6ei8_v_m)))
void vluxseg6ei8(vint8mf8_t *, vint8mf8_t *, vint8mf8_t *, vint8mf8_t *, vint8mf8_t *, vint8mf8_t *, vbool64_t, vint8mf8_t, vint8mf8_t, vint8mf8_t, vint8mf8_t, vint8mf8_t, vint8mf8_t, const int8_t *, vuint8mf8_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vluxseg6ei8_v)))
void vluxseg6ei8(vuint8m1_t *, vuint8m1_t *, vuint8m1_t *, vuint8m1_t *, vuint8m1_t *, vuint8m1_t *, const uint8_t *, vuint8m1_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vluxseg6ei8_v_m)))
void vluxseg6ei8(vuint8m1_t *, vuint8m1_t *, vuint8m1_t *, vuint8m1_t *, vuint8m1_t *, vuint8m1_t *, vbool8_t, vuint8m1_t, vuint8m1_t, vuint8m1_t, vuint8m1_t, vuint8m1_t, vuint8m1_t, const uint8_t *, vuint8m1_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vluxseg6ei8_v)))
void vluxseg6ei8(vuint8mf2_t *, vuint8mf2_t *, vuint8mf2_t *, vuint8mf2_t *, vuint8mf2_t *, vuint8mf2_t *, const uint8_t *, vuint8mf2_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vluxseg6ei8_v_m)))
void vluxseg6ei8(vuint8mf2_t *, vuint8mf2_t *, vuint8mf2_t *, vuint8mf2_t *, vuint8mf2_t *, vuint8mf2_t *, vbool16_t, vuint8mf2_t, vuint8mf2_t, vuint8mf2_t, vuint8mf2_t, vuint8mf2_t, vuint8mf2_t, const uint8_t *, vuint8mf2_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vluxseg6ei8_v)))
void vluxseg6ei8(vuint8mf4_t *, vuint8mf4_t *, vuint8mf4_t *, vuint8mf4_t *, vuint8mf4_t *, vuint8mf4_t *, const uint8_t *, vuint8mf4_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vluxseg6ei8_v_m)))
void vluxseg6ei8(vuint8mf4_t *, vuint8mf4_t *, vuint8mf4_t *, vuint8mf4_t *, vuint8mf4_t *, vuint8mf4_t *, vbool32_t, vuint8mf4_t, vuint8mf4_t, vuint8mf4_t, vuint8mf4_t, vuint8mf4_t, vuint8mf4_t, const uint8_t *, vuint8mf4_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vluxseg6ei8_v)))
void vluxseg6ei8(vuint8mf8_t *, vuint8mf8_t *, vuint8mf8_t *, vuint8mf8_t *, vuint8mf8_t *, vuint8mf8_t *, const uint8_t *, vuint8mf8_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vluxseg6ei8_v_m)))
void vluxseg6ei8(vuint8mf8_t *, vuint8mf8_t *, vuint8mf8_t *, vuint8mf8_t *, vuint8mf8_t *, vuint8mf8_t *, vbool64_t, vuint8mf8_t, vuint8mf8_t, vuint8mf8_t, vuint8mf8_t, vuint8mf8_t, vuint8mf8_t, const uint8_t *, vuint8mf8_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vluxseg7ei8_v)))
void vluxseg7ei8(vint8m1_t *, vint8m1_t *, vint8m1_t *, vint8m1_t *, vint8m1_t *, vint8m1_t *, vint8m1_t *, const int8_t *, vuint8m1_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vluxseg7ei8_v_m)))
void vluxseg7ei8(vint8m1_t *, vint8m1_t *, vint8m1_t *, vint8m1_t *, vint8m1_t *, vint8m1_t *, vint8m1_t *, vbool8_t, vint8m1_t, vint8m1_t, vint8m1_t, vint8m1_t, vint8m1_t, vint8m1_t, vint8m1_t, const int8_t *, vuint8m1_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vluxseg7ei8_v)))
void vluxseg7ei8(vint8mf2_t *, vint8mf2_t *, vint8mf2_t *, vint8mf2_t *, vint8mf2_t *, vint8mf2_t *, vint8mf2_t *, const int8_t *, vuint8mf2_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vluxseg7ei8_v_m)))
void vluxseg7ei8(vint8mf2_t *, vint8mf2_t *, vint8mf2_t *, vint8mf2_t *, vint8mf2_t *, vint8mf2_t *, vint8mf2_t *, vbool16_t, vint8mf2_t, vint8mf2_t, vint8mf2_t, vint8mf2_t, vint8mf2_t, vint8mf2_t, vint8mf2_t, const int8_t *, vuint8mf2_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vluxseg7ei8_v)))
void vluxseg7ei8(vint8mf4_t *, vint8mf4_t *, vint8mf4_t *, vint8mf4_t *, vint8mf4_t *, vint8mf4_t *, vint8mf4_t *, const int8_t *, vuint8mf4_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vluxseg7ei8_v_m)))
void vluxseg7ei8(vint8mf4_t *, vint8mf4_t *, vint8mf4_t *, vint8mf4_t *, vint8mf4_t *, vint8mf4_t *, vint8mf4_t *, vbool32_t, vint8mf4_t, vint8mf4_t, vint8mf4_t, vint8mf4_t, vint8mf4_t, vint8mf4_t, vint8mf4_t, const int8_t *, vuint8mf4_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vluxseg7ei8_v)))
void vluxseg7ei8(vint8mf8_t *, vint8mf8_t *, vint8mf8_t *, vint8mf8_t *, vint8mf8_t *, vint8mf8_t *, vint8mf8_t *, const int8_t *, vuint8mf8_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vluxseg7ei8_v_m)))
void vluxseg7ei8(vint8mf8_t *, vint8mf8_t *, vint8mf8_t *, vint8mf8_t *, vint8mf8_t *, vint8mf8_t *, vint8mf8_t *, vbool64_t, vint8mf8_t, vint8mf8_t, vint8mf8_t, vint8mf8_t, vint8mf8_t, vint8mf8_t, vint8mf8_t, const int8_t *, vuint8mf8_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vluxseg7ei8_v)))
void vluxseg7ei8(vuint8m1_t *, vuint8m1_t *, vuint8m1_t *, vuint8m1_t *, vuint8m1_t *, vuint8m1_t *, vuint8m1_t *, const uint8_t *, vuint8m1_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vluxseg7ei8_v_m)))
void vluxseg7ei8(vuint8m1_t *, vuint8m1_t *, vuint8m1_t *, vuint8m1_t *, vuint8m1_t *, vuint8m1_t *, vuint8m1_t *, vbool8_t, vuint8m1_t, vuint8m1_t, vuint8m1_t, vuint8m1_t, vuint8m1_t, vuint8m1_t, vuint8m1_t, const uint8_t *, vuint8m1_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vluxseg7ei8_v)))
void vluxseg7ei8(vuint8mf2_t *, vuint8mf2_t *, vuint8mf2_t *, vuint8mf2_t *, vuint8mf2_t *, vuint8mf2_t *, vuint8mf2_t *, const uint8_t *, vuint8mf2_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vluxseg7ei8_v_m)))
void vluxseg7ei8(vuint8mf2_t *, vuint8mf2_t *, vuint8mf2_t *, vuint8mf2_t *, vuint8mf2_t *, vuint8mf2_t *, vuint8mf2_t *, vbool16_t, vuint8mf2_t, vuint8mf2_t, vuint8mf2_t, vuint8mf2_t, vuint8mf2_t, vuint8mf2_t, vuint8mf2_t, const uint8_t *, vuint8mf2_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vluxseg7ei8_v)))
void vluxseg7ei8(vuint8mf4_t *, vuint8mf4_t *, vuint8mf4_t *, vuint8mf4_t *, vuint8mf4_t *, vuint8mf4_t *, vuint8mf4_t *, const uint8_t *, vuint8mf4_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vluxseg7ei8_v_m)))
void vluxseg7ei8(vuint8mf4_t *, vuint8mf4_t *, vuint8mf4_t *, vuint8mf4_t *, vuint8mf4_t *, vuint8mf4_t *, vuint8mf4_t *, vbool32_t, vuint8mf4_t, vuint8mf4_t, vuint8mf4_t, vuint8mf4_t, vuint8mf4_t, vuint8mf4_t, vuint8mf4_t, const uint8_t *, vuint8mf4_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vluxseg7ei8_v)))
void vluxseg7ei8(vuint8mf8_t *, vuint8mf8_t *, vuint8mf8_t *, vuint8mf8_t *, vuint8mf8_t *, vuint8mf8_t *, vuint8mf8_t *, const uint8_t *, vuint8mf8_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vluxseg7ei8_v_m)))
void vluxseg7ei8(vuint8mf8_t *, vuint8mf8_t *, vuint8mf8_t *, vuint8mf8_t *, vuint8mf8_t *, vuint8mf8_t *, vuint8mf8_t *, vbool64_t, vuint8mf8_t, vuint8mf8_t, vuint8mf8_t, vuint8mf8_t, vuint8mf8_t, vuint8mf8_t, vuint8mf8_t, const uint8_t *, vuint8mf8_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vluxseg8ei8_v)))
void vluxseg8ei8(vint8m1_t *, vint8m1_t *, vint8m1_t *, vint8m1_t *, vint8m1_t *, vint8m1_t *, vint8m1_t *, vint8m1_t *, const int8_t *, vuint8m1_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vluxseg8ei8_v_m)))
void vluxseg8ei8(vint8m1_t *, vint8m1_t *, vint8m1_t *, vint8m1_t *, vint8m1_t *, vint8m1_t *, vint8m1_t *, vint8m1_t *, vbool8_t, vint8m1_t, vint8m1_t, vint8m1_t, vint8m1_t, vint8m1_t, vint8m1_t, vint8m1_t, vint8m1_t, const int8_t *, vuint8m1_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vluxseg8ei8_v)))
void vluxseg8ei8(vint8mf2_t *, vint8mf2_t *, vint8mf2_t *, vint8mf2_t *, vint8mf2_t *, vint8mf2_t *, vint8mf2_t *, vint8mf2_t *, const int8_t *, vuint8mf2_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vluxseg8ei8_v_m)))
void vluxseg8ei8(vint8mf2_t *, vint8mf2_t *, vint8mf2_t *, vint8mf2_t *, vint8mf2_t *, vint8mf2_t *, vint8mf2_t *, vint8mf2_t *, vbool16_t, vint8mf2_t, vint8mf2_t, vint8mf2_t, vint8mf2_t, vint8mf2_t, vint8mf2_t, vint8mf2_t, vint8mf2_t, const int8_t *, vuint8mf2_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vluxseg8ei8_v)))
void vluxseg8ei8(vint8mf4_t *, vint8mf4_t *, vint8mf4_t *, vint8mf4_t *, vint8mf4_t *, vint8mf4_t *, vint8mf4_t *, vint8mf4_t *, const int8_t *, vuint8mf4_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vluxseg8ei8_v_m)))
void vluxseg8ei8(vint8mf4_t *, vint8mf4_t *, vint8mf4_t *, vint8mf4_t *, vint8mf4_t *, vint8mf4_t *, vint8mf4_t *, vint8mf4_t *, vbool32_t, vint8mf4_t, vint8mf4_t, vint8mf4_t, vint8mf4_t, vint8mf4_t, vint8mf4_t, vint8mf4_t, vint8mf4_t, const int8_t *, vuint8mf4_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vluxseg8ei8_v)))
void vluxseg8ei8(vint8mf8_t *, vint8mf8_t *, vint8mf8_t *, vint8mf8_t *, vint8mf8_t *, vint8mf8_t *, vint8mf8_t *, vint8mf8_t *, const int8_t *, vuint8mf8_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vluxseg8ei8_v_m)))
void vluxseg8ei8(vint8mf8_t *, vint8mf8_t *, vint8mf8_t *, vint8mf8_t *, vint8mf8_t *, vint8mf8_t *, vint8mf8_t *, vint8mf8_t *, vbool64_t, vint8mf8_t, vint8mf8_t, vint8mf8_t, vint8mf8_t, vint8mf8_t, vint8mf8_t, vint8mf8_t, vint8mf8_t, const int8_t *, vuint8mf8_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vluxseg8ei8_v)))
void vluxseg8ei8(vuint8m1_t *, vuint8m1_t *, vuint8m1_t *, vuint8m1_t *, vuint8m1_t *, vuint8m1_t *, vuint8m1_t *, vuint8m1_t *, const uint8_t *, vuint8m1_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vluxseg8ei8_v_m)))
void vluxseg8ei8(vuint8m1_t *, vuint8m1_t *, vuint8m1_t *, vuint8m1_t *, vuint8m1_t *, vuint8m1_t *, vuint8m1_t *, vuint8m1_t *, vbool8_t, vuint8m1_t, vuint8m1_t, vuint8m1_t, vuint8m1_t, vuint8m1_t, vuint8m1_t, vuint8m1_t, vuint8m1_t, const uint8_t *, vuint8m1_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vluxseg8ei8_v)))
void vluxseg8ei8(vuint8mf2_t *, vuint8mf2_t *, vuint8mf2_t *, vuint8mf2_t *, vuint8mf2_t *, vuint8mf2_t *, vuint8mf2_t *, vuint8mf2_t *, const uint8_t *, vuint8mf2_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vluxseg8ei8_v_m)))
void vluxseg8ei8(vuint8mf2_t *, vuint8mf2_t *, vuint8mf2_t *, vuint8mf2_t *, vuint8mf2_t *, vuint8mf2_t *, vuint8mf2_t *, vuint8mf2_t *, vbool16_t, vuint8mf2_t, vuint8mf2_t, vuint8mf2_t, vuint8mf2_t, vuint8mf2_t, vuint8mf2_t, vuint8mf2_t, vuint8mf2_t, const uint8_t *, vuint8mf2_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vluxseg8ei8_v)))
void vluxseg8ei8(vuint8mf4_t *, vuint8mf4_t *, vuint8mf4_t *, vuint8mf4_t *, vuint8mf4_t *, vuint8mf4_t *, vuint8mf4_t *, vuint8mf4_t *, const uint8_t *, vuint8mf4_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vluxseg8ei8_v_m)))
void vluxseg8ei8(vuint8mf4_t *, vuint8mf4_t *, vuint8mf4_t *, vuint8mf4_t *, vuint8mf4_t *, vuint8mf4_t *, vuint8mf4_t *, vuint8mf4_t *, vbool32_t, vuint8mf4_t, vuint8mf4_t, vuint8mf4_t, vuint8mf4_t, vuint8mf4_t, vuint8mf4_t, vuint8mf4_t, vuint8mf4_t, const uint8_t *, vuint8mf4_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vluxseg8ei8_v)))
void vluxseg8ei8(vuint8mf8_t *, vuint8mf8_t *, vuint8mf8_t *, vuint8mf8_t *, vuint8mf8_t *, vuint8mf8_t *, vuint8mf8_t *, vuint8mf8_t *, const uint8_t *, vuint8mf8_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vluxseg8ei8_v_m)))
void vluxseg8ei8(vuint8mf8_t *, vuint8mf8_t *, vuint8mf8_t *, vuint8mf8_t *, vuint8mf8_t *, vuint8mf8_t *, vuint8mf8_t *, vuint8mf8_t *, vbool64_t, vuint8mf8_t, vuint8mf8_t, vuint8mf8_t, vuint8mf8_t, vuint8mf8_t, vuint8mf8_t, vuint8mf8_t, vuint8mf8_t, const uint8_t *, vuint8mf8_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vluxseg2ei16_v)))
void vluxseg2ei16(vint8m1_t *, vint8m1_t *, const int8_t *, vuint16m2_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vluxseg2ei16_v_m)))
void vluxseg2ei16(vint8m1_t *, vint8m1_t *, vbool8_t, vint8m1_t, vint8m1_t, const int8_t *, vuint16m2_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vluxseg2ei16_v)))
void vluxseg2ei16(vint8m2_t *, vint8m2_t *, const int8_t *, vuint16m4_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vluxseg2ei16_v_m)))
void vluxseg2ei16(vint8m2_t *, vint8m2_t *, vbool4_t, vint8m2_t, vint8m2_t, const int8_t *, vuint16m4_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vluxseg2ei16_v)))
void vluxseg2ei16(vint8m4_t *, vint8m4_t *, const int8_t *, vuint16m8_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vluxseg2ei16_v_m)))
void vluxseg2ei16(vint8m4_t *, vint8m4_t *, vbool2_t, vint8m4_t, vint8m4_t, const int8_t *, vuint16m8_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vluxseg2ei16_v)))
void vluxseg2ei16(vint8mf2_t *, vint8mf2_t *, const int8_t *, vuint16m1_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vluxseg2ei16_v_m)))
void vluxseg2ei16(vint8mf2_t *, vint8mf2_t *, vbool16_t, vint8mf2_t, vint8mf2_t, const int8_t *, vuint16m1_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vluxseg2ei16_v)))
void vluxseg2ei16(vint8mf4_t *, vint8mf4_t *, const int8_t *, vuint16mf2_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vluxseg2ei16_v_m)))
void vluxseg2ei16(vint8mf4_t *, vint8mf4_t *, vbool32_t, vint8mf4_t, vint8mf4_t, const int8_t *, vuint16mf2_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vluxseg2ei16_v)))
void vluxseg2ei16(vint8mf8_t *, vint8mf8_t *, const int8_t *, vuint16mf4_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vluxseg2ei16_v_m)))
void vluxseg2ei16(vint8mf8_t *, vint8mf8_t *, vbool64_t, vint8mf8_t, vint8mf8_t, const int8_t *, vuint16mf4_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vluxseg2ei16_v)))
void vluxseg2ei16(vuint8m1_t *, vuint8m1_t *, const uint8_t *, vuint16m2_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vluxseg2ei16_v_m)))
void vluxseg2ei16(vuint8m1_t *, vuint8m1_t *, vbool8_t, vuint8m1_t, vuint8m1_t, const uint8_t *, vuint16m2_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vluxseg2ei16_v)))
void vluxseg2ei16(vuint8m2_t *, vuint8m2_t *, const uint8_t *, vuint16m4_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vluxseg2ei16_v_m)))
void vluxseg2ei16(vuint8m2_t *, vuint8m2_t *, vbool4_t, vuint8m2_t, vuint8m2_t, const uint8_t *, vuint16m4_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vluxseg2ei16_v)))
void vluxseg2ei16(vuint8m4_t *, vuint8m4_t *, const uint8_t *, vuint16m8_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vluxseg2ei16_v_m)))
void vluxseg2ei16(vuint8m4_t *, vuint8m4_t *, vbool2_t, vuint8m4_t, vuint8m4_t, const uint8_t *, vuint16m8_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vluxseg2ei16_v)))
void vluxseg2ei16(vuint8mf2_t *, vuint8mf2_t *, const uint8_t *, vuint16m1_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vluxseg2ei16_v_m)))
void vluxseg2ei16(vuint8mf2_t *, vuint8mf2_t *, vbool16_t, vuint8mf2_t, vuint8mf2_t, const uint8_t *, vuint16m1_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vluxseg2ei16_v)))
void vluxseg2ei16(vuint8mf4_t *, vuint8mf4_t *, const uint8_t *, vuint16mf2_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vluxseg2ei16_v_m)))
void vluxseg2ei16(vuint8mf4_t *, vuint8mf4_t *, vbool32_t, vuint8mf4_t, vuint8mf4_t, const uint8_t *, vuint16mf2_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vluxseg2ei16_v)))
void vluxseg2ei16(vuint8mf8_t *, vuint8mf8_t *, const uint8_t *, vuint16mf4_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vluxseg2ei16_v_m)))
void vluxseg2ei16(vuint8mf8_t *, vuint8mf8_t *, vbool64_t, vuint8mf8_t, vuint8mf8_t, const uint8_t *, vuint16mf4_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vluxseg3ei16_v)))
void vluxseg3ei16(vint8m1_t *, vint8m1_t *, vint8m1_t *, const int8_t *, vuint16m2_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vluxseg3ei16_v_m)))
void vluxseg3ei16(vint8m1_t *, vint8m1_t *, vint8m1_t *, vbool8_t, vint8m1_t, vint8m1_t, vint8m1_t, const int8_t *, vuint16m2_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vluxseg3ei16_v)))
void vluxseg3ei16(vint8m2_t *, vint8m2_t *, vint8m2_t *, const int8_t *, vuint16m4_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vluxseg3ei16_v_m)))
void vluxseg3ei16(vint8m2_t *, vint8m2_t *, vint8m2_t *, vbool4_t, vint8m2_t, vint8m2_t, vint8m2_t, const int8_t *, vuint16m4_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vluxseg3ei16_v)))
void vluxseg3ei16(vint8mf2_t *, vint8mf2_t *, vint8mf2_t *, const int8_t *, vuint16m1_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vluxseg3ei16_v_m)))
void vluxseg3ei16(vint8mf2_t *, vint8mf2_t *, vint8mf2_t *, vbool16_t, vint8mf2_t, vint8mf2_t, vint8mf2_t, const int8_t *, vuint16m1_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vluxseg3ei16_v)))
void vluxseg3ei16(vint8mf4_t *, vint8mf4_t *, vint8mf4_t *, const int8_t *, vuint16mf2_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vluxseg3ei16_v_m)))
void vluxseg3ei16(vint8mf4_t *, vint8mf4_t *, vint8mf4_t *, vbool32_t, vint8mf4_t, vint8mf4_t, vint8mf4_t, const int8_t *, vuint16mf2_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vluxseg3ei16_v)))
void vluxseg3ei16(vint8mf8_t *, vint8mf8_t *, vint8mf8_t *, const int8_t *, vuint16mf4_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vluxseg3ei16_v_m)))
void vluxseg3ei16(vint8mf8_t *, vint8mf8_t *, vint8mf8_t *, vbool64_t, vint8mf8_t, vint8mf8_t, vint8mf8_t, const int8_t *, vuint16mf4_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vluxseg3ei16_v)))
void vluxseg3ei16(vuint8m1_t *, vuint8m1_t *, vuint8m1_t *, const uint8_t *, vuint16m2_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vluxseg3ei16_v_m)))
void vluxseg3ei16(vuint8m1_t *, vuint8m1_t *, vuint8m1_t *, vbool8_t, vuint8m1_t, vuint8m1_t, vuint8m1_t, const uint8_t *, vuint16m2_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vluxseg3ei16_v)))
void vluxseg3ei16(vuint8m2_t *, vuint8m2_t *, vuint8m2_t *, const uint8_t *, vuint16m4_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vluxseg3ei16_v_m)))
void vluxseg3ei16(vuint8m2_t *, vuint8m2_t *, vuint8m2_t *, vbool4_t, vuint8m2_t, vuint8m2_t, vuint8m2_t, const uint8_t *, vuint16m4_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vluxseg3ei16_v)))
void vluxseg3ei16(vuint8mf2_t *, vuint8mf2_t *, vuint8mf2_t *, const uint8_t *, vuint16m1_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vluxseg3ei16_v_m)))
void vluxseg3ei16(vuint8mf2_t *, vuint8mf2_t *, vuint8mf2_t *, vbool16_t, vuint8mf2_t, vuint8mf2_t, vuint8mf2_t, const uint8_t *, vuint16m1_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vluxseg3ei16_v)))
void vluxseg3ei16(vuint8mf4_t *, vuint8mf4_t *, vuint8mf4_t *, const uint8_t *, vuint16mf2_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vluxseg3ei16_v_m)))
void vluxseg3ei16(vuint8mf4_t *, vuint8mf4_t *, vuint8mf4_t *, vbool32_t, vuint8mf4_t, vuint8mf4_t, vuint8mf4_t, const uint8_t *, vuint16mf2_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vluxseg3ei16_v)))
void vluxseg3ei16(vuint8mf8_t *, vuint8mf8_t *, vuint8mf8_t *, const uint8_t *, vuint16mf4_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vluxseg3ei16_v_m)))
void vluxseg3ei16(vuint8mf8_t *, vuint8mf8_t *, vuint8mf8_t *, vbool64_t, vuint8mf8_t, vuint8mf8_t, vuint8mf8_t, const uint8_t *, vuint16mf4_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vluxseg4ei16_v)))
void vluxseg4ei16(vint8m1_t *, vint8m1_t *, vint8m1_t *, vint8m1_t *, const int8_t *, vuint16m2_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vluxseg4ei16_v_m)))
void vluxseg4ei16(vint8m1_t *, vint8m1_t *, vint8m1_t *, vint8m1_t *, vbool8_t, vint8m1_t, vint8m1_t, vint8m1_t, vint8m1_t, const int8_t *, vuint16m2_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vluxseg4ei16_v)))
void vluxseg4ei16(vint8m2_t *, vint8m2_t *, vint8m2_t *, vint8m2_t *, const int8_t *, vuint16m4_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vluxseg4ei16_v_m)))
void vluxseg4ei16(vint8m2_t *, vint8m2_t *, vint8m2_t *, vint8m2_t *, vbool4_t, vint8m2_t, vint8m2_t, vint8m2_t, vint8m2_t, const int8_t *, vuint16m4_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vluxseg4ei16_v)))
void vluxseg4ei16(vint8mf2_t *, vint8mf2_t *, vint8mf2_t *, vint8mf2_t *, const int8_t *, vuint16m1_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vluxseg4ei16_v_m)))
void vluxseg4ei16(vint8mf2_t *, vint8mf2_t *, vint8mf2_t *, vint8mf2_t *, vbool16_t, vint8mf2_t, vint8mf2_t, vint8mf2_t, vint8mf2_t, const int8_t *, vuint16m1_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vluxseg4ei16_v)))
void vluxseg4ei16(vint8mf4_t *, vint8mf4_t *, vint8mf4_t *, vint8mf4_t *, const int8_t *, vuint16mf2_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vluxseg4ei16_v_m)))
void vluxseg4ei16(vint8mf4_t *, vint8mf4_t *, vint8mf4_t *, vint8mf4_t *, vbool32_t, vint8mf4_t, vint8mf4_t, vint8mf4_t, vint8mf4_t, const int8_t *, vuint16mf2_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vluxseg4ei16_v)))
void vluxseg4ei16(vint8mf8_t *, vint8mf8_t *, vint8mf8_t *, vint8mf8_t *, const int8_t *, vuint16mf4_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vluxseg4ei16_v_m)))
void vluxseg4ei16(vint8mf8_t *, vint8mf8_t *, vint8mf8_t *, vint8mf8_t *, vbool64_t, vint8mf8_t, vint8mf8_t, vint8mf8_t, vint8mf8_t, const int8_t *, vuint16mf4_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vluxseg4ei16_v)))
void vluxseg4ei16(vuint8m1_t *, vuint8m1_t *, vuint8m1_t *, vuint8m1_t *, const uint8_t *, vuint16m2_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vluxseg4ei16_v_m)))
void vluxseg4ei16(vuint8m1_t *, vuint8m1_t *, vuint8m1_t *, vuint8m1_t *, vbool8_t, vuint8m1_t, vuint8m1_t, vuint8m1_t, vuint8m1_t, const uint8_t *, vuint16m2_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vluxseg4ei16_v)))
void vluxseg4ei16(vuint8m2_t *, vuint8m2_t *, vuint8m2_t *, vuint8m2_t *, const uint8_t *, vuint16m4_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vluxseg4ei16_v_m)))
void vluxseg4ei16(vuint8m2_t *, vuint8m2_t *, vuint8m2_t *, vuint8m2_t *, vbool4_t, vuint8m2_t, vuint8m2_t, vuint8m2_t, vuint8m2_t, const uint8_t *, vuint16m4_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vluxseg4ei16_v)))
void vluxseg4ei16(vuint8mf2_t *, vuint8mf2_t *, vuint8mf2_t *, vuint8mf2_t *, const uint8_t *, vuint16m1_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vluxseg4ei16_v_m)))
void vluxseg4ei16(vuint8mf2_t *, vuint8mf2_t *, vuint8mf2_t *, vuint8mf2_t *, vbool16_t, vuint8mf2_t, vuint8mf2_t, vuint8mf2_t, vuint8mf2_t, const uint8_t *, vuint16m1_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vluxseg4ei16_v)))
void vluxseg4ei16(vuint8mf4_t *, vuint8mf4_t *, vuint8mf4_t *, vuint8mf4_t *, const uint8_t *, vuint16mf2_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vluxseg4ei16_v_m)))
void vluxseg4ei16(vuint8mf4_t *, vuint8mf4_t *, vuint8mf4_t *, vuint8mf4_t *, vbool32_t, vuint8mf4_t, vuint8mf4_t, vuint8mf4_t, vuint8mf4_t, const uint8_t *, vuint16mf2_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vluxseg4ei16_v)))
void vluxseg4ei16(vuint8mf8_t *, vuint8mf8_t *, vuint8mf8_t *, vuint8mf8_t *, const uint8_t *, vuint16mf4_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vluxseg4ei16_v_m)))
void vluxseg4ei16(vuint8mf8_t *, vuint8mf8_t *, vuint8mf8_t *, vuint8mf8_t *, vbool64_t, vuint8mf8_t, vuint8mf8_t, vuint8mf8_t, vuint8mf8_t, const uint8_t *, vuint16mf4_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vluxseg5ei16_v)))
void vluxseg5ei16(vint8m1_t *, vint8m1_t *, vint8m1_t *, vint8m1_t *, vint8m1_t *, const int8_t *, vuint16m2_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vluxseg5ei16_v_m)))
void vluxseg5ei16(vint8m1_t *, vint8m1_t *, vint8m1_t *, vint8m1_t *, vint8m1_t *, vbool8_t, vint8m1_t, vint8m1_t, vint8m1_t, vint8m1_t, vint8m1_t, const int8_t *, vuint16m2_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vluxseg5ei16_v)))
void vluxseg5ei16(vint8mf2_t *, vint8mf2_t *, vint8mf2_t *, vint8mf2_t *, vint8mf2_t *, const int8_t *, vuint16m1_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vluxseg5ei16_v_m)))
void vluxseg5ei16(vint8mf2_t *, vint8mf2_t *, vint8mf2_t *, vint8mf2_t *, vint8mf2_t *, vbool16_t, vint8mf2_t, vint8mf2_t, vint8mf2_t, vint8mf2_t, vint8mf2_t, const int8_t *, vuint16m1_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vluxseg5ei16_v)))
void vluxseg5ei16(vint8mf4_t *, vint8mf4_t *, vint8mf4_t *, vint8mf4_t *, vint8mf4_t *, const int8_t *, vuint16mf2_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vluxseg5ei16_v_m)))
void vluxseg5ei16(vint8mf4_t *, vint8mf4_t *, vint8mf4_t *, vint8mf4_t *, vint8mf4_t *, vbool32_t, vint8mf4_t, vint8mf4_t, vint8mf4_t, vint8mf4_t, vint8mf4_t, const int8_t *, vuint16mf2_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vluxseg5ei16_v)))
void vluxseg5ei16(vint8mf8_t *, vint8mf8_t *, vint8mf8_t *, vint8mf8_t *, vint8mf8_t *, const int8_t *, vuint16mf4_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vluxseg5ei16_v_m)))
void vluxseg5ei16(vint8mf8_t *, vint8mf8_t *, vint8mf8_t *, vint8mf8_t *, vint8mf8_t *, vbool64_t, vint8mf8_t, vint8mf8_t, vint8mf8_t, vint8mf8_t, vint8mf8_t, const int8_t *, vuint16mf4_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vluxseg5ei16_v)))
void vluxseg5ei16(vuint8m1_t *, vuint8m1_t *, vuint8m1_t *, vuint8m1_t *, vuint8m1_t *, const uint8_t *, vuint16m2_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vluxseg5ei16_v_m)))
void vluxseg5ei16(vuint8m1_t *, vuint8m1_t *, vuint8m1_t *, vuint8m1_t *, vuint8m1_t *, vbool8_t, vuint8m1_t, vuint8m1_t, vuint8m1_t, vuint8m1_t, vuint8m1_t, const uint8_t *, vuint16m2_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vluxseg5ei16_v)))
void vluxseg5ei16(vuint8mf2_t *, vuint8mf2_t *, vuint8mf2_t *, vuint8mf2_t *, vuint8mf2_t *, const uint8_t *, vuint16m1_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vluxseg5ei16_v_m)))
void vluxseg5ei16(vuint8mf2_t *, vuint8mf2_t *, vuint8mf2_t *, vuint8mf2_t *, vuint8mf2_t *, vbool16_t, vuint8mf2_t, vuint8mf2_t, vuint8mf2_t, vuint8mf2_t, vuint8mf2_t, const uint8_t *, vuint16m1_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vluxseg5ei16_v)))
void vluxseg5ei16(vuint8mf4_t *, vuint8mf4_t *, vuint8mf4_t *, vuint8mf4_t *, vuint8mf4_t *, const uint8_t *, vuint16mf2_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vluxseg5ei16_v_m)))
void vluxseg5ei16(vuint8mf4_t *, vuint8mf4_t *, vuint8mf4_t *, vuint8mf4_t *, vuint8mf4_t *, vbool32_t, vuint8mf4_t, vuint8mf4_t, vuint8mf4_t, vuint8mf4_t, vuint8mf4_t, const uint8_t *, vuint16mf2_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vluxseg5ei16_v)))
void vluxseg5ei16(vuint8mf8_t *, vuint8mf8_t *, vuint8mf8_t *, vuint8mf8_t *, vuint8mf8_t *, const uint8_t *, vuint16mf4_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vluxseg5ei16_v_m)))
void vluxseg5ei16(vuint8mf8_t *, vuint8mf8_t *, vuint8mf8_t *, vuint8mf8_t *, vuint8mf8_t *, vbool64_t, vuint8mf8_t, vuint8mf8_t, vuint8mf8_t, vuint8mf8_t, vuint8mf8_t, const uint8_t *, vuint16mf4_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vluxseg6ei16_v)))
void vluxseg6ei16(vint8m1_t *, vint8m1_t *, vint8m1_t *, vint8m1_t *, vint8m1_t *, vint8m1_t *, const int8_t *, vuint16m2_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vluxseg6ei16_v_m)))
void vluxseg6ei16(vint8m1_t *, vint8m1_t *, vint8m1_t *, vint8m1_t *, vint8m1_t *, vint8m1_t *, vbool8_t, vint8m1_t, vint8m1_t, vint8m1_t, vint8m1_t, vint8m1_t, vint8m1_t, const int8_t *, vuint16m2_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vluxseg6ei16_v)))
void vluxseg6ei16(vint8mf2_t *, vint8mf2_t *, vint8mf2_t *, vint8mf2_t *, vint8mf2_t *, vint8mf2_t *, const int8_t *, vuint16m1_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vluxseg6ei16_v_m)))
void vluxseg6ei16(vint8mf2_t *, vint8mf2_t *, vint8mf2_t *, vint8mf2_t *, vint8mf2_t *, vint8mf2_t *, vbool16_t, vint8mf2_t, vint8mf2_t, vint8mf2_t, vint8mf2_t, vint8mf2_t, vint8mf2_t, const int8_t *, vuint16m1_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vluxseg6ei16_v)))
void vluxseg6ei16(vint8mf4_t *, vint8mf4_t *, vint8mf4_t *, vint8mf4_t *, vint8mf4_t *, vint8mf4_t *, const int8_t *, vuint16mf2_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vluxseg6ei16_v_m)))
void vluxseg6ei16(vint8mf4_t *, vint8mf4_t *, vint8mf4_t *, vint8mf4_t *, vint8mf4_t *, vint8mf4_t *, vbool32_t, vint8mf4_t, vint8mf4_t, vint8mf4_t, vint8mf4_t, vint8mf4_t, vint8mf4_t, const int8_t *, vuint16mf2_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vluxseg6ei16_v)))
void vluxseg6ei16(vint8mf8_t *, vint8mf8_t *, vint8mf8_t *, vint8mf8_t *, vint8mf8_t *, vint8mf8_t *, const int8_t *, vuint16mf4_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vluxseg6ei16_v_m)))
void vluxseg6ei16(vint8mf8_t *, vint8mf8_t *, vint8mf8_t *, vint8mf8_t *, vint8mf8_t *, vint8mf8_t *, vbool64_t, vint8mf8_t, vint8mf8_t, vint8mf8_t, vint8mf8_t, vint8mf8_t, vint8mf8_t, const int8_t *, vuint16mf4_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vluxseg6ei16_v)))
void vluxseg6ei16(vuint8m1_t *, vuint8m1_t *, vuint8m1_t *, vuint8m1_t *, vuint8m1_t *, vuint8m1_t *, const uint8_t *, vuint16m2_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vluxseg6ei16_v_m)))
void vluxseg6ei16(vuint8m1_t *, vuint8m1_t *, vuint8m1_t *, vuint8m1_t *, vuint8m1_t *, vuint8m1_t *, vbool8_t, vuint8m1_t, vuint8m1_t, vuint8m1_t, vuint8m1_t, vuint8m1_t, vuint8m1_t, const uint8_t *, vuint16m2_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vluxseg6ei16_v)))
void vluxseg6ei16(vuint8mf2_t *, vuint8mf2_t *, vuint8mf2_t *, vuint8mf2_t *, vuint8mf2_t *, vuint8mf2_t *, const uint8_t *, vuint16m1_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vluxseg6ei16_v_m)))
void vluxseg6ei16(vuint8mf2_t *, vuint8mf2_t *, vuint8mf2_t *, vuint8mf2_t *, vuint8mf2_t *, vuint8mf2_t *, vbool16_t, vuint8mf2_t, vuint8mf2_t, vuint8mf2_t, vuint8mf2_t, vuint8mf2_t, vuint8mf2_t, const uint8_t *, vuint16m1_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vluxseg6ei16_v)))
void vluxseg6ei16(vuint8mf4_t *, vuint8mf4_t *, vuint8mf4_t *, vuint8mf4_t *, vuint8mf4_t *, vuint8mf4_t *, const uint8_t *, vuint16mf2_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vluxseg6ei16_v_m)))
void vluxseg6ei16(vuint8mf4_t *, vuint8mf4_t *, vuint8mf4_t *, vuint8mf4_t *, vuint8mf4_t *, vuint8mf4_t *, vbool32_t, vuint8mf4_t, vuint8mf4_t, vuint8mf4_t, vuint8mf4_t, vuint8mf4_t, vuint8mf4_t, const uint8_t *, vuint16mf2_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vluxseg6ei16_v)))
void vluxseg6ei16(vuint8mf8_t *, vuint8mf8_t *, vuint8mf8_t *, vuint8mf8_t *, vuint8mf8_t *, vuint8mf8_t *, const uint8_t *, vuint16mf4_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vluxseg6ei16_v_m)))
void vluxseg6ei16(vuint8mf8_t *, vuint8mf8_t *, vuint8mf8_t *, vuint8mf8_t *, vuint8mf8_t *, vuint8mf8_t *, vbool64_t, vuint8mf8_t, vuint8mf8_t, vuint8mf8_t, vuint8mf8_t, vuint8mf8_t, vuint8mf8_t, const uint8_t *, vuint16mf4_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vluxseg7ei16_v)))
void vluxseg7ei16(vint8m1_t *, vint8m1_t *, vint8m1_t *, vint8m1_t *, vint8m1_t *, vint8m1_t *, vint8m1_t *, const int8_t *, vuint16m2_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vluxseg7ei16_v_m)))
void vluxseg7ei16(vint8m1_t *, vint8m1_t *, vint8m1_t *, vint8m1_t *, vint8m1_t *, vint8m1_t *, vint8m1_t *, vbool8_t, vint8m1_t, vint8m1_t, vint8m1_t, vint8m1_t, vint8m1_t, vint8m1_t, vint8m1_t, const int8_t *, vuint16m2_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vluxseg7ei16_v)))
void vluxseg7ei16(vint8mf2_t *, vint8mf2_t *, vint8mf2_t *, vint8mf2_t *, vint8mf2_t *, vint8mf2_t *, vint8mf2_t *, const int8_t *, vuint16m1_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vluxseg7ei16_v_m)))
void vluxseg7ei16(vint8mf2_t *, vint8mf2_t *, vint8mf2_t *, vint8mf2_t *, vint8mf2_t *, vint8mf2_t *, vint8mf2_t *, vbool16_t, vint8mf2_t, vint8mf2_t, vint8mf2_t, vint8mf2_t, vint8mf2_t, vint8mf2_t, vint8mf2_t, const int8_t *, vuint16m1_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vluxseg7ei16_v)))
void vluxseg7ei16(vint8mf4_t *, vint8mf4_t *, vint8mf4_t *, vint8mf4_t *, vint8mf4_t *, vint8mf4_t *, vint8mf4_t *, const int8_t *, vuint16mf2_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vluxseg7ei16_v_m)))
void vluxseg7ei16(vint8mf4_t *, vint8mf4_t *, vint8mf4_t *, vint8mf4_t *, vint8mf4_t *, vint8mf4_t *, vint8mf4_t *, vbool32_t, vint8mf4_t, vint8mf4_t, vint8mf4_t, vint8mf4_t, vint8mf4_t, vint8mf4_t, vint8mf4_t, const int8_t *, vuint16mf2_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vluxseg7ei16_v)))
void vluxseg7ei16(vint8mf8_t *, vint8mf8_t *, vint8mf8_t *, vint8mf8_t *, vint8mf8_t *, vint8mf8_t *, vint8mf8_t *, const int8_t *, vuint16mf4_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vluxseg7ei16_v_m)))
void vluxseg7ei16(vint8mf8_t *, vint8mf8_t *, vint8mf8_t *, vint8mf8_t *, vint8mf8_t *, vint8mf8_t *, vint8mf8_t *, vbool64_t, vint8mf8_t, vint8mf8_t, vint8mf8_t, vint8mf8_t, vint8mf8_t, vint8mf8_t, vint8mf8_t, const int8_t *, vuint16mf4_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vluxseg7ei16_v)))
void vluxseg7ei16(vuint8m1_t *, vuint8m1_t *, vuint8m1_t *, vuint8m1_t *, vuint8m1_t *, vuint8m1_t *, vuint8m1_t *, const uint8_t *, vuint16m2_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vluxseg7ei16_v_m)))
void vluxseg7ei16(vuint8m1_t *, vuint8m1_t *, vuint8m1_t *, vuint8m1_t *, vuint8m1_t *, vuint8m1_t *, vuint8m1_t *, vbool8_t, vuint8m1_t, vuint8m1_t, vuint8m1_t, vuint8m1_t, vuint8m1_t, vuint8m1_t, vuint8m1_t, const uint8_t *, vuint16m2_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vluxseg7ei16_v)))
void vluxseg7ei16(vuint8mf2_t *, vuint8mf2_t *, vuint8mf2_t *, vuint8mf2_t *, vuint8mf2_t *, vuint8mf2_t *, vuint8mf2_t *, const uint8_t *, vuint16m1_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vluxseg7ei16_v_m)))
void vluxseg7ei16(vuint8mf2_t *, vuint8mf2_t *, vuint8mf2_t *, vuint8mf2_t *, vuint8mf2_t *, vuint8mf2_t *, vuint8mf2_t *, vbool16_t, vuint8mf2_t, vuint8mf2_t, vuint8mf2_t, vuint8mf2_t, vuint8mf2_t, vuint8mf2_t, vuint8mf2_t, const uint8_t *, vuint16m1_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vluxseg7ei16_v)))
void vluxseg7ei16(vuint8mf4_t *, vuint8mf4_t *, vuint8mf4_t *, vuint8mf4_t *, vuint8mf4_t *, vuint8mf4_t *, vuint8mf4_t *, const uint8_t *, vuint16mf2_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vluxseg7ei16_v_m)))
void vluxseg7ei16(vuint8mf4_t *, vuint8mf4_t *, vuint8mf4_t *, vuint8mf4_t *, vuint8mf4_t *, vuint8mf4_t *, vuint8mf4_t *, vbool32_t, vuint8mf4_t, vuint8mf4_t, vuint8mf4_t, vuint8mf4_t, vuint8mf4_t, vuint8mf4_t, vuint8mf4_t, const uint8_t *, vuint16mf2_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vluxseg7ei16_v)))
void vluxseg7ei16(vuint8mf8_t *, vuint8mf8_t *, vuint8mf8_t *, vuint8mf8_t *, vuint8mf8_t *, vuint8mf8_t *, vuint8mf8_t *, const uint8_t *, vuint16mf4_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vluxseg7ei16_v_m)))
void vluxseg7ei16(vuint8mf8_t *, vuint8mf8_t *, vuint8mf8_t *, vuint8mf8_t *, vuint8mf8_t *, vuint8mf8_t *, vuint8mf8_t *, vbool64_t, vuint8mf8_t, vuint8mf8_t, vuint8mf8_t, vuint8mf8_t, vuint8mf8_t, vuint8mf8_t, vuint8mf8_t, const uint8_t *, vuint16mf4_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vluxseg8ei16_v)))
void vluxseg8ei16(vint8m1_t *, vint8m1_t *, vint8m1_t *, vint8m1_t *, vint8m1_t *, vint8m1_t *, vint8m1_t *, vint8m1_t *, const int8_t *, vuint16m2_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vluxseg8ei16_v_m)))
void vluxseg8ei16(vint8m1_t *, vint8m1_t *, vint8m1_t *, vint8m1_t *, vint8m1_t *, vint8m1_t *, vint8m1_t *, vint8m1_t *, vbool8_t, vint8m1_t, vint8m1_t, vint8m1_t, vint8m1_t, vint8m1_t, vint8m1_t, vint8m1_t, vint8m1_t, const int8_t *, vuint16m2_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vluxseg8ei16_v)))
void vluxseg8ei16(vint8mf2_t *, vint8mf2_t *, vint8mf2_t *, vint8mf2_t *, vint8mf2_t *, vint8mf2_t *, vint8mf2_t *, vint8mf2_t *, const int8_t *, vuint16m1_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vluxseg8ei16_v_m)))
void vluxseg8ei16(vint8mf2_t *, vint8mf2_t *, vint8mf2_t *, vint8mf2_t *, vint8mf2_t *, vint8mf2_t *, vint8mf2_t *, vint8mf2_t *, vbool16_t, vint8mf2_t, vint8mf2_t, vint8mf2_t, vint8mf2_t, vint8mf2_t, vint8mf2_t, vint8mf2_t, vint8mf2_t, const int8_t *, vuint16m1_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vluxseg8ei16_v)))
void vluxseg8ei16(vint8mf4_t *, vint8mf4_t *, vint8mf4_t *, vint8mf4_t *, vint8mf4_t *, vint8mf4_t *, vint8mf4_t *, vint8mf4_t *, const int8_t *, vuint16mf2_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vluxseg8ei16_v_m)))
void vluxseg8ei16(vint8mf4_t *, vint8mf4_t *, vint8mf4_t *, vint8mf4_t *, vint8mf4_t *, vint8mf4_t *, vint8mf4_t *, vint8mf4_t *, vbool32_t, vint8mf4_t, vint8mf4_t, vint8mf4_t, vint8mf4_t, vint8mf4_t, vint8mf4_t, vint8mf4_t, vint8mf4_t, const int8_t *, vuint16mf2_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vluxseg8ei16_v)))
void vluxseg8ei16(vint8mf8_t *, vint8mf8_t *, vint8mf8_t *, vint8mf8_t *, vint8mf8_t *, vint8mf8_t *, vint8mf8_t *, vint8mf8_t *, const int8_t *, vuint16mf4_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vluxseg8ei16_v_m)))
void vluxseg8ei16(vint8mf8_t *, vint8mf8_t *, vint8mf8_t *, vint8mf8_t *, vint8mf8_t *, vint8mf8_t *, vint8mf8_t *, vint8mf8_t *, vbool64_t, vint8mf8_t, vint8mf8_t, vint8mf8_t, vint8mf8_t, vint8mf8_t, vint8mf8_t, vint8mf8_t, vint8mf8_t, const int8_t *, vuint16mf4_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vluxseg8ei16_v)))
void vluxseg8ei16(vuint8m1_t *, vuint8m1_t *, vuint8m1_t *, vuint8m1_t *, vuint8m1_t *, vuint8m1_t *, vuint8m1_t *, vuint8m1_t *, const uint8_t *, vuint16m2_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vluxseg8ei16_v_m)))
void vluxseg8ei16(vuint8m1_t *, vuint8m1_t *, vuint8m1_t *, vuint8m1_t *, vuint8m1_t *, vuint8m1_t *, vuint8m1_t *, vuint8m1_t *, vbool8_t, vuint8m1_t, vuint8m1_t, vuint8m1_t, vuint8m1_t, vuint8m1_t, vuint8m1_t, vuint8m1_t, vuint8m1_t, const uint8_t *, vuint16m2_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vluxseg8ei16_v)))
void vluxseg8ei16(vuint8mf2_t *, vuint8mf2_t *, vuint8mf2_t *, vuint8mf2_t *, vuint8mf2_t *, vuint8mf2_t *, vuint8mf2_t *, vuint8mf2_t *, const uint8_t *, vuint16m1_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vluxseg8ei16_v_m)))
void vluxseg8ei16(vuint8mf2_t *, vuint8mf2_t *, vuint8mf2_t *, vuint8mf2_t *, vuint8mf2_t *, vuint8mf2_t *, vuint8mf2_t *, vuint8mf2_t *, vbool16_t, vuint8mf2_t, vuint8mf2_t, vuint8mf2_t, vuint8mf2_t, vuint8mf2_t, vuint8mf2_t, vuint8mf2_t, vuint8mf2_t, const uint8_t *, vuint16m1_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vluxseg8ei16_v)))
void vluxseg8ei16(vuint8mf4_t *, vuint8mf4_t *, vuint8mf4_t *, vuint8mf4_t *, vuint8mf4_t *, vuint8mf4_t *, vuint8mf4_t *, vuint8mf4_t *, const uint8_t *, vuint16mf2_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vluxseg8ei16_v_m)))
void vluxseg8ei16(vuint8mf4_t *, vuint8mf4_t *, vuint8mf4_t *, vuint8mf4_t *, vuint8mf4_t *, vuint8mf4_t *, vuint8mf4_t *, vuint8mf4_t *, vbool32_t, vuint8mf4_t, vuint8mf4_t, vuint8mf4_t, vuint8mf4_t, vuint8mf4_t, vuint8mf4_t, vuint8mf4_t, vuint8mf4_t, const uint8_t *, vuint16mf2_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vluxseg8ei16_v)))
void vluxseg8ei16(vuint8mf8_t *, vuint8mf8_t *, vuint8mf8_t *, vuint8mf8_t *, vuint8mf8_t *, vuint8mf8_t *, vuint8mf8_t *, vuint8mf8_t *, const uint8_t *, vuint16mf4_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vluxseg8ei16_v_m)))
void vluxseg8ei16(vuint8mf8_t *, vuint8mf8_t *, vuint8mf8_t *, vuint8mf8_t *, vuint8mf8_t *, vuint8mf8_t *, vuint8mf8_t *, vuint8mf8_t *, vbool64_t, vuint8mf8_t, vuint8mf8_t, vuint8mf8_t, vuint8mf8_t, vuint8mf8_t, vuint8mf8_t, vuint8mf8_t, vuint8mf8_t, const uint8_t *, vuint16mf4_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vluxseg2ei32_v)))
void vluxseg2ei32(vint8m1_t *, vint8m1_t *, const int8_t *, vuint32m4_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vluxseg2ei32_v_m)))
void vluxseg2ei32(vint8m1_t *, vint8m1_t *, vbool8_t, vint8m1_t, vint8m1_t, const int8_t *, vuint32m4_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vluxseg2ei32_v)))
void vluxseg2ei32(vint8m2_t *, vint8m2_t *, const int8_t *, vuint32m8_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vluxseg2ei32_v_m)))
void vluxseg2ei32(vint8m2_t *, vint8m2_t *, vbool4_t, vint8m2_t, vint8m2_t, const int8_t *, vuint32m8_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vluxseg2ei32_v)))
void vluxseg2ei32(vint8mf2_t *, vint8mf2_t *, const int8_t *, vuint32m2_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vluxseg2ei32_v_m)))
void vluxseg2ei32(vint8mf2_t *, vint8mf2_t *, vbool16_t, vint8mf2_t, vint8mf2_t, const int8_t *, vuint32m2_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vluxseg2ei32_v)))
void vluxseg2ei32(vint8mf4_t *, vint8mf4_t *, const int8_t *, vuint32m1_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vluxseg2ei32_v_m)))
void vluxseg2ei32(vint8mf4_t *, vint8mf4_t *, vbool32_t, vint8mf4_t, vint8mf4_t, const int8_t *, vuint32m1_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vluxseg2ei32_v)))
void vluxseg2ei32(vint8mf8_t *, vint8mf8_t *, const int8_t *, vuint32mf2_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vluxseg2ei32_v_m)))
void vluxseg2ei32(vint8mf8_t *, vint8mf8_t *, vbool64_t, vint8mf8_t, vint8mf8_t, const int8_t *, vuint32mf2_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vluxseg2ei32_v)))
void vluxseg2ei32(vuint8m1_t *, vuint8m1_t *, const uint8_t *, vuint32m4_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vluxseg2ei32_v_m)))
void vluxseg2ei32(vuint8m1_t *, vuint8m1_t *, vbool8_t, vuint8m1_t, vuint8m1_t, const uint8_t *, vuint32m4_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vluxseg2ei32_v)))
void vluxseg2ei32(vuint8m2_t *, vuint8m2_t *, const uint8_t *, vuint32m8_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vluxseg2ei32_v_m)))
void vluxseg2ei32(vuint8m2_t *, vuint8m2_t *, vbool4_t, vuint8m2_t, vuint8m2_t, const uint8_t *, vuint32m8_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vluxseg2ei32_v)))
void vluxseg2ei32(vuint8mf2_t *, vuint8mf2_t *, const uint8_t *, vuint32m2_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vluxseg2ei32_v_m)))
void vluxseg2ei32(vuint8mf2_t *, vuint8mf2_t *, vbool16_t, vuint8mf2_t, vuint8mf2_t, const uint8_t *, vuint32m2_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vluxseg2ei32_v)))
void vluxseg2ei32(vuint8mf4_t *, vuint8mf4_t *, const uint8_t *, vuint32m1_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vluxseg2ei32_v_m)))
void vluxseg2ei32(vuint8mf4_t *, vuint8mf4_t *, vbool32_t, vuint8mf4_t, vuint8mf4_t, const uint8_t *, vuint32m1_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vluxseg2ei32_v)))
void vluxseg2ei32(vuint8mf8_t *, vuint8mf8_t *, const uint8_t *, vuint32mf2_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vluxseg2ei32_v_m)))
void vluxseg2ei32(vuint8mf8_t *, vuint8mf8_t *, vbool64_t, vuint8mf8_t, vuint8mf8_t, const uint8_t *, vuint32mf2_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vluxseg3ei32_v)))
void vluxseg3ei32(vint8m1_t *, vint8m1_t *, vint8m1_t *, const int8_t *, vuint32m4_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vluxseg3ei32_v_m)))
void vluxseg3ei32(vint8m1_t *, vint8m1_t *, vint8m1_t *, vbool8_t, vint8m1_t, vint8m1_t, vint8m1_t, const int8_t *, vuint32m4_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vluxseg3ei32_v)))
void vluxseg3ei32(vint8m2_t *, vint8m2_t *, vint8m2_t *, const int8_t *, vuint32m8_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vluxseg3ei32_v_m)))
void vluxseg3ei32(vint8m2_t *, vint8m2_t *, vint8m2_t *, vbool4_t, vint8m2_t, vint8m2_t, vint8m2_t, const int8_t *, vuint32m8_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vluxseg3ei32_v)))
void vluxseg3ei32(vint8mf2_t *, vint8mf2_t *, vint8mf2_t *, const int8_t *, vuint32m2_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vluxseg3ei32_v_m)))
void vluxseg3ei32(vint8mf2_t *, vint8mf2_t *, vint8mf2_t *, vbool16_t, vint8mf2_t, vint8mf2_t, vint8mf2_t, const int8_t *, vuint32m2_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vluxseg3ei32_v)))
void vluxseg3ei32(vint8mf4_t *, vint8mf4_t *, vint8mf4_t *, const int8_t *, vuint32m1_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vluxseg3ei32_v_m)))
void vluxseg3ei32(vint8mf4_t *, vint8mf4_t *, vint8mf4_t *, vbool32_t, vint8mf4_t, vint8mf4_t, vint8mf4_t, const int8_t *, vuint32m1_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vluxseg3ei32_v)))
void vluxseg3ei32(vint8mf8_t *, vint8mf8_t *, vint8mf8_t *, const int8_t *, vuint32mf2_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vluxseg3ei32_v_m)))
void vluxseg3ei32(vint8mf8_t *, vint8mf8_t *, vint8mf8_t *, vbool64_t, vint8mf8_t, vint8mf8_t, vint8mf8_t, const int8_t *, vuint32mf2_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vluxseg3ei32_v)))
void vluxseg3ei32(vuint8m1_t *, vuint8m1_t *, vuint8m1_t *, const uint8_t *, vuint32m4_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vluxseg3ei32_v_m)))
void vluxseg3ei32(vuint8m1_t *, vuint8m1_t *, vuint8m1_t *, vbool8_t, vuint8m1_t, vuint8m1_t, vuint8m1_t, const uint8_t *, vuint32m4_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vluxseg3ei32_v)))
void vluxseg3ei32(vuint8m2_t *, vuint8m2_t *, vuint8m2_t *, const uint8_t *, vuint32m8_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vluxseg3ei32_v_m)))
void vluxseg3ei32(vuint8m2_t *, vuint8m2_t *, vuint8m2_t *, vbool4_t, vuint8m2_t, vuint8m2_t, vuint8m2_t, const uint8_t *, vuint32m8_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vluxseg3ei32_v)))
void vluxseg3ei32(vuint8mf2_t *, vuint8mf2_t *, vuint8mf2_t *, const uint8_t *, vuint32m2_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vluxseg3ei32_v_m)))
void vluxseg3ei32(vuint8mf2_t *, vuint8mf2_t *, vuint8mf2_t *, vbool16_t, vuint8mf2_t, vuint8mf2_t, vuint8mf2_t, const uint8_t *, vuint32m2_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vluxseg3ei32_v)))
void vluxseg3ei32(vuint8mf4_t *, vuint8mf4_t *, vuint8mf4_t *, const uint8_t *, vuint32m1_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vluxseg3ei32_v_m)))
void vluxseg3ei32(vuint8mf4_t *, vuint8mf4_t *, vuint8mf4_t *, vbool32_t, vuint8mf4_t, vuint8mf4_t, vuint8mf4_t, const uint8_t *, vuint32m1_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vluxseg3ei32_v)))
void vluxseg3ei32(vuint8mf8_t *, vuint8mf8_t *, vuint8mf8_t *, const uint8_t *, vuint32mf2_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vluxseg3ei32_v_m)))
void vluxseg3ei32(vuint8mf8_t *, vuint8mf8_t *, vuint8mf8_t *, vbool64_t, vuint8mf8_t, vuint8mf8_t, vuint8mf8_t, const uint8_t *, vuint32mf2_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vluxseg4ei32_v)))
void vluxseg4ei32(vint8m1_t *, vint8m1_t *, vint8m1_t *, vint8m1_t *, const int8_t *, vuint32m4_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vluxseg4ei32_v_m)))
void vluxseg4ei32(vint8m1_t *, vint8m1_t *, vint8m1_t *, vint8m1_t *, vbool8_t, vint8m1_t, vint8m1_t, vint8m1_t, vint8m1_t, const int8_t *, vuint32m4_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vluxseg4ei32_v)))
void vluxseg4ei32(vint8m2_t *, vint8m2_t *, vint8m2_t *, vint8m2_t *, const int8_t *, vuint32m8_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vluxseg4ei32_v_m)))
void vluxseg4ei32(vint8m2_t *, vint8m2_t *, vint8m2_t *, vint8m2_t *, vbool4_t, vint8m2_t, vint8m2_t, vint8m2_t, vint8m2_t, const int8_t *, vuint32m8_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vluxseg4ei32_v)))
void vluxseg4ei32(vint8mf2_t *, vint8mf2_t *, vint8mf2_t *, vint8mf2_t *, const int8_t *, vuint32m2_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vluxseg4ei32_v_m)))
void vluxseg4ei32(vint8mf2_t *, vint8mf2_t *, vint8mf2_t *, vint8mf2_t *, vbool16_t, vint8mf2_t, vint8mf2_t, vint8mf2_t, vint8mf2_t, const int8_t *, vuint32m2_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vluxseg4ei32_v)))
void vluxseg4ei32(vint8mf4_t *, vint8mf4_t *, vint8mf4_t *, vint8mf4_t *, const int8_t *, vuint32m1_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vluxseg4ei32_v_m)))
void vluxseg4ei32(vint8mf4_t *, vint8mf4_t *, vint8mf4_t *, vint8mf4_t *, vbool32_t, vint8mf4_t, vint8mf4_t, vint8mf4_t, vint8mf4_t, const int8_t *, vuint32m1_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vluxseg4ei32_v)))
void vluxseg4ei32(vint8mf8_t *, vint8mf8_t *, vint8mf8_t *, vint8mf8_t *, const int8_t *, vuint32mf2_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vluxseg4ei32_v_m)))
void vluxseg4ei32(vint8mf8_t *, vint8mf8_t *, vint8mf8_t *, vint8mf8_t *, vbool64_t, vint8mf8_t, vint8mf8_t, vint8mf8_t, vint8mf8_t, const int8_t *, vuint32mf2_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vluxseg4ei32_v)))
void vluxseg4ei32(vuint8m1_t *, vuint8m1_t *, vuint8m1_t *, vuint8m1_t *, const uint8_t *, vuint32m4_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vluxseg4ei32_v_m)))
void vluxseg4ei32(vuint8m1_t *, vuint8m1_t *, vuint8m1_t *, vuint8m1_t *, vbool8_t, vuint8m1_t, vuint8m1_t, vuint8m1_t, vuint8m1_t, const uint8_t *, vuint32m4_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vluxseg4ei32_v)))
void vluxseg4ei32(vuint8m2_t *, vuint8m2_t *, vuint8m2_t *, vuint8m2_t *, const uint8_t *, vuint32m8_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vluxseg4ei32_v_m)))
void vluxseg4ei32(vuint8m2_t *, vuint8m2_t *, vuint8m2_t *, vuint8m2_t *, vbool4_t, vuint8m2_t, vuint8m2_t, vuint8m2_t, vuint8m2_t, const uint8_t *, vuint32m8_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vluxseg4ei32_v)))
void vluxseg4ei32(vuint8mf2_t *, vuint8mf2_t *, vuint8mf2_t *, vuint8mf2_t *, const uint8_t *, vuint32m2_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vluxseg4ei32_v_m)))
void vluxseg4ei32(vuint8mf2_t *, vuint8mf2_t *, vuint8mf2_t *, vuint8mf2_t *, vbool16_t, vuint8mf2_t, vuint8mf2_t, vuint8mf2_t, vuint8mf2_t, const uint8_t *, vuint32m2_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vluxseg4ei32_v)))
void vluxseg4ei32(vuint8mf4_t *, vuint8mf4_t *, vuint8mf4_t *, vuint8mf4_t *, const uint8_t *, vuint32m1_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vluxseg4ei32_v_m)))
void vluxseg4ei32(vuint8mf4_t *, vuint8mf4_t *, vuint8mf4_t *, vuint8mf4_t *, vbool32_t, vuint8mf4_t, vuint8mf4_t, vuint8mf4_t, vuint8mf4_t, const uint8_t *, vuint32m1_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vluxseg4ei32_v)))
void vluxseg4ei32(vuint8mf8_t *, vuint8mf8_t *, vuint8mf8_t *, vuint8mf8_t *, const uint8_t *, vuint32mf2_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vluxseg4ei32_v_m)))
void vluxseg4ei32(vuint8mf8_t *, vuint8mf8_t *, vuint8mf8_t *, vuint8mf8_t *, vbool64_t, vuint8mf8_t, vuint8mf8_t, vuint8mf8_t, vuint8mf8_t, const uint8_t *, vuint32mf2_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vluxseg5ei32_v)))
void vluxseg5ei32(vint8m1_t *, vint8m1_t *, vint8m1_t *, vint8m1_t *, vint8m1_t *, const int8_t *, vuint32m4_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vluxseg5ei32_v_m)))
void vluxseg5ei32(vint8m1_t *, vint8m1_t *, vint8m1_t *, vint8m1_t *, vint8m1_t *, vbool8_t, vint8m1_t, vint8m1_t, vint8m1_t, vint8m1_t, vint8m1_t, const int8_t *, vuint32m4_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vluxseg5ei32_v)))
void vluxseg5ei32(vint8mf2_t *, vint8mf2_t *, vint8mf2_t *, vint8mf2_t *, vint8mf2_t *, const int8_t *, vuint32m2_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vluxseg5ei32_v_m)))
void vluxseg5ei32(vint8mf2_t *, vint8mf2_t *, vint8mf2_t *, vint8mf2_t *, vint8mf2_t *, vbool16_t, vint8mf2_t, vint8mf2_t, vint8mf2_t, vint8mf2_t, vint8mf2_t, const int8_t *, vuint32m2_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vluxseg5ei32_v)))
void vluxseg5ei32(vint8mf4_t *, vint8mf4_t *, vint8mf4_t *, vint8mf4_t *, vint8mf4_t *, const int8_t *, vuint32m1_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vluxseg5ei32_v_m)))
void vluxseg5ei32(vint8mf4_t *, vint8mf4_t *, vint8mf4_t *, vint8mf4_t *, vint8mf4_t *, vbool32_t, vint8mf4_t, vint8mf4_t, vint8mf4_t, vint8mf4_t, vint8mf4_t, const int8_t *, vuint32m1_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vluxseg5ei32_v)))
void vluxseg5ei32(vint8mf8_t *, vint8mf8_t *, vint8mf8_t *, vint8mf8_t *, vint8mf8_t *, const int8_t *, vuint32mf2_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vluxseg5ei32_v_m)))
void vluxseg5ei32(vint8mf8_t *, vint8mf8_t *, vint8mf8_t *, vint8mf8_t *, vint8mf8_t *, vbool64_t, vint8mf8_t, vint8mf8_t, vint8mf8_t, vint8mf8_t, vint8mf8_t, const int8_t *, vuint32mf2_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vluxseg5ei32_v)))
void vluxseg5ei32(vuint8m1_t *, vuint8m1_t *, vuint8m1_t *, vuint8m1_t *, vuint8m1_t *, const uint8_t *, vuint32m4_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vluxseg5ei32_v_m)))
void vluxseg5ei32(vuint8m1_t *, vuint8m1_t *, vuint8m1_t *, vuint8m1_t *, vuint8m1_t *, vbool8_t, vuint8m1_t, vuint8m1_t, vuint8m1_t, vuint8m1_t, vuint8m1_t, const uint8_t *, vuint32m4_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vluxseg5ei32_v)))
void vluxseg5ei32(vuint8mf2_t *, vuint8mf2_t *, vuint8mf2_t *, vuint8mf2_t *, vuint8mf2_t *, const uint8_t *, vuint32m2_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vluxseg5ei32_v_m)))
void vluxseg5ei32(vuint8mf2_t *, vuint8mf2_t *, vuint8mf2_t *, vuint8mf2_t *, vuint8mf2_t *, vbool16_t, vuint8mf2_t, vuint8mf2_t, vuint8mf2_t, vuint8mf2_t, vuint8mf2_t, const uint8_t *, vuint32m2_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vluxseg5ei32_v)))
void vluxseg5ei32(vuint8mf4_t *, vuint8mf4_t *, vuint8mf4_t *, vuint8mf4_t *, vuint8mf4_t *, const uint8_t *, vuint32m1_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vluxseg5ei32_v_m)))
void vluxseg5ei32(vuint8mf4_t *, vuint8mf4_t *, vuint8mf4_t *, vuint8mf4_t *, vuint8mf4_t *, vbool32_t, vuint8mf4_t, vuint8mf4_t, vuint8mf4_t, vuint8mf4_t, vuint8mf4_t, const uint8_t *, vuint32m1_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vluxseg5ei32_v)))
void vluxseg5ei32(vuint8mf8_t *, vuint8mf8_t *, vuint8mf8_t *, vuint8mf8_t *, vuint8mf8_t *, const uint8_t *, vuint32mf2_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vluxseg5ei32_v_m)))
void vluxseg5ei32(vuint8mf8_t *, vuint8mf8_t *, vuint8mf8_t *, vuint8mf8_t *, vuint8mf8_t *, vbool64_t, vuint8mf8_t, vuint8mf8_t, vuint8mf8_t, vuint8mf8_t, vuint8mf8_t, const uint8_t *, vuint32mf2_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vluxseg6ei32_v)))
void vluxseg6ei32(vint8m1_t *, vint8m1_t *, vint8m1_t *, vint8m1_t *, vint8m1_t *, vint8m1_t *, const int8_t *, vuint32m4_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vluxseg6ei32_v_m)))
void vluxseg6ei32(vint8m1_t *, vint8m1_t *, vint8m1_t *, vint8m1_t *, vint8m1_t *, vint8m1_t *, vbool8_t, vint8m1_t, vint8m1_t, vint8m1_t, vint8m1_t, vint8m1_t, vint8m1_t, const int8_t *, vuint32m4_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vluxseg6ei32_v)))
void vluxseg6ei32(vint8mf2_t *, vint8mf2_t *, vint8mf2_t *, vint8mf2_t *, vint8mf2_t *, vint8mf2_t *, const int8_t *, vuint32m2_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vluxseg6ei32_v_m)))
void vluxseg6ei32(vint8mf2_t *, vint8mf2_t *, vint8mf2_t *, vint8mf2_t *, vint8mf2_t *, vint8mf2_t *, vbool16_t, vint8mf2_t, vint8mf2_t, vint8mf2_t, vint8mf2_t, vint8mf2_t, vint8mf2_t, const int8_t *, vuint32m2_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vluxseg6ei32_v)))
void vluxseg6ei32(vint8mf4_t *, vint8mf4_t *, vint8mf4_t *, vint8mf4_t *, vint8mf4_t *, vint8mf4_t *, const int8_t *, vuint32m1_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vluxseg6ei32_v_m)))
void vluxseg6ei32(vint8mf4_t *, vint8mf4_t *, vint8mf4_t *, vint8mf4_t *, vint8mf4_t *, vint8mf4_t *, vbool32_t, vint8mf4_t, vint8mf4_t, vint8mf4_t, vint8mf4_t, vint8mf4_t, vint8mf4_t, const int8_t *, vuint32m1_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vluxseg6ei32_v)))
void vluxseg6ei32(vint8mf8_t *, vint8mf8_t *, vint8mf8_t *, vint8mf8_t *, vint8mf8_t *, vint8mf8_t *, const int8_t *, vuint32mf2_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vluxseg6ei32_v_m)))
void vluxseg6ei32(vint8mf8_t *, vint8mf8_t *, vint8mf8_t *, vint8mf8_t *, vint8mf8_t *, vint8mf8_t *, vbool64_t, vint8mf8_t, vint8mf8_t, vint8mf8_t, vint8mf8_t, vint8mf8_t, vint8mf8_t, const int8_t *, vuint32mf2_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vluxseg6ei32_v)))
void vluxseg6ei32(vuint8m1_t *, vuint8m1_t *, vuint8m1_t *, vuint8m1_t *, vuint8m1_t *, vuint8m1_t *, const uint8_t *, vuint32m4_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vluxseg6ei32_v_m)))
void vluxseg6ei32(vuint8m1_t *, vuint8m1_t *, vuint8m1_t *, vuint8m1_t *, vuint8m1_t *, vuint8m1_t *, vbool8_t, vuint8m1_t, vuint8m1_t, vuint8m1_t, vuint8m1_t, vuint8m1_t, vuint8m1_t, const uint8_t *, vuint32m4_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vluxseg6ei32_v)))
void vluxseg6ei32(vuint8mf2_t *, vuint8mf2_t *, vuint8mf2_t *, vuint8mf2_t *, vuint8mf2_t *, vuint8mf2_t *, const uint8_t *, vuint32m2_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vluxseg6ei32_v_m)))
void vluxseg6ei32(vuint8mf2_t *, vuint8mf2_t *, vuint8mf2_t *, vuint8mf2_t *, vuint8mf2_t *, vuint8mf2_t *, vbool16_t, vuint8mf2_t, vuint8mf2_t, vuint8mf2_t, vuint8mf2_t, vuint8mf2_t, vuint8mf2_t, const uint8_t *, vuint32m2_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vluxseg6ei32_v)))
void vluxseg6ei32(vuint8mf4_t *, vuint8mf4_t *, vuint8mf4_t *, vuint8mf4_t *, vuint8mf4_t *, vuint8mf4_t *, const uint8_t *, vuint32m1_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vluxseg6ei32_v_m)))
void vluxseg6ei32(vuint8mf4_t *, vuint8mf4_t *, vuint8mf4_t *, vuint8mf4_t *, vuint8mf4_t *, vuint8mf4_t *, vbool32_t, vuint8mf4_t, vuint8mf4_t, vuint8mf4_t, vuint8mf4_t, vuint8mf4_t, vuint8mf4_t, const uint8_t *, vuint32m1_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vluxseg6ei32_v)))
void vluxseg6ei32(vuint8mf8_t *, vuint8mf8_t *, vuint8mf8_t *, vuint8mf8_t *, vuint8mf8_t *, vuint8mf8_t *, const uint8_t *, vuint32mf2_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vluxseg6ei32_v_m)))
void vluxseg6ei32(vuint8mf8_t *, vuint8mf8_t *, vuint8mf8_t *, vuint8mf8_t *, vuint8mf8_t *, vuint8mf8_t *, vbool64_t, vuint8mf8_t, vuint8mf8_t, vuint8mf8_t, vuint8mf8_t, vuint8mf8_t, vuint8mf8_t, const uint8_t *, vuint32mf2_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vluxseg7ei32_v)))
void vluxseg7ei32(vint8m1_t *, vint8m1_t *, vint8m1_t *, vint8m1_t *, vint8m1_t *, vint8m1_t *, vint8m1_t *, const int8_t *, vuint32m4_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vluxseg7ei32_v_m)))
void vluxseg7ei32(vint8m1_t *, vint8m1_t *, vint8m1_t *, vint8m1_t *, vint8m1_t *, vint8m1_t *, vint8m1_t *, vbool8_t, vint8m1_t, vint8m1_t, vint8m1_t, vint8m1_t, vint8m1_t, vint8m1_t, vint8m1_t, const int8_t *, vuint32m4_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vluxseg7ei32_v)))
void vluxseg7ei32(vint8mf2_t *, vint8mf2_t *, vint8mf2_t *, vint8mf2_t *, vint8mf2_t *, vint8mf2_t *, vint8mf2_t *, const int8_t *, vuint32m2_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vluxseg7ei32_v_m)))
void vluxseg7ei32(vint8mf2_t *, vint8mf2_t *, vint8mf2_t *, vint8mf2_t *, vint8mf2_t *, vint8mf2_t *, vint8mf2_t *, vbool16_t, vint8mf2_t, vint8mf2_t, vint8mf2_t, vint8mf2_t, vint8mf2_t, vint8mf2_t, vint8mf2_t, const int8_t *, vuint32m2_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vluxseg7ei32_v)))
void vluxseg7ei32(vint8mf4_t *, vint8mf4_t *, vint8mf4_t *, vint8mf4_t *, vint8mf4_t *, vint8mf4_t *, vint8mf4_t *, const int8_t *, vuint32m1_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vluxseg7ei32_v_m)))
void vluxseg7ei32(vint8mf4_t *, vint8mf4_t *, vint8mf4_t *, vint8mf4_t *, vint8mf4_t *, vint8mf4_t *, vint8mf4_t *, vbool32_t, vint8mf4_t, vint8mf4_t, vint8mf4_t, vint8mf4_t, vint8mf4_t, vint8mf4_t, vint8mf4_t, const int8_t *, vuint32m1_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vluxseg7ei32_v)))
void vluxseg7ei32(vint8mf8_t *, vint8mf8_t *, vint8mf8_t *, vint8mf8_t *, vint8mf8_t *, vint8mf8_t *, vint8mf8_t *, const int8_t *, vuint32mf2_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vluxseg7ei32_v_m)))
void vluxseg7ei32(vint8mf8_t *, vint8mf8_t *, vint8mf8_t *, vint8mf8_t *, vint8mf8_t *, vint8mf8_t *, vint8mf8_t *, vbool64_t, vint8mf8_t, vint8mf8_t, vint8mf8_t, vint8mf8_t, vint8mf8_t, vint8mf8_t, vint8mf8_t, const int8_t *, vuint32mf2_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vluxseg7ei32_v)))
void vluxseg7ei32(vuint8m1_t *, vuint8m1_t *, vuint8m1_t *, vuint8m1_t *, vuint8m1_t *, vuint8m1_t *, vuint8m1_t *, const uint8_t *, vuint32m4_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vluxseg7ei32_v_m)))
void vluxseg7ei32(vuint8m1_t *, vuint8m1_t *, vuint8m1_t *, vuint8m1_t *, vuint8m1_t *, vuint8m1_t *, vuint8m1_t *, vbool8_t, vuint8m1_t, vuint8m1_t, vuint8m1_t, vuint8m1_t, vuint8m1_t, vuint8m1_t, vuint8m1_t, const uint8_t *, vuint32m4_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vluxseg7ei32_v)))
void vluxseg7ei32(vuint8mf2_t *, vuint8mf2_t *, vuint8mf2_t *, vuint8mf2_t *, vuint8mf2_t *, vuint8mf2_t *, vuint8mf2_t *, const uint8_t *, vuint32m2_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vluxseg7ei32_v_m)))
void vluxseg7ei32(vuint8mf2_t *, vuint8mf2_t *, vuint8mf2_t *, vuint8mf2_t *, vuint8mf2_t *, vuint8mf2_t *, vuint8mf2_t *, vbool16_t, vuint8mf2_t, vuint8mf2_t, vuint8mf2_t, vuint8mf2_t, vuint8mf2_t, vuint8mf2_t, vuint8mf2_t, const uint8_t *, vuint32m2_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vluxseg7ei32_v)))
void vluxseg7ei32(vuint8mf4_t *, vuint8mf4_t *, vuint8mf4_t *, vuint8mf4_t *, vuint8mf4_t *, vuint8mf4_t *, vuint8mf4_t *, const uint8_t *, vuint32m1_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vluxseg7ei32_v_m)))
void vluxseg7ei32(vuint8mf4_t *, vuint8mf4_t *, vuint8mf4_t *, vuint8mf4_t *, vuint8mf4_t *, vuint8mf4_t *, vuint8mf4_t *, vbool32_t, vuint8mf4_t, vuint8mf4_t, vuint8mf4_t, vuint8mf4_t, vuint8mf4_t, vuint8mf4_t, vuint8mf4_t, const uint8_t *, vuint32m1_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vluxseg7ei32_v)))
void vluxseg7ei32(vuint8mf8_t *, vuint8mf8_t *, vuint8mf8_t *, vuint8mf8_t *, vuint8mf8_t *, vuint8mf8_t *, vuint8mf8_t *, const uint8_t *, vuint32mf2_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vluxseg7ei32_v_m)))
void vluxseg7ei32(vuint8mf8_t *, vuint8mf8_t *, vuint8mf8_t *, vuint8mf8_t *, vuint8mf8_t *, vuint8mf8_t *, vuint8mf8_t *, vbool64_t, vuint8mf8_t, vuint8mf8_t, vuint8mf8_t, vuint8mf8_t, vuint8mf8_t, vuint8mf8_t, vuint8mf8_t, const uint8_t *, vuint32mf2_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vluxseg8ei32_v)))
void vluxseg8ei32(vint8m1_t *, vint8m1_t *, vint8m1_t *, vint8m1_t *, vint8m1_t *, vint8m1_t *, vint8m1_t *, vint8m1_t *, const int8_t *, vuint32m4_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vluxseg8ei32_v_m)))
void vluxseg8ei32(vint8m1_t *, vint8m1_t *, vint8m1_t *, vint8m1_t *, vint8m1_t *, vint8m1_t *, vint8m1_t *, vint8m1_t *, vbool8_t, vint8m1_t, vint8m1_t, vint8m1_t, vint8m1_t, vint8m1_t, vint8m1_t, vint8m1_t, vint8m1_t, const int8_t *, vuint32m4_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vluxseg8ei32_v)))
void vluxseg8ei32(vint8mf2_t *, vint8mf2_t *, vint8mf2_t *, vint8mf2_t *, vint8mf2_t *, vint8mf2_t *, vint8mf2_t *, vint8mf2_t *, const int8_t *, vuint32m2_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vluxseg8ei32_v_m)))
void vluxseg8ei32(vint8mf2_t *, vint8mf2_t *, vint8mf2_t *, vint8mf2_t *, vint8mf2_t *, vint8mf2_t *, vint8mf2_t *, vint8mf2_t *, vbool16_t, vint8mf2_t, vint8mf2_t, vint8mf2_t, vint8mf2_t, vint8mf2_t, vint8mf2_t, vint8mf2_t, vint8mf2_t, const int8_t *, vuint32m2_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vluxseg8ei32_v)))
void vluxseg8ei32(vint8mf4_t *, vint8mf4_t *, vint8mf4_t *, vint8mf4_t *, vint8mf4_t *, vint8mf4_t *, vint8mf4_t *, vint8mf4_t *, const int8_t *, vuint32m1_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vluxseg8ei32_v_m)))
void vluxseg8ei32(vint8mf4_t *, vint8mf4_t *, vint8mf4_t *, vint8mf4_t *, vint8mf4_t *, vint8mf4_t *, vint8mf4_t *, vint8mf4_t *, vbool32_t, vint8mf4_t, vint8mf4_t, vint8mf4_t, vint8mf4_t, vint8mf4_t, vint8mf4_t, vint8mf4_t, vint8mf4_t, const int8_t *, vuint32m1_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vluxseg8ei32_v)))
void vluxseg8ei32(vint8mf8_t *, vint8mf8_t *, vint8mf8_t *, vint8mf8_t *, vint8mf8_t *, vint8mf8_t *, vint8mf8_t *, vint8mf8_t *, const int8_t *, vuint32mf2_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vluxseg8ei32_v_m)))
void vluxseg8ei32(vint8mf8_t *, vint8mf8_t *, vint8mf8_t *, vint8mf8_t *, vint8mf8_t *, vint8mf8_t *, vint8mf8_t *, vint8mf8_t *, vbool64_t, vint8mf8_t, vint8mf8_t, vint8mf8_t, vint8mf8_t, vint8mf8_t, vint8mf8_t, vint8mf8_t, vint8mf8_t, const int8_t *, vuint32mf2_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vluxseg8ei32_v)))
void vluxseg8ei32(vuint8m1_t *, vuint8m1_t *, vuint8m1_t *, vuint8m1_t *, vuint8m1_t *, vuint8m1_t *, vuint8m1_t *, vuint8m1_t *, const uint8_t *, vuint32m4_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vluxseg8ei32_v_m)))
void vluxseg8ei32(vuint8m1_t *, vuint8m1_t *, vuint8m1_t *, vuint8m1_t *, vuint8m1_t *, vuint8m1_t *, vuint8m1_t *, vuint8m1_t *, vbool8_t, vuint8m1_t, vuint8m1_t, vuint8m1_t, vuint8m1_t, vuint8m1_t, vuint8m1_t, vuint8m1_t, vuint8m1_t, const uint8_t *, vuint32m4_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vluxseg8ei32_v)))
void vluxseg8ei32(vuint8mf2_t *, vuint8mf2_t *, vuint8mf2_t *, vuint8mf2_t *, vuint8mf2_t *, vuint8mf2_t *, vuint8mf2_t *, vuint8mf2_t *, const uint8_t *, vuint32m2_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vluxseg8ei32_v_m)))
void vluxseg8ei32(vuint8mf2_t *, vuint8mf2_t *, vuint8mf2_t *, vuint8mf2_t *, vuint8mf2_t *, vuint8mf2_t *, vuint8mf2_t *, vuint8mf2_t *, vbool16_t, vuint8mf2_t, vuint8mf2_t, vuint8mf2_t, vuint8mf2_t, vuint8mf2_t, vuint8mf2_t, vuint8mf2_t, vuint8mf2_t, const uint8_t *, vuint32m2_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vluxseg8ei32_v)))
void vluxseg8ei32(vuint8mf4_t *, vuint8mf4_t *, vuint8mf4_t *, vuint8mf4_t *, vuint8mf4_t *, vuint8mf4_t *, vuint8mf4_t *, vuint8mf4_t *, const uint8_t *, vuint32m1_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vluxseg8ei32_v_m)))
void vluxseg8ei32(vuint8mf4_t *, vuint8mf4_t *, vuint8mf4_t *, vuint8mf4_t *, vuint8mf4_t *, vuint8mf4_t *, vuint8mf4_t *, vuint8mf4_t *, vbool32_t, vuint8mf4_t, vuint8mf4_t, vuint8mf4_t, vuint8mf4_t, vuint8mf4_t, vuint8mf4_t, vuint8mf4_t, vuint8mf4_t, const uint8_t *, vuint32m1_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vluxseg8ei32_v)))
void vluxseg8ei32(vuint8mf8_t *, vuint8mf8_t *, vuint8mf8_t *, vuint8mf8_t *, vuint8mf8_t *, vuint8mf8_t *, vuint8mf8_t *, vuint8mf8_t *, const uint8_t *, vuint32mf2_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vluxseg8ei32_v_m)))
void vluxseg8ei32(vuint8mf8_t *, vuint8mf8_t *, vuint8mf8_t *, vuint8mf8_t *, vuint8mf8_t *, vuint8mf8_t *, vuint8mf8_t *, vuint8mf8_t *, vbool64_t, vuint8mf8_t, vuint8mf8_t, vuint8mf8_t, vuint8mf8_t, vuint8mf8_t, vuint8mf8_t, vuint8mf8_t, vuint8mf8_t, const uint8_t *, vuint32mf2_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vluxseg2ei8_v)))
void vluxseg2ei8(vint16m1_t *, vint16m1_t *, const int16_t *, vuint8mf2_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vluxseg2ei8_v_m)))
void vluxseg2ei8(vint16m1_t *, vint16m1_t *, vbool16_t, vint16m1_t, vint16m1_t, const int16_t *, vuint8mf2_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vluxseg2ei8_v)))
void vluxseg2ei8(vint16m2_t *, vint16m2_t *, const int16_t *, vuint8m1_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vluxseg2ei8_v_m)))
void vluxseg2ei8(vint16m2_t *, vint16m2_t *, vbool8_t, vint16m2_t, vint16m2_t, const int16_t *, vuint8m1_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vluxseg2ei8_v)))
void vluxseg2ei8(vint16m4_t *, vint16m4_t *, const int16_t *, vuint8m2_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vluxseg2ei8_v_m)))
void vluxseg2ei8(vint16m4_t *, vint16m4_t *, vbool4_t, vint16m4_t, vint16m4_t, const int16_t *, vuint8m2_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vluxseg2ei8_v)))
void vluxseg2ei8(vint16mf2_t *, vint16mf2_t *, const int16_t *, vuint8mf4_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vluxseg2ei8_v_m)))
void vluxseg2ei8(vint16mf2_t *, vint16mf2_t *, vbool32_t, vint16mf2_t, vint16mf2_t, const int16_t *, vuint8mf4_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vluxseg2ei8_v)))
void vluxseg2ei8(vint16mf4_t *, vint16mf4_t *, const int16_t *, vuint8mf8_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vluxseg2ei8_v_m)))
void vluxseg2ei8(vint16mf4_t *, vint16mf4_t *, vbool64_t, vint16mf4_t, vint16mf4_t, const int16_t *, vuint8mf8_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vluxseg2ei8_v)))
void vluxseg2ei8(vuint16m1_t *, vuint16m1_t *, const uint16_t *, vuint8mf2_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vluxseg2ei8_v_m)))
void vluxseg2ei8(vuint16m1_t *, vuint16m1_t *, vbool16_t, vuint16m1_t, vuint16m1_t, const uint16_t *, vuint8mf2_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vluxseg2ei8_v)))
void vluxseg2ei8(vuint16m2_t *, vuint16m2_t *, const uint16_t *, vuint8m1_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vluxseg2ei8_v_m)))
void vluxseg2ei8(vuint16m2_t *, vuint16m2_t *, vbool8_t, vuint16m2_t, vuint16m2_t, const uint16_t *, vuint8m1_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vluxseg2ei8_v)))
void vluxseg2ei8(vuint16m4_t *, vuint16m4_t *, const uint16_t *, vuint8m2_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vluxseg2ei8_v_m)))
void vluxseg2ei8(vuint16m4_t *, vuint16m4_t *, vbool4_t, vuint16m4_t, vuint16m4_t, const uint16_t *, vuint8m2_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vluxseg2ei8_v)))
void vluxseg2ei8(vuint16mf2_t *, vuint16mf2_t *, const uint16_t *, vuint8mf4_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vluxseg2ei8_v_m)))
void vluxseg2ei8(vuint16mf2_t *, vuint16mf2_t *, vbool32_t, vuint16mf2_t, vuint16mf2_t, const uint16_t *, vuint8mf4_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vluxseg2ei8_v)))
void vluxseg2ei8(vuint16mf4_t *, vuint16mf4_t *, const uint16_t *, vuint8mf8_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vluxseg2ei8_v_m)))
void vluxseg2ei8(vuint16mf4_t *, vuint16mf4_t *, vbool64_t, vuint16mf4_t, vuint16mf4_t, const uint16_t *, vuint8mf8_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vluxseg3ei8_v)))
void vluxseg3ei8(vint16m1_t *, vint16m1_t *, vint16m1_t *, const int16_t *, vuint8mf2_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vluxseg3ei8_v_m)))
void vluxseg3ei8(vint16m1_t *, vint16m1_t *, vint16m1_t *, vbool16_t, vint16m1_t, vint16m1_t, vint16m1_t, const int16_t *, vuint8mf2_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vluxseg3ei8_v)))
void vluxseg3ei8(vint16m2_t *, vint16m2_t *, vint16m2_t *, const int16_t *, vuint8m1_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vluxseg3ei8_v_m)))
void vluxseg3ei8(vint16m2_t *, vint16m2_t *, vint16m2_t *, vbool8_t, vint16m2_t, vint16m2_t, vint16m2_t, const int16_t *, vuint8m1_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vluxseg3ei8_v)))
void vluxseg3ei8(vint16mf2_t *, vint16mf2_t *, vint16mf2_t *, const int16_t *, vuint8mf4_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vluxseg3ei8_v_m)))
void vluxseg3ei8(vint16mf2_t *, vint16mf2_t *, vint16mf2_t *, vbool32_t, vint16mf2_t, vint16mf2_t, vint16mf2_t, const int16_t *, vuint8mf4_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vluxseg3ei8_v)))
void vluxseg3ei8(vint16mf4_t *, vint16mf4_t *, vint16mf4_t *, const int16_t *, vuint8mf8_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vluxseg3ei8_v_m)))
void vluxseg3ei8(vint16mf4_t *, vint16mf4_t *, vint16mf4_t *, vbool64_t, vint16mf4_t, vint16mf4_t, vint16mf4_t, const int16_t *, vuint8mf8_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vluxseg3ei8_v)))
void vluxseg3ei8(vuint16m1_t *, vuint16m1_t *, vuint16m1_t *, const uint16_t *, vuint8mf2_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vluxseg3ei8_v_m)))
void vluxseg3ei8(vuint16m1_t *, vuint16m1_t *, vuint16m1_t *, vbool16_t, vuint16m1_t, vuint16m1_t, vuint16m1_t, const uint16_t *, vuint8mf2_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vluxseg3ei8_v)))
void vluxseg3ei8(vuint16m2_t *, vuint16m2_t *, vuint16m2_t *, const uint16_t *, vuint8m1_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vluxseg3ei8_v_m)))
void vluxseg3ei8(vuint16m2_t *, vuint16m2_t *, vuint16m2_t *, vbool8_t, vuint16m2_t, vuint16m2_t, vuint16m2_t, const uint16_t *, vuint8m1_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vluxseg3ei8_v)))
void vluxseg3ei8(vuint16mf2_t *, vuint16mf2_t *, vuint16mf2_t *, const uint16_t *, vuint8mf4_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vluxseg3ei8_v_m)))
void vluxseg3ei8(vuint16mf2_t *, vuint16mf2_t *, vuint16mf2_t *, vbool32_t, vuint16mf2_t, vuint16mf2_t, vuint16mf2_t, const uint16_t *, vuint8mf4_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vluxseg3ei8_v)))
void vluxseg3ei8(vuint16mf4_t *, vuint16mf4_t *, vuint16mf4_t *, const uint16_t *, vuint8mf8_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vluxseg3ei8_v_m)))
void vluxseg3ei8(vuint16mf4_t *, vuint16mf4_t *, vuint16mf4_t *, vbool64_t, vuint16mf4_t, vuint16mf4_t, vuint16mf4_t, const uint16_t *, vuint8mf8_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vluxseg4ei8_v)))
void vluxseg4ei8(vint16m1_t *, vint16m1_t *, vint16m1_t *, vint16m1_t *, const int16_t *, vuint8mf2_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vluxseg4ei8_v_m)))
void vluxseg4ei8(vint16m1_t *, vint16m1_t *, vint16m1_t *, vint16m1_t *, vbool16_t, vint16m1_t, vint16m1_t, vint16m1_t, vint16m1_t, const int16_t *, vuint8mf2_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vluxseg4ei8_v)))
void vluxseg4ei8(vint16m2_t *, vint16m2_t *, vint16m2_t *, vint16m2_t *, const int16_t *, vuint8m1_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vluxseg4ei8_v_m)))
void vluxseg4ei8(vint16m2_t *, vint16m2_t *, vint16m2_t *, vint16m2_t *, vbool8_t, vint16m2_t, vint16m2_t, vint16m2_t, vint16m2_t, const int16_t *, vuint8m1_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vluxseg4ei8_v)))
void vluxseg4ei8(vint16mf2_t *, vint16mf2_t *, vint16mf2_t *, vint16mf2_t *, const int16_t *, vuint8mf4_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vluxseg4ei8_v_m)))
void vluxseg4ei8(vint16mf2_t *, vint16mf2_t *, vint16mf2_t *, vint16mf2_t *, vbool32_t, vint16mf2_t, vint16mf2_t, vint16mf2_t, vint16mf2_t, const int16_t *, vuint8mf4_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vluxseg4ei8_v)))
void vluxseg4ei8(vint16mf4_t *, vint16mf4_t *, vint16mf4_t *, vint16mf4_t *, const int16_t *, vuint8mf8_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vluxseg4ei8_v_m)))
void vluxseg4ei8(vint16mf4_t *, vint16mf4_t *, vint16mf4_t *, vint16mf4_t *, vbool64_t, vint16mf4_t, vint16mf4_t, vint16mf4_t, vint16mf4_t, const int16_t *, vuint8mf8_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vluxseg4ei8_v)))
void vluxseg4ei8(vuint16m1_t *, vuint16m1_t *, vuint16m1_t *, vuint16m1_t *, const uint16_t *, vuint8mf2_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vluxseg4ei8_v_m)))
void vluxseg4ei8(vuint16m1_t *, vuint16m1_t *, vuint16m1_t *, vuint16m1_t *, vbool16_t, vuint16m1_t, vuint16m1_t, vuint16m1_t, vuint16m1_t, const uint16_t *, vuint8mf2_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vluxseg4ei8_v)))
void vluxseg4ei8(vuint16m2_t *, vuint16m2_t *, vuint16m2_t *, vuint16m2_t *, const uint16_t *, vuint8m1_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vluxseg4ei8_v_m)))
void vluxseg4ei8(vuint16m2_t *, vuint16m2_t *, vuint16m2_t *, vuint16m2_t *, vbool8_t, vuint16m2_t, vuint16m2_t, vuint16m2_t, vuint16m2_t, const uint16_t *, vuint8m1_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vluxseg4ei8_v)))
void vluxseg4ei8(vuint16mf2_t *, vuint16mf2_t *, vuint16mf2_t *, vuint16mf2_t *, const uint16_t *, vuint8mf4_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vluxseg4ei8_v_m)))
void vluxseg4ei8(vuint16mf2_t *, vuint16mf2_t *, vuint16mf2_t *, vuint16mf2_t *, vbool32_t, vuint16mf2_t, vuint16mf2_t, vuint16mf2_t, vuint16mf2_t, const uint16_t *, vuint8mf4_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vluxseg4ei8_v)))
void vluxseg4ei8(vuint16mf4_t *, vuint16mf4_t *, vuint16mf4_t *, vuint16mf4_t *, const uint16_t *, vuint8mf8_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vluxseg4ei8_v_m)))
void vluxseg4ei8(vuint16mf4_t *, vuint16mf4_t *, vuint16mf4_t *, vuint16mf4_t *, vbool64_t, vuint16mf4_t, vuint16mf4_t, vuint16mf4_t, vuint16mf4_t, const uint16_t *, vuint8mf8_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vluxseg5ei8_v)))
void vluxseg5ei8(vint16m1_t *, vint16m1_t *, vint16m1_t *, vint16m1_t *, vint16m1_t *, const int16_t *, vuint8mf2_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vluxseg5ei8_v_m)))
void vluxseg5ei8(vint16m1_t *, vint16m1_t *, vint16m1_t *, vint16m1_t *, vint16m1_t *, vbool16_t, vint16m1_t, vint16m1_t, vint16m1_t, vint16m1_t, vint16m1_t, const int16_t *, vuint8mf2_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vluxseg5ei8_v)))
void vluxseg5ei8(vint16mf2_t *, vint16mf2_t *, vint16mf2_t *, vint16mf2_t *, vint16mf2_t *, const int16_t *, vuint8mf4_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vluxseg5ei8_v_m)))
void vluxseg5ei8(vint16mf2_t *, vint16mf2_t *, vint16mf2_t *, vint16mf2_t *, vint16mf2_t *, vbool32_t, vint16mf2_t, vint16mf2_t, vint16mf2_t, vint16mf2_t, vint16mf2_t, const int16_t *, vuint8mf4_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vluxseg5ei8_v)))
void vluxseg5ei8(vint16mf4_t *, vint16mf4_t *, vint16mf4_t *, vint16mf4_t *, vint16mf4_t *, const int16_t *, vuint8mf8_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vluxseg5ei8_v_m)))
void vluxseg5ei8(vint16mf4_t *, vint16mf4_t *, vint16mf4_t *, vint16mf4_t *, vint16mf4_t *, vbool64_t, vint16mf4_t, vint16mf4_t, vint16mf4_t, vint16mf4_t, vint16mf4_t, const int16_t *, vuint8mf8_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vluxseg5ei8_v)))
void vluxseg5ei8(vuint16m1_t *, vuint16m1_t *, vuint16m1_t *, vuint16m1_t *, vuint16m1_t *, const uint16_t *, vuint8mf2_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vluxseg5ei8_v_m)))
void vluxseg5ei8(vuint16m1_t *, vuint16m1_t *, vuint16m1_t *, vuint16m1_t *, vuint16m1_t *, vbool16_t, vuint16m1_t, vuint16m1_t, vuint16m1_t, vuint16m1_t, vuint16m1_t, const uint16_t *, vuint8mf2_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vluxseg5ei8_v)))
void vluxseg5ei8(vuint16mf2_t *, vuint16mf2_t *, vuint16mf2_t *, vuint16mf2_t *, vuint16mf2_t *, const uint16_t *, vuint8mf4_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vluxseg5ei8_v_m)))
void vluxseg5ei8(vuint16mf2_t *, vuint16mf2_t *, vuint16mf2_t *, vuint16mf2_t *, vuint16mf2_t *, vbool32_t, vuint16mf2_t, vuint16mf2_t, vuint16mf2_t, vuint16mf2_t, vuint16mf2_t, const uint16_t *, vuint8mf4_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vluxseg5ei8_v)))
void vluxseg5ei8(vuint16mf4_t *, vuint16mf4_t *, vuint16mf4_t *, vuint16mf4_t *, vuint16mf4_t *, const uint16_t *, vuint8mf8_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vluxseg5ei8_v_m)))
void vluxseg5ei8(vuint16mf4_t *, vuint16mf4_t *, vuint16mf4_t *, vuint16mf4_t *, vuint16mf4_t *, vbool64_t, vuint16mf4_t, vuint16mf4_t, vuint16mf4_t, vuint16mf4_t, vuint16mf4_t, const uint16_t *, vuint8mf8_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vluxseg6ei8_v)))
void vluxseg6ei8(vint16m1_t *, vint16m1_t *, vint16m1_t *, vint16m1_t *, vint16m1_t *, vint16m1_t *, const int16_t *, vuint8mf2_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vluxseg6ei8_v_m)))
void vluxseg6ei8(vint16m1_t *, vint16m1_t *, vint16m1_t *, vint16m1_t *, vint16m1_t *, vint16m1_t *, vbool16_t, vint16m1_t, vint16m1_t, vint16m1_t, vint16m1_t, vint16m1_t, vint16m1_t, const int16_t *, vuint8mf2_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vluxseg6ei8_v)))
void vluxseg6ei8(vint16mf2_t *, vint16mf2_t *, vint16mf2_t *, vint16mf2_t *, vint16mf2_t *, vint16mf2_t *, const int16_t *, vuint8mf4_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vluxseg6ei8_v_m)))
void vluxseg6ei8(vint16mf2_t *, vint16mf2_t *, vint16mf2_t *, vint16mf2_t *, vint16mf2_t *, vint16mf2_t *, vbool32_t, vint16mf2_t, vint16mf2_t, vint16mf2_t, vint16mf2_t, vint16mf2_t, vint16mf2_t, const int16_t *, vuint8mf4_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vluxseg6ei8_v)))
void vluxseg6ei8(vint16mf4_t *, vint16mf4_t *, vint16mf4_t *, vint16mf4_t *, vint16mf4_t *, vint16mf4_t *, const int16_t *, vuint8mf8_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vluxseg6ei8_v_m)))
void vluxseg6ei8(vint16mf4_t *, vint16mf4_t *, vint16mf4_t *, vint16mf4_t *, vint16mf4_t *, vint16mf4_t *, vbool64_t, vint16mf4_t, vint16mf4_t, vint16mf4_t, vint16mf4_t, vint16mf4_t, vint16mf4_t, const int16_t *, vuint8mf8_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vluxseg6ei8_v)))
void vluxseg6ei8(vuint16m1_t *, vuint16m1_t *, vuint16m1_t *, vuint16m1_t *, vuint16m1_t *, vuint16m1_t *, const uint16_t *, vuint8mf2_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vluxseg6ei8_v_m)))
void vluxseg6ei8(vuint16m1_t *, vuint16m1_t *, vuint16m1_t *, vuint16m1_t *, vuint16m1_t *, vuint16m1_t *, vbool16_t, vuint16m1_t, vuint16m1_t, vuint16m1_t, vuint16m1_t, vuint16m1_t, vuint16m1_t, const uint16_t *, vuint8mf2_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vluxseg6ei8_v)))
void vluxseg6ei8(vuint16mf2_t *, vuint16mf2_t *, vuint16mf2_t *, vuint16mf2_t *, vuint16mf2_t *, vuint16mf2_t *, const uint16_t *, vuint8mf4_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vluxseg6ei8_v_m)))
void vluxseg6ei8(vuint16mf2_t *, vuint16mf2_t *, vuint16mf2_t *, vuint16mf2_t *, vuint16mf2_t *, vuint16mf2_t *, vbool32_t, vuint16mf2_t, vuint16mf2_t, vuint16mf2_t, vuint16mf2_t, vuint16mf2_t, vuint16mf2_t, const uint16_t *, vuint8mf4_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vluxseg6ei8_v)))
void vluxseg6ei8(vuint16mf4_t *, vuint16mf4_t *, vuint16mf4_t *, vuint16mf4_t *, vuint16mf4_t *, vuint16mf4_t *, const uint16_t *, vuint8mf8_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vluxseg6ei8_v_m)))
void vluxseg6ei8(vuint16mf4_t *, vuint16mf4_t *, vuint16mf4_t *, vuint16mf4_t *, vuint16mf4_t *, vuint16mf4_t *, vbool64_t, vuint16mf4_t, vuint16mf4_t, vuint16mf4_t, vuint16mf4_t, vuint16mf4_t, vuint16mf4_t, const uint16_t *, vuint8mf8_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vluxseg7ei8_v)))
void vluxseg7ei8(vint16m1_t *, vint16m1_t *, vint16m1_t *, vint16m1_t *, vint16m1_t *, vint16m1_t *, vint16m1_t *, const int16_t *, vuint8mf2_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vluxseg7ei8_v_m)))
void vluxseg7ei8(vint16m1_t *, vint16m1_t *, vint16m1_t *, vint16m1_t *, vint16m1_t *, vint16m1_t *, vint16m1_t *, vbool16_t, vint16m1_t, vint16m1_t, vint16m1_t, vint16m1_t, vint16m1_t, vint16m1_t, vint16m1_t, const int16_t *, vuint8mf2_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vluxseg7ei8_v)))
void vluxseg7ei8(vint16mf2_t *, vint16mf2_t *, vint16mf2_t *, vint16mf2_t *, vint16mf2_t *, vint16mf2_t *, vint16mf2_t *, const int16_t *, vuint8mf4_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vluxseg7ei8_v_m)))
void vluxseg7ei8(vint16mf2_t *, vint16mf2_t *, vint16mf2_t *, vint16mf2_t *, vint16mf2_t *, vint16mf2_t *, vint16mf2_t *, vbool32_t, vint16mf2_t, vint16mf2_t, vint16mf2_t, vint16mf2_t, vint16mf2_t, vint16mf2_t, vint16mf2_t, const int16_t *, vuint8mf4_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vluxseg7ei8_v)))
void vluxseg7ei8(vint16mf4_t *, vint16mf4_t *, vint16mf4_t *, vint16mf4_t *, vint16mf4_t *, vint16mf4_t *, vint16mf4_t *, const int16_t *, vuint8mf8_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vluxseg7ei8_v_m)))
void vluxseg7ei8(vint16mf4_t *, vint16mf4_t *, vint16mf4_t *, vint16mf4_t *, vint16mf4_t *, vint16mf4_t *, vint16mf4_t *, vbool64_t, vint16mf4_t, vint16mf4_t, vint16mf4_t, vint16mf4_t, vint16mf4_t, vint16mf4_t, vint16mf4_t, const int16_t *, vuint8mf8_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vluxseg7ei8_v)))
void vluxseg7ei8(vuint16m1_t *, vuint16m1_t *, vuint16m1_t *, vuint16m1_t *, vuint16m1_t *, vuint16m1_t *, vuint16m1_t *, const uint16_t *, vuint8mf2_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vluxseg7ei8_v_m)))
void vluxseg7ei8(vuint16m1_t *, vuint16m1_t *, vuint16m1_t *, vuint16m1_t *, vuint16m1_t *, vuint16m1_t *, vuint16m1_t *, vbool16_t, vuint16m1_t, vuint16m1_t, vuint16m1_t, vuint16m1_t, vuint16m1_t, vuint16m1_t, vuint16m1_t, const uint16_t *, vuint8mf2_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vluxseg7ei8_v)))
void vluxseg7ei8(vuint16mf2_t *, vuint16mf2_t *, vuint16mf2_t *, vuint16mf2_t *, vuint16mf2_t *, vuint16mf2_t *, vuint16mf2_t *, const uint16_t *, vuint8mf4_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vluxseg7ei8_v_m)))
void vluxseg7ei8(vuint16mf2_t *, vuint16mf2_t *, vuint16mf2_t *, vuint16mf2_t *, vuint16mf2_t *, vuint16mf2_t *, vuint16mf2_t *, vbool32_t, vuint16mf2_t, vuint16mf2_t, vuint16mf2_t, vuint16mf2_t, vuint16mf2_t, vuint16mf2_t, vuint16mf2_t, const uint16_t *, vuint8mf4_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vluxseg7ei8_v)))
void vluxseg7ei8(vuint16mf4_t *, vuint16mf4_t *, vuint16mf4_t *, vuint16mf4_t *, vuint16mf4_t *, vuint16mf4_t *, vuint16mf4_t *, const uint16_t *, vuint8mf8_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vluxseg7ei8_v_m)))
void vluxseg7ei8(vuint16mf4_t *, vuint16mf4_t *, vuint16mf4_t *, vuint16mf4_t *, vuint16mf4_t *, vuint16mf4_t *, vuint16mf4_t *, vbool64_t, vuint16mf4_t, vuint16mf4_t, vuint16mf4_t, vuint16mf4_t, vuint16mf4_t, vuint16mf4_t, vuint16mf4_t, const uint16_t *, vuint8mf8_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vluxseg8ei8_v)))
void vluxseg8ei8(vint16m1_t *, vint16m1_t *, vint16m1_t *, vint16m1_t *, vint16m1_t *, vint16m1_t *, vint16m1_t *, vint16m1_t *, const int16_t *, vuint8mf2_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vluxseg8ei8_v_m)))
void vluxseg8ei8(vint16m1_t *, vint16m1_t *, vint16m1_t *, vint16m1_t *, vint16m1_t *, vint16m1_t *, vint16m1_t *, vint16m1_t *, vbool16_t, vint16m1_t, vint16m1_t, vint16m1_t, vint16m1_t, vint16m1_t, vint16m1_t, vint16m1_t, vint16m1_t, const int16_t *, vuint8mf2_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vluxseg8ei8_v)))
void vluxseg8ei8(vint16mf2_t *, vint16mf2_t *, vint16mf2_t *, vint16mf2_t *, vint16mf2_t *, vint16mf2_t *, vint16mf2_t *, vint16mf2_t *, const int16_t *, vuint8mf4_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vluxseg8ei8_v_m)))
void vluxseg8ei8(vint16mf2_t *, vint16mf2_t *, vint16mf2_t *, vint16mf2_t *, vint16mf2_t *, vint16mf2_t *, vint16mf2_t *, vint16mf2_t *, vbool32_t, vint16mf2_t, vint16mf2_t, vint16mf2_t, vint16mf2_t, vint16mf2_t, vint16mf2_t, vint16mf2_t, vint16mf2_t, const int16_t *, vuint8mf4_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vluxseg8ei8_v)))
void vluxseg8ei8(vint16mf4_t *, vint16mf4_t *, vint16mf4_t *, vint16mf4_t *, vint16mf4_t *, vint16mf4_t *, vint16mf4_t *, vint16mf4_t *, const int16_t *, vuint8mf8_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vluxseg8ei8_v_m)))
void vluxseg8ei8(vint16mf4_t *, vint16mf4_t *, vint16mf4_t *, vint16mf4_t *, vint16mf4_t *, vint16mf4_t *, vint16mf4_t *, vint16mf4_t *, vbool64_t, vint16mf4_t, vint16mf4_t, vint16mf4_t, vint16mf4_t, vint16mf4_t, vint16mf4_t, vint16mf4_t, vint16mf4_t, const int16_t *, vuint8mf8_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vluxseg8ei8_v)))
void vluxseg8ei8(vuint16m1_t *, vuint16m1_t *, vuint16m1_t *, vuint16m1_t *, vuint16m1_t *, vuint16m1_t *, vuint16m1_t *, vuint16m1_t *, const uint16_t *, vuint8mf2_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vluxseg8ei8_v_m)))
void vluxseg8ei8(vuint16m1_t *, vuint16m1_t *, vuint16m1_t *, vuint16m1_t *, vuint16m1_t *, vuint16m1_t *, vuint16m1_t *, vuint16m1_t *, vbool16_t, vuint16m1_t, vuint16m1_t, vuint16m1_t, vuint16m1_t, vuint16m1_t, vuint16m1_t, vuint16m1_t, vuint16m1_t, const uint16_t *, vuint8mf2_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vluxseg8ei8_v)))
void vluxseg8ei8(vuint16mf2_t *, vuint16mf2_t *, vuint16mf2_t *, vuint16mf2_t *, vuint16mf2_t *, vuint16mf2_t *, vuint16mf2_t *, vuint16mf2_t *, const uint16_t *, vuint8mf4_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vluxseg8ei8_v_m)))
void vluxseg8ei8(vuint16mf2_t *, vuint16mf2_t *, vuint16mf2_t *, vuint16mf2_t *, vuint16mf2_t *, vuint16mf2_t *, vuint16mf2_t *, vuint16mf2_t *, vbool32_t, vuint16mf2_t, vuint16mf2_t, vuint16mf2_t, vuint16mf2_t, vuint16mf2_t, vuint16mf2_t, vuint16mf2_t, vuint16mf2_t, const uint16_t *, vuint8mf4_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vluxseg8ei8_v)))
void vluxseg8ei8(vuint16mf4_t *, vuint16mf4_t *, vuint16mf4_t *, vuint16mf4_t *, vuint16mf4_t *, vuint16mf4_t *, vuint16mf4_t *, vuint16mf4_t *, const uint16_t *, vuint8mf8_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vluxseg8ei8_v_m)))
void vluxseg8ei8(vuint16mf4_t *, vuint16mf4_t *, vuint16mf4_t *, vuint16mf4_t *, vuint16mf4_t *, vuint16mf4_t *, vuint16mf4_t *, vuint16mf4_t *, vbool64_t, vuint16mf4_t, vuint16mf4_t, vuint16mf4_t, vuint16mf4_t, vuint16mf4_t, vuint16mf4_t, vuint16mf4_t, vuint16mf4_t, const uint16_t *, vuint8mf8_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vluxseg2ei16_v)))
void vluxseg2ei16(vint16m1_t *, vint16m1_t *, const int16_t *, vuint16m1_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vluxseg2ei16_v_m)))
void vluxseg2ei16(vint16m1_t *, vint16m1_t *, vbool16_t, vint16m1_t, vint16m1_t, const int16_t *, vuint16m1_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vluxseg2ei16_v)))
void vluxseg2ei16(vint16m2_t *, vint16m2_t *, const int16_t *, vuint16m2_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vluxseg2ei16_v_m)))
void vluxseg2ei16(vint16m2_t *, vint16m2_t *, vbool8_t, vint16m2_t, vint16m2_t, const int16_t *, vuint16m2_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vluxseg2ei16_v)))
void vluxseg2ei16(vint16m4_t *, vint16m4_t *, const int16_t *, vuint16m4_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vluxseg2ei16_v_m)))
void vluxseg2ei16(vint16m4_t *, vint16m4_t *, vbool4_t, vint16m4_t, vint16m4_t, const int16_t *, vuint16m4_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vluxseg2ei16_v)))
void vluxseg2ei16(vint16mf2_t *, vint16mf2_t *, const int16_t *, vuint16mf2_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vluxseg2ei16_v_m)))
void vluxseg2ei16(vint16mf2_t *, vint16mf2_t *, vbool32_t, vint16mf2_t, vint16mf2_t, const int16_t *, vuint16mf2_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vluxseg2ei16_v)))
void vluxseg2ei16(vint16mf4_t *, vint16mf4_t *, const int16_t *, vuint16mf4_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vluxseg2ei16_v_m)))
void vluxseg2ei16(vint16mf4_t *, vint16mf4_t *, vbool64_t, vint16mf4_t, vint16mf4_t, const int16_t *, vuint16mf4_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vluxseg2ei16_v)))
void vluxseg2ei16(vuint16m1_t *, vuint16m1_t *, const uint16_t *, vuint16m1_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vluxseg2ei16_v_m)))
void vluxseg2ei16(vuint16m1_t *, vuint16m1_t *, vbool16_t, vuint16m1_t, vuint16m1_t, const uint16_t *, vuint16m1_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vluxseg2ei16_v)))
void vluxseg2ei16(vuint16m2_t *, vuint16m2_t *, const uint16_t *, vuint16m2_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vluxseg2ei16_v_m)))
void vluxseg2ei16(vuint16m2_t *, vuint16m2_t *, vbool8_t, vuint16m2_t, vuint16m2_t, const uint16_t *, vuint16m2_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vluxseg2ei16_v)))
void vluxseg2ei16(vuint16m4_t *, vuint16m4_t *, const uint16_t *, vuint16m4_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vluxseg2ei16_v_m)))
void vluxseg2ei16(vuint16m4_t *, vuint16m4_t *, vbool4_t, vuint16m4_t, vuint16m4_t, const uint16_t *, vuint16m4_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vluxseg2ei16_v)))
void vluxseg2ei16(vuint16mf2_t *, vuint16mf2_t *, const uint16_t *, vuint16mf2_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vluxseg2ei16_v_m)))
void vluxseg2ei16(vuint16mf2_t *, vuint16mf2_t *, vbool32_t, vuint16mf2_t, vuint16mf2_t, const uint16_t *, vuint16mf2_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vluxseg2ei16_v)))
void vluxseg2ei16(vuint16mf4_t *, vuint16mf4_t *, const uint16_t *, vuint16mf4_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vluxseg2ei16_v_m)))
void vluxseg2ei16(vuint16mf4_t *, vuint16mf4_t *, vbool64_t, vuint16mf4_t, vuint16mf4_t, const uint16_t *, vuint16mf4_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vluxseg3ei16_v)))
void vluxseg3ei16(vint16m1_t *, vint16m1_t *, vint16m1_t *, const int16_t *, vuint16m1_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vluxseg3ei16_v_m)))
void vluxseg3ei16(vint16m1_t *, vint16m1_t *, vint16m1_t *, vbool16_t, vint16m1_t, vint16m1_t, vint16m1_t, const int16_t *, vuint16m1_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vluxseg3ei16_v)))
void vluxseg3ei16(vint16m2_t *, vint16m2_t *, vint16m2_t *, const int16_t *, vuint16m2_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vluxseg3ei16_v_m)))
void vluxseg3ei16(vint16m2_t *, vint16m2_t *, vint16m2_t *, vbool8_t, vint16m2_t, vint16m2_t, vint16m2_t, const int16_t *, vuint16m2_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vluxseg3ei16_v)))
void vluxseg3ei16(vint16mf2_t *, vint16mf2_t *, vint16mf2_t *, const int16_t *, vuint16mf2_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vluxseg3ei16_v_m)))
void vluxseg3ei16(vint16mf2_t *, vint16mf2_t *, vint16mf2_t *, vbool32_t, vint16mf2_t, vint16mf2_t, vint16mf2_t, const int16_t *, vuint16mf2_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vluxseg3ei16_v)))
void vluxseg3ei16(vint16mf4_t *, vint16mf4_t *, vint16mf4_t *, const int16_t *, vuint16mf4_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vluxseg3ei16_v_m)))
void vluxseg3ei16(vint16mf4_t *, vint16mf4_t *, vint16mf4_t *, vbool64_t, vint16mf4_t, vint16mf4_t, vint16mf4_t, const int16_t *, vuint16mf4_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vluxseg3ei16_v)))
void vluxseg3ei16(vuint16m1_t *, vuint16m1_t *, vuint16m1_t *, const uint16_t *, vuint16m1_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vluxseg3ei16_v_m)))
void vluxseg3ei16(vuint16m1_t *, vuint16m1_t *, vuint16m1_t *, vbool16_t, vuint16m1_t, vuint16m1_t, vuint16m1_t, const uint16_t *, vuint16m1_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vluxseg3ei16_v)))
void vluxseg3ei16(vuint16m2_t *, vuint16m2_t *, vuint16m2_t *, const uint16_t *, vuint16m2_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vluxseg3ei16_v_m)))
void vluxseg3ei16(vuint16m2_t *, vuint16m2_t *, vuint16m2_t *, vbool8_t, vuint16m2_t, vuint16m2_t, vuint16m2_t, const uint16_t *, vuint16m2_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vluxseg3ei16_v)))
void vluxseg3ei16(vuint16mf2_t *, vuint16mf2_t *, vuint16mf2_t *, const uint16_t *, vuint16mf2_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vluxseg3ei16_v_m)))
void vluxseg3ei16(vuint16mf2_t *, vuint16mf2_t *, vuint16mf2_t *, vbool32_t, vuint16mf2_t, vuint16mf2_t, vuint16mf2_t, const uint16_t *, vuint16mf2_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vluxseg3ei16_v)))
void vluxseg3ei16(vuint16mf4_t *, vuint16mf4_t *, vuint16mf4_t *, const uint16_t *, vuint16mf4_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vluxseg3ei16_v_m)))
void vluxseg3ei16(vuint16mf4_t *, vuint16mf4_t *, vuint16mf4_t *, vbool64_t, vuint16mf4_t, vuint16mf4_t, vuint16mf4_t, const uint16_t *, vuint16mf4_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vluxseg4ei16_v)))
void vluxseg4ei16(vint16m1_t *, vint16m1_t *, vint16m1_t *, vint16m1_t *, const int16_t *, vuint16m1_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vluxseg4ei16_v_m)))
void vluxseg4ei16(vint16m1_t *, vint16m1_t *, vint16m1_t *, vint16m1_t *, vbool16_t, vint16m1_t, vint16m1_t, vint16m1_t, vint16m1_t, const int16_t *, vuint16m1_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vluxseg4ei16_v)))
void vluxseg4ei16(vint16m2_t *, vint16m2_t *, vint16m2_t *, vint16m2_t *, const int16_t *, vuint16m2_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vluxseg4ei16_v_m)))
void vluxseg4ei16(vint16m2_t *, vint16m2_t *, vint16m2_t *, vint16m2_t *, vbool8_t, vint16m2_t, vint16m2_t, vint16m2_t, vint16m2_t, const int16_t *, vuint16m2_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vluxseg4ei16_v)))
void vluxseg4ei16(vint16mf2_t *, vint16mf2_t *, vint16mf2_t *, vint16mf2_t *, const int16_t *, vuint16mf2_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vluxseg4ei16_v_m)))
void vluxseg4ei16(vint16mf2_t *, vint16mf2_t *, vint16mf2_t *, vint16mf2_t *, vbool32_t, vint16mf2_t, vint16mf2_t, vint16mf2_t, vint16mf2_t, const int16_t *, vuint16mf2_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vluxseg4ei16_v)))
void vluxseg4ei16(vint16mf4_t *, vint16mf4_t *, vint16mf4_t *, vint16mf4_t *, const int16_t *, vuint16mf4_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vluxseg4ei16_v_m)))
void vluxseg4ei16(vint16mf4_t *, vint16mf4_t *, vint16mf4_t *, vint16mf4_t *, vbool64_t, vint16mf4_t, vint16mf4_t, vint16mf4_t, vint16mf4_t, const int16_t *, vuint16mf4_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vluxseg4ei16_v)))
void vluxseg4ei16(vuint16m1_t *, vuint16m1_t *, vuint16m1_t *, vuint16m1_t *, const uint16_t *, vuint16m1_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vluxseg4ei16_v_m)))
void vluxseg4ei16(vuint16m1_t *, vuint16m1_t *, vuint16m1_t *, vuint16m1_t *, vbool16_t, vuint16m1_t, vuint16m1_t, vuint16m1_t, vuint16m1_t, const uint16_t *, vuint16m1_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vluxseg4ei16_v)))
void vluxseg4ei16(vuint16m2_t *, vuint16m2_t *, vuint16m2_t *, vuint16m2_t *, const uint16_t *, vuint16m2_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vluxseg4ei16_v_m)))
void vluxseg4ei16(vuint16m2_t *, vuint16m2_t *, vuint16m2_t *, vuint16m2_t *, vbool8_t, vuint16m2_t, vuint16m2_t, vuint16m2_t, vuint16m2_t, const uint16_t *, vuint16m2_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vluxseg4ei16_v)))
void vluxseg4ei16(vuint16mf2_t *, vuint16mf2_t *, vuint16mf2_t *, vuint16mf2_t *, const uint16_t *, vuint16mf2_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vluxseg4ei16_v_m)))
void vluxseg4ei16(vuint16mf2_t *, vuint16mf2_t *, vuint16mf2_t *, vuint16mf2_t *, vbool32_t, vuint16mf2_t, vuint16mf2_t, vuint16mf2_t, vuint16mf2_t, const uint16_t *, vuint16mf2_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vluxseg4ei16_v)))
void vluxseg4ei16(vuint16mf4_t *, vuint16mf4_t *, vuint16mf4_t *, vuint16mf4_t *, const uint16_t *, vuint16mf4_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vluxseg4ei16_v_m)))
void vluxseg4ei16(vuint16mf4_t *, vuint16mf4_t *, vuint16mf4_t *, vuint16mf4_t *, vbool64_t, vuint16mf4_t, vuint16mf4_t, vuint16mf4_t, vuint16mf4_t, const uint16_t *, vuint16mf4_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vluxseg5ei16_v)))
void vluxseg5ei16(vint16m1_t *, vint16m1_t *, vint16m1_t *, vint16m1_t *, vint16m1_t *, const int16_t *, vuint16m1_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vluxseg5ei16_v_m)))
void vluxseg5ei16(vint16m1_t *, vint16m1_t *, vint16m1_t *, vint16m1_t *, vint16m1_t *, vbool16_t, vint16m1_t, vint16m1_t, vint16m1_t, vint16m1_t, vint16m1_t, const int16_t *, vuint16m1_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vluxseg5ei16_v)))
void vluxseg5ei16(vint16mf2_t *, vint16mf2_t *, vint16mf2_t *, vint16mf2_t *, vint16mf2_t *, const int16_t *, vuint16mf2_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vluxseg5ei16_v_m)))
void vluxseg5ei16(vint16mf2_t *, vint16mf2_t *, vint16mf2_t *, vint16mf2_t *, vint16mf2_t *, vbool32_t, vint16mf2_t, vint16mf2_t, vint16mf2_t, vint16mf2_t, vint16mf2_t, const int16_t *, vuint16mf2_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vluxseg5ei16_v)))
void vluxseg5ei16(vint16mf4_t *, vint16mf4_t *, vint16mf4_t *, vint16mf4_t *, vint16mf4_t *, const int16_t *, vuint16mf4_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vluxseg5ei16_v_m)))
void vluxseg5ei16(vint16mf4_t *, vint16mf4_t *, vint16mf4_t *, vint16mf4_t *, vint16mf4_t *, vbool64_t, vint16mf4_t, vint16mf4_t, vint16mf4_t, vint16mf4_t, vint16mf4_t, const int16_t *, vuint16mf4_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vluxseg5ei16_v)))
void vluxseg5ei16(vuint16m1_t *, vuint16m1_t *, vuint16m1_t *, vuint16m1_t *, vuint16m1_t *, const uint16_t *, vuint16m1_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vluxseg5ei16_v_m)))
void vluxseg5ei16(vuint16m1_t *, vuint16m1_t *, vuint16m1_t *, vuint16m1_t *, vuint16m1_t *, vbool16_t, vuint16m1_t, vuint16m1_t, vuint16m1_t, vuint16m1_t, vuint16m1_t, const uint16_t *, vuint16m1_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vluxseg5ei16_v)))
void vluxseg5ei16(vuint16mf2_t *, vuint16mf2_t *, vuint16mf2_t *, vuint16mf2_t *, vuint16mf2_t *, const uint16_t *, vuint16mf2_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vluxseg5ei16_v_m)))
void vluxseg5ei16(vuint16mf2_t *, vuint16mf2_t *, vuint16mf2_t *, vuint16mf2_t *, vuint16mf2_t *, vbool32_t, vuint16mf2_t, vuint16mf2_t, vuint16mf2_t, vuint16mf2_t, vuint16mf2_t, const uint16_t *, vuint16mf2_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vluxseg5ei16_v)))
void vluxseg5ei16(vuint16mf4_t *, vuint16mf4_t *, vuint16mf4_t *, vuint16mf4_t *, vuint16mf4_t *, const uint16_t *, vuint16mf4_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vluxseg5ei16_v_m)))
void vluxseg5ei16(vuint16mf4_t *, vuint16mf4_t *, vuint16mf4_t *, vuint16mf4_t *, vuint16mf4_t *, vbool64_t, vuint16mf4_t, vuint16mf4_t, vuint16mf4_t, vuint16mf4_t, vuint16mf4_t, const uint16_t *, vuint16mf4_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vluxseg6ei16_v)))
void vluxseg6ei16(vint16m1_t *, vint16m1_t *, vint16m1_t *, vint16m1_t *, vint16m1_t *, vint16m1_t *, const int16_t *, vuint16m1_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vluxseg6ei16_v_m)))
void vluxseg6ei16(vint16m1_t *, vint16m1_t *, vint16m1_t *, vint16m1_t *, vint16m1_t *, vint16m1_t *, vbool16_t, vint16m1_t, vint16m1_t, vint16m1_t, vint16m1_t, vint16m1_t, vint16m1_t, const int16_t *, vuint16m1_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vluxseg6ei16_v)))
void vluxseg6ei16(vint16mf2_t *, vint16mf2_t *, vint16mf2_t *, vint16mf2_t *, vint16mf2_t *, vint16mf2_t *, const int16_t *, vuint16mf2_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vluxseg6ei16_v_m)))
void vluxseg6ei16(vint16mf2_t *, vint16mf2_t *, vint16mf2_t *, vint16mf2_t *, vint16mf2_t *, vint16mf2_t *, vbool32_t, vint16mf2_t, vint16mf2_t, vint16mf2_t, vint16mf2_t, vint16mf2_t, vint16mf2_t, const int16_t *, vuint16mf2_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vluxseg6ei16_v)))
void vluxseg6ei16(vint16mf4_t *, vint16mf4_t *, vint16mf4_t *, vint16mf4_t *, vint16mf4_t *, vint16mf4_t *, const int16_t *, vuint16mf4_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vluxseg6ei16_v_m)))
void vluxseg6ei16(vint16mf4_t *, vint16mf4_t *, vint16mf4_t *, vint16mf4_t *, vint16mf4_t *, vint16mf4_t *, vbool64_t, vint16mf4_t, vint16mf4_t, vint16mf4_t, vint16mf4_t, vint16mf4_t, vint16mf4_t, const int16_t *, vuint16mf4_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vle8ff_v_m)))
vuint8m1_t vle8ff(vbool8_t, vuint8m1_t, const uint8_t *, size_t *, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vle8ff_v_m)))
vuint8m2_t vle8ff(vbool4_t, vuint8m2_t, const uint8_t *, size_t *, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vle8ff_v_m)))
vuint8m4_t vle8ff(vbool2_t, vuint8m4_t, const uint8_t *, size_t *, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vle8ff_v_m)))
vuint8m8_t vle8ff(vbool1_t, vuint8m8_t, const uint8_t *, size_t *, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vle8ff_v_m)))
vuint8mf2_t vle8ff(vbool16_t, vuint8mf2_t, const uint8_t *, size_t *, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vle8ff_v_m)))
vuint8mf4_t vle8ff(vbool32_t, vuint8mf4_t, const uint8_t *, size_t *, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vle8ff_v_m)))
vuint8mf8_t vle8ff(vbool64_t, vuint8mf8_t, const uint8_t *, size_t *, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vluxseg6ei16_v)))
void vluxseg6ei16(vuint16m1_t *, vuint16m1_t *, vuint16m1_t *, vuint16m1_t *, vuint16m1_t *, vuint16m1_t *, const uint16_t *, vuint16m1_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vluxseg6ei16_v_m)))
void vluxseg6ei16(vuint16m1_t *, vuint16m1_t *, vuint16m1_t *, vuint16m1_t *, vuint16m1_t *, vuint16m1_t *, vbool16_t, vuint16m1_t, vuint16m1_t, vuint16m1_t, vuint16m1_t, vuint16m1_t, vuint16m1_t, const uint16_t *, vuint16m1_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vluxseg6ei16_v)))
void vluxseg6ei16(vuint16mf2_t *, vuint16mf2_t *, vuint16mf2_t *, vuint16mf2_t *, vuint16mf2_t *, vuint16mf2_t *, const uint16_t *, vuint16mf2_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vluxseg6ei16_v_m)))
void vluxseg6ei16(vuint16mf2_t *, vuint16mf2_t *, vuint16mf2_t *, vuint16mf2_t *, vuint16mf2_t *, vuint16mf2_t *, vbool32_t, vuint16mf2_t, vuint16mf2_t, vuint16mf2_t, vuint16mf2_t, vuint16mf2_t, vuint16mf2_t, const uint16_t *, vuint16mf2_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vluxseg6ei16_v)))
void vluxseg6ei16(vuint16mf4_t *, vuint16mf4_t *, vuint16mf4_t *, vuint16mf4_t *, vuint16mf4_t *, vuint16mf4_t *, const uint16_t *, vuint16mf4_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vluxseg6ei16_v_m)))
void vluxseg6ei16(vuint16mf4_t *, vuint16mf4_t *, vuint16mf4_t *, vuint16mf4_t *, vuint16mf4_t *, vuint16mf4_t *, vbool64_t, vuint16mf4_t, vuint16mf4_t, vuint16mf4_t, vuint16mf4_t, vuint16mf4_t, vuint16mf4_t, const uint16_t *, vuint16mf4_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vluxseg7ei16_v)))
void vluxseg7ei16(vint16m1_t *, vint16m1_t *, vint16m1_t *, vint16m1_t *, vint16m1_t *, vint16m1_t *, vint16m1_t *, const int16_t *, vuint16m1_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vluxseg7ei16_v_m)))
void vluxseg7ei16(vint16m1_t *, vint16m1_t *, vint16m1_t *, vint16m1_t *, vint16m1_t *, vint16m1_t *, vint16m1_t *, vbool16_t, vint16m1_t, vint16m1_t, vint16m1_t, vint16m1_t, vint16m1_t, vint16m1_t, vint16m1_t, const int16_t *, vuint16m1_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vluxseg7ei16_v)))
void vluxseg7ei16(vint16mf2_t *, vint16mf2_t *, vint16mf2_t *, vint16mf2_t *, vint16mf2_t *, vint16mf2_t *, vint16mf2_t *, const int16_t *, vuint16mf2_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vluxseg7ei16_v_m)))
void vluxseg7ei16(vint16mf2_t *, vint16mf2_t *, vint16mf2_t *, vint16mf2_t *, vint16mf2_t *, vint16mf2_t *, vint16mf2_t *, vbool32_t, vint16mf2_t, vint16mf2_t, vint16mf2_t, vint16mf2_t, vint16mf2_t, vint16mf2_t, vint16mf2_t, const int16_t *, vuint16mf2_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vluxseg7ei16_v)))
void vluxseg7ei16(vint16mf4_t *, vint16mf4_t *, vint16mf4_t *, vint16mf4_t *, vint16mf4_t *, vint16mf4_t *, vint16mf4_t *, const int16_t *, vuint16mf4_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vluxseg7ei16_v_m)))
void vluxseg7ei16(vint16mf4_t *, vint16mf4_t *, vint16mf4_t *, vint16mf4_t *, vint16mf4_t *, vint16mf4_t *, vint16mf4_t *, vbool64_t, vint16mf4_t, vint16mf4_t, vint16mf4_t, vint16mf4_t, vint16mf4_t, vint16mf4_t, vint16mf4_t, const int16_t *, vuint16mf4_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vluxseg7ei16_v)))
void vluxseg7ei16(vuint16m1_t *, vuint16m1_t *, vuint16m1_t *, vuint16m1_t *, vuint16m1_t *, vuint16m1_t *, vuint16m1_t *, const uint16_t *, vuint16m1_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vluxseg7ei16_v_m)))
void vluxseg7ei16(vuint16m1_t *, vuint16m1_t *, vuint16m1_t *, vuint16m1_t *, vuint16m1_t *, vuint16m1_t *, vuint16m1_t *, vbool16_t, vuint16m1_t, vuint16m1_t, vuint16m1_t, vuint16m1_t, vuint16m1_t, vuint16m1_t, vuint16m1_t, const uint16_t *, vuint16m1_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vluxseg7ei16_v)))
void vluxseg7ei16(vuint16mf2_t *, vuint16mf2_t *, vuint16mf2_t *, vuint16mf2_t *, vuint16mf2_t *, vuint16mf2_t *, vuint16mf2_t *, const uint16_t *, vuint16mf2_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vluxseg7ei16_v_m)))
void vluxseg7ei16(vuint16mf2_t *, vuint16mf2_t *, vuint16mf2_t *, vuint16mf2_t *, vuint16mf2_t *, vuint16mf2_t *, vuint16mf2_t *, vbool32_t, vuint16mf2_t, vuint16mf2_t, vuint16mf2_t, vuint16mf2_t, vuint16mf2_t, vuint16mf2_t, vuint16mf2_t, const uint16_t *, vuint16mf2_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vluxseg7ei16_v)))
void vluxseg7ei16(vuint16mf4_t *, vuint16mf4_t *, vuint16mf4_t *, vuint16mf4_t *, vuint16mf4_t *, vuint16mf4_t *, vuint16mf4_t *, const uint16_t *, vuint16mf4_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vluxseg7ei16_v_m)))
void vluxseg7ei16(vuint16mf4_t *, vuint16mf4_t *, vuint16mf4_t *, vuint16mf4_t *, vuint16mf4_t *, vuint16mf4_t *, vuint16mf4_t *, vbool64_t, vuint16mf4_t, vuint16mf4_t, vuint16mf4_t, vuint16mf4_t, vuint16mf4_t, vuint16mf4_t, vuint16mf4_t, const uint16_t *, vuint16mf4_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vluxseg8ei16_v)))
void vluxseg8ei16(vint16m1_t *, vint16m1_t *, vint16m1_t *, vint16m1_t *, vint16m1_t *, vint16m1_t *, vint16m1_t *, vint16m1_t *, const int16_t *, vuint16m1_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vluxseg8ei16_v_m)))
void vluxseg8ei16(vint16m1_t *, vint16m1_t *, vint16m1_t *, vint16m1_t *, vint16m1_t *, vint16m1_t *, vint16m1_t *, vint16m1_t *, vbool16_t, vint16m1_t, vint16m1_t, vint16m1_t, vint16m1_t, vint16m1_t, vint16m1_t, vint16m1_t, vint16m1_t, const int16_t *, vuint16m1_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vluxseg8ei16_v)))
void vluxseg8ei16(vint16mf2_t *, vint16mf2_t *, vint16mf2_t *, vint16mf2_t *, vint16mf2_t *, vint16mf2_t *, vint16mf2_t *, vint16mf2_t *, const int16_t *, vuint16mf2_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vluxseg8ei16_v_m)))
void vluxseg8ei16(vint16mf2_t *, vint16mf2_t *, vint16mf2_t *, vint16mf2_t *, vint16mf2_t *, vint16mf2_t *, vint16mf2_t *, vint16mf2_t *, vbool32_t, vint16mf2_t, vint16mf2_t, vint16mf2_t, vint16mf2_t, vint16mf2_t, vint16mf2_t, vint16mf2_t, vint16mf2_t, const int16_t *, vuint16mf2_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vluxseg8ei16_v)))
void vluxseg8ei16(vint16mf4_t *, vint16mf4_t *, vint16mf4_t *, vint16mf4_t *, vint16mf4_t *, vint16mf4_t *, vint16mf4_t *, vint16mf4_t *, const int16_t *, vuint16mf4_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vluxseg8ei16_v_m)))
void vluxseg8ei16(vint16mf4_t *, vint16mf4_t *, vint16mf4_t *, vint16mf4_t *, vint16mf4_t *, vint16mf4_t *, vint16mf4_t *, vint16mf4_t *, vbool64_t, vint16mf4_t, vint16mf4_t, vint16mf4_t, vint16mf4_t, vint16mf4_t, vint16mf4_t, vint16mf4_t, vint16mf4_t, const int16_t *, vuint16mf4_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vluxseg8ei16_v)))
void vluxseg8ei16(vuint16m1_t *, vuint16m1_t *, vuint16m1_t *, vuint16m1_t *, vuint16m1_t *, vuint16m1_t *, vuint16m1_t *, vuint16m1_t *, const uint16_t *, vuint16m1_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vluxseg8ei16_v_m)))
void vluxseg8ei16(vuint16m1_t *, vuint16m1_t *, vuint16m1_t *, vuint16m1_t *, vuint16m1_t *, vuint16m1_t *, vuint16m1_t *, vuint16m1_t *, vbool16_t, vuint16m1_t, vuint16m1_t, vuint16m1_t, vuint16m1_t, vuint16m1_t, vuint16m1_t, vuint16m1_t, vuint16m1_t, const uint16_t *, vuint16m1_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vluxseg8ei16_v)))
void vluxseg8ei16(vuint16mf2_t *, vuint16mf2_t *, vuint16mf2_t *, vuint16mf2_t *, vuint16mf2_t *, vuint16mf2_t *, vuint16mf2_t *, vuint16mf2_t *, const uint16_t *, vuint16mf2_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vluxseg8ei16_v_m)))
void vluxseg8ei16(vuint16mf2_t *, vuint16mf2_t *, vuint16mf2_t *, vuint16mf2_t *, vuint16mf2_t *, vuint16mf2_t *, vuint16mf2_t *, vuint16mf2_t *, vbool32_t, vuint16mf2_t, vuint16mf2_t, vuint16mf2_t, vuint16mf2_t, vuint16mf2_t, vuint16mf2_t, vuint16mf2_t, vuint16mf2_t, const uint16_t *, vuint16mf2_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vluxseg8ei16_v)))
void vluxseg8ei16(vuint16mf4_t *, vuint16mf4_t *, vuint16mf4_t *, vuint16mf4_t *, vuint16mf4_t *, vuint16mf4_t *, vuint16mf4_t *, vuint16mf4_t *, const uint16_t *, vuint16mf4_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vluxseg8ei16_v_m)))
void vluxseg8ei16(vuint16mf4_t *, vuint16mf4_t *, vuint16mf4_t *, vuint16mf4_t *, vuint16mf4_t *, vuint16mf4_t *, vuint16mf4_t *, vuint16mf4_t *, vbool64_t, vuint16mf4_t, vuint16mf4_t, vuint16mf4_t, vuint16mf4_t, vuint16mf4_t, vuint16mf4_t, vuint16mf4_t, vuint16mf4_t, const uint16_t *, vuint16mf4_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vluxseg2ei32_v)))
void vluxseg2ei32(vint16m1_t *, vint16m1_t *, const int16_t *, vuint32m2_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vluxseg2ei32_v_m)))
void vluxseg2ei32(vint16m1_t *, vint16m1_t *, vbool16_t, vint16m1_t, vint16m1_t, const int16_t *, vuint32m2_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vluxseg2ei32_v)))
void vluxseg2ei32(vint16m2_t *, vint16m2_t *, const int16_t *, vuint32m4_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vluxseg2ei32_v_m)))
void vluxseg2ei32(vint16m2_t *, vint16m2_t *, vbool8_t, vint16m2_t, vint16m2_t, const int16_t *, vuint32m4_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vluxseg2ei32_v)))
void vluxseg2ei32(vint16m4_t *, vint16m4_t *, const int16_t *, vuint32m8_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vluxseg2ei32_v_m)))
void vluxseg2ei32(vint16m4_t *, vint16m4_t *, vbool4_t, vint16m4_t, vint16m4_t, const int16_t *, vuint32m8_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vluxseg2ei32_v)))
void vluxseg2ei32(vint16mf2_t *, vint16mf2_t *, const int16_t *, vuint32m1_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vluxseg2ei32_v_m)))
void vluxseg2ei32(vint16mf2_t *, vint16mf2_t *, vbool32_t, vint16mf2_t, vint16mf2_t, const int16_t *, vuint32m1_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vluxseg2ei32_v)))
void vluxseg2ei32(vint16mf4_t *, vint16mf4_t *, const int16_t *, vuint32mf2_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vluxseg2ei32_v_m)))
void vluxseg2ei32(vint16mf4_t *, vint16mf4_t *, vbool64_t, vint16mf4_t, vint16mf4_t, const int16_t *, vuint32mf2_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vluxseg2ei32_v)))
void vluxseg2ei32(vuint16m1_t *, vuint16m1_t *, const uint16_t *, vuint32m2_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vluxseg2ei32_v_m)))
void vluxseg2ei32(vuint16m1_t *, vuint16m1_t *, vbool16_t, vuint16m1_t, vuint16m1_t, const uint16_t *, vuint32m2_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vluxseg2ei32_v)))
void vluxseg2ei32(vuint16m2_t *, vuint16m2_t *, const uint16_t *, vuint32m4_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vluxseg2ei32_v_m)))
void vluxseg2ei32(vuint16m2_t *, vuint16m2_t *, vbool8_t, vuint16m2_t, vuint16m2_t, const uint16_t *, vuint32m4_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vluxseg2ei32_v)))
void vluxseg2ei32(vuint16m4_t *, vuint16m4_t *, const uint16_t *, vuint32m8_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vluxseg2ei32_v_m)))
void vluxseg2ei32(vuint16m4_t *, vuint16m4_t *, vbool4_t, vuint16m4_t, vuint16m4_t, const uint16_t *, vuint32m8_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vluxseg2ei32_v)))
void vluxseg2ei32(vuint16mf2_t *, vuint16mf2_t *, const uint16_t *, vuint32m1_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vluxseg2ei32_v_m)))
void vluxseg2ei32(vuint16mf2_t *, vuint16mf2_t *, vbool32_t, vuint16mf2_t, vuint16mf2_t, const uint16_t *, vuint32m1_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vluxseg2ei32_v)))
void vluxseg2ei32(vuint16mf4_t *, vuint16mf4_t *, const uint16_t *, vuint32mf2_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vluxseg2ei32_v_m)))
void vluxseg2ei32(vuint16mf4_t *, vuint16mf4_t *, vbool64_t, vuint16mf4_t, vuint16mf4_t, const uint16_t *, vuint32mf2_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vluxseg3ei32_v)))
void vluxseg3ei32(vint16m1_t *, vint16m1_t *, vint16m1_t *, const int16_t *, vuint32m2_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vluxseg3ei32_v_m)))
void vluxseg3ei32(vint16m1_t *, vint16m1_t *, vint16m1_t *, vbool16_t, vint16m1_t, vint16m1_t, vint16m1_t, const int16_t *, vuint32m2_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vluxseg3ei32_v)))
void vluxseg3ei32(vint16m2_t *, vint16m2_t *, vint16m2_t *, const int16_t *, vuint32m4_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vluxseg3ei32_v_m)))
void vluxseg3ei32(vint16m2_t *, vint16m2_t *, vint16m2_t *, vbool8_t, vint16m2_t, vint16m2_t, vint16m2_t, const int16_t *, vuint32m4_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vluxseg3ei32_v)))
void vluxseg3ei32(vint16mf2_t *, vint16mf2_t *, vint16mf2_t *, const int16_t *, vuint32m1_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vluxseg3ei32_v_m)))
void vluxseg3ei32(vint16mf2_t *, vint16mf2_t *, vint16mf2_t *, vbool32_t, vint16mf2_t, vint16mf2_t, vint16mf2_t, const int16_t *, vuint32m1_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vluxseg3ei32_v)))
void vluxseg3ei32(vint16mf4_t *, vint16mf4_t *, vint16mf4_t *, const int16_t *, vuint32mf2_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vluxseg3ei32_v_m)))
void vluxseg3ei32(vint16mf4_t *, vint16mf4_t *, vint16mf4_t *, vbool64_t, vint16mf4_t, vint16mf4_t, vint16mf4_t, const int16_t *, vuint32mf2_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vluxseg3ei32_v)))
void vluxseg3ei32(vuint16m1_t *, vuint16m1_t *, vuint16m1_t *, const uint16_t *, vuint32m2_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vluxseg3ei32_v_m)))
void vluxseg3ei32(vuint16m1_t *, vuint16m1_t *, vuint16m1_t *, vbool16_t, vuint16m1_t, vuint16m1_t, vuint16m1_t, const uint16_t *, vuint32m2_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vluxseg3ei32_v)))
void vluxseg3ei32(vuint16m2_t *, vuint16m2_t *, vuint16m2_t *, const uint16_t *, vuint32m4_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vluxseg3ei32_v_m)))
void vluxseg3ei32(vuint16m2_t *, vuint16m2_t *, vuint16m2_t *, vbool8_t, vuint16m2_t, vuint16m2_t, vuint16m2_t, const uint16_t *, vuint32m4_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vluxseg3ei32_v)))
void vluxseg3ei32(vuint16mf2_t *, vuint16mf2_t *, vuint16mf2_t *, const uint16_t *, vuint32m1_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vluxseg3ei32_v_m)))
void vluxseg3ei32(vuint16mf2_t *, vuint16mf2_t *, vuint16mf2_t *, vbool32_t, vuint16mf2_t, vuint16mf2_t, vuint16mf2_t, const uint16_t *, vuint32m1_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vluxseg3ei32_v)))
void vluxseg3ei32(vuint16mf4_t *, vuint16mf4_t *, vuint16mf4_t *, const uint16_t *, vuint32mf2_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vluxseg3ei32_v_m)))
void vluxseg3ei32(vuint16mf4_t *, vuint16mf4_t *, vuint16mf4_t *, vbool64_t, vuint16mf4_t, vuint16mf4_t, vuint16mf4_t, const uint16_t *, vuint32mf2_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vluxseg4ei32_v)))
void vluxseg4ei32(vint16m1_t *, vint16m1_t *, vint16m1_t *, vint16m1_t *, const int16_t *, vuint32m2_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vluxseg4ei32_v_m)))
void vluxseg4ei32(vint16m1_t *, vint16m1_t *, vint16m1_t *, vint16m1_t *, vbool16_t, vint16m1_t, vint16m1_t, vint16m1_t, vint16m1_t, const int16_t *, vuint32m2_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vluxseg4ei32_v)))
void vluxseg4ei32(vint16m2_t *, vint16m2_t *, vint16m2_t *, vint16m2_t *, const int16_t *, vuint32m4_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vluxseg4ei32_v_m)))
void vluxseg4ei32(vint16m2_t *, vint16m2_t *, vint16m2_t *, vint16m2_t *, vbool8_t, vint16m2_t, vint16m2_t, vint16m2_t, vint16m2_t, const int16_t *, vuint32m4_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vluxseg4ei32_v)))
void vluxseg4ei32(vint16mf2_t *, vint16mf2_t *, vint16mf2_t *, vint16mf2_t *, const int16_t *, vuint32m1_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vluxseg4ei32_v_m)))
void vluxseg4ei32(vint16mf2_t *, vint16mf2_t *, vint16mf2_t *, vint16mf2_t *, vbool32_t, vint16mf2_t, vint16mf2_t, vint16mf2_t, vint16mf2_t, const int16_t *, vuint32m1_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vluxseg4ei32_v)))
void vluxseg4ei32(vint16mf4_t *, vint16mf4_t *, vint16mf4_t *, vint16mf4_t *, const int16_t *, vuint32mf2_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vluxseg4ei32_v_m)))
void vluxseg4ei32(vint16mf4_t *, vint16mf4_t *, vint16mf4_t *, vint16mf4_t *, vbool64_t, vint16mf4_t, vint16mf4_t, vint16mf4_t, vint16mf4_t, const int16_t *, vuint32mf2_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vluxseg4ei32_v)))
void vluxseg4ei32(vuint16m1_t *, vuint16m1_t *, vuint16m1_t *, vuint16m1_t *, const uint16_t *, vuint32m2_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vluxseg4ei32_v_m)))
void vluxseg4ei32(vuint16m1_t *, vuint16m1_t *, vuint16m1_t *, vuint16m1_t *, vbool16_t, vuint16m1_t, vuint16m1_t, vuint16m1_t, vuint16m1_t, const uint16_t *, vuint32m2_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vluxseg4ei32_v)))
void vluxseg4ei32(vuint16m2_t *, vuint16m2_t *, vuint16m2_t *, vuint16m2_t *, const uint16_t *, vuint32m4_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vluxseg4ei32_v_m)))
void vluxseg4ei32(vuint16m2_t *, vuint16m2_t *, vuint16m2_t *, vuint16m2_t *, vbool8_t, vuint16m2_t, vuint16m2_t, vuint16m2_t, vuint16m2_t, const uint16_t *, vuint32m4_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vluxseg4ei32_v)))
void vluxseg4ei32(vuint16mf2_t *, vuint16mf2_t *, vuint16mf2_t *, vuint16mf2_t *, const uint16_t *, vuint32m1_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vluxseg4ei32_v_m)))
void vluxseg4ei32(vuint16mf2_t *, vuint16mf2_t *, vuint16mf2_t *, vuint16mf2_t *, vbool32_t, vuint16mf2_t, vuint16mf2_t, vuint16mf2_t, vuint16mf2_t, const uint16_t *, vuint32m1_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vluxseg4ei32_v)))
void vluxseg4ei32(vuint16mf4_t *, vuint16mf4_t *, vuint16mf4_t *, vuint16mf4_t *, const uint16_t *, vuint32mf2_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vluxseg4ei32_v_m)))
void vluxseg4ei32(vuint16mf4_t *, vuint16mf4_t *, vuint16mf4_t *, vuint16mf4_t *, vbool64_t, vuint16mf4_t, vuint16mf4_t, vuint16mf4_t, vuint16mf4_t, const uint16_t *, vuint32mf2_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vluxseg5ei32_v)))
void vluxseg5ei32(vint16m1_t *, vint16m1_t *, vint16m1_t *, vint16m1_t *, vint16m1_t *, const int16_t *, vuint32m2_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vluxseg5ei32_v_m)))
void vluxseg5ei32(vint16m1_t *, vint16m1_t *, vint16m1_t *, vint16m1_t *, vint16m1_t *, vbool16_t, vint16m1_t, vint16m1_t, vint16m1_t, vint16m1_t, vint16m1_t, const int16_t *, vuint32m2_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vluxseg5ei32_v)))
void vluxseg5ei32(vint16mf2_t *, vint16mf2_t *, vint16mf2_t *, vint16mf2_t *, vint16mf2_t *, const int16_t *, vuint32m1_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vluxseg5ei32_v_m)))
void vluxseg5ei32(vint16mf2_t *, vint16mf2_t *, vint16mf2_t *, vint16mf2_t *, vint16mf2_t *, vbool32_t, vint16mf2_t, vint16mf2_t, vint16mf2_t, vint16mf2_t, vint16mf2_t, const int16_t *, vuint32m1_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vluxseg5ei32_v)))
void vluxseg5ei32(vint16mf4_t *, vint16mf4_t *, vint16mf4_t *, vint16mf4_t *, vint16mf4_t *, const int16_t *, vuint32mf2_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vluxseg5ei32_v_m)))
void vluxseg5ei32(vint16mf4_t *, vint16mf4_t *, vint16mf4_t *, vint16mf4_t *, vint16mf4_t *, vbool64_t, vint16mf4_t, vint16mf4_t, vint16mf4_t, vint16mf4_t, vint16mf4_t, const int16_t *, vuint32mf2_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vluxseg5ei32_v)))
void vluxseg5ei32(vuint16m1_t *, vuint16m1_t *, vuint16m1_t *, vuint16m1_t *, vuint16m1_t *, const uint16_t *, vuint32m2_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vluxseg5ei32_v_m)))
void vluxseg5ei32(vuint16m1_t *, vuint16m1_t *, vuint16m1_t *, vuint16m1_t *, vuint16m1_t *, vbool16_t, vuint16m1_t, vuint16m1_t, vuint16m1_t, vuint16m1_t, vuint16m1_t, const uint16_t *, vuint32m2_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vluxseg5ei32_v)))
void vluxseg5ei32(vuint16mf2_t *, vuint16mf2_t *, vuint16mf2_t *, vuint16mf2_t *, vuint16mf2_t *, const uint16_t *, vuint32m1_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vluxseg5ei32_v_m)))
void vluxseg5ei32(vuint16mf2_t *, vuint16mf2_t *, vuint16mf2_t *, vuint16mf2_t *, vuint16mf2_t *, vbool32_t, vuint16mf2_t, vuint16mf2_t, vuint16mf2_t, vuint16mf2_t, vuint16mf2_t, const uint16_t *, vuint32m1_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vluxseg5ei32_v)))
void vluxseg5ei32(vuint16mf4_t *, vuint16mf4_t *, vuint16mf4_t *, vuint16mf4_t *, vuint16mf4_t *, const uint16_t *, vuint32mf2_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vluxseg5ei32_v_m)))
void vluxseg5ei32(vuint16mf4_t *, vuint16mf4_t *, vuint16mf4_t *, vuint16mf4_t *, vuint16mf4_t *, vbool64_t, vuint16mf4_t, vuint16mf4_t, vuint16mf4_t, vuint16mf4_t, vuint16mf4_t, const uint16_t *, vuint32mf2_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vluxseg6ei32_v)))
void vluxseg6ei32(vint16m1_t *, vint16m1_t *, vint16m1_t *, vint16m1_t *, vint16m1_t *, vint16m1_t *, const int16_t *, vuint32m2_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vluxseg6ei32_v_m)))
void vluxseg6ei32(vint16m1_t *, vint16m1_t *, vint16m1_t *, vint16m1_t *, vint16m1_t *, vint16m1_t *, vbool16_t, vint16m1_t, vint16m1_t, vint16m1_t, vint16m1_t, vint16m1_t, vint16m1_t, const int16_t *, vuint32m2_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vluxseg6ei32_v)))
void vluxseg6ei32(vint16mf2_t *, vint16mf2_t *, vint16mf2_t *, vint16mf2_t *, vint16mf2_t *, vint16mf2_t *, const int16_t *, vuint32m1_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vluxseg6ei32_v_m)))
void vluxseg6ei32(vint16mf2_t *, vint16mf2_t *, vint16mf2_t *, vint16mf2_t *, vint16mf2_t *, vint16mf2_t *, vbool32_t, vint16mf2_t, vint16mf2_t, vint16mf2_t, vint16mf2_t, vint16mf2_t, vint16mf2_t, const int16_t *, vuint32m1_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vluxseg6ei32_v)))
void vluxseg6ei32(vint16mf4_t *, vint16mf4_t *, vint16mf4_t *, vint16mf4_t *, vint16mf4_t *, vint16mf4_t *, const int16_t *, vuint32mf2_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vluxseg6ei32_v_m)))
void vluxseg6ei32(vint16mf4_t *, vint16mf4_t *, vint16mf4_t *, vint16mf4_t *, vint16mf4_t *, vint16mf4_t *, vbool64_t, vint16mf4_t, vint16mf4_t, vint16mf4_t, vint16mf4_t, vint16mf4_t, vint16mf4_t, const int16_t *, vuint32mf2_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vluxseg6ei32_v)))
void vluxseg6ei32(vuint16m1_t *, vuint16m1_t *, vuint16m1_t *, vuint16m1_t *, vuint16m1_t *, vuint16m1_t *, const uint16_t *, vuint32m2_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vluxseg6ei32_v_m)))
void vluxseg6ei32(vuint16m1_t *, vuint16m1_t *, vuint16m1_t *, vuint16m1_t *, vuint16m1_t *, vuint16m1_t *, vbool16_t, vuint16m1_t, vuint16m1_t, vuint16m1_t, vuint16m1_t, vuint16m1_t, vuint16m1_t, const uint16_t *, vuint32m2_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vluxseg6ei32_v)))
void vluxseg6ei32(vuint16mf2_t *, vuint16mf2_t *, vuint16mf2_t *, vuint16mf2_t *, vuint16mf2_t *, vuint16mf2_t *, const uint16_t *, vuint32m1_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vluxseg6ei32_v_m)))
void vluxseg6ei32(vuint16mf2_t *, vuint16mf2_t *, vuint16mf2_t *, vuint16mf2_t *, vuint16mf2_t *, vuint16mf2_t *, vbool32_t, vuint16mf2_t, vuint16mf2_t, vuint16mf2_t, vuint16mf2_t, vuint16mf2_t, vuint16mf2_t, const uint16_t *, vuint32m1_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vluxseg6ei32_v)))
void vluxseg6ei32(vuint16mf4_t *, vuint16mf4_t *, vuint16mf4_t *, vuint16mf4_t *, vuint16mf4_t *, vuint16mf4_t *, const uint16_t *, vuint32mf2_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vluxseg6ei32_v_m)))
void vluxseg6ei32(vuint16mf4_t *, vuint16mf4_t *, vuint16mf4_t *, vuint16mf4_t *, vuint16mf4_t *, vuint16mf4_t *, vbool64_t, vuint16mf4_t, vuint16mf4_t, vuint16mf4_t, vuint16mf4_t, vuint16mf4_t, vuint16mf4_t, const uint16_t *, vuint32mf2_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vluxseg7ei32_v)))
void vluxseg7ei32(vint16m1_t *, vint16m1_t *, vint16m1_t *, vint16m1_t *, vint16m1_t *, vint16m1_t *, vint16m1_t *, const int16_t *, vuint32m2_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vluxseg7ei32_v_m)))
void vluxseg7ei32(vint16m1_t *, vint16m1_t *, vint16m1_t *, vint16m1_t *, vint16m1_t *, vint16m1_t *, vint16m1_t *, vbool16_t, vint16m1_t, vint16m1_t, vint16m1_t, vint16m1_t, vint16m1_t, vint16m1_t, vint16m1_t, const int16_t *, vuint32m2_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vluxseg7ei32_v)))
void vluxseg7ei32(vint16mf2_t *, vint16mf2_t *, vint16mf2_t *, vint16mf2_t *, vint16mf2_t *, vint16mf2_t *, vint16mf2_t *, const int16_t *, vuint32m1_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vluxseg7ei32_v_m)))
void vluxseg7ei32(vint16mf2_t *, vint16mf2_t *, vint16mf2_t *, vint16mf2_t *, vint16mf2_t *, vint16mf2_t *, vint16mf2_t *, vbool32_t, vint16mf2_t, vint16mf2_t, vint16mf2_t, vint16mf2_t, vint16mf2_t, vint16mf2_t, vint16mf2_t, const int16_t *, vuint32m1_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vluxseg7ei32_v)))
void vluxseg7ei32(vint16mf4_t *, vint16mf4_t *, vint16mf4_t *, vint16mf4_t *, vint16mf4_t *, vint16mf4_t *, vint16mf4_t *, const int16_t *, vuint32mf2_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vluxseg7ei32_v_m)))
void vluxseg7ei32(vint16mf4_t *, vint16mf4_t *, vint16mf4_t *, vint16mf4_t *, vint16mf4_t *, vint16mf4_t *, vint16mf4_t *, vbool64_t, vint16mf4_t, vint16mf4_t, vint16mf4_t, vint16mf4_t, vint16mf4_t, vint16mf4_t, vint16mf4_t, const int16_t *, vuint32mf2_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vluxseg7ei32_v)))
void vluxseg7ei32(vuint16m1_t *, vuint16m1_t *, vuint16m1_t *, vuint16m1_t *, vuint16m1_t *, vuint16m1_t *, vuint16m1_t *, const uint16_t *, vuint32m2_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vluxseg7ei32_v_m)))
void vluxseg7ei32(vuint16m1_t *, vuint16m1_t *, vuint16m1_t *, vuint16m1_t *, vuint16m1_t *, vuint16m1_t *, vuint16m1_t *, vbool16_t, vuint16m1_t, vuint16m1_t, vuint16m1_t, vuint16m1_t, vuint16m1_t, vuint16m1_t, vuint16m1_t, const uint16_t *, vuint32m2_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vluxseg7ei32_v)))
void vluxseg7ei32(vuint16mf2_t *, vuint16mf2_t *, vuint16mf2_t *, vuint16mf2_t *, vuint16mf2_t *, vuint16mf2_t *, vuint16mf2_t *, const uint16_t *, vuint32m1_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vluxseg7ei32_v_m)))
void vluxseg7ei32(vuint16mf2_t *, vuint16mf2_t *, vuint16mf2_t *, vuint16mf2_t *, vuint16mf2_t *, vuint16mf2_t *, vuint16mf2_t *, vbool32_t, vuint16mf2_t, vuint16mf2_t, vuint16mf2_t, vuint16mf2_t, vuint16mf2_t, vuint16mf2_t, vuint16mf2_t, const uint16_t *, vuint32m1_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vluxseg7ei32_v)))
void vluxseg7ei32(vuint16mf4_t *, vuint16mf4_t *, vuint16mf4_t *, vuint16mf4_t *, vuint16mf4_t *, vuint16mf4_t *, vuint16mf4_t *, const uint16_t *, vuint32mf2_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vluxseg7ei32_v_m)))
void vluxseg7ei32(vuint16mf4_t *, vuint16mf4_t *, vuint16mf4_t *, vuint16mf4_t *, vuint16mf4_t *, vuint16mf4_t *, vuint16mf4_t *, vbool64_t, vuint16mf4_t, vuint16mf4_t, vuint16mf4_t, vuint16mf4_t, vuint16mf4_t, vuint16mf4_t, vuint16mf4_t, const uint16_t *, vuint32mf2_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vluxseg8ei32_v)))
void vluxseg8ei32(vint16m1_t *, vint16m1_t *, vint16m1_t *, vint16m1_t *, vint16m1_t *, vint16m1_t *, vint16m1_t *, vint16m1_t *, const int16_t *, vuint32m2_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vluxseg8ei32_v_m)))
void vluxseg8ei32(vint16m1_t *, vint16m1_t *, vint16m1_t *, vint16m1_t *, vint16m1_t *, vint16m1_t *, vint16m1_t *, vint16m1_t *, vbool16_t, vint16m1_t, vint16m1_t, vint16m1_t, vint16m1_t, vint16m1_t, vint16m1_t, vint16m1_t, vint16m1_t, const int16_t *, vuint32m2_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vluxseg8ei32_v)))
void vluxseg8ei32(vint16mf2_t *, vint16mf2_t *, vint16mf2_t *, vint16mf2_t *, vint16mf2_t *, vint16mf2_t *, vint16mf2_t *, vint16mf2_t *, const int16_t *, vuint32m1_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vluxseg8ei32_v_m)))
void vluxseg8ei32(vint16mf2_t *, vint16mf2_t *, vint16mf2_t *, vint16mf2_t *, vint16mf2_t *, vint16mf2_t *, vint16mf2_t *, vint16mf2_t *, vbool32_t, vint16mf2_t, vint16mf2_t, vint16mf2_t, vint16mf2_t, vint16mf2_t, vint16mf2_t, vint16mf2_t, vint16mf2_t, const int16_t *, vuint32m1_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vluxseg8ei32_v)))
void vluxseg8ei32(vint16mf4_t *, vint16mf4_t *, vint16mf4_t *, vint16mf4_t *, vint16mf4_t *, vint16mf4_t *, vint16mf4_t *, vint16mf4_t *, const int16_t *, vuint32mf2_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vluxseg8ei32_v_m)))
void vluxseg8ei32(vint16mf4_t *, vint16mf4_t *, vint16mf4_t *, vint16mf4_t *, vint16mf4_t *, vint16mf4_t *, vint16mf4_t *, vint16mf4_t *, vbool64_t, vint16mf4_t, vint16mf4_t, vint16mf4_t, vint16mf4_t, vint16mf4_t, vint16mf4_t, vint16mf4_t, vint16mf4_t, const int16_t *, vuint32mf2_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vluxseg8ei32_v)))
void vluxseg8ei32(vuint16m1_t *, vuint16m1_t *, vuint16m1_t *, vuint16m1_t *, vuint16m1_t *, vuint16m1_t *, vuint16m1_t *, vuint16m1_t *, const uint16_t *, vuint32m2_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vluxseg8ei32_v_m)))
void vluxseg8ei32(vuint16m1_t *, vuint16m1_t *, vuint16m1_t *, vuint16m1_t *, vuint16m1_t *, vuint16m1_t *, vuint16m1_t *, vuint16m1_t *, vbool16_t, vuint16m1_t, vuint16m1_t, vuint16m1_t, vuint16m1_t, vuint16m1_t, vuint16m1_t, vuint16m1_t, vuint16m1_t, const uint16_t *, vuint32m2_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vluxseg8ei32_v)))
void vluxseg8ei32(vuint16mf2_t *, vuint16mf2_t *, vuint16mf2_t *, vuint16mf2_t *, vuint16mf2_t *, vuint16mf2_t *, vuint16mf2_t *, vuint16mf2_t *, const uint16_t *, vuint32m1_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vluxseg8ei32_v_m)))
void vluxseg8ei32(vuint16mf2_t *, vuint16mf2_t *, vuint16mf2_t *, vuint16mf2_t *, vuint16mf2_t *, vuint16mf2_t *, vuint16mf2_t *, vuint16mf2_t *, vbool32_t, vuint16mf2_t, vuint16mf2_t, vuint16mf2_t, vuint16mf2_t, vuint16mf2_t, vuint16mf2_t, vuint16mf2_t, vuint16mf2_t, const uint16_t *, vuint32m1_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vluxseg8ei32_v)))
void vluxseg8ei32(vuint16mf4_t *, vuint16mf4_t *, vuint16mf4_t *, vuint16mf4_t *, vuint16mf4_t *, vuint16mf4_t *, vuint16mf4_t *, vuint16mf4_t *, const uint16_t *, vuint32mf2_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vluxseg8ei32_v_m)))
void vluxseg8ei32(vuint16mf4_t *, vuint16mf4_t *, vuint16mf4_t *, vuint16mf4_t *, vuint16mf4_t *, vuint16mf4_t *, vuint16mf4_t *, vuint16mf4_t *, vbool64_t, vuint16mf4_t, vuint16mf4_t, vuint16mf4_t, vuint16mf4_t, vuint16mf4_t, vuint16mf4_t, vuint16mf4_t, vuint16mf4_t, const uint16_t *, vuint32mf2_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vluxseg2ei8_v)))
void vluxseg2ei8(vint32m1_t *, vint32m1_t *, const int32_t *, vuint8mf4_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vluxseg2ei8_v_m)))
void vluxseg2ei8(vint32m1_t *, vint32m1_t *, vbool32_t, vint32m1_t, vint32m1_t, const int32_t *, vuint8mf4_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vluxseg2ei8_v)))
void vluxseg2ei8(vint32m2_t *, vint32m2_t *, const int32_t *, vuint8mf2_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vluxseg2ei8_v_m)))
void vluxseg2ei8(vint32m2_t *, vint32m2_t *, vbool16_t, vint32m2_t, vint32m2_t, const int32_t *, vuint8mf2_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vluxseg2ei8_v)))
void vluxseg2ei8(vint32m4_t *, vint32m4_t *, const int32_t *, vuint8m1_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vluxseg2ei8_v_m)))
void vluxseg2ei8(vint32m4_t *, vint32m4_t *, vbool8_t, vint32m4_t, vint32m4_t, const int32_t *, vuint8m1_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vluxseg2ei8_v)))
void vluxseg2ei8(vint32mf2_t *, vint32mf2_t *, const int32_t *, vuint8mf8_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vluxseg2ei8_v_m)))
void vluxseg2ei8(vint32mf2_t *, vint32mf2_t *, vbool64_t, vint32mf2_t, vint32mf2_t, const int32_t *, vuint8mf8_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vluxseg2ei8_v)))
void vluxseg2ei8(vuint32m1_t *, vuint32m1_t *, const uint32_t *, vuint8mf4_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vluxseg2ei8_v_m)))
void vluxseg2ei8(vuint32m1_t *, vuint32m1_t *, vbool32_t, vuint32m1_t, vuint32m1_t, const uint32_t *, vuint8mf4_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vluxseg2ei8_v)))
void vluxseg2ei8(vuint32m2_t *, vuint32m2_t *, const uint32_t *, vuint8mf2_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vluxseg2ei8_v_m)))
void vluxseg2ei8(vuint32m2_t *, vuint32m2_t *, vbool16_t, vuint32m2_t, vuint32m2_t, const uint32_t *, vuint8mf2_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vluxseg2ei8_v)))
void vluxseg2ei8(vuint32m4_t *, vuint32m4_t *, const uint32_t *, vuint8m1_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vluxseg2ei8_v_m)))
void vluxseg2ei8(vuint32m4_t *, vuint32m4_t *, vbool8_t, vuint32m4_t, vuint32m4_t, const uint32_t *, vuint8m1_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vluxseg2ei8_v)))
void vluxseg2ei8(vuint32mf2_t *, vuint32mf2_t *, const uint32_t *, vuint8mf8_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vluxseg2ei8_v_m)))
void vluxseg2ei8(vuint32mf2_t *, vuint32mf2_t *, vbool64_t, vuint32mf2_t, vuint32mf2_t, const uint32_t *, vuint8mf8_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vluxseg3ei8_v)))
void vluxseg3ei8(vint32m1_t *, vint32m1_t *, vint32m1_t *, const int32_t *, vuint8mf4_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vluxseg3ei8_v_m)))
void vluxseg3ei8(vint32m1_t *, vint32m1_t *, vint32m1_t *, vbool32_t, vint32m1_t, vint32m1_t, vint32m1_t, const int32_t *, vuint8mf4_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vluxseg3ei8_v)))
void vluxseg3ei8(vint32m2_t *, vint32m2_t *, vint32m2_t *, const int32_t *, vuint8mf2_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vluxseg3ei8_v_m)))
void vluxseg3ei8(vint32m2_t *, vint32m2_t *, vint32m2_t *, vbool16_t, vint32m2_t, vint32m2_t, vint32m2_t, const int32_t *, vuint8mf2_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vluxseg3ei8_v)))
void vluxseg3ei8(vint32mf2_t *, vint32mf2_t *, vint32mf2_t *, const int32_t *, vuint8mf8_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vluxseg3ei8_v_m)))
void vluxseg3ei8(vint32mf2_t *, vint32mf2_t *, vint32mf2_t *, vbool64_t, vint32mf2_t, vint32mf2_t, vint32mf2_t, const int32_t *, vuint8mf8_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vluxseg3ei8_v)))
void vluxseg3ei8(vuint32m1_t *, vuint32m1_t *, vuint32m1_t *, const uint32_t *, vuint8mf4_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vluxseg3ei8_v_m)))
void vluxseg3ei8(vuint32m1_t *, vuint32m1_t *, vuint32m1_t *, vbool32_t, vuint32m1_t, vuint32m1_t, vuint32m1_t, const uint32_t *, vuint8mf4_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vluxseg3ei8_v)))
void vluxseg3ei8(vuint32m2_t *, vuint32m2_t *, vuint32m2_t *, const uint32_t *, vuint8mf2_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vluxseg3ei8_v_m)))
void vluxseg3ei8(vuint32m2_t *, vuint32m2_t *, vuint32m2_t *, vbool16_t, vuint32m2_t, vuint32m2_t, vuint32m2_t, const uint32_t *, vuint8mf2_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vluxseg3ei8_v)))
void vluxseg3ei8(vuint32mf2_t *, vuint32mf2_t *, vuint32mf2_t *, const uint32_t *, vuint8mf8_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vluxseg3ei8_v_m)))
void vluxseg3ei8(vuint32mf2_t *, vuint32mf2_t *, vuint32mf2_t *, vbool64_t, vuint32mf2_t, vuint32mf2_t, vuint32mf2_t, const uint32_t *, vuint8mf8_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vluxseg4ei8_v)))
void vluxseg4ei8(vint32m1_t *, vint32m1_t *, vint32m1_t *, vint32m1_t *, const int32_t *, vuint8mf4_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vluxseg4ei8_v_m)))
void vluxseg4ei8(vint32m1_t *, vint32m1_t *, vint32m1_t *, vint32m1_t *, vbool32_t, vint32m1_t, vint32m1_t, vint32m1_t, vint32m1_t, const int32_t *, vuint8mf4_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vluxseg4ei8_v)))
void vluxseg4ei8(vint32m2_t *, vint32m2_t *, vint32m2_t *, vint32m2_t *, const int32_t *, vuint8mf2_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vluxseg4ei8_v_m)))
void vluxseg4ei8(vint32m2_t *, vint32m2_t *, vint32m2_t *, vint32m2_t *, vbool16_t, vint32m2_t, vint32m2_t, vint32m2_t, vint32m2_t, const int32_t *, vuint8mf2_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vluxseg4ei8_v)))
void vluxseg4ei8(vint32mf2_t *, vint32mf2_t *, vint32mf2_t *, vint32mf2_t *, const int32_t *, vuint8mf8_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vluxseg4ei8_v_m)))
void vluxseg4ei8(vint32mf2_t *, vint32mf2_t *, vint32mf2_t *, vint32mf2_t *, vbool64_t, vint32mf2_t, vint32mf2_t, vint32mf2_t, vint32mf2_t, const int32_t *, vuint8mf8_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vluxseg4ei8_v)))
void vluxseg4ei8(vuint32m1_t *, vuint32m1_t *, vuint32m1_t *, vuint32m1_t *, const uint32_t *, vuint8mf4_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vluxseg4ei8_v_m)))
void vluxseg4ei8(vuint32m1_t *, vuint32m1_t *, vuint32m1_t *, vuint32m1_t *, vbool32_t, vuint32m1_t, vuint32m1_t, vuint32m1_t, vuint32m1_t, const uint32_t *, vuint8mf4_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vluxseg4ei8_v)))
void vluxseg4ei8(vuint32m2_t *, vuint32m2_t *, vuint32m2_t *, vuint32m2_t *, const uint32_t *, vuint8mf2_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vluxseg4ei8_v_m)))
void vluxseg4ei8(vuint32m2_t *, vuint32m2_t *, vuint32m2_t *, vuint32m2_t *, vbool16_t, vuint32m2_t, vuint32m2_t, vuint32m2_t, vuint32m2_t, const uint32_t *, vuint8mf2_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vluxseg4ei8_v)))
void vluxseg4ei8(vuint32mf2_t *, vuint32mf2_t *, vuint32mf2_t *, vuint32mf2_t *, const uint32_t *, vuint8mf8_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vluxseg4ei8_v_m)))
void vluxseg4ei8(vuint32mf2_t *, vuint32mf2_t *, vuint32mf2_t *, vuint32mf2_t *, vbool64_t, vuint32mf2_t, vuint32mf2_t, vuint32mf2_t, vuint32mf2_t, const uint32_t *, vuint8mf8_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vluxseg5ei8_v)))
void vluxseg5ei8(vint32m1_t *, vint32m1_t *, vint32m1_t *, vint32m1_t *, vint32m1_t *, const int32_t *, vuint8mf4_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vluxseg5ei8_v_m)))
void vluxseg5ei8(vint32m1_t *, vint32m1_t *, vint32m1_t *, vint32m1_t *, vint32m1_t *, vbool32_t, vint32m1_t, vint32m1_t, vint32m1_t, vint32m1_t, vint32m1_t, const int32_t *, vuint8mf4_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vluxseg5ei8_v)))
void vluxseg5ei8(vint32mf2_t *, vint32mf2_t *, vint32mf2_t *, vint32mf2_t *, vint32mf2_t *, const int32_t *, vuint8mf8_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vluxseg5ei8_v_m)))
void vluxseg5ei8(vint32mf2_t *, vint32mf2_t *, vint32mf2_t *, vint32mf2_t *, vint32mf2_t *, vbool64_t, vint32mf2_t, vint32mf2_t, vint32mf2_t, vint32mf2_t, vint32mf2_t, const int32_t *, vuint8mf8_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vluxseg5ei8_v)))
void vluxseg5ei8(vuint32m1_t *, vuint32m1_t *, vuint32m1_t *, vuint32m1_t *, vuint32m1_t *, const uint32_t *, vuint8mf4_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vluxseg5ei8_v_m)))
void vluxseg5ei8(vuint32m1_t *, vuint32m1_t *, vuint32m1_t *, vuint32m1_t *, vuint32m1_t *, vbool32_t, vuint32m1_t, vuint32m1_t, vuint32m1_t, vuint32m1_t, vuint32m1_t, const uint32_t *, vuint8mf4_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vluxseg5ei8_v)))
void vluxseg5ei8(vuint32mf2_t *, vuint32mf2_t *, vuint32mf2_t *, vuint32mf2_t *, vuint32mf2_t *, const uint32_t *, vuint8mf8_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vluxseg5ei8_v_m)))
void vluxseg5ei8(vuint32mf2_t *, vuint32mf2_t *, vuint32mf2_t *, vuint32mf2_t *, vuint32mf2_t *, vbool64_t, vuint32mf2_t, vuint32mf2_t, vuint32mf2_t, vuint32mf2_t, vuint32mf2_t, const uint32_t *, vuint8mf8_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vluxseg6ei8_v)))
void vluxseg6ei8(vint32m1_t *, vint32m1_t *, vint32m1_t *, vint32m1_t *, vint32m1_t *, vint32m1_t *, const int32_t *, vuint8mf4_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vluxseg6ei8_v_m)))
void vluxseg6ei8(vint32m1_t *, vint32m1_t *, vint32m1_t *, vint32m1_t *, vint32m1_t *, vint32m1_t *, vbool32_t, vint32m1_t, vint32m1_t, vint32m1_t, vint32m1_t, vint32m1_t, vint32m1_t, const int32_t *, vuint8mf4_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vluxseg6ei8_v)))
void vluxseg6ei8(vint32mf2_t *, vint32mf2_t *, vint32mf2_t *, vint32mf2_t *, vint32mf2_t *, vint32mf2_t *, const int32_t *, vuint8mf8_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vluxseg6ei8_v_m)))
void vluxseg6ei8(vint32mf2_t *, vint32mf2_t *, vint32mf2_t *, vint32mf2_t *, vint32mf2_t *, vint32mf2_t *, vbool64_t, vint32mf2_t, vint32mf2_t, vint32mf2_t, vint32mf2_t, vint32mf2_t, vint32mf2_t, const int32_t *, vuint8mf8_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vluxseg6ei8_v)))
void vluxseg6ei8(vuint32m1_t *, vuint32m1_t *, vuint32m1_t *, vuint32m1_t *, vuint32m1_t *, vuint32m1_t *, const uint32_t *, vuint8mf4_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vluxseg6ei8_v_m)))
void vluxseg6ei8(vuint32m1_t *, vuint32m1_t *, vuint32m1_t *, vuint32m1_t *, vuint32m1_t *, vuint32m1_t *, vbool32_t, vuint32m1_t, vuint32m1_t, vuint32m1_t, vuint32m1_t, vuint32m1_t, vuint32m1_t, const uint32_t *, vuint8mf4_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vluxseg6ei8_v)))
void vluxseg6ei8(vuint32mf2_t *, vuint32mf2_t *, vuint32mf2_t *, vuint32mf2_t *, vuint32mf2_t *, vuint32mf2_t *, const uint32_t *, vuint8mf8_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vluxseg6ei8_v_m)))
void vluxseg6ei8(vuint32mf2_t *, vuint32mf2_t *, vuint32mf2_t *, vuint32mf2_t *, vuint32mf2_t *, vuint32mf2_t *, vbool64_t, vuint32mf2_t, vuint32mf2_t, vuint32mf2_t, vuint32mf2_t, vuint32mf2_t, vuint32mf2_t, const uint32_t *, vuint8mf8_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vluxseg7ei8_v)))
void vluxseg7ei8(vint32m1_t *, vint32m1_t *, vint32m1_t *, vint32m1_t *, vint32m1_t *, vint32m1_t *, vint32m1_t *, const int32_t *, vuint8mf4_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vluxseg7ei8_v_m)))
void vluxseg7ei8(vint32m1_t *, vint32m1_t *, vint32m1_t *, vint32m1_t *, vint32m1_t *, vint32m1_t *, vint32m1_t *, vbool32_t, vint32m1_t, vint32m1_t, vint32m1_t, vint32m1_t, vint32m1_t, vint32m1_t, vint32m1_t, const int32_t *, vuint8mf4_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vluxseg7ei8_v)))
void vluxseg7ei8(vint32mf2_t *, vint32mf2_t *, vint32mf2_t *, vint32mf2_t *, vint32mf2_t *, vint32mf2_t *, vint32mf2_t *, const int32_t *, vuint8mf8_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vluxseg7ei8_v_m)))
void vluxseg7ei8(vint32mf2_t *, vint32mf2_t *, vint32mf2_t *, vint32mf2_t *, vint32mf2_t *, vint32mf2_t *, vint32mf2_t *, vbool64_t, vint32mf2_t, vint32mf2_t, vint32mf2_t, vint32mf2_t, vint32mf2_t, vint32mf2_t, vint32mf2_t, const int32_t *, vuint8mf8_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vluxseg7ei8_v)))
void vluxseg7ei8(vuint32m1_t *, vuint32m1_t *, vuint32m1_t *, vuint32m1_t *, vuint32m1_t *, vuint32m1_t *, vuint32m1_t *, const uint32_t *, vuint8mf4_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vluxseg7ei8_v_m)))
void vluxseg7ei8(vuint32m1_t *, vuint32m1_t *, vuint32m1_t *, vuint32m1_t *, vuint32m1_t *, vuint32m1_t *, vuint32m1_t *, vbool32_t, vuint32m1_t, vuint32m1_t, vuint32m1_t, vuint32m1_t, vuint32m1_t, vuint32m1_t, vuint32m1_t, const uint32_t *, vuint8mf4_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vluxseg7ei8_v)))
void vluxseg7ei8(vuint32mf2_t *, vuint32mf2_t *, vuint32mf2_t *, vuint32mf2_t *, vuint32mf2_t *, vuint32mf2_t *, vuint32mf2_t *, const uint32_t *, vuint8mf8_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vluxseg7ei8_v_m)))
void vluxseg7ei8(vuint32mf2_t *, vuint32mf2_t *, vuint32mf2_t *, vuint32mf2_t *, vuint32mf2_t *, vuint32mf2_t *, vuint32mf2_t *, vbool64_t, vuint32mf2_t, vuint32mf2_t, vuint32mf2_t, vuint32mf2_t, vuint32mf2_t, vuint32mf2_t, vuint32mf2_t, const uint32_t *, vuint8mf8_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vluxseg8ei8_v)))
void vluxseg8ei8(vint32m1_t *, vint32m1_t *, vint32m1_t *, vint32m1_t *, vint32m1_t *, vint32m1_t *, vint32m1_t *, vint32m1_t *, const int32_t *, vuint8mf4_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vluxseg8ei8_v_m)))
void vluxseg8ei8(vint32m1_t *, vint32m1_t *, vint32m1_t *, vint32m1_t *, vint32m1_t *, vint32m1_t *, vint32m1_t *, vint32m1_t *, vbool32_t, vint32m1_t, vint32m1_t, vint32m1_t, vint32m1_t, vint32m1_t, vint32m1_t, vint32m1_t, vint32m1_t, const int32_t *, vuint8mf4_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vluxseg8ei8_v)))
void vluxseg8ei8(vint32mf2_t *, vint32mf2_t *, vint32mf2_t *, vint32mf2_t *, vint32mf2_t *, vint32mf2_t *, vint32mf2_t *, vint32mf2_t *, const int32_t *, vuint8mf8_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vluxseg8ei8_v_m)))
void vluxseg8ei8(vint32mf2_t *, vint32mf2_t *, vint32mf2_t *, vint32mf2_t *, vint32mf2_t *, vint32mf2_t *, vint32mf2_t *, vint32mf2_t *, vbool64_t, vint32mf2_t, vint32mf2_t, vint32mf2_t, vint32mf2_t, vint32mf2_t, vint32mf2_t, vint32mf2_t, vint32mf2_t, const int32_t *, vuint8mf8_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vluxseg8ei8_v)))
void vluxseg8ei8(vuint32m1_t *, vuint32m1_t *, vuint32m1_t *, vuint32m1_t *, vuint32m1_t *, vuint32m1_t *, vuint32m1_t *, vuint32m1_t *, const uint32_t *, vuint8mf4_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vluxseg8ei8_v_m)))
void vluxseg8ei8(vuint32m1_t *, vuint32m1_t *, vuint32m1_t *, vuint32m1_t *, vuint32m1_t *, vuint32m1_t *, vuint32m1_t *, vuint32m1_t *, vbool32_t, vuint32m1_t, vuint32m1_t, vuint32m1_t, vuint32m1_t, vuint32m1_t, vuint32m1_t, vuint32m1_t, vuint32m1_t, const uint32_t *, vuint8mf4_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vluxseg8ei8_v)))
void vluxseg8ei8(vuint32mf2_t *, vuint32mf2_t *, vuint32mf2_t *, vuint32mf2_t *, vuint32mf2_t *, vuint32mf2_t *, vuint32mf2_t *, vuint32mf2_t *, const uint32_t *, vuint8mf8_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vluxseg8ei8_v_m)))
void vluxseg8ei8(vuint32mf2_t *, vuint32mf2_t *, vuint32mf2_t *, vuint32mf2_t *, vuint32mf2_t *, vuint32mf2_t *, vuint32mf2_t *, vuint32mf2_t *, vbool64_t, vuint32mf2_t, vuint32mf2_t, vuint32mf2_t, vuint32mf2_t, vuint32mf2_t, vuint32mf2_t, vuint32mf2_t, vuint32mf2_t, const uint32_t *, vuint8mf8_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vluxseg2ei16_v)))
void vluxseg2ei16(vint32m1_t *, vint32m1_t *, const int32_t *, vuint16mf2_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vluxseg2ei16_v_m)))
void vluxseg2ei16(vint32m1_t *, vint32m1_t *, vbool32_t, vint32m1_t, vint32m1_t, const int32_t *, vuint16mf2_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vluxseg2ei16_v)))
void vluxseg2ei16(vint32m2_t *, vint32m2_t *, const int32_t *, vuint16m1_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vluxseg2ei16_v_m)))
void vluxseg2ei16(vint32m2_t *, vint32m2_t *, vbool16_t, vint32m2_t, vint32m2_t, const int32_t *, vuint16m1_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vluxseg2ei16_v)))
void vluxseg2ei16(vint32m4_t *, vint32m4_t *, const int32_t *, vuint16m2_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vluxseg2ei16_v_m)))
void vluxseg2ei16(vint32m4_t *, vint32m4_t *, vbool8_t, vint32m4_t, vint32m4_t, const int32_t *, vuint16m2_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vluxseg2ei16_v)))
void vluxseg2ei16(vint32mf2_t *, vint32mf2_t *, const int32_t *, vuint16mf4_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vluxseg2ei16_v_m)))
void vluxseg2ei16(vint32mf2_t *, vint32mf2_t *, vbool64_t, vint32mf2_t, vint32mf2_t, const int32_t *, vuint16mf4_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vluxseg2ei16_v)))
void vluxseg2ei16(vuint32m1_t *, vuint32m1_t *, const uint32_t *, vuint16mf2_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vluxseg2ei16_v_m)))
void vluxseg2ei16(vuint32m1_t *, vuint32m1_t *, vbool32_t, vuint32m1_t, vuint32m1_t, const uint32_t *, vuint16mf2_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vluxseg2ei16_v)))
void vluxseg2ei16(vuint32m2_t *, vuint32m2_t *, const uint32_t *, vuint16m1_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vluxseg2ei16_v_m)))
void vluxseg2ei16(vuint32m2_t *, vuint32m2_t *, vbool16_t, vuint32m2_t, vuint32m2_t, const uint32_t *, vuint16m1_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vluxseg2ei16_v)))
void vluxseg2ei16(vuint32m4_t *, vuint32m4_t *, const uint32_t *, vuint16m2_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vluxseg2ei16_v_m)))
void vluxseg2ei16(vuint32m4_t *, vuint32m4_t *, vbool8_t, vuint32m4_t, vuint32m4_t, const uint32_t *, vuint16m2_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vluxseg2ei16_v)))
void vluxseg2ei16(vuint32mf2_t *, vuint32mf2_t *, const uint32_t *, vuint16mf4_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vluxseg2ei16_v_m)))
void vluxseg2ei16(vuint32mf2_t *, vuint32mf2_t *, vbool64_t, vuint32mf2_t, vuint32mf2_t, const uint32_t *, vuint16mf4_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vluxseg3ei16_v)))
void vluxseg3ei16(vint32m1_t *, vint32m1_t *, vint32m1_t *, const int32_t *, vuint16mf2_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vluxseg3ei16_v_m)))
void vluxseg3ei16(vint32m1_t *, vint32m1_t *, vint32m1_t *, vbool32_t, vint32m1_t, vint32m1_t, vint32m1_t, const int32_t *, vuint16mf2_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vluxseg3ei16_v)))
void vluxseg3ei16(vint32m2_t *, vint32m2_t *, vint32m2_t *, const int32_t *, vuint16m1_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vluxseg3ei16_v_m)))
void vluxseg3ei16(vint32m2_t *, vint32m2_t *, vint32m2_t *, vbool16_t, vint32m2_t, vint32m2_t, vint32m2_t, const int32_t *, vuint16m1_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vluxseg3ei16_v)))
void vluxseg3ei16(vint32mf2_t *, vint32mf2_t *, vint32mf2_t *, const int32_t *, vuint16mf4_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vluxseg3ei16_v_m)))
void vluxseg3ei16(vint32mf2_t *, vint32mf2_t *, vint32mf2_t *, vbool64_t, vint32mf2_t, vint32mf2_t, vint32mf2_t, const int32_t *, vuint16mf4_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vluxseg3ei16_v)))
void vluxseg3ei16(vuint32m1_t *, vuint32m1_t *, vuint32m1_t *, const uint32_t *, vuint16mf2_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vluxseg3ei16_v_m)))
void vluxseg3ei16(vuint32m1_t *, vuint32m1_t *, vuint32m1_t *, vbool32_t, vuint32m1_t, vuint32m1_t, vuint32m1_t, const uint32_t *, vuint16mf2_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vluxseg3ei16_v)))
void vluxseg3ei16(vuint32m2_t *, vuint32m2_t *, vuint32m2_t *, const uint32_t *, vuint16m1_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vluxseg3ei16_v_m)))
void vluxseg3ei16(vuint32m2_t *, vuint32m2_t *, vuint32m2_t *, vbool16_t, vuint32m2_t, vuint32m2_t, vuint32m2_t, const uint32_t *, vuint16m1_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vluxseg3ei16_v)))
void vluxseg3ei16(vuint32mf2_t *, vuint32mf2_t *, vuint32mf2_t *, const uint32_t *, vuint16mf4_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vluxseg3ei16_v_m)))
void vluxseg3ei16(vuint32mf2_t *, vuint32mf2_t *, vuint32mf2_t *, vbool64_t, vuint32mf2_t, vuint32mf2_t, vuint32mf2_t, const uint32_t *, vuint16mf4_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vluxseg4ei16_v)))
void vluxseg4ei16(vint32m1_t *, vint32m1_t *, vint32m1_t *, vint32m1_t *, const int32_t *, vuint16mf2_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vluxseg4ei16_v_m)))
void vluxseg4ei16(vint32m1_t *, vint32m1_t *, vint32m1_t *, vint32m1_t *, vbool32_t, vint32m1_t, vint32m1_t, vint32m1_t, vint32m1_t, const int32_t *, vuint16mf2_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vluxseg4ei16_v)))
void vluxseg4ei16(vint32m2_t *, vint32m2_t *, vint32m2_t *, vint32m2_t *, const int32_t *, vuint16m1_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vluxseg4ei16_v_m)))
void vluxseg4ei16(vint32m2_t *, vint32m2_t *, vint32m2_t *, vint32m2_t *, vbool16_t, vint32m2_t, vint32m2_t, vint32m2_t, vint32m2_t, const int32_t *, vuint16m1_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vluxseg4ei16_v)))
void vluxseg4ei16(vint32mf2_t *, vint32mf2_t *, vint32mf2_t *, vint32mf2_t *, const int32_t *, vuint16mf4_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vluxseg4ei16_v_m)))
void vluxseg4ei16(vint32mf2_t *, vint32mf2_t *, vint32mf2_t *, vint32mf2_t *, vbool64_t, vint32mf2_t, vint32mf2_t, vint32mf2_t, vint32mf2_t, const int32_t *, vuint16mf4_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vluxseg4ei16_v)))
void vluxseg4ei16(vuint32m1_t *, vuint32m1_t *, vuint32m1_t *, vuint32m1_t *, const uint32_t *, vuint16mf2_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vluxseg4ei16_v_m)))
void vluxseg4ei16(vuint32m1_t *, vuint32m1_t *, vuint32m1_t *, vuint32m1_t *, vbool32_t, vuint32m1_t, vuint32m1_t, vuint32m1_t, vuint32m1_t, const uint32_t *, vuint16mf2_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vluxseg4ei16_v)))
void vluxseg4ei16(vuint32m2_t *, vuint32m2_t *, vuint32m2_t *, vuint32m2_t *, const uint32_t *, vuint16m1_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vluxseg4ei16_v_m)))
void vluxseg4ei16(vuint32m2_t *, vuint32m2_t *, vuint32m2_t *, vuint32m2_t *, vbool16_t, vuint32m2_t, vuint32m2_t, vuint32m2_t, vuint32m2_t, const uint32_t *, vuint16m1_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vluxseg4ei16_v)))
void vluxseg4ei16(vuint32mf2_t *, vuint32mf2_t *, vuint32mf2_t *, vuint32mf2_t *, const uint32_t *, vuint16mf4_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vluxseg4ei16_v_m)))
void vluxseg4ei16(vuint32mf2_t *, vuint32mf2_t *, vuint32mf2_t *, vuint32mf2_t *, vbool64_t, vuint32mf2_t, vuint32mf2_t, vuint32mf2_t, vuint32mf2_t, const uint32_t *, vuint16mf4_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vluxseg5ei16_v)))
void vluxseg5ei16(vint32m1_t *, vint32m1_t *, vint32m1_t *, vint32m1_t *, vint32m1_t *, const int32_t *, vuint16mf2_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vluxseg5ei16_v_m)))
void vluxseg5ei16(vint32m1_t *, vint32m1_t *, vint32m1_t *, vint32m1_t *, vint32m1_t *, vbool32_t, vint32m1_t, vint32m1_t, vint32m1_t, vint32m1_t, vint32m1_t, const int32_t *, vuint16mf2_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vluxseg5ei16_v)))
void vluxseg5ei16(vint32mf2_t *, vint32mf2_t *, vint32mf2_t *, vint32mf2_t *, vint32mf2_t *, const int32_t *, vuint16mf4_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vluxseg5ei16_v_m)))
void vluxseg5ei16(vint32mf2_t *, vint32mf2_t *, vint32mf2_t *, vint32mf2_t *, vint32mf2_t *, vbool64_t, vint32mf2_t, vint32mf2_t, vint32mf2_t, vint32mf2_t, vint32mf2_t, const int32_t *, vuint16mf4_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vluxseg5ei16_v)))
void vluxseg5ei16(vuint32m1_t *, vuint32m1_t *, vuint32m1_t *, vuint32m1_t *, vuint32m1_t *, const uint32_t *, vuint16mf2_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vluxseg5ei16_v_m)))
void vluxseg5ei16(vuint32m1_t *, vuint32m1_t *, vuint32m1_t *, vuint32m1_t *, vuint32m1_t *, vbool32_t, vuint32m1_t, vuint32m1_t, vuint32m1_t, vuint32m1_t, vuint32m1_t, const uint32_t *, vuint16mf2_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vluxseg5ei16_v)))
void vluxseg5ei16(vuint32mf2_t *, vuint32mf2_t *, vuint32mf2_t *, vuint32mf2_t *, vuint32mf2_t *, const uint32_t *, vuint16mf4_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vluxseg5ei16_v_m)))
void vluxseg5ei16(vuint32mf2_t *, vuint32mf2_t *, vuint32mf2_t *, vuint32mf2_t *, vuint32mf2_t *, vbool64_t, vuint32mf2_t, vuint32mf2_t, vuint32mf2_t, vuint32mf2_t, vuint32mf2_t, const uint32_t *, vuint16mf4_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vluxseg6ei16_v)))
void vluxseg6ei16(vint32m1_t *, vint32m1_t *, vint32m1_t *, vint32m1_t *, vint32m1_t *, vint32m1_t *, const int32_t *, vuint16mf2_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vluxseg6ei16_v_m)))
void vluxseg6ei16(vint32m1_t *, vint32m1_t *, vint32m1_t *, vint32m1_t *, vint32m1_t *, vint32m1_t *, vbool32_t, vint32m1_t, vint32m1_t, vint32m1_t, vint32m1_t, vint32m1_t, vint32m1_t, const int32_t *, vuint16mf2_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vluxseg6ei16_v)))
void vluxseg6ei16(vint32mf2_t *, vint32mf2_t *, vint32mf2_t *, vint32mf2_t *, vint32mf2_t *, vint32mf2_t *, const int32_t *, vuint16mf4_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vluxseg6ei16_v_m)))
void vluxseg6ei16(vint32mf2_t *, vint32mf2_t *, vint32mf2_t *, vint32mf2_t *, vint32mf2_t *, vint32mf2_t *, vbool64_t, vint32mf2_t, vint32mf2_t, vint32mf2_t, vint32mf2_t, vint32mf2_t, vint32mf2_t, const int32_t *, vuint16mf4_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vluxseg6ei16_v)))
void vluxseg6ei16(vuint32m1_t *, vuint32m1_t *, vuint32m1_t *, vuint32m1_t *, vuint32m1_t *, vuint32m1_t *, const uint32_t *, vuint16mf2_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vluxseg6ei16_v_m)))
void vluxseg6ei16(vuint32m1_t *, vuint32m1_t *, vuint32m1_t *, vuint32m1_t *, vuint32m1_t *, vuint32m1_t *, vbool32_t, vuint32m1_t, vuint32m1_t, vuint32m1_t, vuint32m1_t, vuint32m1_t, vuint32m1_t, const uint32_t *, vuint16mf2_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vluxseg6ei16_v)))
void vluxseg6ei16(vuint32mf2_t *, vuint32mf2_t *, vuint32mf2_t *, vuint32mf2_t *, vuint32mf2_t *, vuint32mf2_t *, const uint32_t *, vuint16mf4_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vluxseg6ei16_v_m)))
void vluxseg6ei16(vuint32mf2_t *, vuint32mf2_t *, vuint32mf2_t *, vuint32mf2_t *, vuint32mf2_t *, vuint32mf2_t *, vbool64_t, vuint32mf2_t, vuint32mf2_t, vuint32mf2_t, vuint32mf2_t, vuint32mf2_t, vuint32mf2_t, const uint32_t *, vuint16mf4_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vluxseg7ei16_v)))
void vluxseg7ei16(vint32m1_t *, vint32m1_t *, vint32m1_t *, vint32m1_t *, vint32m1_t *, vint32m1_t *, vint32m1_t *, const int32_t *, vuint16mf2_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vluxseg7ei16_v_m)))
void vluxseg7ei16(vint32m1_t *, vint32m1_t *, vint32m1_t *, vint32m1_t *, vint32m1_t *, vint32m1_t *, vint32m1_t *, vbool32_t, vint32m1_t, vint32m1_t, vint32m1_t, vint32m1_t, vint32m1_t, vint32m1_t, vint32m1_t, const int32_t *, vuint16mf2_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vluxseg7ei16_v)))
void vluxseg7ei16(vint32mf2_t *, vint32mf2_t *, vint32mf2_t *, vint32mf2_t *, vint32mf2_t *, vint32mf2_t *, vint32mf2_t *, const int32_t *, vuint16mf4_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vluxseg7ei16_v_m)))
void vluxseg7ei16(vint32mf2_t *, vint32mf2_t *, vint32mf2_t *, vint32mf2_t *, vint32mf2_t *, vint32mf2_t *, vint32mf2_t *, vbool64_t, vint32mf2_t, vint32mf2_t, vint32mf2_t, vint32mf2_t, vint32mf2_t, vint32mf2_t, vint32mf2_t, const int32_t *, vuint16mf4_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vluxseg7ei16_v)))
void vluxseg7ei16(vuint32m1_t *, vuint32m1_t *, vuint32m1_t *, vuint32m1_t *, vuint32m1_t *, vuint32m1_t *, vuint32m1_t *, const uint32_t *, vuint16mf2_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vluxseg7ei16_v_m)))
void vluxseg7ei16(vuint32m1_t *, vuint32m1_t *, vuint32m1_t *, vuint32m1_t *, vuint32m1_t *, vuint32m1_t *, vuint32m1_t *, vbool32_t, vuint32m1_t, vuint32m1_t, vuint32m1_t, vuint32m1_t, vuint32m1_t, vuint32m1_t, vuint32m1_t, const uint32_t *, vuint16mf2_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vluxseg7ei16_v)))
void vluxseg7ei16(vuint32mf2_t *, vuint32mf2_t *, vuint32mf2_t *, vuint32mf2_t *, vuint32mf2_t *, vuint32mf2_t *, vuint32mf2_t *, const uint32_t *, vuint16mf4_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vluxseg7ei16_v_m)))
void vluxseg7ei16(vuint32mf2_t *, vuint32mf2_t *, vuint32mf2_t *, vuint32mf2_t *, vuint32mf2_t *, vuint32mf2_t *, vuint32mf2_t *, vbool64_t, vuint32mf2_t, vuint32mf2_t, vuint32mf2_t, vuint32mf2_t, vuint32mf2_t, vuint32mf2_t, vuint32mf2_t, const uint32_t *, vuint16mf4_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vluxseg8ei16_v)))
void vluxseg8ei16(vint32m1_t *, vint32m1_t *, vint32m1_t *, vint32m1_t *, vint32m1_t *, vint32m1_t *, vint32m1_t *, vint32m1_t *, const int32_t *, vuint16mf2_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vluxseg8ei16_v_m)))
void vluxseg8ei16(vint32m1_t *, vint32m1_t *, vint32m1_t *, vint32m1_t *, vint32m1_t *, vint32m1_t *, vint32m1_t *, vint32m1_t *, vbool32_t, vint32m1_t, vint32m1_t, vint32m1_t, vint32m1_t, vint32m1_t, vint32m1_t, vint32m1_t, vint32m1_t, const int32_t *, vuint16mf2_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vluxseg8ei16_v)))
void vluxseg8ei16(vint32mf2_t *, vint32mf2_t *, vint32mf2_t *, vint32mf2_t *, vint32mf2_t *, vint32mf2_t *, vint32mf2_t *, vint32mf2_t *, const int32_t *, vuint16mf4_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vluxseg8ei16_v_m)))
void vluxseg8ei16(vint32mf2_t *, vint32mf2_t *, vint32mf2_t *, vint32mf2_t *, vint32mf2_t *, vint32mf2_t *, vint32mf2_t *, vint32mf2_t *, vbool64_t, vint32mf2_t, vint32mf2_t, vint32mf2_t, vint32mf2_t, vint32mf2_t, vint32mf2_t, vint32mf2_t, vint32mf2_t, const int32_t *, vuint16mf4_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vssseg2e8_v)))
void vssseg2e8(int8_t *, ptrdiff_t, vint8m1_t, vint8m1_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vssseg2e8_v_m)))
void vssseg2e8(vbool8_t, int8_t *, ptrdiff_t, vint8m1_t, vint8m1_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vssseg2e8_v)))
void vssseg2e8(int8_t *, ptrdiff_t, vint8m2_t, vint8m2_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vssseg2e8_v_m)))
void vssseg2e8(vbool4_t, int8_t *, ptrdiff_t, vint8m2_t, vint8m2_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vssseg2e8_v)))
void vssseg2e8(int8_t *, ptrdiff_t, vint8m4_t, vint8m4_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vssseg2e8_v_m)))
void vssseg2e8(vbool2_t, int8_t *, ptrdiff_t, vint8m4_t, vint8m4_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vssseg2e8_v)))
void vssseg2e8(int8_t *, ptrdiff_t, vint8mf2_t, vint8mf2_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vssseg2e8_v_m)))
void vssseg2e8(vbool16_t, int8_t *, ptrdiff_t, vint8mf2_t, vint8mf2_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vssseg2e8_v)))
void vssseg2e8(int8_t *, ptrdiff_t, vint8mf4_t, vint8mf4_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vssseg2e8_v_m)))
void vssseg2e8(vbool32_t, int8_t *, ptrdiff_t, vint8mf4_t, vint8mf4_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vssseg2e8_v)))
void vssseg2e8(int8_t *, ptrdiff_t, vint8mf8_t, vint8mf8_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vssseg2e8_v_m)))
void vssseg2e8(vbool64_t, int8_t *, ptrdiff_t, vint8mf8_t, vint8mf8_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vluxseg8ei16_v)))
void vluxseg8ei16(vuint32m1_t *, vuint32m1_t *, vuint32m1_t *, vuint32m1_t *, vuint32m1_t *, vuint32m1_t *, vuint32m1_t *, vuint32m1_t *, const uint32_t *, vuint16mf2_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vluxseg8ei16_v_m)))
void vluxseg8ei16(vuint32m1_t *, vuint32m1_t *, vuint32m1_t *, vuint32m1_t *, vuint32m1_t *, vuint32m1_t *, vuint32m1_t *, vuint32m1_t *, vbool32_t, vuint32m1_t, vuint32m1_t, vuint32m1_t, vuint32m1_t, vuint32m1_t, vuint32m1_t, vuint32m1_t, vuint32m1_t, const uint32_t *, vuint16mf2_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vluxseg8ei16_v)))
void vluxseg8ei16(vuint32mf2_t *, vuint32mf2_t *, vuint32mf2_t *, vuint32mf2_t *, vuint32mf2_t *, vuint32mf2_t *, vuint32mf2_t *, vuint32mf2_t *, const uint32_t *, vuint16mf4_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vluxseg8ei16_v_m)))
void vluxseg8ei16(vuint32mf2_t *, vuint32mf2_t *, vuint32mf2_t *, vuint32mf2_t *, vuint32mf2_t *, vuint32mf2_t *, vuint32mf2_t *, vuint32mf2_t *, vbool64_t, vuint32mf2_t, vuint32mf2_t, vuint32mf2_t, vuint32mf2_t, vuint32mf2_t, vuint32mf2_t, vuint32mf2_t, vuint32mf2_t, const uint32_t *, vuint16mf4_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vluxseg2ei32_v)))
void vluxseg2ei32(vint32m1_t *, vint32m1_t *, const int32_t *, vuint32m1_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vluxseg2ei32_v_m)))
void vluxseg2ei32(vint32m1_t *, vint32m1_t *, vbool32_t, vint32m1_t, vint32m1_t, const int32_t *, vuint32m1_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vluxseg2ei32_v)))
void vluxseg2ei32(vint32m2_t *, vint32m2_t *, const int32_t *, vuint32m2_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vluxseg2ei32_v_m)))
void vluxseg2ei32(vint32m2_t *, vint32m2_t *, vbool16_t, vint32m2_t, vint32m2_t, const int32_t *, vuint32m2_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vluxseg2ei32_v)))
void vluxseg2ei32(vint32m4_t *, vint32m4_t *, const int32_t *, vuint32m4_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vluxseg2ei32_v_m)))
void vluxseg2ei32(vint32m4_t *, vint32m4_t *, vbool8_t, vint32m4_t, vint32m4_t, const int32_t *, vuint32m4_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vluxseg2ei32_v)))
void vluxseg2ei32(vint32mf2_t *, vint32mf2_t *, const int32_t *, vuint32mf2_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vluxseg2ei32_v_m)))
void vluxseg2ei32(vint32mf2_t *, vint32mf2_t *, vbool64_t, vint32mf2_t, vint32mf2_t, const int32_t *, vuint32mf2_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vluxseg2ei32_v)))
void vluxseg2ei32(vuint32m1_t *, vuint32m1_t *, const uint32_t *, vuint32m1_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vluxseg2ei32_v_m)))
void vluxseg2ei32(vuint32m1_t *, vuint32m1_t *, vbool32_t, vuint32m1_t, vuint32m1_t, const uint32_t *, vuint32m1_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vluxseg2ei32_v)))
void vluxseg2ei32(vuint32m2_t *, vuint32m2_t *, const uint32_t *, vuint32m2_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vluxseg2ei32_v_m)))
void vluxseg2ei32(vuint32m2_t *, vuint32m2_t *, vbool16_t, vuint32m2_t, vuint32m2_t, const uint32_t *, vuint32m2_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vluxseg2ei32_v)))
void vluxseg2ei32(vuint32m4_t *, vuint32m4_t *, const uint32_t *, vuint32m4_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vluxseg2ei32_v_m)))
void vluxseg2ei32(vuint32m4_t *, vuint32m4_t *, vbool8_t, vuint32m4_t, vuint32m4_t, const uint32_t *, vuint32m4_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vluxseg2ei32_v)))
void vluxseg2ei32(vuint32mf2_t *, vuint32mf2_t *, const uint32_t *, vuint32mf2_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vluxseg2ei32_v_m)))
void vluxseg2ei32(vuint32mf2_t *, vuint32mf2_t *, vbool64_t, vuint32mf2_t, vuint32mf2_t, const uint32_t *, vuint32mf2_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vluxseg3ei32_v)))
void vluxseg3ei32(vint32m1_t *, vint32m1_t *, vint32m1_t *, const int32_t *, vuint32m1_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vluxseg3ei32_v_m)))
void vluxseg3ei32(vint32m1_t *, vint32m1_t *, vint32m1_t *, vbool32_t, vint32m1_t, vint32m1_t, vint32m1_t, const int32_t *, vuint32m1_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vluxseg3ei32_v)))
void vluxseg3ei32(vint32m2_t *, vint32m2_t *, vint32m2_t *, const int32_t *, vuint32m2_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vluxseg3ei32_v_m)))
void vluxseg3ei32(vint32m2_t *, vint32m2_t *, vint32m2_t *, vbool16_t, vint32m2_t, vint32m2_t, vint32m2_t, const int32_t *, vuint32m2_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vluxseg3ei32_v)))
void vluxseg3ei32(vint32mf2_t *, vint32mf2_t *, vint32mf2_t *, const int32_t *, vuint32mf2_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vluxseg3ei32_v_m)))
void vluxseg3ei32(vint32mf2_t *, vint32mf2_t *, vint32mf2_t *, vbool64_t, vint32mf2_t, vint32mf2_t, vint32mf2_t, const int32_t *, vuint32mf2_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vluxseg3ei32_v)))
void vluxseg3ei32(vuint32m1_t *, vuint32m1_t *, vuint32m1_t *, const uint32_t *, vuint32m1_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vluxseg3ei32_v_m)))
void vluxseg3ei32(vuint32m1_t *, vuint32m1_t *, vuint32m1_t *, vbool32_t, vuint32m1_t, vuint32m1_t, vuint32m1_t, const uint32_t *, vuint32m1_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vluxseg3ei32_v)))
void vluxseg3ei32(vuint32m2_t *, vuint32m2_t *, vuint32m2_t *, const uint32_t *, vuint32m2_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vluxseg3ei32_v_m)))
void vluxseg3ei32(vuint32m2_t *, vuint32m2_t *, vuint32m2_t *, vbool16_t, vuint32m2_t, vuint32m2_t, vuint32m2_t, const uint32_t *, vuint32m2_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vluxseg3ei32_v)))
void vluxseg3ei32(vuint32mf2_t *, vuint32mf2_t *, vuint32mf2_t *, const uint32_t *, vuint32mf2_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vluxseg3ei32_v_m)))
void vluxseg3ei32(vuint32mf2_t *, vuint32mf2_t *, vuint32mf2_t *, vbool64_t, vuint32mf2_t, vuint32mf2_t, vuint32mf2_t, const uint32_t *, vuint32mf2_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vluxseg4ei32_v)))
void vluxseg4ei32(vint32m1_t *, vint32m1_t *, vint32m1_t *, vint32m1_t *, const int32_t *, vuint32m1_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vluxseg4ei32_v_m)))
void vluxseg4ei32(vint32m1_t *, vint32m1_t *, vint32m1_t *, vint32m1_t *, vbool32_t, vint32m1_t, vint32m1_t, vint32m1_t, vint32m1_t, const int32_t *, vuint32m1_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vluxseg4ei32_v)))
void vluxseg4ei32(vint32m2_t *, vint32m2_t *, vint32m2_t *, vint32m2_t *, const int32_t *, vuint32m2_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vluxseg4ei32_v_m)))
void vluxseg4ei32(vint32m2_t *, vint32m2_t *, vint32m2_t *, vint32m2_t *, vbool16_t, vint32m2_t, vint32m2_t, vint32m2_t, vint32m2_t, const int32_t *, vuint32m2_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vluxseg4ei32_v)))
void vluxseg4ei32(vint32mf2_t *, vint32mf2_t *, vint32mf2_t *, vint32mf2_t *, const int32_t *, vuint32mf2_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vluxseg4ei32_v_m)))
void vluxseg4ei32(vint32mf2_t *, vint32mf2_t *, vint32mf2_t *, vint32mf2_t *, vbool64_t, vint32mf2_t, vint32mf2_t, vint32mf2_t, vint32mf2_t, const int32_t *, vuint32mf2_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vluxseg4ei32_v)))
void vluxseg4ei32(vuint32m1_t *, vuint32m1_t *, vuint32m1_t *, vuint32m1_t *, const uint32_t *, vuint32m1_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vluxseg4ei32_v_m)))
void vluxseg4ei32(vuint32m1_t *, vuint32m1_t *, vuint32m1_t *, vuint32m1_t *, vbool32_t, vuint32m1_t, vuint32m1_t, vuint32m1_t, vuint32m1_t, const uint32_t *, vuint32m1_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vluxseg4ei32_v)))
void vluxseg4ei32(vuint32m2_t *, vuint32m2_t *, vuint32m2_t *, vuint32m2_t *, const uint32_t *, vuint32m2_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vluxseg4ei32_v_m)))
void vluxseg4ei32(vuint32m2_t *, vuint32m2_t *, vuint32m2_t *, vuint32m2_t *, vbool16_t, vuint32m2_t, vuint32m2_t, vuint32m2_t, vuint32m2_t, const uint32_t *, vuint32m2_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vluxseg4ei32_v)))
void vluxseg4ei32(vuint32mf2_t *, vuint32mf2_t *, vuint32mf2_t *, vuint32mf2_t *, const uint32_t *, vuint32mf2_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vluxseg4ei32_v_m)))
void vluxseg4ei32(vuint32mf2_t *, vuint32mf2_t *, vuint32mf2_t *, vuint32mf2_t *, vbool64_t, vuint32mf2_t, vuint32mf2_t, vuint32mf2_t, vuint32mf2_t, const uint32_t *, vuint32mf2_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vluxseg5ei32_v)))
void vluxseg5ei32(vint32m1_t *, vint32m1_t *, vint32m1_t *, vint32m1_t *, vint32m1_t *, const int32_t *, vuint32m1_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vluxseg5ei32_v_m)))
void vluxseg5ei32(vint32m1_t *, vint32m1_t *, vint32m1_t *, vint32m1_t *, vint32m1_t *, vbool32_t, vint32m1_t, vint32m1_t, vint32m1_t, vint32m1_t, vint32m1_t, const int32_t *, vuint32m1_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vluxseg5ei32_v)))
void vluxseg5ei32(vint32mf2_t *, vint32mf2_t *, vint32mf2_t *, vint32mf2_t *, vint32mf2_t *, const int32_t *, vuint32mf2_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vluxseg5ei32_v_m)))
void vluxseg5ei32(vint32mf2_t *, vint32mf2_t *, vint32mf2_t *, vint32mf2_t *, vint32mf2_t *, vbool64_t, vint32mf2_t, vint32mf2_t, vint32mf2_t, vint32mf2_t, vint32mf2_t, const int32_t *, vuint32mf2_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vluxseg5ei32_v)))
void vluxseg5ei32(vuint32m1_t *, vuint32m1_t *, vuint32m1_t *, vuint32m1_t *, vuint32m1_t *, const uint32_t *, vuint32m1_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vluxseg5ei32_v_m)))
void vluxseg5ei32(vuint32m1_t *, vuint32m1_t *, vuint32m1_t *, vuint32m1_t *, vuint32m1_t *, vbool32_t, vuint32m1_t, vuint32m1_t, vuint32m1_t, vuint32m1_t, vuint32m1_t, const uint32_t *, vuint32m1_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vluxseg5ei32_v)))
void vluxseg5ei32(vuint32mf2_t *, vuint32mf2_t *, vuint32mf2_t *, vuint32mf2_t *, vuint32mf2_t *, const uint32_t *, vuint32mf2_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vluxseg5ei32_v_m)))
void vluxseg5ei32(vuint32mf2_t *, vuint32mf2_t *, vuint32mf2_t *, vuint32mf2_t *, vuint32mf2_t *, vbool64_t, vuint32mf2_t, vuint32mf2_t, vuint32mf2_t, vuint32mf2_t, vuint32mf2_t, const uint32_t *, vuint32mf2_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vluxseg6ei32_v)))
void vluxseg6ei32(vint32m1_t *, vint32m1_t *, vint32m1_t *, vint32m1_t *, vint32m1_t *, vint32m1_t *, const int32_t *, vuint32m1_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vluxseg6ei32_v_m)))
void vluxseg6ei32(vint32m1_t *, vint32m1_t *, vint32m1_t *, vint32m1_t *, vint32m1_t *, vint32m1_t *, vbool32_t, vint32m1_t, vint32m1_t, vint32m1_t, vint32m1_t, vint32m1_t, vint32m1_t, const int32_t *, vuint32m1_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vluxseg6ei32_v)))
void vluxseg6ei32(vint32mf2_t *, vint32mf2_t *, vint32mf2_t *, vint32mf2_t *, vint32mf2_t *, vint32mf2_t *, const int32_t *, vuint32mf2_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vluxseg6ei32_v_m)))
void vluxseg6ei32(vint32mf2_t *, vint32mf2_t *, vint32mf2_t *, vint32mf2_t *, vint32mf2_t *, vint32mf2_t *, vbool64_t, vint32mf2_t, vint32mf2_t, vint32mf2_t, vint32mf2_t, vint32mf2_t, vint32mf2_t, const int32_t *, vuint32mf2_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vssseg2e8_v)))
void vssseg2e8(uint8_t *, ptrdiff_t, vuint8m1_t, vuint8m1_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vssseg2e8_v_m)))
void vssseg2e8(vbool8_t, uint8_t *, ptrdiff_t, vuint8m1_t, vuint8m1_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vssseg2e8_v)))
void vssseg2e8(uint8_t *, ptrdiff_t, vuint8m2_t, vuint8m2_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vssseg2e8_v_m)))
void vssseg2e8(vbool4_t, uint8_t *, ptrdiff_t, vuint8m2_t, vuint8m2_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vssseg2e8_v)))
void vssseg2e8(uint8_t *, ptrdiff_t, vuint8m4_t, vuint8m4_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vssseg2e8_v_m)))
void vssseg2e8(vbool2_t, uint8_t *, ptrdiff_t, vuint8m4_t, vuint8m4_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vssseg2e8_v)))
void vssseg2e8(uint8_t *, ptrdiff_t, vuint8mf2_t, vuint8mf2_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vssseg2e8_v_m)))
void vssseg2e8(vbool16_t, uint8_t *, ptrdiff_t, vuint8mf2_t, vuint8mf2_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vssseg2e8_v)))
void vssseg2e8(uint8_t *, ptrdiff_t, vuint8mf4_t, vuint8mf4_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vssseg2e8_v_m)))
void vssseg2e8(vbool32_t, uint8_t *, ptrdiff_t, vuint8mf4_t, vuint8mf4_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vssseg2e8_v)))
void vssseg2e8(uint8_t *, ptrdiff_t, vuint8mf8_t, vuint8mf8_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vssseg2e8_v_m)))
void vssseg2e8(vbool64_t, uint8_t *, ptrdiff_t, vuint8mf8_t, vuint8mf8_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vluxseg6ei32_v)))
void vluxseg6ei32(vuint32m1_t *, vuint32m1_t *, vuint32m1_t *, vuint32m1_t *, vuint32m1_t *, vuint32m1_t *, const uint32_t *, vuint32m1_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vluxseg6ei32_v_m)))
void vluxseg6ei32(vuint32m1_t *, vuint32m1_t *, vuint32m1_t *, vuint32m1_t *, vuint32m1_t *, vuint32m1_t *, vbool32_t, vuint32m1_t, vuint32m1_t, vuint32m1_t, vuint32m1_t, vuint32m1_t, vuint32m1_t, const uint32_t *, vuint32m1_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vluxseg6ei32_v)))
void vluxseg6ei32(vuint32mf2_t *, vuint32mf2_t *, vuint32mf2_t *, vuint32mf2_t *, vuint32mf2_t *, vuint32mf2_t *, const uint32_t *, vuint32mf2_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vluxseg6ei32_v_m)))
void vluxseg6ei32(vuint32mf2_t *, vuint32mf2_t *, vuint32mf2_t *, vuint32mf2_t *, vuint32mf2_t *, vuint32mf2_t *, vbool64_t, vuint32mf2_t, vuint32mf2_t, vuint32mf2_t, vuint32mf2_t, vuint32mf2_t, vuint32mf2_t, const uint32_t *, vuint32mf2_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vluxseg7ei32_v)))
void vluxseg7ei32(vint32m1_t *, vint32m1_t *, vint32m1_t *, vint32m1_t *, vint32m1_t *, vint32m1_t *, vint32m1_t *, const int32_t *, vuint32m1_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vluxseg7ei32_v_m)))
void vluxseg7ei32(vint32m1_t *, vint32m1_t *, vint32m1_t *, vint32m1_t *, vint32m1_t *, vint32m1_t *, vint32m1_t *, vbool32_t, vint32m1_t, vint32m1_t, vint32m1_t, vint32m1_t, vint32m1_t, vint32m1_t, vint32m1_t, const int32_t *, vuint32m1_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vluxseg7ei32_v)))
void vluxseg7ei32(vint32mf2_t *, vint32mf2_t *, vint32mf2_t *, vint32mf2_t *, vint32mf2_t *, vint32mf2_t *, vint32mf2_t *, const int32_t *, vuint32mf2_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vluxseg7ei32_v_m)))
void vluxseg7ei32(vint32mf2_t *, vint32mf2_t *, vint32mf2_t *, vint32mf2_t *, vint32mf2_t *, vint32mf2_t *, vint32mf2_t *, vbool64_t, vint32mf2_t, vint32mf2_t, vint32mf2_t, vint32mf2_t, vint32mf2_t, vint32mf2_t, vint32mf2_t, const int32_t *, vuint32mf2_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vluxseg7ei32_v)))
void vluxseg7ei32(vuint32m1_t *, vuint32m1_t *, vuint32m1_t *, vuint32m1_t *, vuint32m1_t *, vuint32m1_t *, vuint32m1_t *, const uint32_t *, vuint32m1_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vluxseg7ei32_v_m)))
void vluxseg7ei32(vuint32m1_t *, vuint32m1_t *, vuint32m1_t *, vuint32m1_t *, vuint32m1_t *, vuint32m1_t *, vuint32m1_t *, vbool32_t, vuint32m1_t, vuint32m1_t, vuint32m1_t, vuint32m1_t, vuint32m1_t, vuint32m1_t, vuint32m1_t, const uint32_t *, vuint32m1_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vluxseg7ei32_v)))
void vluxseg7ei32(vuint32mf2_t *, vuint32mf2_t *, vuint32mf2_t *, vuint32mf2_t *, vuint32mf2_t *, vuint32mf2_t *, vuint32mf2_t *, const uint32_t *, vuint32mf2_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vluxseg7ei32_v_m)))
void vluxseg7ei32(vuint32mf2_t *, vuint32mf2_t *, vuint32mf2_t *, vuint32mf2_t *, vuint32mf2_t *, vuint32mf2_t *, vuint32mf2_t *, vbool64_t, vuint32mf2_t, vuint32mf2_t, vuint32mf2_t, vuint32mf2_t, vuint32mf2_t, vuint32mf2_t, vuint32mf2_t, const uint32_t *, vuint32mf2_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vluxseg8ei32_v)))
void vluxseg8ei32(vint32m1_t *, vint32m1_t *, vint32m1_t *, vint32m1_t *, vint32m1_t *, vint32m1_t *, vint32m1_t *, vint32m1_t *, const int32_t *, vuint32m1_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vluxseg8ei32_v_m)))
void vluxseg8ei32(vint32m1_t *, vint32m1_t *, vint32m1_t *, vint32m1_t *, vint32m1_t *, vint32m1_t *, vint32m1_t *, vint32m1_t *, vbool32_t, vint32m1_t, vint32m1_t, vint32m1_t, vint32m1_t, vint32m1_t, vint32m1_t, vint32m1_t, vint32m1_t, const int32_t *, vuint32m1_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vluxseg8ei32_v)))
void vluxseg8ei32(vint32mf2_t *, vint32mf2_t *, vint32mf2_t *, vint32mf2_t *, vint32mf2_t *, vint32mf2_t *, vint32mf2_t *, vint32mf2_t *, const int32_t *, vuint32mf2_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vluxseg8ei32_v_m)))
void vluxseg8ei32(vint32mf2_t *, vint32mf2_t *, vint32mf2_t *, vint32mf2_t *, vint32mf2_t *, vint32mf2_t *, vint32mf2_t *, vint32mf2_t *, vbool64_t, vint32mf2_t, vint32mf2_t, vint32mf2_t, vint32mf2_t, vint32mf2_t, vint32mf2_t, vint32mf2_t, vint32mf2_t, const int32_t *, vuint32mf2_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vluxseg8ei32_v)))
void vluxseg8ei32(vuint32m1_t *, vuint32m1_t *, vuint32m1_t *, vuint32m1_t *, vuint32m1_t *, vuint32m1_t *, vuint32m1_t *, vuint32m1_t *, const uint32_t *, vuint32m1_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vluxseg8ei32_v_m)))
void vluxseg8ei32(vuint32m1_t *, vuint32m1_t *, vuint32m1_t *, vuint32m1_t *, vuint32m1_t *, vuint32m1_t *, vuint32m1_t *, vuint32m1_t *, vbool32_t, vuint32m1_t, vuint32m1_t, vuint32m1_t, vuint32m1_t, vuint32m1_t, vuint32m1_t, vuint32m1_t, vuint32m1_t, const uint32_t *, vuint32m1_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vluxseg8ei32_v)))
void vluxseg8ei32(vuint32mf2_t *, vuint32mf2_t *, vuint32mf2_t *, vuint32mf2_t *, vuint32mf2_t *, vuint32mf2_t *, vuint32mf2_t *, vuint32mf2_t *, const uint32_t *, vuint32mf2_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vluxseg8ei32_v_m)))
void vluxseg8ei32(vuint32mf2_t *, vuint32mf2_t *, vuint32mf2_t *, vuint32mf2_t *, vuint32mf2_t *, vuint32mf2_t *, vuint32mf2_t *, vuint32mf2_t *, vbool64_t, vuint32mf2_t, vuint32mf2_t, vuint32mf2_t, vuint32mf2_t, vuint32mf2_t, vuint32mf2_t, vuint32mf2_t, vuint32mf2_t, const uint32_t *, vuint32mf2_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vsuxseg2ei8_v)))
void vsuxseg2ei8(int8_t *, vuint8m1_t, vint8m1_t, vint8m1_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vsuxseg2ei8_v_m)))
void vsuxseg2ei8(vbool8_t, int8_t *, vuint8m1_t, vint8m1_t, vint8m1_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vsuxseg2ei8_v)))
void vsuxseg2ei8(int8_t *, vuint8m2_t, vint8m2_t, vint8m2_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vsuxseg2ei8_v_m)))
void vsuxseg2ei8(vbool4_t, int8_t *, vuint8m2_t, vint8m2_t, vint8m2_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vsuxseg2ei8_v)))
void vsuxseg2ei8(int8_t *, vuint8m4_t, vint8m4_t, vint8m4_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vsuxseg2ei8_v_m)))
void vsuxseg2ei8(vbool2_t, int8_t *, vuint8m4_t, vint8m4_t, vint8m4_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vsuxseg2ei8_v)))
void vsuxseg2ei8(int8_t *, vuint8mf2_t, vint8mf2_t, vint8mf2_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vsuxseg2ei8_v_m)))
void vsuxseg2ei8(vbool16_t, int8_t *, vuint8mf2_t, vint8mf2_t, vint8mf2_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vsuxseg2ei8_v)))
void vsuxseg2ei8(int8_t *, vuint8mf4_t, vint8mf4_t, vint8mf4_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vsuxseg2ei8_v_m)))
void vsuxseg2ei8(vbool32_t, int8_t *, vuint8mf4_t, vint8mf4_t, vint8mf4_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vsuxseg2ei8_v)))
void vsuxseg2ei8(int8_t *, vuint8mf8_t, vint8mf8_t, vint8mf8_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vsuxseg2ei8_v_m)))
void vsuxseg2ei8(vbool64_t, int8_t *, vuint8mf8_t, vint8mf8_t, vint8mf8_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vsuxseg2ei8_v)))
void vsuxseg2ei8(uint8_t *, vuint8m1_t, vuint8m1_t, vuint8m1_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vsuxseg2ei8_v_m)))
void vsuxseg2ei8(vbool8_t, uint8_t *, vuint8m1_t, vuint8m1_t, vuint8m1_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vsuxseg2ei8_v)))
void vsuxseg2ei8(uint8_t *, vuint8m2_t, vuint8m2_t, vuint8m2_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vsuxseg2ei8_v_m)))
void vsuxseg2ei8(vbool4_t, uint8_t *, vuint8m2_t, vuint8m2_t, vuint8m2_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vsuxseg2ei8_v)))
void vsuxseg2ei8(uint8_t *, vuint8m4_t, vuint8m4_t, vuint8m4_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vsuxseg2ei8_v_m)))
void vsuxseg2ei8(vbool2_t, uint8_t *, vuint8m4_t, vuint8m4_t, vuint8m4_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vsuxseg2ei8_v)))
void vsuxseg2ei8(uint8_t *, vuint8mf2_t, vuint8mf2_t, vuint8mf2_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vsuxseg2ei8_v_m)))
void vsuxseg2ei8(vbool16_t, uint8_t *, vuint8mf2_t, vuint8mf2_t, vuint8mf2_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vsuxseg2ei8_v)))
void vsuxseg2ei8(uint8_t *, vuint8mf4_t, vuint8mf4_t, vuint8mf4_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vsuxseg2ei8_v_m)))
void vsuxseg2ei8(vbool32_t, uint8_t *, vuint8mf4_t, vuint8mf4_t, vuint8mf4_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vsuxseg2ei8_v)))
void vsuxseg2ei8(uint8_t *, vuint8mf8_t, vuint8mf8_t, vuint8mf8_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vsuxseg2ei8_v_m)))
void vsuxseg2ei8(vbool64_t, uint8_t *, vuint8mf8_t, vuint8mf8_t, vuint8mf8_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vlse8_v_m)))
vint8m1_t vlse8(vbool8_t, vint8m1_t, const int8_t *, ptrdiff_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vlse8_v_m)))
vint8m2_t vlse8(vbool4_t, vint8m2_t, const int8_t *, ptrdiff_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vlse8_v_m)))
vint8m4_t vlse8(vbool2_t, vint8m4_t, const int8_t *, ptrdiff_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vlse8_v_m)))
vint8m8_t vlse8(vbool1_t, vint8m8_t, const int8_t *, ptrdiff_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vlse8_v_m)))
vint8mf2_t vlse8(vbool16_t, vint8mf2_t, const int8_t *, ptrdiff_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vlse8_v_m)))
vint8mf4_t vlse8(vbool32_t, vint8mf4_t, const int8_t *, ptrdiff_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vlse8_v_m)))
vint8mf8_t vlse8(vbool64_t, vint8mf8_t, const int8_t *, ptrdiff_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vneg_v)))
vint8m1_t vneg(vint8m1_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vneg_v_m)))
vint8m1_t vneg(vbool8_t, vint8m1_t, vint8m1_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vneg_v)))
vint8m2_t vneg(vint8m2_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vneg_v_m)))
vint8m2_t vneg(vbool4_t, vint8m2_t, vint8m2_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vneg_v)))
vint8m4_t vneg(vint8m4_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vneg_v_m)))
vint8m4_t vneg(vbool2_t, vint8m4_t, vint8m4_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vneg_v)))
vint8m8_t vneg(vint8m8_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vneg_v_m)))
vint8m8_t vneg(vbool1_t, vint8m8_t, vint8m8_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vneg_v)))
vint8mf2_t vneg(vint8mf2_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vneg_v_m)))
vint8mf2_t vneg(vbool16_t, vint8mf2_t, vint8mf2_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vneg_v)))
vint8mf4_t vneg(vint8mf4_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vneg_v_m)))
vint8mf4_t vneg(vbool32_t, vint8mf4_t, vint8mf4_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vneg_v)))
vint8mf8_t vneg(vint8mf8_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vneg_v_m)))
vint8mf8_t vneg(vbool64_t, vint8mf8_t, vint8mf8_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vneg_v)))
vint16m1_t vneg(vint16m1_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vneg_v_m)))
vint16m1_t vneg(vbool16_t, vint16m1_t, vint16m1_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vneg_v)))
vint16m2_t vneg(vint16m2_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vneg_v_m)))
vint16m2_t vneg(vbool8_t, vint16m2_t, vint16m2_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vneg_v)))
vint16m4_t vneg(vint16m4_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vneg_v_m)))
vint16m4_t vneg(vbool4_t, vint16m4_t, vint16m4_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vneg_v)))
vint16m8_t vneg(vint16m8_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vneg_v_m)))
vint16m8_t vneg(vbool2_t, vint16m8_t, vint16m8_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vneg_v)))
vint16mf2_t vneg(vint16mf2_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vneg_v_m)))
vint16mf2_t vneg(vbool32_t, vint16mf2_t, vint16mf2_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vneg_v)))
vint16mf4_t vneg(vint16mf4_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vneg_v_m)))
vint16mf4_t vneg(vbool64_t, vint16mf4_t, vint16mf4_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vneg_v)))
vint32m1_t vneg(vint32m1_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vneg_v_m)))
vint32m1_t vneg(vbool32_t, vint32m1_t, vint32m1_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vneg_v)))
vint32m2_t vneg(vint32m2_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vneg_v_m)))
vint32m2_t vneg(vbool16_t, vint32m2_t, vint32m2_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vneg_v)))
vint32m4_t vneg(vint32m4_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vneg_v_m)))
vint32m4_t vneg(vbool8_t, vint32m4_t, vint32m4_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vneg_v)))
vint32m8_t vneg(vint32m8_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vneg_v_m)))
vint32m8_t vneg(vbool4_t, vint32m8_t, vint32m8_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vneg_v)))
vint32mf2_t vneg(vint32mf2_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vneg_v_m)))
vint32mf2_t vneg(vbool64_t, vint32mf2_t, vint32mf2_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vnot_v)))
vint8m1_t vnot(vint8m1_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vnot_v_m)))
vint8m1_t vnot(vbool8_t, vint8m1_t, vint8m1_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vnot_v)))
vint8m2_t vnot(vint8m2_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vnot_v_m)))
vint8m2_t vnot(vbool4_t, vint8m2_t, vint8m2_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vnot_v)))
vint8m4_t vnot(vint8m4_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vnot_v_m)))
vint8m4_t vnot(vbool2_t, vint8m4_t, vint8m4_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vnot_v)))
vint8m8_t vnot(vint8m8_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vnot_v_m)))
vint8m8_t vnot(vbool1_t, vint8m8_t, vint8m8_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vnot_v)))
vint8mf2_t vnot(vint8mf2_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vnot_v_m)))
vint8mf2_t vnot(vbool16_t, vint8mf2_t, vint8mf2_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vnot_v)))
vint8mf4_t vnot(vint8mf4_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vnot_v_m)))
vint8mf4_t vnot(vbool32_t, vint8mf4_t, vint8mf4_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vnot_v)))
vint8mf8_t vnot(vint8mf8_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vnot_v_m)))
vint8mf8_t vnot(vbool64_t, vint8mf8_t, vint8mf8_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vnot_v)))
vint16m1_t vnot(vint16m1_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vnot_v_m)))
vint16m1_t vnot(vbool16_t, vint16m1_t, vint16m1_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vnot_v)))
vint16m2_t vnot(vint16m2_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vnot_v_m)))
vint16m2_t vnot(vbool8_t, vint16m2_t, vint16m2_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vnot_v)))
vint16m4_t vnot(vint16m4_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vnot_v_m)))
vint16m4_t vnot(vbool4_t, vint16m4_t, vint16m4_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vnot_v)))
vint16m8_t vnot(vint16m8_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vnot_v_m)))
vint16m8_t vnot(vbool2_t, vint16m8_t, vint16m8_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vnot_v)))
vint16mf2_t vnot(vint16mf2_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vnot_v_m)))
vint16mf2_t vnot(vbool32_t, vint16mf2_t, vint16mf2_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vnot_v)))
vint16mf4_t vnot(vint16mf4_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vnot_v_m)))
vint16mf4_t vnot(vbool64_t, vint16mf4_t, vint16mf4_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vnot_v)))
vint32m1_t vnot(vint32m1_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vnot_v_m)))
vint32m1_t vnot(vbool32_t, vint32m1_t, vint32m1_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vnot_v)))
vint32m2_t vnot(vint32m2_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vnot_v_m)))
vint32m2_t vnot(vbool16_t, vint32m2_t, vint32m2_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vnot_v)))
vint32m4_t vnot(vint32m4_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vnot_v_m)))
vint32m4_t vnot(vbool8_t, vint32m4_t, vint32m4_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vnot_v)))
vint32m8_t vnot(vint32m8_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vnot_v_m)))
vint32m8_t vnot(vbool4_t, vint32m8_t, vint32m8_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vnot_v)))
vint32mf2_t vnot(vint32mf2_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vnot_v_m)))
vint32mf2_t vnot(vbool64_t, vint32mf2_t, vint32mf2_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vnot_v)))
vuint8m1_t vnot(vuint8m1_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vnot_v_m)))
vuint8m1_t vnot(vbool8_t, vuint8m1_t, vuint8m1_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vnot_v)))
vuint8m2_t vnot(vuint8m2_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vnot_v_m)))
vuint8m2_t vnot(vbool4_t, vuint8m2_t, vuint8m2_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vnot_v)))
vuint8m4_t vnot(vuint8m4_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vnot_v_m)))
vuint8m4_t vnot(vbool2_t, vuint8m4_t, vuint8m4_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vnot_v)))
vuint8m8_t vnot(vuint8m8_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vnot_v_m)))
vuint8m8_t vnot(vbool1_t, vuint8m8_t, vuint8m8_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vnot_v)))
vuint8mf2_t vnot(vuint8mf2_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vnot_v_m)))
vuint8mf2_t vnot(vbool16_t, vuint8mf2_t, vuint8mf2_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vnot_v)))
vuint8mf4_t vnot(vuint8mf4_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vnot_v_m)))
vuint8mf4_t vnot(vbool32_t, vuint8mf4_t, vuint8mf4_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vnot_v)))
vuint8mf8_t vnot(vuint8mf8_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vnot_v_m)))
vuint8mf8_t vnot(vbool64_t, vuint8mf8_t, vuint8mf8_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vnot_v)))
vuint16m1_t vnot(vuint16m1_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vnot_v_m)))
vuint16m1_t vnot(vbool16_t, vuint16m1_t, vuint16m1_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vnot_v)))
vuint16m2_t vnot(vuint16m2_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vnot_v_m)))
vuint16m2_t vnot(vbool8_t, vuint16m2_t, vuint16m2_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vnot_v)))
vuint16m4_t vnot(vuint16m4_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vnot_v_m)))
vuint16m4_t vnot(vbool4_t, vuint16m4_t, vuint16m4_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vnot_v)))
vuint16m8_t vnot(vuint16m8_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vnot_v_m)))
vuint16m8_t vnot(vbool2_t, vuint16m8_t, vuint16m8_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vnot_v)))
vuint16mf2_t vnot(vuint16mf2_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vnot_v_m)))
vuint16mf2_t vnot(vbool32_t, vuint16mf2_t, vuint16mf2_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vnot_v)))
vuint16mf4_t vnot(vuint16mf4_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vnot_v_m)))
vuint16mf4_t vnot(vbool64_t, vuint16mf4_t, vuint16mf4_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vnot_v)))
vuint32m1_t vnot(vuint32m1_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vnot_v_m)))
vuint32m1_t vnot(vbool32_t, vuint32m1_t, vuint32m1_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vnot_v)))
vuint32m2_t vnot(vuint32m2_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vnot_v_m)))
vuint32m2_t vnot(vbool16_t, vuint32m2_t, vuint32m2_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vnot_v)))
vuint32m4_t vnot(vuint32m4_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vnot_v_m)))
vuint32m4_t vnot(vbool8_t, vuint32m4_t, vuint32m4_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vnot_v)))
vuint32m8_t vnot(vuint32m8_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vnot_v_m)))
vuint32m8_t vnot(vbool4_t, vuint32m8_t, vuint32m8_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vnot_v)))
vuint32mf2_t vnot(vuint32mf2_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vnot_v_m)))
vuint32mf2_t vnot(vbool64_t, vuint32mf2_t, vuint32mf2_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vmmv_m)))
vbool8_t vmmv(vbool8_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vmmv_m)))
vbool4_t vmmv(vbool4_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vmmv_m)))
vbool2_t vmmv(vbool2_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vmmv_m)))
vbool1_t vmmv(vbool1_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vmmv_m)))
vbool16_t vmmv(vbool16_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vmmv_m)))
vbool32_t vmmv(vbool32_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vmmv_m)))
vbool64_t vmmv(vbool64_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vwcvtu_x_x_v)))
vuint16m2_t vwcvtu_x(vuint8m1_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vwcvtu_x_x_v_m)))
vuint16m2_t vwcvtu_x(vbool8_t, vuint16m2_t, vuint8m1_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vwcvtu_x_x_v)))
vuint16m4_t vwcvtu_x(vuint8m2_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vwcvtu_x_x_v_m)))
vuint16m4_t vwcvtu_x(vbool4_t, vuint16m4_t, vuint8m2_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vwcvtu_x_x_v)))
vuint16m8_t vwcvtu_x(vuint8m4_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vwcvtu_x_x_v_m)))
vuint16m8_t vwcvtu_x(vbool2_t, vuint16m8_t, vuint8m4_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vwcvtu_x_x_v)))
vuint16m1_t vwcvtu_x(vuint8mf2_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vwcvtu_x_x_v_m)))
vuint16m1_t vwcvtu_x(vbool16_t, vuint16m1_t, vuint8mf2_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vwcvtu_x_x_v)))
vuint16mf2_t vwcvtu_x(vuint8mf4_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vwcvtu_x_x_v_m)))
vuint16mf2_t vwcvtu_x(vbool32_t, vuint16mf2_t, vuint8mf4_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vwcvtu_x_x_v)))
vuint16mf4_t vwcvtu_x(vuint8mf8_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vwcvtu_x_x_v_m)))
vuint16mf4_t vwcvtu_x(vbool64_t, vuint16mf4_t, vuint8mf8_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vwcvtu_x_x_v)))
vuint32m2_t vwcvtu_x(vuint16m1_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vwcvtu_x_x_v_m)))
vuint32m2_t vwcvtu_x(vbool16_t, vuint32m2_t, vuint16m1_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vwcvtu_x_x_v)))
vuint32m4_t vwcvtu_x(vuint16m2_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vwcvtu_x_x_v_m)))
vuint32m4_t vwcvtu_x(vbool8_t, vuint32m4_t, vuint16m2_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vwcvtu_x_x_v)))
vuint32m8_t vwcvtu_x(vuint16m4_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vwcvtu_x_x_v_m)))
vuint32m8_t vwcvtu_x(vbool4_t, vuint32m8_t, vuint16m4_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vwcvtu_x_x_v)))
vuint32m1_t vwcvtu_x(vuint16mf2_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vwcvtu_x_x_v_m)))
vuint32m1_t vwcvtu_x(vbool32_t, vuint32m1_t, vuint16mf2_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vwcvtu_x_x_v)))
vuint32mf2_t vwcvtu_x(vuint16mf4_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vwcvtu_x_x_v_m)))
vuint32mf2_t vwcvtu_x(vbool64_t, vuint32mf2_t, vuint16mf4_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vncvt_x_x_w)))
vint8m1_t vncvt_x(vint16m2_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vncvt_x_x_w_m)))
vint8m1_t vncvt_x(vbool8_t, vint8m1_t, vint16m2_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vncvt_x_x_w)))
vint8m2_t vncvt_x(vint16m4_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vncvt_x_x_w_m)))
vint8m2_t vncvt_x(vbool4_t, vint8m2_t, vint16m4_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vncvt_x_x_w)))
vint8m4_t vncvt_x(vint16m8_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vncvt_x_x_w_m)))
vint8m4_t vncvt_x(vbool2_t, vint8m4_t, vint16m8_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vncvt_x_x_w)))
vint8mf2_t vncvt_x(vint16m1_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vncvt_x_x_w_m)))
vint8mf2_t vncvt_x(vbool16_t, vint8mf2_t, vint16m1_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vncvt_x_x_w)))
vint8mf4_t vncvt_x(vint16mf2_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vncvt_x_x_w_m)))
vint8mf4_t vncvt_x(vbool32_t, vint8mf4_t, vint16mf2_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vncvt_x_x_w)))
vint8mf8_t vncvt_x(vint16mf4_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vncvt_x_x_w_m)))
vint8mf8_t vncvt_x(vbool64_t, vint8mf8_t, vint16mf4_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vncvt_x_x_w)))
vint16m1_t vncvt_x(vint32m2_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vncvt_x_x_w_m)))
vint16m1_t vncvt_x(vbool16_t, vint16m1_t, vint32m2_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vncvt_x_x_w)))
vint16m2_t vncvt_x(vint32m4_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vncvt_x_x_w_m)))
vint16m2_t vncvt_x(vbool8_t, vint16m2_t, vint32m4_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vncvt_x_x_w)))
vint16m4_t vncvt_x(vint32m8_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vncvt_x_x_w_m)))
vint16m4_t vncvt_x(vbool4_t, vint16m4_t, vint32m8_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vncvt_x_x_w)))
vint16mf2_t vncvt_x(vint32m1_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vncvt_x_x_w_m)))
vint16mf2_t vncvt_x(vbool32_t, vint16mf2_t, vint32m1_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vncvt_x_x_w)))
vint16mf4_t vncvt_x(vint32mf2_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vncvt_x_x_w_m)))
vint16mf4_t vncvt_x(vbool64_t, vint16mf4_t, vint32mf2_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vle16_v_m)))
vint16m1_t vle16(vbool16_t, vint16m1_t, const int16_t *, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vle16_v_m)))
vint16m2_t vle16(vbool8_t, vint16m2_t, const int16_t *, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vle16_v_m)))
vint16m4_t vle16(vbool4_t, vint16m4_t, const int16_t *, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vle16_v_m)))
vint16m8_t vle16(vbool2_t, vint16m8_t, const int16_t *, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vle16_v_m)))
vint16mf2_t vle16(vbool32_t, vint16mf2_t, const int16_t *, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vle16_v_m)))
vint16mf4_t vle16(vbool64_t, vint16mf4_t, const int16_t *, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vle16_v_m)))
vuint16m1_t vle16(vbool16_t, vuint16m1_t, const uint16_t *, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vle16_v_m)))
vuint16m2_t vle16(vbool8_t, vuint16m2_t, const uint16_t *, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vle16_v_m)))
vuint16m4_t vle16(vbool4_t, vuint16m4_t, const uint16_t *, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vle16_v_m)))
vuint16m8_t vle16(vbool2_t, vuint16m8_t, const uint16_t *, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vle16_v_m)))
vuint16mf2_t vle16(vbool32_t, vuint16mf2_t, const uint16_t *, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vle16_v_m)))
vuint16mf4_t vle16(vbool64_t, vuint16mf4_t, const uint16_t *, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vlse8_v_m)))
vuint8m1_t vlse8(vbool8_t, vuint8m1_t, const uint8_t *, ptrdiff_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vlse8_v_m)))
vuint8m2_t vlse8(vbool4_t, vuint8m2_t, const uint8_t *, ptrdiff_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vlse8_v_m)))
vuint8m4_t vlse8(vbool2_t, vuint8m4_t, const uint8_t *, ptrdiff_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vlse8_v_m)))
vuint8m8_t vlse8(vbool1_t, vuint8m8_t, const uint8_t *, ptrdiff_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vlse8_v_m)))
vuint8mf2_t vlse8(vbool16_t, vuint8mf2_t, const uint8_t *, ptrdiff_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vlse8_v_m)))
vuint8mf4_t vlse8(vbool32_t, vuint8mf4_t, const uint8_t *, ptrdiff_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vlse8_v_m)))
vuint8mf8_t vlse8(vbool64_t, vuint8mf8_t, const uint8_t *, ptrdiff_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vle32_v_m)))
vint32m1_t vle32(vbool32_t, vint32m1_t, const int32_t *, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vle32_v_m)))
vint32m2_t vle32(vbool16_t, vint32m2_t, const int32_t *, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vle32_v_m)))
vint32m4_t vle32(vbool8_t, vint32m4_t, const int32_t *, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vle32_v_m)))
vint32m8_t vle32(vbool4_t, vint32m8_t, const int32_t *, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vle32_v_m)))
vint32mf2_t vle32(vbool64_t, vint32mf2_t, const int32_t *, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vle32_v_m)))
vuint32m1_t vle32(vbool32_t, vuint32m1_t, const uint32_t *, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vle32_v_m)))
vuint32m2_t vle32(vbool16_t, vuint32m2_t, const uint32_t *, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vle32_v_m)))
vuint32m4_t vle32(vbool8_t, vuint32m4_t, const uint32_t *, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vle32_v_m)))
vuint32m8_t vle32(vbool4_t, vuint32m8_t, const uint32_t *, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vle32_v_m)))
vuint32mf2_t vle32(vbool64_t, vuint32mf2_t, const uint32_t *, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vloxseg2ei8_v)))
void vloxseg2ei8(vint8m1_t *, vint8m1_t *, const int8_t *, vuint8m1_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vloxseg2ei8_v_m)))
void vloxseg2ei8(vint8m1_t *, vint8m1_t *, vbool8_t, vint8m1_t, vint8m1_t, const int8_t *, vuint8m1_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vloxseg2ei8_v)))
void vloxseg2ei8(vint8m2_t *, vint8m2_t *, const int8_t *, vuint8m2_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vloxseg2ei8_v_m)))
void vloxseg2ei8(vint8m2_t *, vint8m2_t *, vbool4_t, vint8m2_t, vint8m2_t, const int8_t *, vuint8m2_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vloxseg2ei8_v)))
void vloxseg2ei8(vint8m4_t *, vint8m4_t *, const int8_t *, vuint8m4_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vloxseg2ei8_v_m)))
void vloxseg2ei8(vint8m4_t *, vint8m4_t *, vbool2_t, vint8m4_t, vint8m4_t, const int8_t *, vuint8m4_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vloxseg2ei8_v)))
void vloxseg2ei8(vint8mf2_t *, vint8mf2_t *, const int8_t *, vuint8mf2_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vloxseg2ei8_v_m)))
void vloxseg2ei8(vint8mf2_t *, vint8mf2_t *, vbool16_t, vint8mf2_t, vint8mf2_t, const int8_t *, vuint8mf2_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vloxseg2ei8_v)))
void vloxseg2ei8(vint8mf4_t *, vint8mf4_t *, const int8_t *, vuint8mf4_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vloxseg2ei8_v_m)))
void vloxseg2ei8(vint8mf4_t *, vint8mf4_t *, vbool32_t, vint8mf4_t, vint8mf4_t, const int8_t *, vuint8mf4_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vloxseg2ei8_v)))
void vloxseg2ei8(vint8mf8_t *, vint8mf8_t *, const int8_t *, vuint8mf8_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vloxseg2ei8_v_m)))
void vloxseg2ei8(vint8mf8_t *, vint8mf8_t *, vbool64_t, vint8mf8_t, vint8mf8_t, const int8_t *, vuint8mf8_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vloxseg2ei8_v)))
void vloxseg2ei8(vuint8m1_t *, vuint8m1_t *, const uint8_t *, vuint8m1_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vloxseg2ei8_v_m)))
void vloxseg2ei8(vuint8m1_t *, vuint8m1_t *, vbool8_t, vuint8m1_t, vuint8m1_t, const uint8_t *, vuint8m1_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vloxseg2ei8_v)))
void vloxseg2ei8(vuint8m2_t *, vuint8m2_t *, const uint8_t *, vuint8m2_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vloxseg2ei8_v_m)))
void vloxseg2ei8(vuint8m2_t *, vuint8m2_t *, vbool4_t, vuint8m2_t, vuint8m2_t, const uint8_t *, vuint8m2_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vloxseg2ei8_v)))
void vloxseg2ei8(vuint8m4_t *, vuint8m4_t *, const uint8_t *, vuint8m4_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vloxseg2ei8_v_m)))
void vloxseg2ei8(vuint8m4_t *, vuint8m4_t *, vbool2_t, vuint8m4_t, vuint8m4_t, const uint8_t *, vuint8m4_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vloxseg2ei8_v)))
void vloxseg2ei8(vuint8mf2_t *, vuint8mf2_t *, const uint8_t *, vuint8mf2_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vloxseg2ei8_v_m)))
void vloxseg2ei8(vuint8mf2_t *, vuint8mf2_t *, vbool16_t, vuint8mf2_t, vuint8mf2_t, const uint8_t *, vuint8mf2_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vloxseg2ei8_v)))
void vloxseg2ei8(vuint8mf4_t *, vuint8mf4_t *, const uint8_t *, vuint8mf4_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vloxseg2ei8_v_m)))
void vloxseg2ei8(vuint8mf4_t *, vuint8mf4_t *, vbool32_t, vuint8mf4_t, vuint8mf4_t, const uint8_t *, vuint8mf4_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vloxseg2ei8_v)))
void vloxseg2ei8(vuint8mf8_t *, vuint8mf8_t *, const uint8_t *, vuint8mf8_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vloxseg2ei8_v_m)))
void vloxseg2ei8(vuint8mf8_t *, vuint8mf8_t *, vbool64_t, vuint8mf8_t, vuint8mf8_t, const uint8_t *, vuint8mf8_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vloxseg3ei8_v)))
void vloxseg3ei8(vint8m1_t *, vint8m1_t *, vint8m1_t *, const int8_t *, vuint8m1_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vloxseg3ei8_v_m)))
void vloxseg3ei8(vint8m1_t *, vint8m1_t *, vint8m1_t *, vbool8_t, vint8m1_t, vint8m1_t, vint8m1_t, const int8_t *, vuint8m1_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vloxseg3ei8_v)))
void vloxseg3ei8(vint8m2_t *, vint8m2_t *, vint8m2_t *, const int8_t *, vuint8m2_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vloxseg3ei8_v_m)))
void vloxseg3ei8(vint8m2_t *, vint8m2_t *, vint8m2_t *, vbool4_t, vint8m2_t, vint8m2_t, vint8m2_t, const int8_t *, vuint8m2_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vloxseg3ei8_v)))
void vloxseg3ei8(vint8mf2_t *, vint8mf2_t *, vint8mf2_t *, const int8_t *, vuint8mf2_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vloxseg3ei8_v_m)))
void vloxseg3ei8(vint8mf2_t *, vint8mf2_t *, vint8mf2_t *, vbool16_t, vint8mf2_t, vint8mf2_t, vint8mf2_t, const int8_t *, vuint8mf2_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vloxseg3ei8_v)))
void vloxseg3ei8(vint8mf4_t *, vint8mf4_t *, vint8mf4_t *, const int8_t *, vuint8mf4_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vloxseg3ei8_v_m)))
void vloxseg3ei8(vint8mf4_t *, vint8mf4_t *, vint8mf4_t *, vbool32_t, vint8mf4_t, vint8mf4_t, vint8mf4_t, const int8_t *, vuint8mf4_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vloxseg3ei8_v)))
void vloxseg3ei8(vint8mf8_t *, vint8mf8_t *, vint8mf8_t *, const int8_t *, vuint8mf8_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vloxseg3ei8_v_m)))
void vloxseg3ei8(vint8mf8_t *, vint8mf8_t *, vint8mf8_t *, vbool64_t, vint8mf8_t, vint8mf8_t, vint8mf8_t, const int8_t *, vuint8mf8_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vloxseg3ei8_v)))
void vloxseg3ei8(vuint8m1_t *, vuint8m1_t *, vuint8m1_t *, const uint8_t *, vuint8m1_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vloxseg3ei8_v_m)))
void vloxseg3ei8(vuint8m1_t *, vuint8m1_t *, vuint8m1_t *, vbool8_t, vuint8m1_t, vuint8m1_t, vuint8m1_t, const uint8_t *, vuint8m1_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vloxseg3ei8_v)))
void vloxseg3ei8(vuint8m2_t *, vuint8m2_t *, vuint8m2_t *, const uint8_t *, vuint8m2_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vloxseg3ei8_v_m)))
void vloxseg3ei8(vuint8m2_t *, vuint8m2_t *, vuint8m2_t *, vbool4_t, vuint8m2_t, vuint8m2_t, vuint8m2_t, const uint8_t *, vuint8m2_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vloxseg3ei8_v)))
void vloxseg3ei8(vuint8mf2_t *, vuint8mf2_t *, vuint8mf2_t *, const uint8_t *, vuint8mf2_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vloxseg3ei8_v_m)))
void vloxseg3ei8(vuint8mf2_t *, vuint8mf2_t *, vuint8mf2_t *, vbool16_t, vuint8mf2_t, vuint8mf2_t, vuint8mf2_t, const uint8_t *, vuint8mf2_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vloxseg3ei8_v)))
void vloxseg3ei8(vuint8mf4_t *, vuint8mf4_t *, vuint8mf4_t *, const uint8_t *, vuint8mf4_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vloxseg3ei8_v_m)))
void vloxseg3ei8(vuint8mf4_t *, vuint8mf4_t *, vuint8mf4_t *, vbool32_t, vuint8mf4_t, vuint8mf4_t, vuint8mf4_t, const uint8_t *, vuint8mf4_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vloxseg3ei8_v)))
void vloxseg3ei8(vuint8mf8_t *, vuint8mf8_t *, vuint8mf8_t *, const uint8_t *, vuint8mf8_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vloxseg3ei8_v_m)))
void vloxseg3ei8(vuint8mf8_t *, vuint8mf8_t *, vuint8mf8_t *, vbool64_t, vuint8mf8_t, vuint8mf8_t, vuint8mf8_t, const uint8_t *, vuint8mf8_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vloxseg4ei8_v)))
void vloxseg4ei8(vint8m1_t *, vint8m1_t *, vint8m1_t *, vint8m1_t *, const int8_t *, vuint8m1_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vloxseg4ei8_v_m)))
void vloxseg4ei8(vint8m1_t *, vint8m1_t *, vint8m1_t *, vint8m1_t *, vbool8_t, vint8m1_t, vint8m1_t, vint8m1_t, vint8m1_t, const int8_t *, vuint8m1_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vloxseg4ei8_v)))
void vloxseg4ei8(vint8m2_t *, vint8m2_t *, vint8m2_t *, vint8m2_t *, const int8_t *, vuint8m2_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vloxseg4ei8_v_m)))
void vloxseg4ei8(vint8m2_t *, vint8m2_t *, vint8m2_t *, vint8m2_t *, vbool4_t, vint8m2_t, vint8m2_t, vint8m2_t, vint8m2_t, const int8_t *, vuint8m2_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vloxseg4ei8_v)))
void vloxseg4ei8(vint8mf2_t *, vint8mf2_t *, vint8mf2_t *, vint8mf2_t *, const int8_t *, vuint8mf2_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vloxseg4ei8_v_m)))
void vloxseg4ei8(vint8mf2_t *, vint8mf2_t *, vint8mf2_t *, vint8mf2_t *, vbool16_t, vint8mf2_t, vint8mf2_t, vint8mf2_t, vint8mf2_t, const int8_t *, vuint8mf2_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vloxseg4ei8_v)))
void vloxseg4ei8(vint8mf4_t *, vint8mf4_t *, vint8mf4_t *, vint8mf4_t *, const int8_t *, vuint8mf4_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vloxseg4ei8_v_m)))
void vloxseg4ei8(vint8mf4_t *, vint8mf4_t *, vint8mf4_t *, vint8mf4_t *, vbool32_t, vint8mf4_t, vint8mf4_t, vint8mf4_t, vint8mf4_t, const int8_t *, vuint8mf4_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vloxseg4ei8_v)))
void vloxseg4ei8(vint8mf8_t *, vint8mf8_t *, vint8mf8_t *, vint8mf8_t *, const int8_t *, vuint8mf8_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vloxseg4ei8_v_m)))
void vloxseg4ei8(vint8mf8_t *, vint8mf8_t *, vint8mf8_t *, vint8mf8_t *, vbool64_t, vint8mf8_t, vint8mf8_t, vint8mf8_t, vint8mf8_t, const int8_t *, vuint8mf8_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vloxseg4ei8_v)))
void vloxseg4ei8(vuint8m1_t *, vuint8m1_t *, vuint8m1_t *, vuint8m1_t *, const uint8_t *, vuint8m1_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vloxseg4ei8_v_m)))
void vloxseg4ei8(vuint8m1_t *, vuint8m1_t *, vuint8m1_t *, vuint8m1_t *, vbool8_t, vuint8m1_t, vuint8m1_t, vuint8m1_t, vuint8m1_t, const uint8_t *, vuint8m1_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vloxseg4ei8_v)))
void vloxseg4ei8(vuint8m2_t *, vuint8m2_t *, vuint8m2_t *, vuint8m2_t *, const uint8_t *, vuint8m2_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vloxseg4ei8_v_m)))
void vloxseg4ei8(vuint8m2_t *, vuint8m2_t *, vuint8m2_t *, vuint8m2_t *, vbool4_t, vuint8m2_t, vuint8m2_t, vuint8m2_t, vuint8m2_t, const uint8_t *, vuint8m2_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vloxseg4ei8_v)))
void vloxseg4ei8(vuint8mf2_t *, vuint8mf2_t *, vuint8mf2_t *, vuint8mf2_t *, const uint8_t *, vuint8mf2_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vloxseg4ei8_v_m)))
void vloxseg4ei8(vuint8mf2_t *, vuint8mf2_t *, vuint8mf2_t *, vuint8mf2_t *, vbool16_t, vuint8mf2_t, vuint8mf2_t, vuint8mf2_t, vuint8mf2_t, const uint8_t *, vuint8mf2_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vloxseg4ei8_v)))
void vloxseg4ei8(vuint8mf4_t *, vuint8mf4_t *, vuint8mf4_t *, vuint8mf4_t *, const uint8_t *, vuint8mf4_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vloxseg4ei8_v_m)))
void vloxseg4ei8(vuint8mf4_t *, vuint8mf4_t *, vuint8mf4_t *, vuint8mf4_t *, vbool32_t, vuint8mf4_t, vuint8mf4_t, vuint8mf4_t, vuint8mf4_t, const uint8_t *, vuint8mf4_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vloxseg4ei8_v)))
void vloxseg4ei8(vuint8mf8_t *, vuint8mf8_t *, vuint8mf8_t *, vuint8mf8_t *, const uint8_t *, vuint8mf8_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vloxseg4ei8_v_m)))
void vloxseg4ei8(vuint8mf8_t *, vuint8mf8_t *, vuint8mf8_t *, vuint8mf8_t *, vbool64_t, vuint8mf8_t, vuint8mf8_t, vuint8mf8_t, vuint8mf8_t, const uint8_t *, vuint8mf8_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vloxseg5ei8_v)))
void vloxseg5ei8(vint8m1_t *, vint8m1_t *, vint8m1_t *, vint8m1_t *, vint8m1_t *, const int8_t *, vuint8m1_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vloxseg5ei8_v_m)))
void vloxseg5ei8(vint8m1_t *, vint8m1_t *, vint8m1_t *, vint8m1_t *, vint8m1_t *, vbool8_t, vint8m1_t, vint8m1_t, vint8m1_t, vint8m1_t, vint8m1_t, const int8_t *, vuint8m1_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vloxseg5ei8_v)))
void vloxseg5ei8(vint8mf2_t *, vint8mf2_t *, vint8mf2_t *, vint8mf2_t *, vint8mf2_t *, const int8_t *, vuint8mf2_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vloxseg5ei8_v_m)))
void vloxseg5ei8(vint8mf2_t *, vint8mf2_t *, vint8mf2_t *, vint8mf2_t *, vint8mf2_t *, vbool16_t, vint8mf2_t, vint8mf2_t, vint8mf2_t, vint8mf2_t, vint8mf2_t, const int8_t *, vuint8mf2_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vloxseg5ei8_v)))
void vloxseg5ei8(vint8mf4_t *, vint8mf4_t *, vint8mf4_t *, vint8mf4_t *, vint8mf4_t *, const int8_t *, vuint8mf4_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vloxseg5ei8_v_m)))
void vloxseg5ei8(vint8mf4_t *, vint8mf4_t *, vint8mf4_t *, vint8mf4_t *, vint8mf4_t *, vbool32_t, vint8mf4_t, vint8mf4_t, vint8mf4_t, vint8mf4_t, vint8mf4_t, const int8_t *, vuint8mf4_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vloxseg5ei8_v)))
void vloxseg5ei8(vint8mf8_t *, vint8mf8_t *, vint8mf8_t *, vint8mf8_t *, vint8mf8_t *, const int8_t *, vuint8mf8_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vloxseg5ei8_v_m)))
void vloxseg5ei8(vint8mf8_t *, vint8mf8_t *, vint8mf8_t *, vint8mf8_t *, vint8mf8_t *, vbool64_t, vint8mf8_t, vint8mf8_t, vint8mf8_t, vint8mf8_t, vint8mf8_t, const int8_t *, vuint8mf8_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vloxseg5ei8_v)))
void vloxseg5ei8(vuint8m1_t *, vuint8m1_t *, vuint8m1_t *, vuint8m1_t *, vuint8m1_t *, const uint8_t *, vuint8m1_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vloxseg5ei8_v_m)))
void vloxseg5ei8(vuint8m1_t *, vuint8m1_t *, vuint8m1_t *, vuint8m1_t *, vuint8m1_t *, vbool8_t, vuint8m1_t, vuint8m1_t, vuint8m1_t, vuint8m1_t, vuint8m1_t, const uint8_t *, vuint8m1_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vloxseg5ei8_v)))
void vloxseg5ei8(vuint8mf2_t *, vuint8mf2_t *, vuint8mf2_t *, vuint8mf2_t *, vuint8mf2_t *, const uint8_t *, vuint8mf2_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vloxseg5ei8_v_m)))
void vloxseg5ei8(vuint8mf2_t *, vuint8mf2_t *, vuint8mf2_t *, vuint8mf2_t *, vuint8mf2_t *, vbool16_t, vuint8mf2_t, vuint8mf2_t, vuint8mf2_t, vuint8mf2_t, vuint8mf2_t, const uint8_t *, vuint8mf2_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vloxseg5ei8_v)))
void vloxseg5ei8(vuint8mf4_t *, vuint8mf4_t *, vuint8mf4_t *, vuint8mf4_t *, vuint8mf4_t *, const uint8_t *, vuint8mf4_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vloxseg5ei8_v_m)))
void vloxseg5ei8(vuint8mf4_t *, vuint8mf4_t *, vuint8mf4_t *, vuint8mf4_t *, vuint8mf4_t *, vbool32_t, vuint8mf4_t, vuint8mf4_t, vuint8mf4_t, vuint8mf4_t, vuint8mf4_t, const uint8_t *, vuint8mf4_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vloxseg5ei8_v)))
void vloxseg5ei8(vuint8mf8_t *, vuint8mf8_t *, vuint8mf8_t *, vuint8mf8_t *, vuint8mf8_t *, const uint8_t *, vuint8mf8_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vloxseg5ei8_v_m)))
void vloxseg5ei8(vuint8mf8_t *, vuint8mf8_t *, vuint8mf8_t *, vuint8mf8_t *, vuint8mf8_t *, vbool64_t, vuint8mf8_t, vuint8mf8_t, vuint8mf8_t, vuint8mf8_t, vuint8mf8_t, const uint8_t *, vuint8mf8_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vloxseg6ei8_v)))
void vloxseg6ei8(vint8m1_t *, vint8m1_t *, vint8m1_t *, vint8m1_t *, vint8m1_t *, vint8m1_t *, const int8_t *, vuint8m1_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vloxseg6ei8_v_m)))
void vloxseg6ei8(vint8m1_t *, vint8m1_t *, vint8m1_t *, vint8m1_t *, vint8m1_t *, vint8m1_t *, vbool8_t, vint8m1_t, vint8m1_t, vint8m1_t, vint8m1_t, vint8m1_t, vint8m1_t, const int8_t *, vuint8m1_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vloxseg6ei8_v)))
void vloxseg6ei8(vint8mf2_t *, vint8mf2_t *, vint8mf2_t *, vint8mf2_t *, vint8mf2_t *, vint8mf2_t *, const int8_t *, vuint8mf2_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vloxseg6ei8_v_m)))
void vloxseg6ei8(vint8mf2_t *, vint8mf2_t *, vint8mf2_t *, vint8mf2_t *, vint8mf2_t *, vint8mf2_t *, vbool16_t, vint8mf2_t, vint8mf2_t, vint8mf2_t, vint8mf2_t, vint8mf2_t, vint8mf2_t, const int8_t *, vuint8mf2_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vloxseg6ei8_v)))
void vloxseg6ei8(vint8mf4_t *, vint8mf4_t *, vint8mf4_t *, vint8mf4_t *, vint8mf4_t *, vint8mf4_t *, const int8_t *, vuint8mf4_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vloxseg6ei8_v_m)))
void vloxseg6ei8(vint8mf4_t *, vint8mf4_t *, vint8mf4_t *, vint8mf4_t *, vint8mf4_t *, vint8mf4_t *, vbool32_t, vint8mf4_t, vint8mf4_t, vint8mf4_t, vint8mf4_t, vint8mf4_t, vint8mf4_t, const int8_t *, vuint8mf4_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vloxseg6ei8_v)))
void vloxseg6ei8(vint8mf8_t *, vint8mf8_t *, vint8mf8_t *, vint8mf8_t *, vint8mf8_t *, vint8mf8_t *, const int8_t *, vuint8mf8_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vloxseg6ei8_v_m)))
void vloxseg6ei8(vint8mf8_t *, vint8mf8_t *, vint8mf8_t *, vint8mf8_t *, vint8mf8_t *, vint8mf8_t *, vbool64_t, vint8mf8_t, vint8mf8_t, vint8mf8_t, vint8mf8_t, vint8mf8_t, vint8mf8_t, const int8_t *, vuint8mf8_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vloxseg6ei8_v)))
void vloxseg6ei8(vuint8m1_t *, vuint8m1_t *, vuint8m1_t *, vuint8m1_t *, vuint8m1_t *, vuint8m1_t *, const uint8_t *, vuint8m1_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vloxseg6ei8_v_m)))
void vloxseg6ei8(vuint8m1_t *, vuint8m1_t *, vuint8m1_t *, vuint8m1_t *, vuint8m1_t *, vuint8m1_t *, vbool8_t, vuint8m1_t, vuint8m1_t, vuint8m1_t, vuint8m1_t, vuint8m1_t, vuint8m1_t, const uint8_t *, vuint8m1_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vloxseg6ei8_v)))
void vloxseg6ei8(vuint8mf2_t *, vuint8mf2_t *, vuint8mf2_t *, vuint8mf2_t *, vuint8mf2_t *, vuint8mf2_t *, const uint8_t *, vuint8mf2_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vloxseg6ei8_v_m)))
void vloxseg6ei8(vuint8mf2_t *, vuint8mf2_t *, vuint8mf2_t *, vuint8mf2_t *, vuint8mf2_t *, vuint8mf2_t *, vbool16_t, vuint8mf2_t, vuint8mf2_t, vuint8mf2_t, vuint8mf2_t, vuint8mf2_t, vuint8mf2_t, const uint8_t *, vuint8mf2_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vloxseg6ei8_v)))
void vloxseg6ei8(vuint8mf4_t *, vuint8mf4_t *, vuint8mf4_t *, vuint8mf4_t *, vuint8mf4_t *, vuint8mf4_t *, const uint8_t *, vuint8mf4_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vloxseg6ei8_v_m)))
void vloxseg6ei8(vuint8mf4_t *, vuint8mf4_t *, vuint8mf4_t *, vuint8mf4_t *, vuint8mf4_t *, vuint8mf4_t *, vbool32_t, vuint8mf4_t, vuint8mf4_t, vuint8mf4_t, vuint8mf4_t, vuint8mf4_t, vuint8mf4_t, const uint8_t *, vuint8mf4_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vloxseg6ei8_v)))
void vloxseg6ei8(vuint8mf8_t *, vuint8mf8_t *, vuint8mf8_t *, vuint8mf8_t *, vuint8mf8_t *, vuint8mf8_t *, const uint8_t *, vuint8mf8_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vloxseg6ei8_v_m)))
void vloxseg6ei8(vuint8mf8_t *, vuint8mf8_t *, vuint8mf8_t *, vuint8mf8_t *, vuint8mf8_t *, vuint8mf8_t *, vbool64_t, vuint8mf8_t, vuint8mf8_t, vuint8mf8_t, vuint8mf8_t, vuint8mf8_t, vuint8mf8_t, const uint8_t *, vuint8mf8_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vloxseg7ei8_v)))
void vloxseg7ei8(vint8m1_t *, vint8m1_t *, vint8m1_t *, vint8m1_t *, vint8m1_t *, vint8m1_t *, vint8m1_t *, const int8_t *, vuint8m1_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vloxseg7ei8_v_m)))
void vloxseg7ei8(vint8m1_t *, vint8m1_t *, vint8m1_t *, vint8m1_t *, vint8m1_t *, vint8m1_t *, vint8m1_t *, vbool8_t, vint8m1_t, vint8m1_t, vint8m1_t, vint8m1_t, vint8m1_t, vint8m1_t, vint8m1_t, const int8_t *, vuint8m1_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vloxseg7ei8_v)))
void vloxseg7ei8(vint8mf2_t *, vint8mf2_t *, vint8mf2_t *, vint8mf2_t *, vint8mf2_t *, vint8mf2_t *, vint8mf2_t *, const int8_t *, vuint8mf2_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vloxseg7ei8_v_m)))
void vloxseg7ei8(vint8mf2_t *, vint8mf2_t *, vint8mf2_t *, vint8mf2_t *, vint8mf2_t *, vint8mf2_t *, vint8mf2_t *, vbool16_t, vint8mf2_t, vint8mf2_t, vint8mf2_t, vint8mf2_t, vint8mf2_t, vint8mf2_t, vint8mf2_t, const int8_t *, vuint8mf2_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vloxseg7ei8_v)))
void vloxseg7ei8(vint8mf4_t *, vint8mf4_t *, vint8mf4_t *, vint8mf4_t *, vint8mf4_t *, vint8mf4_t *, vint8mf4_t *, const int8_t *, vuint8mf4_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vloxseg7ei8_v_m)))
void vloxseg7ei8(vint8mf4_t *, vint8mf4_t *, vint8mf4_t *, vint8mf4_t *, vint8mf4_t *, vint8mf4_t *, vint8mf4_t *, vbool32_t, vint8mf4_t, vint8mf4_t, vint8mf4_t, vint8mf4_t, vint8mf4_t, vint8mf4_t, vint8mf4_t, const int8_t *, vuint8mf4_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vloxseg7ei8_v)))
void vloxseg7ei8(vint8mf8_t *, vint8mf8_t *, vint8mf8_t *, vint8mf8_t *, vint8mf8_t *, vint8mf8_t *, vint8mf8_t *, const int8_t *, vuint8mf8_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vloxseg7ei8_v_m)))
void vloxseg7ei8(vint8mf8_t *, vint8mf8_t *, vint8mf8_t *, vint8mf8_t *, vint8mf8_t *, vint8mf8_t *, vint8mf8_t *, vbool64_t, vint8mf8_t, vint8mf8_t, vint8mf8_t, vint8mf8_t, vint8mf8_t, vint8mf8_t, vint8mf8_t, const int8_t *, vuint8mf8_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vloxseg7ei8_v)))
void vloxseg7ei8(vuint8m1_t *, vuint8m1_t *, vuint8m1_t *, vuint8m1_t *, vuint8m1_t *, vuint8m1_t *, vuint8m1_t *, const uint8_t *, vuint8m1_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vloxseg7ei8_v_m)))
void vloxseg7ei8(vuint8m1_t *, vuint8m1_t *, vuint8m1_t *, vuint8m1_t *, vuint8m1_t *, vuint8m1_t *, vuint8m1_t *, vbool8_t, vuint8m1_t, vuint8m1_t, vuint8m1_t, vuint8m1_t, vuint8m1_t, vuint8m1_t, vuint8m1_t, const uint8_t *, vuint8m1_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vloxseg7ei8_v)))
void vloxseg7ei8(vuint8mf2_t *, vuint8mf2_t *, vuint8mf2_t *, vuint8mf2_t *, vuint8mf2_t *, vuint8mf2_t *, vuint8mf2_t *, const uint8_t *, vuint8mf2_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vloxseg7ei8_v_m)))
void vloxseg7ei8(vuint8mf2_t *, vuint8mf2_t *, vuint8mf2_t *, vuint8mf2_t *, vuint8mf2_t *, vuint8mf2_t *, vuint8mf2_t *, vbool16_t, vuint8mf2_t, vuint8mf2_t, vuint8mf2_t, vuint8mf2_t, vuint8mf2_t, vuint8mf2_t, vuint8mf2_t, const uint8_t *, vuint8mf2_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vloxseg7ei8_v)))
void vloxseg7ei8(vuint8mf4_t *, vuint8mf4_t *, vuint8mf4_t *, vuint8mf4_t *, vuint8mf4_t *, vuint8mf4_t *, vuint8mf4_t *, const uint8_t *, vuint8mf4_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vloxseg7ei8_v_m)))
void vloxseg7ei8(vuint8mf4_t *, vuint8mf4_t *, vuint8mf4_t *, vuint8mf4_t *, vuint8mf4_t *, vuint8mf4_t *, vuint8mf4_t *, vbool32_t, vuint8mf4_t, vuint8mf4_t, vuint8mf4_t, vuint8mf4_t, vuint8mf4_t, vuint8mf4_t, vuint8mf4_t, const uint8_t *, vuint8mf4_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vloxseg7ei8_v)))
void vloxseg7ei8(vuint8mf8_t *, vuint8mf8_t *, vuint8mf8_t *, vuint8mf8_t *, vuint8mf8_t *, vuint8mf8_t *, vuint8mf8_t *, const uint8_t *, vuint8mf8_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vloxseg7ei8_v_m)))
void vloxseg7ei8(vuint8mf8_t *, vuint8mf8_t *, vuint8mf8_t *, vuint8mf8_t *, vuint8mf8_t *, vuint8mf8_t *, vuint8mf8_t *, vbool64_t, vuint8mf8_t, vuint8mf8_t, vuint8mf8_t, vuint8mf8_t, vuint8mf8_t, vuint8mf8_t, vuint8mf8_t, const uint8_t *, vuint8mf8_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vloxseg8ei8_v)))
void vloxseg8ei8(vint8m1_t *, vint8m1_t *, vint8m1_t *, vint8m1_t *, vint8m1_t *, vint8m1_t *, vint8m1_t *, vint8m1_t *, const int8_t *, vuint8m1_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vloxseg8ei8_v_m)))
void vloxseg8ei8(vint8m1_t *, vint8m1_t *, vint8m1_t *, vint8m1_t *, vint8m1_t *, vint8m1_t *, vint8m1_t *, vint8m1_t *, vbool8_t, vint8m1_t, vint8m1_t, vint8m1_t, vint8m1_t, vint8m1_t, vint8m1_t, vint8m1_t, vint8m1_t, const int8_t *, vuint8m1_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vloxseg8ei8_v)))
void vloxseg8ei8(vint8mf2_t *, vint8mf2_t *, vint8mf2_t *, vint8mf2_t *, vint8mf2_t *, vint8mf2_t *, vint8mf2_t *, vint8mf2_t *, const int8_t *, vuint8mf2_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vloxseg8ei8_v_m)))
void vloxseg8ei8(vint8mf2_t *, vint8mf2_t *, vint8mf2_t *, vint8mf2_t *, vint8mf2_t *, vint8mf2_t *, vint8mf2_t *, vint8mf2_t *, vbool16_t, vint8mf2_t, vint8mf2_t, vint8mf2_t, vint8mf2_t, vint8mf2_t, vint8mf2_t, vint8mf2_t, vint8mf2_t, const int8_t *, vuint8mf2_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vloxseg8ei8_v)))
void vloxseg8ei8(vint8mf4_t *, vint8mf4_t *, vint8mf4_t *, vint8mf4_t *, vint8mf4_t *, vint8mf4_t *, vint8mf4_t *, vint8mf4_t *, const int8_t *, vuint8mf4_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vloxseg8ei8_v_m)))
void vloxseg8ei8(vint8mf4_t *, vint8mf4_t *, vint8mf4_t *, vint8mf4_t *, vint8mf4_t *, vint8mf4_t *, vint8mf4_t *, vint8mf4_t *, vbool32_t, vint8mf4_t, vint8mf4_t, vint8mf4_t, vint8mf4_t, vint8mf4_t, vint8mf4_t, vint8mf4_t, vint8mf4_t, const int8_t *, vuint8mf4_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vloxseg8ei8_v)))
void vloxseg8ei8(vint8mf8_t *, vint8mf8_t *, vint8mf8_t *, vint8mf8_t *, vint8mf8_t *, vint8mf8_t *, vint8mf8_t *, vint8mf8_t *, const int8_t *, vuint8mf8_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vloxseg8ei8_v_m)))
void vloxseg8ei8(vint8mf8_t *, vint8mf8_t *, vint8mf8_t *, vint8mf8_t *, vint8mf8_t *, vint8mf8_t *, vint8mf8_t *, vint8mf8_t *, vbool64_t, vint8mf8_t, vint8mf8_t, vint8mf8_t, vint8mf8_t, vint8mf8_t, vint8mf8_t, vint8mf8_t, vint8mf8_t, const int8_t *, vuint8mf8_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vloxseg8ei8_v)))
void vloxseg8ei8(vuint8m1_t *, vuint8m1_t *, vuint8m1_t *, vuint8m1_t *, vuint8m1_t *, vuint8m1_t *, vuint8m1_t *, vuint8m1_t *, const uint8_t *, vuint8m1_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vloxseg8ei8_v_m)))
void vloxseg8ei8(vuint8m1_t *, vuint8m1_t *, vuint8m1_t *, vuint8m1_t *, vuint8m1_t *, vuint8m1_t *, vuint8m1_t *, vuint8m1_t *, vbool8_t, vuint8m1_t, vuint8m1_t, vuint8m1_t, vuint8m1_t, vuint8m1_t, vuint8m1_t, vuint8m1_t, vuint8m1_t, const uint8_t *, vuint8m1_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vloxseg8ei8_v)))
void vloxseg8ei8(vuint8mf2_t *, vuint8mf2_t *, vuint8mf2_t *, vuint8mf2_t *, vuint8mf2_t *, vuint8mf2_t *, vuint8mf2_t *, vuint8mf2_t *, const uint8_t *, vuint8mf2_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vloxseg8ei8_v_m)))
void vloxseg8ei8(vuint8mf2_t *, vuint8mf2_t *, vuint8mf2_t *, vuint8mf2_t *, vuint8mf2_t *, vuint8mf2_t *, vuint8mf2_t *, vuint8mf2_t *, vbool16_t, vuint8mf2_t, vuint8mf2_t, vuint8mf2_t, vuint8mf2_t, vuint8mf2_t, vuint8mf2_t, vuint8mf2_t, vuint8mf2_t, const uint8_t *, vuint8mf2_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vloxseg8ei8_v)))
void vloxseg8ei8(vuint8mf4_t *, vuint8mf4_t *, vuint8mf4_t *, vuint8mf4_t *, vuint8mf4_t *, vuint8mf4_t *, vuint8mf4_t *, vuint8mf4_t *, const uint8_t *, vuint8mf4_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vloxseg8ei8_v_m)))
void vloxseg8ei8(vuint8mf4_t *, vuint8mf4_t *, vuint8mf4_t *, vuint8mf4_t *, vuint8mf4_t *, vuint8mf4_t *, vuint8mf4_t *, vuint8mf4_t *, vbool32_t, vuint8mf4_t, vuint8mf4_t, vuint8mf4_t, vuint8mf4_t, vuint8mf4_t, vuint8mf4_t, vuint8mf4_t, vuint8mf4_t, const uint8_t *, vuint8mf4_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vloxseg8ei8_v)))
void vloxseg8ei8(vuint8mf8_t *, vuint8mf8_t *, vuint8mf8_t *, vuint8mf8_t *, vuint8mf8_t *, vuint8mf8_t *, vuint8mf8_t *, vuint8mf8_t *, const uint8_t *, vuint8mf8_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vloxseg8ei8_v_m)))
void vloxseg8ei8(vuint8mf8_t *, vuint8mf8_t *, vuint8mf8_t *, vuint8mf8_t *, vuint8mf8_t *, vuint8mf8_t *, vuint8mf8_t *, vuint8mf8_t *, vbool64_t, vuint8mf8_t, vuint8mf8_t, vuint8mf8_t, vuint8mf8_t, vuint8mf8_t, vuint8mf8_t, vuint8mf8_t, vuint8mf8_t, const uint8_t *, vuint8mf8_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vloxseg2ei16_v)))
void vloxseg2ei16(vint8m1_t *, vint8m1_t *, const int8_t *, vuint16m2_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vloxseg2ei16_v_m)))
void vloxseg2ei16(vint8m1_t *, vint8m1_t *, vbool8_t, vint8m1_t, vint8m1_t, const int8_t *, vuint16m2_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vloxseg2ei16_v)))
void vloxseg2ei16(vint8m2_t *, vint8m2_t *, const int8_t *, vuint16m4_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vloxseg2ei16_v_m)))
void vloxseg2ei16(vint8m2_t *, vint8m2_t *, vbool4_t, vint8m2_t, vint8m2_t, const int8_t *, vuint16m4_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vloxseg2ei16_v)))
void vloxseg2ei16(vint8m4_t *, vint8m4_t *, const int8_t *, vuint16m8_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vloxseg2ei16_v_m)))
void vloxseg2ei16(vint8m4_t *, vint8m4_t *, vbool2_t, vint8m4_t, vint8m4_t, const int8_t *, vuint16m8_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vloxseg2ei16_v)))
void vloxseg2ei16(vint8mf2_t *, vint8mf2_t *, const int8_t *, vuint16m1_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vloxseg2ei16_v_m)))
void vloxseg2ei16(vint8mf2_t *, vint8mf2_t *, vbool16_t, vint8mf2_t, vint8mf2_t, const int8_t *, vuint16m1_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vloxseg2ei16_v)))
void vloxseg2ei16(vint8mf4_t *, vint8mf4_t *, const int8_t *, vuint16mf2_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vloxseg2ei16_v_m)))
void vloxseg2ei16(vint8mf4_t *, vint8mf4_t *, vbool32_t, vint8mf4_t, vint8mf4_t, const int8_t *, vuint16mf2_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vloxseg2ei16_v)))
void vloxseg2ei16(vint8mf8_t *, vint8mf8_t *, const int8_t *, vuint16mf4_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vloxseg2ei16_v_m)))
void vloxseg2ei16(vint8mf8_t *, vint8mf8_t *, vbool64_t, vint8mf8_t, vint8mf8_t, const int8_t *, vuint16mf4_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vloxseg2ei16_v)))
void vloxseg2ei16(vuint8m1_t *, vuint8m1_t *, const uint8_t *, vuint16m2_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vloxseg2ei16_v_m)))
void vloxseg2ei16(vuint8m1_t *, vuint8m1_t *, vbool8_t, vuint8m1_t, vuint8m1_t, const uint8_t *, vuint16m2_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vloxseg2ei16_v)))
void vloxseg2ei16(vuint8m2_t *, vuint8m2_t *, const uint8_t *, vuint16m4_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vloxseg2ei16_v_m)))
void vloxseg2ei16(vuint8m2_t *, vuint8m2_t *, vbool4_t, vuint8m2_t, vuint8m2_t, const uint8_t *, vuint16m4_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vloxseg2ei16_v)))
void vloxseg2ei16(vuint8m4_t *, vuint8m4_t *, const uint8_t *, vuint16m8_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vloxseg2ei16_v_m)))
void vloxseg2ei16(vuint8m4_t *, vuint8m4_t *, vbool2_t, vuint8m4_t, vuint8m4_t, const uint8_t *, vuint16m8_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vloxseg2ei16_v)))
void vloxseg2ei16(vuint8mf2_t *, vuint8mf2_t *, const uint8_t *, vuint16m1_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vloxseg2ei16_v_m)))
void vloxseg2ei16(vuint8mf2_t *, vuint8mf2_t *, vbool16_t, vuint8mf2_t, vuint8mf2_t, const uint8_t *, vuint16m1_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vloxseg2ei16_v)))
void vloxseg2ei16(vuint8mf4_t *, vuint8mf4_t *, const uint8_t *, vuint16mf2_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vloxseg2ei16_v_m)))
void vloxseg2ei16(vuint8mf4_t *, vuint8mf4_t *, vbool32_t, vuint8mf4_t, vuint8mf4_t, const uint8_t *, vuint16mf2_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vloxseg2ei16_v)))
void vloxseg2ei16(vuint8mf8_t *, vuint8mf8_t *, const uint8_t *, vuint16mf4_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vloxseg2ei16_v_m)))
void vloxseg2ei16(vuint8mf8_t *, vuint8mf8_t *, vbool64_t, vuint8mf8_t, vuint8mf8_t, const uint8_t *, vuint16mf4_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vloxseg3ei16_v)))
void vloxseg3ei16(vint8m1_t *, vint8m1_t *, vint8m1_t *, const int8_t *, vuint16m2_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vloxseg3ei16_v_m)))
void vloxseg3ei16(vint8m1_t *, vint8m1_t *, vint8m1_t *, vbool8_t, vint8m1_t, vint8m1_t, vint8m1_t, const int8_t *, vuint16m2_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vloxseg3ei16_v)))
void vloxseg3ei16(vint8m2_t *, vint8m2_t *, vint8m2_t *, const int8_t *, vuint16m4_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vloxseg3ei16_v_m)))
void vloxseg3ei16(vint8m2_t *, vint8m2_t *, vint8m2_t *, vbool4_t, vint8m2_t, vint8m2_t, vint8m2_t, const int8_t *, vuint16m4_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vloxseg3ei16_v)))
void vloxseg3ei16(vint8mf2_t *, vint8mf2_t *, vint8mf2_t *, const int8_t *, vuint16m1_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vloxseg3ei16_v_m)))
void vloxseg3ei16(vint8mf2_t *, vint8mf2_t *, vint8mf2_t *, vbool16_t, vint8mf2_t, vint8mf2_t, vint8mf2_t, const int8_t *, vuint16m1_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vloxseg3ei16_v)))
void vloxseg3ei16(vint8mf4_t *, vint8mf4_t *, vint8mf4_t *, const int8_t *, vuint16mf2_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vloxseg3ei16_v_m)))
void vloxseg3ei16(vint8mf4_t *, vint8mf4_t *, vint8mf4_t *, vbool32_t, vint8mf4_t, vint8mf4_t, vint8mf4_t, const int8_t *, vuint16mf2_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vloxseg3ei16_v)))
void vloxseg3ei16(vint8mf8_t *, vint8mf8_t *, vint8mf8_t *, const int8_t *, vuint16mf4_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vloxseg3ei16_v_m)))
void vloxseg3ei16(vint8mf8_t *, vint8mf8_t *, vint8mf8_t *, vbool64_t, vint8mf8_t, vint8mf8_t, vint8mf8_t, const int8_t *, vuint16mf4_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vloxseg3ei16_v)))
void vloxseg3ei16(vuint8m1_t *, vuint8m1_t *, vuint8m1_t *, const uint8_t *, vuint16m2_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vloxseg3ei16_v_m)))
void vloxseg3ei16(vuint8m1_t *, vuint8m1_t *, vuint8m1_t *, vbool8_t, vuint8m1_t, vuint8m1_t, vuint8m1_t, const uint8_t *, vuint16m2_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vloxseg3ei16_v)))
void vloxseg3ei16(vuint8m2_t *, vuint8m2_t *, vuint8m2_t *, const uint8_t *, vuint16m4_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vloxseg3ei16_v_m)))
void vloxseg3ei16(vuint8m2_t *, vuint8m2_t *, vuint8m2_t *, vbool4_t, vuint8m2_t, vuint8m2_t, vuint8m2_t, const uint8_t *, vuint16m4_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vloxseg3ei16_v)))
void vloxseg3ei16(vuint8mf2_t *, vuint8mf2_t *, vuint8mf2_t *, const uint8_t *, vuint16m1_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vloxseg3ei16_v_m)))
void vloxseg3ei16(vuint8mf2_t *, vuint8mf2_t *, vuint8mf2_t *, vbool16_t, vuint8mf2_t, vuint8mf2_t, vuint8mf2_t, const uint8_t *, vuint16m1_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vloxseg3ei16_v)))
void vloxseg3ei16(vuint8mf4_t *, vuint8mf4_t *, vuint8mf4_t *, const uint8_t *, vuint16mf2_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vloxseg3ei16_v_m)))
void vloxseg3ei16(vuint8mf4_t *, vuint8mf4_t *, vuint8mf4_t *, vbool32_t, vuint8mf4_t, vuint8mf4_t, vuint8mf4_t, const uint8_t *, vuint16mf2_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vloxseg3ei16_v)))
void vloxseg3ei16(vuint8mf8_t *, vuint8mf8_t *, vuint8mf8_t *, const uint8_t *, vuint16mf4_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vloxseg3ei16_v_m)))
void vloxseg3ei16(vuint8mf8_t *, vuint8mf8_t *, vuint8mf8_t *, vbool64_t, vuint8mf8_t, vuint8mf8_t, vuint8mf8_t, const uint8_t *, vuint16mf4_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vloxseg4ei16_v)))
void vloxseg4ei16(vint8m1_t *, vint8m1_t *, vint8m1_t *, vint8m1_t *, const int8_t *, vuint16m2_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vloxseg4ei16_v_m)))
void vloxseg4ei16(vint8m1_t *, vint8m1_t *, vint8m1_t *, vint8m1_t *, vbool8_t, vint8m1_t, vint8m1_t, vint8m1_t, vint8m1_t, const int8_t *, vuint16m2_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vloxseg4ei16_v)))
void vloxseg4ei16(vint8m2_t *, vint8m2_t *, vint8m2_t *, vint8m2_t *, const int8_t *, vuint16m4_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vloxseg4ei16_v_m)))
void vloxseg4ei16(vint8m2_t *, vint8m2_t *, vint8m2_t *, vint8m2_t *, vbool4_t, vint8m2_t, vint8m2_t, vint8m2_t, vint8m2_t, const int8_t *, vuint16m4_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vloxseg4ei16_v)))
void vloxseg4ei16(vint8mf2_t *, vint8mf2_t *, vint8mf2_t *, vint8mf2_t *, const int8_t *, vuint16m1_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vloxseg4ei16_v_m)))
void vloxseg4ei16(vint8mf2_t *, vint8mf2_t *, vint8mf2_t *, vint8mf2_t *, vbool16_t, vint8mf2_t, vint8mf2_t, vint8mf2_t, vint8mf2_t, const int8_t *, vuint16m1_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vloxseg4ei16_v)))
void vloxseg4ei16(vint8mf4_t *, vint8mf4_t *, vint8mf4_t *, vint8mf4_t *, const int8_t *, vuint16mf2_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vloxseg4ei16_v_m)))
void vloxseg4ei16(vint8mf4_t *, vint8mf4_t *, vint8mf4_t *, vint8mf4_t *, vbool32_t, vint8mf4_t, vint8mf4_t, vint8mf4_t, vint8mf4_t, const int8_t *, vuint16mf2_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vloxseg4ei16_v)))
void vloxseg4ei16(vint8mf8_t *, vint8mf8_t *, vint8mf8_t *, vint8mf8_t *, const int8_t *, vuint16mf4_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vloxseg4ei16_v_m)))
void vloxseg4ei16(vint8mf8_t *, vint8mf8_t *, vint8mf8_t *, vint8mf8_t *, vbool64_t, vint8mf8_t, vint8mf8_t, vint8mf8_t, vint8mf8_t, const int8_t *, vuint16mf4_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vloxseg4ei16_v)))
void vloxseg4ei16(vuint8m1_t *, vuint8m1_t *, vuint8m1_t *, vuint8m1_t *, const uint8_t *, vuint16m2_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vloxseg4ei16_v_m)))
void vloxseg4ei16(vuint8m1_t *, vuint8m1_t *, vuint8m1_t *, vuint8m1_t *, vbool8_t, vuint8m1_t, vuint8m1_t, vuint8m1_t, vuint8m1_t, const uint8_t *, vuint16m2_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vloxseg4ei16_v)))
void vloxseg4ei16(vuint8m2_t *, vuint8m2_t *, vuint8m2_t *, vuint8m2_t *, const uint8_t *, vuint16m4_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vloxseg4ei16_v_m)))
void vloxseg4ei16(vuint8m2_t *, vuint8m2_t *, vuint8m2_t *, vuint8m2_t *, vbool4_t, vuint8m2_t, vuint8m2_t, vuint8m2_t, vuint8m2_t, const uint8_t *, vuint16m4_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vloxseg4ei16_v)))
void vloxseg4ei16(vuint8mf2_t *, vuint8mf2_t *, vuint8mf2_t *, vuint8mf2_t *, const uint8_t *, vuint16m1_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vloxseg4ei16_v_m)))
void vloxseg4ei16(vuint8mf2_t *, vuint8mf2_t *, vuint8mf2_t *, vuint8mf2_t *, vbool16_t, vuint8mf2_t, vuint8mf2_t, vuint8mf2_t, vuint8mf2_t, const uint8_t *, vuint16m1_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vloxseg4ei16_v)))
void vloxseg4ei16(vuint8mf4_t *, vuint8mf4_t *, vuint8mf4_t *, vuint8mf4_t *, const uint8_t *, vuint16mf2_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vloxseg4ei16_v_m)))
void vloxseg4ei16(vuint8mf4_t *, vuint8mf4_t *, vuint8mf4_t *, vuint8mf4_t *, vbool32_t, vuint8mf4_t, vuint8mf4_t, vuint8mf4_t, vuint8mf4_t, const uint8_t *, vuint16mf2_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vloxseg4ei16_v)))
void vloxseg4ei16(vuint8mf8_t *, vuint8mf8_t *, vuint8mf8_t *, vuint8mf8_t *, const uint8_t *, vuint16mf4_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vloxseg4ei16_v_m)))
void vloxseg4ei16(vuint8mf8_t *, vuint8mf8_t *, vuint8mf8_t *, vuint8mf8_t *, vbool64_t, vuint8mf8_t, vuint8mf8_t, vuint8mf8_t, vuint8mf8_t, const uint8_t *, vuint16mf4_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vloxseg5ei16_v)))
void vloxseg5ei16(vint8m1_t *, vint8m1_t *, vint8m1_t *, vint8m1_t *, vint8m1_t *, const int8_t *, vuint16m2_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vloxseg5ei16_v_m)))
void vloxseg5ei16(vint8m1_t *, vint8m1_t *, vint8m1_t *, vint8m1_t *, vint8m1_t *, vbool8_t, vint8m1_t, vint8m1_t, vint8m1_t, vint8m1_t, vint8m1_t, const int8_t *, vuint16m2_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vloxseg5ei16_v)))
void vloxseg5ei16(vint8mf2_t *, vint8mf2_t *, vint8mf2_t *, vint8mf2_t *, vint8mf2_t *, const int8_t *, vuint16m1_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vloxseg5ei16_v_m)))
void vloxseg5ei16(vint8mf2_t *, vint8mf2_t *, vint8mf2_t *, vint8mf2_t *, vint8mf2_t *, vbool16_t, vint8mf2_t, vint8mf2_t, vint8mf2_t, vint8mf2_t, vint8mf2_t, const int8_t *, vuint16m1_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vloxseg5ei16_v)))
void vloxseg5ei16(vint8mf4_t *, vint8mf4_t *, vint8mf4_t *, vint8mf4_t *, vint8mf4_t *, const int8_t *, vuint16mf2_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vloxseg5ei16_v_m)))
void vloxseg5ei16(vint8mf4_t *, vint8mf4_t *, vint8mf4_t *, vint8mf4_t *, vint8mf4_t *, vbool32_t, vint8mf4_t, vint8mf4_t, vint8mf4_t, vint8mf4_t, vint8mf4_t, const int8_t *, vuint16mf2_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vloxseg5ei16_v)))
void vloxseg5ei16(vint8mf8_t *, vint8mf8_t *, vint8mf8_t *, vint8mf8_t *, vint8mf8_t *, const int8_t *, vuint16mf4_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vloxseg5ei16_v_m)))
void vloxseg5ei16(vint8mf8_t *, vint8mf8_t *, vint8mf8_t *, vint8mf8_t *, vint8mf8_t *, vbool64_t, vint8mf8_t, vint8mf8_t, vint8mf8_t, vint8mf8_t, vint8mf8_t, const int8_t *, vuint16mf4_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vloxseg5ei16_v)))
void vloxseg5ei16(vuint8m1_t *, vuint8m1_t *, vuint8m1_t *, vuint8m1_t *, vuint8m1_t *, const uint8_t *, vuint16m2_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vloxseg5ei16_v_m)))
void vloxseg5ei16(vuint8m1_t *, vuint8m1_t *, vuint8m1_t *, vuint8m1_t *, vuint8m1_t *, vbool8_t, vuint8m1_t, vuint8m1_t, vuint8m1_t, vuint8m1_t, vuint8m1_t, const uint8_t *, vuint16m2_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vloxseg5ei16_v)))
void vloxseg5ei16(vuint8mf2_t *, vuint8mf2_t *, vuint8mf2_t *, vuint8mf2_t *, vuint8mf2_t *, const uint8_t *, vuint16m1_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vloxseg5ei16_v_m)))
void vloxseg5ei16(vuint8mf2_t *, vuint8mf2_t *, vuint8mf2_t *, vuint8mf2_t *, vuint8mf2_t *, vbool16_t, vuint8mf2_t, vuint8mf2_t, vuint8mf2_t, vuint8mf2_t, vuint8mf2_t, const uint8_t *, vuint16m1_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vloxseg5ei16_v)))
void vloxseg5ei16(vuint8mf4_t *, vuint8mf4_t *, vuint8mf4_t *, vuint8mf4_t *, vuint8mf4_t *, const uint8_t *, vuint16mf2_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vloxseg5ei16_v_m)))
void vloxseg5ei16(vuint8mf4_t *, vuint8mf4_t *, vuint8mf4_t *, vuint8mf4_t *, vuint8mf4_t *, vbool32_t, vuint8mf4_t, vuint8mf4_t, vuint8mf4_t, vuint8mf4_t, vuint8mf4_t, const uint8_t *, vuint16mf2_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vloxseg5ei16_v)))
void vloxseg5ei16(vuint8mf8_t *, vuint8mf8_t *, vuint8mf8_t *, vuint8mf8_t *, vuint8mf8_t *, const uint8_t *, vuint16mf4_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vloxseg5ei16_v_m)))
void vloxseg5ei16(vuint8mf8_t *, vuint8mf8_t *, vuint8mf8_t *, vuint8mf8_t *, vuint8mf8_t *, vbool64_t, vuint8mf8_t, vuint8mf8_t, vuint8mf8_t, vuint8mf8_t, vuint8mf8_t, const uint8_t *, vuint16mf4_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vloxseg6ei16_v)))
void vloxseg6ei16(vint8m1_t *, vint8m1_t *, vint8m1_t *, vint8m1_t *, vint8m1_t *, vint8m1_t *, const int8_t *, vuint16m2_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vloxseg6ei16_v_m)))
void vloxseg6ei16(vint8m1_t *, vint8m1_t *, vint8m1_t *, vint8m1_t *, vint8m1_t *, vint8m1_t *, vbool8_t, vint8m1_t, vint8m1_t, vint8m1_t, vint8m1_t, vint8m1_t, vint8m1_t, const int8_t *, vuint16m2_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vloxseg6ei16_v)))
void vloxseg6ei16(vint8mf2_t *, vint8mf2_t *, vint8mf2_t *, vint8mf2_t *, vint8mf2_t *, vint8mf2_t *, const int8_t *, vuint16m1_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vloxseg6ei16_v_m)))
void vloxseg6ei16(vint8mf2_t *, vint8mf2_t *, vint8mf2_t *, vint8mf2_t *, vint8mf2_t *, vint8mf2_t *, vbool16_t, vint8mf2_t, vint8mf2_t, vint8mf2_t, vint8mf2_t, vint8mf2_t, vint8mf2_t, const int8_t *, vuint16m1_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vloxseg6ei16_v)))
void vloxseg6ei16(vint8mf4_t *, vint8mf4_t *, vint8mf4_t *, vint8mf4_t *, vint8mf4_t *, vint8mf4_t *, const int8_t *, vuint16mf2_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vloxseg6ei16_v_m)))
void vloxseg6ei16(vint8mf4_t *, vint8mf4_t *, vint8mf4_t *, vint8mf4_t *, vint8mf4_t *, vint8mf4_t *, vbool32_t, vint8mf4_t, vint8mf4_t, vint8mf4_t, vint8mf4_t, vint8mf4_t, vint8mf4_t, const int8_t *, vuint16mf2_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vloxseg6ei16_v)))
void vloxseg6ei16(vint8mf8_t *, vint8mf8_t *, vint8mf8_t *, vint8mf8_t *, vint8mf8_t *, vint8mf8_t *, const int8_t *, vuint16mf4_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vloxseg6ei16_v_m)))
void vloxseg6ei16(vint8mf8_t *, vint8mf8_t *, vint8mf8_t *, vint8mf8_t *, vint8mf8_t *, vint8mf8_t *, vbool64_t, vint8mf8_t, vint8mf8_t, vint8mf8_t, vint8mf8_t, vint8mf8_t, vint8mf8_t, const int8_t *, vuint16mf4_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vloxseg6ei16_v)))
void vloxseg6ei16(vuint8m1_t *, vuint8m1_t *, vuint8m1_t *, vuint8m1_t *, vuint8m1_t *, vuint8m1_t *, const uint8_t *, vuint16m2_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vloxseg6ei16_v_m)))
void vloxseg6ei16(vuint8m1_t *, vuint8m1_t *, vuint8m1_t *, vuint8m1_t *, vuint8m1_t *, vuint8m1_t *, vbool8_t, vuint8m1_t, vuint8m1_t, vuint8m1_t, vuint8m1_t, vuint8m1_t, vuint8m1_t, const uint8_t *, vuint16m2_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vloxseg6ei16_v)))
void vloxseg6ei16(vuint8mf2_t *, vuint8mf2_t *, vuint8mf2_t *, vuint8mf2_t *, vuint8mf2_t *, vuint8mf2_t *, const uint8_t *, vuint16m1_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vloxseg6ei16_v_m)))
void vloxseg6ei16(vuint8mf2_t *, vuint8mf2_t *, vuint8mf2_t *, vuint8mf2_t *, vuint8mf2_t *, vuint8mf2_t *, vbool16_t, vuint8mf2_t, vuint8mf2_t, vuint8mf2_t, vuint8mf2_t, vuint8mf2_t, vuint8mf2_t, const uint8_t *, vuint16m1_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vloxseg6ei16_v)))
void vloxseg6ei16(vuint8mf4_t *, vuint8mf4_t *, vuint8mf4_t *, vuint8mf4_t *, vuint8mf4_t *, vuint8mf4_t *, const uint8_t *, vuint16mf2_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vloxseg6ei16_v_m)))
void vloxseg6ei16(vuint8mf4_t *, vuint8mf4_t *, vuint8mf4_t *, vuint8mf4_t *, vuint8mf4_t *, vuint8mf4_t *, vbool32_t, vuint8mf4_t, vuint8mf4_t, vuint8mf4_t, vuint8mf4_t, vuint8mf4_t, vuint8mf4_t, const uint8_t *, vuint16mf2_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vloxseg6ei16_v)))
void vloxseg6ei16(vuint8mf8_t *, vuint8mf8_t *, vuint8mf8_t *, vuint8mf8_t *, vuint8mf8_t *, vuint8mf8_t *, const uint8_t *, vuint16mf4_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vloxseg6ei16_v_m)))
void vloxseg6ei16(vuint8mf8_t *, vuint8mf8_t *, vuint8mf8_t *, vuint8mf8_t *, vuint8mf8_t *, vuint8mf8_t *, vbool64_t, vuint8mf8_t, vuint8mf8_t, vuint8mf8_t, vuint8mf8_t, vuint8mf8_t, vuint8mf8_t, const uint8_t *, vuint16mf4_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vloxseg7ei16_v)))
void vloxseg7ei16(vint8m1_t *, vint8m1_t *, vint8m1_t *, vint8m1_t *, vint8m1_t *, vint8m1_t *, vint8m1_t *, const int8_t *, vuint16m2_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vloxseg7ei16_v_m)))
void vloxseg7ei16(vint8m1_t *, vint8m1_t *, vint8m1_t *, vint8m1_t *, vint8m1_t *, vint8m1_t *, vint8m1_t *, vbool8_t, vint8m1_t, vint8m1_t, vint8m1_t, vint8m1_t, vint8m1_t, vint8m1_t, vint8m1_t, const int8_t *, vuint16m2_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vloxseg7ei16_v)))
void vloxseg7ei16(vint8mf2_t *, vint8mf2_t *, vint8mf2_t *, vint8mf2_t *, vint8mf2_t *, vint8mf2_t *, vint8mf2_t *, const int8_t *, vuint16m1_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vloxseg7ei16_v_m)))
void vloxseg7ei16(vint8mf2_t *, vint8mf2_t *, vint8mf2_t *, vint8mf2_t *, vint8mf2_t *, vint8mf2_t *, vint8mf2_t *, vbool16_t, vint8mf2_t, vint8mf2_t, vint8mf2_t, vint8mf2_t, vint8mf2_t, vint8mf2_t, vint8mf2_t, const int8_t *, vuint16m1_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vloxseg7ei16_v)))
void vloxseg7ei16(vint8mf4_t *, vint8mf4_t *, vint8mf4_t *, vint8mf4_t *, vint8mf4_t *, vint8mf4_t *, vint8mf4_t *, const int8_t *, vuint16mf2_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vloxseg7ei16_v_m)))
void vloxseg7ei16(vint8mf4_t *, vint8mf4_t *, vint8mf4_t *, vint8mf4_t *, vint8mf4_t *, vint8mf4_t *, vint8mf4_t *, vbool32_t, vint8mf4_t, vint8mf4_t, vint8mf4_t, vint8mf4_t, vint8mf4_t, vint8mf4_t, vint8mf4_t, const int8_t *, vuint16mf2_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vloxseg7ei16_v)))
void vloxseg7ei16(vint8mf8_t *, vint8mf8_t *, vint8mf8_t *, vint8mf8_t *, vint8mf8_t *, vint8mf8_t *, vint8mf8_t *, const int8_t *, vuint16mf4_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vloxseg7ei16_v_m)))
void vloxseg7ei16(vint8mf8_t *, vint8mf8_t *, vint8mf8_t *, vint8mf8_t *, vint8mf8_t *, vint8mf8_t *, vint8mf8_t *, vbool64_t, vint8mf8_t, vint8mf8_t, vint8mf8_t, vint8mf8_t, vint8mf8_t, vint8mf8_t, vint8mf8_t, const int8_t *, vuint16mf4_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vloxseg7ei16_v)))
void vloxseg7ei16(vuint8m1_t *, vuint8m1_t *, vuint8m1_t *, vuint8m1_t *, vuint8m1_t *, vuint8m1_t *, vuint8m1_t *, const uint8_t *, vuint16m2_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vloxseg7ei16_v_m)))
void vloxseg7ei16(vuint8m1_t *, vuint8m1_t *, vuint8m1_t *, vuint8m1_t *, vuint8m1_t *, vuint8m1_t *, vuint8m1_t *, vbool8_t, vuint8m1_t, vuint8m1_t, vuint8m1_t, vuint8m1_t, vuint8m1_t, vuint8m1_t, vuint8m1_t, const uint8_t *, vuint16m2_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vloxseg7ei16_v)))
void vloxseg7ei16(vuint8mf2_t *, vuint8mf2_t *, vuint8mf2_t *, vuint8mf2_t *, vuint8mf2_t *, vuint8mf2_t *, vuint8mf2_t *, const uint8_t *, vuint16m1_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vloxseg7ei16_v_m)))
void vloxseg7ei16(vuint8mf2_t *, vuint8mf2_t *, vuint8mf2_t *, vuint8mf2_t *, vuint8mf2_t *, vuint8mf2_t *, vuint8mf2_t *, vbool16_t, vuint8mf2_t, vuint8mf2_t, vuint8mf2_t, vuint8mf2_t, vuint8mf2_t, vuint8mf2_t, vuint8mf2_t, const uint8_t *, vuint16m1_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vloxseg7ei16_v)))
void vloxseg7ei16(vuint8mf4_t *, vuint8mf4_t *, vuint8mf4_t *, vuint8mf4_t *, vuint8mf4_t *, vuint8mf4_t *, vuint8mf4_t *, const uint8_t *, vuint16mf2_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vloxseg7ei16_v_m)))
void vloxseg7ei16(vuint8mf4_t *, vuint8mf4_t *, vuint8mf4_t *, vuint8mf4_t *, vuint8mf4_t *, vuint8mf4_t *, vuint8mf4_t *, vbool32_t, vuint8mf4_t, vuint8mf4_t, vuint8mf4_t, vuint8mf4_t, vuint8mf4_t, vuint8mf4_t, vuint8mf4_t, const uint8_t *, vuint16mf2_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vloxseg7ei16_v)))
void vloxseg7ei16(vuint8mf8_t *, vuint8mf8_t *, vuint8mf8_t *, vuint8mf8_t *, vuint8mf8_t *, vuint8mf8_t *, vuint8mf8_t *, const uint8_t *, vuint16mf4_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vloxseg7ei16_v_m)))
void vloxseg7ei16(vuint8mf8_t *, vuint8mf8_t *, vuint8mf8_t *, vuint8mf8_t *, vuint8mf8_t *, vuint8mf8_t *, vuint8mf8_t *, vbool64_t, vuint8mf8_t, vuint8mf8_t, vuint8mf8_t, vuint8mf8_t, vuint8mf8_t, vuint8mf8_t, vuint8mf8_t, const uint8_t *, vuint16mf4_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vloxseg8ei16_v)))
void vloxseg8ei16(vint8m1_t *, vint8m1_t *, vint8m1_t *, vint8m1_t *, vint8m1_t *, vint8m1_t *, vint8m1_t *, vint8m1_t *, const int8_t *, vuint16m2_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vloxseg8ei16_v_m)))
void vloxseg8ei16(vint8m1_t *, vint8m1_t *, vint8m1_t *, vint8m1_t *, vint8m1_t *, vint8m1_t *, vint8m1_t *, vint8m1_t *, vbool8_t, vint8m1_t, vint8m1_t, vint8m1_t, vint8m1_t, vint8m1_t, vint8m1_t, vint8m1_t, vint8m1_t, const int8_t *, vuint16m2_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vloxseg8ei16_v)))
void vloxseg8ei16(vint8mf2_t *, vint8mf2_t *, vint8mf2_t *, vint8mf2_t *, vint8mf2_t *, vint8mf2_t *, vint8mf2_t *, vint8mf2_t *, const int8_t *, vuint16m1_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vloxseg8ei16_v_m)))
void vloxseg8ei16(vint8mf2_t *, vint8mf2_t *, vint8mf2_t *, vint8mf2_t *, vint8mf2_t *, vint8mf2_t *, vint8mf2_t *, vint8mf2_t *, vbool16_t, vint8mf2_t, vint8mf2_t, vint8mf2_t, vint8mf2_t, vint8mf2_t, vint8mf2_t, vint8mf2_t, vint8mf2_t, const int8_t *, vuint16m1_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vloxseg8ei16_v)))
void vloxseg8ei16(vint8mf4_t *, vint8mf4_t *, vint8mf4_t *, vint8mf4_t *, vint8mf4_t *, vint8mf4_t *, vint8mf4_t *, vint8mf4_t *, const int8_t *, vuint16mf2_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vloxseg8ei16_v_m)))
void vloxseg8ei16(vint8mf4_t *, vint8mf4_t *, vint8mf4_t *, vint8mf4_t *, vint8mf4_t *, vint8mf4_t *, vint8mf4_t *, vint8mf4_t *, vbool32_t, vint8mf4_t, vint8mf4_t, vint8mf4_t, vint8mf4_t, vint8mf4_t, vint8mf4_t, vint8mf4_t, vint8mf4_t, const int8_t *, vuint16mf2_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vloxseg8ei16_v)))
void vloxseg8ei16(vint8mf8_t *, vint8mf8_t *, vint8mf8_t *, vint8mf8_t *, vint8mf8_t *, vint8mf8_t *, vint8mf8_t *, vint8mf8_t *, const int8_t *, vuint16mf4_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vloxseg8ei16_v_m)))
void vloxseg8ei16(vint8mf8_t *, vint8mf8_t *, vint8mf8_t *, vint8mf8_t *, vint8mf8_t *, vint8mf8_t *, vint8mf8_t *, vint8mf8_t *, vbool64_t, vint8mf8_t, vint8mf8_t, vint8mf8_t, vint8mf8_t, vint8mf8_t, vint8mf8_t, vint8mf8_t, vint8mf8_t, const int8_t *, vuint16mf4_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vloxseg8ei16_v)))
void vloxseg8ei16(vuint8m1_t *, vuint8m1_t *, vuint8m1_t *, vuint8m1_t *, vuint8m1_t *, vuint8m1_t *, vuint8m1_t *, vuint8m1_t *, const uint8_t *, vuint16m2_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vloxseg8ei16_v_m)))
void vloxseg8ei16(vuint8m1_t *, vuint8m1_t *, vuint8m1_t *, vuint8m1_t *, vuint8m1_t *, vuint8m1_t *, vuint8m1_t *, vuint8m1_t *, vbool8_t, vuint8m1_t, vuint8m1_t, vuint8m1_t, vuint8m1_t, vuint8m1_t, vuint8m1_t, vuint8m1_t, vuint8m1_t, const uint8_t *, vuint16m2_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vloxseg8ei16_v)))
void vloxseg8ei16(vuint8mf2_t *, vuint8mf2_t *, vuint8mf2_t *, vuint8mf2_t *, vuint8mf2_t *, vuint8mf2_t *, vuint8mf2_t *, vuint8mf2_t *, const uint8_t *, vuint16m1_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vloxseg8ei16_v_m)))
void vloxseg8ei16(vuint8mf2_t *, vuint8mf2_t *, vuint8mf2_t *, vuint8mf2_t *, vuint8mf2_t *, vuint8mf2_t *, vuint8mf2_t *, vuint8mf2_t *, vbool16_t, vuint8mf2_t, vuint8mf2_t, vuint8mf2_t, vuint8mf2_t, vuint8mf2_t, vuint8mf2_t, vuint8mf2_t, vuint8mf2_t, const uint8_t *, vuint16m1_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vloxseg8ei16_v)))
void vloxseg8ei16(vuint8mf4_t *, vuint8mf4_t *, vuint8mf4_t *, vuint8mf4_t *, vuint8mf4_t *, vuint8mf4_t *, vuint8mf4_t *, vuint8mf4_t *, const uint8_t *, vuint16mf2_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vloxseg8ei16_v_m)))
void vloxseg8ei16(vuint8mf4_t *, vuint8mf4_t *, vuint8mf4_t *, vuint8mf4_t *, vuint8mf4_t *, vuint8mf4_t *, vuint8mf4_t *, vuint8mf4_t *, vbool32_t, vuint8mf4_t, vuint8mf4_t, vuint8mf4_t, vuint8mf4_t, vuint8mf4_t, vuint8mf4_t, vuint8mf4_t, vuint8mf4_t, const uint8_t *, vuint16mf2_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vloxseg8ei16_v)))
void vloxseg8ei16(vuint8mf8_t *, vuint8mf8_t *, vuint8mf8_t *, vuint8mf8_t *, vuint8mf8_t *, vuint8mf8_t *, vuint8mf8_t *, vuint8mf8_t *, const uint8_t *, vuint16mf4_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vloxseg8ei16_v_m)))
void vloxseg8ei16(vuint8mf8_t *, vuint8mf8_t *, vuint8mf8_t *, vuint8mf8_t *, vuint8mf8_t *, vuint8mf8_t *, vuint8mf8_t *, vuint8mf8_t *, vbool64_t, vuint8mf8_t, vuint8mf8_t, vuint8mf8_t, vuint8mf8_t, vuint8mf8_t, vuint8mf8_t, vuint8mf8_t, vuint8mf8_t, const uint8_t *, vuint16mf4_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vloxseg2ei32_v)))
void vloxseg2ei32(vint8m1_t *, vint8m1_t *, const int8_t *, vuint32m4_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vloxseg2ei32_v_m)))
void vloxseg2ei32(vint8m1_t *, vint8m1_t *, vbool8_t, vint8m1_t, vint8m1_t, const int8_t *, vuint32m4_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vloxseg2ei32_v)))
void vloxseg2ei32(vint8m2_t *, vint8m2_t *, const int8_t *, vuint32m8_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vloxseg2ei32_v_m)))
void vloxseg2ei32(vint8m2_t *, vint8m2_t *, vbool4_t, vint8m2_t, vint8m2_t, const int8_t *, vuint32m8_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vloxseg2ei32_v)))
void vloxseg2ei32(vint8mf2_t *, vint8mf2_t *, const int8_t *, vuint32m2_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vloxseg2ei32_v_m)))
void vloxseg2ei32(vint8mf2_t *, vint8mf2_t *, vbool16_t, vint8mf2_t, vint8mf2_t, const int8_t *, vuint32m2_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vloxseg2ei32_v)))
void vloxseg2ei32(vint8mf4_t *, vint8mf4_t *, const int8_t *, vuint32m1_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vloxseg2ei32_v_m)))
void vloxseg2ei32(vint8mf4_t *, vint8mf4_t *, vbool32_t, vint8mf4_t, vint8mf4_t, const int8_t *, vuint32m1_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vloxseg2ei32_v)))
void vloxseg2ei32(vint8mf8_t *, vint8mf8_t *, const int8_t *, vuint32mf2_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vloxseg2ei32_v_m)))
void vloxseg2ei32(vint8mf8_t *, vint8mf8_t *, vbool64_t, vint8mf8_t, vint8mf8_t, const int8_t *, vuint32mf2_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vloxseg2ei32_v)))
void vloxseg2ei32(vuint8m1_t *, vuint8m1_t *, const uint8_t *, vuint32m4_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vloxseg2ei32_v_m)))
void vloxseg2ei32(vuint8m1_t *, vuint8m1_t *, vbool8_t, vuint8m1_t, vuint8m1_t, const uint8_t *, vuint32m4_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vloxseg2ei32_v)))
void vloxseg2ei32(vuint8m2_t *, vuint8m2_t *, const uint8_t *, vuint32m8_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vloxseg2ei32_v_m)))
void vloxseg2ei32(vuint8m2_t *, vuint8m2_t *, vbool4_t, vuint8m2_t, vuint8m2_t, const uint8_t *, vuint32m8_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vloxseg2ei32_v)))
void vloxseg2ei32(vuint8mf2_t *, vuint8mf2_t *, const uint8_t *, vuint32m2_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vloxseg2ei32_v_m)))
void vloxseg2ei32(vuint8mf2_t *, vuint8mf2_t *, vbool16_t, vuint8mf2_t, vuint8mf2_t, const uint8_t *, vuint32m2_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vloxseg2ei32_v)))
void vloxseg2ei32(vuint8mf4_t *, vuint8mf4_t *, const uint8_t *, vuint32m1_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vloxseg2ei32_v_m)))
void vloxseg2ei32(vuint8mf4_t *, vuint8mf4_t *, vbool32_t, vuint8mf4_t, vuint8mf4_t, const uint8_t *, vuint32m1_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vloxseg2ei32_v)))
void vloxseg2ei32(vuint8mf8_t *, vuint8mf8_t *, const uint8_t *, vuint32mf2_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vloxseg2ei32_v_m)))
void vloxseg2ei32(vuint8mf8_t *, vuint8mf8_t *, vbool64_t, vuint8mf8_t, vuint8mf8_t, const uint8_t *, vuint32mf2_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vse16_v)))
void vse16(int16_t *, vint16m1_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vse16_v_m)))
void vse16(vbool16_t, int16_t *, vint16m1_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vse16_v)))
void vse16(int16_t *, vint16m2_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vse16_v_m)))
void vse16(vbool8_t, int16_t *, vint16m2_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vse16_v)))
void vse16(int16_t *, vint16m4_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vse16_v_m)))
void vse16(vbool4_t, int16_t *, vint16m4_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vse16_v)))
void vse16(int16_t *, vint16m8_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vse16_v_m)))
void vse16(vbool2_t, int16_t *, vint16m8_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vse16_v)))
void vse16(int16_t *, vint16mf2_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vse16_v_m)))
void vse16(vbool32_t, int16_t *, vint16mf2_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vse16_v)))
void vse16(int16_t *, vint16mf4_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vse16_v_m)))
void vse16(vbool64_t, int16_t *, vint16mf4_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vloxseg3ei32_v)))
void vloxseg3ei32(vint8m1_t *, vint8m1_t *, vint8m1_t *, const int8_t *, vuint32m4_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vloxseg3ei32_v_m)))
void vloxseg3ei32(vint8m1_t *, vint8m1_t *, vint8m1_t *, vbool8_t, vint8m1_t, vint8m1_t, vint8m1_t, const int8_t *, vuint32m4_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vloxseg3ei32_v)))
void vloxseg3ei32(vint8m2_t *, vint8m2_t *, vint8m2_t *, const int8_t *, vuint32m8_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vloxseg3ei32_v_m)))
void vloxseg3ei32(vint8m2_t *, vint8m2_t *, vint8m2_t *, vbool4_t, vint8m2_t, vint8m2_t, vint8m2_t, const int8_t *, vuint32m8_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vloxseg3ei32_v)))
void vloxseg3ei32(vint8mf2_t *, vint8mf2_t *, vint8mf2_t *, const int8_t *, vuint32m2_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vloxseg3ei32_v_m)))
void vloxseg3ei32(vint8mf2_t *, vint8mf2_t *, vint8mf2_t *, vbool16_t, vint8mf2_t, vint8mf2_t, vint8mf2_t, const int8_t *, vuint32m2_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vloxseg3ei32_v)))
void vloxseg3ei32(vint8mf4_t *, vint8mf4_t *, vint8mf4_t *, const int8_t *, vuint32m1_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vloxseg3ei32_v_m)))
void vloxseg3ei32(vint8mf4_t *, vint8mf4_t *, vint8mf4_t *, vbool32_t, vint8mf4_t, vint8mf4_t, vint8mf4_t, const int8_t *, vuint32m1_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vloxseg3ei32_v)))
void vloxseg3ei32(vint8mf8_t *, vint8mf8_t *, vint8mf8_t *, const int8_t *, vuint32mf2_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vloxseg3ei32_v_m)))
void vloxseg3ei32(vint8mf8_t *, vint8mf8_t *, vint8mf8_t *, vbool64_t, vint8mf8_t, vint8mf8_t, vint8mf8_t, const int8_t *, vuint32mf2_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vloxseg3ei32_v)))
void vloxseg3ei32(vuint8m1_t *, vuint8m1_t *, vuint8m1_t *, const uint8_t *, vuint32m4_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vloxseg3ei32_v_m)))
void vloxseg3ei32(vuint8m1_t *, vuint8m1_t *, vuint8m1_t *, vbool8_t, vuint8m1_t, vuint8m1_t, vuint8m1_t, const uint8_t *, vuint32m4_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vloxseg3ei32_v)))
void vloxseg3ei32(vuint8m2_t *, vuint8m2_t *, vuint8m2_t *, const uint8_t *, vuint32m8_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vloxseg3ei32_v_m)))
void vloxseg3ei32(vuint8m2_t *, vuint8m2_t *, vuint8m2_t *, vbool4_t, vuint8m2_t, vuint8m2_t, vuint8m2_t, const uint8_t *, vuint32m8_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vloxseg3ei32_v)))
void vloxseg3ei32(vuint8mf2_t *, vuint8mf2_t *, vuint8mf2_t *, const uint8_t *, vuint32m2_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vloxseg3ei32_v_m)))
void vloxseg3ei32(vuint8mf2_t *, vuint8mf2_t *, vuint8mf2_t *, vbool16_t, vuint8mf2_t, vuint8mf2_t, vuint8mf2_t, const uint8_t *, vuint32m2_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vloxseg3ei32_v)))
void vloxseg3ei32(vuint8mf4_t *, vuint8mf4_t *, vuint8mf4_t *, const uint8_t *, vuint32m1_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vloxseg3ei32_v_m)))
void vloxseg3ei32(vuint8mf4_t *, vuint8mf4_t *, vuint8mf4_t *, vbool32_t, vuint8mf4_t, vuint8mf4_t, vuint8mf4_t, const uint8_t *, vuint32m1_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vloxseg3ei32_v)))
void vloxseg3ei32(vuint8mf8_t *, vuint8mf8_t *, vuint8mf8_t *, const uint8_t *, vuint32mf2_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vloxseg3ei32_v_m)))
void vloxseg3ei32(vuint8mf8_t *, vuint8mf8_t *, vuint8mf8_t *, vbool64_t, vuint8mf8_t, vuint8mf8_t, vuint8mf8_t, const uint8_t *, vuint32mf2_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vloxseg4ei32_v)))
void vloxseg4ei32(vint8m1_t *, vint8m1_t *, vint8m1_t *, vint8m1_t *, const int8_t *, vuint32m4_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vloxseg4ei32_v_m)))
void vloxseg4ei32(vint8m1_t *, vint8m1_t *, vint8m1_t *, vint8m1_t *, vbool8_t, vint8m1_t, vint8m1_t, vint8m1_t, vint8m1_t, const int8_t *, vuint32m4_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vloxseg4ei32_v)))
void vloxseg4ei32(vint8m2_t *, vint8m2_t *, vint8m2_t *, vint8m2_t *, const int8_t *, vuint32m8_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vloxseg4ei32_v_m)))
void vloxseg4ei32(vint8m2_t *, vint8m2_t *, vint8m2_t *, vint8m2_t *, vbool4_t, vint8m2_t, vint8m2_t, vint8m2_t, vint8m2_t, const int8_t *, vuint32m8_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vloxseg4ei32_v)))
void vloxseg4ei32(vint8mf2_t *, vint8mf2_t *, vint8mf2_t *, vint8mf2_t *, const int8_t *, vuint32m2_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vloxseg4ei32_v_m)))
void vloxseg4ei32(vint8mf2_t *, vint8mf2_t *, vint8mf2_t *, vint8mf2_t *, vbool16_t, vint8mf2_t, vint8mf2_t, vint8mf2_t, vint8mf2_t, const int8_t *, vuint32m2_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vloxseg4ei32_v)))
void vloxseg4ei32(vint8mf4_t *, vint8mf4_t *, vint8mf4_t *, vint8mf4_t *, const int8_t *, vuint32m1_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vloxseg4ei32_v_m)))
void vloxseg4ei32(vint8mf4_t *, vint8mf4_t *, vint8mf4_t *, vint8mf4_t *, vbool32_t, vint8mf4_t, vint8mf4_t, vint8mf4_t, vint8mf4_t, const int8_t *, vuint32m1_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vloxseg4ei32_v)))
void vloxseg4ei32(vint8mf8_t *, vint8mf8_t *, vint8mf8_t *, vint8mf8_t *, const int8_t *, vuint32mf2_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vloxseg4ei32_v_m)))
void vloxseg4ei32(vint8mf8_t *, vint8mf8_t *, vint8mf8_t *, vint8mf8_t *, vbool64_t, vint8mf8_t, vint8mf8_t, vint8mf8_t, vint8mf8_t, const int8_t *, vuint32mf2_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vloxseg4ei32_v)))
void vloxseg4ei32(vuint8m1_t *, vuint8m1_t *, vuint8m1_t *, vuint8m1_t *, const uint8_t *, vuint32m4_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vloxseg4ei32_v_m)))
void vloxseg4ei32(vuint8m1_t *, vuint8m1_t *, vuint8m1_t *, vuint8m1_t *, vbool8_t, vuint8m1_t, vuint8m1_t, vuint8m1_t, vuint8m1_t, const uint8_t *, vuint32m4_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vloxseg4ei32_v)))
void vloxseg4ei32(vuint8m2_t *, vuint8m2_t *, vuint8m2_t *, vuint8m2_t *, const uint8_t *, vuint32m8_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vloxseg4ei32_v_m)))
void vloxseg4ei32(vuint8m2_t *, vuint8m2_t *, vuint8m2_t *, vuint8m2_t *, vbool4_t, vuint8m2_t, vuint8m2_t, vuint8m2_t, vuint8m2_t, const uint8_t *, vuint32m8_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vloxseg4ei32_v)))
void vloxseg4ei32(vuint8mf2_t *, vuint8mf2_t *, vuint8mf2_t *, vuint8mf2_t *, const uint8_t *, vuint32m2_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vloxseg4ei32_v_m)))
void vloxseg4ei32(vuint8mf2_t *, vuint8mf2_t *, vuint8mf2_t *, vuint8mf2_t *, vbool16_t, vuint8mf2_t, vuint8mf2_t, vuint8mf2_t, vuint8mf2_t, const uint8_t *, vuint32m2_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vloxseg4ei32_v)))
void vloxseg4ei32(vuint8mf4_t *, vuint8mf4_t *, vuint8mf4_t *, vuint8mf4_t *, const uint8_t *, vuint32m1_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vloxseg4ei32_v_m)))
void vloxseg4ei32(vuint8mf4_t *, vuint8mf4_t *, vuint8mf4_t *, vuint8mf4_t *, vbool32_t, vuint8mf4_t, vuint8mf4_t, vuint8mf4_t, vuint8mf4_t, const uint8_t *, vuint32m1_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vloxseg4ei32_v)))
void vloxseg4ei32(vuint8mf8_t *, vuint8mf8_t *, vuint8mf8_t *, vuint8mf8_t *, const uint8_t *, vuint32mf2_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vloxseg4ei32_v_m)))
void vloxseg4ei32(vuint8mf8_t *, vuint8mf8_t *, vuint8mf8_t *, vuint8mf8_t *, vbool64_t, vuint8mf8_t, vuint8mf8_t, vuint8mf8_t, vuint8mf8_t, const uint8_t *, vuint32mf2_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vloxseg5ei32_v)))
void vloxseg5ei32(vint8m1_t *, vint8m1_t *, vint8m1_t *, vint8m1_t *, vint8m1_t *, const int8_t *, vuint32m4_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vloxseg5ei32_v_m)))
void vloxseg5ei32(vint8m1_t *, vint8m1_t *, vint8m1_t *, vint8m1_t *, vint8m1_t *, vbool8_t, vint8m1_t, vint8m1_t, vint8m1_t, vint8m1_t, vint8m1_t, const int8_t *, vuint32m4_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vloxseg5ei32_v)))
void vloxseg5ei32(vint8mf2_t *, vint8mf2_t *, vint8mf2_t *, vint8mf2_t *, vint8mf2_t *, const int8_t *, vuint32m2_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vloxseg5ei32_v_m)))
void vloxseg5ei32(vint8mf2_t *, vint8mf2_t *, vint8mf2_t *, vint8mf2_t *, vint8mf2_t *, vbool16_t, vint8mf2_t, vint8mf2_t, vint8mf2_t, vint8mf2_t, vint8mf2_t, const int8_t *, vuint32m2_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vloxseg5ei32_v)))
void vloxseg5ei32(vint8mf4_t *, vint8mf4_t *, vint8mf4_t *, vint8mf4_t *, vint8mf4_t *, const int8_t *, vuint32m1_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vloxseg5ei32_v_m)))
void vloxseg5ei32(vint8mf4_t *, vint8mf4_t *, vint8mf4_t *, vint8mf4_t *, vint8mf4_t *, vbool32_t, vint8mf4_t, vint8mf4_t, vint8mf4_t, vint8mf4_t, vint8mf4_t, const int8_t *, vuint32m1_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vloxseg5ei32_v)))
void vloxseg5ei32(vint8mf8_t *, vint8mf8_t *, vint8mf8_t *, vint8mf8_t *, vint8mf8_t *, const int8_t *, vuint32mf2_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vloxseg5ei32_v_m)))
void vloxseg5ei32(vint8mf8_t *, vint8mf8_t *, vint8mf8_t *, vint8mf8_t *, vint8mf8_t *, vbool64_t, vint8mf8_t, vint8mf8_t, vint8mf8_t, vint8mf8_t, vint8mf8_t, const int8_t *, vuint32mf2_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vloxseg5ei32_v)))
void vloxseg5ei32(vuint8m1_t *, vuint8m1_t *, vuint8m1_t *, vuint8m1_t *, vuint8m1_t *, const uint8_t *, vuint32m4_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vloxseg5ei32_v_m)))
void vloxseg5ei32(vuint8m1_t *, vuint8m1_t *, vuint8m1_t *, vuint8m1_t *, vuint8m1_t *, vbool8_t, vuint8m1_t, vuint8m1_t, vuint8m1_t, vuint8m1_t, vuint8m1_t, const uint8_t *, vuint32m4_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vloxseg5ei32_v)))
void vloxseg5ei32(vuint8mf2_t *, vuint8mf2_t *, vuint8mf2_t *, vuint8mf2_t *, vuint8mf2_t *, const uint8_t *, vuint32m2_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vloxseg5ei32_v_m)))
void vloxseg5ei32(vuint8mf2_t *, vuint8mf2_t *, vuint8mf2_t *, vuint8mf2_t *, vuint8mf2_t *, vbool16_t, vuint8mf2_t, vuint8mf2_t, vuint8mf2_t, vuint8mf2_t, vuint8mf2_t, const uint8_t *, vuint32m2_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vloxseg5ei32_v)))
void vloxseg5ei32(vuint8mf4_t *, vuint8mf4_t *, vuint8mf4_t *, vuint8mf4_t *, vuint8mf4_t *, const uint8_t *, vuint32m1_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vloxseg5ei32_v_m)))
void vloxseg5ei32(vuint8mf4_t *, vuint8mf4_t *, vuint8mf4_t *, vuint8mf4_t *, vuint8mf4_t *, vbool32_t, vuint8mf4_t, vuint8mf4_t, vuint8mf4_t, vuint8mf4_t, vuint8mf4_t, const uint8_t *, vuint32m1_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vloxseg5ei32_v)))
void vloxseg5ei32(vuint8mf8_t *, vuint8mf8_t *, vuint8mf8_t *, vuint8mf8_t *, vuint8mf8_t *, const uint8_t *, vuint32mf2_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vloxseg5ei32_v_m)))
void vloxseg5ei32(vuint8mf8_t *, vuint8mf8_t *, vuint8mf8_t *, vuint8mf8_t *, vuint8mf8_t *, vbool64_t, vuint8mf8_t, vuint8mf8_t, vuint8mf8_t, vuint8mf8_t, vuint8mf8_t, const uint8_t *, vuint32mf2_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vloxseg6ei32_v)))
void vloxseg6ei32(vint8m1_t *, vint8m1_t *, vint8m1_t *, vint8m1_t *, vint8m1_t *, vint8m1_t *, const int8_t *, vuint32m4_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vloxseg6ei32_v_m)))
void vloxseg6ei32(vint8m1_t *, vint8m1_t *, vint8m1_t *, vint8m1_t *, vint8m1_t *, vint8m1_t *, vbool8_t, vint8m1_t, vint8m1_t, vint8m1_t, vint8m1_t, vint8m1_t, vint8m1_t, const int8_t *, vuint32m4_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vloxseg6ei32_v)))
void vloxseg6ei32(vint8mf2_t *, vint8mf2_t *, vint8mf2_t *, vint8mf2_t *, vint8mf2_t *, vint8mf2_t *, const int8_t *, vuint32m2_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vloxseg6ei32_v_m)))
void vloxseg6ei32(vint8mf2_t *, vint8mf2_t *, vint8mf2_t *, vint8mf2_t *, vint8mf2_t *, vint8mf2_t *, vbool16_t, vint8mf2_t, vint8mf2_t, vint8mf2_t, vint8mf2_t, vint8mf2_t, vint8mf2_t, const int8_t *, vuint32m2_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vloxseg6ei32_v)))
void vloxseg6ei32(vint8mf4_t *, vint8mf4_t *, vint8mf4_t *, vint8mf4_t *, vint8mf4_t *, vint8mf4_t *, const int8_t *, vuint32m1_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vloxseg6ei32_v_m)))
void vloxseg6ei32(vint8mf4_t *, vint8mf4_t *, vint8mf4_t *, vint8mf4_t *, vint8mf4_t *, vint8mf4_t *, vbool32_t, vint8mf4_t, vint8mf4_t, vint8mf4_t, vint8mf4_t, vint8mf4_t, vint8mf4_t, const int8_t *, vuint32m1_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vloxseg6ei32_v)))
void vloxseg6ei32(vint8mf8_t *, vint8mf8_t *, vint8mf8_t *, vint8mf8_t *, vint8mf8_t *, vint8mf8_t *, const int8_t *, vuint32mf2_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vloxseg6ei32_v_m)))
void vloxseg6ei32(vint8mf8_t *, vint8mf8_t *, vint8mf8_t *, vint8mf8_t *, vint8mf8_t *, vint8mf8_t *, vbool64_t, vint8mf8_t, vint8mf8_t, vint8mf8_t, vint8mf8_t, vint8mf8_t, vint8mf8_t, const int8_t *, vuint32mf2_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vloxseg6ei32_v)))
void vloxseg6ei32(vuint8m1_t *, vuint8m1_t *, vuint8m1_t *, vuint8m1_t *, vuint8m1_t *, vuint8m1_t *, const uint8_t *, vuint32m4_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vloxseg6ei32_v_m)))
void vloxseg6ei32(vuint8m1_t *, vuint8m1_t *, vuint8m1_t *, vuint8m1_t *, vuint8m1_t *, vuint8m1_t *, vbool8_t, vuint8m1_t, vuint8m1_t, vuint8m1_t, vuint8m1_t, vuint8m1_t, vuint8m1_t, const uint8_t *, vuint32m4_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vloxseg6ei32_v)))
void vloxseg6ei32(vuint8mf2_t *, vuint8mf2_t *, vuint8mf2_t *, vuint8mf2_t *, vuint8mf2_t *, vuint8mf2_t *, const uint8_t *, vuint32m2_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vloxseg6ei32_v_m)))
void vloxseg6ei32(vuint8mf2_t *, vuint8mf2_t *, vuint8mf2_t *, vuint8mf2_t *, vuint8mf2_t *, vuint8mf2_t *, vbool16_t, vuint8mf2_t, vuint8mf2_t, vuint8mf2_t, vuint8mf2_t, vuint8mf2_t, vuint8mf2_t, const uint8_t *, vuint32m2_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vloxseg6ei32_v)))
void vloxseg6ei32(vuint8mf4_t *, vuint8mf4_t *, vuint8mf4_t *, vuint8mf4_t *, vuint8mf4_t *, vuint8mf4_t *, const uint8_t *, vuint32m1_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vloxseg6ei32_v_m)))
void vloxseg6ei32(vuint8mf4_t *, vuint8mf4_t *, vuint8mf4_t *, vuint8mf4_t *, vuint8mf4_t *, vuint8mf4_t *, vbool32_t, vuint8mf4_t, vuint8mf4_t, vuint8mf4_t, vuint8mf4_t, vuint8mf4_t, vuint8mf4_t, const uint8_t *, vuint32m1_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vloxseg6ei32_v)))
void vloxseg6ei32(vuint8mf8_t *, vuint8mf8_t *, vuint8mf8_t *, vuint8mf8_t *, vuint8mf8_t *, vuint8mf8_t *, const uint8_t *, vuint32mf2_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vloxseg6ei32_v_m)))
void vloxseg6ei32(vuint8mf8_t *, vuint8mf8_t *, vuint8mf8_t *, vuint8mf8_t *, vuint8mf8_t *, vuint8mf8_t *, vbool64_t, vuint8mf8_t, vuint8mf8_t, vuint8mf8_t, vuint8mf8_t, vuint8mf8_t, vuint8mf8_t, const uint8_t *, vuint32mf2_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vloxseg7ei32_v)))
void vloxseg7ei32(vint8m1_t *, vint8m1_t *, vint8m1_t *, vint8m1_t *, vint8m1_t *, vint8m1_t *, vint8m1_t *, const int8_t *, vuint32m4_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vloxseg7ei32_v_m)))
void vloxseg7ei32(vint8m1_t *, vint8m1_t *, vint8m1_t *, vint8m1_t *, vint8m1_t *, vint8m1_t *, vint8m1_t *, vbool8_t, vint8m1_t, vint8m1_t, vint8m1_t, vint8m1_t, vint8m1_t, vint8m1_t, vint8m1_t, const int8_t *, vuint32m4_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vloxseg7ei32_v)))
void vloxseg7ei32(vint8mf2_t *, vint8mf2_t *, vint8mf2_t *, vint8mf2_t *, vint8mf2_t *, vint8mf2_t *, vint8mf2_t *, const int8_t *, vuint32m2_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vloxseg7ei32_v_m)))
void vloxseg7ei32(vint8mf2_t *, vint8mf2_t *, vint8mf2_t *, vint8mf2_t *, vint8mf2_t *, vint8mf2_t *, vint8mf2_t *, vbool16_t, vint8mf2_t, vint8mf2_t, vint8mf2_t, vint8mf2_t, vint8mf2_t, vint8mf2_t, vint8mf2_t, const int8_t *, vuint32m2_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vloxseg7ei32_v)))
void vloxseg7ei32(vint8mf4_t *, vint8mf4_t *, vint8mf4_t *, vint8mf4_t *, vint8mf4_t *, vint8mf4_t *, vint8mf4_t *, const int8_t *, vuint32m1_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vloxseg7ei32_v_m)))
void vloxseg7ei32(vint8mf4_t *, vint8mf4_t *, vint8mf4_t *, vint8mf4_t *, vint8mf4_t *, vint8mf4_t *, vint8mf4_t *, vbool32_t, vint8mf4_t, vint8mf4_t, vint8mf4_t, vint8mf4_t, vint8mf4_t, vint8mf4_t, vint8mf4_t, const int8_t *, vuint32m1_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vloxseg7ei32_v)))
void vloxseg7ei32(vint8mf8_t *, vint8mf8_t *, vint8mf8_t *, vint8mf8_t *, vint8mf8_t *, vint8mf8_t *, vint8mf8_t *, const int8_t *, vuint32mf2_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vloxseg7ei32_v_m)))
void vloxseg7ei32(vint8mf8_t *, vint8mf8_t *, vint8mf8_t *, vint8mf8_t *, vint8mf8_t *, vint8mf8_t *, vint8mf8_t *, vbool64_t, vint8mf8_t, vint8mf8_t, vint8mf8_t, vint8mf8_t, vint8mf8_t, vint8mf8_t, vint8mf8_t, const int8_t *, vuint32mf2_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vloxseg7ei32_v)))
void vloxseg7ei32(vuint8m1_t *, vuint8m1_t *, vuint8m1_t *, vuint8m1_t *, vuint8m1_t *, vuint8m1_t *, vuint8m1_t *, const uint8_t *, vuint32m4_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vloxseg7ei32_v_m)))
void vloxseg7ei32(vuint8m1_t *, vuint8m1_t *, vuint8m1_t *, vuint8m1_t *, vuint8m1_t *, vuint8m1_t *, vuint8m1_t *, vbool8_t, vuint8m1_t, vuint8m1_t, vuint8m1_t, vuint8m1_t, vuint8m1_t, vuint8m1_t, vuint8m1_t, const uint8_t *, vuint32m4_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vloxseg7ei32_v)))
void vloxseg7ei32(vuint8mf2_t *, vuint8mf2_t *, vuint8mf2_t *, vuint8mf2_t *, vuint8mf2_t *, vuint8mf2_t *, vuint8mf2_t *, const uint8_t *, vuint32m2_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vloxseg7ei32_v_m)))
void vloxseg7ei32(vuint8mf2_t *, vuint8mf2_t *, vuint8mf2_t *, vuint8mf2_t *, vuint8mf2_t *, vuint8mf2_t *, vuint8mf2_t *, vbool16_t, vuint8mf2_t, vuint8mf2_t, vuint8mf2_t, vuint8mf2_t, vuint8mf2_t, vuint8mf2_t, vuint8mf2_t, const uint8_t *, vuint32m2_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vloxseg7ei32_v)))
void vloxseg7ei32(vuint8mf4_t *, vuint8mf4_t *, vuint8mf4_t *, vuint8mf4_t *, vuint8mf4_t *, vuint8mf4_t *, vuint8mf4_t *, const uint8_t *, vuint32m1_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vloxseg7ei32_v_m)))
void vloxseg7ei32(vuint8mf4_t *, vuint8mf4_t *, vuint8mf4_t *, vuint8mf4_t *, vuint8mf4_t *, vuint8mf4_t *, vuint8mf4_t *, vbool32_t, vuint8mf4_t, vuint8mf4_t, vuint8mf4_t, vuint8mf4_t, vuint8mf4_t, vuint8mf4_t, vuint8mf4_t, const uint8_t *, vuint32m1_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vloxseg7ei32_v)))
void vloxseg7ei32(vuint8mf8_t *, vuint8mf8_t *, vuint8mf8_t *, vuint8mf8_t *, vuint8mf8_t *, vuint8mf8_t *, vuint8mf8_t *, const uint8_t *, vuint32mf2_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vloxseg7ei32_v_m)))
void vloxseg7ei32(vuint8mf8_t *, vuint8mf8_t *, vuint8mf8_t *, vuint8mf8_t *, vuint8mf8_t *, vuint8mf8_t *, vuint8mf8_t *, vbool64_t, vuint8mf8_t, vuint8mf8_t, vuint8mf8_t, vuint8mf8_t, vuint8mf8_t, vuint8mf8_t, vuint8mf8_t, const uint8_t *, vuint32mf2_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vse16_v)))
void vse16(uint16_t *, vuint16m1_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vse16_v_m)))
void vse16(vbool16_t, uint16_t *, vuint16m1_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vse16_v)))
void vse16(uint16_t *, vuint16m2_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vse16_v_m)))
void vse16(vbool8_t, uint16_t *, vuint16m2_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vse16_v)))
void vse16(uint16_t *, vuint16m4_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vse16_v_m)))
void vse16(vbool4_t, uint16_t *, vuint16m4_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vse16_v)))
void vse16(uint16_t *, vuint16m8_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vse16_v_m)))
void vse16(vbool2_t, uint16_t *, vuint16m8_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vse16_v)))
void vse16(uint16_t *, vuint16mf2_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vse16_v_m)))
void vse16(vbool32_t, uint16_t *, vuint16mf2_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vse16_v)))
void vse16(uint16_t *, vuint16mf4_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vse16_v_m)))
void vse16(vbool64_t, uint16_t *, vuint16mf4_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vloxseg8ei32_v)))
void vloxseg8ei32(vint8m1_t *, vint8m1_t *, vint8m1_t *, vint8m1_t *, vint8m1_t *, vint8m1_t *, vint8m1_t *, vint8m1_t *, const int8_t *, vuint32m4_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vloxseg8ei32_v_m)))
void vloxseg8ei32(vint8m1_t *, vint8m1_t *, vint8m1_t *, vint8m1_t *, vint8m1_t *, vint8m1_t *, vint8m1_t *, vint8m1_t *, vbool8_t, vint8m1_t, vint8m1_t, vint8m1_t, vint8m1_t, vint8m1_t, vint8m1_t, vint8m1_t, vint8m1_t, const int8_t *, vuint32m4_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vloxseg8ei32_v)))
void vloxseg8ei32(vint8mf2_t *, vint8mf2_t *, vint8mf2_t *, vint8mf2_t *, vint8mf2_t *, vint8mf2_t *, vint8mf2_t *, vint8mf2_t *, const int8_t *, vuint32m2_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vloxseg8ei32_v_m)))
void vloxseg8ei32(vint8mf2_t *, vint8mf2_t *, vint8mf2_t *, vint8mf2_t *, vint8mf2_t *, vint8mf2_t *, vint8mf2_t *, vint8mf2_t *, vbool16_t, vint8mf2_t, vint8mf2_t, vint8mf2_t, vint8mf2_t, vint8mf2_t, vint8mf2_t, vint8mf2_t, vint8mf2_t, const int8_t *, vuint32m2_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vloxseg8ei32_v)))
void vloxseg8ei32(vint8mf4_t *, vint8mf4_t *, vint8mf4_t *, vint8mf4_t *, vint8mf4_t *, vint8mf4_t *, vint8mf4_t *, vint8mf4_t *, const int8_t *, vuint32m1_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vloxseg8ei32_v_m)))
void vloxseg8ei32(vint8mf4_t *, vint8mf4_t *, vint8mf4_t *, vint8mf4_t *, vint8mf4_t *, vint8mf4_t *, vint8mf4_t *, vint8mf4_t *, vbool32_t, vint8mf4_t, vint8mf4_t, vint8mf4_t, vint8mf4_t, vint8mf4_t, vint8mf4_t, vint8mf4_t, vint8mf4_t, const int8_t *, vuint32m1_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vloxseg8ei32_v)))
void vloxseg8ei32(vint8mf8_t *, vint8mf8_t *, vint8mf8_t *, vint8mf8_t *, vint8mf8_t *, vint8mf8_t *, vint8mf8_t *, vint8mf8_t *, const int8_t *, vuint32mf2_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vloxseg8ei32_v_m)))
void vloxseg8ei32(vint8mf8_t *, vint8mf8_t *, vint8mf8_t *, vint8mf8_t *, vint8mf8_t *, vint8mf8_t *, vint8mf8_t *, vint8mf8_t *, vbool64_t, vint8mf8_t, vint8mf8_t, vint8mf8_t, vint8mf8_t, vint8mf8_t, vint8mf8_t, vint8mf8_t, vint8mf8_t, const int8_t *, vuint32mf2_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vloxseg8ei32_v)))
void vloxseg8ei32(vuint8m1_t *, vuint8m1_t *, vuint8m1_t *, vuint8m1_t *, vuint8m1_t *, vuint8m1_t *, vuint8m1_t *, vuint8m1_t *, const uint8_t *, vuint32m4_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vloxseg8ei32_v_m)))
void vloxseg8ei32(vuint8m1_t *, vuint8m1_t *, vuint8m1_t *, vuint8m1_t *, vuint8m1_t *, vuint8m1_t *, vuint8m1_t *, vuint8m1_t *, vbool8_t, vuint8m1_t, vuint8m1_t, vuint8m1_t, vuint8m1_t, vuint8m1_t, vuint8m1_t, vuint8m1_t, vuint8m1_t, const uint8_t *, vuint32m4_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vloxseg8ei32_v)))
void vloxseg8ei32(vuint8mf2_t *, vuint8mf2_t *, vuint8mf2_t *, vuint8mf2_t *, vuint8mf2_t *, vuint8mf2_t *, vuint8mf2_t *, vuint8mf2_t *, const uint8_t *, vuint32m2_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vloxseg8ei32_v_m)))
void vloxseg8ei32(vuint8mf2_t *, vuint8mf2_t *, vuint8mf2_t *, vuint8mf2_t *, vuint8mf2_t *, vuint8mf2_t *, vuint8mf2_t *, vuint8mf2_t *, vbool16_t, vuint8mf2_t, vuint8mf2_t, vuint8mf2_t, vuint8mf2_t, vuint8mf2_t, vuint8mf2_t, vuint8mf2_t, vuint8mf2_t, const uint8_t *, vuint32m2_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vloxseg8ei32_v)))
void vloxseg8ei32(vuint8mf4_t *, vuint8mf4_t *, vuint8mf4_t *, vuint8mf4_t *, vuint8mf4_t *, vuint8mf4_t *, vuint8mf4_t *, vuint8mf4_t *, const uint8_t *, vuint32m1_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vloxseg8ei32_v_m)))
void vloxseg8ei32(vuint8mf4_t *, vuint8mf4_t *, vuint8mf4_t *, vuint8mf4_t *, vuint8mf4_t *, vuint8mf4_t *, vuint8mf4_t *, vuint8mf4_t *, vbool32_t, vuint8mf4_t, vuint8mf4_t, vuint8mf4_t, vuint8mf4_t, vuint8mf4_t, vuint8mf4_t, vuint8mf4_t, vuint8mf4_t, const uint8_t *, vuint32m1_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vloxseg8ei32_v)))
void vloxseg8ei32(vuint8mf8_t *, vuint8mf8_t *, vuint8mf8_t *, vuint8mf8_t *, vuint8mf8_t *, vuint8mf8_t *, vuint8mf8_t *, vuint8mf8_t *, const uint8_t *, vuint32mf2_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vloxseg8ei32_v_m)))
void vloxseg8ei32(vuint8mf8_t *, vuint8mf8_t *, vuint8mf8_t *, vuint8mf8_t *, vuint8mf8_t *, vuint8mf8_t *, vuint8mf8_t *, vuint8mf8_t *, vbool64_t, vuint8mf8_t, vuint8mf8_t, vuint8mf8_t, vuint8mf8_t, vuint8mf8_t, vuint8mf8_t, vuint8mf8_t, vuint8mf8_t, const uint8_t *, vuint32mf2_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vloxseg2ei8_v)))
void vloxseg2ei8(vint16m1_t *, vint16m1_t *, const int16_t *, vuint8mf2_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vloxseg2ei8_v_m)))
void vloxseg2ei8(vint16m1_t *, vint16m1_t *, vbool16_t, vint16m1_t, vint16m1_t, const int16_t *, vuint8mf2_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vloxseg2ei8_v)))
void vloxseg2ei8(vint16m2_t *, vint16m2_t *, const int16_t *, vuint8m1_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vloxseg2ei8_v_m)))
void vloxseg2ei8(vint16m2_t *, vint16m2_t *, vbool8_t, vint16m2_t, vint16m2_t, const int16_t *, vuint8m1_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vloxseg2ei8_v)))
void vloxseg2ei8(vint16m4_t *, vint16m4_t *, const int16_t *, vuint8m2_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vloxseg2ei8_v_m)))
void vloxseg2ei8(vint16m4_t *, vint16m4_t *, vbool4_t, vint16m4_t, vint16m4_t, const int16_t *, vuint8m2_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vloxseg2ei8_v)))
void vloxseg2ei8(vint16mf2_t *, vint16mf2_t *, const int16_t *, vuint8mf4_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vloxseg2ei8_v_m)))
void vloxseg2ei8(vint16mf2_t *, vint16mf2_t *, vbool32_t, vint16mf2_t, vint16mf2_t, const int16_t *, vuint8mf4_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vloxseg2ei8_v)))
void vloxseg2ei8(vint16mf4_t *, vint16mf4_t *, const int16_t *, vuint8mf8_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vloxseg2ei8_v_m)))
void vloxseg2ei8(vint16mf4_t *, vint16mf4_t *, vbool64_t, vint16mf4_t, vint16mf4_t, const int16_t *, vuint8mf8_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vloxseg2ei8_v)))
void vloxseg2ei8(vuint16m1_t *, vuint16m1_t *, const uint16_t *, vuint8mf2_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vloxseg2ei8_v_m)))
void vloxseg2ei8(vuint16m1_t *, vuint16m1_t *, vbool16_t, vuint16m1_t, vuint16m1_t, const uint16_t *, vuint8mf2_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vloxseg2ei8_v)))
void vloxseg2ei8(vuint16m2_t *, vuint16m2_t *, const uint16_t *, vuint8m1_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vloxseg2ei8_v_m)))
void vloxseg2ei8(vuint16m2_t *, vuint16m2_t *, vbool8_t, vuint16m2_t, vuint16m2_t, const uint16_t *, vuint8m1_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vloxseg2ei8_v)))
void vloxseg2ei8(vuint16m4_t *, vuint16m4_t *, const uint16_t *, vuint8m2_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vloxseg2ei8_v_m)))
void vloxseg2ei8(vuint16m4_t *, vuint16m4_t *, vbool4_t, vuint16m4_t, vuint16m4_t, const uint16_t *, vuint8m2_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vloxseg2ei8_v)))
void vloxseg2ei8(vuint16mf2_t *, vuint16mf2_t *, const uint16_t *, vuint8mf4_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vloxseg2ei8_v_m)))
void vloxseg2ei8(vuint16mf2_t *, vuint16mf2_t *, vbool32_t, vuint16mf2_t, vuint16mf2_t, const uint16_t *, vuint8mf4_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vloxseg2ei8_v)))
void vloxseg2ei8(vuint16mf4_t *, vuint16mf4_t *, const uint16_t *, vuint8mf8_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vloxseg2ei8_v_m)))
void vloxseg2ei8(vuint16mf4_t *, vuint16mf4_t *, vbool64_t, vuint16mf4_t, vuint16mf4_t, const uint16_t *, vuint8mf8_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vloxseg3ei8_v)))
void vloxseg3ei8(vint16m1_t *, vint16m1_t *, vint16m1_t *, const int16_t *, vuint8mf2_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vloxseg3ei8_v_m)))
void vloxseg3ei8(vint16m1_t *, vint16m1_t *, vint16m1_t *, vbool16_t, vint16m1_t, vint16m1_t, vint16m1_t, const int16_t *, vuint8mf2_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vloxseg3ei8_v)))
void vloxseg3ei8(vint16m2_t *, vint16m2_t *, vint16m2_t *, const int16_t *, vuint8m1_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vloxseg3ei8_v_m)))
void vloxseg3ei8(vint16m2_t *, vint16m2_t *, vint16m2_t *, vbool8_t, vint16m2_t, vint16m2_t, vint16m2_t, const int16_t *, vuint8m1_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vloxseg3ei8_v)))
void vloxseg3ei8(vint16mf2_t *, vint16mf2_t *, vint16mf2_t *, const int16_t *, vuint8mf4_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vloxseg3ei8_v_m)))
void vloxseg3ei8(vint16mf2_t *, vint16mf2_t *, vint16mf2_t *, vbool32_t, vint16mf2_t, vint16mf2_t, vint16mf2_t, const int16_t *, vuint8mf4_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vloxseg3ei8_v)))
void vloxseg3ei8(vint16mf4_t *, vint16mf4_t *, vint16mf4_t *, const int16_t *, vuint8mf8_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vloxseg3ei8_v_m)))
void vloxseg3ei8(vint16mf4_t *, vint16mf4_t *, vint16mf4_t *, vbool64_t, vint16mf4_t, vint16mf4_t, vint16mf4_t, const int16_t *, vuint8mf8_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vloxseg3ei8_v)))
void vloxseg3ei8(vuint16m1_t *, vuint16m1_t *, vuint16m1_t *, const uint16_t *, vuint8mf2_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vloxseg3ei8_v_m)))
void vloxseg3ei8(vuint16m1_t *, vuint16m1_t *, vuint16m1_t *, vbool16_t, vuint16m1_t, vuint16m1_t, vuint16m1_t, const uint16_t *, vuint8mf2_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vloxseg3ei8_v)))
void vloxseg3ei8(vuint16m2_t *, vuint16m2_t *, vuint16m2_t *, const uint16_t *, vuint8m1_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vloxseg3ei8_v_m)))
void vloxseg3ei8(vuint16m2_t *, vuint16m2_t *, vuint16m2_t *, vbool8_t, vuint16m2_t, vuint16m2_t, vuint16m2_t, const uint16_t *, vuint8m1_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vloxseg3ei8_v)))
void vloxseg3ei8(vuint16mf2_t *, vuint16mf2_t *, vuint16mf2_t *, const uint16_t *, vuint8mf4_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vloxseg3ei8_v_m)))
void vloxseg3ei8(vuint16mf2_t *, vuint16mf2_t *, vuint16mf2_t *, vbool32_t, vuint16mf2_t, vuint16mf2_t, vuint16mf2_t, const uint16_t *, vuint8mf4_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vloxseg3ei8_v)))
void vloxseg3ei8(vuint16mf4_t *, vuint16mf4_t *, vuint16mf4_t *, const uint16_t *, vuint8mf8_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vloxseg3ei8_v_m)))
void vloxseg3ei8(vuint16mf4_t *, vuint16mf4_t *, vuint16mf4_t *, vbool64_t, vuint16mf4_t, vuint16mf4_t, vuint16mf4_t, const uint16_t *, vuint8mf8_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vse32_v)))
void vse32(int32_t *, vint32m1_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vse32_v_m)))
void vse32(vbool32_t, int32_t *, vint32m1_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vse32_v)))
void vse32(int32_t *, vint32m2_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vse32_v_m)))
void vse32(vbool16_t, int32_t *, vint32m2_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vse32_v)))
void vse32(int32_t *, vint32m4_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vse32_v_m)))
void vse32(vbool8_t, int32_t *, vint32m4_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vse32_v)))
void vse32(int32_t *, vint32m8_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vse32_v_m)))
void vse32(vbool4_t, int32_t *, vint32m8_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vse32_v)))
void vse32(int32_t *, vint32mf2_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vse32_v_m)))
void vse32(vbool64_t, int32_t *, vint32mf2_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vloxseg4ei8_v)))
void vloxseg4ei8(vint16m1_t *, vint16m1_t *, vint16m1_t *, vint16m1_t *, const int16_t *, vuint8mf2_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vloxseg4ei8_v_m)))
void vloxseg4ei8(vint16m1_t *, vint16m1_t *, vint16m1_t *, vint16m1_t *, vbool16_t, vint16m1_t, vint16m1_t, vint16m1_t, vint16m1_t, const int16_t *, vuint8mf2_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vloxseg4ei8_v)))
void vloxseg4ei8(vint16m2_t *, vint16m2_t *, vint16m2_t *, vint16m2_t *, const int16_t *, vuint8m1_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vloxseg4ei8_v_m)))
void vloxseg4ei8(vint16m2_t *, vint16m2_t *, vint16m2_t *, vint16m2_t *, vbool8_t, vint16m2_t, vint16m2_t, vint16m2_t, vint16m2_t, const int16_t *, vuint8m1_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vloxseg4ei8_v)))
void vloxseg4ei8(vint16mf2_t *, vint16mf2_t *, vint16mf2_t *, vint16mf2_t *, const int16_t *, vuint8mf4_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vloxseg4ei8_v_m)))
void vloxseg4ei8(vint16mf2_t *, vint16mf2_t *, vint16mf2_t *, vint16mf2_t *, vbool32_t, vint16mf2_t, vint16mf2_t, vint16mf2_t, vint16mf2_t, const int16_t *, vuint8mf4_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vloxseg4ei8_v)))
void vloxseg4ei8(vint16mf4_t *, vint16mf4_t *, vint16mf4_t *, vint16mf4_t *, const int16_t *, vuint8mf8_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vloxseg4ei8_v_m)))
void vloxseg4ei8(vint16mf4_t *, vint16mf4_t *, vint16mf4_t *, vint16mf4_t *, vbool64_t, vint16mf4_t, vint16mf4_t, vint16mf4_t, vint16mf4_t, const int16_t *, vuint8mf8_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vloxseg4ei8_v)))
void vloxseg4ei8(vuint16m1_t *, vuint16m1_t *, vuint16m1_t *, vuint16m1_t *, const uint16_t *, vuint8mf2_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vloxseg4ei8_v_m)))
void vloxseg4ei8(vuint16m1_t *, vuint16m1_t *, vuint16m1_t *, vuint16m1_t *, vbool16_t, vuint16m1_t, vuint16m1_t, vuint16m1_t, vuint16m1_t, const uint16_t *, vuint8mf2_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vloxseg4ei8_v)))
void vloxseg4ei8(vuint16m2_t *, vuint16m2_t *, vuint16m2_t *, vuint16m2_t *, const uint16_t *, vuint8m1_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vloxseg4ei8_v_m)))
void vloxseg4ei8(vuint16m2_t *, vuint16m2_t *, vuint16m2_t *, vuint16m2_t *, vbool8_t, vuint16m2_t, vuint16m2_t, vuint16m2_t, vuint16m2_t, const uint16_t *, vuint8m1_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vloxseg4ei8_v)))
void vloxseg4ei8(vuint16mf2_t *, vuint16mf2_t *, vuint16mf2_t *, vuint16mf2_t *, const uint16_t *, vuint8mf4_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vloxseg4ei8_v_m)))
void vloxseg4ei8(vuint16mf2_t *, vuint16mf2_t *, vuint16mf2_t *, vuint16mf2_t *, vbool32_t, vuint16mf2_t, vuint16mf2_t, vuint16mf2_t, vuint16mf2_t, const uint16_t *, vuint8mf4_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vloxseg4ei8_v)))
void vloxseg4ei8(vuint16mf4_t *, vuint16mf4_t *, vuint16mf4_t *, vuint16mf4_t *, const uint16_t *, vuint8mf8_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vloxseg4ei8_v_m)))
void vloxseg4ei8(vuint16mf4_t *, vuint16mf4_t *, vuint16mf4_t *, vuint16mf4_t *, vbool64_t, vuint16mf4_t, vuint16mf4_t, vuint16mf4_t, vuint16mf4_t, const uint16_t *, vuint8mf8_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vloxseg5ei8_v)))
void vloxseg5ei8(vint16m1_t *, vint16m1_t *, vint16m1_t *, vint16m1_t *, vint16m1_t *, const int16_t *, vuint8mf2_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vloxseg5ei8_v_m)))
void vloxseg5ei8(vint16m1_t *, vint16m1_t *, vint16m1_t *, vint16m1_t *, vint16m1_t *, vbool16_t, vint16m1_t, vint16m1_t, vint16m1_t, vint16m1_t, vint16m1_t, const int16_t *, vuint8mf2_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vloxseg5ei8_v)))
void vloxseg5ei8(vint16mf2_t *, vint16mf2_t *, vint16mf2_t *, vint16mf2_t *, vint16mf2_t *, const int16_t *, vuint8mf4_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vloxseg5ei8_v_m)))
void vloxseg5ei8(vint16mf2_t *, vint16mf2_t *, vint16mf2_t *, vint16mf2_t *, vint16mf2_t *, vbool32_t, vint16mf2_t, vint16mf2_t, vint16mf2_t, vint16mf2_t, vint16mf2_t, const int16_t *, vuint8mf4_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vloxseg5ei8_v)))
void vloxseg5ei8(vint16mf4_t *, vint16mf4_t *, vint16mf4_t *, vint16mf4_t *, vint16mf4_t *, const int16_t *, vuint8mf8_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vloxseg5ei8_v_m)))
void vloxseg5ei8(vint16mf4_t *, vint16mf4_t *, vint16mf4_t *, vint16mf4_t *, vint16mf4_t *, vbool64_t, vint16mf4_t, vint16mf4_t, vint16mf4_t, vint16mf4_t, vint16mf4_t, const int16_t *, vuint8mf8_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vloxseg5ei8_v)))
void vloxseg5ei8(vuint16m1_t *, vuint16m1_t *, vuint16m1_t *, vuint16m1_t *, vuint16m1_t *, const uint16_t *, vuint8mf2_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vloxseg5ei8_v_m)))
void vloxseg5ei8(vuint16m1_t *, vuint16m1_t *, vuint16m1_t *, vuint16m1_t *, vuint16m1_t *, vbool16_t, vuint16m1_t, vuint16m1_t, vuint16m1_t, vuint16m1_t, vuint16m1_t, const uint16_t *, vuint8mf2_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vloxseg5ei8_v)))
void vloxseg5ei8(vuint16mf2_t *, vuint16mf2_t *, vuint16mf2_t *, vuint16mf2_t *, vuint16mf2_t *, const uint16_t *, vuint8mf4_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vloxseg5ei8_v_m)))
void vloxseg5ei8(vuint16mf2_t *, vuint16mf2_t *, vuint16mf2_t *, vuint16mf2_t *, vuint16mf2_t *, vbool32_t, vuint16mf2_t, vuint16mf2_t, vuint16mf2_t, vuint16mf2_t, vuint16mf2_t, const uint16_t *, vuint8mf4_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vloxseg5ei8_v)))
void vloxseg5ei8(vuint16mf4_t *, vuint16mf4_t *, vuint16mf4_t *, vuint16mf4_t *, vuint16mf4_t *, const uint16_t *, vuint8mf8_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vloxseg5ei8_v_m)))
void vloxseg5ei8(vuint16mf4_t *, vuint16mf4_t *, vuint16mf4_t *, vuint16mf4_t *, vuint16mf4_t *, vbool64_t, vuint16mf4_t, vuint16mf4_t, vuint16mf4_t, vuint16mf4_t, vuint16mf4_t, const uint16_t *, vuint8mf8_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vloxseg6ei8_v)))
void vloxseg6ei8(vint16m1_t *, vint16m1_t *, vint16m1_t *, vint16m1_t *, vint16m1_t *, vint16m1_t *, const int16_t *, vuint8mf2_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vloxseg6ei8_v_m)))
void vloxseg6ei8(vint16m1_t *, vint16m1_t *, vint16m1_t *, vint16m1_t *, vint16m1_t *, vint16m1_t *, vbool16_t, vint16m1_t, vint16m1_t, vint16m1_t, vint16m1_t, vint16m1_t, vint16m1_t, const int16_t *, vuint8mf2_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vloxseg6ei8_v)))
void vloxseg6ei8(vint16mf2_t *, vint16mf2_t *, vint16mf2_t *, vint16mf2_t *, vint16mf2_t *, vint16mf2_t *, const int16_t *, vuint8mf4_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vloxseg6ei8_v_m)))
void vloxseg6ei8(vint16mf2_t *, vint16mf2_t *, vint16mf2_t *, vint16mf2_t *, vint16mf2_t *, vint16mf2_t *, vbool32_t, vint16mf2_t, vint16mf2_t, vint16mf2_t, vint16mf2_t, vint16mf2_t, vint16mf2_t, const int16_t *, vuint8mf4_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vloxseg6ei8_v)))
void vloxseg6ei8(vint16mf4_t *, vint16mf4_t *, vint16mf4_t *, vint16mf4_t *, vint16mf4_t *, vint16mf4_t *, const int16_t *, vuint8mf8_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vloxseg6ei8_v_m)))
void vloxseg6ei8(vint16mf4_t *, vint16mf4_t *, vint16mf4_t *, vint16mf4_t *, vint16mf4_t *, vint16mf4_t *, vbool64_t, vint16mf4_t, vint16mf4_t, vint16mf4_t, vint16mf4_t, vint16mf4_t, vint16mf4_t, const int16_t *, vuint8mf8_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vloxseg6ei8_v)))
void vloxseg6ei8(vuint16m1_t *, vuint16m1_t *, vuint16m1_t *, vuint16m1_t *, vuint16m1_t *, vuint16m1_t *, const uint16_t *, vuint8mf2_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vloxseg6ei8_v_m)))
void vloxseg6ei8(vuint16m1_t *, vuint16m1_t *, vuint16m1_t *, vuint16m1_t *, vuint16m1_t *, vuint16m1_t *, vbool16_t, vuint16m1_t, vuint16m1_t, vuint16m1_t, vuint16m1_t, vuint16m1_t, vuint16m1_t, const uint16_t *, vuint8mf2_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vloxseg6ei8_v)))
void vloxseg6ei8(vuint16mf2_t *, vuint16mf2_t *, vuint16mf2_t *, vuint16mf2_t *, vuint16mf2_t *, vuint16mf2_t *, const uint16_t *, vuint8mf4_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vloxseg6ei8_v_m)))
void vloxseg6ei8(vuint16mf2_t *, vuint16mf2_t *, vuint16mf2_t *, vuint16mf2_t *, vuint16mf2_t *, vuint16mf2_t *, vbool32_t, vuint16mf2_t, vuint16mf2_t, vuint16mf2_t, vuint16mf2_t, vuint16mf2_t, vuint16mf2_t, const uint16_t *, vuint8mf4_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vloxseg6ei8_v)))
void vloxseg6ei8(vuint16mf4_t *, vuint16mf4_t *, vuint16mf4_t *, vuint16mf4_t *, vuint16mf4_t *, vuint16mf4_t *, const uint16_t *, vuint8mf8_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vloxseg6ei8_v_m)))
void vloxseg6ei8(vuint16mf4_t *, vuint16mf4_t *, vuint16mf4_t *, vuint16mf4_t *, vuint16mf4_t *, vuint16mf4_t *, vbool64_t, vuint16mf4_t, vuint16mf4_t, vuint16mf4_t, vuint16mf4_t, vuint16mf4_t, vuint16mf4_t, const uint16_t *, vuint8mf8_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vloxseg7ei8_v)))
void vloxseg7ei8(vint16m1_t *, vint16m1_t *, vint16m1_t *, vint16m1_t *, vint16m1_t *, vint16m1_t *, vint16m1_t *, const int16_t *, vuint8mf2_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vloxseg7ei8_v_m)))
void vloxseg7ei8(vint16m1_t *, vint16m1_t *, vint16m1_t *, vint16m1_t *, vint16m1_t *, vint16m1_t *, vint16m1_t *, vbool16_t, vint16m1_t, vint16m1_t, vint16m1_t, vint16m1_t, vint16m1_t, vint16m1_t, vint16m1_t, const int16_t *, vuint8mf2_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vloxseg7ei8_v)))
void vloxseg7ei8(vint16mf2_t *, vint16mf2_t *, vint16mf2_t *, vint16mf2_t *, vint16mf2_t *, vint16mf2_t *, vint16mf2_t *, const int16_t *, vuint8mf4_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vloxseg7ei8_v_m)))
void vloxseg7ei8(vint16mf2_t *, vint16mf2_t *, vint16mf2_t *, vint16mf2_t *, vint16mf2_t *, vint16mf2_t *, vint16mf2_t *, vbool32_t, vint16mf2_t, vint16mf2_t, vint16mf2_t, vint16mf2_t, vint16mf2_t, vint16mf2_t, vint16mf2_t, const int16_t *, vuint8mf4_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vloxseg7ei8_v)))
void vloxseg7ei8(vint16mf4_t *, vint16mf4_t *, vint16mf4_t *, vint16mf4_t *, vint16mf4_t *, vint16mf4_t *, vint16mf4_t *, const int16_t *, vuint8mf8_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vloxseg7ei8_v_m)))
void vloxseg7ei8(vint16mf4_t *, vint16mf4_t *, vint16mf4_t *, vint16mf4_t *, vint16mf4_t *, vint16mf4_t *, vint16mf4_t *, vbool64_t, vint16mf4_t, vint16mf4_t, vint16mf4_t, vint16mf4_t, vint16mf4_t, vint16mf4_t, vint16mf4_t, const int16_t *, vuint8mf8_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vloxseg7ei8_v)))
void vloxseg7ei8(vuint16m1_t *, vuint16m1_t *, vuint16m1_t *, vuint16m1_t *, vuint16m1_t *, vuint16m1_t *, vuint16m1_t *, const uint16_t *, vuint8mf2_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vloxseg7ei8_v_m)))
void vloxseg7ei8(vuint16m1_t *, vuint16m1_t *, vuint16m1_t *, vuint16m1_t *, vuint16m1_t *, vuint16m1_t *, vuint16m1_t *, vbool16_t, vuint16m1_t, vuint16m1_t, vuint16m1_t, vuint16m1_t, vuint16m1_t, vuint16m1_t, vuint16m1_t, const uint16_t *, vuint8mf2_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vloxseg7ei8_v)))
void vloxseg7ei8(vuint16mf2_t *, vuint16mf2_t *, vuint16mf2_t *, vuint16mf2_t *, vuint16mf2_t *, vuint16mf2_t *, vuint16mf2_t *, const uint16_t *, vuint8mf4_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vloxseg7ei8_v_m)))
void vloxseg7ei8(vuint16mf2_t *, vuint16mf2_t *, vuint16mf2_t *, vuint16mf2_t *, vuint16mf2_t *, vuint16mf2_t *, vuint16mf2_t *, vbool32_t, vuint16mf2_t, vuint16mf2_t, vuint16mf2_t, vuint16mf2_t, vuint16mf2_t, vuint16mf2_t, vuint16mf2_t, const uint16_t *, vuint8mf4_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vloxseg7ei8_v)))
void vloxseg7ei8(vuint16mf4_t *, vuint16mf4_t *, vuint16mf4_t *, vuint16mf4_t *, vuint16mf4_t *, vuint16mf4_t *, vuint16mf4_t *, const uint16_t *, vuint8mf8_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vloxseg7ei8_v_m)))
void vloxseg7ei8(vuint16mf4_t *, vuint16mf4_t *, vuint16mf4_t *, vuint16mf4_t *, vuint16mf4_t *, vuint16mf4_t *, vuint16mf4_t *, vbool64_t, vuint16mf4_t, vuint16mf4_t, vuint16mf4_t, vuint16mf4_t, vuint16mf4_t, vuint16mf4_t, vuint16mf4_t, const uint16_t *, vuint8mf8_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vloxseg8ei8_v)))
void vloxseg8ei8(vint16m1_t *, vint16m1_t *, vint16m1_t *, vint16m1_t *, vint16m1_t *, vint16m1_t *, vint16m1_t *, vint16m1_t *, const int16_t *, vuint8mf2_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vloxseg8ei8_v_m)))
void vloxseg8ei8(vint16m1_t *, vint16m1_t *, vint16m1_t *, vint16m1_t *, vint16m1_t *, vint16m1_t *, vint16m1_t *, vint16m1_t *, vbool16_t, vint16m1_t, vint16m1_t, vint16m1_t, vint16m1_t, vint16m1_t, vint16m1_t, vint16m1_t, vint16m1_t, const int16_t *, vuint8mf2_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vloxseg8ei8_v)))
void vloxseg8ei8(vint16mf2_t *, vint16mf2_t *, vint16mf2_t *, vint16mf2_t *, vint16mf2_t *, vint16mf2_t *, vint16mf2_t *, vint16mf2_t *, const int16_t *, vuint8mf4_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vloxseg8ei8_v_m)))
void vloxseg8ei8(vint16mf2_t *, vint16mf2_t *, vint16mf2_t *, vint16mf2_t *, vint16mf2_t *, vint16mf2_t *, vint16mf2_t *, vint16mf2_t *, vbool32_t, vint16mf2_t, vint16mf2_t, vint16mf2_t, vint16mf2_t, vint16mf2_t, vint16mf2_t, vint16mf2_t, vint16mf2_t, const int16_t *, vuint8mf4_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vloxseg8ei8_v)))
void vloxseg8ei8(vint16mf4_t *, vint16mf4_t *, vint16mf4_t *, vint16mf4_t *, vint16mf4_t *, vint16mf4_t *, vint16mf4_t *, vint16mf4_t *, const int16_t *, vuint8mf8_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vloxseg8ei8_v_m)))
void vloxseg8ei8(vint16mf4_t *, vint16mf4_t *, vint16mf4_t *, vint16mf4_t *, vint16mf4_t *, vint16mf4_t *, vint16mf4_t *, vint16mf4_t *, vbool64_t, vint16mf4_t, vint16mf4_t, vint16mf4_t, vint16mf4_t, vint16mf4_t, vint16mf4_t, vint16mf4_t, vint16mf4_t, const int16_t *, vuint8mf8_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vloxseg8ei8_v)))
void vloxseg8ei8(vuint16m1_t *, vuint16m1_t *, vuint16m1_t *, vuint16m1_t *, vuint16m1_t *, vuint16m1_t *, vuint16m1_t *, vuint16m1_t *, const uint16_t *, vuint8mf2_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vloxseg8ei8_v_m)))
void vloxseg8ei8(vuint16m1_t *, vuint16m1_t *, vuint16m1_t *, vuint16m1_t *, vuint16m1_t *, vuint16m1_t *, vuint16m1_t *, vuint16m1_t *, vbool16_t, vuint16m1_t, vuint16m1_t, vuint16m1_t, vuint16m1_t, vuint16m1_t, vuint16m1_t, vuint16m1_t, vuint16m1_t, const uint16_t *, vuint8mf2_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vloxseg8ei8_v)))
void vloxseg8ei8(vuint16mf2_t *, vuint16mf2_t *, vuint16mf2_t *, vuint16mf2_t *, vuint16mf2_t *, vuint16mf2_t *, vuint16mf2_t *, vuint16mf2_t *, const uint16_t *, vuint8mf4_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vloxseg8ei8_v_m)))
void vloxseg8ei8(vuint16mf2_t *, vuint16mf2_t *, vuint16mf2_t *, vuint16mf2_t *, vuint16mf2_t *, vuint16mf2_t *, vuint16mf2_t *, vuint16mf2_t *, vbool32_t, vuint16mf2_t, vuint16mf2_t, vuint16mf2_t, vuint16mf2_t, vuint16mf2_t, vuint16mf2_t, vuint16mf2_t, vuint16mf2_t, const uint16_t *, vuint8mf4_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vloxseg8ei8_v)))
void vloxseg8ei8(vuint16mf4_t *, vuint16mf4_t *, vuint16mf4_t *, vuint16mf4_t *, vuint16mf4_t *, vuint16mf4_t *, vuint16mf4_t *, vuint16mf4_t *, const uint16_t *, vuint8mf8_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vloxseg8ei8_v_m)))
void vloxseg8ei8(vuint16mf4_t *, vuint16mf4_t *, vuint16mf4_t *, vuint16mf4_t *, vuint16mf4_t *, vuint16mf4_t *, vuint16mf4_t *, vuint16mf4_t *, vbool64_t, vuint16mf4_t, vuint16mf4_t, vuint16mf4_t, vuint16mf4_t, vuint16mf4_t, vuint16mf4_t, vuint16mf4_t, vuint16mf4_t, const uint16_t *, vuint8mf8_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vluxei8_v)))
vint8m1_t vluxei8(const int8_t *, vuint8m1_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vluxei8_v_m)))
vint8m1_t vluxei8(vbool8_t, vint8m1_t, const int8_t *, vuint8m1_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vluxei8_v)))
vint8m2_t vluxei8(const int8_t *, vuint8m2_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vluxei8_v_m)))
vint8m2_t vluxei8(vbool4_t, vint8m2_t, const int8_t *, vuint8m2_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vluxei8_v)))
vint8m4_t vluxei8(const int8_t *, vuint8m4_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vluxei8_v_m)))
vint8m4_t vluxei8(vbool2_t, vint8m4_t, const int8_t *, vuint8m4_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vluxei8_v)))
vint8m8_t vluxei8(const int8_t *, vuint8m8_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vluxei8_v_m)))
vint8m8_t vluxei8(vbool1_t, vint8m8_t, const int8_t *, vuint8m8_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vluxei8_v)))
vint8mf2_t vluxei8(const int8_t *, vuint8mf2_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vluxei8_v_m)))
vint8mf2_t vluxei8(vbool16_t, vint8mf2_t, const int8_t *, vuint8mf2_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vluxei8_v)))
vint8mf4_t vluxei8(const int8_t *, vuint8mf4_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vluxei8_v_m)))
vint8mf4_t vluxei8(vbool32_t, vint8mf4_t, const int8_t *, vuint8mf4_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vluxei8_v)))
vint8mf8_t vluxei8(const int8_t *, vuint8mf8_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vluxei8_v_m)))
vint8mf8_t vluxei8(vbool64_t, vint8mf8_t, const int8_t *, vuint8mf8_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vse32_v)))
void vse32(uint32_t *, vuint32m1_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vse32_v_m)))
void vse32(vbool32_t, uint32_t *, vuint32m1_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vse32_v)))
void vse32(uint32_t *, vuint32m2_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vse32_v_m)))
void vse32(vbool16_t, uint32_t *, vuint32m2_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vse32_v)))
void vse32(uint32_t *, vuint32m4_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vse32_v_m)))
void vse32(vbool8_t, uint32_t *, vuint32m4_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vse32_v)))
void vse32(uint32_t *, vuint32m8_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vse32_v_m)))
void vse32(vbool4_t, uint32_t *, vuint32m8_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vse32_v)))
void vse32(uint32_t *, vuint32mf2_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vse32_v_m)))
void vse32(vbool64_t, uint32_t *, vuint32mf2_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vloxseg2ei16_v)))
void vloxseg2ei16(vint16m1_t *, vint16m1_t *, const int16_t *, vuint16m1_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vloxseg2ei16_v_m)))
void vloxseg2ei16(vint16m1_t *, vint16m1_t *, vbool16_t, vint16m1_t, vint16m1_t, const int16_t *, vuint16m1_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vloxseg2ei16_v)))
void vloxseg2ei16(vint16m2_t *, vint16m2_t *, const int16_t *, vuint16m2_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vloxseg2ei16_v_m)))
void vloxseg2ei16(vint16m2_t *, vint16m2_t *, vbool8_t, vint16m2_t, vint16m2_t, const int16_t *, vuint16m2_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vloxseg2ei16_v)))
void vloxseg2ei16(vint16m4_t *, vint16m4_t *, const int16_t *, vuint16m4_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vloxseg2ei16_v_m)))
void vloxseg2ei16(vint16m4_t *, vint16m4_t *, vbool4_t, vint16m4_t, vint16m4_t, const int16_t *, vuint16m4_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vloxseg2ei16_v)))
void vloxseg2ei16(vint16mf2_t *, vint16mf2_t *, const int16_t *, vuint16mf2_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vloxseg2ei16_v_m)))
void vloxseg2ei16(vint16mf2_t *, vint16mf2_t *, vbool32_t, vint16mf2_t, vint16mf2_t, const int16_t *, vuint16mf2_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vloxseg2ei16_v)))
void vloxseg2ei16(vint16mf4_t *, vint16mf4_t *, const int16_t *, vuint16mf4_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vloxseg2ei16_v_m)))
void vloxseg2ei16(vint16mf4_t *, vint16mf4_t *, vbool64_t, vint16mf4_t, vint16mf4_t, const int16_t *, vuint16mf4_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vloxseg2ei16_v)))
void vloxseg2ei16(vuint16m1_t *, vuint16m1_t *, const uint16_t *, vuint16m1_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vloxseg2ei16_v_m)))
void vloxseg2ei16(vuint16m1_t *, vuint16m1_t *, vbool16_t, vuint16m1_t, vuint16m1_t, const uint16_t *, vuint16m1_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vloxseg2ei16_v)))
void vloxseg2ei16(vuint16m2_t *, vuint16m2_t *, const uint16_t *, vuint16m2_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vloxseg2ei16_v_m)))
void vloxseg2ei16(vuint16m2_t *, vuint16m2_t *, vbool8_t, vuint16m2_t, vuint16m2_t, const uint16_t *, vuint16m2_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vloxseg2ei16_v)))
void vloxseg2ei16(vuint16m4_t *, vuint16m4_t *, const uint16_t *, vuint16m4_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vloxseg2ei16_v_m)))
void vloxseg2ei16(vuint16m4_t *, vuint16m4_t *, vbool4_t, vuint16m4_t, vuint16m4_t, const uint16_t *, vuint16m4_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vloxseg2ei16_v)))
void vloxseg2ei16(vuint16mf2_t *, vuint16mf2_t *, const uint16_t *, vuint16mf2_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vloxseg2ei16_v_m)))
void vloxseg2ei16(vuint16mf2_t *, vuint16mf2_t *, vbool32_t, vuint16mf2_t, vuint16mf2_t, const uint16_t *, vuint16mf2_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vloxseg2ei16_v)))
void vloxseg2ei16(vuint16mf4_t *, vuint16mf4_t *, const uint16_t *, vuint16mf4_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vloxseg2ei16_v_m)))
void vloxseg2ei16(vuint16mf4_t *, vuint16mf4_t *, vbool64_t, vuint16mf4_t, vuint16mf4_t, const uint16_t *, vuint16mf4_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vloxseg3ei16_v)))
void vloxseg3ei16(vint16m1_t *, vint16m1_t *, vint16m1_t *, const int16_t *, vuint16m1_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vloxseg3ei16_v_m)))
void vloxseg3ei16(vint16m1_t *, vint16m1_t *, vint16m1_t *, vbool16_t, vint16m1_t, vint16m1_t, vint16m1_t, const int16_t *, vuint16m1_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vloxseg3ei16_v)))
void vloxseg3ei16(vint16m2_t *, vint16m2_t *, vint16m2_t *, const int16_t *, vuint16m2_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vloxseg3ei16_v_m)))
void vloxseg3ei16(vint16m2_t *, vint16m2_t *, vint16m2_t *, vbool8_t, vint16m2_t, vint16m2_t, vint16m2_t, const int16_t *, vuint16m2_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vloxseg3ei16_v)))
void vloxseg3ei16(vint16mf2_t *, vint16mf2_t *, vint16mf2_t *, const int16_t *, vuint16mf2_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vloxseg3ei16_v_m)))
void vloxseg3ei16(vint16mf2_t *, vint16mf2_t *, vint16mf2_t *, vbool32_t, vint16mf2_t, vint16mf2_t, vint16mf2_t, const int16_t *, vuint16mf2_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vloxseg3ei16_v)))
void vloxseg3ei16(vint16mf4_t *, vint16mf4_t *, vint16mf4_t *, const int16_t *, vuint16mf4_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vloxseg3ei16_v_m)))
void vloxseg3ei16(vint16mf4_t *, vint16mf4_t *, vint16mf4_t *, vbool64_t, vint16mf4_t, vint16mf4_t, vint16mf4_t, const int16_t *, vuint16mf4_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vloxseg3ei16_v)))
void vloxseg3ei16(vuint16m1_t *, vuint16m1_t *, vuint16m1_t *, const uint16_t *, vuint16m1_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vloxseg3ei16_v_m)))
void vloxseg3ei16(vuint16m1_t *, vuint16m1_t *, vuint16m1_t *, vbool16_t, vuint16m1_t, vuint16m1_t, vuint16m1_t, const uint16_t *, vuint16m1_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vloxseg3ei16_v)))
void vloxseg3ei16(vuint16m2_t *, vuint16m2_t *, vuint16m2_t *, const uint16_t *, vuint16m2_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vloxseg3ei16_v_m)))
void vloxseg3ei16(vuint16m2_t *, vuint16m2_t *, vuint16m2_t *, vbool8_t, vuint16m2_t, vuint16m2_t, vuint16m2_t, const uint16_t *, vuint16m2_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vloxseg3ei16_v)))
void vloxseg3ei16(vuint16mf2_t *, vuint16mf2_t *, vuint16mf2_t *, const uint16_t *, vuint16mf2_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vloxseg3ei16_v_m)))
void vloxseg3ei16(vuint16mf2_t *, vuint16mf2_t *, vuint16mf2_t *, vbool32_t, vuint16mf2_t, vuint16mf2_t, vuint16mf2_t, const uint16_t *, vuint16mf2_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vloxseg3ei16_v)))
void vloxseg3ei16(vuint16mf4_t *, vuint16mf4_t *, vuint16mf4_t *, const uint16_t *, vuint16mf4_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vloxseg3ei16_v_m)))
void vloxseg3ei16(vuint16mf4_t *, vuint16mf4_t *, vuint16mf4_t *, vbool64_t, vuint16mf4_t, vuint16mf4_t, vuint16mf4_t, const uint16_t *, vuint16mf4_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vloxseg4ei16_v)))
void vloxseg4ei16(vint16m1_t *, vint16m1_t *, vint16m1_t *, vint16m1_t *, const int16_t *, vuint16m1_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vloxseg4ei16_v_m)))
void vloxseg4ei16(vint16m1_t *, vint16m1_t *, vint16m1_t *, vint16m1_t *, vbool16_t, vint16m1_t, vint16m1_t, vint16m1_t, vint16m1_t, const int16_t *, vuint16m1_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vloxseg4ei16_v)))
void vloxseg4ei16(vint16m2_t *, vint16m2_t *, vint16m2_t *, vint16m2_t *, const int16_t *, vuint16m2_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vloxseg4ei16_v_m)))
void vloxseg4ei16(vint16m2_t *, vint16m2_t *, vint16m2_t *, vint16m2_t *, vbool8_t, vint16m2_t, vint16m2_t, vint16m2_t, vint16m2_t, const int16_t *, vuint16m2_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vloxseg4ei16_v)))
void vloxseg4ei16(vint16mf2_t *, vint16mf2_t *, vint16mf2_t *, vint16mf2_t *, const int16_t *, vuint16mf2_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vloxseg4ei16_v_m)))
void vloxseg4ei16(vint16mf2_t *, vint16mf2_t *, vint16mf2_t *, vint16mf2_t *, vbool32_t, vint16mf2_t, vint16mf2_t, vint16mf2_t, vint16mf2_t, const int16_t *, vuint16mf2_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vloxseg4ei16_v)))
void vloxseg4ei16(vint16mf4_t *, vint16mf4_t *, vint16mf4_t *, vint16mf4_t *, const int16_t *, vuint16mf4_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vloxseg4ei16_v_m)))
void vloxseg4ei16(vint16mf4_t *, vint16mf4_t *, vint16mf4_t *, vint16mf4_t *, vbool64_t, vint16mf4_t, vint16mf4_t, vint16mf4_t, vint16mf4_t, const int16_t *, vuint16mf4_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vloxseg4ei16_v)))
void vloxseg4ei16(vuint16m1_t *, vuint16m1_t *, vuint16m1_t *, vuint16m1_t *, const uint16_t *, vuint16m1_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vloxseg4ei16_v_m)))
void vloxseg4ei16(vuint16m1_t *, vuint16m1_t *, vuint16m1_t *, vuint16m1_t *, vbool16_t, vuint16m1_t, vuint16m1_t, vuint16m1_t, vuint16m1_t, const uint16_t *, vuint16m1_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vloxseg4ei16_v)))
void vloxseg4ei16(vuint16m2_t *, vuint16m2_t *, vuint16m2_t *, vuint16m2_t *, const uint16_t *, vuint16m2_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vloxseg4ei16_v_m)))
void vloxseg4ei16(vuint16m2_t *, vuint16m2_t *, vuint16m2_t *, vuint16m2_t *, vbool8_t, vuint16m2_t, vuint16m2_t, vuint16m2_t, vuint16m2_t, const uint16_t *, vuint16m2_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vloxseg4ei16_v)))
void vloxseg4ei16(vuint16mf2_t *, vuint16mf2_t *, vuint16mf2_t *, vuint16mf2_t *, const uint16_t *, vuint16mf2_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vloxseg4ei16_v_m)))
void vloxseg4ei16(vuint16mf2_t *, vuint16mf2_t *, vuint16mf2_t *, vuint16mf2_t *, vbool32_t, vuint16mf2_t, vuint16mf2_t, vuint16mf2_t, vuint16mf2_t, const uint16_t *, vuint16mf2_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vloxseg4ei16_v)))
void vloxseg4ei16(vuint16mf4_t *, vuint16mf4_t *, vuint16mf4_t *, vuint16mf4_t *, const uint16_t *, vuint16mf4_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vloxseg4ei16_v_m)))
void vloxseg4ei16(vuint16mf4_t *, vuint16mf4_t *, vuint16mf4_t *, vuint16mf4_t *, vbool64_t, vuint16mf4_t, vuint16mf4_t, vuint16mf4_t, vuint16mf4_t, const uint16_t *, vuint16mf4_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vloxseg5ei16_v)))
void vloxseg5ei16(vint16m1_t *, vint16m1_t *, vint16m1_t *, vint16m1_t *, vint16m1_t *, const int16_t *, vuint16m1_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vloxseg5ei16_v_m)))
void vloxseg5ei16(vint16m1_t *, vint16m1_t *, vint16m1_t *, vint16m1_t *, vint16m1_t *, vbool16_t, vint16m1_t, vint16m1_t, vint16m1_t, vint16m1_t, vint16m1_t, const int16_t *, vuint16m1_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vloxseg5ei16_v)))
void vloxseg5ei16(vint16mf2_t *, vint16mf2_t *, vint16mf2_t *, vint16mf2_t *, vint16mf2_t *, const int16_t *, vuint16mf2_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vloxseg5ei16_v_m)))
void vloxseg5ei16(vint16mf2_t *, vint16mf2_t *, vint16mf2_t *, vint16mf2_t *, vint16mf2_t *, vbool32_t, vint16mf2_t, vint16mf2_t, vint16mf2_t, vint16mf2_t, vint16mf2_t, const int16_t *, vuint16mf2_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vloxseg5ei16_v)))
void vloxseg5ei16(vint16mf4_t *, vint16mf4_t *, vint16mf4_t *, vint16mf4_t *, vint16mf4_t *, const int16_t *, vuint16mf4_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vloxseg5ei16_v_m)))
void vloxseg5ei16(vint16mf4_t *, vint16mf4_t *, vint16mf4_t *, vint16mf4_t *, vint16mf4_t *, vbool64_t, vint16mf4_t, vint16mf4_t, vint16mf4_t, vint16mf4_t, vint16mf4_t, const int16_t *, vuint16mf4_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vloxseg5ei16_v)))
void vloxseg5ei16(vuint16m1_t *, vuint16m1_t *, vuint16m1_t *, vuint16m1_t *, vuint16m1_t *, const uint16_t *, vuint16m1_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vloxseg5ei16_v_m)))
void vloxseg5ei16(vuint16m1_t *, vuint16m1_t *, vuint16m1_t *, vuint16m1_t *, vuint16m1_t *, vbool16_t, vuint16m1_t, vuint16m1_t, vuint16m1_t, vuint16m1_t, vuint16m1_t, const uint16_t *, vuint16m1_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vloxseg5ei16_v)))
void vloxseg5ei16(vuint16mf2_t *, vuint16mf2_t *, vuint16mf2_t *, vuint16mf2_t *, vuint16mf2_t *, const uint16_t *, vuint16mf2_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vloxseg5ei16_v_m)))
void vloxseg5ei16(vuint16mf2_t *, vuint16mf2_t *, vuint16mf2_t *, vuint16mf2_t *, vuint16mf2_t *, vbool32_t, vuint16mf2_t, vuint16mf2_t, vuint16mf2_t, vuint16mf2_t, vuint16mf2_t, const uint16_t *, vuint16mf2_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vloxseg5ei16_v)))
void vloxseg5ei16(vuint16mf4_t *, vuint16mf4_t *, vuint16mf4_t *, vuint16mf4_t *, vuint16mf4_t *, const uint16_t *, vuint16mf4_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vloxseg5ei16_v_m)))
void vloxseg5ei16(vuint16mf4_t *, vuint16mf4_t *, vuint16mf4_t *, vuint16mf4_t *, vuint16mf4_t *, vbool64_t, vuint16mf4_t, vuint16mf4_t, vuint16mf4_t, vuint16mf4_t, vuint16mf4_t, const uint16_t *, vuint16mf4_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vloxseg6ei16_v)))
void vloxseg6ei16(vint16m1_t *, vint16m1_t *, vint16m1_t *, vint16m1_t *, vint16m1_t *, vint16m1_t *, const int16_t *, vuint16m1_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vloxseg6ei16_v_m)))
void vloxseg6ei16(vint16m1_t *, vint16m1_t *, vint16m1_t *, vint16m1_t *, vint16m1_t *, vint16m1_t *, vbool16_t, vint16m1_t, vint16m1_t, vint16m1_t, vint16m1_t, vint16m1_t, vint16m1_t, const int16_t *, vuint16m1_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vloxseg6ei16_v)))
void vloxseg6ei16(vint16mf2_t *, vint16mf2_t *, vint16mf2_t *, vint16mf2_t *, vint16mf2_t *, vint16mf2_t *, const int16_t *, vuint16mf2_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vloxseg6ei16_v_m)))
void vloxseg6ei16(vint16mf2_t *, vint16mf2_t *, vint16mf2_t *, vint16mf2_t *, vint16mf2_t *, vint16mf2_t *, vbool32_t, vint16mf2_t, vint16mf2_t, vint16mf2_t, vint16mf2_t, vint16mf2_t, vint16mf2_t, const int16_t *, vuint16mf2_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vloxseg6ei16_v)))
void vloxseg6ei16(vint16mf4_t *, vint16mf4_t *, vint16mf4_t *, vint16mf4_t *, vint16mf4_t *, vint16mf4_t *, const int16_t *, vuint16mf4_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vloxseg6ei16_v_m)))
void vloxseg6ei16(vint16mf4_t *, vint16mf4_t *, vint16mf4_t *, vint16mf4_t *, vint16mf4_t *, vint16mf4_t *, vbool64_t, vint16mf4_t, vint16mf4_t, vint16mf4_t, vint16mf4_t, vint16mf4_t, vint16mf4_t, const int16_t *, vuint16mf4_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vloxseg6ei16_v)))
void vloxseg6ei16(vuint16m1_t *, vuint16m1_t *, vuint16m1_t *, vuint16m1_t *, vuint16m1_t *, vuint16m1_t *, const uint16_t *, vuint16m1_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vloxseg6ei16_v_m)))
void vloxseg6ei16(vuint16m1_t *, vuint16m1_t *, vuint16m1_t *, vuint16m1_t *, vuint16m1_t *, vuint16m1_t *, vbool16_t, vuint16m1_t, vuint16m1_t, vuint16m1_t, vuint16m1_t, vuint16m1_t, vuint16m1_t, const uint16_t *, vuint16m1_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vloxseg6ei16_v)))
void vloxseg6ei16(vuint16mf2_t *, vuint16mf2_t *, vuint16mf2_t *, vuint16mf2_t *, vuint16mf2_t *, vuint16mf2_t *, const uint16_t *, vuint16mf2_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vloxseg6ei16_v_m)))
void vloxseg6ei16(vuint16mf2_t *, vuint16mf2_t *, vuint16mf2_t *, vuint16mf2_t *, vuint16mf2_t *, vuint16mf2_t *, vbool32_t, vuint16mf2_t, vuint16mf2_t, vuint16mf2_t, vuint16mf2_t, vuint16mf2_t, vuint16mf2_t, const uint16_t *, vuint16mf2_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vloxseg6ei16_v)))
void vloxseg6ei16(vuint16mf4_t *, vuint16mf4_t *, vuint16mf4_t *, vuint16mf4_t *, vuint16mf4_t *, vuint16mf4_t *, const uint16_t *, vuint16mf4_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vloxseg6ei16_v_m)))
void vloxseg6ei16(vuint16mf4_t *, vuint16mf4_t *, vuint16mf4_t *, vuint16mf4_t *, vuint16mf4_t *, vuint16mf4_t *, vbool64_t, vuint16mf4_t, vuint16mf4_t, vuint16mf4_t, vuint16mf4_t, vuint16mf4_t, vuint16mf4_t, const uint16_t *, vuint16mf4_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vloxseg7ei16_v)))
void vloxseg7ei16(vint16m1_t *, vint16m1_t *, vint16m1_t *, vint16m1_t *, vint16m1_t *, vint16m1_t *, vint16m1_t *, const int16_t *, vuint16m1_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vloxseg7ei16_v_m)))
void vloxseg7ei16(vint16m1_t *, vint16m1_t *, vint16m1_t *, vint16m1_t *, vint16m1_t *, vint16m1_t *, vint16m1_t *, vbool16_t, vint16m1_t, vint16m1_t, vint16m1_t, vint16m1_t, vint16m1_t, vint16m1_t, vint16m1_t, const int16_t *, vuint16m1_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vloxseg7ei16_v)))
void vloxseg7ei16(vint16mf2_t *, vint16mf2_t *, vint16mf2_t *, vint16mf2_t *, vint16mf2_t *, vint16mf2_t *, vint16mf2_t *, const int16_t *, vuint16mf2_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vloxseg7ei16_v_m)))
void vloxseg7ei16(vint16mf2_t *, vint16mf2_t *, vint16mf2_t *, vint16mf2_t *, vint16mf2_t *, vint16mf2_t *, vint16mf2_t *, vbool32_t, vint16mf2_t, vint16mf2_t, vint16mf2_t, vint16mf2_t, vint16mf2_t, vint16mf2_t, vint16mf2_t, const int16_t *, vuint16mf2_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vloxseg7ei16_v)))
void vloxseg7ei16(vint16mf4_t *, vint16mf4_t *, vint16mf4_t *, vint16mf4_t *, vint16mf4_t *, vint16mf4_t *, vint16mf4_t *, const int16_t *, vuint16mf4_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vloxseg7ei16_v_m)))
void vloxseg7ei16(vint16mf4_t *, vint16mf4_t *, vint16mf4_t *, vint16mf4_t *, vint16mf4_t *, vint16mf4_t *, vint16mf4_t *, vbool64_t, vint16mf4_t, vint16mf4_t, vint16mf4_t, vint16mf4_t, vint16mf4_t, vint16mf4_t, vint16mf4_t, const int16_t *, vuint16mf4_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vloxseg7ei16_v)))
void vloxseg7ei16(vuint16m1_t *, vuint16m1_t *, vuint16m1_t *, vuint16m1_t *, vuint16m1_t *, vuint16m1_t *, vuint16m1_t *, const uint16_t *, vuint16m1_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vloxseg7ei16_v_m)))
void vloxseg7ei16(vuint16m1_t *, vuint16m1_t *, vuint16m1_t *, vuint16m1_t *, vuint16m1_t *, vuint16m1_t *, vuint16m1_t *, vbool16_t, vuint16m1_t, vuint16m1_t, vuint16m1_t, vuint16m1_t, vuint16m1_t, vuint16m1_t, vuint16m1_t, const uint16_t *, vuint16m1_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vloxseg7ei16_v)))
void vloxseg7ei16(vuint16mf2_t *, vuint16mf2_t *, vuint16mf2_t *, vuint16mf2_t *, vuint16mf2_t *, vuint16mf2_t *, vuint16mf2_t *, const uint16_t *, vuint16mf2_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vloxseg7ei16_v_m)))
void vloxseg7ei16(vuint16mf2_t *, vuint16mf2_t *, vuint16mf2_t *, vuint16mf2_t *, vuint16mf2_t *, vuint16mf2_t *, vuint16mf2_t *, vbool32_t, vuint16mf2_t, vuint16mf2_t, vuint16mf2_t, vuint16mf2_t, vuint16mf2_t, vuint16mf2_t, vuint16mf2_t, const uint16_t *, vuint16mf2_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vloxseg7ei16_v)))
void vloxseg7ei16(vuint16mf4_t *, vuint16mf4_t *, vuint16mf4_t *, vuint16mf4_t *, vuint16mf4_t *, vuint16mf4_t *, vuint16mf4_t *, const uint16_t *, vuint16mf4_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vloxseg7ei16_v_m)))
void vloxseg7ei16(vuint16mf4_t *, vuint16mf4_t *, vuint16mf4_t *, vuint16mf4_t *, vuint16mf4_t *, vuint16mf4_t *, vuint16mf4_t *, vbool64_t, vuint16mf4_t, vuint16mf4_t, vuint16mf4_t, vuint16mf4_t, vuint16mf4_t, vuint16mf4_t, vuint16mf4_t, const uint16_t *, vuint16mf4_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vloxseg8ei16_v)))
void vloxseg8ei16(vint16m1_t *, vint16m1_t *, vint16m1_t *, vint16m1_t *, vint16m1_t *, vint16m1_t *, vint16m1_t *, vint16m1_t *, const int16_t *, vuint16m1_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vloxseg8ei16_v_m)))
void vloxseg8ei16(vint16m1_t *, vint16m1_t *, vint16m1_t *, vint16m1_t *, vint16m1_t *, vint16m1_t *, vint16m1_t *, vint16m1_t *, vbool16_t, vint16m1_t, vint16m1_t, vint16m1_t, vint16m1_t, vint16m1_t, vint16m1_t, vint16m1_t, vint16m1_t, const int16_t *, vuint16m1_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vloxseg8ei16_v)))
void vloxseg8ei16(vint16mf2_t *, vint16mf2_t *, vint16mf2_t *, vint16mf2_t *, vint16mf2_t *, vint16mf2_t *, vint16mf2_t *, vint16mf2_t *, const int16_t *, vuint16mf2_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vloxseg8ei16_v_m)))
void vloxseg8ei16(vint16mf2_t *, vint16mf2_t *, vint16mf2_t *, vint16mf2_t *, vint16mf2_t *, vint16mf2_t *, vint16mf2_t *, vint16mf2_t *, vbool32_t, vint16mf2_t, vint16mf2_t, vint16mf2_t, vint16mf2_t, vint16mf2_t, vint16mf2_t, vint16mf2_t, vint16mf2_t, const int16_t *, vuint16mf2_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vloxseg8ei16_v)))
void vloxseg8ei16(vint16mf4_t *, vint16mf4_t *, vint16mf4_t *, vint16mf4_t *, vint16mf4_t *, vint16mf4_t *, vint16mf4_t *, vint16mf4_t *, const int16_t *, vuint16mf4_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vloxseg8ei16_v_m)))
void vloxseg8ei16(vint16mf4_t *, vint16mf4_t *, vint16mf4_t *, vint16mf4_t *, vint16mf4_t *, vint16mf4_t *, vint16mf4_t *, vint16mf4_t *, vbool64_t, vint16mf4_t, vint16mf4_t, vint16mf4_t, vint16mf4_t, vint16mf4_t, vint16mf4_t, vint16mf4_t, vint16mf4_t, const int16_t *, vuint16mf4_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vloxseg8ei16_v)))
void vloxseg8ei16(vuint16m1_t *, vuint16m1_t *, vuint16m1_t *, vuint16m1_t *, vuint16m1_t *, vuint16m1_t *, vuint16m1_t *, vuint16m1_t *, const uint16_t *, vuint16m1_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vloxseg8ei16_v_m)))
void vloxseg8ei16(vuint16m1_t *, vuint16m1_t *, vuint16m1_t *, vuint16m1_t *, vuint16m1_t *, vuint16m1_t *, vuint16m1_t *, vuint16m1_t *, vbool16_t, vuint16m1_t, vuint16m1_t, vuint16m1_t, vuint16m1_t, vuint16m1_t, vuint16m1_t, vuint16m1_t, vuint16m1_t, const uint16_t *, vuint16m1_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vloxseg8ei16_v)))
void vloxseg8ei16(vuint16mf2_t *, vuint16mf2_t *, vuint16mf2_t *, vuint16mf2_t *, vuint16mf2_t *, vuint16mf2_t *, vuint16mf2_t *, vuint16mf2_t *, const uint16_t *, vuint16mf2_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vloxseg8ei16_v_m)))
void vloxseg8ei16(vuint16mf2_t *, vuint16mf2_t *, vuint16mf2_t *, vuint16mf2_t *, vuint16mf2_t *, vuint16mf2_t *, vuint16mf2_t *, vuint16mf2_t *, vbool32_t, vuint16mf2_t, vuint16mf2_t, vuint16mf2_t, vuint16mf2_t, vuint16mf2_t, vuint16mf2_t, vuint16mf2_t, vuint16mf2_t, const uint16_t *, vuint16mf2_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vloxseg8ei16_v)))
void vloxseg8ei16(vuint16mf4_t *, vuint16mf4_t *, vuint16mf4_t *, vuint16mf4_t *, vuint16mf4_t *, vuint16mf4_t *, vuint16mf4_t *, vuint16mf4_t *, const uint16_t *, vuint16mf4_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vloxseg8ei16_v_m)))
void vloxseg8ei16(vuint16mf4_t *, vuint16mf4_t *, vuint16mf4_t *, vuint16mf4_t *, vuint16mf4_t *, vuint16mf4_t *, vuint16mf4_t *, vuint16mf4_t *, vbool64_t, vuint16mf4_t, vuint16mf4_t, vuint16mf4_t, vuint16mf4_t, vuint16mf4_t, vuint16mf4_t, vuint16mf4_t, vuint16mf4_t, const uint16_t *, vuint16mf4_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vloxseg2ei32_v)))
void vloxseg2ei32(vint16m1_t *, vint16m1_t *, const int16_t *, vuint32m2_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vloxseg2ei32_v_m)))
void vloxseg2ei32(vint16m1_t *, vint16m1_t *, vbool16_t, vint16m1_t, vint16m1_t, const int16_t *, vuint32m2_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vloxseg2ei32_v)))
void vloxseg2ei32(vint16m2_t *, vint16m2_t *, const int16_t *, vuint32m4_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vloxseg2ei32_v_m)))
void vloxseg2ei32(vint16m2_t *, vint16m2_t *, vbool8_t, vint16m2_t, vint16m2_t, const int16_t *, vuint32m4_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vloxseg2ei32_v)))
void vloxseg2ei32(vint16m4_t *, vint16m4_t *, const int16_t *, vuint32m8_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vloxseg2ei32_v_m)))
void vloxseg2ei32(vint16m4_t *, vint16m4_t *, vbool4_t, vint16m4_t, vint16m4_t, const int16_t *, vuint32m8_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vloxseg2ei32_v)))
void vloxseg2ei32(vint16mf2_t *, vint16mf2_t *, const int16_t *, vuint32m1_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vloxseg2ei32_v_m)))
void vloxseg2ei32(vint16mf2_t *, vint16mf2_t *, vbool32_t, vint16mf2_t, vint16mf2_t, const int16_t *, vuint32m1_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vloxseg2ei32_v)))
void vloxseg2ei32(vint16mf4_t *, vint16mf4_t *, const int16_t *, vuint32mf2_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vloxseg2ei32_v_m)))
void vloxseg2ei32(vint16mf4_t *, vint16mf4_t *, vbool64_t, vint16mf4_t, vint16mf4_t, const int16_t *, vuint32mf2_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vloxseg2ei32_v)))
void vloxseg2ei32(vuint16m1_t *, vuint16m1_t *, const uint16_t *, vuint32m2_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vloxseg2ei32_v_m)))
void vloxseg2ei32(vuint16m1_t *, vuint16m1_t *, vbool16_t, vuint16m1_t, vuint16m1_t, const uint16_t *, vuint32m2_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vloxseg2ei32_v)))
void vloxseg2ei32(vuint16m2_t *, vuint16m2_t *, const uint16_t *, vuint32m4_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vloxseg2ei32_v_m)))
void vloxseg2ei32(vuint16m2_t *, vuint16m2_t *, vbool8_t, vuint16m2_t, vuint16m2_t, const uint16_t *, vuint32m4_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vloxseg2ei32_v)))
void vloxseg2ei32(vuint16m4_t *, vuint16m4_t *, const uint16_t *, vuint32m8_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vloxseg2ei32_v_m)))
void vloxseg2ei32(vuint16m4_t *, vuint16m4_t *, vbool4_t, vuint16m4_t, vuint16m4_t, const uint16_t *, vuint32m8_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vloxseg2ei32_v)))
void vloxseg2ei32(vuint16mf2_t *, vuint16mf2_t *, const uint16_t *, vuint32m1_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vloxseg2ei32_v_m)))
void vloxseg2ei32(vuint16mf2_t *, vuint16mf2_t *, vbool32_t, vuint16mf2_t, vuint16mf2_t, const uint16_t *, vuint32m1_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vloxseg2ei32_v)))
void vloxseg2ei32(vuint16mf4_t *, vuint16mf4_t *, const uint16_t *, vuint32mf2_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vloxseg2ei32_v_m)))
void vloxseg2ei32(vuint16mf4_t *, vuint16mf4_t *, vbool64_t, vuint16mf4_t, vuint16mf4_t, const uint16_t *, vuint32mf2_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vloxseg3ei32_v)))
void vloxseg3ei32(vint16m1_t *, vint16m1_t *, vint16m1_t *, const int16_t *, vuint32m2_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vloxseg3ei32_v_m)))
void vloxseg3ei32(vint16m1_t *, vint16m1_t *, vint16m1_t *, vbool16_t, vint16m1_t, vint16m1_t, vint16m1_t, const int16_t *, vuint32m2_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vloxseg3ei32_v)))
void vloxseg3ei32(vint16m2_t *, vint16m2_t *, vint16m2_t *, const int16_t *, vuint32m4_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vloxseg3ei32_v_m)))
void vloxseg3ei32(vint16m2_t *, vint16m2_t *, vint16m2_t *, vbool8_t, vint16m2_t, vint16m2_t, vint16m2_t, const int16_t *, vuint32m4_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vloxseg3ei32_v)))
void vloxseg3ei32(vint16mf2_t *, vint16mf2_t *, vint16mf2_t *, const int16_t *, vuint32m1_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vloxseg3ei32_v_m)))
void vloxseg3ei32(vint16mf2_t *, vint16mf2_t *, vint16mf2_t *, vbool32_t, vint16mf2_t, vint16mf2_t, vint16mf2_t, const int16_t *, vuint32m1_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vloxseg3ei32_v)))
void vloxseg3ei32(vint16mf4_t *, vint16mf4_t *, vint16mf4_t *, const int16_t *, vuint32mf2_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vloxseg3ei32_v_m)))
void vloxseg3ei32(vint16mf4_t *, vint16mf4_t *, vint16mf4_t *, vbool64_t, vint16mf4_t, vint16mf4_t, vint16mf4_t, const int16_t *, vuint32mf2_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vloxseg3ei32_v)))
void vloxseg3ei32(vuint16m1_t *, vuint16m1_t *, vuint16m1_t *, const uint16_t *, vuint32m2_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vloxseg3ei32_v_m)))
void vloxseg3ei32(vuint16m1_t *, vuint16m1_t *, vuint16m1_t *, vbool16_t, vuint16m1_t, vuint16m1_t, vuint16m1_t, const uint16_t *, vuint32m2_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vloxseg3ei32_v)))
void vloxseg3ei32(vuint16m2_t *, vuint16m2_t *, vuint16m2_t *, const uint16_t *, vuint32m4_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vloxseg3ei32_v_m)))
void vloxseg3ei32(vuint16m2_t *, vuint16m2_t *, vuint16m2_t *, vbool8_t, vuint16m2_t, vuint16m2_t, vuint16m2_t, const uint16_t *, vuint32m4_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vloxseg3ei32_v)))
void vloxseg3ei32(vuint16mf2_t *, vuint16mf2_t *, vuint16mf2_t *, const uint16_t *, vuint32m1_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vloxseg3ei32_v_m)))
void vloxseg3ei32(vuint16mf2_t *, vuint16mf2_t *, vuint16mf2_t *, vbool32_t, vuint16mf2_t, vuint16mf2_t, vuint16mf2_t, const uint16_t *, vuint32m1_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vloxseg3ei32_v)))
void vloxseg3ei32(vuint16mf4_t *, vuint16mf4_t *, vuint16mf4_t *, const uint16_t *, vuint32mf2_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vloxseg3ei32_v_m)))
void vloxseg3ei32(vuint16mf4_t *, vuint16mf4_t *, vuint16mf4_t *, vbool64_t, vuint16mf4_t, vuint16mf4_t, vuint16mf4_t, const uint16_t *, vuint32mf2_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vloxseg4ei32_v)))
void vloxseg4ei32(vint16m1_t *, vint16m1_t *, vint16m1_t *, vint16m1_t *, const int16_t *, vuint32m2_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vloxseg4ei32_v_m)))
void vloxseg4ei32(vint16m1_t *, vint16m1_t *, vint16m1_t *, vint16m1_t *, vbool16_t, vint16m1_t, vint16m1_t, vint16m1_t, vint16m1_t, const int16_t *, vuint32m2_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vloxseg4ei32_v)))
void vloxseg4ei32(vint16m2_t *, vint16m2_t *, vint16m2_t *, vint16m2_t *, const int16_t *, vuint32m4_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vloxseg4ei32_v_m)))
void vloxseg4ei32(vint16m2_t *, vint16m2_t *, vint16m2_t *, vint16m2_t *, vbool8_t, vint16m2_t, vint16m2_t, vint16m2_t, vint16m2_t, const int16_t *, vuint32m4_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vloxseg4ei32_v)))
void vloxseg4ei32(vint16mf2_t *, vint16mf2_t *, vint16mf2_t *, vint16mf2_t *, const int16_t *, vuint32m1_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vloxseg4ei32_v_m)))
void vloxseg4ei32(vint16mf2_t *, vint16mf2_t *, vint16mf2_t *, vint16mf2_t *, vbool32_t, vint16mf2_t, vint16mf2_t, vint16mf2_t, vint16mf2_t, const int16_t *, vuint32m1_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vloxseg4ei32_v)))
void vloxseg4ei32(vint16mf4_t *, vint16mf4_t *, vint16mf4_t *, vint16mf4_t *, const int16_t *, vuint32mf2_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vloxseg4ei32_v_m)))
void vloxseg4ei32(vint16mf4_t *, vint16mf4_t *, vint16mf4_t *, vint16mf4_t *, vbool64_t, vint16mf4_t, vint16mf4_t, vint16mf4_t, vint16mf4_t, const int16_t *, vuint32mf2_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vloxseg4ei32_v)))
void vloxseg4ei32(vuint16m1_t *, vuint16m1_t *, vuint16m1_t *, vuint16m1_t *, const uint16_t *, vuint32m2_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vloxseg4ei32_v_m)))
void vloxseg4ei32(vuint16m1_t *, vuint16m1_t *, vuint16m1_t *, vuint16m1_t *, vbool16_t, vuint16m1_t, vuint16m1_t, vuint16m1_t, vuint16m1_t, const uint16_t *, vuint32m2_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vloxseg4ei32_v)))
void vloxseg4ei32(vuint16m2_t *, vuint16m2_t *, vuint16m2_t *, vuint16m2_t *, const uint16_t *, vuint32m4_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vloxseg4ei32_v_m)))
void vloxseg4ei32(vuint16m2_t *, vuint16m2_t *, vuint16m2_t *, vuint16m2_t *, vbool8_t, vuint16m2_t, vuint16m2_t, vuint16m2_t, vuint16m2_t, const uint16_t *, vuint32m4_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vloxseg4ei32_v)))
void vloxseg4ei32(vuint16mf2_t *, vuint16mf2_t *, vuint16mf2_t *, vuint16mf2_t *, const uint16_t *, vuint32m1_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vloxseg4ei32_v_m)))
void vloxseg4ei32(vuint16mf2_t *, vuint16mf2_t *, vuint16mf2_t *, vuint16mf2_t *, vbool32_t, vuint16mf2_t, vuint16mf2_t, vuint16mf2_t, vuint16mf2_t, const uint16_t *, vuint32m1_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vloxseg4ei32_v)))
void vloxseg4ei32(vuint16mf4_t *, vuint16mf4_t *, vuint16mf4_t *, vuint16mf4_t *, const uint16_t *, vuint32mf2_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vloxseg4ei32_v_m)))
void vloxseg4ei32(vuint16mf4_t *, vuint16mf4_t *, vuint16mf4_t *, vuint16mf4_t *, vbool64_t, vuint16mf4_t, vuint16mf4_t, vuint16mf4_t, vuint16mf4_t, const uint16_t *, vuint32mf2_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vloxseg5ei32_v)))
void vloxseg5ei32(vint16m1_t *, vint16m1_t *, vint16m1_t *, vint16m1_t *, vint16m1_t *, const int16_t *, vuint32m2_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vloxseg5ei32_v_m)))
void vloxseg5ei32(vint16m1_t *, vint16m1_t *, vint16m1_t *, vint16m1_t *, vint16m1_t *, vbool16_t, vint16m1_t, vint16m1_t, vint16m1_t, vint16m1_t, vint16m1_t, const int16_t *, vuint32m2_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vloxseg5ei32_v)))
void vloxseg5ei32(vint16mf2_t *, vint16mf2_t *, vint16mf2_t *, vint16mf2_t *, vint16mf2_t *, const int16_t *, vuint32m1_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vloxseg5ei32_v_m)))
void vloxseg5ei32(vint16mf2_t *, vint16mf2_t *, vint16mf2_t *, vint16mf2_t *, vint16mf2_t *, vbool32_t, vint16mf2_t, vint16mf2_t, vint16mf2_t, vint16mf2_t, vint16mf2_t, const int16_t *, vuint32m1_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vloxseg5ei32_v)))
void vloxseg5ei32(vint16mf4_t *, vint16mf4_t *, vint16mf4_t *, vint16mf4_t *, vint16mf4_t *, const int16_t *, vuint32mf2_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vloxseg5ei32_v_m)))
void vloxseg5ei32(vint16mf4_t *, vint16mf4_t *, vint16mf4_t *, vint16mf4_t *, vint16mf4_t *, vbool64_t, vint16mf4_t, vint16mf4_t, vint16mf4_t, vint16mf4_t, vint16mf4_t, const int16_t *, vuint32mf2_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vloxseg5ei32_v)))
void vloxseg5ei32(vuint16m1_t *, vuint16m1_t *, vuint16m1_t *, vuint16m1_t *, vuint16m1_t *, const uint16_t *, vuint32m2_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vloxseg5ei32_v_m)))
void vloxseg5ei32(vuint16m1_t *, vuint16m1_t *, vuint16m1_t *, vuint16m1_t *, vuint16m1_t *, vbool16_t, vuint16m1_t, vuint16m1_t, vuint16m1_t, vuint16m1_t, vuint16m1_t, const uint16_t *, vuint32m2_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vloxseg5ei32_v)))
void vloxseg5ei32(vuint16mf2_t *, vuint16mf2_t *, vuint16mf2_t *, vuint16mf2_t *, vuint16mf2_t *, const uint16_t *, vuint32m1_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vloxseg5ei32_v_m)))
void vloxseg5ei32(vuint16mf2_t *, vuint16mf2_t *, vuint16mf2_t *, vuint16mf2_t *, vuint16mf2_t *, vbool32_t, vuint16mf2_t, vuint16mf2_t, vuint16mf2_t, vuint16mf2_t, vuint16mf2_t, const uint16_t *, vuint32m1_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vloxseg5ei32_v)))
void vloxseg5ei32(vuint16mf4_t *, vuint16mf4_t *, vuint16mf4_t *, vuint16mf4_t *, vuint16mf4_t *, const uint16_t *, vuint32mf2_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vloxseg5ei32_v_m)))
void vloxseg5ei32(vuint16mf4_t *, vuint16mf4_t *, vuint16mf4_t *, vuint16mf4_t *, vuint16mf4_t *, vbool64_t, vuint16mf4_t, vuint16mf4_t, vuint16mf4_t, vuint16mf4_t, vuint16mf4_t, const uint16_t *, vuint32mf2_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vloxseg6ei32_v)))
void vloxseg6ei32(vint16m1_t *, vint16m1_t *, vint16m1_t *, vint16m1_t *, vint16m1_t *, vint16m1_t *, const int16_t *, vuint32m2_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vloxseg6ei32_v_m)))
void vloxseg6ei32(vint16m1_t *, vint16m1_t *, vint16m1_t *, vint16m1_t *, vint16m1_t *, vint16m1_t *, vbool16_t, vint16m1_t, vint16m1_t, vint16m1_t, vint16m1_t, vint16m1_t, vint16m1_t, const int16_t *, vuint32m2_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vloxseg6ei32_v)))
void vloxseg6ei32(vint16mf2_t *, vint16mf2_t *, vint16mf2_t *, vint16mf2_t *, vint16mf2_t *, vint16mf2_t *, const int16_t *, vuint32m1_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vloxseg6ei32_v_m)))
void vloxseg6ei32(vint16mf2_t *, vint16mf2_t *, vint16mf2_t *, vint16mf2_t *, vint16mf2_t *, vint16mf2_t *, vbool32_t, vint16mf2_t, vint16mf2_t, vint16mf2_t, vint16mf2_t, vint16mf2_t, vint16mf2_t, const int16_t *, vuint32m1_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vloxseg6ei32_v)))
void vloxseg6ei32(vint16mf4_t *, vint16mf4_t *, vint16mf4_t *, vint16mf4_t *, vint16mf4_t *, vint16mf4_t *, const int16_t *, vuint32mf2_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vloxseg6ei32_v_m)))
void vloxseg6ei32(vint16mf4_t *, vint16mf4_t *, vint16mf4_t *, vint16mf4_t *, vint16mf4_t *, vint16mf4_t *, vbool64_t, vint16mf4_t, vint16mf4_t, vint16mf4_t, vint16mf4_t, vint16mf4_t, vint16mf4_t, const int16_t *, vuint32mf2_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vloxseg6ei32_v)))
void vloxseg6ei32(vuint16m1_t *, vuint16m1_t *, vuint16m1_t *, vuint16m1_t *, vuint16m1_t *, vuint16m1_t *, const uint16_t *, vuint32m2_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vloxseg6ei32_v_m)))
void vloxseg6ei32(vuint16m1_t *, vuint16m1_t *, vuint16m1_t *, vuint16m1_t *, vuint16m1_t *, vuint16m1_t *, vbool16_t, vuint16m1_t, vuint16m1_t, vuint16m1_t, vuint16m1_t, vuint16m1_t, vuint16m1_t, const uint16_t *, vuint32m2_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vloxseg6ei32_v)))
void vloxseg6ei32(vuint16mf2_t *, vuint16mf2_t *, vuint16mf2_t *, vuint16mf2_t *, vuint16mf2_t *, vuint16mf2_t *, const uint16_t *, vuint32m1_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vloxseg6ei32_v_m)))
void vloxseg6ei32(vuint16mf2_t *, vuint16mf2_t *, vuint16mf2_t *, vuint16mf2_t *, vuint16mf2_t *, vuint16mf2_t *, vbool32_t, vuint16mf2_t, vuint16mf2_t, vuint16mf2_t, vuint16mf2_t, vuint16mf2_t, vuint16mf2_t, const uint16_t *, vuint32m1_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vloxseg6ei32_v)))
void vloxseg6ei32(vuint16mf4_t *, vuint16mf4_t *, vuint16mf4_t *, vuint16mf4_t *, vuint16mf4_t *, vuint16mf4_t *, const uint16_t *, vuint32mf2_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vloxseg6ei32_v_m)))
void vloxseg6ei32(vuint16mf4_t *, vuint16mf4_t *, vuint16mf4_t *, vuint16mf4_t *, vuint16mf4_t *, vuint16mf4_t *, vbool64_t, vuint16mf4_t, vuint16mf4_t, vuint16mf4_t, vuint16mf4_t, vuint16mf4_t, vuint16mf4_t, const uint16_t *, vuint32mf2_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vloxseg7ei32_v)))
void vloxseg7ei32(vint16m1_t *, vint16m1_t *, vint16m1_t *, vint16m1_t *, vint16m1_t *, vint16m1_t *, vint16m1_t *, const int16_t *, vuint32m2_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vloxseg7ei32_v_m)))
void vloxseg7ei32(vint16m1_t *, vint16m1_t *, vint16m1_t *, vint16m1_t *, vint16m1_t *, vint16m1_t *, vint16m1_t *, vbool16_t, vint16m1_t, vint16m1_t, vint16m1_t, vint16m1_t, vint16m1_t, vint16m1_t, vint16m1_t, const int16_t *, vuint32m2_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vloxseg7ei32_v)))
void vloxseg7ei32(vint16mf2_t *, vint16mf2_t *, vint16mf2_t *, vint16mf2_t *, vint16mf2_t *, vint16mf2_t *, vint16mf2_t *, const int16_t *, vuint32m1_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vloxseg7ei32_v_m)))
void vloxseg7ei32(vint16mf2_t *, vint16mf2_t *, vint16mf2_t *, vint16mf2_t *, vint16mf2_t *, vint16mf2_t *, vint16mf2_t *, vbool32_t, vint16mf2_t, vint16mf2_t, vint16mf2_t, vint16mf2_t, vint16mf2_t, vint16mf2_t, vint16mf2_t, const int16_t *, vuint32m1_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vloxseg7ei32_v)))
void vloxseg7ei32(vint16mf4_t *, vint16mf4_t *, vint16mf4_t *, vint16mf4_t *, vint16mf4_t *, vint16mf4_t *, vint16mf4_t *, const int16_t *, vuint32mf2_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vloxseg7ei32_v_m)))
void vloxseg7ei32(vint16mf4_t *, vint16mf4_t *, vint16mf4_t *, vint16mf4_t *, vint16mf4_t *, vint16mf4_t *, vint16mf4_t *, vbool64_t, vint16mf4_t, vint16mf4_t, vint16mf4_t, vint16mf4_t, vint16mf4_t, vint16mf4_t, vint16mf4_t, const int16_t *, vuint32mf2_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vloxseg7ei32_v)))
void vloxseg7ei32(vuint16m1_t *, vuint16m1_t *, vuint16m1_t *, vuint16m1_t *, vuint16m1_t *, vuint16m1_t *, vuint16m1_t *, const uint16_t *, vuint32m2_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vloxseg7ei32_v_m)))
void vloxseg7ei32(vuint16m1_t *, vuint16m1_t *, vuint16m1_t *, vuint16m1_t *, vuint16m1_t *, vuint16m1_t *, vuint16m1_t *, vbool16_t, vuint16m1_t, vuint16m1_t, vuint16m1_t, vuint16m1_t, vuint16m1_t, vuint16m1_t, vuint16m1_t, const uint16_t *, vuint32m2_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vloxseg7ei32_v)))
void vloxseg7ei32(vuint16mf2_t *, vuint16mf2_t *, vuint16mf2_t *, vuint16mf2_t *, vuint16mf2_t *, vuint16mf2_t *, vuint16mf2_t *, const uint16_t *, vuint32m1_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vloxseg7ei32_v_m)))
void vloxseg7ei32(vuint16mf2_t *, vuint16mf2_t *, vuint16mf2_t *, vuint16mf2_t *, vuint16mf2_t *, vuint16mf2_t *, vuint16mf2_t *, vbool32_t, vuint16mf2_t, vuint16mf2_t, vuint16mf2_t, vuint16mf2_t, vuint16mf2_t, vuint16mf2_t, vuint16mf2_t, const uint16_t *, vuint32m1_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vloxseg7ei32_v)))
void vloxseg7ei32(vuint16mf4_t *, vuint16mf4_t *, vuint16mf4_t *, vuint16mf4_t *, vuint16mf4_t *, vuint16mf4_t *, vuint16mf4_t *, const uint16_t *, vuint32mf2_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vloxseg7ei32_v_m)))
void vloxseg7ei32(vuint16mf4_t *, vuint16mf4_t *, vuint16mf4_t *, vuint16mf4_t *, vuint16mf4_t *, vuint16mf4_t *, vuint16mf4_t *, vbool64_t, vuint16mf4_t, vuint16mf4_t, vuint16mf4_t, vuint16mf4_t, vuint16mf4_t, vuint16mf4_t, vuint16mf4_t, const uint16_t *, vuint32mf2_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vloxseg8ei32_v)))
void vloxseg8ei32(vint16m1_t *, vint16m1_t *, vint16m1_t *, vint16m1_t *, vint16m1_t *, vint16m1_t *, vint16m1_t *, vint16m1_t *, const int16_t *, vuint32m2_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vloxseg8ei32_v_m)))
void vloxseg8ei32(vint16m1_t *, vint16m1_t *, vint16m1_t *, vint16m1_t *, vint16m1_t *, vint16m1_t *, vint16m1_t *, vint16m1_t *, vbool16_t, vint16m1_t, vint16m1_t, vint16m1_t, vint16m1_t, vint16m1_t, vint16m1_t, vint16m1_t, vint16m1_t, const int16_t *, vuint32m2_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vloxseg8ei32_v)))
void vloxseg8ei32(vint16mf2_t *, vint16mf2_t *, vint16mf2_t *, vint16mf2_t *, vint16mf2_t *, vint16mf2_t *, vint16mf2_t *, vint16mf2_t *, const int16_t *, vuint32m1_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vloxseg8ei32_v_m)))
void vloxseg8ei32(vint16mf2_t *, vint16mf2_t *, vint16mf2_t *, vint16mf2_t *, vint16mf2_t *, vint16mf2_t *, vint16mf2_t *, vint16mf2_t *, vbool32_t, vint16mf2_t, vint16mf2_t, vint16mf2_t, vint16mf2_t, vint16mf2_t, vint16mf2_t, vint16mf2_t, vint16mf2_t, const int16_t *, vuint32m1_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vloxseg8ei32_v)))
void vloxseg8ei32(vint16mf4_t *, vint16mf4_t *, vint16mf4_t *, vint16mf4_t *, vint16mf4_t *, vint16mf4_t *, vint16mf4_t *, vint16mf4_t *, const int16_t *, vuint32mf2_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vloxseg8ei32_v_m)))
void vloxseg8ei32(vint16mf4_t *, vint16mf4_t *, vint16mf4_t *, vint16mf4_t *, vint16mf4_t *, vint16mf4_t *, vint16mf4_t *, vint16mf4_t *, vbool64_t, vint16mf4_t, vint16mf4_t, vint16mf4_t, vint16mf4_t, vint16mf4_t, vint16mf4_t, vint16mf4_t, vint16mf4_t, const int16_t *, vuint32mf2_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vloxseg8ei32_v)))
void vloxseg8ei32(vuint16m1_t *, vuint16m1_t *, vuint16m1_t *, vuint16m1_t *, vuint16m1_t *, vuint16m1_t *, vuint16m1_t *, vuint16m1_t *, const uint16_t *, vuint32m2_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vloxseg8ei32_v_m)))
void vloxseg8ei32(vuint16m1_t *, vuint16m1_t *, vuint16m1_t *, vuint16m1_t *, vuint16m1_t *, vuint16m1_t *, vuint16m1_t *, vuint16m1_t *, vbool16_t, vuint16m1_t, vuint16m1_t, vuint16m1_t, vuint16m1_t, vuint16m1_t, vuint16m1_t, vuint16m1_t, vuint16m1_t, const uint16_t *, vuint32m2_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vloxseg8ei32_v)))
void vloxseg8ei32(vuint16mf2_t *, vuint16mf2_t *, vuint16mf2_t *, vuint16mf2_t *, vuint16mf2_t *, vuint16mf2_t *, vuint16mf2_t *, vuint16mf2_t *, const uint16_t *, vuint32m1_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vloxseg8ei32_v_m)))
void vloxseg8ei32(vuint16mf2_t *, vuint16mf2_t *, vuint16mf2_t *, vuint16mf2_t *, vuint16mf2_t *, vuint16mf2_t *, vuint16mf2_t *, vuint16mf2_t *, vbool32_t, vuint16mf2_t, vuint16mf2_t, vuint16mf2_t, vuint16mf2_t, vuint16mf2_t, vuint16mf2_t, vuint16mf2_t, vuint16mf2_t, const uint16_t *, vuint32m1_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vloxseg8ei32_v)))
void vloxseg8ei32(vuint16mf4_t *, vuint16mf4_t *, vuint16mf4_t *, vuint16mf4_t *, vuint16mf4_t *, vuint16mf4_t *, vuint16mf4_t *, vuint16mf4_t *, const uint16_t *, vuint32mf2_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vloxseg8ei32_v_m)))
void vloxseg8ei32(vuint16mf4_t *, vuint16mf4_t *, vuint16mf4_t *, vuint16mf4_t *, vuint16mf4_t *, vuint16mf4_t *, vuint16mf4_t *, vuint16mf4_t *, vbool64_t, vuint16mf4_t, vuint16mf4_t, vuint16mf4_t, vuint16mf4_t, vuint16mf4_t, vuint16mf4_t, vuint16mf4_t, vuint16mf4_t, const uint16_t *, vuint32mf2_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vloxseg2ei8_v)))
void vloxseg2ei8(vint32m1_t *, vint32m1_t *, const int32_t *, vuint8mf4_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vloxseg2ei8_v_m)))
void vloxseg2ei8(vint32m1_t *, vint32m1_t *, vbool32_t, vint32m1_t, vint32m1_t, const int32_t *, vuint8mf4_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vloxseg2ei8_v)))
void vloxseg2ei8(vint32m2_t *, vint32m2_t *, const int32_t *, vuint8mf2_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vloxseg2ei8_v_m)))
void vloxseg2ei8(vint32m2_t *, vint32m2_t *, vbool16_t, vint32m2_t, vint32m2_t, const int32_t *, vuint8mf2_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vloxseg2ei8_v)))
void vloxseg2ei8(vint32m4_t *, vint32m4_t *, const int32_t *, vuint8m1_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vloxseg2ei8_v_m)))
void vloxseg2ei8(vint32m4_t *, vint32m4_t *, vbool8_t, vint32m4_t, vint32m4_t, const int32_t *, vuint8m1_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vloxseg2ei8_v)))
void vloxseg2ei8(vint32mf2_t *, vint32mf2_t *, const int32_t *, vuint8mf8_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vloxseg2ei8_v_m)))
void vloxseg2ei8(vint32mf2_t *, vint32mf2_t *, vbool64_t, vint32mf2_t, vint32mf2_t, const int32_t *, vuint8mf8_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vloxseg2ei8_v)))
void vloxseg2ei8(vuint32m1_t *, vuint32m1_t *, const uint32_t *, vuint8mf4_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vloxseg2ei8_v_m)))
void vloxseg2ei8(vuint32m1_t *, vuint32m1_t *, vbool32_t, vuint32m1_t, vuint32m1_t, const uint32_t *, vuint8mf4_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vloxseg2ei8_v)))
void vloxseg2ei8(vuint32m2_t *, vuint32m2_t *, const uint32_t *, vuint8mf2_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vloxseg2ei8_v_m)))
void vloxseg2ei8(vuint32m2_t *, vuint32m2_t *, vbool16_t, vuint32m2_t, vuint32m2_t, const uint32_t *, vuint8mf2_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vloxseg2ei8_v)))
void vloxseg2ei8(vuint32m4_t *, vuint32m4_t *, const uint32_t *, vuint8m1_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vloxseg2ei8_v_m)))
void vloxseg2ei8(vuint32m4_t *, vuint32m4_t *, vbool8_t, vuint32m4_t, vuint32m4_t, const uint32_t *, vuint8m1_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vloxseg2ei8_v)))
void vloxseg2ei8(vuint32mf2_t *, vuint32mf2_t *, const uint32_t *, vuint8mf8_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vloxseg2ei8_v_m)))
void vloxseg2ei8(vuint32mf2_t *, vuint32mf2_t *, vbool64_t, vuint32mf2_t, vuint32mf2_t, const uint32_t *, vuint8mf8_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vloxseg3ei8_v)))
void vloxseg3ei8(vint32m1_t *, vint32m1_t *, vint32m1_t *, const int32_t *, vuint8mf4_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vloxseg3ei8_v_m)))
void vloxseg3ei8(vint32m1_t *, vint32m1_t *, vint32m1_t *, vbool32_t, vint32m1_t, vint32m1_t, vint32m1_t, const int32_t *, vuint8mf4_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vloxseg3ei8_v)))
void vloxseg3ei8(vint32m2_t *, vint32m2_t *, vint32m2_t *, const int32_t *, vuint8mf2_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vloxseg3ei8_v_m)))
void vloxseg3ei8(vint32m2_t *, vint32m2_t *, vint32m2_t *, vbool16_t, vint32m2_t, vint32m2_t, vint32m2_t, const int32_t *, vuint8mf2_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vloxseg3ei8_v)))
void vloxseg3ei8(vint32mf2_t *, vint32mf2_t *, vint32mf2_t *, const int32_t *, vuint8mf8_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vloxseg3ei8_v_m)))
void vloxseg3ei8(vint32mf2_t *, vint32mf2_t *, vint32mf2_t *, vbool64_t, vint32mf2_t, vint32mf2_t, vint32mf2_t, const int32_t *, vuint8mf8_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vloxseg3ei8_v)))
void vloxseg3ei8(vuint32m1_t *, vuint32m1_t *, vuint32m1_t *, const uint32_t *, vuint8mf4_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vloxseg3ei8_v_m)))
void vloxseg3ei8(vuint32m1_t *, vuint32m1_t *, vuint32m1_t *, vbool32_t, vuint32m1_t, vuint32m1_t, vuint32m1_t, const uint32_t *, vuint8mf4_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vloxseg3ei8_v)))
void vloxseg3ei8(vuint32m2_t *, vuint32m2_t *, vuint32m2_t *, const uint32_t *, vuint8mf2_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vloxseg3ei8_v_m)))
void vloxseg3ei8(vuint32m2_t *, vuint32m2_t *, vuint32m2_t *, vbool16_t, vuint32m2_t, vuint32m2_t, vuint32m2_t, const uint32_t *, vuint8mf2_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vloxseg3ei8_v)))
void vloxseg3ei8(vuint32mf2_t *, vuint32mf2_t *, vuint32mf2_t *, const uint32_t *, vuint8mf8_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vloxseg3ei8_v_m)))
void vloxseg3ei8(vuint32mf2_t *, vuint32mf2_t *, vuint32mf2_t *, vbool64_t, vuint32mf2_t, vuint32mf2_t, vuint32mf2_t, const uint32_t *, vuint8mf8_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vloxseg4ei8_v)))
void vloxseg4ei8(vint32m1_t *, vint32m1_t *, vint32m1_t *, vint32m1_t *, const int32_t *, vuint8mf4_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vloxseg4ei8_v_m)))
void vloxseg4ei8(vint32m1_t *, vint32m1_t *, vint32m1_t *, vint32m1_t *, vbool32_t, vint32m1_t, vint32m1_t, vint32m1_t, vint32m1_t, const int32_t *, vuint8mf4_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vloxseg4ei8_v)))
void vloxseg4ei8(vint32m2_t *, vint32m2_t *, vint32m2_t *, vint32m2_t *, const int32_t *, vuint8mf2_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vloxseg4ei8_v_m)))
void vloxseg4ei8(vint32m2_t *, vint32m2_t *, vint32m2_t *, vint32m2_t *, vbool16_t, vint32m2_t, vint32m2_t, vint32m2_t, vint32m2_t, const int32_t *, vuint8mf2_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vloxseg4ei8_v)))
void vloxseg4ei8(vint32mf2_t *, vint32mf2_t *, vint32mf2_t *, vint32mf2_t *, const int32_t *, vuint8mf8_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vloxseg4ei8_v_m)))
void vloxseg4ei8(vint32mf2_t *, vint32mf2_t *, vint32mf2_t *, vint32mf2_t *, vbool64_t, vint32mf2_t, vint32mf2_t, vint32mf2_t, vint32mf2_t, const int32_t *, vuint8mf8_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vloxseg4ei8_v)))
void vloxseg4ei8(vuint32m1_t *, vuint32m1_t *, vuint32m1_t *, vuint32m1_t *, const uint32_t *, vuint8mf4_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vloxseg4ei8_v_m)))
void vloxseg4ei8(vuint32m1_t *, vuint32m1_t *, vuint32m1_t *, vuint32m1_t *, vbool32_t, vuint32m1_t, vuint32m1_t, vuint32m1_t, vuint32m1_t, const uint32_t *, vuint8mf4_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vloxseg4ei8_v)))
void vloxseg4ei8(vuint32m2_t *, vuint32m2_t *, vuint32m2_t *, vuint32m2_t *, const uint32_t *, vuint8mf2_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vloxseg4ei8_v_m)))
void vloxseg4ei8(vuint32m2_t *, vuint32m2_t *, vuint32m2_t *, vuint32m2_t *, vbool16_t, vuint32m2_t, vuint32m2_t, vuint32m2_t, vuint32m2_t, const uint32_t *, vuint8mf2_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vloxseg4ei8_v)))
void vloxseg4ei8(vuint32mf2_t *, vuint32mf2_t *, vuint32mf2_t *, vuint32mf2_t *, const uint32_t *, vuint8mf8_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vloxseg4ei8_v_m)))
void vloxseg4ei8(vuint32mf2_t *, vuint32mf2_t *, vuint32mf2_t *, vuint32mf2_t *, vbool64_t, vuint32mf2_t, vuint32mf2_t, vuint32mf2_t, vuint32mf2_t, const uint32_t *, vuint8mf8_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vloxseg5ei8_v)))
void vloxseg5ei8(vint32m1_t *, vint32m1_t *, vint32m1_t *, vint32m1_t *, vint32m1_t *, const int32_t *, vuint8mf4_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vloxseg5ei8_v_m)))
void vloxseg5ei8(vint32m1_t *, vint32m1_t *, vint32m1_t *, vint32m1_t *, vint32m1_t *, vbool32_t, vint32m1_t, vint32m1_t, vint32m1_t, vint32m1_t, vint32m1_t, const int32_t *, vuint8mf4_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vloxseg5ei8_v)))
void vloxseg5ei8(vint32mf2_t *, vint32mf2_t *, vint32mf2_t *, vint32mf2_t *, vint32mf2_t *, const int32_t *, vuint8mf8_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vloxseg5ei8_v_m)))
void vloxseg5ei8(vint32mf2_t *, vint32mf2_t *, vint32mf2_t *, vint32mf2_t *, vint32mf2_t *, vbool64_t, vint32mf2_t, vint32mf2_t, vint32mf2_t, vint32mf2_t, vint32mf2_t, const int32_t *, vuint8mf8_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vloxseg5ei8_v)))
void vloxseg5ei8(vuint32m1_t *, vuint32m1_t *, vuint32m1_t *, vuint32m1_t *, vuint32m1_t *, const uint32_t *, vuint8mf4_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vloxseg5ei8_v_m)))
void vloxseg5ei8(vuint32m1_t *, vuint32m1_t *, vuint32m1_t *, vuint32m1_t *, vuint32m1_t *, vbool32_t, vuint32m1_t, vuint32m1_t, vuint32m1_t, vuint32m1_t, vuint32m1_t, const uint32_t *, vuint8mf4_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vloxseg5ei8_v)))
void vloxseg5ei8(vuint32mf2_t *, vuint32mf2_t *, vuint32mf2_t *, vuint32mf2_t *, vuint32mf2_t *, const uint32_t *, vuint8mf8_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vloxseg5ei8_v_m)))
void vloxseg5ei8(vuint32mf2_t *, vuint32mf2_t *, vuint32mf2_t *, vuint32mf2_t *, vuint32mf2_t *, vbool64_t, vuint32mf2_t, vuint32mf2_t, vuint32mf2_t, vuint32mf2_t, vuint32mf2_t, const uint32_t *, vuint8mf8_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vlse16_v_m)))
vint16m1_t vlse16(vbool16_t, vint16m1_t, const int16_t *, ptrdiff_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vlse16_v_m)))
vint16m2_t vlse16(vbool8_t, vint16m2_t, const int16_t *, ptrdiff_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vlse16_v_m)))
vint16m4_t vlse16(vbool4_t, vint16m4_t, const int16_t *, ptrdiff_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vlse16_v_m)))
vint16m8_t vlse16(vbool2_t, vint16m8_t, const int16_t *, ptrdiff_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vlse16_v_m)))
vint16mf2_t vlse16(vbool32_t, vint16mf2_t, const int16_t *, ptrdiff_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vlse16_v_m)))
vint16mf4_t vlse16(vbool64_t, vint16mf4_t, const int16_t *, ptrdiff_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vloxseg6ei8_v)))
void vloxseg6ei8(vint32m1_t *, vint32m1_t *, vint32m1_t *, vint32m1_t *, vint32m1_t *, vint32m1_t *, const int32_t *, vuint8mf4_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vloxseg6ei8_v_m)))
void vloxseg6ei8(vint32m1_t *, vint32m1_t *, vint32m1_t *, vint32m1_t *, vint32m1_t *, vint32m1_t *, vbool32_t, vint32m1_t, vint32m1_t, vint32m1_t, vint32m1_t, vint32m1_t, vint32m1_t, const int32_t *, vuint8mf4_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vloxseg6ei8_v)))
void vloxseg6ei8(vint32mf2_t *, vint32mf2_t *, vint32mf2_t *, vint32mf2_t *, vint32mf2_t *, vint32mf2_t *, const int32_t *, vuint8mf8_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vloxseg6ei8_v_m)))
void vloxseg6ei8(vint32mf2_t *, vint32mf2_t *, vint32mf2_t *, vint32mf2_t *, vint32mf2_t *, vint32mf2_t *, vbool64_t, vint32mf2_t, vint32mf2_t, vint32mf2_t, vint32mf2_t, vint32mf2_t, vint32mf2_t, const int32_t *, vuint8mf8_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vloxseg6ei8_v)))
void vloxseg6ei8(vuint32m1_t *, vuint32m1_t *, vuint32m1_t *, vuint32m1_t *, vuint32m1_t *, vuint32m1_t *, const uint32_t *, vuint8mf4_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vloxseg6ei8_v_m)))
void vloxseg6ei8(vuint32m1_t *, vuint32m1_t *, vuint32m1_t *, vuint32m1_t *, vuint32m1_t *, vuint32m1_t *, vbool32_t, vuint32m1_t, vuint32m1_t, vuint32m1_t, vuint32m1_t, vuint32m1_t, vuint32m1_t, const uint32_t *, vuint8mf4_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vloxseg6ei8_v)))
void vloxseg6ei8(vuint32mf2_t *, vuint32mf2_t *, vuint32mf2_t *, vuint32mf2_t *, vuint32mf2_t *, vuint32mf2_t *, const uint32_t *, vuint8mf8_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vloxseg6ei8_v_m)))
void vloxseg6ei8(vuint32mf2_t *, vuint32mf2_t *, vuint32mf2_t *, vuint32mf2_t *, vuint32mf2_t *, vuint32mf2_t *, vbool64_t, vuint32mf2_t, vuint32mf2_t, vuint32mf2_t, vuint32mf2_t, vuint32mf2_t, vuint32mf2_t, const uint32_t *, vuint8mf8_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vloxseg7ei8_v)))
void vloxseg7ei8(vint32m1_t *, vint32m1_t *, vint32m1_t *, vint32m1_t *, vint32m1_t *, vint32m1_t *, vint32m1_t *, const int32_t *, vuint8mf4_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vloxseg7ei8_v_m)))
void vloxseg7ei8(vint32m1_t *, vint32m1_t *, vint32m1_t *, vint32m1_t *, vint32m1_t *, vint32m1_t *, vint32m1_t *, vbool32_t, vint32m1_t, vint32m1_t, vint32m1_t, vint32m1_t, vint32m1_t, vint32m1_t, vint32m1_t, const int32_t *, vuint8mf4_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vloxseg7ei8_v)))
void vloxseg7ei8(vint32mf2_t *, vint32mf2_t *, vint32mf2_t *, vint32mf2_t *, vint32mf2_t *, vint32mf2_t *, vint32mf2_t *, const int32_t *, vuint8mf8_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vloxseg7ei8_v_m)))
void vloxseg7ei8(vint32mf2_t *, vint32mf2_t *, vint32mf2_t *, vint32mf2_t *, vint32mf2_t *, vint32mf2_t *, vint32mf2_t *, vbool64_t, vint32mf2_t, vint32mf2_t, vint32mf2_t, vint32mf2_t, vint32mf2_t, vint32mf2_t, vint32mf2_t, const int32_t *, vuint8mf8_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vloxseg7ei8_v)))
void vloxseg7ei8(vuint32m1_t *, vuint32m1_t *, vuint32m1_t *, vuint32m1_t *, vuint32m1_t *, vuint32m1_t *, vuint32m1_t *, const uint32_t *, vuint8mf4_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vloxseg7ei8_v_m)))
void vloxseg7ei8(vuint32m1_t *, vuint32m1_t *, vuint32m1_t *, vuint32m1_t *, vuint32m1_t *, vuint32m1_t *, vuint32m1_t *, vbool32_t, vuint32m1_t, vuint32m1_t, vuint32m1_t, vuint32m1_t, vuint32m1_t, vuint32m1_t, vuint32m1_t, const uint32_t *, vuint8mf4_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vloxseg7ei8_v)))
void vloxseg7ei8(vuint32mf2_t *, vuint32mf2_t *, vuint32mf2_t *, vuint32mf2_t *, vuint32mf2_t *, vuint32mf2_t *, vuint32mf2_t *, const uint32_t *, vuint8mf8_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vloxseg7ei8_v_m)))
void vloxseg7ei8(vuint32mf2_t *, vuint32mf2_t *, vuint32mf2_t *, vuint32mf2_t *, vuint32mf2_t *, vuint32mf2_t *, vuint32mf2_t *, vbool64_t, vuint32mf2_t, vuint32mf2_t, vuint32mf2_t, vuint32mf2_t, vuint32mf2_t, vuint32mf2_t, vuint32mf2_t, const uint32_t *, vuint8mf8_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vloxseg8ei8_v)))
void vloxseg8ei8(vint32m1_t *, vint32m1_t *, vint32m1_t *, vint32m1_t *, vint32m1_t *, vint32m1_t *, vint32m1_t *, vint32m1_t *, const int32_t *, vuint8mf4_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vloxseg8ei8_v_m)))
void vloxseg8ei8(vint32m1_t *, vint32m1_t *, vint32m1_t *, vint32m1_t *, vint32m1_t *, vint32m1_t *, vint32m1_t *, vint32m1_t *, vbool32_t, vint32m1_t, vint32m1_t, vint32m1_t, vint32m1_t, vint32m1_t, vint32m1_t, vint32m1_t, vint32m1_t, const int32_t *, vuint8mf4_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vloxseg8ei8_v)))
void vloxseg8ei8(vint32mf2_t *, vint32mf2_t *, vint32mf2_t *, vint32mf2_t *, vint32mf2_t *, vint32mf2_t *, vint32mf2_t *, vint32mf2_t *, const int32_t *, vuint8mf8_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vloxseg8ei8_v_m)))
void vloxseg8ei8(vint32mf2_t *, vint32mf2_t *, vint32mf2_t *, vint32mf2_t *, vint32mf2_t *, vint32mf2_t *, vint32mf2_t *, vint32mf2_t *, vbool64_t, vint32mf2_t, vint32mf2_t, vint32mf2_t, vint32mf2_t, vint32mf2_t, vint32mf2_t, vint32mf2_t, vint32mf2_t, const int32_t *, vuint8mf8_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vloxseg8ei8_v)))
void vloxseg8ei8(vuint32m1_t *, vuint32m1_t *, vuint32m1_t *, vuint32m1_t *, vuint32m1_t *, vuint32m1_t *, vuint32m1_t *, vuint32m1_t *, const uint32_t *, vuint8mf4_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vloxseg8ei8_v_m)))
void vloxseg8ei8(vuint32m1_t *, vuint32m1_t *, vuint32m1_t *, vuint32m1_t *, vuint32m1_t *, vuint32m1_t *, vuint32m1_t *, vuint32m1_t *, vbool32_t, vuint32m1_t, vuint32m1_t, vuint32m1_t, vuint32m1_t, vuint32m1_t, vuint32m1_t, vuint32m1_t, vuint32m1_t, const uint32_t *, vuint8mf4_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vloxseg8ei8_v)))
void vloxseg8ei8(vuint32mf2_t *, vuint32mf2_t *, vuint32mf2_t *, vuint32mf2_t *, vuint32mf2_t *, vuint32mf2_t *, vuint32mf2_t *, vuint32mf2_t *, const uint32_t *, vuint8mf8_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vloxseg8ei8_v_m)))
void vloxseg8ei8(vuint32mf2_t *, vuint32mf2_t *, vuint32mf2_t *, vuint32mf2_t *, vuint32mf2_t *, vuint32mf2_t *, vuint32mf2_t *, vuint32mf2_t *, vbool64_t, vuint32mf2_t, vuint32mf2_t, vuint32mf2_t, vuint32mf2_t, vuint32mf2_t, vuint32mf2_t, vuint32mf2_t, vuint32mf2_t, const uint32_t *, vuint8mf8_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vloxseg2ei16_v)))
void vloxseg2ei16(vint32m1_t *, vint32m1_t *, const int32_t *, vuint16mf2_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vloxseg2ei16_v_m)))
void vloxseg2ei16(vint32m1_t *, vint32m1_t *, vbool32_t, vint32m1_t, vint32m1_t, const int32_t *, vuint16mf2_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vloxseg2ei16_v)))
void vloxseg2ei16(vint32m2_t *, vint32m2_t *, const int32_t *, vuint16m1_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vloxseg2ei16_v_m)))
void vloxseg2ei16(vint32m2_t *, vint32m2_t *, vbool16_t, vint32m2_t, vint32m2_t, const int32_t *, vuint16m1_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vloxseg2ei16_v)))
void vloxseg2ei16(vint32m4_t *, vint32m4_t *, const int32_t *, vuint16m2_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vloxseg2ei16_v_m)))
void vloxseg2ei16(vint32m4_t *, vint32m4_t *, vbool8_t, vint32m4_t, vint32m4_t, const int32_t *, vuint16m2_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vloxseg2ei16_v)))
void vloxseg2ei16(vint32mf2_t *, vint32mf2_t *, const int32_t *, vuint16mf4_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vloxseg2ei16_v_m)))
void vloxseg2ei16(vint32mf2_t *, vint32mf2_t *, vbool64_t, vint32mf2_t, vint32mf2_t, const int32_t *, vuint16mf4_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vloxseg2ei16_v)))
void vloxseg2ei16(vuint32m1_t *, vuint32m1_t *, const uint32_t *, vuint16mf2_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vloxseg2ei16_v_m)))
void vloxseg2ei16(vuint32m1_t *, vuint32m1_t *, vbool32_t, vuint32m1_t, vuint32m1_t, const uint32_t *, vuint16mf2_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vloxseg2ei16_v)))
void vloxseg2ei16(vuint32m2_t *, vuint32m2_t *, const uint32_t *, vuint16m1_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vloxseg2ei16_v_m)))
void vloxseg2ei16(vuint32m2_t *, vuint32m2_t *, vbool16_t, vuint32m2_t, vuint32m2_t, const uint32_t *, vuint16m1_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vloxseg2ei16_v)))
void vloxseg2ei16(vuint32m4_t *, vuint32m4_t *, const uint32_t *, vuint16m2_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vloxseg2ei16_v_m)))
void vloxseg2ei16(vuint32m4_t *, vuint32m4_t *, vbool8_t, vuint32m4_t, vuint32m4_t, const uint32_t *, vuint16m2_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vloxseg2ei16_v)))
void vloxseg2ei16(vuint32mf2_t *, vuint32mf2_t *, const uint32_t *, vuint16mf4_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vloxseg2ei16_v_m)))
void vloxseg2ei16(vuint32mf2_t *, vuint32mf2_t *, vbool64_t, vuint32mf2_t, vuint32mf2_t, const uint32_t *, vuint16mf4_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vloxseg3ei16_v)))
void vloxseg3ei16(vint32m1_t *, vint32m1_t *, vint32m1_t *, const int32_t *, vuint16mf2_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vloxseg3ei16_v_m)))
void vloxseg3ei16(vint32m1_t *, vint32m1_t *, vint32m1_t *, vbool32_t, vint32m1_t, vint32m1_t, vint32m1_t, const int32_t *, vuint16mf2_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vloxseg3ei16_v)))
void vloxseg3ei16(vint32m2_t *, vint32m2_t *, vint32m2_t *, const int32_t *, vuint16m1_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vloxseg3ei16_v_m)))
void vloxseg3ei16(vint32m2_t *, vint32m2_t *, vint32m2_t *, vbool16_t, vint32m2_t, vint32m2_t, vint32m2_t, const int32_t *, vuint16m1_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vloxseg3ei16_v)))
void vloxseg3ei16(vint32mf2_t *, vint32mf2_t *, vint32mf2_t *, const int32_t *, vuint16mf4_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vloxseg3ei16_v_m)))
void vloxseg3ei16(vint32mf2_t *, vint32mf2_t *, vint32mf2_t *, vbool64_t, vint32mf2_t, vint32mf2_t, vint32mf2_t, const int32_t *, vuint16mf4_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vloxseg3ei16_v)))
void vloxseg3ei16(vuint32m1_t *, vuint32m1_t *, vuint32m1_t *, const uint32_t *, vuint16mf2_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vloxseg3ei16_v_m)))
void vloxseg3ei16(vuint32m1_t *, vuint32m1_t *, vuint32m1_t *, vbool32_t, vuint32m1_t, vuint32m1_t, vuint32m1_t, const uint32_t *, vuint16mf2_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vloxseg3ei16_v)))
void vloxseg3ei16(vuint32m2_t *, vuint32m2_t *, vuint32m2_t *, const uint32_t *, vuint16m1_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vloxseg3ei16_v_m)))
void vloxseg3ei16(vuint32m2_t *, vuint32m2_t *, vuint32m2_t *, vbool16_t, vuint32m2_t, vuint32m2_t, vuint32m2_t, const uint32_t *, vuint16m1_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vloxseg3ei16_v)))
void vloxseg3ei16(vuint32mf2_t *, vuint32mf2_t *, vuint32mf2_t *, const uint32_t *, vuint16mf4_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vloxseg3ei16_v_m)))
void vloxseg3ei16(vuint32mf2_t *, vuint32mf2_t *, vuint32mf2_t *, vbool64_t, vuint32mf2_t, vuint32mf2_t, vuint32mf2_t, const uint32_t *, vuint16mf4_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vlse16_v_m)))
vuint16m1_t vlse16(vbool16_t, vuint16m1_t, const uint16_t *, ptrdiff_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vlse16_v_m)))
vuint16m2_t vlse16(vbool8_t, vuint16m2_t, const uint16_t *, ptrdiff_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vlse16_v_m)))
vuint16m4_t vlse16(vbool4_t, vuint16m4_t, const uint16_t *, ptrdiff_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vlse16_v_m)))
vuint16m8_t vlse16(vbool2_t, vuint16m8_t, const uint16_t *, ptrdiff_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vlse16_v_m)))
vuint16mf2_t vlse16(vbool32_t, vuint16mf2_t, const uint16_t *, ptrdiff_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vlse16_v_m)))
vuint16mf4_t vlse16(vbool64_t, vuint16mf4_t, const uint16_t *, ptrdiff_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vloxseg4ei16_v)))
void vloxseg4ei16(vint32m1_t *, vint32m1_t *, vint32m1_t *, vint32m1_t *, const int32_t *, vuint16mf2_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vloxseg4ei16_v_m)))
void vloxseg4ei16(vint32m1_t *, vint32m1_t *, vint32m1_t *, vint32m1_t *, vbool32_t, vint32m1_t, vint32m1_t, vint32m1_t, vint32m1_t, const int32_t *, vuint16mf2_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vloxseg4ei16_v)))
void vloxseg4ei16(vint32m2_t *, vint32m2_t *, vint32m2_t *, vint32m2_t *, const int32_t *, vuint16m1_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vloxseg4ei16_v_m)))
void vloxseg4ei16(vint32m2_t *, vint32m2_t *, vint32m2_t *, vint32m2_t *, vbool16_t, vint32m2_t, vint32m2_t, vint32m2_t, vint32m2_t, const int32_t *, vuint16m1_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vloxseg4ei16_v)))
void vloxseg4ei16(vint32mf2_t *, vint32mf2_t *, vint32mf2_t *, vint32mf2_t *, const int32_t *, vuint16mf4_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vloxseg4ei16_v_m)))
void vloxseg4ei16(vint32mf2_t *, vint32mf2_t *, vint32mf2_t *, vint32mf2_t *, vbool64_t, vint32mf2_t, vint32mf2_t, vint32mf2_t, vint32mf2_t, const int32_t *, vuint16mf4_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vloxseg4ei16_v)))
void vloxseg4ei16(vuint32m1_t *, vuint32m1_t *, vuint32m1_t *, vuint32m1_t *, const uint32_t *, vuint16mf2_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vloxseg4ei16_v_m)))
void vloxseg4ei16(vuint32m1_t *, vuint32m1_t *, vuint32m1_t *, vuint32m1_t *, vbool32_t, vuint32m1_t, vuint32m1_t, vuint32m1_t, vuint32m1_t, const uint32_t *, vuint16mf2_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vloxseg4ei16_v)))
void vloxseg4ei16(vuint32m2_t *, vuint32m2_t *, vuint32m2_t *, vuint32m2_t *, const uint32_t *, vuint16m1_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vloxseg4ei16_v_m)))
void vloxseg4ei16(vuint32m2_t *, vuint32m2_t *, vuint32m2_t *, vuint32m2_t *, vbool16_t, vuint32m2_t, vuint32m2_t, vuint32m2_t, vuint32m2_t, const uint32_t *, vuint16m1_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vloxseg4ei16_v)))
void vloxseg4ei16(vuint32mf2_t *, vuint32mf2_t *, vuint32mf2_t *, vuint32mf2_t *, const uint32_t *, vuint16mf4_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vloxseg4ei16_v_m)))
void vloxseg4ei16(vuint32mf2_t *, vuint32mf2_t *, vuint32mf2_t *, vuint32mf2_t *, vbool64_t, vuint32mf2_t, vuint32mf2_t, vuint32mf2_t, vuint32mf2_t, const uint32_t *, vuint16mf4_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vloxseg5ei16_v)))
void vloxseg5ei16(vint32m1_t *, vint32m1_t *, vint32m1_t *, vint32m1_t *, vint32m1_t *, const int32_t *, vuint16mf2_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vloxseg5ei16_v_m)))
void vloxseg5ei16(vint32m1_t *, vint32m1_t *, vint32m1_t *, vint32m1_t *, vint32m1_t *, vbool32_t, vint32m1_t, vint32m1_t, vint32m1_t, vint32m1_t, vint32m1_t, const int32_t *, vuint16mf2_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vloxseg5ei16_v)))
void vloxseg5ei16(vint32mf2_t *, vint32mf2_t *, vint32mf2_t *, vint32mf2_t *, vint32mf2_t *, const int32_t *, vuint16mf4_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vloxseg5ei16_v_m)))
void vloxseg5ei16(vint32mf2_t *, vint32mf2_t *, vint32mf2_t *, vint32mf2_t *, vint32mf2_t *, vbool64_t, vint32mf2_t, vint32mf2_t, vint32mf2_t, vint32mf2_t, vint32mf2_t, const int32_t *, vuint16mf4_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vloxseg5ei16_v)))
void vloxseg5ei16(vuint32m1_t *, vuint32m1_t *, vuint32m1_t *, vuint32m1_t *, vuint32m1_t *, const uint32_t *, vuint16mf2_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vloxseg5ei16_v_m)))
void vloxseg5ei16(vuint32m1_t *, vuint32m1_t *, vuint32m1_t *, vuint32m1_t *, vuint32m1_t *, vbool32_t, vuint32m1_t, vuint32m1_t, vuint32m1_t, vuint32m1_t, vuint32m1_t, const uint32_t *, vuint16mf2_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vloxseg5ei16_v)))
void vloxseg5ei16(vuint32mf2_t *, vuint32mf2_t *, vuint32mf2_t *, vuint32mf2_t *, vuint32mf2_t *, const uint32_t *, vuint16mf4_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vloxseg5ei16_v_m)))
void vloxseg5ei16(vuint32mf2_t *, vuint32mf2_t *, vuint32mf2_t *, vuint32mf2_t *, vuint32mf2_t *, vbool64_t, vuint32mf2_t, vuint32mf2_t, vuint32mf2_t, vuint32mf2_t, vuint32mf2_t, const uint32_t *, vuint16mf4_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vloxseg6ei16_v)))
void vloxseg6ei16(vint32m1_t *, vint32m1_t *, vint32m1_t *, vint32m1_t *, vint32m1_t *, vint32m1_t *, const int32_t *, vuint16mf2_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vloxseg6ei16_v_m)))
void vloxseg6ei16(vint32m1_t *, vint32m1_t *, vint32m1_t *, vint32m1_t *, vint32m1_t *, vint32m1_t *, vbool32_t, vint32m1_t, vint32m1_t, vint32m1_t, vint32m1_t, vint32m1_t, vint32m1_t, const int32_t *, vuint16mf2_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vloxseg6ei16_v)))
void vloxseg6ei16(vint32mf2_t *, vint32mf2_t *, vint32mf2_t *, vint32mf2_t *, vint32mf2_t *, vint32mf2_t *, const int32_t *, vuint16mf4_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vloxseg6ei16_v_m)))
void vloxseg6ei16(vint32mf2_t *, vint32mf2_t *, vint32mf2_t *, vint32mf2_t *, vint32mf2_t *, vint32mf2_t *, vbool64_t, vint32mf2_t, vint32mf2_t, vint32mf2_t, vint32mf2_t, vint32mf2_t, vint32mf2_t, const int32_t *, vuint16mf4_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vloxseg6ei16_v)))
void vloxseg6ei16(vuint32m1_t *, vuint32m1_t *, vuint32m1_t *, vuint32m1_t *, vuint32m1_t *, vuint32m1_t *, const uint32_t *, vuint16mf2_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vloxseg6ei16_v_m)))
void vloxseg6ei16(vuint32m1_t *, vuint32m1_t *, vuint32m1_t *, vuint32m1_t *, vuint32m1_t *, vuint32m1_t *, vbool32_t, vuint32m1_t, vuint32m1_t, vuint32m1_t, vuint32m1_t, vuint32m1_t, vuint32m1_t, const uint32_t *, vuint16mf2_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vloxseg6ei16_v)))
void vloxseg6ei16(vuint32mf2_t *, vuint32mf2_t *, vuint32mf2_t *, vuint32mf2_t *, vuint32mf2_t *, vuint32mf2_t *, const uint32_t *, vuint16mf4_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vloxseg6ei16_v_m)))
void vloxseg6ei16(vuint32mf2_t *, vuint32mf2_t *, vuint32mf2_t *, vuint32mf2_t *, vuint32mf2_t *, vuint32mf2_t *, vbool64_t, vuint32mf2_t, vuint32mf2_t, vuint32mf2_t, vuint32mf2_t, vuint32mf2_t, vuint32mf2_t, const uint32_t *, vuint16mf4_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vloxseg7ei16_v)))
void vloxseg7ei16(vint32m1_t *, vint32m1_t *, vint32m1_t *, vint32m1_t *, vint32m1_t *, vint32m1_t *, vint32m1_t *, const int32_t *, vuint16mf2_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vloxseg7ei16_v_m)))
void vloxseg7ei16(vint32m1_t *, vint32m1_t *, vint32m1_t *, vint32m1_t *, vint32m1_t *, vint32m1_t *, vint32m1_t *, vbool32_t, vint32m1_t, vint32m1_t, vint32m1_t, vint32m1_t, vint32m1_t, vint32m1_t, vint32m1_t, const int32_t *, vuint16mf2_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vloxseg7ei16_v)))
void vloxseg7ei16(vint32mf2_t *, vint32mf2_t *, vint32mf2_t *, vint32mf2_t *, vint32mf2_t *, vint32mf2_t *, vint32mf2_t *, const int32_t *, vuint16mf4_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vloxseg7ei16_v_m)))
void vloxseg7ei16(vint32mf2_t *, vint32mf2_t *, vint32mf2_t *, vint32mf2_t *, vint32mf2_t *, vint32mf2_t *, vint32mf2_t *, vbool64_t, vint32mf2_t, vint32mf2_t, vint32mf2_t, vint32mf2_t, vint32mf2_t, vint32mf2_t, vint32mf2_t, const int32_t *, vuint16mf4_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vloxseg7ei16_v)))
void vloxseg7ei16(vuint32m1_t *, vuint32m1_t *, vuint32m1_t *, vuint32m1_t *, vuint32m1_t *, vuint32m1_t *, vuint32m1_t *, const uint32_t *, vuint16mf2_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vloxseg7ei16_v_m)))
void vloxseg7ei16(vuint32m1_t *, vuint32m1_t *, vuint32m1_t *, vuint32m1_t *, vuint32m1_t *, vuint32m1_t *, vuint32m1_t *, vbool32_t, vuint32m1_t, vuint32m1_t, vuint32m1_t, vuint32m1_t, vuint32m1_t, vuint32m1_t, vuint32m1_t, const uint32_t *, vuint16mf2_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vloxseg7ei16_v)))
void vloxseg7ei16(vuint32mf2_t *, vuint32mf2_t *, vuint32mf2_t *, vuint32mf2_t *, vuint32mf2_t *, vuint32mf2_t *, vuint32mf2_t *, const uint32_t *, vuint16mf4_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vloxseg7ei16_v_m)))
void vloxseg7ei16(vuint32mf2_t *, vuint32mf2_t *, vuint32mf2_t *, vuint32mf2_t *, vuint32mf2_t *, vuint32mf2_t *, vuint32mf2_t *, vbool64_t, vuint32mf2_t, vuint32mf2_t, vuint32mf2_t, vuint32mf2_t, vuint32mf2_t, vuint32mf2_t, vuint32mf2_t, const uint32_t *, vuint16mf4_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vloxseg8ei16_v)))
void vloxseg8ei16(vint32m1_t *, vint32m1_t *, vint32m1_t *, vint32m1_t *, vint32m1_t *, vint32m1_t *, vint32m1_t *, vint32m1_t *, const int32_t *, vuint16mf2_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vloxseg8ei16_v_m)))
void vloxseg8ei16(vint32m1_t *, vint32m1_t *, vint32m1_t *, vint32m1_t *, vint32m1_t *, vint32m1_t *, vint32m1_t *, vint32m1_t *, vbool32_t, vint32m1_t, vint32m1_t, vint32m1_t, vint32m1_t, vint32m1_t, vint32m1_t, vint32m1_t, vint32m1_t, const int32_t *, vuint16mf2_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vloxseg8ei16_v)))
void vloxseg8ei16(vint32mf2_t *, vint32mf2_t *, vint32mf2_t *, vint32mf2_t *, vint32mf2_t *, vint32mf2_t *, vint32mf2_t *, vint32mf2_t *, const int32_t *, vuint16mf4_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vloxseg8ei16_v_m)))
void vloxseg8ei16(vint32mf2_t *, vint32mf2_t *, vint32mf2_t *, vint32mf2_t *, vint32mf2_t *, vint32mf2_t *, vint32mf2_t *, vint32mf2_t *, vbool64_t, vint32mf2_t, vint32mf2_t, vint32mf2_t, vint32mf2_t, vint32mf2_t, vint32mf2_t, vint32mf2_t, vint32mf2_t, const int32_t *, vuint16mf4_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vloxseg8ei16_v)))
void vloxseg8ei16(vuint32m1_t *, vuint32m1_t *, vuint32m1_t *, vuint32m1_t *, vuint32m1_t *, vuint32m1_t *, vuint32m1_t *, vuint32m1_t *, const uint32_t *, vuint16mf2_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vloxseg8ei16_v_m)))
void vloxseg8ei16(vuint32m1_t *, vuint32m1_t *, vuint32m1_t *, vuint32m1_t *, vuint32m1_t *, vuint32m1_t *, vuint32m1_t *, vuint32m1_t *, vbool32_t, vuint32m1_t, vuint32m1_t, vuint32m1_t, vuint32m1_t, vuint32m1_t, vuint32m1_t, vuint32m1_t, vuint32m1_t, const uint32_t *, vuint16mf2_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vloxseg8ei16_v)))
void vloxseg8ei16(vuint32mf2_t *, vuint32mf2_t *, vuint32mf2_t *, vuint32mf2_t *, vuint32mf2_t *, vuint32mf2_t *, vuint32mf2_t *, vuint32mf2_t *, const uint32_t *, vuint16mf4_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vloxseg8ei16_v_m)))
void vloxseg8ei16(vuint32mf2_t *, vuint32mf2_t *, vuint32mf2_t *, vuint32mf2_t *, vuint32mf2_t *, vuint32mf2_t *, vuint32mf2_t *, vuint32mf2_t *, vbool64_t, vuint32mf2_t, vuint32mf2_t, vuint32mf2_t, vuint32mf2_t, vuint32mf2_t, vuint32mf2_t, vuint32mf2_t, vuint32mf2_t, const uint32_t *, vuint16mf4_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vloxseg2ei32_v)))
void vloxseg2ei32(vint32m1_t *, vint32m1_t *, const int32_t *, vuint32m1_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vloxseg2ei32_v_m)))
void vloxseg2ei32(vint32m1_t *, vint32m1_t *, vbool32_t, vint32m1_t, vint32m1_t, const int32_t *, vuint32m1_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vloxseg2ei32_v)))
void vloxseg2ei32(vint32m2_t *, vint32m2_t *, const int32_t *, vuint32m2_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vloxseg2ei32_v_m)))
void vloxseg2ei32(vint32m2_t *, vint32m2_t *, vbool16_t, vint32m2_t, vint32m2_t, const int32_t *, vuint32m2_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vloxseg2ei32_v)))
void vloxseg2ei32(vint32m4_t *, vint32m4_t *, const int32_t *, vuint32m4_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vloxseg2ei32_v_m)))
void vloxseg2ei32(vint32m4_t *, vint32m4_t *, vbool8_t, vint32m4_t, vint32m4_t, const int32_t *, vuint32m4_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vloxseg2ei32_v)))
void vloxseg2ei32(vint32mf2_t *, vint32mf2_t *, const int32_t *, vuint32mf2_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vloxseg2ei32_v_m)))
void vloxseg2ei32(vint32mf2_t *, vint32mf2_t *, vbool64_t, vint32mf2_t, vint32mf2_t, const int32_t *, vuint32mf2_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vloxseg2ei32_v)))
void vloxseg2ei32(vuint32m1_t *, vuint32m1_t *, const uint32_t *, vuint32m1_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vloxseg2ei32_v_m)))
void vloxseg2ei32(vuint32m1_t *, vuint32m1_t *, vbool32_t, vuint32m1_t, vuint32m1_t, const uint32_t *, vuint32m1_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vloxseg2ei32_v)))
void vloxseg2ei32(vuint32m2_t *, vuint32m2_t *, const uint32_t *, vuint32m2_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vloxseg2ei32_v_m)))
void vloxseg2ei32(vuint32m2_t *, vuint32m2_t *, vbool16_t, vuint32m2_t, vuint32m2_t, const uint32_t *, vuint32m2_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vloxseg2ei32_v)))
void vloxseg2ei32(vuint32m4_t *, vuint32m4_t *, const uint32_t *, vuint32m4_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vloxseg2ei32_v_m)))
void vloxseg2ei32(vuint32m4_t *, vuint32m4_t *, vbool8_t, vuint32m4_t, vuint32m4_t, const uint32_t *, vuint32m4_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vloxseg2ei32_v)))
void vloxseg2ei32(vuint32mf2_t *, vuint32mf2_t *, const uint32_t *, vuint32mf2_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vloxseg2ei32_v_m)))
void vloxseg2ei32(vuint32mf2_t *, vuint32mf2_t *, vbool64_t, vuint32mf2_t, vuint32mf2_t, const uint32_t *, vuint32mf2_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vloxseg3ei32_v)))
void vloxseg3ei32(vint32m1_t *, vint32m1_t *, vint32m1_t *, const int32_t *, vuint32m1_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vloxseg3ei32_v_m)))
void vloxseg3ei32(vint32m1_t *, vint32m1_t *, vint32m1_t *, vbool32_t, vint32m1_t, vint32m1_t, vint32m1_t, const int32_t *, vuint32m1_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vloxseg3ei32_v)))
void vloxseg3ei32(vint32m2_t *, vint32m2_t *, vint32m2_t *, const int32_t *, vuint32m2_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vloxseg3ei32_v_m)))
void vloxseg3ei32(vint32m2_t *, vint32m2_t *, vint32m2_t *, vbool16_t, vint32m2_t, vint32m2_t, vint32m2_t, const int32_t *, vuint32m2_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vloxseg3ei32_v)))
void vloxseg3ei32(vint32mf2_t *, vint32mf2_t *, vint32mf2_t *, const int32_t *, vuint32mf2_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vloxseg3ei32_v_m)))
void vloxseg3ei32(vint32mf2_t *, vint32mf2_t *, vint32mf2_t *, vbool64_t, vint32mf2_t, vint32mf2_t, vint32mf2_t, const int32_t *, vuint32mf2_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vloxseg3ei32_v)))
void vloxseg3ei32(vuint32m1_t *, vuint32m1_t *, vuint32m1_t *, const uint32_t *, vuint32m1_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vloxseg3ei32_v_m)))
void vloxseg3ei32(vuint32m1_t *, vuint32m1_t *, vuint32m1_t *, vbool32_t, vuint32m1_t, vuint32m1_t, vuint32m1_t, const uint32_t *, vuint32m1_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vloxseg3ei32_v)))
void vloxseg3ei32(vuint32m2_t *, vuint32m2_t *, vuint32m2_t *, const uint32_t *, vuint32m2_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vloxseg3ei32_v_m)))
void vloxseg3ei32(vuint32m2_t *, vuint32m2_t *, vuint32m2_t *, vbool16_t, vuint32m2_t, vuint32m2_t, vuint32m2_t, const uint32_t *, vuint32m2_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vloxseg3ei32_v)))
void vloxseg3ei32(vuint32mf2_t *, vuint32mf2_t *, vuint32mf2_t *, const uint32_t *, vuint32mf2_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vloxseg3ei32_v_m)))
void vloxseg3ei32(vuint32mf2_t *, vuint32mf2_t *, vuint32mf2_t *, vbool64_t, vuint32mf2_t, vuint32mf2_t, vuint32mf2_t, const uint32_t *, vuint32mf2_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vloxseg4ei32_v)))
void vloxseg4ei32(vint32m1_t *, vint32m1_t *, vint32m1_t *, vint32m1_t *, const int32_t *, vuint32m1_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vloxseg4ei32_v_m)))
void vloxseg4ei32(vint32m1_t *, vint32m1_t *, vint32m1_t *, vint32m1_t *, vbool32_t, vint32m1_t, vint32m1_t, vint32m1_t, vint32m1_t, const int32_t *, vuint32m1_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vloxseg4ei32_v)))
void vloxseg4ei32(vint32m2_t *, vint32m2_t *, vint32m2_t *, vint32m2_t *, const int32_t *, vuint32m2_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vloxseg4ei32_v_m)))
void vloxseg4ei32(vint32m2_t *, vint32m2_t *, vint32m2_t *, vint32m2_t *, vbool16_t, vint32m2_t, vint32m2_t, vint32m2_t, vint32m2_t, const int32_t *, vuint32m2_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vloxseg4ei32_v)))
void vloxseg4ei32(vint32mf2_t *, vint32mf2_t *, vint32mf2_t *, vint32mf2_t *, const int32_t *, vuint32mf2_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vloxseg4ei32_v_m)))
void vloxseg4ei32(vint32mf2_t *, vint32mf2_t *, vint32mf2_t *, vint32mf2_t *, vbool64_t, vint32mf2_t, vint32mf2_t, vint32mf2_t, vint32mf2_t, const int32_t *, vuint32mf2_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vloxseg4ei32_v)))
void vloxseg4ei32(vuint32m1_t *, vuint32m1_t *, vuint32m1_t *, vuint32m1_t *, const uint32_t *, vuint32m1_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vloxseg4ei32_v_m)))
void vloxseg4ei32(vuint32m1_t *, vuint32m1_t *, vuint32m1_t *, vuint32m1_t *, vbool32_t, vuint32m1_t, vuint32m1_t, vuint32m1_t, vuint32m1_t, const uint32_t *, vuint32m1_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vloxseg4ei32_v)))
void vloxseg4ei32(vuint32m2_t *, vuint32m2_t *, vuint32m2_t *, vuint32m2_t *, const uint32_t *, vuint32m2_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vloxseg4ei32_v_m)))
void vloxseg4ei32(vuint32m2_t *, vuint32m2_t *, vuint32m2_t *, vuint32m2_t *, vbool16_t, vuint32m2_t, vuint32m2_t, vuint32m2_t, vuint32m2_t, const uint32_t *, vuint32m2_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vloxseg4ei32_v)))
void vloxseg4ei32(vuint32mf2_t *, vuint32mf2_t *, vuint32mf2_t *, vuint32mf2_t *, const uint32_t *, vuint32mf2_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vloxseg4ei32_v_m)))
void vloxseg4ei32(vuint32mf2_t *, vuint32mf2_t *, vuint32mf2_t *, vuint32mf2_t *, vbool64_t, vuint32mf2_t, vuint32mf2_t, vuint32mf2_t, vuint32mf2_t, const uint32_t *, vuint32mf2_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vloxseg5ei32_v)))
void vloxseg5ei32(vint32m1_t *, vint32m1_t *, vint32m1_t *, vint32m1_t *, vint32m1_t *, const int32_t *, vuint32m1_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vloxseg5ei32_v_m)))
void vloxseg5ei32(vint32m1_t *, vint32m1_t *, vint32m1_t *, vint32m1_t *, vint32m1_t *, vbool32_t, vint32m1_t, vint32m1_t, vint32m1_t, vint32m1_t, vint32m1_t, const int32_t *, vuint32m1_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vloxseg5ei32_v)))
void vloxseg5ei32(vint32mf2_t *, vint32mf2_t *, vint32mf2_t *, vint32mf2_t *, vint32mf2_t *, const int32_t *, vuint32mf2_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vloxseg5ei32_v_m)))
void vloxseg5ei32(vint32mf2_t *, vint32mf2_t *, vint32mf2_t *, vint32mf2_t *, vint32mf2_t *, vbool64_t, vint32mf2_t, vint32mf2_t, vint32mf2_t, vint32mf2_t, vint32mf2_t, const int32_t *, vuint32mf2_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vloxseg5ei32_v)))
void vloxseg5ei32(vuint32m1_t *, vuint32m1_t *, vuint32m1_t *, vuint32m1_t *, vuint32m1_t *, const uint32_t *, vuint32m1_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vloxseg5ei32_v_m)))
void vloxseg5ei32(vuint32m1_t *, vuint32m1_t *, vuint32m1_t *, vuint32m1_t *, vuint32m1_t *, vbool32_t, vuint32m1_t, vuint32m1_t, vuint32m1_t, vuint32m1_t, vuint32m1_t, const uint32_t *, vuint32m1_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vloxseg5ei32_v)))
void vloxseg5ei32(vuint32mf2_t *, vuint32mf2_t *, vuint32mf2_t *, vuint32mf2_t *, vuint32mf2_t *, const uint32_t *, vuint32mf2_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vloxseg5ei32_v_m)))
void vloxseg5ei32(vuint32mf2_t *, vuint32mf2_t *, vuint32mf2_t *, vuint32mf2_t *, vuint32mf2_t *, vbool64_t, vuint32mf2_t, vuint32mf2_t, vuint32mf2_t, vuint32mf2_t, vuint32mf2_t, const uint32_t *, vuint32mf2_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vloxseg6ei32_v)))
void vloxseg6ei32(vint32m1_t *, vint32m1_t *, vint32m1_t *, vint32m1_t *, vint32m1_t *, vint32m1_t *, const int32_t *, vuint32m1_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vloxseg6ei32_v_m)))
void vloxseg6ei32(vint32m1_t *, vint32m1_t *, vint32m1_t *, vint32m1_t *, vint32m1_t *, vint32m1_t *, vbool32_t, vint32m1_t, vint32m1_t, vint32m1_t, vint32m1_t, vint32m1_t, vint32m1_t, const int32_t *, vuint32m1_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vloxseg6ei32_v)))
void vloxseg6ei32(vint32mf2_t *, vint32mf2_t *, vint32mf2_t *, vint32mf2_t *, vint32mf2_t *, vint32mf2_t *, const int32_t *, vuint32mf2_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vloxseg6ei32_v_m)))
void vloxseg6ei32(vint32mf2_t *, vint32mf2_t *, vint32mf2_t *, vint32mf2_t *, vint32mf2_t *, vint32mf2_t *, vbool64_t, vint32mf2_t, vint32mf2_t, vint32mf2_t, vint32mf2_t, vint32mf2_t, vint32mf2_t, const int32_t *, vuint32mf2_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vloxseg6ei32_v)))
void vloxseg6ei32(vuint32m1_t *, vuint32m1_t *, vuint32m1_t *, vuint32m1_t *, vuint32m1_t *, vuint32m1_t *, const uint32_t *, vuint32m1_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vloxseg6ei32_v_m)))
void vloxseg6ei32(vuint32m1_t *, vuint32m1_t *, vuint32m1_t *, vuint32m1_t *, vuint32m1_t *, vuint32m1_t *, vbool32_t, vuint32m1_t, vuint32m1_t, vuint32m1_t, vuint32m1_t, vuint32m1_t, vuint32m1_t, const uint32_t *, vuint32m1_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vloxseg6ei32_v)))
void vloxseg6ei32(vuint32mf2_t *, vuint32mf2_t *, vuint32mf2_t *, vuint32mf2_t *, vuint32mf2_t *, vuint32mf2_t *, const uint32_t *, vuint32mf2_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vloxseg6ei32_v_m)))
void vloxseg6ei32(vuint32mf2_t *, vuint32mf2_t *, vuint32mf2_t *, vuint32mf2_t *, vuint32mf2_t *, vuint32mf2_t *, vbool64_t, vuint32mf2_t, vuint32mf2_t, vuint32mf2_t, vuint32mf2_t, vuint32mf2_t, vuint32mf2_t, const uint32_t *, vuint32mf2_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vlse32_v_m)))
vint32m1_t vlse32(vbool32_t, vint32m1_t, const int32_t *, ptrdiff_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vlse32_v_m)))
vint32m2_t vlse32(vbool16_t, vint32m2_t, const int32_t *, ptrdiff_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vlse32_v_m)))
vint32m4_t vlse32(vbool8_t, vint32m4_t, const int32_t *, ptrdiff_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vlse32_v_m)))
vint32m8_t vlse32(vbool4_t, vint32m8_t, const int32_t *, ptrdiff_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vlse32_v_m)))
vint32mf2_t vlse32(vbool64_t, vint32mf2_t, const int32_t *, ptrdiff_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vloxseg7ei32_v)))
void vloxseg7ei32(vint32m1_t *, vint32m1_t *, vint32m1_t *, vint32m1_t *, vint32m1_t *, vint32m1_t *, vint32m1_t *, const int32_t *, vuint32m1_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vloxseg7ei32_v_m)))
void vloxseg7ei32(vint32m1_t *, vint32m1_t *, vint32m1_t *, vint32m1_t *, vint32m1_t *, vint32m1_t *, vint32m1_t *, vbool32_t, vint32m1_t, vint32m1_t, vint32m1_t, vint32m1_t, vint32m1_t, vint32m1_t, vint32m1_t, const int32_t *, vuint32m1_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vloxseg7ei32_v)))
void vloxseg7ei32(vint32mf2_t *, vint32mf2_t *, vint32mf2_t *, vint32mf2_t *, vint32mf2_t *, vint32mf2_t *, vint32mf2_t *, const int32_t *, vuint32mf2_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vloxseg7ei32_v_m)))
void vloxseg7ei32(vint32mf2_t *, vint32mf2_t *, vint32mf2_t *, vint32mf2_t *, vint32mf2_t *, vint32mf2_t *, vint32mf2_t *, vbool64_t, vint32mf2_t, vint32mf2_t, vint32mf2_t, vint32mf2_t, vint32mf2_t, vint32mf2_t, vint32mf2_t, const int32_t *, vuint32mf2_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vloxseg7ei32_v)))
void vloxseg7ei32(vuint32m1_t *, vuint32m1_t *, vuint32m1_t *, vuint32m1_t *, vuint32m1_t *, vuint32m1_t *, vuint32m1_t *, const uint32_t *, vuint32m1_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vloxseg7ei32_v_m)))
void vloxseg7ei32(vuint32m1_t *, vuint32m1_t *, vuint32m1_t *, vuint32m1_t *, vuint32m1_t *, vuint32m1_t *, vuint32m1_t *, vbool32_t, vuint32m1_t, vuint32m1_t, vuint32m1_t, vuint32m1_t, vuint32m1_t, vuint32m1_t, vuint32m1_t, const uint32_t *, vuint32m1_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vloxseg7ei32_v)))
void vloxseg7ei32(vuint32mf2_t *, vuint32mf2_t *, vuint32mf2_t *, vuint32mf2_t *, vuint32mf2_t *, vuint32mf2_t *, vuint32mf2_t *, const uint32_t *, vuint32mf2_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vloxseg7ei32_v_m)))
void vloxseg7ei32(vuint32mf2_t *, vuint32mf2_t *, vuint32mf2_t *, vuint32mf2_t *, vuint32mf2_t *, vuint32mf2_t *, vuint32mf2_t *, vbool64_t, vuint32mf2_t, vuint32mf2_t, vuint32mf2_t, vuint32mf2_t, vuint32mf2_t, vuint32mf2_t, vuint32mf2_t, const uint32_t *, vuint32mf2_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vloxseg8ei32_v)))
void vloxseg8ei32(vint32m1_t *, vint32m1_t *, vint32m1_t *, vint32m1_t *, vint32m1_t *, vint32m1_t *, vint32m1_t *, vint32m1_t *, const int32_t *, vuint32m1_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vloxseg8ei32_v_m)))
void vloxseg8ei32(vint32m1_t *, vint32m1_t *, vint32m1_t *, vint32m1_t *, vint32m1_t *, vint32m1_t *, vint32m1_t *, vint32m1_t *, vbool32_t, vint32m1_t, vint32m1_t, vint32m1_t, vint32m1_t, vint32m1_t, vint32m1_t, vint32m1_t, vint32m1_t, const int32_t *, vuint32m1_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vloxseg8ei32_v)))
void vloxseg8ei32(vint32mf2_t *, vint32mf2_t *, vint32mf2_t *, vint32mf2_t *, vint32mf2_t *, vint32mf2_t *, vint32mf2_t *, vint32mf2_t *, const int32_t *, vuint32mf2_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vloxseg8ei32_v_m)))
void vloxseg8ei32(vint32mf2_t *, vint32mf2_t *, vint32mf2_t *, vint32mf2_t *, vint32mf2_t *, vint32mf2_t *, vint32mf2_t *, vint32mf2_t *, vbool64_t, vint32mf2_t, vint32mf2_t, vint32mf2_t, vint32mf2_t, vint32mf2_t, vint32mf2_t, vint32mf2_t, vint32mf2_t, const int32_t *, vuint32mf2_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vloxseg8ei32_v)))
void vloxseg8ei32(vuint32m1_t *, vuint32m1_t *, vuint32m1_t *, vuint32m1_t *, vuint32m1_t *, vuint32m1_t *, vuint32m1_t *, vuint32m1_t *, const uint32_t *, vuint32m1_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vloxseg8ei32_v_m)))
void vloxseg8ei32(vuint32m1_t *, vuint32m1_t *, vuint32m1_t *, vuint32m1_t *, vuint32m1_t *, vuint32m1_t *, vuint32m1_t *, vuint32m1_t *, vbool32_t, vuint32m1_t, vuint32m1_t, vuint32m1_t, vuint32m1_t, vuint32m1_t, vuint32m1_t, vuint32m1_t, vuint32m1_t, const uint32_t *, vuint32m1_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vloxseg8ei32_v)))
void vloxseg8ei32(vuint32mf2_t *, vuint32mf2_t *, vuint32mf2_t *, vuint32mf2_t *, vuint32mf2_t *, vuint32mf2_t *, vuint32mf2_t *, vuint32mf2_t *, const uint32_t *, vuint32mf2_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vloxseg8ei32_v_m)))
void vloxseg8ei32(vuint32mf2_t *, vuint32mf2_t *, vuint32mf2_t *, vuint32mf2_t *, vuint32mf2_t *, vuint32mf2_t *, vuint32mf2_t *, vuint32mf2_t *, vbool64_t, vuint32mf2_t, vuint32mf2_t, vuint32mf2_t, vuint32mf2_t, vuint32mf2_t, vuint32mf2_t, vuint32mf2_t, vuint32mf2_t, const uint32_t *, vuint32mf2_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vlse32_v_m)))
vuint32m1_t vlse32(vbool32_t, vuint32m1_t, const uint32_t *, ptrdiff_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vlse32_v_m)))
vuint32m2_t vlse32(vbool16_t, vuint32m2_t, const uint32_t *, ptrdiff_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vlse32_v_m)))
vuint32m4_t vlse32(vbool8_t, vuint32m4_t, const uint32_t *, ptrdiff_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vlse32_v_m)))
vuint32m8_t vlse32(vbool4_t, vuint32m8_t, const uint32_t *, ptrdiff_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vlse32_v_m)))
vuint32mf2_t vlse32(vbool64_t, vuint32mf2_t, const uint32_t *, ptrdiff_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vcpop_m)))
unsigned long vcpop(vbool8_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vcpop_m_m)))
unsigned long vcpop(vbool8_t, vbool8_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vcpop_m)))
unsigned long vcpop(vbool4_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vcpop_m_m)))
unsigned long vcpop(vbool4_t, vbool4_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vcpop_m)))
unsigned long vcpop(vbool2_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vcpop_m_m)))
unsigned long vcpop(vbool2_t, vbool2_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vcpop_m)))
unsigned long vcpop(vbool1_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vcpop_m_m)))
unsigned long vcpop(vbool1_t, vbool1_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vcpop_m)))
unsigned long vcpop(vbool16_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vcpop_m_m)))
unsigned long vcpop(vbool16_t, vbool16_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vcpop_m)))
unsigned long vcpop(vbool32_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vcpop_m_m)))
unsigned long vcpop(vbool32_t, vbool32_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vcpop_m)))
unsigned long vcpop(vbool64_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vcpop_m_m)))
unsigned long vcpop(vbool64_t, vbool64_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vfirst_m)))
long vfirst(vbool8_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vfirst_m_m)))
long vfirst(vbool8_t, vbool8_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vfirst_m)))
long vfirst(vbool4_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vfirst_m_m)))
long vfirst(vbool4_t, vbool4_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vfirst_m)))
long vfirst(vbool2_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vfirst_m_m)))
long vfirst(vbool2_t, vbool2_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vfirst_m)))
long vfirst(vbool1_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vfirst_m_m)))
long vfirst(vbool1_t, vbool1_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vfirst_m)))
long vfirst(vbool16_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vfirst_m_m)))
long vfirst(vbool16_t, vbool16_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vfirst_m)))
long vfirst(vbool32_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vfirst_m_m)))
long vfirst(vbool32_t, vbool32_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vfirst_m)))
long vfirst(vbool64_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vfirst_m_m)))
long vfirst(vbool64_t, vbool64_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vlmul_ext_v)))
vint8m1_t vlmul_ext_i8m1(vint8mf2_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vlmul_ext_v)))
vint8m1_t vlmul_ext_i8m1(vint8mf4_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vlmul_ext_v)))
vint8m1_t vlmul_ext_i8m1(vint8mf8_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vlmul_ext_v)))
vint16m1_t vlmul_ext_i16m1(vint16mf2_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vlmul_ext_v)))
vint16m1_t vlmul_ext_i16m1(vint16mf4_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vlmul_ext_v)))
vint32m1_t vlmul_ext_i32m1(vint32mf2_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vlmul_ext_v)))
vint8mf2_t vlmul_ext_i8mf2(vint8mf4_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vlmul_ext_v)))
vint8mf2_t vlmul_ext_i8mf2(vint8mf8_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vlmul_ext_v)))
vint16mf2_t vlmul_ext_i16mf2(vint16mf4_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vlmul_ext_v)))
vint8mf4_t vlmul_ext_i8mf4(vint8mf8_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vlmul_ext_v)))
vint8m2_t vlmul_ext_i8m2(vint8m1_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vlmul_ext_v)))
vint8m2_t vlmul_ext_i8m2(vint8mf2_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vlmul_ext_v)))
vint8m2_t vlmul_ext_i8m2(vint8mf4_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vlmul_ext_v)))
vint8m2_t vlmul_ext_i8m2(vint8mf8_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vlmul_ext_v)))
vint16m2_t vlmul_ext_i16m2(vint16m1_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vlmul_ext_v)))
vint16m2_t vlmul_ext_i16m2(vint16mf2_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vlmul_ext_v)))
vint16m2_t vlmul_ext_i16m2(vint16mf4_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vlmul_ext_v)))
vint32m2_t vlmul_ext_i32m2(vint32m1_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vlmul_ext_v)))
vint32m2_t vlmul_ext_i32m2(vint32mf2_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vlmul_ext_v)))
vint8m4_t vlmul_ext_i8m4(vint8m1_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vlmul_ext_v)))
vint8m4_t vlmul_ext_i8m4(vint8m2_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vlmul_ext_v)))
vint8m4_t vlmul_ext_i8m4(vint8mf2_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vlmul_ext_v)))
vint8m4_t vlmul_ext_i8m4(vint8mf4_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vlmul_ext_v)))
vint8m4_t vlmul_ext_i8m4(vint8mf8_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vlmul_ext_v)))
vint16m4_t vlmul_ext_i16m4(vint16m1_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vlmul_ext_v)))
vint16m4_t vlmul_ext_i16m4(vint16m2_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vlmul_ext_v)))
vint16m4_t vlmul_ext_i16m4(vint16mf2_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vlmul_ext_v)))
vint16m4_t vlmul_ext_i16m4(vint16mf4_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vlmul_ext_v)))
vint32m4_t vlmul_ext_i32m4(vint32m1_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vlmul_ext_v)))
vint32m4_t vlmul_ext_i32m4(vint32m2_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vlmul_ext_v)))
vint32m4_t vlmul_ext_i32m4(vint32mf2_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vlmul_ext_v)))
vint8m8_t vlmul_ext_i8m8(vint8m1_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vlmul_ext_v)))
vint8m8_t vlmul_ext_i8m8(vint8m2_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vlmul_ext_v)))
vint8m8_t vlmul_ext_i8m8(vint8m4_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vlmul_ext_v)))
vint8m8_t vlmul_ext_i8m8(vint8mf2_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vlmul_ext_v)))
vint8m8_t vlmul_ext_i8m8(vint8mf4_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vlmul_ext_v)))
vint8m8_t vlmul_ext_i8m8(vint8mf8_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vlmul_ext_v)))
vint16m8_t vlmul_ext_i16m8(vint16m1_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vlmul_ext_v)))
vint16m8_t vlmul_ext_i16m8(vint16m2_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vlmul_ext_v)))
vint16m8_t vlmul_ext_i16m8(vint16m4_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vlmul_ext_v)))
vint16m8_t vlmul_ext_i16m8(vint16mf2_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vlmul_ext_v)))
vint16m8_t vlmul_ext_i16m8(vint16mf4_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vlmul_ext_v)))
vint32m8_t vlmul_ext_i32m8(vint32m1_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vlmul_ext_v)))
vint32m8_t vlmul_ext_i32m8(vint32m2_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vlmul_ext_v)))
vint32m8_t vlmul_ext_i32m8(vint32m4_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vlmul_ext_v)))
vint32m8_t vlmul_ext_i32m8(vint32mf2_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vlmul_ext_v)))
vuint8m1_t vlmul_ext_u8m1(vuint8mf2_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vlmul_ext_v)))
vuint8m1_t vlmul_ext_u8m1(vuint8mf4_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vlmul_ext_v)))
vuint8m1_t vlmul_ext_u8m1(vuint8mf8_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vlmul_ext_v)))
vuint16m1_t vlmul_ext_u16m1(vuint16mf2_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vlmul_ext_v)))
vuint16m1_t vlmul_ext_u16m1(vuint16mf4_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vlmul_ext_v)))
vuint32m1_t vlmul_ext_u32m1(vuint32mf2_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vlmul_ext_v)))
vuint8mf2_t vlmul_ext_u8mf2(vuint8mf4_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vlmul_ext_v)))
vuint8mf2_t vlmul_ext_u8mf2(vuint8mf8_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vlmul_ext_v)))
vuint16mf2_t vlmul_ext_u16mf2(vuint16mf4_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vlmul_ext_v)))
vuint8mf4_t vlmul_ext_u8mf4(vuint8mf8_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vlmul_ext_v)))
vuint8m2_t vlmul_ext_u8m2(vuint8m1_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vlmul_ext_v)))
vuint8m2_t vlmul_ext_u8m2(vuint8mf2_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vlmul_ext_v)))
vuint8m2_t vlmul_ext_u8m2(vuint8mf4_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vlmul_ext_v)))
vuint8m2_t vlmul_ext_u8m2(vuint8mf8_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vlmul_ext_v)))
vuint16m2_t vlmul_ext_u16m2(vuint16m1_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vlmul_ext_v)))
vuint16m2_t vlmul_ext_u16m2(vuint16mf2_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vlmul_ext_v)))
vuint16m2_t vlmul_ext_u16m2(vuint16mf4_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vlmul_ext_v)))
vuint32m2_t vlmul_ext_u32m2(vuint32m1_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vlmul_ext_v)))
vuint32m2_t vlmul_ext_u32m2(vuint32mf2_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vlmul_ext_v)))
vuint8m4_t vlmul_ext_u8m4(vuint8m1_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vlmul_ext_v)))
vuint8m4_t vlmul_ext_u8m4(vuint8m2_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vlmul_ext_v)))
vuint8m4_t vlmul_ext_u8m4(vuint8mf2_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vlmul_ext_v)))
vuint8m4_t vlmul_ext_u8m4(vuint8mf4_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vlmul_ext_v)))
vuint8m4_t vlmul_ext_u8m4(vuint8mf8_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vlmul_ext_v)))
vuint16m4_t vlmul_ext_u16m4(vuint16m1_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vlmul_ext_v)))
vuint16m4_t vlmul_ext_u16m4(vuint16m2_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vlmul_ext_v)))
vuint16m4_t vlmul_ext_u16m4(vuint16mf2_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vlmul_ext_v)))
vuint16m4_t vlmul_ext_u16m4(vuint16mf4_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vlmul_ext_v)))
vuint32m4_t vlmul_ext_u32m4(vuint32m1_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vlmul_ext_v)))
vuint32m4_t vlmul_ext_u32m4(vuint32m2_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vlmul_ext_v)))
vuint32m4_t vlmul_ext_u32m4(vuint32mf2_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vlmul_ext_v)))
vuint8m8_t vlmul_ext_u8m8(vuint8m1_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vlmul_ext_v)))
vuint8m8_t vlmul_ext_u8m8(vuint8m2_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vlmul_ext_v)))
vuint8m8_t vlmul_ext_u8m8(vuint8m4_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vlmul_ext_v)))
vuint8m8_t vlmul_ext_u8m8(vuint8mf2_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vlmul_ext_v)))
vuint8m8_t vlmul_ext_u8m8(vuint8mf4_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vlmul_ext_v)))
vuint8m8_t vlmul_ext_u8m8(vuint8mf8_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vlmul_ext_v)))
vuint16m8_t vlmul_ext_u16m8(vuint16m1_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vlmul_ext_v)))
vuint16m8_t vlmul_ext_u16m8(vuint16m2_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vlmul_ext_v)))
vuint16m8_t vlmul_ext_u16m8(vuint16m4_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vlmul_ext_v)))
vuint16m8_t vlmul_ext_u16m8(vuint16mf2_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vlmul_ext_v)))
vuint16m8_t vlmul_ext_u16m8(vuint16mf4_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vlmul_ext_v)))
vuint32m8_t vlmul_ext_u32m8(vuint32m1_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vlmul_ext_v)))
vuint32m8_t vlmul_ext_u32m8(vuint32m2_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vlmul_ext_v)))
vuint32m8_t vlmul_ext_u32m8(vuint32m4_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vlmul_ext_v)))
vuint32m8_t vlmul_ext_u32m8(vuint32mf2_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vlmul_trunc_v)))
vint8mf2_t vlmul_trunc_i8mf2(vint8m1_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vlmul_trunc_v)))
vint8mf2_t vlmul_trunc_i8mf2(vint8m2_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vlmul_trunc_v)))
vint8mf2_t vlmul_trunc_i8mf2(vint8m4_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vlmul_trunc_v)))
vint8mf2_t vlmul_trunc_i8mf2(vint8m8_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vlmul_trunc_v)))
vint16mf2_t vlmul_trunc_i16mf2(vint16m1_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vlmul_trunc_v)))
vint16mf2_t vlmul_trunc_i16mf2(vint16m2_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vlmul_trunc_v)))
vint16mf2_t vlmul_trunc_i16mf2(vint16m4_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vlmul_trunc_v)))
vint16mf2_t vlmul_trunc_i16mf2(vint16m8_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vlmul_trunc_v)))
vint32mf2_t vlmul_trunc_i32mf2(vint32m1_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vlmul_trunc_v)))
vint32mf2_t vlmul_trunc_i32mf2(vint32m2_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vlmul_trunc_v)))
vint32mf2_t vlmul_trunc_i32mf2(vint32m4_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vlmul_trunc_v)))
vint32mf2_t vlmul_trunc_i32mf2(vint32m8_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vlmul_trunc_v)))
vint8mf4_t vlmul_trunc_i8mf4(vint8m1_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vlmul_trunc_v)))
vint8mf4_t vlmul_trunc_i8mf4(vint8m2_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vlmul_trunc_v)))
vint8mf4_t vlmul_trunc_i8mf4(vint8m4_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vlmul_trunc_v)))
vint8mf4_t vlmul_trunc_i8mf4(vint8m8_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vlmul_trunc_v)))
vint8mf4_t vlmul_trunc_i8mf4(vint8mf2_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vlmul_trunc_v)))
vint16mf4_t vlmul_trunc_i16mf4(vint16m1_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vlmul_trunc_v)))
vint16mf4_t vlmul_trunc_i16mf4(vint16m2_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vlmul_trunc_v)))
vint16mf4_t vlmul_trunc_i16mf4(vint16m4_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vlmul_trunc_v)))
vint16mf4_t vlmul_trunc_i16mf4(vint16m8_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vlmul_trunc_v)))
vint16mf4_t vlmul_trunc_i16mf4(vint16mf2_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vlmul_trunc_v)))
vint8mf8_t vlmul_trunc_i8mf8(vint8m1_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vlmul_trunc_v)))
vint8mf8_t vlmul_trunc_i8mf8(vint8m2_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vlmul_trunc_v)))
vint8mf8_t vlmul_trunc_i8mf8(vint8m4_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vlmul_trunc_v)))
vint8mf8_t vlmul_trunc_i8mf8(vint8m8_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vlmul_trunc_v)))
vint8mf8_t vlmul_trunc_i8mf8(vint8mf2_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vlmul_trunc_v)))
vint8mf8_t vlmul_trunc_i8mf8(vint8mf4_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vlmul_trunc_v)))
vint8m1_t vlmul_trunc_i8m1(vint8m2_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vlmul_trunc_v)))
vint8m1_t vlmul_trunc_i8m1(vint8m4_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vlmul_trunc_v)))
vint8m1_t vlmul_trunc_i8m1(vint8m8_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vlmul_trunc_v)))
vint16m1_t vlmul_trunc_i16m1(vint16m2_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vlmul_trunc_v)))
vint16m1_t vlmul_trunc_i16m1(vint16m4_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vlmul_trunc_v)))
vint16m1_t vlmul_trunc_i16m1(vint16m8_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vlmul_trunc_v)))
vint32m1_t vlmul_trunc_i32m1(vint32m2_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vlmul_trunc_v)))
vint32m1_t vlmul_trunc_i32m1(vint32m4_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vlmul_trunc_v)))
vint32m1_t vlmul_trunc_i32m1(vint32m8_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vlmul_trunc_v)))
vint8m2_t vlmul_trunc_i8m2(vint8m4_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vlmul_trunc_v)))
vint8m2_t vlmul_trunc_i8m2(vint8m8_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vlmul_trunc_v)))
vint16m2_t vlmul_trunc_i16m2(vint16m4_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vlmul_trunc_v)))
vint16m2_t vlmul_trunc_i16m2(vint16m8_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vlmul_trunc_v)))
vint32m2_t vlmul_trunc_i32m2(vint32m4_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vlmul_trunc_v)))
vint32m2_t vlmul_trunc_i32m2(vint32m8_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vlmul_trunc_v)))
vint8m4_t vlmul_trunc_i8m4(vint8m8_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vlmul_trunc_v)))
vint16m4_t vlmul_trunc_i16m4(vint16m8_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vlmul_trunc_v)))
vint32m4_t vlmul_trunc_i32m4(vint32m8_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vlmul_trunc_v)))
vuint8mf2_t vlmul_trunc_u8mf2(vuint8m1_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vlmul_trunc_v)))
vuint8mf2_t vlmul_trunc_u8mf2(vuint8m2_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vlmul_trunc_v)))
vuint8mf2_t vlmul_trunc_u8mf2(vuint8m4_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vlmul_trunc_v)))
vuint8mf2_t vlmul_trunc_u8mf2(vuint8m8_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vlmul_trunc_v)))
vuint16mf2_t vlmul_trunc_u16mf2(vuint16m1_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vlmul_trunc_v)))
vuint16mf2_t vlmul_trunc_u16mf2(vuint16m2_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vlmul_trunc_v)))
vuint16mf2_t vlmul_trunc_u16mf2(vuint16m4_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vlmul_trunc_v)))
vuint16mf2_t vlmul_trunc_u16mf2(vuint16m8_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vlmul_trunc_v)))
vuint32mf2_t vlmul_trunc_u32mf2(vuint32m1_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vlmul_trunc_v)))
vuint32mf2_t vlmul_trunc_u32mf2(vuint32m2_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vlmul_trunc_v)))
vuint32mf2_t vlmul_trunc_u32mf2(vuint32m4_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vlmul_trunc_v)))
vuint32mf2_t vlmul_trunc_u32mf2(vuint32m8_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vlmul_trunc_v)))
vuint8mf4_t vlmul_trunc_u8mf4(vuint8m1_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vlmul_trunc_v)))
vuint8mf4_t vlmul_trunc_u8mf4(vuint8m2_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vlmul_trunc_v)))
vuint8mf4_t vlmul_trunc_u8mf4(vuint8m4_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vlmul_trunc_v)))
vuint8mf4_t vlmul_trunc_u8mf4(vuint8m8_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vlmul_trunc_v)))
vuint8mf4_t vlmul_trunc_u8mf4(vuint8mf2_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vlmul_trunc_v)))
vuint16mf4_t vlmul_trunc_u16mf4(vuint16m1_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vlmul_trunc_v)))
vuint16mf4_t vlmul_trunc_u16mf4(vuint16m2_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vlmul_trunc_v)))
vuint16mf4_t vlmul_trunc_u16mf4(vuint16m4_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vlmul_trunc_v)))
vuint16mf4_t vlmul_trunc_u16mf4(vuint16m8_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vlmul_trunc_v)))
vuint16mf4_t vlmul_trunc_u16mf4(vuint16mf2_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vlmul_trunc_v)))
vuint8mf8_t vlmul_trunc_u8mf8(vuint8m1_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vlmul_trunc_v)))
vuint8mf8_t vlmul_trunc_u8mf8(vuint8m2_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vlmul_trunc_v)))
vuint8mf8_t vlmul_trunc_u8mf8(vuint8m4_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vlmul_trunc_v)))
vuint8mf8_t vlmul_trunc_u8mf8(vuint8m8_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vlmul_trunc_v)))
vuint8mf8_t vlmul_trunc_u8mf8(vuint8mf2_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vlmul_trunc_v)))
vuint8mf8_t vlmul_trunc_u8mf8(vuint8mf4_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vlmul_trunc_v)))
vuint8m1_t vlmul_trunc_u8m1(vuint8m2_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vlmul_trunc_v)))
vuint8m1_t vlmul_trunc_u8m1(vuint8m4_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vlmul_trunc_v)))
vuint8m1_t vlmul_trunc_u8m1(vuint8m8_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vlmul_trunc_v)))
vuint16m1_t vlmul_trunc_u16m1(vuint16m2_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vlmul_trunc_v)))
vuint16m1_t vlmul_trunc_u16m1(vuint16m4_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vlmul_trunc_v)))
vuint16m1_t vlmul_trunc_u16m1(vuint16m8_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vlmul_trunc_v)))
vuint32m1_t vlmul_trunc_u32m1(vuint32m2_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vlmul_trunc_v)))
vuint32m1_t vlmul_trunc_u32m1(vuint32m4_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vlmul_trunc_v)))
vuint32m1_t vlmul_trunc_u32m1(vuint32m8_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vlmul_trunc_v)))
vuint8m2_t vlmul_trunc_u8m2(vuint8m4_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vlmul_trunc_v)))
vuint8m2_t vlmul_trunc_u8m2(vuint8m8_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vlmul_trunc_v)))
vuint16m2_t vlmul_trunc_u16m2(vuint16m4_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vlmul_trunc_v)))
vuint16m2_t vlmul_trunc_u16m2(vuint16m8_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vlmul_trunc_v)))
vuint32m2_t vlmul_trunc_u32m2(vuint32m4_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vlmul_trunc_v)))
vuint32m2_t vlmul_trunc_u32m2(vuint32m8_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vlmul_trunc_v)))
vuint8m4_t vlmul_trunc_u8m4(vuint8m8_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vlmul_trunc_v)))
vuint16m4_t vlmul_trunc_u16m4(vuint16m8_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vlmul_trunc_v)))
vuint32m4_t vlmul_trunc_u32m4(vuint32m8_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vmand_mm)))
vbool8_t vmand(vbool8_t, vbool8_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vmand_mm)))
vbool4_t vmand(vbool4_t, vbool4_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vmand_mm)))
vbool2_t vmand(vbool2_t, vbool2_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vmand_mm)))
vbool1_t vmand(vbool1_t, vbool1_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vmand_mm)))
vbool16_t vmand(vbool16_t, vbool16_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vmand_mm)))
vbool32_t vmand(vbool32_t, vbool32_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vmand_mm)))
vbool64_t vmand(vbool64_t, vbool64_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vmandn_mm)))
vbool8_t vmandn(vbool8_t, vbool8_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vmandn_mm)))
vbool4_t vmandn(vbool4_t, vbool4_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vmandn_mm)))
vbool2_t vmandn(vbool2_t, vbool2_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vmandn_mm)))
vbool1_t vmandn(vbool1_t, vbool1_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vmandn_mm)))
vbool16_t vmandn(vbool16_t, vbool16_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vmandn_mm)))
vbool32_t vmandn(vbool32_t, vbool32_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vmandn_mm)))
vbool64_t vmandn(vbool64_t, vbool64_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vmnand_mm)))
vbool8_t vmnand(vbool8_t, vbool8_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vmnand_mm)))
vbool4_t vmnand(vbool4_t, vbool4_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vmnand_mm)))
vbool2_t vmnand(vbool2_t, vbool2_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vmnand_mm)))
vbool1_t vmnand(vbool1_t, vbool1_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vmnand_mm)))
vbool16_t vmnand(vbool16_t, vbool16_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vmnand_mm)))
vbool32_t vmnand(vbool32_t, vbool32_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vmnand_mm)))
vbool64_t vmnand(vbool64_t, vbool64_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vmnor_mm)))
vbool8_t vmnor(vbool8_t, vbool8_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vmnor_mm)))
vbool4_t vmnor(vbool4_t, vbool4_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vmnor_mm)))
vbool2_t vmnor(vbool2_t, vbool2_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vmnor_mm)))
vbool1_t vmnor(vbool1_t, vbool1_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vmnor_mm)))
vbool16_t vmnor(vbool16_t, vbool16_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vmnor_mm)))
vbool32_t vmnor(vbool32_t, vbool32_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vmnor_mm)))
vbool64_t vmnor(vbool64_t, vbool64_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vmor_mm)))
vbool8_t vmor(vbool8_t, vbool8_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vmor_mm)))
vbool4_t vmor(vbool4_t, vbool4_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vmor_mm)))
vbool2_t vmor(vbool2_t, vbool2_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vmor_mm)))
vbool1_t vmor(vbool1_t, vbool1_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vmor_mm)))
vbool16_t vmor(vbool16_t, vbool16_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vmor_mm)))
vbool32_t vmor(vbool32_t, vbool32_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vmor_mm)))
vbool64_t vmor(vbool64_t, vbool64_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vmorn_mm)))
vbool8_t vmorn(vbool8_t, vbool8_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vmorn_mm)))
vbool4_t vmorn(vbool4_t, vbool4_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vmorn_mm)))
vbool2_t vmorn(vbool2_t, vbool2_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vmorn_mm)))
vbool1_t vmorn(vbool1_t, vbool1_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vmorn_mm)))
vbool16_t vmorn(vbool16_t, vbool16_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vmorn_mm)))
vbool32_t vmorn(vbool32_t, vbool32_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vmorn_mm)))
vbool64_t vmorn(vbool64_t, vbool64_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vmsbf_m)))
vbool8_t vmsbf(vbool8_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vmsbf_m_m)))
vbool8_t vmsbf(vbool8_t, vbool8_t, vbool8_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vmsbf_m)))
vbool4_t vmsbf(vbool4_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vmsbf_m_m)))
vbool4_t vmsbf(vbool4_t, vbool4_t, vbool4_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vmsbf_m)))
vbool2_t vmsbf(vbool2_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vmsbf_m_m)))
vbool2_t vmsbf(vbool2_t, vbool2_t, vbool2_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vmsbf_m)))
vbool1_t vmsbf(vbool1_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vmsbf_m_m)))
vbool1_t vmsbf(vbool1_t, vbool1_t, vbool1_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vmsbf_m)))
vbool16_t vmsbf(vbool16_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vmsbf_m_m)))
vbool16_t vmsbf(vbool16_t, vbool16_t, vbool16_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vmsbf_m)))
vbool32_t vmsbf(vbool32_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vmsbf_m_m)))
vbool32_t vmsbf(vbool32_t, vbool32_t, vbool32_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vmsbf_m)))
vbool64_t vmsbf(vbool64_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vmsbf_m_m)))
vbool64_t vmsbf(vbool64_t, vbool64_t, vbool64_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vmsif_m)))
vbool8_t vmsif(vbool8_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vmsif_m_m)))
vbool8_t vmsif(vbool8_t, vbool8_t, vbool8_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vmsif_m)))
vbool4_t vmsif(vbool4_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vmsif_m_m)))
vbool4_t vmsif(vbool4_t, vbool4_t, vbool4_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vmsif_m)))
vbool2_t vmsif(vbool2_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vmsif_m_m)))
vbool2_t vmsif(vbool2_t, vbool2_t, vbool2_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vmsif_m)))
vbool1_t vmsif(vbool1_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vmsif_m_m)))
vbool1_t vmsif(vbool1_t, vbool1_t, vbool1_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vmsif_m)))
vbool16_t vmsif(vbool16_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vmsif_m_m)))
vbool16_t vmsif(vbool16_t, vbool16_t, vbool16_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vmsif_m)))
vbool32_t vmsif(vbool32_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vmsif_m_m)))
vbool32_t vmsif(vbool32_t, vbool32_t, vbool32_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vmsif_m)))
vbool64_t vmsif(vbool64_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vmsif_m_m)))
vbool64_t vmsif(vbool64_t, vbool64_t, vbool64_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vmsof_m)))
vbool8_t vmsof(vbool8_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vmsof_m_m)))
vbool8_t vmsof(vbool8_t, vbool8_t, vbool8_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vmsof_m)))
vbool4_t vmsof(vbool4_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vmsof_m_m)))
vbool4_t vmsof(vbool4_t, vbool4_t, vbool4_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vmsof_m)))
vbool2_t vmsof(vbool2_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vmsof_m_m)))
vbool2_t vmsof(vbool2_t, vbool2_t, vbool2_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vmsof_m)))
vbool1_t vmsof(vbool1_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vmsof_m_m)))
vbool1_t vmsof(vbool1_t, vbool1_t, vbool1_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vmsof_m)))
vbool16_t vmsof(vbool16_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vmsof_m_m)))
vbool16_t vmsof(vbool16_t, vbool16_t, vbool16_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vmsof_m)))
vbool32_t vmsof(vbool32_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vmsof_m_m)))
vbool32_t vmsof(vbool32_t, vbool32_t, vbool32_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vmsof_m)))
vbool64_t vmsof(vbool64_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vmsof_m_m)))
vbool64_t vmsof(vbool64_t, vbool64_t, vbool64_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vmxnor_mm)))
vbool8_t vmxnor(vbool8_t, vbool8_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vmxnor_mm)))
vbool4_t vmxnor(vbool4_t, vbool4_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vmxnor_mm)))
vbool2_t vmxnor(vbool2_t, vbool2_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vmxnor_mm)))
vbool1_t vmxnor(vbool1_t, vbool1_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vmxnor_mm)))
vbool16_t vmxnor(vbool16_t, vbool16_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vmxnor_mm)))
vbool32_t vmxnor(vbool32_t, vbool32_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vmxnor_mm)))
vbool64_t vmxnor(vbool64_t, vbool64_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vmxor_mm)))
vbool8_t vmxor(vbool8_t, vbool8_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vmxor_mm)))
vbool4_t vmxor(vbool4_t, vbool4_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vmxor_mm)))
vbool2_t vmxor(vbool2_t, vbool2_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vmxor_mm)))
vbool1_t vmxor(vbool1_t, vbool1_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vmxor_mm)))
vbool16_t vmxor(vbool16_t, vbool16_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vmxor_mm)))
vbool32_t vmxor(vbool32_t, vbool32_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vmxor_mm)))
vbool64_t vmxor(vbool64_t, vbool64_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vreinterpret_v)))
vint16m1_t vreinterpret_i16m1(vint8m1_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vreinterpret_v)))
vint16m2_t vreinterpret_i16m2(vint8m2_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vreinterpret_v)))
vint16m4_t vreinterpret_i16m4(vint8m4_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vreinterpret_v)))
vint16m8_t vreinterpret_i16m8(vint8m8_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vreinterpret_v)))
vint16mf2_t vreinterpret_i16mf2(vint8mf2_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vreinterpret_v)))
vint16mf4_t vreinterpret_i16mf4(vint8mf4_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vreinterpret_v)))
vint16m1_t vreinterpret_i16m1(vint32m1_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vreinterpret_v)))
vint16m2_t vreinterpret_i16m2(vint32m2_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vreinterpret_v)))
vint16m4_t vreinterpret_i16m4(vint32m4_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vreinterpret_v)))
vint16m8_t vreinterpret_i16m8(vint32m8_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vreinterpret_v)))
vint16mf2_t vreinterpret_i16mf2(vint32mf2_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vreinterpret_v)))
vint32m1_t vreinterpret_i32m1(vint8m1_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vreinterpret_v)))
vint32m2_t vreinterpret_i32m2(vint8m2_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vreinterpret_v)))
vint32m4_t vreinterpret_i32m4(vint8m4_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vreinterpret_v)))
vint32m8_t vreinterpret_i32m8(vint8m8_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vreinterpret_v)))
vint32mf2_t vreinterpret_i32mf2(vint8mf2_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vreinterpret_v)))
vint32m1_t vreinterpret_i32m1(vint16m1_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vreinterpret_v)))
vint32m2_t vreinterpret_i32m2(vint16m2_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vreinterpret_v)))
vint32m4_t vreinterpret_i32m4(vint16m4_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vreinterpret_v)))
vint32m8_t vreinterpret_i32m8(vint16m8_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vreinterpret_v)))
vint32mf2_t vreinterpret_i32mf2(vint16mf2_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vreinterpret_v)))
vint8m1_t vreinterpret_i8m1(vint16m1_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vreinterpret_v)))
vint8m2_t vreinterpret_i8m2(vint16m2_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vreinterpret_v)))
vint8m4_t vreinterpret_i8m4(vint16m4_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vreinterpret_v)))
vint8m8_t vreinterpret_i8m8(vint16m8_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vreinterpret_v)))
vint8mf2_t vreinterpret_i8mf2(vint16mf2_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vreinterpret_v)))
vint8mf4_t vreinterpret_i8mf4(vint16mf4_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vreinterpret_v)))
vint8m1_t vreinterpret_i8m1(vint32m1_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vreinterpret_v)))
vint8m2_t vreinterpret_i8m2(vint32m2_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vreinterpret_v)))
vint8m4_t vreinterpret_i8m4(vint32m4_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vreinterpret_v)))
vint8m8_t vreinterpret_i8m8(vint32m8_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vreinterpret_v)))
vint8mf2_t vreinterpret_i8mf2(vint32mf2_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vreinterpret_v)))
vint8m1_t vreinterpret_i8m1(vuint8m1_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vreinterpret_v)))
vint8m2_t vreinterpret_i8m2(vuint8m2_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vreinterpret_v)))
vint8m4_t vreinterpret_i8m4(vuint8m4_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vreinterpret_v)))
vint8m8_t vreinterpret_i8m8(vuint8m8_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vreinterpret_v)))
vint8mf2_t vreinterpret_i8mf2(vuint8mf2_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vreinterpret_v)))
vint8mf4_t vreinterpret_i8mf4(vuint8mf4_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vreinterpret_v)))
vint8mf8_t vreinterpret_i8mf8(vuint8mf8_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vreinterpret_v)))
vint16m1_t vreinterpret_i16m1(vuint16m1_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vreinterpret_v)))
vint16m2_t vreinterpret_i16m2(vuint16m2_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vreinterpret_v)))
vint16m4_t vreinterpret_i16m4(vuint16m4_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vreinterpret_v)))
vint16m8_t vreinterpret_i16m8(vuint16m8_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vreinterpret_v)))
vint16mf2_t vreinterpret_i16mf2(vuint16mf2_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vreinterpret_v)))
vint16mf4_t vreinterpret_i16mf4(vuint16mf4_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vreinterpret_v)))
vint32m1_t vreinterpret_i32m1(vuint32m1_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vreinterpret_v)))
vint32m2_t vreinterpret_i32m2(vuint32m2_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vreinterpret_v)))
vint32m4_t vreinterpret_i32m4(vuint32m4_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vreinterpret_v)))
vint32m8_t vreinterpret_i32m8(vuint32m8_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vreinterpret_v)))
vint32mf2_t vreinterpret_i32mf2(vuint32mf2_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vreinterpret_v)))
vuint16m1_t vreinterpret_u16m1(vuint8m1_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vreinterpret_v)))
vuint16m2_t vreinterpret_u16m2(vuint8m2_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vreinterpret_v)))
vuint16m4_t vreinterpret_u16m4(vuint8m4_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vreinterpret_v)))
vuint16m8_t vreinterpret_u16m8(vuint8m8_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vreinterpret_v)))
vuint16mf2_t vreinterpret_u16mf2(vuint8mf2_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vreinterpret_v)))
vuint16mf4_t vreinterpret_u16mf4(vuint8mf4_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vreinterpret_v)))
vuint16m1_t vreinterpret_u16m1(vuint32m1_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vreinterpret_v)))
vuint16m2_t vreinterpret_u16m2(vuint32m2_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vreinterpret_v)))
vuint16m4_t vreinterpret_u16m4(vuint32m4_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vreinterpret_v)))
vuint16m8_t vreinterpret_u16m8(vuint32m8_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vreinterpret_v)))
vuint16mf2_t vreinterpret_u16mf2(vuint32mf2_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vreinterpret_v)))
vuint32m1_t vreinterpret_u32m1(vuint8m1_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vreinterpret_v)))
vuint32m2_t vreinterpret_u32m2(vuint8m2_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vreinterpret_v)))
vuint32m4_t vreinterpret_u32m4(vuint8m4_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vreinterpret_v)))
vuint32m8_t vreinterpret_u32m8(vuint8m8_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vreinterpret_v)))
vuint32mf2_t vreinterpret_u32mf2(vuint8mf2_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vreinterpret_v)))
vuint32m1_t vreinterpret_u32m1(vuint16m1_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vreinterpret_v)))
vuint32m2_t vreinterpret_u32m2(vuint16m2_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vreinterpret_v)))
vuint32m4_t vreinterpret_u32m4(vuint16m4_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vreinterpret_v)))
vuint32m8_t vreinterpret_u32m8(vuint16m8_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vreinterpret_v)))
vuint32mf2_t vreinterpret_u32mf2(vuint16mf2_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vreinterpret_v)))
vuint8m1_t vreinterpret_u8m1(vuint16m1_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vreinterpret_v)))
vuint8m2_t vreinterpret_u8m2(vuint16m2_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vreinterpret_v)))
vuint8m4_t vreinterpret_u8m4(vuint16m4_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vreinterpret_v)))
vuint8m8_t vreinterpret_u8m8(vuint16m8_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vreinterpret_v)))
vuint8mf2_t vreinterpret_u8mf2(vuint16mf2_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vreinterpret_v)))
vuint8mf4_t vreinterpret_u8mf4(vuint16mf4_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vreinterpret_v)))
vuint8m1_t vreinterpret_u8m1(vuint32m1_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vreinterpret_v)))
vuint8m2_t vreinterpret_u8m2(vuint32m2_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vreinterpret_v)))
vuint8m4_t vreinterpret_u8m4(vuint32m4_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vreinterpret_v)))
vuint8m8_t vreinterpret_u8m8(vuint32m8_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vreinterpret_v)))
vuint8mf2_t vreinterpret_u8mf2(vuint32mf2_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vreinterpret_v)))
vuint8m1_t vreinterpret_u8m1(vint8m1_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vreinterpret_v)))
vuint8m2_t vreinterpret_u8m2(vint8m2_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vreinterpret_v)))
vuint8m4_t vreinterpret_u8m4(vint8m4_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vreinterpret_v)))
vuint8m8_t vreinterpret_u8m8(vint8m8_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vreinterpret_v)))
vuint8mf2_t vreinterpret_u8mf2(vint8mf2_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vreinterpret_v)))
vuint8mf4_t vreinterpret_u8mf4(vint8mf4_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vreinterpret_v)))
vuint8mf8_t vreinterpret_u8mf8(vint8mf8_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vreinterpret_v)))
vuint16m1_t vreinterpret_u16m1(vint16m1_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vreinterpret_v)))
vuint16m2_t vreinterpret_u16m2(vint16m2_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vreinterpret_v)))
vuint16m4_t vreinterpret_u16m4(vint16m4_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vreinterpret_v)))
vuint16m8_t vreinterpret_u16m8(vint16m8_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vreinterpret_v)))
vuint16mf2_t vreinterpret_u16mf2(vint16mf2_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vreinterpret_v)))
vuint16mf4_t vreinterpret_u16mf4(vint16mf4_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vreinterpret_v)))
vuint32m1_t vreinterpret_u32m1(vint32m1_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vreinterpret_v)))
vuint32m2_t vreinterpret_u32m2(vint32m2_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vreinterpret_v)))
vuint32m4_t vreinterpret_u32m4(vint32m4_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vreinterpret_v)))
vuint32m8_t vreinterpret_u32m8(vint32m8_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vreinterpret_v)))
vuint32mf2_t vreinterpret_u32mf2(vint32mf2_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vsext_vf2)))
vint16mf4_t vsext_vf2(vint8mf8_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vsext_vf2_m)))
vint16mf4_t vsext_vf2(vbool64_t, vint16mf4_t, vint8mf8_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vsext_vf2)))
vint16mf2_t vsext_vf2(vint8mf4_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vsext_vf2_m)))
vint16mf2_t vsext_vf2(vbool32_t, vint16mf2_t, vint8mf4_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vsext_vf2)))
vint16m1_t vsext_vf2(vint8mf2_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vsext_vf2_m)))
vint16m1_t vsext_vf2(vbool16_t, vint16m1_t, vint8mf2_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vsext_vf2)))
vint16m2_t vsext_vf2(vint8m1_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vsext_vf2_m)))
vint16m2_t vsext_vf2(vbool8_t, vint16m2_t, vint8m1_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vsext_vf2)))
vint16m4_t vsext_vf2(vint8m2_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vsext_vf2_m)))
vint16m4_t vsext_vf2(vbool4_t, vint16m4_t, vint8m2_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vsext_vf2)))
vint16m8_t vsext_vf2(vint8m4_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vsext_vf2_m)))
vint16m8_t vsext_vf2(vbool2_t, vint16m8_t, vint8m4_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vsext_vf2)))
vint32mf2_t vsext_vf2(vint16mf4_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vsext_vf2_m)))
vint32mf2_t vsext_vf2(vbool64_t, vint32mf2_t, vint16mf4_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vsext_vf2)))
vint32m1_t vsext_vf2(vint16mf2_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vsext_vf2_m)))
vint32m1_t vsext_vf2(vbool32_t, vint32m1_t, vint16mf2_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vsext_vf2)))
vint32m2_t vsext_vf2(vint16m1_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vsext_vf2_m)))
vint32m2_t vsext_vf2(vbool16_t, vint32m2_t, vint16m1_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vsext_vf2)))
vint32m4_t vsext_vf2(vint16m2_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vsext_vf2_m)))
vint32m4_t vsext_vf2(vbool8_t, vint32m4_t, vint16m2_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vsext_vf2)))
vint32m8_t vsext_vf2(vint16m4_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vsext_vf2_m)))
vint32m8_t vsext_vf2(vbool4_t, vint32m8_t, vint16m4_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vsext_vf4)))
vint32mf2_t vsext_vf4(vint8mf8_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vsext_vf4_m)))
vint32mf2_t vsext_vf4(vbool64_t, vint32mf2_t, vint8mf8_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vsext_vf4)))
vint32m1_t vsext_vf4(vint8mf4_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vsext_vf4_m)))
vint32m1_t vsext_vf4(vbool32_t, vint32m1_t, vint8mf4_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vsext_vf4)))
vint32m2_t vsext_vf4(vint8mf2_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vsext_vf4_m)))
vint32m2_t vsext_vf4(vbool16_t, vint32m2_t, vint8mf2_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vsext_vf4)))
vint32m4_t vsext_vf4(vint8m1_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vsext_vf4_m)))
vint32m4_t vsext_vf4(vbool8_t, vint32m4_t, vint8m1_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vsext_vf4)))
vint32m8_t vsext_vf4(vint8m2_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vsext_vf4_m)))
vint32m8_t vsext_vf4(vbool4_t, vint32m8_t, vint8m2_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vsm_v)))
void vsm(uint8_t *, vbool8_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vsm_v)))
void vsm(uint8_t *, vbool4_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vsm_v)))
void vsm(uint8_t *, vbool2_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vsm_v)))
void vsm(uint8_t *, vbool1_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vsm_v)))
void vsm(uint8_t *, vbool16_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vsm_v)))
void vsm(uint8_t *, vbool32_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vsm_v)))
void vsm(uint8_t *, vbool64_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vzext_vf2)))
vuint16mf4_t vzext_vf2(vuint8mf8_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vzext_vf2_m)))
vuint16mf4_t vzext_vf2(vbool64_t, vuint16mf4_t, vuint8mf8_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vzext_vf2)))
vuint16mf2_t vzext_vf2(vuint8mf4_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vzext_vf2_m)))
vuint16mf2_t vzext_vf2(vbool32_t, vuint16mf2_t, vuint8mf4_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vzext_vf2)))
vuint16m1_t vzext_vf2(vuint8mf2_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vzext_vf2_m)))
vuint16m1_t vzext_vf2(vbool16_t, vuint16m1_t, vuint8mf2_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vzext_vf2)))
vuint16m2_t vzext_vf2(vuint8m1_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vzext_vf2_m)))
vuint16m2_t vzext_vf2(vbool8_t, vuint16m2_t, vuint8m1_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vzext_vf2)))
vuint16m4_t vzext_vf2(vuint8m2_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vzext_vf2_m)))
vuint16m4_t vzext_vf2(vbool4_t, vuint16m4_t, vuint8m2_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vzext_vf2)))
vuint16m8_t vzext_vf2(vuint8m4_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vzext_vf2_m)))
vuint16m8_t vzext_vf2(vbool2_t, vuint16m8_t, vuint8m4_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vzext_vf2)))
vuint32mf2_t vzext_vf2(vuint16mf4_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vzext_vf2_m)))
vuint32mf2_t vzext_vf2(vbool64_t, vuint32mf2_t, vuint16mf4_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vzext_vf2)))
vuint32m1_t vzext_vf2(vuint16mf2_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vzext_vf2_m)))
vuint32m1_t vzext_vf2(vbool32_t, vuint32m1_t, vuint16mf2_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vzext_vf2)))
vuint32m2_t vzext_vf2(vuint16m1_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vzext_vf2_m)))
vuint32m2_t vzext_vf2(vbool16_t, vuint32m2_t, vuint16m1_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vzext_vf2)))
vuint32m4_t vzext_vf2(vuint16m2_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vzext_vf2_m)))
vuint32m4_t vzext_vf2(vbool8_t, vuint32m4_t, vuint16m2_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vzext_vf2)))
vuint32m8_t vzext_vf2(vuint16m4_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vzext_vf2_m)))
vuint32m8_t vzext_vf2(vbool4_t, vuint32m8_t, vuint16m4_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vzext_vf4)))
vuint32mf2_t vzext_vf4(vuint8mf8_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vzext_vf4_m)))
vuint32mf2_t vzext_vf4(vbool64_t, vuint32mf2_t, vuint8mf8_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vzext_vf4)))
vuint32m1_t vzext_vf4(vuint8mf4_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vzext_vf4_m)))
vuint32m1_t vzext_vf4(vbool32_t, vuint32m1_t, vuint8mf4_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vzext_vf4)))
vuint32m2_t vzext_vf4(vuint8mf2_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vzext_vf4_m)))
vuint32m2_t vzext_vf4(vbool16_t, vuint32m2_t, vuint8mf2_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vzext_vf4)))
vuint32m4_t vzext_vf4(vuint8m1_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vzext_vf4_m)))
vuint32m4_t vzext_vf4(vbool8_t, vuint32m4_t, vuint8m1_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vzext_vf4)))
vuint32m8_t vzext_vf4(vuint8m2_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vzext_vf4_m)))
vuint32m8_t vzext_vf4(vbool4_t, vuint32m8_t, vuint8m2_t, size_t);
#if defined(__riscv_zfh)
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vloxseg2ei8_v)))
void vloxseg2ei8(vfloat16m1_t *, vfloat16m1_t *, const _Float16 *, vuint8mf2_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vloxseg2ei8_v_m)))
void vloxseg2ei8(vfloat16m1_t *, vfloat16m1_t *, vbool16_t, vfloat16m1_t, vfloat16m1_t, const _Float16 *, vuint8mf2_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vloxseg2ei8_v)))
void vloxseg2ei8(vfloat16m2_t *, vfloat16m2_t *, const _Float16 *, vuint8m1_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vloxseg2ei8_v_m)))
void vloxseg2ei8(vfloat16m2_t *, vfloat16m2_t *, vbool8_t, vfloat16m2_t, vfloat16m2_t, const _Float16 *, vuint8m1_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vloxseg2ei8_v)))
void vloxseg2ei8(vfloat16m4_t *, vfloat16m4_t *, const _Float16 *, vuint8m2_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vloxseg2ei8_v_m)))
void vloxseg2ei8(vfloat16m4_t *, vfloat16m4_t *, vbool4_t, vfloat16m4_t, vfloat16m4_t, const _Float16 *, vuint8m2_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vloxseg2ei8_v)))
void vloxseg2ei8(vfloat16mf2_t *, vfloat16mf2_t *, const _Float16 *, vuint8mf4_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vloxseg2ei8_v_m)))
void vloxseg2ei8(vfloat16mf2_t *, vfloat16mf2_t *, vbool32_t, vfloat16mf2_t, vfloat16mf2_t, const _Float16 *, vuint8mf4_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vloxseg2ei8_v)))
void vloxseg2ei8(vfloat16mf4_t *, vfloat16mf4_t *, const _Float16 *, vuint8mf8_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vloxseg2ei8_v_m)))
void vloxseg2ei8(vfloat16mf4_t *, vfloat16mf4_t *, vbool64_t, vfloat16mf4_t, vfloat16mf4_t, const _Float16 *, vuint8mf8_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vloxseg3ei8_v)))
void vloxseg3ei8(vfloat16m1_t *, vfloat16m1_t *, vfloat16m1_t *, const _Float16 *, vuint8mf2_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vloxseg3ei8_v_m)))
void vloxseg3ei8(vfloat16m1_t *, vfloat16m1_t *, vfloat16m1_t *, vbool16_t, vfloat16m1_t, vfloat16m1_t, vfloat16m1_t, const _Float16 *, vuint8mf2_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vloxseg3ei8_v)))
void vloxseg3ei8(vfloat16m2_t *, vfloat16m2_t *, vfloat16m2_t *, const _Float16 *, vuint8m1_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vloxseg3ei8_v_m)))
void vloxseg3ei8(vfloat16m2_t *, vfloat16m2_t *, vfloat16m2_t *, vbool8_t, vfloat16m2_t, vfloat16m2_t, vfloat16m2_t, const _Float16 *, vuint8m1_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vloxseg3ei8_v)))
void vloxseg3ei8(vfloat16mf2_t *, vfloat16mf2_t *, vfloat16mf2_t *, const _Float16 *, vuint8mf4_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vloxseg3ei8_v_m)))
void vloxseg3ei8(vfloat16mf2_t *, vfloat16mf2_t *, vfloat16mf2_t *, vbool32_t, vfloat16mf2_t, vfloat16mf2_t, vfloat16mf2_t, const _Float16 *, vuint8mf4_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vloxseg3ei8_v)))
void vloxseg3ei8(vfloat16mf4_t *, vfloat16mf4_t *, vfloat16mf4_t *, const _Float16 *, vuint8mf8_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vloxseg3ei8_v_m)))
void vloxseg3ei8(vfloat16mf4_t *, vfloat16mf4_t *, vfloat16mf4_t *, vbool64_t, vfloat16mf4_t, vfloat16mf4_t, vfloat16mf4_t, const _Float16 *, vuint8mf8_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vloxseg4ei8_v)))
void vloxseg4ei8(vfloat16m1_t *, vfloat16m1_t *, vfloat16m1_t *, vfloat16m1_t *, const _Float16 *, vuint8mf2_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vloxseg4ei8_v_m)))
void vloxseg4ei8(vfloat16m1_t *, vfloat16m1_t *, vfloat16m1_t *, vfloat16m1_t *, vbool16_t, vfloat16m1_t, vfloat16m1_t, vfloat16m1_t, vfloat16m1_t, const _Float16 *, vuint8mf2_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vloxseg4ei8_v)))
void vloxseg4ei8(vfloat16m2_t *, vfloat16m2_t *, vfloat16m2_t *, vfloat16m2_t *, const _Float16 *, vuint8m1_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vloxseg4ei8_v_m)))
void vloxseg4ei8(vfloat16m2_t *, vfloat16m2_t *, vfloat16m2_t *, vfloat16m2_t *, vbool8_t, vfloat16m2_t, vfloat16m2_t, vfloat16m2_t, vfloat16m2_t, const _Float16 *, vuint8m1_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vloxseg4ei8_v)))
void vloxseg4ei8(vfloat16mf2_t *, vfloat16mf2_t *, vfloat16mf2_t *, vfloat16mf2_t *, const _Float16 *, vuint8mf4_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vloxseg4ei8_v_m)))
void vloxseg4ei8(vfloat16mf2_t *, vfloat16mf2_t *, vfloat16mf2_t *, vfloat16mf2_t *, vbool32_t, vfloat16mf2_t, vfloat16mf2_t, vfloat16mf2_t, vfloat16mf2_t, const _Float16 *, vuint8mf4_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vloxseg4ei8_v)))
void vloxseg4ei8(vfloat16mf4_t *, vfloat16mf4_t *, vfloat16mf4_t *, vfloat16mf4_t *, const _Float16 *, vuint8mf8_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vloxseg4ei8_v_m)))
void vloxseg4ei8(vfloat16mf4_t *, vfloat16mf4_t *, vfloat16mf4_t *, vfloat16mf4_t *, vbool64_t, vfloat16mf4_t, vfloat16mf4_t, vfloat16mf4_t, vfloat16mf4_t, const _Float16 *, vuint8mf8_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vloxseg5ei8_v)))
void vloxseg5ei8(vfloat16m1_t *, vfloat16m1_t *, vfloat16m1_t *, vfloat16m1_t *, vfloat16m1_t *, const _Float16 *, vuint8mf2_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vloxseg5ei8_v_m)))
void vloxseg5ei8(vfloat16m1_t *, vfloat16m1_t *, vfloat16m1_t *, vfloat16m1_t *, vfloat16m1_t *, vbool16_t, vfloat16m1_t, vfloat16m1_t, vfloat16m1_t, vfloat16m1_t, vfloat16m1_t, const _Float16 *, vuint8mf2_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vloxseg5ei8_v)))
void vloxseg5ei8(vfloat16mf2_t *, vfloat16mf2_t *, vfloat16mf2_t *, vfloat16mf2_t *, vfloat16mf2_t *, const _Float16 *, vuint8mf4_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vloxseg5ei8_v_m)))
void vloxseg5ei8(vfloat16mf2_t *, vfloat16mf2_t *, vfloat16mf2_t *, vfloat16mf2_t *, vfloat16mf2_t *, vbool32_t, vfloat16mf2_t, vfloat16mf2_t, vfloat16mf2_t, vfloat16mf2_t, vfloat16mf2_t, const _Float16 *, vuint8mf4_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vloxseg5ei8_v)))
void vloxseg5ei8(vfloat16mf4_t *, vfloat16mf4_t *, vfloat16mf4_t *, vfloat16mf4_t *, vfloat16mf4_t *, const _Float16 *, vuint8mf8_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vloxseg5ei8_v_m)))
void vloxseg5ei8(vfloat16mf4_t *, vfloat16mf4_t *, vfloat16mf4_t *, vfloat16mf4_t *, vfloat16mf4_t *, vbool64_t, vfloat16mf4_t, vfloat16mf4_t, vfloat16mf4_t, vfloat16mf4_t, vfloat16mf4_t, const _Float16 *, vuint8mf8_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vloxseg6ei8_v)))
void vloxseg6ei8(vfloat16m1_t *, vfloat16m1_t *, vfloat16m1_t *, vfloat16m1_t *, vfloat16m1_t *, vfloat16m1_t *, const _Float16 *, vuint8mf2_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vloxseg6ei8_v_m)))
void vloxseg6ei8(vfloat16m1_t *, vfloat16m1_t *, vfloat16m1_t *, vfloat16m1_t *, vfloat16m1_t *, vfloat16m1_t *, vbool16_t, vfloat16m1_t, vfloat16m1_t, vfloat16m1_t, vfloat16m1_t, vfloat16m1_t, vfloat16m1_t, const _Float16 *, vuint8mf2_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vloxseg6ei8_v)))
void vloxseg6ei8(vfloat16mf2_t *, vfloat16mf2_t *, vfloat16mf2_t *, vfloat16mf2_t *, vfloat16mf2_t *, vfloat16mf2_t *, const _Float16 *, vuint8mf4_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vloxseg6ei8_v_m)))
void vloxseg6ei8(vfloat16mf2_t *, vfloat16mf2_t *, vfloat16mf2_t *, vfloat16mf2_t *, vfloat16mf2_t *, vfloat16mf2_t *, vbool32_t, vfloat16mf2_t, vfloat16mf2_t, vfloat16mf2_t, vfloat16mf2_t, vfloat16mf2_t, vfloat16mf2_t, const _Float16 *, vuint8mf4_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vloxseg6ei8_v)))
void vloxseg6ei8(vfloat16mf4_t *, vfloat16mf4_t *, vfloat16mf4_t *, vfloat16mf4_t *, vfloat16mf4_t *, vfloat16mf4_t *, const _Float16 *, vuint8mf8_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vloxseg6ei8_v_m)))
void vloxseg6ei8(vfloat16mf4_t *, vfloat16mf4_t *, vfloat16mf4_t *, vfloat16mf4_t *, vfloat16mf4_t *, vfloat16mf4_t *, vbool64_t, vfloat16mf4_t, vfloat16mf4_t, vfloat16mf4_t, vfloat16mf4_t, vfloat16mf4_t, vfloat16mf4_t, const _Float16 *, vuint8mf8_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vloxseg7ei8_v)))
void vloxseg7ei8(vfloat16m1_t *, vfloat16m1_t *, vfloat16m1_t *, vfloat16m1_t *, vfloat16m1_t *, vfloat16m1_t *, vfloat16m1_t *, const _Float16 *, vuint8mf2_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vloxseg7ei8_v_m)))
void vloxseg7ei8(vfloat16m1_t *, vfloat16m1_t *, vfloat16m1_t *, vfloat16m1_t *, vfloat16m1_t *, vfloat16m1_t *, vfloat16m1_t *, vbool16_t, vfloat16m1_t, vfloat16m1_t, vfloat16m1_t, vfloat16m1_t, vfloat16m1_t, vfloat16m1_t, vfloat16m1_t, const _Float16 *, vuint8mf2_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vloxseg7ei8_v)))
void vloxseg7ei8(vfloat16mf2_t *, vfloat16mf2_t *, vfloat16mf2_t *, vfloat16mf2_t *, vfloat16mf2_t *, vfloat16mf2_t *, vfloat16mf2_t *, const _Float16 *, vuint8mf4_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vloxseg7ei8_v_m)))
void vloxseg7ei8(vfloat16mf2_t *, vfloat16mf2_t *, vfloat16mf2_t *, vfloat16mf2_t *, vfloat16mf2_t *, vfloat16mf2_t *, vfloat16mf2_t *, vbool32_t, vfloat16mf2_t, vfloat16mf2_t, vfloat16mf2_t, vfloat16mf2_t, vfloat16mf2_t, vfloat16mf2_t, vfloat16mf2_t, const _Float16 *, vuint8mf4_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vloxseg7ei8_v)))
void vloxseg7ei8(vfloat16mf4_t *, vfloat16mf4_t *, vfloat16mf4_t *, vfloat16mf4_t *, vfloat16mf4_t *, vfloat16mf4_t *, vfloat16mf4_t *, const _Float16 *, vuint8mf8_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vloxseg7ei8_v_m)))
void vloxseg7ei8(vfloat16mf4_t *, vfloat16mf4_t *, vfloat16mf4_t *, vfloat16mf4_t *, vfloat16mf4_t *, vfloat16mf4_t *, vfloat16mf4_t *, vbool64_t, vfloat16mf4_t, vfloat16mf4_t, vfloat16mf4_t, vfloat16mf4_t, vfloat16mf4_t, vfloat16mf4_t, vfloat16mf4_t, const _Float16 *, vuint8mf8_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vsse16_v)))
void vsse16(_Float16 *, ptrdiff_t, vfloat16m1_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vsse16_v_m)))
void vsse16(vbool16_t, _Float16 *, ptrdiff_t, vfloat16m1_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vsse16_v)))
void vsse16(_Float16 *, ptrdiff_t, vfloat16m2_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vsse16_v_m)))
void vsse16(vbool8_t, _Float16 *, ptrdiff_t, vfloat16m2_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vsse16_v)))
void vsse16(_Float16 *, ptrdiff_t, vfloat16m4_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vsse16_v_m)))
void vsse16(vbool4_t, _Float16 *, ptrdiff_t, vfloat16m4_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vsse16_v)))
void vsse16(_Float16 *, ptrdiff_t, vfloat16m8_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vsse16_v_m)))
void vsse16(vbool2_t, _Float16 *, ptrdiff_t, vfloat16m8_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vsse16_v)))
void vsse16(_Float16 *, ptrdiff_t, vfloat16mf2_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vsse16_v_m)))
void vsse16(vbool32_t, _Float16 *, ptrdiff_t, vfloat16mf2_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vsse16_v)))
void vsse16(_Float16 *, ptrdiff_t, vfloat16mf4_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vsse16_v_m)))
void vsse16(vbool64_t, _Float16 *, ptrdiff_t, vfloat16mf4_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vloxseg8ei8_v)))
void vloxseg8ei8(vfloat16m1_t *, vfloat16m1_t *, vfloat16m1_t *, vfloat16m1_t *, vfloat16m1_t *, vfloat16m1_t *, vfloat16m1_t *, vfloat16m1_t *, const _Float16 *, vuint8mf2_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vloxseg8ei8_v_m)))
void vloxseg8ei8(vfloat16m1_t *, vfloat16m1_t *, vfloat16m1_t *, vfloat16m1_t *, vfloat16m1_t *, vfloat16m1_t *, vfloat16m1_t *, vfloat16m1_t *, vbool16_t, vfloat16m1_t, vfloat16m1_t, vfloat16m1_t, vfloat16m1_t, vfloat16m1_t, vfloat16m1_t, vfloat16m1_t, vfloat16m1_t, const _Float16 *, vuint8mf2_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vloxseg8ei8_v)))
void vloxseg8ei8(vfloat16mf2_t *, vfloat16mf2_t *, vfloat16mf2_t *, vfloat16mf2_t *, vfloat16mf2_t *, vfloat16mf2_t *, vfloat16mf2_t *, vfloat16mf2_t *, const _Float16 *, vuint8mf4_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vloxseg8ei8_v_m)))
void vloxseg8ei8(vfloat16mf2_t *, vfloat16mf2_t *, vfloat16mf2_t *, vfloat16mf2_t *, vfloat16mf2_t *, vfloat16mf2_t *, vfloat16mf2_t *, vfloat16mf2_t *, vbool32_t, vfloat16mf2_t, vfloat16mf2_t, vfloat16mf2_t, vfloat16mf2_t, vfloat16mf2_t, vfloat16mf2_t, vfloat16mf2_t, vfloat16mf2_t, const _Float16 *, vuint8mf4_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vloxseg8ei8_v)))
void vloxseg8ei8(vfloat16mf4_t *, vfloat16mf4_t *, vfloat16mf4_t *, vfloat16mf4_t *, vfloat16mf4_t *, vfloat16mf4_t *, vfloat16mf4_t *, vfloat16mf4_t *, const _Float16 *, vuint8mf8_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vloxseg8ei8_v_m)))
void vloxseg8ei8(vfloat16mf4_t *, vfloat16mf4_t *, vfloat16mf4_t *, vfloat16mf4_t *, vfloat16mf4_t *, vfloat16mf4_t *, vfloat16mf4_t *, vfloat16mf4_t *, vbool64_t, vfloat16mf4_t, vfloat16mf4_t, vfloat16mf4_t, vfloat16mf4_t, vfloat16mf4_t, vfloat16mf4_t, vfloat16mf4_t, vfloat16mf4_t, const _Float16 *, vuint8mf8_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vloxseg2ei16_v)))
void vloxseg2ei16(vfloat16m1_t *, vfloat16m1_t *, const _Float16 *, vuint16m1_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vloxseg2ei16_v_m)))
void vloxseg2ei16(vfloat16m1_t *, vfloat16m1_t *, vbool16_t, vfloat16m1_t, vfloat16m1_t, const _Float16 *, vuint16m1_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vloxseg2ei16_v)))
void vloxseg2ei16(vfloat16m2_t *, vfloat16m2_t *, const _Float16 *, vuint16m2_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vloxseg2ei16_v_m)))
void vloxseg2ei16(vfloat16m2_t *, vfloat16m2_t *, vbool8_t, vfloat16m2_t, vfloat16m2_t, const _Float16 *, vuint16m2_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vloxseg2ei16_v)))
void vloxseg2ei16(vfloat16m4_t *, vfloat16m4_t *, const _Float16 *, vuint16m4_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vloxseg2ei16_v_m)))
void vloxseg2ei16(vfloat16m4_t *, vfloat16m4_t *, vbool4_t, vfloat16m4_t, vfloat16m4_t, const _Float16 *, vuint16m4_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vloxseg2ei16_v)))
void vloxseg2ei16(vfloat16mf2_t *, vfloat16mf2_t *, const _Float16 *, vuint16mf2_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vloxseg2ei16_v_m)))
void vloxseg2ei16(vfloat16mf2_t *, vfloat16mf2_t *, vbool32_t, vfloat16mf2_t, vfloat16mf2_t, const _Float16 *, vuint16mf2_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vloxseg2ei16_v)))
void vloxseg2ei16(vfloat16mf4_t *, vfloat16mf4_t *, const _Float16 *, vuint16mf4_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vloxseg2ei16_v_m)))
void vloxseg2ei16(vfloat16mf4_t *, vfloat16mf4_t *, vbool64_t, vfloat16mf4_t, vfloat16mf4_t, const _Float16 *, vuint16mf4_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vloxseg3ei16_v)))
void vloxseg3ei16(vfloat16m1_t *, vfloat16m1_t *, vfloat16m1_t *, const _Float16 *, vuint16m1_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vloxseg3ei16_v_m)))
void vloxseg3ei16(vfloat16m1_t *, vfloat16m1_t *, vfloat16m1_t *, vbool16_t, vfloat16m1_t, vfloat16m1_t, vfloat16m1_t, const _Float16 *, vuint16m1_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vloxseg3ei16_v)))
void vloxseg3ei16(vfloat16m2_t *, vfloat16m2_t *, vfloat16m2_t *, const _Float16 *, vuint16m2_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vloxseg3ei16_v_m)))
void vloxseg3ei16(vfloat16m2_t *, vfloat16m2_t *, vfloat16m2_t *, vbool8_t, vfloat16m2_t, vfloat16m2_t, vfloat16m2_t, const _Float16 *, vuint16m2_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vloxseg3ei16_v)))
void vloxseg3ei16(vfloat16mf2_t *, vfloat16mf2_t *, vfloat16mf2_t *, const _Float16 *, vuint16mf2_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vloxseg3ei16_v_m)))
void vloxseg3ei16(vfloat16mf2_t *, vfloat16mf2_t *, vfloat16mf2_t *, vbool32_t, vfloat16mf2_t, vfloat16mf2_t, vfloat16mf2_t, const _Float16 *, vuint16mf2_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vloxseg3ei16_v)))
void vloxseg3ei16(vfloat16mf4_t *, vfloat16mf4_t *, vfloat16mf4_t *, const _Float16 *, vuint16mf4_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vloxseg3ei16_v_m)))
void vloxseg3ei16(vfloat16mf4_t *, vfloat16mf4_t *, vfloat16mf4_t *, vbool64_t, vfloat16mf4_t, vfloat16mf4_t, vfloat16mf4_t, const _Float16 *, vuint16mf4_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vloxseg4ei16_v)))
void vloxseg4ei16(vfloat16m1_t *, vfloat16m1_t *, vfloat16m1_t *, vfloat16m1_t *, const _Float16 *, vuint16m1_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vloxseg4ei16_v_m)))
void vloxseg4ei16(vfloat16m1_t *, vfloat16m1_t *, vfloat16m1_t *, vfloat16m1_t *, vbool16_t, vfloat16m1_t, vfloat16m1_t, vfloat16m1_t, vfloat16m1_t, const _Float16 *, vuint16m1_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vloxseg4ei16_v)))
void vloxseg4ei16(vfloat16m2_t *, vfloat16m2_t *, vfloat16m2_t *, vfloat16m2_t *, const _Float16 *, vuint16m2_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vloxseg4ei16_v_m)))
void vloxseg4ei16(vfloat16m2_t *, vfloat16m2_t *, vfloat16m2_t *, vfloat16m2_t *, vbool8_t, vfloat16m2_t, vfloat16m2_t, vfloat16m2_t, vfloat16m2_t, const _Float16 *, vuint16m2_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vloxseg4ei16_v)))
void vloxseg4ei16(vfloat16mf2_t *, vfloat16mf2_t *, vfloat16mf2_t *, vfloat16mf2_t *, const _Float16 *, vuint16mf2_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vloxseg4ei16_v_m)))
void vloxseg4ei16(vfloat16mf2_t *, vfloat16mf2_t *, vfloat16mf2_t *, vfloat16mf2_t *, vbool32_t, vfloat16mf2_t, vfloat16mf2_t, vfloat16mf2_t, vfloat16mf2_t, const _Float16 *, vuint16mf2_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vloxseg4ei16_v)))
void vloxseg4ei16(vfloat16mf4_t *, vfloat16mf4_t *, vfloat16mf4_t *, vfloat16mf4_t *, const _Float16 *, vuint16mf4_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vloxseg4ei16_v_m)))
void vloxseg4ei16(vfloat16mf4_t *, vfloat16mf4_t *, vfloat16mf4_t *, vfloat16mf4_t *, vbool64_t, vfloat16mf4_t, vfloat16mf4_t, vfloat16mf4_t, vfloat16mf4_t, const _Float16 *, vuint16mf4_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vloxseg5ei16_v)))
void vloxseg5ei16(vfloat16m1_t *, vfloat16m1_t *, vfloat16m1_t *, vfloat16m1_t *, vfloat16m1_t *, const _Float16 *, vuint16m1_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vloxseg5ei16_v_m)))
void vloxseg5ei16(vfloat16m1_t *, vfloat16m1_t *, vfloat16m1_t *, vfloat16m1_t *, vfloat16m1_t *, vbool16_t, vfloat16m1_t, vfloat16m1_t, vfloat16m1_t, vfloat16m1_t, vfloat16m1_t, const _Float16 *, vuint16m1_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vloxseg5ei16_v)))
void vloxseg5ei16(vfloat16mf2_t *, vfloat16mf2_t *, vfloat16mf2_t *, vfloat16mf2_t *, vfloat16mf2_t *, const _Float16 *, vuint16mf2_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vloxseg5ei16_v_m)))
void vloxseg5ei16(vfloat16mf2_t *, vfloat16mf2_t *, vfloat16mf2_t *, vfloat16mf2_t *, vfloat16mf2_t *, vbool32_t, vfloat16mf2_t, vfloat16mf2_t, vfloat16mf2_t, vfloat16mf2_t, vfloat16mf2_t, const _Float16 *, vuint16mf2_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vloxseg5ei16_v)))
void vloxseg5ei16(vfloat16mf4_t *, vfloat16mf4_t *, vfloat16mf4_t *, vfloat16mf4_t *, vfloat16mf4_t *, const _Float16 *, vuint16mf4_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vloxseg5ei16_v_m)))
void vloxseg5ei16(vfloat16mf4_t *, vfloat16mf4_t *, vfloat16mf4_t *, vfloat16mf4_t *, vfloat16mf4_t *, vbool64_t, vfloat16mf4_t, vfloat16mf4_t, vfloat16mf4_t, vfloat16mf4_t, vfloat16mf4_t, const _Float16 *, vuint16mf4_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vloxseg6ei16_v)))
void vloxseg6ei16(vfloat16m1_t *, vfloat16m1_t *, vfloat16m1_t *, vfloat16m1_t *, vfloat16m1_t *, vfloat16m1_t *, const _Float16 *, vuint16m1_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vloxseg6ei16_v_m)))
void vloxseg6ei16(vfloat16m1_t *, vfloat16m1_t *, vfloat16m1_t *, vfloat16m1_t *, vfloat16m1_t *, vfloat16m1_t *, vbool16_t, vfloat16m1_t, vfloat16m1_t, vfloat16m1_t, vfloat16m1_t, vfloat16m1_t, vfloat16m1_t, const _Float16 *, vuint16m1_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vloxseg6ei16_v)))
void vloxseg6ei16(vfloat16mf2_t *, vfloat16mf2_t *, vfloat16mf2_t *, vfloat16mf2_t *, vfloat16mf2_t *, vfloat16mf2_t *, const _Float16 *, vuint16mf2_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vloxseg6ei16_v_m)))
void vloxseg6ei16(vfloat16mf2_t *, vfloat16mf2_t *, vfloat16mf2_t *, vfloat16mf2_t *, vfloat16mf2_t *, vfloat16mf2_t *, vbool32_t, vfloat16mf2_t, vfloat16mf2_t, vfloat16mf2_t, vfloat16mf2_t, vfloat16mf2_t, vfloat16mf2_t, const _Float16 *, vuint16mf2_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vloxseg6ei16_v)))
void vloxseg6ei16(vfloat16mf4_t *, vfloat16mf4_t *, vfloat16mf4_t *, vfloat16mf4_t *, vfloat16mf4_t *, vfloat16mf4_t *, const _Float16 *, vuint16mf4_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vloxseg6ei16_v_m)))
void vloxseg6ei16(vfloat16mf4_t *, vfloat16mf4_t *, vfloat16mf4_t *, vfloat16mf4_t *, vfloat16mf4_t *, vfloat16mf4_t *, vbool64_t, vfloat16mf4_t, vfloat16mf4_t, vfloat16mf4_t, vfloat16mf4_t, vfloat16mf4_t, vfloat16mf4_t, const _Float16 *, vuint16mf4_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vloxseg7ei16_v)))
void vloxseg7ei16(vfloat16m1_t *, vfloat16m1_t *, vfloat16m1_t *, vfloat16m1_t *, vfloat16m1_t *, vfloat16m1_t *, vfloat16m1_t *, const _Float16 *, vuint16m1_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vloxseg7ei16_v_m)))
void vloxseg7ei16(vfloat16m1_t *, vfloat16m1_t *, vfloat16m1_t *, vfloat16m1_t *, vfloat16m1_t *, vfloat16m1_t *, vfloat16m1_t *, vbool16_t, vfloat16m1_t, vfloat16m1_t, vfloat16m1_t, vfloat16m1_t, vfloat16m1_t, vfloat16m1_t, vfloat16m1_t, const _Float16 *, vuint16m1_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vloxseg7ei16_v)))
void vloxseg7ei16(vfloat16mf2_t *, vfloat16mf2_t *, vfloat16mf2_t *, vfloat16mf2_t *, vfloat16mf2_t *, vfloat16mf2_t *, vfloat16mf2_t *, const _Float16 *, vuint16mf2_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vloxseg7ei16_v_m)))
void vloxseg7ei16(vfloat16mf2_t *, vfloat16mf2_t *, vfloat16mf2_t *, vfloat16mf2_t *, vfloat16mf2_t *, vfloat16mf2_t *, vfloat16mf2_t *, vbool32_t, vfloat16mf2_t, vfloat16mf2_t, vfloat16mf2_t, vfloat16mf2_t, vfloat16mf2_t, vfloat16mf2_t, vfloat16mf2_t, const _Float16 *, vuint16mf2_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vloxseg7ei16_v)))
void vloxseg7ei16(vfloat16mf4_t *, vfloat16mf4_t *, vfloat16mf4_t *, vfloat16mf4_t *, vfloat16mf4_t *, vfloat16mf4_t *, vfloat16mf4_t *, const _Float16 *, vuint16mf4_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vloxseg7ei16_v_m)))
void vloxseg7ei16(vfloat16mf4_t *, vfloat16mf4_t *, vfloat16mf4_t *, vfloat16mf4_t *, vfloat16mf4_t *, vfloat16mf4_t *, vfloat16mf4_t *, vbool64_t, vfloat16mf4_t, vfloat16mf4_t, vfloat16mf4_t, vfloat16mf4_t, vfloat16mf4_t, vfloat16mf4_t, vfloat16mf4_t, const _Float16 *, vuint16mf4_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vloxseg8ei16_v)))
void vloxseg8ei16(vfloat16m1_t *, vfloat16m1_t *, vfloat16m1_t *, vfloat16m1_t *, vfloat16m1_t *, vfloat16m1_t *, vfloat16m1_t *, vfloat16m1_t *, const _Float16 *, vuint16m1_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vloxseg8ei16_v_m)))
void vloxseg8ei16(vfloat16m1_t *, vfloat16m1_t *, vfloat16m1_t *, vfloat16m1_t *, vfloat16m1_t *, vfloat16m1_t *, vfloat16m1_t *, vfloat16m1_t *, vbool16_t, vfloat16m1_t, vfloat16m1_t, vfloat16m1_t, vfloat16m1_t, vfloat16m1_t, vfloat16m1_t, vfloat16m1_t, vfloat16m1_t, const _Float16 *, vuint16m1_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vloxseg8ei16_v)))
void vloxseg8ei16(vfloat16mf2_t *, vfloat16mf2_t *, vfloat16mf2_t *, vfloat16mf2_t *, vfloat16mf2_t *, vfloat16mf2_t *, vfloat16mf2_t *, vfloat16mf2_t *, const _Float16 *, vuint16mf2_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vloxseg8ei16_v_m)))
void vloxseg8ei16(vfloat16mf2_t *, vfloat16mf2_t *, vfloat16mf2_t *, vfloat16mf2_t *, vfloat16mf2_t *, vfloat16mf2_t *, vfloat16mf2_t *, vfloat16mf2_t *, vbool32_t, vfloat16mf2_t, vfloat16mf2_t, vfloat16mf2_t, vfloat16mf2_t, vfloat16mf2_t, vfloat16mf2_t, vfloat16mf2_t, vfloat16mf2_t, const _Float16 *, vuint16mf2_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vloxseg8ei16_v)))
void vloxseg8ei16(vfloat16mf4_t *, vfloat16mf4_t *, vfloat16mf4_t *, vfloat16mf4_t *, vfloat16mf4_t *, vfloat16mf4_t *, vfloat16mf4_t *, vfloat16mf4_t *, const _Float16 *, vuint16mf4_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vloxseg8ei16_v_m)))
void vloxseg8ei16(vfloat16mf4_t *, vfloat16mf4_t *, vfloat16mf4_t *, vfloat16mf4_t *, vfloat16mf4_t *, vfloat16mf4_t *, vfloat16mf4_t *, vfloat16mf4_t *, vbool64_t, vfloat16mf4_t, vfloat16mf4_t, vfloat16mf4_t, vfloat16mf4_t, vfloat16mf4_t, vfloat16mf4_t, vfloat16mf4_t, vfloat16mf4_t, const _Float16 *, vuint16mf4_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vloxseg2ei32_v)))
void vloxseg2ei32(vfloat16m1_t *, vfloat16m1_t *, const _Float16 *, vuint32m2_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vloxseg2ei32_v_m)))
void vloxseg2ei32(vfloat16m1_t *, vfloat16m1_t *, vbool16_t, vfloat16m1_t, vfloat16m1_t, const _Float16 *, vuint32m2_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vloxseg2ei32_v)))
void vloxseg2ei32(vfloat16m2_t *, vfloat16m2_t *, const _Float16 *, vuint32m4_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vloxseg2ei32_v_m)))
void vloxseg2ei32(vfloat16m2_t *, vfloat16m2_t *, vbool8_t, vfloat16m2_t, vfloat16m2_t, const _Float16 *, vuint32m4_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vloxseg2ei32_v)))
void vloxseg2ei32(vfloat16m4_t *, vfloat16m4_t *, const _Float16 *, vuint32m8_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vloxseg2ei32_v_m)))
void vloxseg2ei32(vfloat16m4_t *, vfloat16m4_t *, vbool4_t, vfloat16m4_t, vfloat16m4_t, const _Float16 *, vuint32m8_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vloxseg2ei32_v)))
void vloxseg2ei32(vfloat16mf2_t *, vfloat16mf2_t *, const _Float16 *, vuint32m1_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vloxseg2ei32_v_m)))
void vloxseg2ei32(vfloat16mf2_t *, vfloat16mf2_t *, vbool32_t, vfloat16mf2_t, vfloat16mf2_t, const _Float16 *, vuint32m1_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vloxseg2ei32_v)))
void vloxseg2ei32(vfloat16mf4_t *, vfloat16mf4_t *, const _Float16 *, vuint32mf2_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vloxseg2ei32_v_m)))
void vloxseg2ei32(vfloat16mf4_t *, vfloat16mf4_t *, vbool64_t, vfloat16mf4_t, vfloat16mf4_t, const _Float16 *, vuint32mf2_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vloxseg3ei32_v)))
void vloxseg3ei32(vfloat16m1_t *, vfloat16m1_t *, vfloat16m1_t *, const _Float16 *, vuint32m2_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vloxseg3ei32_v_m)))
void vloxseg3ei32(vfloat16m1_t *, vfloat16m1_t *, vfloat16m1_t *, vbool16_t, vfloat16m1_t, vfloat16m1_t, vfloat16m1_t, const _Float16 *, vuint32m2_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vloxseg3ei32_v)))
void vloxseg3ei32(vfloat16m2_t *, vfloat16m2_t *, vfloat16m2_t *, const _Float16 *, vuint32m4_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vloxseg3ei32_v_m)))
void vloxseg3ei32(vfloat16m2_t *, vfloat16m2_t *, vfloat16m2_t *, vbool8_t, vfloat16m2_t, vfloat16m2_t, vfloat16m2_t, const _Float16 *, vuint32m4_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vloxseg3ei32_v)))
void vloxseg3ei32(vfloat16mf2_t *, vfloat16mf2_t *, vfloat16mf2_t *, const _Float16 *, vuint32m1_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vloxseg3ei32_v_m)))
void vloxseg3ei32(vfloat16mf2_t *, vfloat16mf2_t *, vfloat16mf2_t *, vbool32_t, vfloat16mf2_t, vfloat16mf2_t, vfloat16mf2_t, const _Float16 *, vuint32m1_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vloxseg3ei32_v)))
void vloxseg3ei32(vfloat16mf4_t *, vfloat16mf4_t *, vfloat16mf4_t *, const _Float16 *, vuint32mf2_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vloxseg3ei32_v_m)))
void vloxseg3ei32(vfloat16mf4_t *, vfloat16mf4_t *, vfloat16mf4_t *, vbool64_t, vfloat16mf4_t, vfloat16mf4_t, vfloat16mf4_t, const _Float16 *, vuint32mf2_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vloxseg4ei32_v)))
void vloxseg4ei32(vfloat16m1_t *, vfloat16m1_t *, vfloat16m1_t *, vfloat16m1_t *, const _Float16 *, vuint32m2_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vloxseg4ei32_v_m)))
void vloxseg4ei32(vfloat16m1_t *, vfloat16m1_t *, vfloat16m1_t *, vfloat16m1_t *, vbool16_t, vfloat16m1_t, vfloat16m1_t, vfloat16m1_t, vfloat16m1_t, const _Float16 *, vuint32m2_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vloxseg4ei32_v)))
void vloxseg4ei32(vfloat16m2_t *, vfloat16m2_t *, vfloat16m2_t *, vfloat16m2_t *, const _Float16 *, vuint32m4_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vloxseg4ei32_v_m)))
void vloxseg4ei32(vfloat16m2_t *, vfloat16m2_t *, vfloat16m2_t *, vfloat16m2_t *, vbool8_t, vfloat16m2_t, vfloat16m2_t, vfloat16m2_t, vfloat16m2_t, const _Float16 *, vuint32m4_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vloxseg4ei32_v)))
void vloxseg4ei32(vfloat16mf2_t *, vfloat16mf2_t *, vfloat16mf2_t *, vfloat16mf2_t *, const _Float16 *, vuint32m1_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vloxseg4ei32_v_m)))
void vloxseg4ei32(vfloat16mf2_t *, vfloat16mf2_t *, vfloat16mf2_t *, vfloat16mf2_t *, vbool32_t, vfloat16mf2_t, vfloat16mf2_t, vfloat16mf2_t, vfloat16mf2_t, const _Float16 *, vuint32m1_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vloxseg4ei32_v)))
void vloxseg4ei32(vfloat16mf4_t *, vfloat16mf4_t *, vfloat16mf4_t *, vfloat16mf4_t *, const _Float16 *, vuint32mf2_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vloxseg4ei32_v_m)))
void vloxseg4ei32(vfloat16mf4_t *, vfloat16mf4_t *, vfloat16mf4_t *, vfloat16mf4_t *, vbool64_t, vfloat16mf4_t, vfloat16mf4_t, vfloat16mf4_t, vfloat16mf4_t, const _Float16 *, vuint32mf2_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vloxseg5ei32_v)))
void vloxseg5ei32(vfloat16m1_t *, vfloat16m1_t *, vfloat16m1_t *, vfloat16m1_t *, vfloat16m1_t *, const _Float16 *, vuint32m2_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vloxseg5ei32_v_m)))
void vloxseg5ei32(vfloat16m1_t *, vfloat16m1_t *, vfloat16m1_t *, vfloat16m1_t *, vfloat16m1_t *, vbool16_t, vfloat16m1_t, vfloat16m1_t, vfloat16m1_t, vfloat16m1_t, vfloat16m1_t, const _Float16 *, vuint32m2_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vloxseg5ei32_v)))
void vloxseg5ei32(vfloat16mf2_t *, vfloat16mf2_t *, vfloat16mf2_t *, vfloat16mf2_t *, vfloat16mf2_t *, const _Float16 *, vuint32m1_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vloxseg5ei32_v_m)))
void vloxseg5ei32(vfloat16mf2_t *, vfloat16mf2_t *, vfloat16mf2_t *, vfloat16mf2_t *, vfloat16mf2_t *, vbool32_t, vfloat16mf2_t, vfloat16mf2_t, vfloat16mf2_t, vfloat16mf2_t, vfloat16mf2_t, const _Float16 *, vuint32m1_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vloxseg5ei32_v)))
void vloxseg5ei32(vfloat16mf4_t *, vfloat16mf4_t *, vfloat16mf4_t *, vfloat16mf4_t *, vfloat16mf4_t *, const _Float16 *, vuint32mf2_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vloxseg5ei32_v_m)))
void vloxseg5ei32(vfloat16mf4_t *, vfloat16mf4_t *, vfloat16mf4_t *, vfloat16mf4_t *, vfloat16mf4_t *, vbool64_t, vfloat16mf4_t, vfloat16mf4_t, vfloat16mf4_t, vfloat16mf4_t, vfloat16mf4_t, const _Float16 *, vuint32mf2_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vloxseg6ei32_v)))
void vloxseg6ei32(vfloat16m1_t *, vfloat16m1_t *, vfloat16m1_t *, vfloat16m1_t *, vfloat16m1_t *, vfloat16m1_t *, const _Float16 *, vuint32m2_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vloxseg6ei32_v_m)))
void vloxseg6ei32(vfloat16m1_t *, vfloat16m1_t *, vfloat16m1_t *, vfloat16m1_t *, vfloat16m1_t *, vfloat16m1_t *, vbool16_t, vfloat16m1_t, vfloat16m1_t, vfloat16m1_t, vfloat16m1_t, vfloat16m1_t, vfloat16m1_t, const _Float16 *, vuint32m2_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vloxseg6ei32_v)))
void vloxseg6ei32(vfloat16mf2_t *, vfloat16mf2_t *, vfloat16mf2_t *, vfloat16mf2_t *, vfloat16mf2_t *, vfloat16mf2_t *, const _Float16 *, vuint32m1_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vloxseg6ei32_v_m)))
void vloxseg6ei32(vfloat16mf2_t *, vfloat16mf2_t *, vfloat16mf2_t *, vfloat16mf2_t *, vfloat16mf2_t *, vfloat16mf2_t *, vbool32_t, vfloat16mf2_t, vfloat16mf2_t, vfloat16mf2_t, vfloat16mf2_t, vfloat16mf2_t, vfloat16mf2_t, const _Float16 *, vuint32m1_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vloxseg6ei32_v)))
void vloxseg6ei32(vfloat16mf4_t *, vfloat16mf4_t *, vfloat16mf4_t *, vfloat16mf4_t *, vfloat16mf4_t *, vfloat16mf4_t *, const _Float16 *, vuint32mf2_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vloxseg6ei32_v_m)))
void vloxseg6ei32(vfloat16mf4_t *, vfloat16mf4_t *, vfloat16mf4_t *, vfloat16mf4_t *, vfloat16mf4_t *, vfloat16mf4_t *, vbool64_t, vfloat16mf4_t, vfloat16mf4_t, vfloat16mf4_t, vfloat16mf4_t, vfloat16mf4_t, vfloat16mf4_t, const _Float16 *, vuint32mf2_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vloxseg7ei32_v)))
void vloxseg7ei32(vfloat16m1_t *, vfloat16m1_t *, vfloat16m1_t *, vfloat16m1_t *, vfloat16m1_t *, vfloat16m1_t *, vfloat16m1_t *, const _Float16 *, vuint32m2_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vloxseg7ei32_v_m)))
void vloxseg7ei32(vfloat16m1_t *, vfloat16m1_t *, vfloat16m1_t *, vfloat16m1_t *, vfloat16m1_t *, vfloat16m1_t *, vfloat16m1_t *, vbool16_t, vfloat16m1_t, vfloat16m1_t, vfloat16m1_t, vfloat16m1_t, vfloat16m1_t, vfloat16m1_t, vfloat16m1_t, const _Float16 *, vuint32m2_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vloxseg7ei32_v)))
void vloxseg7ei32(vfloat16mf2_t *, vfloat16mf2_t *, vfloat16mf2_t *, vfloat16mf2_t *, vfloat16mf2_t *, vfloat16mf2_t *, vfloat16mf2_t *, const _Float16 *, vuint32m1_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vloxseg7ei32_v_m)))
void vloxseg7ei32(vfloat16mf2_t *, vfloat16mf2_t *, vfloat16mf2_t *, vfloat16mf2_t *, vfloat16mf2_t *, vfloat16mf2_t *, vfloat16mf2_t *, vbool32_t, vfloat16mf2_t, vfloat16mf2_t, vfloat16mf2_t, vfloat16mf2_t, vfloat16mf2_t, vfloat16mf2_t, vfloat16mf2_t, const _Float16 *, vuint32m1_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vloxseg7ei32_v)))
void vloxseg7ei32(vfloat16mf4_t *, vfloat16mf4_t *, vfloat16mf4_t *, vfloat16mf4_t *, vfloat16mf4_t *, vfloat16mf4_t *, vfloat16mf4_t *, const _Float16 *, vuint32mf2_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vloxseg7ei32_v_m)))
void vloxseg7ei32(vfloat16mf4_t *, vfloat16mf4_t *, vfloat16mf4_t *, vfloat16mf4_t *, vfloat16mf4_t *, vfloat16mf4_t *, vfloat16mf4_t *, vbool64_t, vfloat16mf4_t, vfloat16mf4_t, vfloat16mf4_t, vfloat16mf4_t, vfloat16mf4_t, vfloat16mf4_t, vfloat16mf4_t, const _Float16 *, vuint32mf2_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vloxseg8ei32_v)))
void vloxseg8ei32(vfloat16m1_t *, vfloat16m1_t *, vfloat16m1_t *, vfloat16m1_t *, vfloat16m1_t *, vfloat16m1_t *, vfloat16m1_t *, vfloat16m1_t *, const _Float16 *, vuint32m2_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vloxseg8ei32_v_m)))
void vloxseg8ei32(vfloat16m1_t *, vfloat16m1_t *, vfloat16m1_t *, vfloat16m1_t *, vfloat16m1_t *, vfloat16m1_t *, vfloat16m1_t *, vfloat16m1_t *, vbool16_t, vfloat16m1_t, vfloat16m1_t, vfloat16m1_t, vfloat16m1_t, vfloat16m1_t, vfloat16m1_t, vfloat16m1_t, vfloat16m1_t, const _Float16 *, vuint32m2_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vloxseg8ei32_v)))
void vloxseg8ei32(vfloat16mf2_t *, vfloat16mf2_t *, vfloat16mf2_t *, vfloat16mf2_t *, vfloat16mf2_t *, vfloat16mf2_t *, vfloat16mf2_t *, vfloat16mf2_t *, const _Float16 *, vuint32m1_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vloxseg8ei32_v_m)))
void vloxseg8ei32(vfloat16mf2_t *, vfloat16mf2_t *, vfloat16mf2_t *, vfloat16mf2_t *, vfloat16mf2_t *, vfloat16mf2_t *, vfloat16mf2_t *, vfloat16mf2_t *, vbool32_t, vfloat16mf2_t, vfloat16mf2_t, vfloat16mf2_t, vfloat16mf2_t, vfloat16mf2_t, vfloat16mf2_t, vfloat16mf2_t, vfloat16mf2_t, const _Float16 *, vuint32m1_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vloxseg8ei32_v)))
void vloxseg8ei32(vfloat16mf4_t *, vfloat16mf4_t *, vfloat16mf4_t *, vfloat16mf4_t *, vfloat16mf4_t *, vfloat16mf4_t *, vfloat16mf4_t *, vfloat16mf4_t *, const _Float16 *, vuint32mf2_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vloxseg8ei32_v_m)))
void vloxseg8ei32(vfloat16mf4_t *, vfloat16mf4_t *, vfloat16mf4_t *, vfloat16mf4_t *, vfloat16mf4_t *, vfloat16mf4_t *, vfloat16mf4_t *, vfloat16mf4_t *, vbool64_t, vfloat16mf4_t, vfloat16mf4_t, vfloat16mf4_t, vfloat16mf4_t, vfloat16mf4_t, vfloat16mf4_t, vfloat16mf4_t, vfloat16mf4_t, const _Float16 *, vuint32mf2_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vsseg2e16_v)))
void vsseg2e16(_Float16 *, vfloat16m1_t, vfloat16m1_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vsseg2e16_v_m)))
void vsseg2e16(vbool16_t, _Float16 *, vfloat16m1_t, vfloat16m1_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vsseg2e16_v)))
void vsseg2e16(_Float16 *, vfloat16m2_t, vfloat16m2_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vsseg2e16_v_m)))
void vsseg2e16(vbool8_t, _Float16 *, vfloat16m2_t, vfloat16m2_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vsseg2e16_v)))
void vsseg2e16(_Float16 *, vfloat16m4_t, vfloat16m4_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vsseg2e16_v_m)))
void vsseg2e16(vbool4_t, _Float16 *, vfloat16m4_t, vfloat16m4_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vsseg2e16_v)))
void vsseg2e16(_Float16 *, vfloat16mf2_t, vfloat16mf2_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vsseg2e16_v_m)))
void vsseg2e16(vbool32_t, _Float16 *, vfloat16mf2_t, vfloat16mf2_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vsseg2e16_v)))
void vsseg2e16(_Float16 *, vfloat16mf4_t, vfloat16mf4_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vsseg2e16_v_m)))
void vsseg2e16(vbool64_t, _Float16 *, vfloat16mf4_t, vfloat16mf4_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vsseg3e16_v)))
void vsseg3e16(_Float16 *, vfloat16m1_t, vfloat16m1_t, vfloat16m1_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vsseg3e16_v_m)))
void vsseg3e16(vbool16_t, _Float16 *, vfloat16m1_t, vfloat16m1_t, vfloat16m1_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vsseg3e16_v)))
void vsseg3e16(_Float16 *, vfloat16m2_t, vfloat16m2_t, vfloat16m2_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vsseg3e16_v_m)))
void vsseg3e16(vbool8_t, _Float16 *, vfloat16m2_t, vfloat16m2_t, vfloat16m2_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vsseg3e16_v)))
void vsseg3e16(_Float16 *, vfloat16mf2_t, vfloat16mf2_t, vfloat16mf2_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vsseg3e16_v_m)))
void vsseg3e16(vbool32_t, _Float16 *, vfloat16mf2_t, vfloat16mf2_t, vfloat16mf2_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vsseg3e16_v)))
void vsseg3e16(_Float16 *, vfloat16mf4_t, vfloat16mf4_t, vfloat16mf4_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vsseg3e16_v_m)))
void vsseg3e16(vbool64_t, _Float16 *, vfloat16mf4_t, vfloat16mf4_t, vfloat16mf4_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vsseg4e16_v)))
void vsseg4e16(_Float16 *, vfloat16m1_t, vfloat16m1_t, vfloat16m1_t, vfloat16m1_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vsseg4e16_v_m)))
void vsseg4e16(vbool16_t, _Float16 *, vfloat16m1_t, vfloat16m1_t, vfloat16m1_t, vfloat16m1_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vsseg4e16_v)))
void vsseg4e16(_Float16 *, vfloat16m2_t, vfloat16m2_t, vfloat16m2_t, vfloat16m2_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vsseg4e16_v_m)))
void vsseg4e16(vbool8_t, _Float16 *, vfloat16m2_t, vfloat16m2_t, vfloat16m2_t, vfloat16m2_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vsseg4e16_v)))
void vsseg4e16(_Float16 *, vfloat16mf2_t, vfloat16mf2_t, vfloat16mf2_t, vfloat16mf2_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vsseg4e16_v_m)))
void vsseg4e16(vbool32_t, _Float16 *, vfloat16mf2_t, vfloat16mf2_t, vfloat16mf2_t, vfloat16mf2_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vsseg4e16_v)))
void vsseg4e16(_Float16 *, vfloat16mf4_t, vfloat16mf4_t, vfloat16mf4_t, vfloat16mf4_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vsseg4e16_v_m)))
void vsseg4e16(vbool64_t, _Float16 *, vfloat16mf4_t, vfloat16mf4_t, vfloat16mf4_t, vfloat16mf4_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vsseg5e16_v)))
void vsseg5e16(_Float16 *, vfloat16m1_t, vfloat16m1_t, vfloat16m1_t, vfloat16m1_t, vfloat16m1_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vsseg5e16_v_m)))
void vsseg5e16(vbool16_t, _Float16 *, vfloat16m1_t, vfloat16m1_t, vfloat16m1_t, vfloat16m1_t, vfloat16m1_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vsseg5e16_v)))
void vsseg5e16(_Float16 *, vfloat16mf2_t, vfloat16mf2_t, vfloat16mf2_t, vfloat16mf2_t, vfloat16mf2_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vsseg5e16_v_m)))
void vsseg5e16(vbool32_t, _Float16 *, vfloat16mf2_t, vfloat16mf2_t, vfloat16mf2_t, vfloat16mf2_t, vfloat16mf2_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vsseg5e16_v)))
void vsseg5e16(_Float16 *, vfloat16mf4_t, vfloat16mf4_t, vfloat16mf4_t, vfloat16mf4_t, vfloat16mf4_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vsseg5e16_v_m)))
void vsseg5e16(vbool64_t, _Float16 *, vfloat16mf4_t, vfloat16mf4_t, vfloat16mf4_t, vfloat16mf4_t, vfloat16mf4_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vsseg6e16_v)))
void vsseg6e16(_Float16 *, vfloat16m1_t, vfloat16m1_t, vfloat16m1_t, vfloat16m1_t, vfloat16m1_t, vfloat16m1_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vsseg6e16_v_m)))
void vsseg6e16(vbool16_t, _Float16 *, vfloat16m1_t, vfloat16m1_t, vfloat16m1_t, vfloat16m1_t, vfloat16m1_t, vfloat16m1_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vsseg6e16_v)))
void vsseg6e16(_Float16 *, vfloat16mf2_t, vfloat16mf2_t, vfloat16mf2_t, vfloat16mf2_t, vfloat16mf2_t, vfloat16mf2_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vsseg6e16_v_m)))
void vsseg6e16(vbool32_t, _Float16 *, vfloat16mf2_t, vfloat16mf2_t, vfloat16mf2_t, vfloat16mf2_t, vfloat16mf2_t, vfloat16mf2_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vsseg6e16_v)))
void vsseg6e16(_Float16 *, vfloat16mf4_t, vfloat16mf4_t, vfloat16mf4_t, vfloat16mf4_t, vfloat16mf4_t, vfloat16mf4_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vsseg6e16_v_m)))
void vsseg6e16(vbool64_t, _Float16 *, vfloat16mf4_t, vfloat16mf4_t, vfloat16mf4_t, vfloat16mf4_t, vfloat16mf4_t, vfloat16mf4_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vsseg7e16_v)))
void vsseg7e16(_Float16 *, vfloat16m1_t, vfloat16m1_t, vfloat16m1_t, vfloat16m1_t, vfloat16m1_t, vfloat16m1_t, vfloat16m1_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vsseg7e16_v_m)))
void vsseg7e16(vbool16_t, _Float16 *, vfloat16m1_t, vfloat16m1_t, vfloat16m1_t, vfloat16m1_t, vfloat16m1_t, vfloat16m1_t, vfloat16m1_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vsseg7e16_v)))
void vsseg7e16(_Float16 *, vfloat16mf2_t, vfloat16mf2_t, vfloat16mf2_t, vfloat16mf2_t, vfloat16mf2_t, vfloat16mf2_t, vfloat16mf2_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vsseg7e16_v_m)))
void vsseg7e16(vbool32_t, _Float16 *, vfloat16mf2_t, vfloat16mf2_t, vfloat16mf2_t, vfloat16mf2_t, vfloat16mf2_t, vfloat16mf2_t, vfloat16mf2_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vsseg7e16_v)))
void vsseg7e16(_Float16 *, vfloat16mf4_t, vfloat16mf4_t, vfloat16mf4_t, vfloat16mf4_t, vfloat16mf4_t, vfloat16mf4_t, vfloat16mf4_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vsseg7e16_v_m)))
void vsseg7e16(vbool64_t, _Float16 *, vfloat16mf4_t, vfloat16mf4_t, vfloat16mf4_t, vfloat16mf4_t, vfloat16mf4_t, vfloat16mf4_t, vfloat16mf4_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vsseg8e16_v)))
void vsseg8e16(_Float16 *, vfloat16m1_t, vfloat16m1_t, vfloat16m1_t, vfloat16m1_t, vfloat16m1_t, vfloat16m1_t, vfloat16m1_t, vfloat16m1_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vsseg8e16_v_m)))
void vsseg8e16(vbool16_t, _Float16 *, vfloat16m1_t, vfloat16m1_t, vfloat16m1_t, vfloat16m1_t, vfloat16m1_t, vfloat16m1_t, vfloat16m1_t, vfloat16m1_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vsseg8e16_v)))
void vsseg8e16(_Float16 *, vfloat16mf2_t, vfloat16mf2_t, vfloat16mf2_t, vfloat16mf2_t, vfloat16mf2_t, vfloat16mf2_t, vfloat16mf2_t, vfloat16mf2_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vsseg8e16_v_m)))
void vsseg8e16(vbool32_t, _Float16 *, vfloat16mf2_t, vfloat16mf2_t, vfloat16mf2_t, vfloat16mf2_t, vfloat16mf2_t, vfloat16mf2_t, vfloat16mf2_t, vfloat16mf2_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vsseg8e16_v)))
void vsseg8e16(_Float16 *, vfloat16mf4_t, vfloat16mf4_t, vfloat16mf4_t, vfloat16mf4_t, vfloat16mf4_t, vfloat16mf4_t, vfloat16mf4_t, vfloat16mf4_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vsseg8e16_v_m)))
void vsseg8e16(vbool64_t, _Float16 *, vfloat16mf4_t, vfloat16mf4_t, vfloat16mf4_t, vfloat16mf4_t, vfloat16mf4_t, vfloat16mf4_t, vfloat16mf4_t, vfloat16mf4_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vssseg2e16_v)))
void vssseg2e16(_Float16 *, ptrdiff_t, vfloat16m1_t, vfloat16m1_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vssseg2e16_v_m)))
void vssseg2e16(vbool16_t, _Float16 *, ptrdiff_t, vfloat16m1_t, vfloat16m1_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vssseg2e16_v)))
void vssseg2e16(_Float16 *, ptrdiff_t, vfloat16m2_t, vfloat16m2_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vssseg2e16_v_m)))
void vssseg2e16(vbool8_t, _Float16 *, ptrdiff_t, vfloat16m2_t, vfloat16m2_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vssseg2e16_v)))
void vssseg2e16(_Float16 *, ptrdiff_t, vfloat16m4_t, vfloat16m4_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vssseg2e16_v_m)))
void vssseg2e16(vbool4_t, _Float16 *, ptrdiff_t, vfloat16m4_t, vfloat16m4_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vssseg2e16_v)))
void vssseg2e16(_Float16 *, ptrdiff_t, vfloat16mf2_t, vfloat16mf2_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vssseg2e16_v_m)))
void vssseg2e16(vbool32_t, _Float16 *, ptrdiff_t, vfloat16mf2_t, vfloat16mf2_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vssseg2e16_v)))
void vssseg2e16(_Float16 *, ptrdiff_t, vfloat16mf4_t, vfloat16mf4_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vssseg2e16_v_m)))
void vssseg2e16(vbool64_t, _Float16 *, ptrdiff_t, vfloat16mf4_t, vfloat16mf4_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vssseg3e16_v)))
void vssseg3e16(_Float16 *, ptrdiff_t, vfloat16m1_t, vfloat16m1_t, vfloat16m1_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vssseg3e16_v_m)))
void vssseg3e16(vbool16_t, _Float16 *, ptrdiff_t, vfloat16m1_t, vfloat16m1_t, vfloat16m1_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vssseg3e16_v)))
void vssseg3e16(_Float16 *, ptrdiff_t, vfloat16m2_t, vfloat16m2_t, vfloat16m2_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vssseg3e16_v_m)))
void vssseg3e16(vbool8_t, _Float16 *, ptrdiff_t, vfloat16m2_t, vfloat16m2_t, vfloat16m2_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vssseg3e16_v)))
void vssseg3e16(_Float16 *, ptrdiff_t, vfloat16mf2_t, vfloat16mf2_t, vfloat16mf2_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vssseg3e16_v_m)))
void vssseg3e16(vbool32_t, _Float16 *, ptrdiff_t, vfloat16mf2_t, vfloat16mf2_t, vfloat16mf2_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vssseg3e16_v)))
void vssseg3e16(_Float16 *, ptrdiff_t, vfloat16mf4_t, vfloat16mf4_t, vfloat16mf4_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vssseg3e16_v_m)))
void vssseg3e16(vbool64_t, _Float16 *, ptrdiff_t, vfloat16mf4_t, vfloat16mf4_t, vfloat16mf4_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vssseg4e16_v)))
void vssseg4e16(_Float16 *, ptrdiff_t, vfloat16m1_t, vfloat16m1_t, vfloat16m1_t, vfloat16m1_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vssseg4e16_v_m)))
void vssseg4e16(vbool16_t, _Float16 *, ptrdiff_t, vfloat16m1_t, vfloat16m1_t, vfloat16m1_t, vfloat16m1_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vssseg4e16_v)))
void vssseg4e16(_Float16 *, ptrdiff_t, vfloat16m2_t, vfloat16m2_t, vfloat16m2_t, vfloat16m2_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vssseg4e16_v_m)))
void vssseg4e16(vbool8_t, _Float16 *, ptrdiff_t, vfloat16m2_t, vfloat16m2_t, vfloat16m2_t, vfloat16m2_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vssseg4e16_v)))
void vssseg4e16(_Float16 *, ptrdiff_t, vfloat16mf2_t, vfloat16mf2_t, vfloat16mf2_t, vfloat16mf2_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vssseg4e16_v_m)))
void vssseg4e16(vbool32_t, _Float16 *, ptrdiff_t, vfloat16mf2_t, vfloat16mf2_t, vfloat16mf2_t, vfloat16mf2_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vssseg4e16_v)))
void vssseg4e16(_Float16 *, ptrdiff_t, vfloat16mf4_t, vfloat16mf4_t, vfloat16mf4_t, vfloat16mf4_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vssseg4e16_v_m)))
void vssseg4e16(vbool64_t, _Float16 *, ptrdiff_t, vfloat16mf4_t, vfloat16mf4_t, vfloat16mf4_t, vfloat16mf4_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vssseg5e16_v)))
void vssseg5e16(_Float16 *, ptrdiff_t, vfloat16m1_t, vfloat16m1_t, vfloat16m1_t, vfloat16m1_t, vfloat16m1_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vssseg5e16_v_m)))
void vssseg5e16(vbool16_t, _Float16 *, ptrdiff_t, vfloat16m1_t, vfloat16m1_t, vfloat16m1_t, vfloat16m1_t, vfloat16m1_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vssseg5e16_v)))
void vssseg5e16(_Float16 *, ptrdiff_t, vfloat16mf2_t, vfloat16mf2_t, vfloat16mf2_t, vfloat16mf2_t, vfloat16mf2_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vssseg5e16_v_m)))
void vssseg5e16(vbool32_t, _Float16 *, ptrdiff_t, vfloat16mf2_t, vfloat16mf2_t, vfloat16mf2_t, vfloat16mf2_t, vfloat16mf2_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vssseg5e16_v)))
void vssseg5e16(_Float16 *, ptrdiff_t, vfloat16mf4_t, vfloat16mf4_t, vfloat16mf4_t, vfloat16mf4_t, vfloat16mf4_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vssseg5e16_v_m)))
void vssseg5e16(vbool64_t, _Float16 *, ptrdiff_t, vfloat16mf4_t, vfloat16mf4_t, vfloat16mf4_t, vfloat16mf4_t, vfloat16mf4_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vssseg6e16_v)))
void vssseg6e16(_Float16 *, ptrdiff_t, vfloat16m1_t, vfloat16m1_t, vfloat16m1_t, vfloat16m1_t, vfloat16m1_t, vfloat16m1_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vssseg6e16_v_m)))
void vssseg6e16(vbool16_t, _Float16 *, ptrdiff_t, vfloat16m1_t, vfloat16m1_t, vfloat16m1_t, vfloat16m1_t, vfloat16m1_t, vfloat16m1_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vssseg6e16_v)))
void vssseg6e16(_Float16 *, ptrdiff_t, vfloat16mf2_t, vfloat16mf2_t, vfloat16mf2_t, vfloat16mf2_t, vfloat16mf2_t, vfloat16mf2_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vssseg6e16_v_m)))
void vssseg6e16(vbool32_t, _Float16 *, ptrdiff_t, vfloat16mf2_t, vfloat16mf2_t, vfloat16mf2_t, vfloat16mf2_t, vfloat16mf2_t, vfloat16mf2_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vssseg6e16_v)))
void vssseg6e16(_Float16 *, ptrdiff_t, vfloat16mf4_t, vfloat16mf4_t, vfloat16mf4_t, vfloat16mf4_t, vfloat16mf4_t, vfloat16mf4_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vssseg6e16_v_m)))
void vssseg6e16(vbool64_t, _Float16 *, ptrdiff_t, vfloat16mf4_t, vfloat16mf4_t, vfloat16mf4_t, vfloat16mf4_t, vfloat16mf4_t, vfloat16mf4_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vssseg7e16_v)))
void vssseg7e16(_Float16 *, ptrdiff_t, vfloat16m1_t, vfloat16m1_t, vfloat16m1_t, vfloat16m1_t, vfloat16m1_t, vfloat16m1_t, vfloat16m1_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vssseg7e16_v_m)))
void vssseg7e16(vbool16_t, _Float16 *, ptrdiff_t, vfloat16m1_t, vfloat16m1_t, vfloat16m1_t, vfloat16m1_t, vfloat16m1_t, vfloat16m1_t, vfloat16m1_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vssseg7e16_v)))
void vssseg7e16(_Float16 *, ptrdiff_t, vfloat16mf2_t, vfloat16mf2_t, vfloat16mf2_t, vfloat16mf2_t, vfloat16mf2_t, vfloat16mf2_t, vfloat16mf2_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vssseg7e16_v_m)))
void vssseg7e16(vbool32_t, _Float16 *, ptrdiff_t, vfloat16mf2_t, vfloat16mf2_t, vfloat16mf2_t, vfloat16mf2_t, vfloat16mf2_t, vfloat16mf2_t, vfloat16mf2_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vssseg7e16_v)))
void vssseg7e16(_Float16 *, ptrdiff_t, vfloat16mf4_t, vfloat16mf4_t, vfloat16mf4_t, vfloat16mf4_t, vfloat16mf4_t, vfloat16mf4_t, vfloat16mf4_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vssseg7e16_v_m)))
void vssseg7e16(vbool64_t, _Float16 *, ptrdiff_t, vfloat16mf4_t, vfloat16mf4_t, vfloat16mf4_t, vfloat16mf4_t, vfloat16mf4_t, vfloat16mf4_t, vfloat16mf4_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vssseg8e16_v)))
void vssseg8e16(_Float16 *, ptrdiff_t, vfloat16m1_t, vfloat16m1_t, vfloat16m1_t, vfloat16m1_t, vfloat16m1_t, vfloat16m1_t, vfloat16m1_t, vfloat16m1_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vssseg8e16_v_m)))
void vssseg8e16(vbool16_t, _Float16 *, ptrdiff_t, vfloat16m1_t, vfloat16m1_t, vfloat16m1_t, vfloat16m1_t, vfloat16m1_t, vfloat16m1_t, vfloat16m1_t, vfloat16m1_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vssseg8e16_v)))
void vssseg8e16(_Float16 *, ptrdiff_t, vfloat16mf2_t, vfloat16mf2_t, vfloat16mf2_t, vfloat16mf2_t, vfloat16mf2_t, vfloat16mf2_t, vfloat16mf2_t, vfloat16mf2_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vssseg8e16_v_m)))
void vssseg8e16(vbool32_t, _Float16 *, ptrdiff_t, vfloat16mf2_t, vfloat16mf2_t, vfloat16mf2_t, vfloat16mf2_t, vfloat16mf2_t, vfloat16mf2_t, vfloat16mf2_t, vfloat16mf2_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vssseg8e16_v)))
void vssseg8e16(_Float16 *, ptrdiff_t, vfloat16mf4_t, vfloat16mf4_t, vfloat16mf4_t, vfloat16mf4_t, vfloat16mf4_t, vfloat16mf4_t, vfloat16mf4_t, vfloat16mf4_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vssseg8e16_v_m)))
void vssseg8e16(vbool64_t, _Float16 *, ptrdiff_t, vfloat16mf4_t, vfloat16mf4_t, vfloat16mf4_t, vfloat16mf4_t, vfloat16mf4_t, vfloat16mf4_t, vfloat16mf4_t, vfloat16mf4_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vluxei8_v)))
vfloat16m1_t vluxei8(const _Float16 *, vuint8mf2_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vluxei8_v_m)))
vfloat16m1_t vluxei8(vbool16_t, vfloat16m1_t, const _Float16 *, vuint8mf2_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vluxei8_v)))
vfloat16m2_t vluxei8(const _Float16 *, vuint8m1_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vluxei8_v_m)))
vfloat16m2_t vluxei8(vbool8_t, vfloat16m2_t, const _Float16 *, vuint8m1_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vluxei8_v)))
vfloat16m4_t vluxei8(const _Float16 *, vuint8m2_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vluxei8_v_m)))
vfloat16m4_t vluxei8(vbool4_t, vfloat16m4_t, const _Float16 *, vuint8m2_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vluxei8_v)))
vfloat16m8_t vluxei8(const _Float16 *, vuint8m4_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vluxei8_v_m)))
vfloat16m8_t vluxei8(vbool2_t, vfloat16m8_t, const _Float16 *, vuint8m4_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vluxei8_v)))
vfloat16mf2_t vluxei8(const _Float16 *, vuint8mf4_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vluxei8_v_m)))
vfloat16mf2_t vluxei8(vbool32_t, vfloat16mf2_t, const _Float16 *, vuint8mf4_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vluxei8_v)))
vfloat16mf4_t vluxei8(const _Float16 *, vuint8mf8_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vluxei8_v_m)))
vfloat16mf4_t vluxei8(vbool64_t, vfloat16mf4_t, const _Float16 *, vuint8mf8_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vluxei16_v)))
vfloat16m1_t vluxei16(const _Float16 *, vuint16m1_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vluxei16_v_m)))
vfloat16m1_t vluxei16(vbool16_t, vfloat16m1_t, const _Float16 *, vuint16m1_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vluxei16_v)))
vfloat16m2_t vluxei16(const _Float16 *, vuint16m2_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vluxei16_v_m)))
vfloat16m2_t vluxei16(vbool8_t, vfloat16m2_t, const _Float16 *, vuint16m2_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vluxei16_v)))
vfloat16m4_t vluxei16(const _Float16 *, vuint16m4_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vluxei16_v_m)))
vfloat16m4_t vluxei16(vbool4_t, vfloat16m4_t, const _Float16 *, vuint16m4_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vluxei16_v)))
vfloat16m8_t vluxei16(const _Float16 *, vuint16m8_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vluxei16_v_m)))
vfloat16m8_t vluxei16(vbool2_t, vfloat16m8_t, const _Float16 *, vuint16m8_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vluxei16_v)))
vfloat16mf2_t vluxei16(const _Float16 *, vuint16mf2_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vluxei16_v_m)))
vfloat16mf2_t vluxei16(vbool32_t, vfloat16mf2_t, const _Float16 *, vuint16mf2_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vluxei16_v)))
vfloat16mf4_t vluxei16(const _Float16 *, vuint16mf4_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vluxei16_v_m)))
vfloat16mf4_t vluxei16(vbool64_t, vfloat16mf4_t, const _Float16 *, vuint16mf4_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vluxei32_v)))
vfloat16m1_t vluxei32(const _Float16 *, vuint32m2_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vluxei32_v_m)))
vfloat16m1_t vluxei32(vbool16_t, vfloat16m1_t, const _Float16 *, vuint32m2_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vluxei32_v)))
vfloat16m2_t vluxei32(const _Float16 *, vuint32m4_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vluxei32_v_m)))
vfloat16m2_t vluxei32(vbool8_t, vfloat16m2_t, const _Float16 *, vuint32m4_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vluxei32_v)))
vfloat16m4_t vluxei32(const _Float16 *, vuint32m8_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vluxei32_v_m)))
vfloat16m4_t vluxei32(vbool4_t, vfloat16m4_t, const _Float16 *, vuint32m8_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vluxei32_v)))
vfloat16mf2_t vluxei32(const _Float16 *, vuint32m1_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vluxei32_v_m)))
vfloat16mf2_t vluxei32(vbool32_t, vfloat16mf2_t, const _Float16 *, vuint32m1_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vluxei32_v)))
vfloat16mf4_t vluxei32(const _Float16 *, vuint32mf2_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vluxei32_v_m)))
vfloat16mf4_t vluxei32(vbool64_t, vfloat16mf4_t, const _Float16 *, vuint32mf2_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vsuxseg2ei8_v)))
void vsuxseg2ei8(_Float16 *, vuint8mf2_t, vfloat16m1_t, vfloat16m1_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vsuxseg2ei8_v_m)))
void vsuxseg2ei8(vbool16_t, _Float16 *, vuint8mf2_t, vfloat16m1_t, vfloat16m1_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vsuxseg2ei8_v)))
void vsuxseg2ei8(_Float16 *, vuint8m1_t, vfloat16m2_t, vfloat16m2_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vsuxseg2ei8_v_m)))
void vsuxseg2ei8(vbool8_t, _Float16 *, vuint8m1_t, vfloat16m2_t, vfloat16m2_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vsuxseg2ei8_v)))
void vsuxseg2ei8(_Float16 *, vuint8m2_t, vfloat16m4_t, vfloat16m4_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vsuxseg2ei8_v_m)))
void vsuxseg2ei8(vbool4_t, _Float16 *, vuint8m2_t, vfloat16m4_t, vfloat16m4_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vsuxseg2ei8_v)))
void vsuxseg2ei8(_Float16 *, vuint8mf4_t, vfloat16mf2_t, vfloat16mf2_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vsuxseg2ei8_v_m)))
void vsuxseg2ei8(vbool32_t, _Float16 *, vuint8mf4_t, vfloat16mf2_t, vfloat16mf2_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vsuxseg2ei8_v)))
void vsuxseg2ei8(_Float16 *, vuint8mf8_t, vfloat16mf4_t, vfloat16mf4_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vsuxseg2ei8_v_m)))
void vsuxseg2ei8(vbool64_t, _Float16 *, vuint8mf8_t, vfloat16mf4_t, vfloat16mf4_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vsuxseg3ei8_v)))
void vsuxseg3ei8(_Float16 *, vuint8mf2_t, vfloat16m1_t, vfloat16m1_t, vfloat16m1_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vsuxseg3ei8_v_m)))
void vsuxseg3ei8(vbool16_t, _Float16 *, vuint8mf2_t, vfloat16m1_t, vfloat16m1_t, vfloat16m1_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vsuxseg3ei8_v)))
void vsuxseg3ei8(_Float16 *, vuint8m1_t, vfloat16m2_t, vfloat16m2_t, vfloat16m2_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vsuxseg3ei8_v_m)))
void vsuxseg3ei8(vbool8_t, _Float16 *, vuint8m1_t, vfloat16m2_t, vfloat16m2_t, vfloat16m2_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vsuxseg3ei8_v)))
void vsuxseg3ei8(_Float16 *, vuint8mf4_t, vfloat16mf2_t, vfloat16mf2_t, vfloat16mf2_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vsuxseg3ei8_v_m)))
void vsuxseg3ei8(vbool32_t, _Float16 *, vuint8mf4_t, vfloat16mf2_t, vfloat16mf2_t, vfloat16mf2_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vsuxseg3ei8_v)))
void vsuxseg3ei8(_Float16 *, vuint8mf8_t, vfloat16mf4_t, vfloat16mf4_t, vfloat16mf4_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vsuxseg3ei8_v_m)))
void vsuxseg3ei8(vbool64_t, _Float16 *, vuint8mf8_t, vfloat16mf4_t, vfloat16mf4_t, vfloat16mf4_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vsuxseg4ei8_v)))
void vsuxseg4ei8(_Float16 *, vuint8mf2_t, vfloat16m1_t, vfloat16m1_t, vfloat16m1_t, vfloat16m1_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vsuxseg4ei8_v_m)))
void vsuxseg4ei8(vbool16_t, _Float16 *, vuint8mf2_t, vfloat16m1_t, vfloat16m1_t, vfloat16m1_t, vfloat16m1_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vsuxseg4ei8_v)))
void vsuxseg4ei8(_Float16 *, vuint8m1_t, vfloat16m2_t, vfloat16m2_t, vfloat16m2_t, vfloat16m2_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vsuxseg4ei8_v_m)))
void vsuxseg4ei8(vbool8_t, _Float16 *, vuint8m1_t, vfloat16m2_t, vfloat16m2_t, vfloat16m2_t, vfloat16m2_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vsuxseg4ei8_v)))
void vsuxseg4ei8(_Float16 *, vuint8mf4_t, vfloat16mf2_t, vfloat16mf2_t, vfloat16mf2_t, vfloat16mf2_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vsuxseg4ei8_v_m)))
void vsuxseg4ei8(vbool32_t, _Float16 *, vuint8mf4_t, vfloat16mf2_t, vfloat16mf2_t, vfloat16mf2_t, vfloat16mf2_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vsuxseg4ei8_v)))
void vsuxseg4ei8(_Float16 *, vuint8mf8_t, vfloat16mf4_t, vfloat16mf4_t, vfloat16mf4_t, vfloat16mf4_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vsuxseg4ei8_v_m)))
void vsuxseg4ei8(vbool64_t, _Float16 *, vuint8mf8_t, vfloat16mf4_t, vfloat16mf4_t, vfloat16mf4_t, vfloat16mf4_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vsuxseg5ei8_v)))
void vsuxseg5ei8(_Float16 *, vuint8mf2_t, vfloat16m1_t, vfloat16m1_t, vfloat16m1_t, vfloat16m1_t, vfloat16m1_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vsuxseg5ei8_v_m)))
void vsuxseg5ei8(vbool16_t, _Float16 *, vuint8mf2_t, vfloat16m1_t, vfloat16m1_t, vfloat16m1_t, vfloat16m1_t, vfloat16m1_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vsuxseg5ei8_v)))
void vsuxseg5ei8(_Float16 *, vuint8mf4_t, vfloat16mf2_t, vfloat16mf2_t, vfloat16mf2_t, vfloat16mf2_t, vfloat16mf2_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vsuxseg5ei8_v_m)))
void vsuxseg5ei8(vbool32_t, _Float16 *, vuint8mf4_t, vfloat16mf2_t, vfloat16mf2_t, vfloat16mf2_t, vfloat16mf2_t, vfloat16mf2_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vsuxseg5ei8_v)))
void vsuxseg5ei8(_Float16 *, vuint8mf8_t, vfloat16mf4_t, vfloat16mf4_t, vfloat16mf4_t, vfloat16mf4_t, vfloat16mf4_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vsuxseg5ei8_v_m)))
void vsuxseg5ei8(vbool64_t, _Float16 *, vuint8mf8_t, vfloat16mf4_t, vfloat16mf4_t, vfloat16mf4_t, vfloat16mf4_t, vfloat16mf4_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vsuxseg6ei8_v)))
void vsuxseg6ei8(_Float16 *, vuint8mf2_t, vfloat16m1_t, vfloat16m1_t, vfloat16m1_t, vfloat16m1_t, vfloat16m1_t, vfloat16m1_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vsuxseg6ei8_v_m)))
void vsuxseg6ei8(vbool16_t, _Float16 *, vuint8mf2_t, vfloat16m1_t, vfloat16m1_t, vfloat16m1_t, vfloat16m1_t, vfloat16m1_t, vfloat16m1_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vsuxseg6ei8_v)))
void vsuxseg6ei8(_Float16 *, vuint8mf4_t, vfloat16mf2_t, vfloat16mf2_t, vfloat16mf2_t, vfloat16mf2_t, vfloat16mf2_t, vfloat16mf2_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vsuxseg6ei8_v_m)))
void vsuxseg6ei8(vbool32_t, _Float16 *, vuint8mf4_t, vfloat16mf2_t, vfloat16mf2_t, vfloat16mf2_t, vfloat16mf2_t, vfloat16mf2_t, vfloat16mf2_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vsuxseg6ei8_v)))
void vsuxseg6ei8(_Float16 *, vuint8mf8_t, vfloat16mf4_t, vfloat16mf4_t, vfloat16mf4_t, vfloat16mf4_t, vfloat16mf4_t, vfloat16mf4_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vsuxseg6ei8_v_m)))
void vsuxseg6ei8(vbool64_t, _Float16 *, vuint8mf8_t, vfloat16mf4_t, vfloat16mf4_t, vfloat16mf4_t, vfloat16mf4_t, vfloat16mf4_t, vfloat16mf4_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vsuxseg7ei8_v)))
void vsuxseg7ei8(_Float16 *, vuint8mf2_t, vfloat16m1_t, vfloat16m1_t, vfloat16m1_t, vfloat16m1_t, vfloat16m1_t, vfloat16m1_t, vfloat16m1_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vsuxseg7ei8_v_m)))
void vsuxseg7ei8(vbool16_t, _Float16 *, vuint8mf2_t, vfloat16m1_t, vfloat16m1_t, vfloat16m1_t, vfloat16m1_t, vfloat16m1_t, vfloat16m1_t, vfloat16m1_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vsuxseg7ei8_v)))
void vsuxseg7ei8(_Float16 *, vuint8mf4_t, vfloat16mf2_t, vfloat16mf2_t, vfloat16mf2_t, vfloat16mf2_t, vfloat16mf2_t, vfloat16mf2_t, vfloat16mf2_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vsuxseg7ei8_v_m)))
void vsuxseg7ei8(vbool32_t, _Float16 *, vuint8mf4_t, vfloat16mf2_t, vfloat16mf2_t, vfloat16mf2_t, vfloat16mf2_t, vfloat16mf2_t, vfloat16mf2_t, vfloat16mf2_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vsuxseg7ei8_v)))
void vsuxseg7ei8(_Float16 *, vuint8mf8_t, vfloat16mf4_t, vfloat16mf4_t, vfloat16mf4_t, vfloat16mf4_t, vfloat16mf4_t, vfloat16mf4_t, vfloat16mf4_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vsuxseg7ei8_v_m)))
void vsuxseg7ei8(vbool64_t, _Float16 *, vuint8mf8_t, vfloat16mf4_t, vfloat16mf4_t, vfloat16mf4_t, vfloat16mf4_t, vfloat16mf4_t, vfloat16mf4_t, vfloat16mf4_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vsuxseg8ei8_v)))
void vsuxseg8ei8(_Float16 *, vuint8mf2_t, vfloat16m1_t, vfloat16m1_t, vfloat16m1_t, vfloat16m1_t, vfloat16m1_t, vfloat16m1_t, vfloat16m1_t, vfloat16m1_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vsuxseg8ei8_v_m)))
void vsuxseg8ei8(vbool16_t, _Float16 *, vuint8mf2_t, vfloat16m1_t, vfloat16m1_t, vfloat16m1_t, vfloat16m1_t, vfloat16m1_t, vfloat16m1_t, vfloat16m1_t, vfloat16m1_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vsuxseg8ei8_v)))
void vsuxseg8ei8(_Float16 *, vuint8mf4_t, vfloat16mf2_t, vfloat16mf2_t, vfloat16mf2_t, vfloat16mf2_t, vfloat16mf2_t, vfloat16mf2_t, vfloat16mf2_t, vfloat16mf2_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vsuxseg8ei8_v_m)))
void vsuxseg8ei8(vbool32_t, _Float16 *, vuint8mf4_t, vfloat16mf2_t, vfloat16mf2_t, vfloat16mf2_t, vfloat16mf2_t, vfloat16mf2_t, vfloat16mf2_t, vfloat16mf2_t, vfloat16mf2_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vsuxseg8ei8_v)))
void vsuxseg8ei8(_Float16 *, vuint8mf8_t, vfloat16mf4_t, vfloat16mf4_t, vfloat16mf4_t, vfloat16mf4_t, vfloat16mf4_t, vfloat16mf4_t, vfloat16mf4_t, vfloat16mf4_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vsuxseg8ei8_v_m)))
void vsuxseg8ei8(vbool64_t, _Float16 *, vuint8mf8_t, vfloat16mf4_t, vfloat16mf4_t, vfloat16mf4_t, vfloat16mf4_t, vfloat16mf4_t, vfloat16mf4_t, vfloat16mf4_t, vfloat16mf4_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vsuxseg2ei16_v)))
void vsuxseg2ei16(_Float16 *, vuint16m1_t, vfloat16m1_t, vfloat16m1_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vsuxseg2ei16_v_m)))
void vsuxseg2ei16(vbool16_t, _Float16 *, vuint16m1_t, vfloat16m1_t, vfloat16m1_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vsuxseg2ei16_v)))
void vsuxseg2ei16(_Float16 *, vuint16m2_t, vfloat16m2_t, vfloat16m2_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vsuxseg2ei16_v_m)))
void vsuxseg2ei16(vbool8_t, _Float16 *, vuint16m2_t, vfloat16m2_t, vfloat16m2_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vsuxseg2ei16_v)))
void vsuxseg2ei16(_Float16 *, vuint16m4_t, vfloat16m4_t, vfloat16m4_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vsuxseg2ei16_v_m)))
void vsuxseg2ei16(vbool4_t, _Float16 *, vuint16m4_t, vfloat16m4_t, vfloat16m4_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vsuxseg2ei16_v)))
void vsuxseg2ei16(_Float16 *, vuint16mf2_t, vfloat16mf2_t, vfloat16mf2_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vsuxseg2ei16_v_m)))
void vsuxseg2ei16(vbool32_t, _Float16 *, vuint16mf2_t, vfloat16mf2_t, vfloat16mf2_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vsuxseg2ei16_v)))
void vsuxseg2ei16(_Float16 *, vuint16mf4_t, vfloat16mf4_t, vfloat16mf4_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vsuxseg2ei16_v_m)))
void vsuxseg2ei16(vbool64_t, _Float16 *, vuint16mf4_t, vfloat16mf4_t, vfloat16mf4_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vsuxseg3ei16_v)))
void vsuxseg3ei16(_Float16 *, vuint16m1_t, vfloat16m1_t, vfloat16m1_t, vfloat16m1_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vsuxseg3ei16_v_m)))
void vsuxseg3ei16(vbool16_t, _Float16 *, vuint16m1_t, vfloat16m1_t, vfloat16m1_t, vfloat16m1_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vsuxseg3ei16_v)))
void vsuxseg3ei16(_Float16 *, vuint16m2_t, vfloat16m2_t, vfloat16m2_t, vfloat16m2_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vsuxseg3ei16_v_m)))
void vsuxseg3ei16(vbool8_t, _Float16 *, vuint16m2_t, vfloat16m2_t, vfloat16m2_t, vfloat16m2_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vsuxseg3ei16_v)))
void vsuxseg3ei16(_Float16 *, vuint16mf2_t, vfloat16mf2_t, vfloat16mf2_t, vfloat16mf2_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vsuxseg3ei16_v_m)))
void vsuxseg3ei16(vbool32_t, _Float16 *, vuint16mf2_t, vfloat16mf2_t, vfloat16mf2_t, vfloat16mf2_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vsuxseg3ei16_v)))
void vsuxseg3ei16(_Float16 *, vuint16mf4_t, vfloat16mf4_t, vfloat16mf4_t, vfloat16mf4_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vsuxseg3ei16_v_m)))
void vsuxseg3ei16(vbool64_t, _Float16 *, vuint16mf4_t, vfloat16mf4_t, vfloat16mf4_t, vfloat16mf4_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vsuxseg4ei16_v)))
void vsuxseg4ei16(_Float16 *, vuint16m1_t, vfloat16m1_t, vfloat16m1_t, vfloat16m1_t, vfloat16m1_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vsuxseg4ei16_v_m)))
void vsuxseg4ei16(vbool16_t, _Float16 *, vuint16m1_t, vfloat16m1_t, vfloat16m1_t, vfloat16m1_t, vfloat16m1_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vsuxseg4ei16_v)))
void vsuxseg4ei16(_Float16 *, vuint16m2_t, vfloat16m2_t, vfloat16m2_t, vfloat16m2_t, vfloat16m2_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vsuxseg4ei16_v_m)))
void vsuxseg4ei16(vbool8_t, _Float16 *, vuint16m2_t, vfloat16m2_t, vfloat16m2_t, vfloat16m2_t, vfloat16m2_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vsuxseg4ei16_v)))
void vsuxseg4ei16(_Float16 *, vuint16mf2_t, vfloat16mf2_t, vfloat16mf2_t, vfloat16mf2_t, vfloat16mf2_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vsuxseg4ei16_v_m)))
void vsuxseg4ei16(vbool32_t, _Float16 *, vuint16mf2_t, vfloat16mf2_t, vfloat16mf2_t, vfloat16mf2_t, vfloat16mf2_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vsuxseg4ei16_v)))
void vsuxseg4ei16(_Float16 *, vuint16mf4_t, vfloat16mf4_t, vfloat16mf4_t, vfloat16mf4_t, vfloat16mf4_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vsuxseg4ei16_v_m)))
void vsuxseg4ei16(vbool64_t, _Float16 *, vuint16mf4_t, vfloat16mf4_t, vfloat16mf4_t, vfloat16mf4_t, vfloat16mf4_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vsuxseg5ei16_v)))
void vsuxseg5ei16(_Float16 *, vuint16m1_t, vfloat16m1_t, vfloat16m1_t, vfloat16m1_t, vfloat16m1_t, vfloat16m1_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vsuxseg5ei16_v_m)))
void vsuxseg5ei16(vbool16_t, _Float16 *, vuint16m1_t, vfloat16m1_t, vfloat16m1_t, vfloat16m1_t, vfloat16m1_t, vfloat16m1_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vsuxseg5ei16_v)))
void vsuxseg5ei16(_Float16 *, vuint16mf2_t, vfloat16mf2_t, vfloat16mf2_t, vfloat16mf2_t, vfloat16mf2_t, vfloat16mf2_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vsuxseg5ei16_v_m)))
void vsuxseg5ei16(vbool32_t, _Float16 *, vuint16mf2_t, vfloat16mf2_t, vfloat16mf2_t, vfloat16mf2_t, vfloat16mf2_t, vfloat16mf2_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vsuxseg5ei16_v)))
void vsuxseg5ei16(_Float16 *, vuint16mf4_t, vfloat16mf4_t, vfloat16mf4_t, vfloat16mf4_t, vfloat16mf4_t, vfloat16mf4_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vsuxseg5ei16_v_m)))
void vsuxseg5ei16(vbool64_t, _Float16 *, vuint16mf4_t, vfloat16mf4_t, vfloat16mf4_t, vfloat16mf4_t, vfloat16mf4_t, vfloat16mf4_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vsuxseg6ei16_v)))
void vsuxseg6ei16(_Float16 *, vuint16m1_t, vfloat16m1_t, vfloat16m1_t, vfloat16m1_t, vfloat16m1_t, vfloat16m1_t, vfloat16m1_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vsuxseg6ei16_v_m)))
void vsuxseg6ei16(vbool16_t, _Float16 *, vuint16m1_t, vfloat16m1_t, vfloat16m1_t, vfloat16m1_t, vfloat16m1_t, vfloat16m1_t, vfloat16m1_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vsuxseg6ei16_v)))
void vsuxseg6ei16(_Float16 *, vuint16mf2_t, vfloat16mf2_t, vfloat16mf2_t, vfloat16mf2_t, vfloat16mf2_t, vfloat16mf2_t, vfloat16mf2_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vsuxseg6ei16_v_m)))
void vsuxseg6ei16(vbool32_t, _Float16 *, vuint16mf2_t, vfloat16mf2_t, vfloat16mf2_t, vfloat16mf2_t, vfloat16mf2_t, vfloat16mf2_t, vfloat16mf2_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vsuxseg6ei16_v)))
void vsuxseg6ei16(_Float16 *, vuint16mf4_t, vfloat16mf4_t, vfloat16mf4_t, vfloat16mf4_t, vfloat16mf4_t, vfloat16mf4_t, vfloat16mf4_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vsuxseg6ei16_v_m)))
void vsuxseg6ei16(vbool64_t, _Float16 *, vuint16mf4_t, vfloat16mf4_t, vfloat16mf4_t, vfloat16mf4_t, vfloat16mf4_t, vfloat16mf4_t, vfloat16mf4_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vsuxseg7ei16_v)))
void vsuxseg7ei16(_Float16 *, vuint16m1_t, vfloat16m1_t, vfloat16m1_t, vfloat16m1_t, vfloat16m1_t, vfloat16m1_t, vfloat16m1_t, vfloat16m1_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vsuxseg7ei16_v_m)))
void vsuxseg7ei16(vbool16_t, _Float16 *, vuint16m1_t, vfloat16m1_t, vfloat16m1_t, vfloat16m1_t, vfloat16m1_t, vfloat16m1_t, vfloat16m1_t, vfloat16m1_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vsuxseg7ei16_v)))
void vsuxseg7ei16(_Float16 *, vuint16mf2_t, vfloat16mf2_t, vfloat16mf2_t, vfloat16mf2_t, vfloat16mf2_t, vfloat16mf2_t, vfloat16mf2_t, vfloat16mf2_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vsuxseg7ei16_v_m)))
void vsuxseg7ei16(vbool32_t, _Float16 *, vuint16mf2_t, vfloat16mf2_t, vfloat16mf2_t, vfloat16mf2_t, vfloat16mf2_t, vfloat16mf2_t, vfloat16mf2_t, vfloat16mf2_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vsuxseg7ei16_v)))
void vsuxseg7ei16(_Float16 *, vuint16mf4_t, vfloat16mf4_t, vfloat16mf4_t, vfloat16mf4_t, vfloat16mf4_t, vfloat16mf4_t, vfloat16mf4_t, vfloat16mf4_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vsuxseg7ei16_v_m)))
void vsuxseg7ei16(vbool64_t, _Float16 *, vuint16mf4_t, vfloat16mf4_t, vfloat16mf4_t, vfloat16mf4_t, vfloat16mf4_t, vfloat16mf4_t, vfloat16mf4_t, vfloat16mf4_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vsuxseg8ei16_v)))
void vsuxseg8ei16(_Float16 *, vuint16m1_t, vfloat16m1_t, vfloat16m1_t, vfloat16m1_t, vfloat16m1_t, vfloat16m1_t, vfloat16m1_t, vfloat16m1_t, vfloat16m1_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vsuxseg8ei16_v_m)))
void vsuxseg8ei16(vbool16_t, _Float16 *, vuint16m1_t, vfloat16m1_t, vfloat16m1_t, vfloat16m1_t, vfloat16m1_t, vfloat16m1_t, vfloat16m1_t, vfloat16m1_t, vfloat16m1_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vsuxseg8ei16_v)))
void vsuxseg8ei16(_Float16 *, vuint16mf2_t, vfloat16mf2_t, vfloat16mf2_t, vfloat16mf2_t, vfloat16mf2_t, vfloat16mf2_t, vfloat16mf2_t, vfloat16mf2_t, vfloat16mf2_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vsuxseg8ei16_v_m)))
void vsuxseg8ei16(vbool32_t, _Float16 *, vuint16mf2_t, vfloat16mf2_t, vfloat16mf2_t, vfloat16mf2_t, vfloat16mf2_t, vfloat16mf2_t, vfloat16mf2_t, vfloat16mf2_t, vfloat16mf2_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vsuxseg8ei16_v)))
void vsuxseg8ei16(_Float16 *, vuint16mf4_t, vfloat16mf4_t, vfloat16mf4_t, vfloat16mf4_t, vfloat16mf4_t, vfloat16mf4_t, vfloat16mf4_t, vfloat16mf4_t, vfloat16mf4_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vsuxseg8ei16_v_m)))
void vsuxseg8ei16(vbool64_t, _Float16 *, vuint16mf4_t, vfloat16mf4_t, vfloat16mf4_t, vfloat16mf4_t, vfloat16mf4_t, vfloat16mf4_t, vfloat16mf4_t, vfloat16mf4_t, vfloat16mf4_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vsuxseg2ei32_v)))
void vsuxseg2ei32(_Float16 *, vuint32m2_t, vfloat16m1_t, vfloat16m1_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vsuxseg2ei32_v_m)))
void vsuxseg2ei32(vbool16_t, _Float16 *, vuint32m2_t, vfloat16m1_t, vfloat16m1_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vsuxseg2ei32_v)))
void vsuxseg2ei32(_Float16 *, vuint32m4_t, vfloat16m2_t, vfloat16m2_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vsuxseg2ei32_v_m)))
void vsuxseg2ei32(vbool8_t, _Float16 *, vuint32m4_t, vfloat16m2_t, vfloat16m2_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vsuxseg2ei32_v)))
void vsuxseg2ei32(_Float16 *, vuint32m8_t, vfloat16m4_t, vfloat16m4_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vsuxseg2ei32_v_m)))
void vsuxseg2ei32(vbool4_t, _Float16 *, vuint32m8_t, vfloat16m4_t, vfloat16m4_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vsuxseg2ei32_v)))
void vsuxseg2ei32(_Float16 *, vuint32m1_t, vfloat16mf2_t, vfloat16mf2_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vsuxseg2ei32_v_m)))
void vsuxseg2ei32(vbool32_t, _Float16 *, vuint32m1_t, vfloat16mf2_t, vfloat16mf2_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vsuxseg2ei32_v)))
void vsuxseg2ei32(_Float16 *, vuint32mf2_t, vfloat16mf4_t, vfloat16mf4_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vsuxseg2ei32_v_m)))
void vsuxseg2ei32(vbool64_t, _Float16 *, vuint32mf2_t, vfloat16mf4_t, vfloat16mf4_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vsuxseg3ei32_v)))
void vsuxseg3ei32(_Float16 *, vuint32m2_t, vfloat16m1_t, vfloat16m1_t, vfloat16m1_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vsuxseg3ei32_v_m)))
void vsuxseg3ei32(vbool16_t, _Float16 *, vuint32m2_t, vfloat16m1_t, vfloat16m1_t, vfloat16m1_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vsuxseg3ei32_v)))
void vsuxseg3ei32(_Float16 *, vuint32m4_t, vfloat16m2_t, vfloat16m2_t, vfloat16m2_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vsuxseg3ei32_v_m)))
void vsuxseg3ei32(vbool8_t, _Float16 *, vuint32m4_t, vfloat16m2_t, vfloat16m2_t, vfloat16m2_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vsuxseg3ei32_v)))
void vsuxseg3ei32(_Float16 *, vuint32m1_t, vfloat16mf2_t, vfloat16mf2_t, vfloat16mf2_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vsuxseg3ei32_v_m)))
void vsuxseg3ei32(vbool32_t, _Float16 *, vuint32m1_t, vfloat16mf2_t, vfloat16mf2_t, vfloat16mf2_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vsuxseg3ei32_v)))
void vsuxseg3ei32(_Float16 *, vuint32mf2_t, vfloat16mf4_t, vfloat16mf4_t, vfloat16mf4_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vsuxseg3ei32_v_m)))
void vsuxseg3ei32(vbool64_t, _Float16 *, vuint32mf2_t, vfloat16mf4_t, vfloat16mf4_t, vfloat16mf4_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vsuxseg4ei32_v)))
void vsuxseg4ei32(_Float16 *, vuint32m2_t, vfloat16m1_t, vfloat16m1_t, vfloat16m1_t, vfloat16m1_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vsuxseg4ei32_v_m)))
void vsuxseg4ei32(vbool16_t, _Float16 *, vuint32m2_t, vfloat16m1_t, vfloat16m1_t, vfloat16m1_t, vfloat16m1_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vsuxseg4ei32_v)))
void vsuxseg4ei32(_Float16 *, vuint32m4_t, vfloat16m2_t, vfloat16m2_t, vfloat16m2_t, vfloat16m2_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vsuxseg4ei32_v_m)))
void vsuxseg4ei32(vbool8_t, _Float16 *, vuint32m4_t, vfloat16m2_t, vfloat16m2_t, vfloat16m2_t, vfloat16m2_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vsuxseg4ei32_v)))
void vsuxseg4ei32(_Float16 *, vuint32m1_t, vfloat16mf2_t, vfloat16mf2_t, vfloat16mf2_t, vfloat16mf2_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vsuxseg4ei32_v_m)))
void vsuxseg4ei32(vbool32_t, _Float16 *, vuint32m1_t, vfloat16mf2_t, vfloat16mf2_t, vfloat16mf2_t, vfloat16mf2_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vsuxseg4ei32_v)))
void vsuxseg4ei32(_Float16 *, vuint32mf2_t, vfloat16mf4_t, vfloat16mf4_t, vfloat16mf4_t, vfloat16mf4_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vsuxseg4ei32_v_m)))
void vsuxseg4ei32(vbool64_t, _Float16 *, vuint32mf2_t, vfloat16mf4_t, vfloat16mf4_t, vfloat16mf4_t, vfloat16mf4_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vsuxseg5ei32_v)))
void vsuxseg5ei32(_Float16 *, vuint32m2_t, vfloat16m1_t, vfloat16m1_t, vfloat16m1_t, vfloat16m1_t, vfloat16m1_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vsuxseg5ei32_v_m)))
void vsuxseg5ei32(vbool16_t, _Float16 *, vuint32m2_t, vfloat16m1_t, vfloat16m1_t, vfloat16m1_t, vfloat16m1_t, vfloat16m1_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vsuxseg5ei32_v)))
void vsuxseg5ei32(_Float16 *, vuint32m1_t, vfloat16mf2_t, vfloat16mf2_t, vfloat16mf2_t, vfloat16mf2_t, vfloat16mf2_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vsuxseg5ei32_v_m)))
void vsuxseg5ei32(vbool32_t, _Float16 *, vuint32m1_t, vfloat16mf2_t, vfloat16mf2_t, vfloat16mf2_t, vfloat16mf2_t, vfloat16mf2_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vsuxseg5ei32_v)))
void vsuxseg5ei32(_Float16 *, vuint32mf2_t, vfloat16mf4_t, vfloat16mf4_t, vfloat16mf4_t, vfloat16mf4_t, vfloat16mf4_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vsuxseg5ei32_v_m)))
void vsuxseg5ei32(vbool64_t, _Float16 *, vuint32mf2_t, vfloat16mf4_t, vfloat16mf4_t, vfloat16mf4_t, vfloat16mf4_t, vfloat16mf4_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vsuxseg6ei32_v)))
void vsuxseg6ei32(_Float16 *, vuint32m2_t, vfloat16m1_t, vfloat16m1_t, vfloat16m1_t, vfloat16m1_t, vfloat16m1_t, vfloat16m1_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vsuxseg6ei32_v_m)))
void vsuxseg6ei32(vbool16_t, _Float16 *, vuint32m2_t, vfloat16m1_t, vfloat16m1_t, vfloat16m1_t, vfloat16m1_t, vfloat16m1_t, vfloat16m1_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vsuxseg6ei32_v)))
void vsuxseg6ei32(_Float16 *, vuint32m1_t, vfloat16mf2_t, vfloat16mf2_t, vfloat16mf2_t, vfloat16mf2_t, vfloat16mf2_t, vfloat16mf2_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vsuxseg6ei32_v_m)))
void vsuxseg6ei32(vbool32_t, _Float16 *, vuint32m1_t, vfloat16mf2_t, vfloat16mf2_t, vfloat16mf2_t, vfloat16mf2_t, vfloat16mf2_t, vfloat16mf2_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vsuxseg6ei32_v)))
void vsuxseg6ei32(_Float16 *, vuint32mf2_t, vfloat16mf4_t, vfloat16mf4_t, vfloat16mf4_t, vfloat16mf4_t, vfloat16mf4_t, vfloat16mf4_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vsuxseg6ei32_v_m)))
void vsuxseg6ei32(vbool64_t, _Float16 *, vuint32mf2_t, vfloat16mf4_t, vfloat16mf4_t, vfloat16mf4_t, vfloat16mf4_t, vfloat16mf4_t, vfloat16mf4_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vsuxseg7ei32_v)))
void vsuxseg7ei32(_Float16 *, vuint32m2_t, vfloat16m1_t, vfloat16m1_t, vfloat16m1_t, vfloat16m1_t, vfloat16m1_t, vfloat16m1_t, vfloat16m1_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vsuxseg7ei32_v_m)))
void vsuxseg7ei32(vbool16_t, _Float16 *, vuint32m2_t, vfloat16m1_t, vfloat16m1_t, vfloat16m1_t, vfloat16m1_t, vfloat16m1_t, vfloat16m1_t, vfloat16m1_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vsuxseg7ei32_v)))
void vsuxseg7ei32(_Float16 *, vuint32m1_t, vfloat16mf2_t, vfloat16mf2_t, vfloat16mf2_t, vfloat16mf2_t, vfloat16mf2_t, vfloat16mf2_t, vfloat16mf2_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vsuxseg7ei32_v_m)))
void vsuxseg7ei32(vbool32_t, _Float16 *, vuint32m1_t, vfloat16mf2_t, vfloat16mf2_t, vfloat16mf2_t, vfloat16mf2_t, vfloat16mf2_t, vfloat16mf2_t, vfloat16mf2_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vsuxseg7ei32_v)))
void vsuxseg7ei32(_Float16 *, vuint32mf2_t, vfloat16mf4_t, vfloat16mf4_t, vfloat16mf4_t, vfloat16mf4_t, vfloat16mf4_t, vfloat16mf4_t, vfloat16mf4_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vsuxseg7ei32_v_m)))
void vsuxseg7ei32(vbool64_t, _Float16 *, vuint32mf2_t, vfloat16mf4_t, vfloat16mf4_t, vfloat16mf4_t, vfloat16mf4_t, vfloat16mf4_t, vfloat16mf4_t, vfloat16mf4_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vsuxseg8ei32_v)))
void vsuxseg8ei32(_Float16 *, vuint32m2_t, vfloat16m1_t, vfloat16m1_t, vfloat16m1_t, vfloat16m1_t, vfloat16m1_t, vfloat16m1_t, vfloat16m1_t, vfloat16m1_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vsuxseg8ei32_v_m)))
void vsuxseg8ei32(vbool16_t, _Float16 *, vuint32m2_t, vfloat16m1_t, vfloat16m1_t, vfloat16m1_t, vfloat16m1_t, vfloat16m1_t, vfloat16m1_t, vfloat16m1_t, vfloat16m1_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vsuxseg8ei32_v)))
void vsuxseg8ei32(_Float16 *, vuint32m1_t, vfloat16mf2_t, vfloat16mf2_t, vfloat16mf2_t, vfloat16mf2_t, vfloat16mf2_t, vfloat16mf2_t, vfloat16mf2_t, vfloat16mf2_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vsuxseg8ei32_v_m)))
void vsuxseg8ei32(vbool32_t, _Float16 *, vuint32m1_t, vfloat16mf2_t, vfloat16mf2_t, vfloat16mf2_t, vfloat16mf2_t, vfloat16mf2_t, vfloat16mf2_t, vfloat16mf2_t, vfloat16mf2_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vsuxseg8ei32_v)))
void vsuxseg8ei32(_Float16 *, vuint32mf2_t, vfloat16mf4_t, vfloat16mf4_t, vfloat16mf4_t, vfloat16mf4_t, vfloat16mf4_t, vfloat16mf4_t, vfloat16mf4_t, vfloat16mf4_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vsuxseg8ei32_v_m)))
void vsuxseg8ei32(vbool64_t, _Float16 *, vuint32mf2_t, vfloat16mf4_t, vfloat16mf4_t, vfloat16mf4_t, vfloat16mf4_t, vfloat16mf4_t, vfloat16mf4_t, vfloat16mf4_t, vfloat16mf4_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vsoxseg2ei8_v)))
void vsoxseg2ei8(_Float16 *, vuint8mf2_t, vfloat16m1_t, vfloat16m1_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vsoxseg2ei8_v_m)))
void vsoxseg2ei8(vbool16_t, _Float16 *, vuint8mf2_t, vfloat16m1_t, vfloat16m1_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vsoxseg2ei8_v)))
void vsoxseg2ei8(_Float16 *, vuint8m1_t, vfloat16m2_t, vfloat16m2_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vsoxseg2ei8_v_m)))
void vsoxseg2ei8(vbool8_t, _Float16 *, vuint8m1_t, vfloat16m2_t, vfloat16m2_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vsoxseg2ei8_v)))
void vsoxseg2ei8(_Float16 *, vuint8m2_t, vfloat16m4_t, vfloat16m4_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vsoxseg2ei8_v_m)))
void vsoxseg2ei8(vbool4_t, _Float16 *, vuint8m2_t, vfloat16m4_t, vfloat16m4_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vsoxseg2ei8_v)))
void vsoxseg2ei8(_Float16 *, vuint8mf4_t, vfloat16mf2_t, vfloat16mf2_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vsoxseg2ei8_v_m)))
void vsoxseg2ei8(vbool32_t, _Float16 *, vuint8mf4_t, vfloat16mf2_t, vfloat16mf2_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vsoxseg2ei8_v)))
void vsoxseg2ei8(_Float16 *, vuint8mf8_t, vfloat16mf4_t, vfloat16mf4_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vsoxseg2ei8_v_m)))
void vsoxseg2ei8(vbool64_t, _Float16 *, vuint8mf8_t, vfloat16mf4_t, vfloat16mf4_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vsoxseg3ei8_v)))
void vsoxseg3ei8(_Float16 *, vuint8mf2_t, vfloat16m1_t, vfloat16m1_t, vfloat16m1_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vsoxseg3ei8_v_m)))
void vsoxseg3ei8(vbool16_t, _Float16 *, vuint8mf2_t, vfloat16m1_t, vfloat16m1_t, vfloat16m1_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vsoxseg3ei8_v)))
void vsoxseg3ei8(_Float16 *, vuint8m1_t, vfloat16m2_t, vfloat16m2_t, vfloat16m2_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vsoxseg3ei8_v_m)))
void vsoxseg3ei8(vbool8_t, _Float16 *, vuint8m1_t, vfloat16m2_t, vfloat16m2_t, vfloat16m2_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vsoxseg3ei8_v)))
void vsoxseg3ei8(_Float16 *, vuint8mf4_t, vfloat16mf2_t, vfloat16mf2_t, vfloat16mf2_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vsoxseg3ei8_v_m)))
void vsoxseg3ei8(vbool32_t, _Float16 *, vuint8mf4_t, vfloat16mf2_t, vfloat16mf2_t, vfloat16mf2_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vsoxseg3ei8_v)))
void vsoxseg3ei8(_Float16 *, vuint8mf8_t, vfloat16mf4_t, vfloat16mf4_t, vfloat16mf4_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vsoxseg3ei8_v_m)))
void vsoxseg3ei8(vbool64_t, _Float16 *, vuint8mf8_t, vfloat16mf4_t, vfloat16mf4_t, vfloat16mf4_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vsoxseg4ei8_v)))
void vsoxseg4ei8(_Float16 *, vuint8mf2_t, vfloat16m1_t, vfloat16m1_t, vfloat16m1_t, vfloat16m1_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vsoxseg4ei8_v_m)))
void vsoxseg4ei8(vbool16_t, _Float16 *, vuint8mf2_t, vfloat16m1_t, vfloat16m1_t, vfloat16m1_t, vfloat16m1_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vsoxseg4ei8_v)))
void vsoxseg4ei8(_Float16 *, vuint8m1_t, vfloat16m2_t, vfloat16m2_t, vfloat16m2_t, vfloat16m2_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vsoxseg4ei8_v_m)))
void vsoxseg4ei8(vbool8_t, _Float16 *, vuint8m1_t, vfloat16m2_t, vfloat16m2_t, vfloat16m2_t, vfloat16m2_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vsoxseg4ei8_v)))
void vsoxseg4ei8(_Float16 *, vuint8mf4_t, vfloat16mf2_t, vfloat16mf2_t, vfloat16mf2_t, vfloat16mf2_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vsoxseg4ei8_v_m)))
void vsoxseg4ei8(vbool32_t, _Float16 *, vuint8mf4_t, vfloat16mf2_t, vfloat16mf2_t, vfloat16mf2_t, vfloat16mf2_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vsoxseg4ei8_v)))
void vsoxseg4ei8(_Float16 *, vuint8mf8_t, vfloat16mf4_t, vfloat16mf4_t, vfloat16mf4_t, vfloat16mf4_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vsoxseg4ei8_v_m)))
void vsoxseg4ei8(vbool64_t, _Float16 *, vuint8mf8_t, vfloat16mf4_t, vfloat16mf4_t, vfloat16mf4_t, vfloat16mf4_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vsoxseg5ei8_v)))
void vsoxseg5ei8(_Float16 *, vuint8mf2_t, vfloat16m1_t, vfloat16m1_t, vfloat16m1_t, vfloat16m1_t, vfloat16m1_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vsoxseg5ei8_v_m)))
void vsoxseg5ei8(vbool16_t, _Float16 *, vuint8mf2_t, vfloat16m1_t, vfloat16m1_t, vfloat16m1_t, vfloat16m1_t, vfloat16m1_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vsoxseg5ei8_v)))
void vsoxseg5ei8(_Float16 *, vuint8mf4_t, vfloat16mf2_t, vfloat16mf2_t, vfloat16mf2_t, vfloat16mf2_t, vfloat16mf2_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vsoxseg5ei8_v_m)))
void vsoxseg5ei8(vbool32_t, _Float16 *, vuint8mf4_t, vfloat16mf2_t, vfloat16mf2_t, vfloat16mf2_t, vfloat16mf2_t, vfloat16mf2_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vsoxseg5ei8_v)))
void vsoxseg5ei8(_Float16 *, vuint8mf8_t, vfloat16mf4_t, vfloat16mf4_t, vfloat16mf4_t, vfloat16mf4_t, vfloat16mf4_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vsoxseg5ei8_v_m)))
void vsoxseg5ei8(vbool64_t, _Float16 *, vuint8mf8_t, vfloat16mf4_t, vfloat16mf4_t, vfloat16mf4_t, vfloat16mf4_t, vfloat16mf4_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vsoxseg6ei8_v)))
void vsoxseg6ei8(_Float16 *, vuint8mf2_t, vfloat16m1_t, vfloat16m1_t, vfloat16m1_t, vfloat16m1_t, vfloat16m1_t, vfloat16m1_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vsoxseg6ei8_v_m)))
void vsoxseg6ei8(vbool16_t, _Float16 *, vuint8mf2_t, vfloat16m1_t, vfloat16m1_t, vfloat16m1_t, vfloat16m1_t, vfloat16m1_t, vfloat16m1_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vsoxseg6ei8_v)))
void vsoxseg6ei8(_Float16 *, vuint8mf4_t, vfloat16mf2_t, vfloat16mf2_t, vfloat16mf2_t, vfloat16mf2_t, vfloat16mf2_t, vfloat16mf2_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vsoxseg6ei8_v_m)))
void vsoxseg6ei8(vbool32_t, _Float16 *, vuint8mf4_t, vfloat16mf2_t, vfloat16mf2_t, vfloat16mf2_t, vfloat16mf2_t, vfloat16mf2_t, vfloat16mf2_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vsoxseg6ei8_v)))
void vsoxseg6ei8(_Float16 *, vuint8mf8_t, vfloat16mf4_t, vfloat16mf4_t, vfloat16mf4_t, vfloat16mf4_t, vfloat16mf4_t, vfloat16mf4_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vsoxseg6ei8_v_m)))
void vsoxseg6ei8(vbool64_t, _Float16 *, vuint8mf8_t, vfloat16mf4_t, vfloat16mf4_t, vfloat16mf4_t, vfloat16mf4_t, vfloat16mf4_t, vfloat16mf4_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vsoxseg7ei8_v)))
void vsoxseg7ei8(_Float16 *, vuint8mf2_t, vfloat16m1_t, vfloat16m1_t, vfloat16m1_t, vfloat16m1_t, vfloat16m1_t, vfloat16m1_t, vfloat16m1_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vsoxseg7ei8_v_m)))
void vsoxseg7ei8(vbool16_t, _Float16 *, vuint8mf2_t, vfloat16m1_t, vfloat16m1_t, vfloat16m1_t, vfloat16m1_t, vfloat16m1_t, vfloat16m1_t, vfloat16m1_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vsoxseg7ei8_v)))
void vsoxseg7ei8(_Float16 *, vuint8mf4_t, vfloat16mf2_t, vfloat16mf2_t, vfloat16mf2_t, vfloat16mf2_t, vfloat16mf2_t, vfloat16mf2_t, vfloat16mf2_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vsoxseg7ei8_v_m)))
void vsoxseg7ei8(vbool32_t, _Float16 *, vuint8mf4_t, vfloat16mf2_t, vfloat16mf2_t, vfloat16mf2_t, vfloat16mf2_t, vfloat16mf2_t, vfloat16mf2_t, vfloat16mf2_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vsoxseg7ei8_v)))
void vsoxseg7ei8(_Float16 *, vuint8mf8_t, vfloat16mf4_t, vfloat16mf4_t, vfloat16mf4_t, vfloat16mf4_t, vfloat16mf4_t, vfloat16mf4_t, vfloat16mf4_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vsoxseg7ei8_v_m)))
void vsoxseg7ei8(vbool64_t, _Float16 *, vuint8mf8_t, vfloat16mf4_t, vfloat16mf4_t, vfloat16mf4_t, vfloat16mf4_t, vfloat16mf4_t, vfloat16mf4_t, vfloat16mf4_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vsoxseg8ei8_v)))
void vsoxseg8ei8(_Float16 *, vuint8mf2_t, vfloat16m1_t, vfloat16m1_t, vfloat16m1_t, vfloat16m1_t, vfloat16m1_t, vfloat16m1_t, vfloat16m1_t, vfloat16m1_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vsoxseg8ei8_v_m)))
void vsoxseg8ei8(vbool16_t, _Float16 *, vuint8mf2_t, vfloat16m1_t, vfloat16m1_t, vfloat16m1_t, vfloat16m1_t, vfloat16m1_t, vfloat16m1_t, vfloat16m1_t, vfloat16m1_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vsoxseg8ei8_v)))
void vsoxseg8ei8(_Float16 *, vuint8mf4_t, vfloat16mf2_t, vfloat16mf2_t, vfloat16mf2_t, vfloat16mf2_t, vfloat16mf2_t, vfloat16mf2_t, vfloat16mf2_t, vfloat16mf2_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vsoxseg8ei8_v_m)))
void vsoxseg8ei8(vbool32_t, _Float16 *, vuint8mf4_t, vfloat16mf2_t, vfloat16mf2_t, vfloat16mf2_t, vfloat16mf2_t, vfloat16mf2_t, vfloat16mf2_t, vfloat16mf2_t, vfloat16mf2_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vsoxseg8ei8_v)))
void vsoxseg8ei8(_Float16 *, vuint8mf8_t, vfloat16mf4_t, vfloat16mf4_t, vfloat16mf4_t, vfloat16mf4_t, vfloat16mf4_t, vfloat16mf4_t, vfloat16mf4_t, vfloat16mf4_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vsoxseg8ei8_v_m)))
void vsoxseg8ei8(vbool64_t, _Float16 *, vuint8mf8_t, vfloat16mf4_t, vfloat16mf4_t, vfloat16mf4_t, vfloat16mf4_t, vfloat16mf4_t, vfloat16mf4_t, vfloat16mf4_t, vfloat16mf4_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vsoxseg2ei16_v)))
void vsoxseg2ei16(_Float16 *, vuint16m1_t, vfloat16m1_t, vfloat16m1_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vsoxseg2ei16_v_m)))
void vsoxseg2ei16(vbool16_t, _Float16 *, vuint16m1_t, vfloat16m1_t, vfloat16m1_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vsoxseg2ei16_v)))
void vsoxseg2ei16(_Float16 *, vuint16m2_t, vfloat16m2_t, vfloat16m2_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vsoxseg2ei16_v_m)))
void vsoxseg2ei16(vbool8_t, _Float16 *, vuint16m2_t, vfloat16m2_t, vfloat16m2_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vsoxseg2ei16_v)))
void vsoxseg2ei16(_Float16 *, vuint16m4_t, vfloat16m4_t, vfloat16m4_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vsoxseg2ei16_v_m)))
void vsoxseg2ei16(vbool4_t, _Float16 *, vuint16m4_t, vfloat16m4_t, vfloat16m4_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vsoxseg2ei16_v)))
void vsoxseg2ei16(_Float16 *, vuint16mf2_t, vfloat16mf2_t, vfloat16mf2_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vsoxseg2ei16_v_m)))
void vsoxseg2ei16(vbool32_t, _Float16 *, vuint16mf2_t, vfloat16mf2_t, vfloat16mf2_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vsoxseg2ei16_v)))
void vsoxseg2ei16(_Float16 *, vuint16mf4_t, vfloat16mf4_t, vfloat16mf4_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vsoxseg2ei16_v_m)))
void vsoxseg2ei16(vbool64_t, _Float16 *, vuint16mf4_t, vfloat16mf4_t, vfloat16mf4_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vsoxseg3ei16_v)))
void vsoxseg3ei16(_Float16 *, vuint16m1_t, vfloat16m1_t, vfloat16m1_t, vfloat16m1_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vsoxseg3ei16_v_m)))
void vsoxseg3ei16(vbool16_t, _Float16 *, vuint16m1_t, vfloat16m1_t, vfloat16m1_t, vfloat16m1_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vsoxseg3ei16_v)))
void vsoxseg3ei16(_Float16 *, vuint16m2_t, vfloat16m2_t, vfloat16m2_t, vfloat16m2_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vsoxseg3ei16_v_m)))
void vsoxseg3ei16(vbool8_t, _Float16 *, vuint16m2_t, vfloat16m2_t, vfloat16m2_t, vfloat16m2_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vsoxseg3ei16_v)))
void vsoxseg3ei16(_Float16 *, vuint16mf2_t, vfloat16mf2_t, vfloat16mf2_t, vfloat16mf2_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vsoxseg3ei16_v_m)))
void vsoxseg3ei16(vbool32_t, _Float16 *, vuint16mf2_t, vfloat16mf2_t, vfloat16mf2_t, vfloat16mf2_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vsoxseg3ei16_v)))
void vsoxseg3ei16(_Float16 *, vuint16mf4_t, vfloat16mf4_t, vfloat16mf4_t, vfloat16mf4_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vsoxseg3ei16_v_m)))
void vsoxseg3ei16(vbool64_t, _Float16 *, vuint16mf4_t, vfloat16mf4_t, vfloat16mf4_t, vfloat16mf4_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vsoxseg4ei16_v)))
void vsoxseg4ei16(_Float16 *, vuint16m1_t, vfloat16m1_t, vfloat16m1_t, vfloat16m1_t, vfloat16m1_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vsoxseg4ei16_v_m)))
void vsoxseg4ei16(vbool16_t, _Float16 *, vuint16m1_t, vfloat16m1_t, vfloat16m1_t, vfloat16m1_t, vfloat16m1_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vsoxseg4ei16_v)))
void vsoxseg4ei16(_Float16 *, vuint16m2_t, vfloat16m2_t, vfloat16m2_t, vfloat16m2_t, vfloat16m2_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vsoxseg4ei16_v_m)))
void vsoxseg4ei16(vbool8_t, _Float16 *, vuint16m2_t, vfloat16m2_t, vfloat16m2_t, vfloat16m2_t, vfloat16m2_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vsoxseg4ei16_v)))
void vsoxseg4ei16(_Float16 *, vuint16mf2_t, vfloat16mf2_t, vfloat16mf2_t, vfloat16mf2_t, vfloat16mf2_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vsoxseg4ei16_v_m)))
void vsoxseg4ei16(vbool32_t, _Float16 *, vuint16mf2_t, vfloat16mf2_t, vfloat16mf2_t, vfloat16mf2_t, vfloat16mf2_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vsoxseg4ei16_v)))
void vsoxseg4ei16(_Float16 *, vuint16mf4_t, vfloat16mf4_t, vfloat16mf4_t, vfloat16mf4_t, vfloat16mf4_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vsoxseg4ei16_v_m)))
void vsoxseg4ei16(vbool64_t, _Float16 *, vuint16mf4_t, vfloat16mf4_t, vfloat16mf4_t, vfloat16mf4_t, vfloat16mf4_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vsoxseg5ei16_v)))
void vsoxseg5ei16(_Float16 *, vuint16m1_t, vfloat16m1_t, vfloat16m1_t, vfloat16m1_t, vfloat16m1_t, vfloat16m1_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vsoxseg5ei16_v_m)))
void vsoxseg5ei16(vbool16_t, _Float16 *, vuint16m1_t, vfloat16m1_t, vfloat16m1_t, vfloat16m1_t, vfloat16m1_t, vfloat16m1_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vsoxseg5ei16_v)))
void vsoxseg5ei16(_Float16 *, vuint16mf2_t, vfloat16mf2_t, vfloat16mf2_t, vfloat16mf2_t, vfloat16mf2_t, vfloat16mf2_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vsoxseg5ei16_v_m)))
void vsoxseg5ei16(vbool32_t, _Float16 *, vuint16mf2_t, vfloat16mf2_t, vfloat16mf2_t, vfloat16mf2_t, vfloat16mf2_t, vfloat16mf2_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vsoxseg5ei16_v)))
void vsoxseg5ei16(_Float16 *, vuint16mf4_t, vfloat16mf4_t, vfloat16mf4_t, vfloat16mf4_t, vfloat16mf4_t, vfloat16mf4_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vsoxseg5ei16_v_m)))
void vsoxseg5ei16(vbool64_t, _Float16 *, vuint16mf4_t, vfloat16mf4_t, vfloat16mf4_t, vfloat16mf4_t, vfloat16mf4_t, vfloat16mf4_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vsoxseg6ei16_v)))
void vsoxseg6ei16(_Float16 *, vuint16m1_t, vfloat16m1_t, vfloat16m1_t, vfloat16m1_t, vfloat16m1_t, vfloat16m1_t, vfloat16m1_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vsoxseg6ei16_v_m)))
void vsoxseg6ei16(vbool16_t, _Float16 *, vuint16m1_t, vfloat16m1_t, vfloat16m1_t, vfloat16m1_t, vfloat16m1_t, vfloat16m1_t, vfloat16m1_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vsoxseg6ei16_v)))
void vsoxseg6ei16(_Float16 *, vuint16mf2_t, vfloat16mf2_t, vfloat16mf2_t, vfloat16mf2_t, vfloat16mf2_t, vfloat16mf2_t, vfloat16mf2_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vsoxseg6ei16_v_m)))
void vsoxseg6ei16(vbool32_t, _Float16 *, vuint16mf2_t, vfloat16mf2_t, vfloat16mf2_t, vfloat16mf2_t, vfloat16mf2_t, vfloat16mf2_t, vfloat16mf2_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vsoxseg6ei16_v)))
void vsoxseg6ei16(_Float16 *, vuint16mf4_t, vfloat16mf4_t, vfloat16mf4_t, vfloat16mf4_t, vfloat16mf4_t, vfloat16mf4_t, vfloat16mf4_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vsoxseg6ei16_v_m)))
void vsoxseg6ei16(vbool64_t, _Float16 *, vuint16mf4_t, vfloat16mf4_t, vfloat16mf4_t, vfloat16mf4_t, vfloat16mf4_t, vfloat16mf4_t, vfloat16mf4_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vsoxseg7ei16_v)))
void vsoxseg7ei16(_Float16 *, vuint16m1_t, vfloat16m1_t, vfloat16m1_t, vfloat16m1_t, vfloat16m1_t, vfloat16m1_t, vfloat16m1_t, vfloat16m1_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vsoxseg7ei16_v_m)))
void vsoxseg7ei16(vbool16_t, _Float16 *, vuint16m1_t, vfloat16m1_t, vfloat16m1_t, vfloat16m1_t, vfloat16m1_t, vfloat16m1_t, vfloat16m1_t, vfloat16m1_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vsoxseg7ei16_v)))
void vsoxseg7ei16(_Float16 *, vuint16mf2_t, vfloat16mf2_t, vfloat16mf2_t, vfloat16mf2_t, vfloat16mf2_t, vfloat16mf2_t, vfloat16mf2_t, vfloat16mf2_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vsoxseg7ei16_v_m)))
void vsoxseg7ei16(vbool32_t, _Float16 *, vuint16mf2_t, vfloat16mf2_t, vfloat16mf2_t, vfloat16mf2_t, vfloat16mf2_t, vfloat16mf2_t, vfloat16mf2_t, vfloat16mf2_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vsoxseg7ei16_v)))
void vsoxseg7ei16(_Float16 *, vuint16mf4_t, vfloat16mf4_t, vfloat16mf4_t, vfloat16mf4_t, vfloat16mf4_t, vfloat16mf4_t, vfloat16mf4_t, vfloat16mf4_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vsoxseg7ei16_v_m)))
void vsoxseg7ei16(vbool64_t, _Float16 *, vuint16mf4_t, vfloat16mf4_t, vfloat16mf4_t, vfloat16mf4_t, vfloat16mf4_t, vfloat16mf4_t, vfloat16mf4_t, vfloat16mf4_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vsoxseg8ei16_v)))
void vsoxseg8ei16(_Float16 *, vuint16m1_t, vfloat16m1_t, vfloat16m1_t, vfloat16m1_t, vfloat16m1_t, vfloat16m1_t, vfloat16m1_t, vfloat16m1_t, vfloat16m1_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vsoxseg8ei16_v_m)))
void vsoxseg8ei16(vbool16_t, _Float16 *, vuint16m1_t, vfloat16m1_t, vfloat16m1_t, vfloat16m1_t, vfloat16m1_t, vfloat16m1_t, vfloat16m1_t, vfloat16m1_t, vfloat16m1_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vsoxseg8ei16_v)))
void vsoxseg8ei16(_Float16 *, vuint16mf2_t, vfloat16mf2_t, vfloat16mf2_t, vfloat16mf2_t, vfloat16mf2_t, vfloat16mf2_t, vfloat16mf2_t, vfloat16mf2_t, vfloat16mf2_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vsoxseg8ei16_v_m)))
void vsoxseg8ei16(vbool32_t, _Float16 *, vuint16mf2_t, vfloat16mf2_t, vfloat16mf2_t, vfloat16mf2_t, vfloat16mf2_t, vfloat16mf2_t, vfloat16mf2_t, vfloat16mf2_t, vfloat16mf2_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vsoxseg8ei16_v)))
void vsoxseg8ei16(_Float16 *, vuint16mf4_t, vfloat16mf4_t, vfloat16mf4_t, vfloat16mf4_t, vfloat16mf4_t, vfloat16mf4_t, vfloat16mf4_t, vfloat16mf4_t, vfloat16mf4_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vsoxseg8ei16_v_m)))
void vsoxseg8ei16(vbool64_t, _Float16 *, vuint16mf4_t, vfloat16mf4_t, vfloat16mf4_t, vfloat16mf4_t, vfloat16mf4_t, vfloat16mf4_t, vfloat16mf4_t, vfloat16mf4_t, vfloat16mf4_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vsoxseg2ei32_v)))
void vsoxseg2ei32(_Float16 *, vuint32m2_t, vfloat16m1_t, vfloat16m1_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vsoxseg2ei32_v_m)))
void vsoxseg2ei32(vbool16_t, _Float16 *, vuint32m2_t, vfloat16m1_t, vfloat16m1_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vsoxseg2ei32_v)))
void vsoxseg2ei32(_Float16 *, vuint32m4_t, vfloat16m2_t, vfloat16m2_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vsoxseg2ei32_v_m)))
void vsoxseg2ei32(vbool8_t, _Float16 *, vuint32m4_t, vfloat16m2_t, vfloat16m2_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vsoxseg2ei32_v)))
void vsoxseg2ei32(_Float16 *, vuint32m8_t, vfloat16m4_t, vfloat16m4_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vsoxseg2ei32_v_m)))
void vsoxseg2ei32(vbool4_t, _Float16 *, vuint32m8_t, vfloat16m4_t, vfloat16m4_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vsoxseg2ei32_v)))
void vsoxseg2ei32(_Float16 *, vuint32m1_t, vfloat16mf2_t, vfloat16mf2_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vsoxseg2ei32_v_m)))
void vsoxseg2ei32(vbool32_t, _Float16 *, vuint32m1_t, vfloat16mf2_t, vfloat16mf2_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vsoxseg2ei32_v)))
void vsoxseg2ei32(_Float16 *, vuint32mf2_t, vfloat16mf4_t, vfloat16mf4_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vsoxseg2ei32_v_m)))
void vsoxseg2ei32(vbool64_t, _Float16 *, vuint32mf2_t, vfloat16mf4_t, vfloat16mf4_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vsoxseg3ei32_v)))
void vsoxseg3ei32(_Float16 *, vuint32m2_t, vfloat16m1_t, vfloat16m1_t, vfloat16m1_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vsoxseg3ei32_v_m)))
void vsoxseg3ei32(vbool16_t, _Float16 *, vuint32m2_t, vfloat16m1_t, vfloat16m1_t, vfloat16m1_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vsoxseg3ei32_v)))
void vsoxseg3ei32(_Float16 *, vuint32m4_t, vfloat16m2_t, vfloat16m2_t, vfloat16m2_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vsoxseg3ei32_v_m)))
void vsoxseg3ei32(vbool8_t, _Float16 *, vuint32m4_t, vfloat16m2_t, vfloat16m2_t, vfloat16m2_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vsoxseg3ei32_v)))
void vsoxseg3ei32(_Float16 *, vuint32m1_t, vfloat16mf2_t, vfloat16mf2_t, vfloat16mf2_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vsoxseg3ei32_v_m)))
void vsoxseg3ei32(vbool32_t, _Float16 *, vuint32m1_t, vfloat16mf2_t, vfloat16mf2_t, vfloat16mf2_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vsoxseg3ei32_v)))
void vsoxseg3ei32(_Float16 *, vuint32mf2_t, vfloat16mf4_t, vfloat16mf4_t, vfloat16mf4_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vsoxseg3ei32_v_m)))
void vsoxseg3ei32(vbool64_t, _Float16 *, vuint32mf2_t, vfloat16mf4_t, vfloat16mf4_t, vfloat16mf4_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vsoxseg4ei32_v)))
void vsoxseg4ei32(_Float16 *, vuint32m2_t, vfloat16m1_t, vfloat16m1_t, vfloat16m1_t, vfloat16m1_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vsoxseg4ei32_v_m)))
void vsoxseg4ei32(vbool16_t, _Float16 *, vuint32m2_t, vfloat16m1_t, vfloat16m1_t, vfloat16m1_t, vfloat16m1_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vsoxseg4ei32_v)))
void vsoxseg4ei32(_Float16 *, vuint32m4_t, vfloat16m2_t, vfloat16m2_t, vfloat16m2_t, vfloat16m2_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vsoxseg4ei32_v_m)))
void vsoxseg4ei32(vbool8_t, _Float16 *, vuint32m4_t, vfloat16m2_t, vfloat16m2_t, vfloat16m2_t, vfloat16m2_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vsoxseg4ei32_v)))
void vsoxseg4ei32(_Float16 *, vuint32m1_t, vfloat16mf2_t, vfloat16mf2_t, vfloat16mf2_t, vfloat16mf2_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vsoxseg4ei32_v_m)))
void vsoxseg4ei32(vbool32_t, _Float16 *, vuint32m1_t, vfloat16mf2_t, vfloat16mf2_t, vfloat16mf2_t, vfloat16mf2_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vsoxseg4ei32_v)))
void vsoxseg4ei32(_Float16 *, vuint32mf2_t, vfloat16mf4_t, vfloat16mf4_t, vfloat16mf4_t, vfloat16mf4_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vsoxseg4ei32_v_m)))
void vsoxseg4ei32(vbool64_t, _Float16 *, vuint32mf2_t, vfloat16mf4_t, vfloat16mf4_t, vfloat16mf4_t, vfloat16mf4_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vsoxseg5ei32_v)))
void vsoxseg5ei32(_Float16 *, vuint32m2_t, vfloat16m1_t, vfloat16m1_t, vfloat16m1_t, vfloat16m1_t, vfloat16m1_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vsoxseg5ei32_v_m)))
void vsoxseg5ei32(vbool16_t, _Float16 *, vuint32m2_t, vfloat16m1_t, vfloat16m1_t, vfloat16m1_t, vfloat16m1_t, vfloat16m1_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vsoxseg5ei32_v)))
void vsoxseg5ei32(_Float16 *, vuint32m1_t, vfloat16mf2_t, vfloat16mf2_t, vfloat16mf2_t, vfloat16mf2_t, vfloat16mf2_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vsoxseg5ei32_v_m)))
void vsoxseg5ei32(vbool32_t, _Float16 *, vuint32m1_t, vfloat16mf2_t, vfloat16mf2_t, vfloat16mf2_t, vfloat16mf2_t, vfloat16mf2_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vsoxseg5ei32_v)))
void vsoxseg5ei32(_Float16 *, vuint32mf2_t, vfloat16mf4_t, vfloat16mf4_t, vfloat16mf4_t, vfloat16mf4_t, vfloat16mf4_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vsoxseg5ei32_v_m)))
void vsoxseg5ei32(vbool64_t, _Float16 *, vuint32mf2_t, vfloat16mf4_t, vfloat16mf4_t, vfloat16mf4_t, vfloat16mf4_t, vfloat16mf4_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vsoxseg6ei32_v)))
void vsoxseg6ei32(_Float16 *, vuint32m2_t, vfloat16m1_t, vfloat16m1_t, vfloat16m1_t, vfloat16m1_t, vfloat16m1_t, vfloat16m1_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vsoxseg6ei32_v_m)))
void vsoxseg6ei32(vbool16_t, _Float16 *, vuint32m2_t, vfloat16m1_t, vfloat16m1_t, vfloat16m1_t, vfloat16m1_t, vfloat16m1_t, vfloat16m1_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vsoxseg6ei32_v)))
void vsoxseg6ei32(_Float16 *, vuint32m1_t, vfloat16mf2_t, vfloat16mf2_t, vfloat16mf2_t, vfloat16mf2_t, vfloat16mf2_t, vfloat16mf2_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vsoxseg6ei32_v_m)))
void vsoxseg6ei32(vbool32_t, _Float16 *, vuint32m1_t, vfloat16mf2_t, vfloat16mf2_t, vfloat16mf2_t, vfloat16mf2_t, vfloat16mf2_t, vfloat16mf2_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vsoxseg6ei32_v)))
void vsoxseg6ei32(_Float16 *, vuint32mf2_t, vfloat16mf4_t, vfloat16mf4_t, vfloat16mf4_t, vfloat16mf4_t, vfloat16mf4_t, vfloat16mf4_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vsoxseg6ei32_v_m)))
void vsoxseg6ei32(vbool64_t, _Float16 *, vuint32mf2_t, vfloat16mf4_t, vfloat16mf4_t, vfloat16mf4_t, vfloat16mf4_t, vfloat16mf4_t, vfloat16mf4_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vsoxseg7ei32_v)))
void vsoxseg7ei32(_Float16 *, vuint32m2_t, vfloat16m1_t, vfloat16m1_t, vfloat16m1_t, vfloat16m1_t, vfloat16m1_t, vfloat16m1_t, vfloat16m1_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vsoxseg7ei32_v_m)))
void vsoxseg7ei32(vbool16_t, _Float16 *, vuint32m2_t, vfloat16m1_t, vfloat16m1_t, vfloat16m1_t, vfloat16m1_t, vfloat16m1_t, vfloat16m1_t, vfloat16m1_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vsoxseg7ei32_v)))
void vsoxseg7ei32(_Float16 *, vuint32m1_t, vfloat16mf2_t, vfloat16mf2_t, vfloat16mf2_t, vfloat16mf2_t, vfloat16mf2_t, vfloat16mf2_t, vfloat16mf2_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vsoxseg7ei32_v_m)))
void vsoxseg7ei32(vbool32_t, _Float16 *, vuint32m1_t, vfloat16mf2_t, vfloat16mf2_t, vfloat16mf2_t, vfloat16mf2_t, vfloat16mf2_t, vfloat16mf2_t, vfloat16mf2_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vsoxseg7ei32_v)))
void vsoxseg7ei32(_Float16 *, vuint32mf2_t, vfloat16mf4_t, vfloat16mf4_t, vfloat16mf4_t, vfloat16mf4_t, vfloat16mf4_t, vfloat16mf4_t, vfloat16mf4_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vsoxseg7ei32_v_m)))
void vsoxseg7ei32(vbool64_t, _Float16 *, vuint32mf2_t, vfloat16mf4_t, vfloat16mf4_t, vfloat16mf4_t, vfloat16mf4_t, vfloat16mf4_t, vfloat16mf4_t, vfloat16mf4_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vsoxseg8ei32_v)))
void vsoxseg8ei32(_Float16 *, vuint32m2_t, vfloat16m1_t, vfloat16m1_t, vfloat16m1_t, vfloat16m1_t, vfloat16m1_t, vfloat16m1_t, vfloat16m1_t, vfloat16m1_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vsoxseg8ei32_v_m)))
void vsoxseg8ei32(vbool16_t, _Float16 *, vuint32m2_t, vfloat16m1_t, vfloat16m1_t, vfloat16m1_t, vfloat16m1_t, vfloat16m1_t, vfloat16m1_t, vfloat16m1_t, vfloat16m1_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vsoxseg8ei32_v)))
void vsoxseg8ei32(_Float16 *, vuint32m1_t, vfloat16mf2_t, vfloat16mf2_t, vfloat16mf2_t, vfloat16mf2_t, vfloat16mf2_t, vfloat16mf2_t, vfloat16mf2_t, vfloat16mf2_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vsoxseg8ei32_v_m)))
void vsoxseg8ei32(vbool32_t, _Float16 *, vuint32m1_t, vfloat16mf2_t, vfloat16mf2_t, vfloat16mf2_t, vfloat16mf2_t, vfloat16mf2_t, vfloat16mf2_t, vfloat16mf2_t, vfloat16mf2_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vsoxseg8ei32_v)))
void vsoxseg8ei32(_Float16 *, vuint32mf2_t, vfloat16mf4_t, vfloat16mf4_t, vfloat16mf4_t, vfloat16mf4_t, vfloat16mf4_t, vfloat16mf4_t, vfloat16mf4_t, vfloat16mf4_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vsoxseg8ei32_v_m)))
void vsoxseg8ei32(vbool64_t, _Float16 *, vuint32mf2_t, vfloat16mf4_t, vfloat16mf4_t, vfloat16mf4_t, vfloat16mf4_t, vfloat16mf4_t, vfloat16mf4_t, vfloat16mf4_t, vfloat16mf4_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vloxei8_v)))
vfloat16m1_t vloxei8(const _Float16 *, vuint8mf2_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vloxei8_v_m)))
vfloat16m1_t vloxei8(vbool16_t, vfloat16m1_t, const _Float16 *, vuint8mf2_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vloxei8_v)))
vfloat16m2_t vloxei8(const _Float16 *, vuint8m1_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vloxei8_v_m)))
vfloat16m2_t vloxei8(vbool8_t, vfloat16m2_t, const _Float16 *, vuint8m1_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vloxei8_v)))
vfloat16m4_t vloxei8(const _Float16 *, vuint8m2_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vloxei8_v_m)))
vfloat16m4_t vloxei8(vbool4_t, vfloat16m4_t, const _Float16 *, vuint8m2_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vloxei8_v)))
vfloat16m8_t vloxei8(const _Float16 *, vuint8m4_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vloxei8_v_m)))
vfloat16m8_t vloxei8(vbool2_t, vfloat16m8_t, const _Float16 *, vuint8m4_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vloxei8_v)))
vfloat16mf2_t vloxei8(const _Float16 *, vuint8mf4_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vloxei8_v_m)))
vfloat16mf2_t vloxei8(vbool32_t, vfloat16mf2_t, const _Float16 *, vuint8mf4_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vloxei8_v)))
vfloat16mf4_t vloxei8(const _Float16 *, vuint8mf8_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vloxei8_v_m)))
vfloat16mf4_t vloxei8(vbool64_t, vfloat16mf4_t, const _Float16 *, vuint8mf8_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vloxei16_v)))
vfloat16m1_t vloxei16(const _Float16 *, vuint16m1_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vloxei16_v_m)))
vfloat16m1_t vloxei16(vbool16_t, vfloat16m1_t, const _Float16 *, vuint16m1_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vloxei16_v)))
vfloat16m2_t vloxei16(const _Float16 *, vuint16m2_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vloxei16_v_m)))
vfloat16m2_t vloxei16(vbool8_t, vfloat16m2_t, const _Float16 *, vuint16m2_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vloxei16_v)))
vfloat16m4_t vloxei16(const _Float16 *, vuint16m4_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vloxei16_v_m)))
vfloat16m4_t vloxei16(vbool4_t, vfloat16m4_t, const _Float16 *, vuint16m4_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vloxei16_v)))
vfloat16m8_t vloxei16(const _Float16 *, vuint16m8_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vloxei16_v_m)))
vfloat16m8_t vloxei16(vbool2_t, vfloat16m8_t, const _Float16 *, vuint16m8_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vloxei16_v)))
vfloat16mf2_t vloxei16(const _Float16 *, vuint16mf2_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vloxei16_v_m)))
vfloat16mf2_t vloxei16(vbool32_t, vfloat16mf2_t, const _Float16 *, vuint16mf2_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vloxei16_v)))
vfloat16mf4_t vloxei16(const _Float16 *, vuint16mf4_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vloxei16_v_m)))
vfloat16mf4_t vloxei16(vbool64_t, vfloat16mf4_t, const _Float16 *, vuint16mf4_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vloxei32_v)))
vfloat16m1_t vloxei32(const _Float16 *, vuint32m2_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vloxei32_v_m)))
vfloat16m1_t vloxei32(vbool16_t, vfloat16m1_t, const _Float16 *, vuint32m2_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vloxei32_v)))
vfloat16m2_t vloxei32(const _Float16 *, vuint32m4_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vloxei32_v_m)))
vfloat16m2_t vloxei32(vbool8_t, vfloat16m2_t, const _Float16 *, vuint32m4_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vloxei32_v)))
vfloat16m4_t vloxei32(const _Float16 *, vuint32m8_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vloxei32_v_m)))
vfloat16m4_t vloxei32(vbool4_t, vfloat16m4_t, const _Float16 *, vuint32m8_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vloxei32_v)))
vfloat16mf2_t vloxei32(const _Float16 *, vuint32m1_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vloxei32_v_m)))
vfloat16mf2_t vloxei32(vbool32_t, vfloat16mf2_t, const _Float16 *, vuint32m1_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vloxei32_v)))
vfloat16mf4_t vloxei32(const _Float16 *, vuint32mf2_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vloxei32_v_m)))
vfloat16mf4_t vloxei32(vbool64_t, vfloat16mf4_t, const _Float16 *, vuint32mf2_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vmv_v_v)))
vfloat16m1_t vmv_v(vfloat16m1_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vmv_v_v)))
vfloat16m2_t vmv_v(vfloat16m2_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vmv_v_v)))
vfloat16m4_t vmv_v(vfloat16m4_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vmv_v_v)))
vfloat16m8_t vmv_v(vfloat16m8_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vmv_v_v)))
vfloat16mf2_t vmv_v(vfloat16mf2_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vmv_v_v)))
vfloat16mf4_t vmv_v(vfloat16mf4_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vfadd_vv)))
vfloat16m1_t vfadd(vfloat16m1_t, vfloat16m1_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vfadd_vv_m)))
vfloat16m1_t vfadd(vbool16_t, vfloat16m1_t, vfloat16m1_t, vfloat16m1_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vfadd_vv)))
vfloat16m2_t vfadd(vfloat16m2_t, vfloat16m2_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vfadd_vv_m)))
vfloat16m2_t vfadd(vbool8_t, vfloat16m2_t, vfloat16m2_t, vfloat16m2_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vfadd_vv)))
vfloat16m4_t vfadd(vfloat16m4_t, vfloat16m4_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vfadd_vv_m)))
vfloat16m4_t vfadd(vbool4_t, vfloat16m4_t, vfloat16m4_t, vfloat16m4_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vfadd_vv)))
vfloat16m8_t vfadd(vfloat16m8_t, vfloat16m8_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vfadd_vv_m)))
vfloat16m8_t vfadd(vbool2_t, vfloat16m8_t, vfloat16m8_t, vfloat16m8_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vfadd_vv)))
vfloat16mf2_t vfadd(vfloat16mf2_t, vfloat16mf2_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vfadd_vv_m)))
vfloat16mf2_t vfadd(vbool32_t, vfloat16mf2_t, vfloat16mf2_t, vfloat16mf2_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vfadd_vv)))
vfloat16mf4_t vfadd(vfloat16mf4_t, vfloat16mf4_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vfadd_vv_m)))
vfloat16mf4_t vfadd(vbool64_t, vfloat16mf4_t, vfloat16mf4_t, vfloat16mf4_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vfadd_vf)))
vfloat16m1_t vfadd(vfloat16m1_t, _Float16, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vfadd_vf_m)))
vfloat16m1_t vfadd(vbool16_t, vfloat16m1_t, vfloat16m1_t, _Float16, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vfadd_vf)))
vfloat16m2_t vfadd(vfloat16m2_t, _Float16, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vfadd_vf_m)))
vfloat16m2_t vfadd(vbool8_t, vfloat16m2_t, vfloat16m2_t, _Float16, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vfadd_vf)))
vfloat16m4_t vfadd(vfloat16m4_t, _Float16, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vfadd_vf_m)))
vfloat16m4_t vfadd(vbool4_t, vfloat16m4_t, vfloat16m4_t, _Float16, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vfadd_vf)))
vfloat16m8_t vfadd(vfloat16m8_t, _Float16, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vfadd_vf_m)))
vfloat16m8_t vfadd(vbool2_t, vfloat16m8_t, vfloat16m8_t, _Float16, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vfadd_vf)))
vfloat16mf2_t vfadd(vfloat16mf2_t, _Float16, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vfadd_vf_m)))
vfloat16mf2_t vfadd(vbool32_t, vfloat16mf2_t, vfloat16mf2_t, _Float16, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vfadd_vf)))
vfloat16mf4_t vfadd(vfloat16mf4_t, _Float16, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vfadd_vf_m)))
vfloat16mf4_t vfadd(vbool64_t, vfloat16mf4_t, vfloat16mf4_t, _Float16, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vfsub_vv)))
vfloat16m1_t vfsub(vfloat16m1_t, vfloat16m1_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vfsub_vv_m)))
vfloat16m1_t vfsub(vbool16_t, vfloat16m1_t, vfloat16m1_t, vfloat16m1_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vfsub_vv)))
vfloat16m2_t vfsub(vfloat16m2_t, vfloat16m2_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vfsub_vv_m)))
vfloat16m2_t vfsub(vbool8_t, vfloat16m2_t, vfloat16m2_t, vfloat16m2_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vfsub_vv)))
vfloat16m4_t vfsub(vfloat16m4_t, vfloat16m4_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vfsub_vv_m)))
vfloat16m4_t vfsub(vbool4_t, vfloat16m4_t, vfloat16m4_t, vfloat16m4_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vfsub_vv)))
vfloat16m8_t vfsub(vfloat16m8_t, vfloat16m8_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vfsub_vv_m)))
vfloat16m8_t vfsub(vbool2_t, vfloat16m8_t, vfloat16m8_t, vfloat16m8_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vfsub_vv)))
vfloat16mf2_t vfsub(vfloat16mf2_t, vfloat16mf2_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vfsub_vv_m)))
vfloat16mf2_t vfsub(vbool32_t, vfloat16mf2_t, vfloat16mf2_t, vfloat16mf2_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vfsub_vv)))
vfloat16mf4_t vfsub(vfloat16mf4_t, vfloat16mf4_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vfsub_vv_m)))
vfloat16mf4_t vfsub(vbool64_t, vfloat16mf4_t, vfloat16mf4_t, vfloat16mf4_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vfsub_vf)))
vfloat16m1_t vfsub(vfloat16m1_t, _Float16, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vfsub_vf_m)))
vfloat16m1_t vfsub(vbool16_t, vfloat16m1_t, vfloat16m1_t, _Float16, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vfsub_vf)))
vfloat16m2_t vfsub(vfloat16m2_t, _Float16, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vfsub_vf_m)))
vfloat16m2_t vfsub(vbool8_t, vfloat16m2_t, vfloat16m2_t, _Float16, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vfsub_vf)))
vfloat16m4_t vfsub(vfloat16m4_t, _Float16, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vfsub_vf_m)))
vfloat16m4_t vfsub(vbool4_t, vfloat16m4_t, vfloat16m4_t, _Float16, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vfsub_vf)))
vfloat16m8_t vfsub(vfloat16m8_t, _Float16, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vfsub_vf_m)))
vfloat16m8_t vfsub(vbool2_t, vfloat16m8_t, vfloat16m8_t, _Float16, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vfsub_vf)))
vfloat16mf2_t vfsub(vfloat16mf2_t, _Float16, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vfsub_vf_m)))
vfloat16mf2_t vfsub(vbool32_t, vfloat16mf2_t, vfloat16mf2_t, _Float16, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vfsub_vf)))
vfloat16mf4_t vfsub(vfloat16mf4_t, _Float16, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vfsub_vf_m)))
vfloat16mf4_t vfsub(vbool64_t, vfloat16mf4_t, vfloat16mf4_t, _Float16, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vfrsub_vf)))
vfloat16m1_t vfrsub(vfloat16m1_t, _Float16, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vfrsub_vf_m)))
vfloat16m1_t vfrsub(vbool16_t, vfloat16m1_t, vfloat16m1_t, _Float16, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vfrsub_vf)))
vfloat16m2_t vfrsub(vfloat16m2_t, _Float16, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vfrsub_vf_m)))
vfloat16m2_t vfrsub(vbool8_t, vfloat16m2_t, vfloat16m2_t, _Float16, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vfrsub_vf)))
vfloat16m4_t vfrsub(vfloat16m4_t, _Float16, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vfrsub_vf_m)))
vfloat16m4_t vfrsub(vbool4_t, vfloat16m4_t, vfloat16m4_t, _Float16, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vfrsub_vf)))
vfloat16m8_t vfrsub(vfloat16m8_t, _Float16, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vfrsub_vf_m)))
vfloat16m8_t vfrsub(vbool2_t, vfloat16m8_t, vfloat16m8_t, _Float16, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vfrsub_vf)))
vfloat16mf2_t vfrsub(vfloat16mf2_t, _Float16, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vfrsub_vf_m)))
vfloat16mf2_t vfrsub(vbool32_t, vfloat16mf2_t, vfloat16mf2_t, _Float16, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vfrsub_vf)))
vfloat16mf4_t vfrsub(vfloat16mf4_t, _Float16, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vfrsub_vf_m)))
vfloat16mf4_t vfrsub(vbool64_t, vfloat16mf4_t, vfloat16mf4_t, _Float16, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vfmul_vv)))
vfloat16m1_t vfmul(vfloat16m1_t, vfloat16m1_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vfmul_vv_m)))
vfloat16m1_t vfmul(vbool16_t, vfloat16m1_t, vfloat16m1_t, vfloat16m1_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vfmul_vv)))
vfloat16m2_t vfmul(vfloat16m2_t, vfloat16m2_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vfmul_vv_m)))
vfloat16m2_t vfmul(vbool8_t, vfloat16m2_t, vfloat16m2_t, vfloat16m2_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vfmul_vv)))
vfloat16m4_t vfmul(vfloat16m4_t, vfloat16m4_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vfmul_vv_m)))
vfloat16m4_t vfmul(vbool4_t, vfloat16m4_t, vfloat16m4_t, vfloat16m4_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vfmul_vv)))
vfloat16m8_t vfmul(vfloat16m8_t, vfloat16m8_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vfmul_vv_m)))
vfloat16m8_t vfmul(vbool2_t, vfloat16m8_t, vfloat16m8_t, vfloat16m8_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vfmul_vv)))
vfloat16mf2_t vfmul(vfloat16mf2_t, vfloat16mf2_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vfmul_vv_m)))
vfloat16mf2_t vfmul(vbool32_t, vfloat16mf2_t, vfloat16mf2_t, vfloat16mf2_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vfmul_vv)))
vfloat16mf4_t vfmul(vfloat16mf4_t, vfloat16mf4_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vfmul_vv_m)))
vfloat16mf4_t vfmul(vbool64_t, vfloat16mf4_t, vfloat16mf4_t, vfloat16mf4_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vfmul_vf)))
vfloat16m1_t vfmul(vfloat16m1_t, _Float16, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vfmul_vf_m)))
vfloat16m1_t vfmul(vbool16_t, vfloat16m1_t, vfloat16m1_t, _Float16, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vfmul_vf)))
vfloat16m2_t vfmul(vfloat16m2_t, _Float16, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vfmul_vf_m)))
vfloat16m2_t vfmul(vbool8_t, vfloat16m2_t, vfloat16m2_t, _Float16, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vfmul_vf)))
vfloat16m4_t vfmul(vfloat16m4_t, _Float16, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vfmul_vf_m)))
vfloat16m4_t vfmul(vbool4_t, vfloat16m4_t, vfloat16m4_t, _Float16, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vfmul_vf)))
vfloat16m8_t vfmul(vfloat16m8_t, _Float16, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vfmul_vf_m)))
vfloat16m8_t vfmul(vbool2_t, vfloat16m8_t, vfloat16m8_t, _Float16, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vfmul_vf)))
vfloat16mf2_t vfmul(vfloat16mf2_t, _Float16, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vfmul_vf_m)))
vfloat16mf2_t vfmul(vbool32_t, vfloat16mf2_t, vfloat16mf2_t, _Float16, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vfmul_vf)))
vfloat16mf4_t vfmul(vfloat16mf4_t, _Float16, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vfmul_vf_m)))
vfloat16mf4_t vfmul(vbool64_t, vfloat16mf4_t, vfloat16mf4_t, _Float16, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vfdiv_vv)))
vfloat16m1_t vfdiv(vfloat16m1_t, vfloat16m1_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vfdiv_vv_m)))
vfloat16m1_t vfdiv(vbool16_t, vfloat16m1_t, vfloat16m1_t, vfloat16m1_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vfdiv_vv)))
vfloat16m2_t vfdiv(vfloat16m2_t, vfloat16m2_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vfdiv_vv_m)))
vfloat16m2_t vfdiv(vbool8_t, vfloat16m2_t, vfloat16m2_t, vfloat16m2_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vfdiv_vv)))
vfloat16m4_t vfdiv(vfloat16m4_t, vfloat16m4_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vfdiv_vv_m)))
vfloat16m4_t vfdiv(vbool4_t, vfloat16m4_t, vfloat16m4_t, vfloat16m4_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vfdiv_vv)))
vfloat16m8_t vfdiv(vfloat16m8_t, vfloat16m8_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vfdiv_vv_m)))
vfloat16m8_t vfdiv(vbool2_t, vfloat16m8_t, vfloat16m8_t, vfloat16m8_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vfdiv_vv)))
vfloat16mf2_t vfdiv(vfloat16mf2_t, vfloat16mf2_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vfdiv_vv_m)))
vfloat16mf2_t vfdiv(vbool32_t, vfloat16mf2_t, vfloat16mf2_t, vfloat16mf2_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vfdiv_vv)))
vfloat16mf4_t vfdiv(vfloat16mf4_t, vfloat16mf4_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vfdiv_vv_m)))
vfloat16mf4_t vfdiv(vbool64_t, vfloat16mf4_t, vfloat16mf4_t, vfloat16mf4_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vfdiv_vf)))
vfloat16m1_t vfdiv(vfloat16m1_t, _Float16, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vfdiv_vf_m)))
vfloat16m1_t vfdiv(vbool16_t, vfloat16m1_t, vfloat16m1_t, _Float16, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vfdiv_vf)))
vfloat16m2_t vfdiv(vfloat16m2_t, _Float16, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vfdiv_vf_m)))
vfloat16m2_t vfdiv(vbool8_t, vfloat16m2_t, vfloat16m2_t, _Float16, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vfdiv_vf)))
vfloat16m4_t vfdiv(vfloat16m4_t, _Float16, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vfdiv_vf_m)))
vfloat16m4_t vfdiv(vbool4_t, vfloat16m4_t, vfloat16m4_t, _Float16, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vfdiv_vf)))
vfloat16m8_t vfdiv(vfloat16m8_t, _Float16, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vfdiv_vf_m)))
vfloat16m8_t vfdiv(vbool2_t, vfloat16m8_t, vfloat16m8_t, _Float16, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vfdiv_vf)))
vfloat16mf2_t vfdiv(vfloat16mf2_t, _Float16, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vfdiv_vf_m)))
vfloat16mf2_t vfdiv(vbool32_t, vfloat16mf2_t, vfloat16mf2_t, _Float16, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vfdiv_vf)))
vfloat16mf4_t vfdiv(vfloat16mf4_t, _Float16, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vfdiv_vf_m)))
vfloat16mf4_t vfdiv(vbool64_t, vfloat16mf4_t, vfloat16mf4_t, _Float16, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vfrdiv_vf)))
vfloat16m1_t vfrdiv(vfloat16m1_t, _Float16, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vfrdiv_vf_m)))
vfloat16m1_t vfrdiv(vbool16_t, vfloat16m1_t, vfloat16m1_t, _Float16, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vfrdiv_vf)))
vfloat16m2_t vfrdiv(vfloat16m2_t, _Float16, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vfrdiv_vf_m)))
vfloat16m2_t vfrdiv(vbool8_t, vfloat16m2_t, vfloat16m2_t, _Float16, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vfrdiv_vf)))
vfloat16m4_t vfrdiv(vfloat16m4_t, _Float16, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vfrdiv_vf_m)))
vfloat16m4_t vfrdiv(vbool4_t, vfloat16m4_t, vfloat16m4_t, _Float16, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vfrdiv_vf)))
vfloat16m8_t vfrdiv(vfloat16m8_t, _Float16, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vfrdiv_vf_m)))
vfloat16m8_t vfrdiv(vbool2_t, vfloat16m8_t, vfloat16m8_t, _Float16, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vfrdiv_vf)))
vfloat16mf2_t vfrdiv(vfloat16mf2_t, _Float16, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vfrdiv_vf_m)))
vfloat16mf2_t vfrdiv(vbool32_t, vfloat16mf2_t, vfloat16mf2_t, _Float16, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vfrdiv_vf)))
vfloat16mf4_t vfrdiv(vfloat16mf4_t, _Float16, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vfrdiv_vf_m)))
vfloat16mf4_t vfrdiv(vbool64_t, vfloat16mf4_t, vfloat16mf4_t, _Float16, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vfmacc_vv)))
vfloat16m1_t vfmacc(vfloat16m1_t, vfloat16m1_t, vfloat16m1_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vfmacc_vv_m)))
vfloat16m1_t vfmacc(vbool16_t, vfloat16m1_t, vfloat16m1_t, vfloat16m1_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vfmacc_vv)))
vfloat16m2_t vfmacc(vfloat16m2_t, vfloat16m2_t, vfloat16m2_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vfmacc_vv_m)))
vfloat16m2_t vfmacc(vbool8_t, vfloat16m2_t, vfloat16m2_t, vfloat16m2_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vfmacc_vv)))
vfloat16m4_t vfmacc(vfloat16m4_t, vfloat16m4_t, vfloat16m4_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vfmacc_vv_m)))
vfloat16m4_t vfmacc(vbool4_t, vfloat16m4_t, vfloat16m4_t, vfloat16m4_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vfmacc_vv)))
vfloat16m8_t vfmacc(vfloat16m8_t, vfloat16m8_t, vfloat16m8_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vfmacc_vv_m)))
vfloat16m8_t vfmacc(vbool2_t, vfloat16m8_t, vfloat16m8_t, vfloat16m8_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vfmacc_vv)))
vfloat16mf2_t vfmacc(vfloat16mf2_t, vfloat16mf2_t, vfloat16mf2_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vfmacc_vv_m)))
vfloat16mf2_t vfmacc(vbool32_t, vfloat16mf2_t, vfloat16mf2_t, vfloat16mf2_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vfmacc_vv)))
vfloat16mf4_t vfmacc(vfloat16mf4_t, vfloat16mf4_t, vfloat16mf4_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vfmacc_vv_m)))
vfloat16mf4_t vfmacc(vbool64_t, vfloat16mf4_t, vfloat16mf4_t, vfloat16mf4_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vfmacc_vf)))
vfloat16m1_t vfmacc(vfloat16m1_t, _Float16, vfloat16m1_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vfmacc_vf_m)))
vfloat16m1_t vfmacc(vbool16_t, vfloat16m1_t, _Float16, vfloat16m1_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vfmacc_vf)))
vfloat16m2_t vfmacc(vfloat16m2_t, _Float16, vfloat16m2_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vfmacc_vf_m)))
vfloat16m2_t vfmacc(vbool8_t, vfloat16m2_t, _Float16, vfloat16m2_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vfmacc_vf)))
vfloat16m4_t vfmacc(vfloat16m4_t, _Float16, vfloat16m4_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vfmacc_vf_m)))
vfloat16m4_t vfmacc(vbool4_t, vfloat16m4_t, _Float16, vfloat16m4_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vfmacc_vf)))
vfloat16m8_t vfmacc(vfloat16m8_t, _Float16, vfloat16m8_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vfmacc_vf_m)))
vfloat16m8_t vfmacc(vbool2_t, vfloat16m8_t, _Float16, vfloat16m8_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vfmacc_vf)))
vfloat16mf2_t vfmacc(vfloat16mf2_t, _Float16, vfloat16mf2_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vfmacc_vf_m)))
vfloat16mf2_t vfmacc(vbool32_t, vfloat16mf2_t, _Float16, vfloat16mf2_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vfmacc_vf)))
vfloat16mf4_t vfmacc(vfloat16mf4_t, _Float16, vfloat16mf4_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vfmacc_vf_m)))
vfloat16mf4_t vfmacc(vbool64_t, vfloat16mf4_t, _Float16, vfloat16mf4_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vfnmacc_vv)))
vfloat16m1_t vfnmacc(vfloat16m1_t, vfloat16m1_t, vfloat16m1_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vfnmacc_vv_m)))
vfloat16m1_t vfnmacc(vbool16_t, vfloat16m1_t, vfloat16m1_t, vfloat16m1_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vfnmacc_vv)))
vfloat16m2_t vfnmacc(vfloat16m2_t, vfloat16m2_t, vfloat16m2_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vfnmacc_vv_m)))
vfloat16m2_t vfnmacc(vbool8_t, vfloat16m2_t, vfloat16m2_t, vfloat16m2_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vfnmacc_vv)))
vfloat16m4_t vfnmacc(vfloat16m4_t, vfloat16m4_t, vfloat16m4_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vfnmacc_vv_m)))
vfloat16m4_t vfnmacc(vbool4_t, vfloat16m4_t, vfloat16m4_t, vfloat16m4_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vfnmacc_vv)))
vfloat16m8_t vfnmacc(vfloat16m8_t, vfloat16m8_t, vfloat16m8_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vfnmacc_vv_m)))
vfloat16m8_t vfnmacc(vbool2_t, vfloat16m8_t, vfloat16m8_t, vfloat16m8_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vfnmacc_vv)))
vfloat16mf2_t vfnmacc(vfloat16mf2_t, vfloat16mf2_t, vfloat16mf2_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vfnmacc_vv_m)))
vfloat16mf2_t vfnmacc(vbool32_t, vfloat16mf2_t, vfloat16mf2_t, vfloat16mf2_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vfnmacc_vv)))
vfloat16mf4_t vfnmacc(vfloat16mf4_t, vfloat16mf4_t, vfloat16mf4_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vfnmacc_vv_m)))
vfloat16mf4_t vfnmacc(vbool64_t, vfloat16mf4_t, vfloat16mf4_t, vfloat16mf4_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vfnmacc_vf)))
vfloat16m1_t vfnmacc(vfloat16m1_t, _Float16, vfloat16m1_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vfnmacc_vf_m)))
vfloat16m1_t vfnmacc(vbool16_t, vfloat16m1_t, _Float16, vfloat16m1_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vfnmacc_vf)))
vfloat16m2_t vfnmacc(vfloat16m2_t, _Float16, vfloat16m2_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vfnmacc_vf_m)))
vfloat16m2_t vfnmacc(vbool8_t, vfloat16m2_t, _Float16, vfloat16m2_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vfnmacc_vf)))
vfloat16m4_t vfnmacc(vfloat16m4_t, _Float16, vfloat16m4_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vfnmacc_vf_m)))
vfloat16m4_t vfnmacc(vbool4_t, vfloat16m4_t, _Float16, vfloat16m4_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vfnmacc_vf)))
vfloat16m8_t vfnmacc(vfloat16m8_t, _Float16, vfloat16m8_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vfnmacc_vf_m)))
vfloat16m8_t vfnmacc(vbool2_t, vfloat16m8_t, _Float16, vfloat16m8_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vfnmacc_vf)))
vfloat16mf2_t vfnmacc(vfloat16mf2_t, _Float16, vfloat16mf2_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vfnmacc_vf_m)))
vfloat16mf2_t vfnmacc(vbool32_t, vfloat16mf2_t, _Float16, vfloat16mf2_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vfnmacc_vf)))
vfloat16mf4_t vfnmacc(vfloat16mf4_t, _Float16, vfloat16mf4_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vfnmacc_vf_m)))
vfloat16mf4_t vfnmacc(vbool64_t, vfloat16mf4_t, _Float16, vfloat16mf4_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vfmsac_vv)))
vfloat16m1_t vfmsac(vfloat16m1_t, vfloat16m1_t, vfloat16m1_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vfmsac_vv_m)))
vfloat16m1_t vfmsac(vbool16_t, vfloat16m1_t, vfloat16m1_t, vfloat16m1_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vfmsac_vv)))
vfloat16m2_t vfmsac(vfloat16m2_t, vfloat16m2_t, vfloat16m2_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vfmsac_vv_m)))
vfloat16m2_t vfmsac(vbool8_t, vfloat16m2_t, vfloat16m2_t, vfloat16m2_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vfmsac_vv)))
vfloat16m4_t vfmsac(vfloat16m4_t, vfloat16m4_t, vfloat16m4_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vfmsac_vv_m)))
vfloat16m4_t vfmsac(vbool4_t, vfloat16m4_t, vfloat16m4_t, vfloat16m4_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vfmsac_vv)))
vfloat16m8_t vfmsac(vfloat16m8_t, vfloat16m8_t, vfloat16m8_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vfmsac_vv_m)))
vfloat16m8_t vfmsac(vbool2_t, vfloat16m8_t, vfloat16m8_t, vfloat16m8_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vfmsac_vv)))
vfloat16mf2_t vfmsac(vfloat16mf2_t, vfloat16mf2_t, vfloat16mf2_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vfmsac_vv_m)))
vfloat16mf2_t vfmsac(vbool32_t, vfloat16mf2_t, vfloat16mf2_t, vfloat16mf2_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vfmsac_vv)))
vfloat16mf4_t vfmsac(vfloat16mf4_t, vfloat16mf4_t, vfloat16mf4_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vfmsac_vv_m)))
vfloat16mf4_t vfmsac(vbool64_t, vfloat16mf4_t, vfloat16mf4_t, vfloat16mf4_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vfmsac_vf)))
vfloat16m1_t vfmsac(vfloat16m1_t, _Float16, vfloat16m1_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vfmsac_vf_m)))
vfloat16m1_t vfmsac(vbool16_t, vfloat16m1_t, _Float16, vfloat16m1_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vfmsac_vf)))
vfloat16m2_t vfmsac(vfloat16m2_t, _Float16, vfloat16m2_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vfmsac_vf_m)))
vfloat16m2_t vfmsac(vbool8_t, vfloat16m2_t, _Float16, vfloat16m2_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vfmsac_vf)))
vfloat16m4_t vfmsac(vfloat16m4_t, _Float16, vfloat16m4_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vfmsac_vf_m)))
vfloat16m4_t vfmsac(vbool4_t, vfloat16m4_t, _Float16, vfloat16m4_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vfmsac_vf)))
vfloat16m8_t vfmsac(vfloat16m8_t, _Float16, vfloat16m8_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vfmsac_vf_m)))
vfloat16m8_t vfmsac(vbool2_t, vfloat16m8_t, _Float16, vfloat16m8_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vfmsac_vf)))
vfloat16mf2_t vfmsac(vfloat16mf2_t, _Float16, vfloat16mf2_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vfmsac_vf_m)))
vfloat16mf2_t vfmsac(vbool32_t, vfloat16mf2_t, _Float16, vfloat16mf2_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vfmsac_vf)))
vfloat16mf4_t vfmsac(vfloat16mf4_t, _Float16, vfloat16mf4_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vfmsac_vf_m)))
vfloat16mf4_t vfmsac(vbool64_t, vfloat16mf4_t, _Float16, vfloat16mf4_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vfnmsac_vv)))
vfloat16m1_t vfnmsac(vfloat16m1_t, vfloat16m1_t, vfloat16m1_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vfnmsac_vv_m)))
vfloat16m1_t vfnmsac(vbool16_t, vfloat16m1_t, vfloat16m1_t, vfloat16m1_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vfnmsac_vv)))
vfloat16m2_t vfnmsac(vfloat16m2_t, vfloat16m2_t, vfloat16m2_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vfnmsac_vv_m)))
vfloat16m2_t vfnmsac(vbool8_t, vfloat16m2_t, vfloat16m2_t, vfloat16m2_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vfnmsac_vv)))
vfloat16m4_t vfnmsac(vfloat16m4_t, vfloat16m4_t, vfloat16m4_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vfnmsac_vv_m)))
vfloat16m4_t vfnmsac(vbool4_t, vfloat16m4_t, vfloat16m4_t, vfloat16m4_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vfnmsac_vv)))
vfloat16m8_t vfnmsac(vfloat16m8_t, vfloat16m8_t, vfloat16m8_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vfnmsac_vv_m)))
vfloat16m8_t vfnmsac(vbool2_t, vfloat16m8_t, vfloat16m8_t, vfloat16m8_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vfnmsac_vv)))
vfloat16mf2_t vfnmsac(vfloat16mf2_t, vfloat16mf2_t, vfloat16mf2_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vfnmsac_vv_m)))
vfloat16mf2_t vfnmsac(vbool32_t, vfloat16mf2_t, vfloat16mf2_t, vfloat16mf2_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vfnmsac_vv)))
vfloat16mf4_t vfnmsac(vfloat16mf4_t, vfloat16mf4_t, vfloat16mf4_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vfnmsac_vv_m)))
vfloat16mf4_t vfnmsac(vbool64_t, vfloat16mf4_t, vfloat16mf4_t, vfloat16mf4_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vfnmsac_vf)))
vfloat16m1_t vfnmsac(vfloat16m1_t, _Float16, vfloat16m1_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vfnmsac_vf_m)))
vfloat16m1_t vfnmsac(vbool16_t, vfloat16m1_t, _Float16, vfloat16m1_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vfnmsac_vf)))
vfloat16m2_t vfnmsac(vfloat16m2_t, _Float16, vfloat16m2_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vfnmsac_vf_m)))
vfloat16m2_t vfnmsac(vbool8_t, vfloat16m2_t, _Float16, vfloat16m2_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vfnmsac_vf)))
vfloat16m4_t vfnmsac(vfloat16m4_t, _Float16, vfloat16m4_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vfnmsac_vf_m)))
vfloat16m4_t vfnmsac(vbool4_t, vfloat16m4_t, _Float16, vfloat16m4_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vfnmsac_vf)))
vfloat16m8_t vfnmsac(vfloat16m8_t, _Float16, vfloat16m8_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vfnmsac_vf_m)))
vfloat16m8_t vfnmsac(vbool2_t, vfloat16m8_t, _Float16, vfloat16m8_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vfnmsac_vf)))
vfloat16mf2_t vfnmsac(vfloat16mf2_t, _Float16, vfloat16mf2_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vfnmsac_vf_m)))
vfloat16mf2_t vfnmsac(vbool32_t, vfloat16mf2_t, _Float16, vfloat16mf2_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vfnmsac_vf)))
vfloat16mf4_t vfnmsac(vfloat16mf4_t, _Float16, vfloat16mf4_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vfnmsac_vf_m)))
vfloat16mf4_t vfnmsac(vbool64_t, vfloat16mf4_t, _Float16, vfloat16mf4_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vfmadd_vv)))
vfloat16m1_t vfmadd(vfloat16m1_t, vfloat16m1_t, vfloat16m1_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vfmadd_vv_m)))
vfloat16m1_t vfmadd(vbool16_t, vfloat16m1_t, vfloat16m1_t, vfloat16m1_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vfmadd_vv)))
vfloat16m2_t vfmadd(vfloat16m2_t, vfloat16m2_t, vfloat16m2_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vfmadd_vv_m)))
vfloat16m2_t vfmadd(vbool8_t, vfloat16m2_t, vfloat16m2_t, vfloat16m2_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vfmadd_vv)))
vfloat16m4_t vfmadd(vfloat16m4_t, vfloat16m4_t, vfloat16m4_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vfmadd_vv_m)))
vfloat16m4_t vfmadd(vbool4_t, vfloat16m4_t, vfloat16m4_t, vfloat16m4_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vfmadd_vv)))
vfloat16m8_t vfmadd(vfloat16m8_t, vfloat16m8_t, vfloat16m8_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vfmadd_vv_m)))
vfloat16m8_t vfmadd(vbool2_t, vfloat16m8_t, vfloat16m8_t, vfloat16m8_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vfmadd_vv)))
vfloat16mf2_t vfmadd(vfloat16mf2_t, vfloat16mf2_t, vfloat16mf2_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vfmadd_vv_m)))
vfloat16mf2_t vfmadd(vbool32_t, vfloat16mf2_t, vfloat16mf2_t, vfloat16mf2_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vfmadd_vv)))
vfloat16mf4_t vfmadd(vfloat16mf4_t, vfloat16mf4_t, vfloat16mf4_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vfmadd_vv_m)))
vfloat16mf4_t vfmadd(vbool64_t, vfloat16mf4_t, vfloat16mf4_t, vfloat16mf4_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vfmadd_vf)))
vfloat16m1_t vfmadd(vfloat16m1_t, _Float16, vfloat16m1_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vfmadd_vf_m)))
vfloat16m1_t vfmadd(vbool16_t, vfloat16m1_t, _Float16, vfloat16m1_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vfmadd_vf)))
vfloat16m2_t vfmadd(vfloat16m2_t, _Float16, vfloat16m2_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vfmadd_vf_m)))
vfloat16m2_t vfmadd(vbool8_t, vfloat16m2_t, _Float16, vfloat16m2_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vfmadd_vf)))
vfloat16m4_t vfmadd(vfloat16m4_t, _Float16, vfloat16m4_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vfmadd_vf_m)))
vfloat16m4_t vfmadd(vbool4_t, vfloat16m4_t, _Float16, vfloat16m4_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vfmadd_vf)))
vfloat16m8_t vfmadd(vfloat16m8_t, _Float16, vfloat16m8_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vfmadd_vf_m)))
vfloat16m8_t vfmadd(vbool2_t, vfloat16m8_t, _Float16, vfloat16m8_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vfmadd_vf)))
vfloat16mf2_t vfmadd(vfloat16mf2_t, _Float16, vfloat16mf2_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vfmadd_vf_m)))
vfloat16mf2_t vfmadd(vbool32_t, vfloat16mf2_t, _Float16, vfloat16mf2_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vfmadd_vf)))
vfloat16mf4_t vfmadd(vfloat16mf4_t, _Float16, vfloat16mf4_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vfmadd_vf_m)))
vfloat16mf4_t vfmadd(vbool64_t, vfloat16mf4_t, _Float16, vfloat16mf4_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vfnmadd_vv)))
vfloat16m1_t vfnmadd(vfloat16m1_t, vfloat16m1_t, vfloat16m1_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vfnmadd_vv_m)))
vfloat16m1_t vfnmadd(vbool16_t, vfloat16m1_t, vfloat16m1_t, vfloat16m1_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vfnmadd_vv)))
vfloat16m2_t vfnmadd(vfloat16m2_t, vfloat16m2_t, vfloat16m2_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vfnmadd_vv_m)))
vfloat16m2_t vfnmadd(vbool8_t, vfloat16m2_t, vfloat16m2_t, vfloat16m2_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vfnmadd_vv)))
vfloat16m4_t vfnmadd(vfloat16m4_t, vfloat16m4_t, vfloat16m4_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vfnmadd_vv_m)))
vfloat16m4_t vfnmadd(vbool4_t, vfloat16m4_t, vfloat16m4_t, vfloat16m4_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vfnmadd_vv)))
vfloat16m8_t vfnmadd(vfloat16m8_t, vfloat16m8_t, vfloat16m8_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vfnmadd_vv_m)))
vfloat16m8_t vfnmadd(vbool2_t, vfloat16m8_t, vfloat16m8_t, vfloat16m8_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vfnmadd_vv)))
vfloat16mf2_t vfnmadd(vfloat16mf2_t, vfloat16mf2_t, vfloat16mf2_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vfnmadd_vv_m)))
vfloat16mf2_t vfnmadd(vbool32_t, vfloat16mf2_t, vfloat16mf2_t, vfloat16mf2_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vfnmadd_vv)))
vfloat16mf4_t vfnmadd(vfloat16mf4_t, vfloat16mf4_t, vfloat16mf4_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vfnmadd_vv_m)))
vfloat16mf4_t vfnmadd(vbool64_t, vfloat16mf4_t, vfloat16mf4_t, vfloat16mf4_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vfnmadd_vf)))
vfloat16m1_t vfnmadd(vfloat16m1_t, _Float16, vfloat16m1_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vfnmadd_vf_m)))
vfloat16m1_t vfnmadd(vbool16_t, vfloat16m1_t, _Float16, vfloat16m1_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vfnmadd_vf)))
vfloat16m2_t vfnmadd(vfloat16m2_t, _Float16, vfloat16m2_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vfnmadd_vf_m)))
vfloat16m2_t vfnmadd(vbool8_t, vfloat16m2_t, _Float16, vfloat16m2_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vfnmadd_vf)))
vfloat16m4_t vfnmadd(vfloat16m4_t, _Float16, vfloat16m4_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vfnmadd_vf_m)))
vfloat16m4_t vfnmadd(vbool4_t, vfloat16m4_t, _Float16, vfloat16m4_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vfnmadd_vf)))
vfloat16m8_t vfnmadd(vfloat16m8_t, _Float16, vfloat16m8_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vfnmadd_vf_m)))
vfloat16m8_t vfnmadd(vbool2_t, vfloat16m8_t, _Float16, vfloat16m8_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vfnmadd_vf)))
vfloat16mf2_t vfnmadd(vfloat16mf2_t, _Float16, vfloat16mf2_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vfnmadd_vf_m)))
vfloat16mf2_t vfnmadd(vbool32_t, vfloat16mf2_t, _Float16, vfloat16mf2_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vfnmadd_vf)))
vfloat16mf4_t vfnmadd(vfloat16mf4_t, _Float16, vfloat16mf4_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vfnmadd_vf_m)))
vfloat16mf4_t vfnmadd(vbool64_t, vfloat16mf4_t, _Float16, vfloat16mf4_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vfmsub_vv)))
vfloat16m1_t vfmsub(vfloat16m1_t, vfloat16m1_t, vfloat16m1_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vfmsub_vv_m)))
vfloat16m1_t vfmsub(vbool16_t, vfloat16m1_t, vfloat16m1_t, vfloat16m1_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vfmsub_vv)))
vfloat16m2_t vfmsub(vfloat16m2_t, vfloat16m2_t, vfloat16m2_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vfmsub_vv_m)))
vfloat16m2_t vfmsub(vbool8_t, vfloat16m2_t, vfloat16m2_t, vfloat16m2_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vfmsub_vv)))
vfloat16m4_t vfmsub(vfloat16m4_t, vfloat16m4_t, vfloat16m4_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vfmsub_vv_m)))
vfloat16m4_t vfmsub(vbool4_t, vfloat16m4_t, vfloat16m4_t, vfloat16m4_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vfmsub_vv)))
vfloat16m8_t vfmsub(vfloat16m8_t, vfloat16m8_t, vfloat16m8_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vfmsub_vv_m)))
vfloat16m8_t vfmsub(vbool2_t, vfloat16m8_t, vfloat16m8_t, vfloat16m8_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vfmsub_vv)))
vfloat16mf2_t vfmsub(vfloat16mf2_t, vfloat16mf2_t, vfloat16mf2_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vfmsub_vv_m)))
vfloat16mf2_t vfmsub(vbool32_t, vfloat16mf2_t, vfloat16mf2_t, vfloat16mf2_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vfmsub_vv)))
vfloat16mf4_t vfmsub(vfloat16mf4_t, vfloat16mf4_t, vfloat16mf4_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vfmsub_vv_m)))
vfloat16mf4_t vfmsub(vbool64_t, vfloat16mf4_t, vfloat16mf4_t, vfloat16mf4_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vfmsub_vf)))
vfloat16m1_t vfmsub(vfloat16m1_t, _Float16, vfloat16m1_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vfmsub_vf_m)))
vfloat16m1_t vfmsub(vbool16_t, vfloat16m1_t, _Float16, vfloat16m1_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vfmsub_vf)))
vfloat16m2_t vfmsub(vfloat16m2_t, _Float16, vfloat16m2_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vfmsub_vf_m)))
vfloat16m2_t vfmsub(vbool8_t, vfloat16m2_t, _Float16, vfloat16m2_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vfmsub_vf)))
vfloat16m4_t vfmsub(vfloat16m4_t, _Float16, vfloat16m4_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vfmsub_vf_m)))
vfloat16m4_t vfmsub(vbool4_t, vfloat16m4_t, _Float16, vfloat16m4_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vfmsub_vf)))
vfloat16m8_t vfmsub(vfloat16m8_t, _Float16, vfloat16m8_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vfmsub_vf_m)))
vfloat16m8_t vfmsub(vbool2_t, vfloat16m8_t, _Float16, vfloat16m8_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vfmsub_vf)))
vfloat16mf2_t vfmsub(vfloat16mf2_t, _Float16, vfloat16mf2_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vfmsub_vf_m)))
vfloat16mf2_t vfmsub(vbool32_t, vfloat16mf2_t, _Float16, vfloat16mf2_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vfmsub_vf)))
vfloat16mf4_t vfmsub(vfloat16mf4_t, _Float16, vfloat16mf4_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vfmsub_vf_m)))
vfloat16mf4_t vfmsub(vbool64_t, vfloat16mf4_t, _Float16, vfloat16mf4_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vfnmsub_vv)))
vfloat16m1_t vfnmsub(vfloat16m1_t, vfloat16m1_t, vfloat16m1_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vfnmsub_vv_m)))
vfloat16m1_t vfnmsub(vbool16_t, vfloat16m1_t, vfloat16m1_t, vfloat16m1_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vfnmsub_vv)))
vfloat16m2_t vfnmsub(vfloat16m2_t, vfloat16m2_t, vfloat16m2_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vfnmsub_vv_m)))
vfloat16m2_t vfnmsub(vbool8_t, vfloat16m2_t, vfloat16m2_t, vfloat16m2_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vfnmsub_vv)))
vfloat16m4_t vfnmsub(vfloat16m4_t, vfloat16m4_t, vfloat16m4_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vfnmsub_vv_m)))
vfloat16m4_t vfnmsub(vbool4_t, vfloat16m4_t, vfloat16m4_t, vfloat16m4_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vfnmsub_vv)))
vfloat16m8_t vfnmsub(vfloat16m8_t, vfloat16m8_t, vfloat16m8_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vfnmsub_vv_m)))
vfloat16m8_t vfnmsub(vbool2_t, vfloat16m8_t, vfloat16m8_t, vfloat16m8_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vfnmsub_vv)))
vfloat16mf2_t vfnmsub(vfloat16mf2_t, vfloat16mf2_t, vfloat16mf2_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vfnmsub_vv_m)))
vfloat16mf2_t vfnmsub(vbool32_t, vfloat16mf2_t, vfloat16mf2_t, vfloat16mf2_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vfnmsub_vv)))
vfloat16mf4_t vfnmsub(vfloat16mf4_t, vfloat16mf4_t, vfloat16mf4_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vfnmsub_vv_m)))
vfloat16mf4_t vfnmsub(vbool64_t, vfloat16mf4_t, vfloat16mf4_t, vfloat16mf4_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vfnmsub_vf)))
vfloat16m1_t vfnmsub(vfloat16m1_t, _Float16, vfloat16m1_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vfnmsub_vf_m)))
vfloat16m1_t vfnmsub(vbool16_t, vfloat16m1_t, _Float16, vfloat16m1_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vfnmsub_vf)))
vfloat16m2_t vfnmsub(vfloat16m2_t, _Float16, vfloat16m2_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vfnmsub_vf_m)))
vfloat16m2_t vfnmsub(vbool8_t, vfloat16m2_t, _Float16, vfloat16m2_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vfnmsub_vf)))
vfloat16m4_t vfnmsub(vfloat16m4_t, _Float16, vfloat16m4_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vfnmsub_vf_m)))
vfloat16m4_t vfnmsub(vbool4_t, vfloat16m4_t, _Float16, vfloat16m4_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vfnmsub_vf)))
vfloat16m8_t vfnmsub(vfloat16m8_t, _Float16, vfloat16m8_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vfnmsub_vf_m)))
vfloat16m8_t vfnmsub(vbool2_t, vfloat16m8_t, _Float16, vfloat16m8_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vfnmsub_vf)))
vfloat16mf2_t vfnmsub(vfloat16mf2_t, _Float16, vfloat16mf2_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vfnmsub_vf_m)))
vfloat16mf2_t vfnmsub(vbool32_t, vfloat16mf2_t, _Float16, vfloat16mf2_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vfnmsub_vf)))
vfloat16mf4_t vfnmsub(vfloat16mf4_t, _Float16, vfloat16mf4_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vfnmsub_vf_m)))
vfloat16mf4_t vfnmsub(vbool64_t, vfloat16mf4_t, _Float16, vfloat16mf4_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vfmin_vv)))
vfloat16m1_t vfmin(vfloat16m1_t, vfloat16m1_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vfmin_vv_m)))
vfloat16m1_t vfmin(vbool16_t, vfloat16m1_t, vfloat16m1_t, vfloat16m1_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vfmin_vv)))
vfloat16m2_t vfmin(vfloat16m2_t, vfloat16m2_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vfmin_vv_m)))
vfloat16m2_t vfmin(vbool8_t, vfloat16m2_t, vfloat16m2_t, vfloat16m2_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vfmin_vv)))
vfloat16m4_t vfmin(vfloat16m4_t, vfloat16m4_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vfmin_vv_m)))
vfloat16m4_t vfmin(vbool4_t, vfloat16m4_t, vfloat16m4_t, vfloat16m4_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vfmin_vv)))
vfloat16m8_t vfmin(vfloat16m8_t, vfloat16m8_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vfmin_vv_m)))
vfloat16m8_t vfmin(vbool2_t, vfloat16m8_t, vfloat16m8_t, vfloat16m8_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vfmin_vv)))
vfloat16mf2_t vfmin(vfloat16mf2_t, vfloat16mf2_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vfmin_vv_m)))
vfloat16mf2_t vfmin(vbool32_t, vfloat16mf2_t, vfloat16mf2_t, vfloat16mf2_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vfmin_vv)))
vfloat16mf4_t vfmin(vfloat16mf4_t, vfloat16mf4_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vfmin_vv_m)))
vfloat16mf4_t vfmin(vbool64_t, vfloat16mf4_t, vfloat16mf4_t, vfloat16mf4_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vfmin_vf)))
vfloat16m1_t vfmin(vfloat16m1_t, _Float16, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vfmin_vf_m)))
vfloat16m1_t vfmin(vbool16_t, vfloat16m1_t, vfloat16m1_t, _Float16, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vfmin_vf)))
vfloat16m2_t vfmin(vfloat16m2_t, _Float16, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vfmin_vf_m)))
vfloat16m2_t vfmin(vbool8_t, vfloat16m2_t, vfloat16m2_t, _Float16, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vfmin_vf)))
vfloat16m4_t vfmin(vfloat16m4_t, _Float16, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vfmin_vf_m)))
vfloat16m4_t vfmin(vbool4_t, vfloat16m4_t, vfloat16m4_t, _Float16, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vfmin_vf)))
vfloat16m8_t vfmin(vfloat16m8_t, _Float16, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vfmin_vf_m)))
vfloat16m8_t vfmin(vbool2_t, vfloat16m8_t, vfloat16m8_t, _Float16, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vfmin_vf)))
vfloat16mf2_t vfmin(vfloat16mf2_t, _Float16, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vfmin_vf_m)))
vfloat16mf2_t vfmin(vbool32_t, vfloat16mf2_t, vfloat16mf2_t, _Float16, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vfmin_vf)))
vfloat16mf4_t vfmin(vfloat16mf4_t, _Float16, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vfmin_vf_m)))
vfloat16mf4_t vfmin(vbool64_t, vfloat16mf4_t, vfloat16mf4_t, _Float16, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vfmax_vv)))
vfloat16m1_t vfmax(vfloat16m1_t, vfloat16m1_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vfmax_vv_m)))
vfloat16m1_t vfmax(vbool16_t, vfloat16m1_t, vfloat16m1_t, vfloat16m1_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vfmax_vv)))
vfloat16m2_t vfmax(vfloat16m2_t, vfloat16m2_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vfmax_vv_m)))
vfloat16m2_t vfmax(vbool8_t, vfloat16m2_t, vfloat16m2_t, vfloat16m2_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vfmax_vv)))
vfloat16m4_t vfmax(vfloat16m4_t, vfloat16m4_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vfmax_vv_m)))
vfloat16m4_t vfmax(vbool4_t, vfloat16m4_t, vfloat16m4_t, vfloat16m4_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vfmax_vv)))
vfloat16m8_t vfmax(vfloat16m8_t, vfloat16m8_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vfmax_vv_m)))
vfloat16m8_t vfmax(vbool2_t, vfloat16m8_t, vfloat16m8_t, vfloat16m8_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vfmax_vv)))
vfloat16mf2_t vfmax(vfloat16mf2_t, vfloat16mf2_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vfmax_vv_m)))
vfloat16mf2_t vfmax(vbool32_t, vfloat16mf2_t, vfloat16mf2_t, vfloat16mf2_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vfmax_vv)))
vfloat16mf4_t vfmax(vfloat16mf4_t, vfloat16mf4_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vfmax_vv_m)))
vfloat16mf4_t vfmax(vbool64_t, vfloat16mf4_t, vfloat16mf4_t, vfloat16mf4_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vfmax_vf)))
vfloat16m1_t vfmax(vfloat16m1_t, _Float16, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vfmax_vf_m)))
vfloat16m1_t vfmax(vbool16_t, vfloat16m1_t, vfloat16m1_t, _Float16, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vfmax_vf)))
vfloat16m2_t vfmax(vfloat16m2_t, _Float16, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vfmax_vf_m)))
vfloat16m2_t vfmax(vbool8_t, vfloat16m2_t, vfloat16m2_t, _Float16, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vfmax_vf)))
vfloat16m4_t vfmax(vfloat16m4_t, _Float16, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vfmax_vf_m)))
vfloat16m4_t vfmax(vbool4_t, vfloat16m4_t, vfloat16m4_t, _Float16, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vfmax_vf)))
vfloat16m8_t vfmax(vfloat16m8_t, _Float16, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vfmax_vf_m)))
vfloat16m8_t vfmax(vbool2_t, vfloat16m8_t, vfloat16m8_t, _Float16, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vfmax_vf)))
vfloat16mf2_t vfmax(vfloat16mf2_t, _Float16, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vfmax_vf_m)))
vfloat16mf2_t vfmax(vbool32_t, vfloat16mf2_t, vfloat16mf2_t, _Float16, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vfmax_vf)))
vfloat16mf4_t vfmax(vfloat16mf4_t, _Float16, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vfmax_vf_m)))
vfloat16mf4_t vfmax(vbool64_t, vfloat16mf4_t, vfloat16mf4_t, _Float16, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vfsgnj_vv)))
vfloat16m1_t vfsgnj(vfloat16m1_t, vfloat16m1_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vfsgnj_vv_m)))
vfloat16m1_t vfsgnj(vbool16_t, vfloat16m1_t, vfloat16m1_t, vfloat16m1_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vfsgnj_vv)))
vfloat16m2_t vfsgnj(vfloat16m2_t, vfloat16m2_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vfsgnj_vv_m)))
vfloat16m2_t vfsgnj(vbool8_t, vfloat16m2_t, vfloat16m2_t, vfloat16m2_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vfsgnj_vv)))
vfloat16m4_t vfsgnj(vfloat16m4_t, vfloat16m4_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vfsgnj_vv_m)))
vfloat16m4_t vfsgnj(vbool4_t, vfloat16m4_t, vfloat16m4_t, vfloat16m4_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vfsgnj_vv)))
vfloat16m8_t vfsgnj(vfloat16m8_t, vfloat16m8_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vfsgnj_vv_m)))
vfloat16m8_t vfsgnj(vbool2_t, vfloat16m8_t, vfloat16m8_t, vfloat16m8_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vfsgnj_vv)))
vfloat16mf2_t vfsgnj(vfloat16mf2_t, vfloat16mf2_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vfsgnj_vv_m)))
vfloat16mf2_t vfsgnj(vbool32_t, vfloat16mf2_t, vfloat16mf2_t, vfloat16mf2_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vfsgnj_vv)))
vfloat16mf4_t vfsgnj(vfloat16mf4_t, vfloat16mf4_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vfsgnj_vv_m)))
vfloat16mf4_t vfsgnj(vbool64_t, vfloat16mf4_t, vfloat16mf4_t, vfloat16mf4_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vfsgnj_vf)))
vfloat16m1_t vfsgnj(vfloat16m1_t, _Float16, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vfsgnj_vf_m)))
vfloat16m1_t vfsgnj(vbool16_t, vfloat16m1_t, vfloat16m1_t, _Float16, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vfsgnj_vf)))
vfloat16m2_t vfsgnj(vfloat16m2_t, _Float16, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vfsgnj_vf_m)))
vfloat16m2_t vfsgnj(vbool8_t, vfloat16m2_t, vfloat16m2_t, _Float16, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vfsgnj_vf)))
vfloat16m4_t vfsgnj(vfloat16m4_t, _Float16, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vfsgnj_vf_m)))
vfloat16m4_t vfsgnj(vbool4_t, vfloat16m4_t, vfloat16m4_t, _Float16, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vfsgnj_vf)))
vfloat16m8_t vfsgnj(vfloat16m8_t, _Float16, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vfsgnj_vf_m)))
vfloat16m8_t vfsgnj(vbool2_t, vfloat16m8_t, vfloat16m8_t, _Float16, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vfsgnj_vf)))
vfloat16mf2_t vfsgnj(vfloat16mf2_t, _Float16, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vfsgnj_vf_m)))
vfloat16mf2_t vfsgnj(vbool32_t, vfloat16mf2_t, vfloat16mf2_t, _Float16, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vfsgnj_vf)))
vfloat16mf4_t vfsgnj(vfloat16mf4_t, _Float16, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vfsgnj_vf_m)))
vfloat16mf4_t vfsgnj(vbool64_t, vfloat16mf4_t, vfloat16mf4_t, _Float16, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vfsgnjn_vv)))
vfloat16m1_t vfsgnjn(vfloat16m1_t, vfloat16m1_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vfsgnjn_vv_m)))
vfloat16m1_t vfsgnjn(vbool16_t, vfloat16m1_t, vfloat16m1_t, vfloat16m1_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vfsgnjn_vv)))
vfloat16m2_t vfsgnjn(vfloat16m2_t, vfloat16m2_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vfsgnjn_vv_m)))
vfloat16m2_t vfsgnjn(vbool8_t, vfloat16m2_t, vfloat16m2_t, vfloat16m2_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vfsgnjn_vv)))
vfloat16m4_t vfsgnjn(vfloat16m4_t, vfloat16m4_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vfsgnjn_vv_m)))
vfloat16m4_t vfsgnjn(vbool4_t, vfloat16m4_t, vfloat16m4_t, vfloat16m4_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vfsgnjn_vv)))
vfloat16m8_t vfsgnjn(vfloat16m8_t, vfloat16m8_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vfsgnjn_vv_m)))
vfloat16m8_t vfsgnjn(vbool2_t, vfloat16m8_t, vfloat16m8_t, vfloat16m8_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vfsgnjn_vv)))
vfloat16mf2_t vfsgnjn(vfloat16mf2_t, vfloat16mf2_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vfsgnjn_vv_m)))
vfloat16mf2_t vfsgnjn(vbool32_t, vfloat16mf2_t, vfloat16mf2_t, vfloat16mf2_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vfsgnjn_vv)))
vfloat16mf4_t vfsgnjn(vfloat16mf4_t, vfloat16mf4_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vfsgnjn_vv_m)))
vfloat16mf4_t vfsgnjn(vbool64_t, vfloat16mf4_t, vfloat16mf4_t, vfloat16mf4_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vfsgnjn_vf)))
vfloat16m1_t vfsgnjn(vfloat16m1_t, _Float16, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vfsgnjn_vf_m)))
vfloat16m1_t vfsgnjn(vbool16_t, vfloat16m1_t, vfloat16m1_t, _Float16, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vfsgnjn_vf)))
vfloat16m2_t vfsgnjn(vfloat16m2_t, _Float16, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vfsgnjn_vf_m)))
vfloat16m2_t vfsgnjn(vbool8_t, vfloat16m2_t, vfloat16m2_t, _Float16, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vfsgnjn_vf)))
vfloat16m4_t vfsgnjn(vfloat16m4_t, _Float16, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vfsgnjn_vf_m)))
vfloat16m4_t vfsgnjn(vbool4_t, vfloat16m4_t, vfloat16m4_t, _Float16, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vfsgnjn_vf)))
vfloat16m8_t vfsgnjn(vfloat16m8_t, _Float16, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vfsgnjn_vf_m)))
vfloat16m8_t vfsgnjn(vbool2_t, vfloat16m8_t, vfloat16m8_t, _Float16, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vfsgnjn_vf)))
vfloat16mf2_t vfsgnjn(vfloat16mf2_t, _Float16, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vfsgnjn_vf_m)))
vfloat16mf2_t vfsgnjn(vbool32_t, vfloat16mf2_t, vfloat16mf2_t, _Float16, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vfsgnjn_vf)))
vfloat16mf4_t vfsgnjn(vfloat16mf4_t, _Float16, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vfsgnjn_vf_m)))
vfloat16mf4_t vfsgnjn(vbool64_t, vfloat16mf4_t, vfloat16mf4_t, _Float16, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vfsgnjx_vv)))
vfloat16m1_t vfsgnjx(vfloat16m1_t, vfloat16m1_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vfsgnjx_vv_m)))
vfloat16m1_t vfsgnjx(vbool16_t, vfloat16m1_t, vfloat16m1_t, vfloat16m1_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vfsgnjx_vv)))
vfloat16m2_t vfsgnjx(vfloat16m2_t, vfloat16m2_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vfsgnjx_vv_m)))
vfloat16m2_t vfsgnjx(vbool8_t, vfloat16m2_t, vfloat16m2_t, vfloat16m2_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vfsgnjx_vv)))
vfloat16m4_t vfsgnjx(vfloat16m4_t, vfloat16m4_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vfsgnjx_vv_m)))
vfloat16m4_t vfsgnjx(vbool4_t, vfloat16m4_t, vfloat16m4_t, vfloat16m4_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vfsgnjx_vv)))
vfloat16m8_t vfsgnjx(vfloat16m8_t, vfloat16m8_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vfsgnjx_vv_m)))
vfloat16m8_t vfsgnjx(vbool2_t, vfloat16m8_t, vfloat16m8_t, vfloat16m8_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vfsgnjx_vv)))
vfloat16mf2_t vfsgnjx(vfloat16mf2_t, vfloat16mf2_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vfsgnjx_vv_m)))
vfloat16mf2_t vfsgnjx(vbool32_t, vfloat16mf2_t, vfloat16mf2_t, vfloat16mf2_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vfsgnjx_vv)))
vfloat16mf4_t vfsgnjx(vfloat16mf4_t, vfloat16mf4_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vfsgnjx_vv_m)))
vfloat16mf4_t vfsgnjx(vbool64_t, vfloat16mf4_t, vfloat16mf4_t, vfloat16mf4_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vfsgnjx_vf)))
vfloat16m1_t vfsgnjx(vfloat16m1_t, _Float16, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vfsgnjx_vf_m)))
vfloat16m1_t vfsgnjx(vbool16_t, vfloat16m1_t, vfloat16m1_t, _Float16, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vfsgnjx_vf)))
vfloat16m2_t vfsgnjx(vfloat16m2_t, _Float16, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vfsgnjx_vf_m)))
vfloat16m2_t vfsgnjx(vbool8_t, vfloat16m2_t, vfloat16m2_t, _Float16, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vfsgnjx_vf)))
vfloat16m4_t vfsgnjx(vfloat16m4_t, _Float16, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vfsgnjx_vf_m)))
vfloat16m4_t vfsgnjx(vbool4_t, vfloat16m4_t, vfloat16m4_t, _Float16, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vfsgnjx_vf)))
vfloat16m8_t vfsgnjx(vfloat16m8_t, _Float16, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vfsgnjx_vf_m)))
vfloat16m8_t vfsgnjx(vbool2_t, vfloat16m8_t, vfloat16m8_t, _Float16, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vfsgnjx_vf)))
vfloat16mf2_t vfsgnjx(vfloat16mf2_t, _Float16, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vfsgnjx_vf_m)))
vfloat16mf2_t vfsgnjx(vbool32_t, vfloat16mf2_t, vfloat16mf2_t, _Float16, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vfsgnjx_vf)))
vfloat16mf4_t vfsgnjx(vfloat16mf4_t, _Float16, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vfsgnjx_vf_m)))
vfloat16mf4_t vfsgnjx(vbool64_t, vfloat16mf4_t, vfloat16mf4_t, _Float16, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vfabs_v)))
vfloat16m1_t vfabs(vfloat16m1_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vfabs_v_m)))
vfloat16m1_t vfabs(vbool16_t, vfloat16m1_t, vfloat16m1_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vfabs_v)))
vfloat16m2_t vfabs(vfloat16m2_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vfabs_v_m)))
vfloat16m2_t vfabs(vbool8_t, vfloat16m2_t, vfloat16m2_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vfabs_v)))
vfloat16m4_t vfabs(vfloat16m4_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vfabs_v_m)))
vfloat16m4_t vfabs(vbool4_t, vfloat16m4_t, vfloat16m4_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vfabs_v)))
vfloat16m8_t vfabs(vfloat16m8_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vfabs_v_m)))
vfloat16m8_t vfabs(vbool2_t, vfloat16m8_t, vfloat16m8_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vfabs_v)))
vfloat16mf2_t vfabs(vfloat16mf2_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vfabs_v_m)))
vfloat16mf2_t vfabs(vbool32_t, vfloat16mf2_t, vfloat16mf2_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vfabs_v)))
vfloat16mf4_t vfabs(vfloat16mf4_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vfabs_v_m)))
vfloat16mf4_t vfabs(vbool64_t, vfloat16mf4_t, vfloat16mf4_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vmfeq_vv)))
vbool16_t vmfeq(vfloat16m1_t, vfloat16m1_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vmfeq_vv_m)))
vbool16_t vmfeq(vbool16_t, vbool16_t, vfloat16m1_t, vfloat16m1_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vmfeq_vv)))
vbool8_t vmfeq(vfloat16m2_t, vfloat16m2_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vmfeq_vv_m)))
vbool8_t vmfeq(vbool8_t, vbool8_t, vfloat16m2_t, vfloat16m2_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vmfeq_vv)))
vbool4_t vmfeq(vfloat16m4_t, vfloat16m4_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vmfeq_vv_m)))
vbool4_t vmfeq(vbool4_t, vbool4_t, vfloat16m4_t, vfloat16m4_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vmfeq_vv)))
vbool2_t vmfeq(vfloat16m8_t, vfloat16m8_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vmfeq_vv_m)))
vbool2_t vmfeq(vbool2_t, vbool2_t, vfloat16m8_t, vfloat16m8_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vmfeq_vv)))
vbool32_t vmfeq(vfloat16mf2_t, vfloat16mf2_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vmfeq_vv_m)))
vbool32_t vmfeq(vbool32_t, vbool32_t, vfloat16mf2_t, vfloat16mf2_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vmfeq_vv)))
vbool64_t vmfeq(vfloat16mf4_t, vfloat16mf4_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vmfeq_vv_m)))
vbool64_t vmfeq(vbool64_t, vbool64_t, vfloat16mf4_t, vfloat16mf4_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vmfeq_vf)))
vbool16_t vmfeq(vfloat16m1_t, _Float16, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vmfeq_vf_m)))
vbool16_t vmfeq(vbool16_t, vbool16_t, vfloat16m1_t, _Float16, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vmfeq_vf)))
vbool8_t vmfeq(vfloat16m2_t, _Float16, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vmfeq_vf_m)))
vbool8_t vmfeq(vbool8_t, vbool8_t, vfloat16m2_t, _Float16, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vmfeq_vf)))
vbool4_t vmfeq(vfloat16m4_t, _Float16, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vmfeq_vf_m)))
vbool4_t vmfeq(vbool4_t, vbool4_t, vfloat16m4_t, _Float16, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vmfeq_vf)))
vbool2_t vmfeq(vfloat16m8_t, _Float16, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vmfeq_vf_m)))
vbool2_t vmfeq(vbool2_t, vbool2_t, vfloat16m8_t, _Float16, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vmfeq_vf)))
vbool32_t vmfeq(vfloat16mf2_t, _Float16, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vmfeq_vf_m)))
vbool32_t vmfeq(vbool32_t, vbool32_t, vfloat16mf2_t, _Float16, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vmfeq_vf)))
vbool64_t vmfeq(vfloat16mf4_t, _Float16, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vmfeq_vf_m)))
vbool64_t vmfeq(vbool64_t, vbool64_t, vfloat16mf4_t, _Float16, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vmfne_vv)))
vbool16_t vmfne(vfloat16m1_t, vfloat16m1_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vmfne_vv_m)))
vbool16_t vmfne(vbool16_t, vbool16_t, vfloat16m1_t, vfloat16m1_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vmfne_vv)))
vbool8_t vmfne(vfloat16m2_t, vfloat16m2_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vmfne_vv_m)))
vbool8_t vmfne(vbool8_t, vbool8_t, vfloat16m2_t, vfloat16m2_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vmfne_vv)))
vbool4_t vmfne(vfloat16m4_t, vfloat16m4_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vmfne_vv_m)))
vbool4_t vmfne(vbool4_t, vbool4_t, vfloat16m4_t, vfloat16m4_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vmfne_vv)))
vbool2_t vmfne(vfloat16m8_t, vfloat16m8_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vmfne_vv_m)))
vbool2_t vmfne(vbool2_t, vbool2_t, vfloat16m8_t, vfloat16m8_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vmfne_vv)))
vbool32_t vmfne(vfloat16mf2_t, vfloat16mf2_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vmfne_vv_m)))
vbool32_t vmfne(vbool32_t, vbool32_t, vfloat16mf2_t, vfloat16mf2_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vmfne_vv)))
vbool64_t vmfne(vfloat16mf4_t, vfloat16mf4_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vmfne_vv_m)))
vbool64_t vmfne(vbool64_t, vbool64_t, vfloat16mf4_t, vfloat16mf4_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vmfne_vf)))
vbool16_t vmfne(vfloat16m1_t, _Float16, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vmfne_vf_m)))
vbool16_t vmfne(vbool16_t, vbool16_t, vfloat16m1_t, _Float16, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vmfne_vf)))
vbool8_t vmfne(vfloat16m2_t, _Float16, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vmfne_vf_m)))
vbool8_t vmfne(vbool8_t, vbool8_t, vfloat16m2_t, _Float16, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vmfne_vf)))
vbool4_t vmfne(vfloat16m4_t, _Float16, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vmfne_vf_m)))
vbool4_t vmfne(vbool4_t, vbool4_t, vfloat16m4_t, _Float16, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vmfne_vf)))
vbool2_t vmfne(vfloat16m8_t, _Float16, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vmfne_vf_m)))
vbool2_t vmfne(vbool2_t, vbool2_t, vfloat16m8_t, _Float16, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vmfne_vf)))
vbool32_t vmfne(vfloat16mf2_t, _Float16, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vmfne_vf_m)))
vbool32_t vmfne(vbool32_t, vbool32_t, vfloat16mf2_t, _Float16, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vmfne_vf)))
vbool64_t vmfne(vfloat16mf4_t, _Float16, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vmfne_vf_m)))
vbool64_t vmfne(vbool64_t, vbool64_t, vfloat16mf4_t, _Float16, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vmflt_vv)))
vbool16_t vmflt(vfloat16m1_t, vfloat16m1_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vmflt_vv_m)))
vbool16_t vmflt(vbool16_t, vbool16_t, vfloat16m1_t, vfloat16m1_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vmflt_vv)))
vbool8_t vmflt(vfloat16m2_t, vfloat16m2_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vmflt_vv_m)))
vbool8_t vmflt(vbool8_t, vbool8_t, vfloat16m2_t, vfloat16m2_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vmflt_vv)))
vbool4_t vmflt(vfloat16m4_t, vfloat16m4_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vmflt_vv_m)))
vbool4_t vmflt(vbool4_t, vbool4_t, vfloat16m4_t, vfloat16m4_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vmflt_vv)))
vbool2_t vmflt(vfloat16m8_t, vfloat16m8_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vmflt_vv_m)))
vbool2_t vmflt(vbool2_t, vbool2_t, vfloat16m8_t, vfloat16m8_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vmflt_vv)))
vbool32_t vmflt(vfloat16mf2_t, vfloat16mf2_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vmflt_vv_m)))
vbool32_t vmflt(vbool32_t, vbool32_t, vfloat16mf2_t, vfloat16mf2_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vmflt_vv)))
vbool64_t vmflt(vfloat16mf4_t, vfloat16mf4_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vmflt_vv_m)))
vbool64_t vmflt(vbool64_t, vbool64_t, vfloat16mf4_t, vfloat16mf4_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vmflt_vf)))
vbool16_t vmflt(vfloat16m1_t, _Float16, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vmflt_vf_m)))
vbool16_t vmflt(vbool16_t, vbool16_t, vfloat16m1_t, _Float16, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vmflt_vf)))
vbool8_t vmflt(vfloat16m2_t, _Float16, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vmflt_vf_m)))
vbool8_t vmflt(vbool8_t, vbool8_t, vfloat16m2_t, _Float16, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vmflt_vf)))
vbool4_t vmflt(vfloat16m4_t, _Float16, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vmflt_vf_m)))
vbool4_t vmflt(vbool4_t, vbool4_t, vfloat16m4_t, _Float16, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vmflt_vf)))
vbool2_t vmflt(vfloat16m8_t, _Float16, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vmflt_vf_m)))
vbool2_t vmflt(vbool2_t, vbool2_t, vfloat16m8_t, _Float16, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vmflt_vf)))
vbool32_t vmflt(vfloat16mf2_t, _Float16, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vmflt_vf_m)))
vbool32_t vmflt(vbool32_t, vbool32_t, vfloat16mf2_t, _Float16, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vmflt_vf)))
vbool64_t vmflt(vfloat16mf4_t, _Float16, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vmflt_vf_m)))
vbool64_t vmflt(vbool64_t, vbool64_t, vfloat16mf4_t, _Float16, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vmfle_vv)))
vbool16_t vmfle(vfloat16m1_t, vfloat16m1_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vmfle_vv_m)))
vbool16_t vmfle(vbool16_t, vbool16_t, vfloat16m1_t, vfloat16m1_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vmfle_vv)))
vbool8_t vmfle(vfloat16m2_t, vfloat16m2_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vmfle_vv_m)))
vbool8_t vmfle(vbool8_t, vbool8_t, vfloat16m2_t, vfloat16m2_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vmfle_vv)))
vbool4_t vmfle(vfloat16m4_t, vfloat16m4_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vmfle_vv_m)))
vbool4_t vmfle(vbool4_t, vbool4_t, vfloat16m4_t, vfloat16m4_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vmfle_vv)))
vbool2_t vmfle(vfloat16m8_t, vfloat16m8_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vmfle_vv_m)))
vbool2_t vmfle(vbool2_t, vbool2_t, vfloat16m8_t, vfloat16m8_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vmfle_vv)))
vbool32_t vmfle(vfloat16mf2_t, vfloat16mf2_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vmfle_vv_m)))
vbool32_t vmfle(vbool32_t, vbool32_t, vfloat16mf2_t, vfloat16mf2_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vmfle_vv)))
vbool64_t vmfle(vfloat16mf4_t, vfloat16mf4_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vmfle_vv_m)))
vbool64_t vmfle(vbool64_t, vbool64_t, vfloat16mf4_t, vfloat16mf4_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vmfle_vf)))
vbool16_t vmfle(vfloat16m1_t, _Float16, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vmfle_vf_m)))
vbool16_t vmfle(vbool16_t, vbool16_t, vfloat16m1_t, _Float16, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vmfle_vf)))
vbool8_t vmfle(vfloat16m2_t, _Float16, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vmfle_vf_m)))
vbool8_t vmfle(vbool8_t, vbool8_t, vfloat16m2_t, _Float16, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vmfle_vf)))
vbool4_t vmfle(vfloat16m4_t, _Float16, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vmfle_vf_m)))
vbool4_t vmfle(vbool4_t, vbool4_t, vfloat16m4_t, _Float16, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vmfle_vf)))
vbool2_t vmfle(vfloat16m8_t, _Float16, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vmfle_vf_m)))
vbool2_t vmfle(vbool2_t, vbool2_t, vfloat16m8_t, _Float16, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vmfle_vf)))
vbool32_t vmfle(vfloat16mf2_t, _Float16, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vmfle_vf_m)))
vbool32_t vmfle(vbool32_t, vbool32_t, vfloat16mf2_t, _Float16, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vmfle_vf)))
vbool64_t vmfle(vfloat16mf4_t, _Float16, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vmfle_vf_m)))
vbool64_t vmfle(vbool64_t, vbool64_t, vfloat16mf4_t, _Float16, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vmfgt_vv)))
vbool16_t vmfgt(vfloat16m1_t, vfloat16m1_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vmfgt_vv_m)))
vbool16_t vmfgt(vbool16_t, vbool16_t, vfloat16m1_t, vfloat16m1_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vmfgt_vv)))
vbool8_t vmfgt(vfloat16m2_t, vfloat16m2_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vmfgt_vv_m)))
vbool8_t vmfgt(vbool8_t, vbool8_t, vfloat16m2_t, vfloat16m2_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vmfgt_vv)))
vbool4_t vmfgt(vfloat16m4_t, vfloat16m4_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vmfgt_vv_m)))
vbool4_t vmfgt(vbool4_t, vbool4_t, vfloat16m4_t, vfloat16m4_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vmfgt_vv)))
vbool2_t vmfgt(vfloat16m8_t, vfloat16m8_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vmfgt_vv_m)))
vbool2_t vmfgt(vbool2_t, vbool2_t, vfloat16m8_t, vfloat16m8_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vmfgt_vv)))
vbool32_t vmfgt(vfloat16mf2_t, vfloat16mf2_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vmfgt_vv_m)))
vbool32_t vmfgt(vbool32_t, vbool32_t, vfloat16mf2_t, vfloat16mf2_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vmfgt_vv)))
vbool64_t vmfgt(vfloat16mf4_t, vfloat16mf4_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vmfgt_vv_m)))
vbool64_t vmfgt(vbool64_t, vbool64_t, vfloat16mf4_t, vfloat16mf4_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vmfgt_vf)))
vbool16_t vmfgt(vfloat16m1_t, _Float16, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vmfgt_vf_m)))
vbool16_t vmfgt(vbool16_t, vbool16_t, vfloat16m1_t, _Float16, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vmfgt_vf)))
vbool8_t vmfgt(vfloat16m2_t, _Float16, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vmfgt_vf_m)))
vbool8_t vmfgt(vbool8_t, vbool8_t, vfloat16m2_t, _Float16, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vmfgt_vf)))
vbool4_t vmfgt(vfloat16m4_t, _Float16, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vmfgt_vf_m)))
vbool4_t vmfgt(vbool4_t, vbool4_t, vfloat16m4_t, _Float16, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vmfgt_vf)))
vbool2_t vmfgt(vfloat16m8_t, _Float16, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vmfgt_vf_m)))
vbool2_t vmfgt(vbool2_t, vbool2_t, vfloat16m8_t, _Float16, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vmfgt_vf)))
vbool32_t vmfgt(vfloat16mf2_t, _Float16, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vmfgt_vf_m)))
vbool32_t vmfgt(vbool32_t, vbool32_t, vfloat16mf2_t, _Float16, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vmfgt_vf)))
vbool64_t vmfgt(vfloat16mf4_t, _Float16, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vmfgt_vf_m)))
vbool64_t vmfgt(vbool64_t, vbool64_t, vfloat16mf4_t, _Float16, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vmfge_vv)))
vbool16_t vmfge(vfloat16m1_t, vfloat16m1_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vmfge_vv_m)))
vbool16_t vmfge(vbool16_t, vbool16_t, vfloat16m1_t, vfloat16m1_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vmfge_vv)))
vbool8_t vmfge(vfloat16m2_t, vfloat16m2_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vmfge_vv_m)))
vbool8_t vmfge(vbool8_t, vbool8_t, vfloat16m2_t, vfloat16m2_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vmfge_vv)))
vbool4_t vmfge(vfloat16m4_t, vfloat16m4_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vmfge_vv_m)))
vbool4_t vmfge(vbool4_t, vbool4_t, vfloat16m4_t, vfloat16m4_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vmfge_vv)))
vbool2_t vmfge(vfloat16m8_t, vfloat16m8_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vmfge_vv_m)))
vbool2_t vmfge(vbool2_t, vbool2_t, vfloat16m8_t, vfloat16m8_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vmfge_vv)))
vbool32_t vmfge(vfloat16mf2_t, vfloat16mf2_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vmfge_vv_m)))
vbool32_t vmfge(vbool32_t, vbool32_t, vfloat16mf2_t, vfloat16mf2_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vmfge_vv)))
vbool64_t vmfge(vfloat16mf4_t, vfloat16mf4_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vmfge_vv_m)))
vbool64_t vmfge(vbool64_t, vbool64_t, vfloat16mf4_t, vfloat16mf4_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vmfge_vf)))
vbool16_t vmfge(vfloat16m1_t, _Float16, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vmfge_vf_m)))
vbool16_t vmfge(vbool16_t, vbool16_t, vfloat16m1_t, _Float16, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vmfge_vf)))
vbool8_t vmfge(vfloat16m2_t, _Float16, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vmfge_vf_m)))
vbool8_t vmfge(vbool8_t, vbool8_t, vfloat16m2_t, _Float16, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vmfge_vf)))
vbool4_t vmfge(vfloat16m4_t, _Float16, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vmfge_vf_m)))
vbool4_t vmfge(vbool4_t, vbool4_t, vfloat16m4_t, _Float16, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vmfge_vf)))
vbool2_t vmfge(vfloat16m8_t, _Float16, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vmfge_vf_m)))
vbool2_t vmfge(vbool2_t, vbool2_t, vfloat16m8_t, _Float16, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vmfge_vf)))
vbool32_t vmfge(vfloat16mf2_t, _Float16, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vmfge_vf_m)))
vbool32_t vmfge(vbool32_t, vbool32_t, vfloat16mf2_t, _Float16, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vmfge_vf)))
vbool64_t vmfge(vfloat16mf4_t, _Float16, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vmfge_vf_m)))
vbool64_t vmfge(vbool64_t, vbool64_t, vfloat16mf4_t, _Float16, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vmerge_vvm)))
vfloat16m1_t vmerge(vbool16_t, vfloat16m1_t, vfloat16m1_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vmerge_vvm)))
vfloat16m2_t vmerge(vbool8_t, vfloat16m2_t, vfloat16m2_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vmerge_vvm)))
vfloat16m4_t vmerge(vbool4_t, vfloat16m4_t, vfloat16m4_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vmerge_vvm)))
vfloat16m8_t vmerge(vbool2_t, vfloat16m8_t, vfloat16m8_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vmerge_vvm)))
vfloat16mf2_t vmerge(vbool32_t, vfloat16mf2_t, vfloat16mf2_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vmerge_vvm)))
vfloat16mf4_t vmerge(vbool64_t, vfloat16mf4_t, vfloat16mf4_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vfmerge_vfm)))
vfloat16m1_t vfmerge(vbool16_t, vfloat16m1_t, _Float16, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vfmerge_vfm)))
vfloat16m2_t vfmerge(vbool8_t, vfloat16m2_t, _Float16, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vfmerge_vfm)))
vfloat16m4_t vfmerge(vbool4_t, vfloat16m4_t, _Float16, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vfmerge_vfm)))
vfloat16m8_t vfmerge(vbool2_t, vfloat16m8_t, _Float16, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vfmerge_vfm)))
vfloat16mf2_t vfmerge(vbool32_t, vfloat16mf2_t, _Float16, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vfmerge_vfm)))
vfloat16mf4_t vfmerge(vbool64_t, vfloat16mf4_t, _Float16, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vfredmax_vs)))
vfloat16m1_t vfredmax(vfloat16m1_t, vfloat16m1_t, vfloat16m1_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vfredmax_vs_m)))
vfloat16m1_t vfredmax(vbool16_t, vfloat16m1_t, vfloat16m1_t, vfloat16m1_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vfredmax_vs)))
vfloat16m1_t vfredmax(vfloat16m1_t, vfloat16m2_t, vfloat16m1_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vfredmax_vs_m)))
vfloat16m1_t vfredmax(vbool8_t, vfloat16m1_t, vfloat16m2_t, vfloat16m1_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vfredmax_vs)))
vfloat16m1_t vfredmax(vfloat16m1_t, vfloat16m4_t, vfloat16m1_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vfredmax_vs_m)))
vfloat16m1_t vfredmax(vbool4_t, vfloat16m1_t, vfloat16m4_t, vfloat16m1_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vfredmax_vs)))
vfloat16m1_t vfredmax(vfloat16m1_t, vfloat16m8_t, vfloat16m1_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vfredmax_vs_m)))
vfloat16m1_t vfredmax(vbool2_t, vfloat16m1_t, vfloat16m8_t, vfloat16m1_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vfredmax_vs)))
vfloat16m1_t vfredmax(vfloat16m1_t, vfloat16mf2_t, vfloat16m1_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vfredmax_vs_m)))
vfloat16m1_t vfredmax(vbool32_t, vfloat16m1_t, vfloat16mf2_t, vfloat16m1_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vfredmax_vs)))
vfloat16m1_t vfredmax(vfloat16m1_t, vfloat16mf4_t, vfloat16m1_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vfredmax_vs_m)))
vfloat16m1_t vfredmax(vbool64_t, vfloat16m1_t, vfloat16mf4_t, vfloat16m1_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vfredmin_vs)))
vfloat16m1_t vfredmin(vfloat16m1_t, vfloat16m1_t, vfloat16m1_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vfredmin_vs_m)))
vfloat16m1_t vfredmin(vbool16_t, vfloat16m1_t, vfloat16m1_t, vfloat16m1_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vfredmin_vs)))
vfloat16m1_t vfredmin(vfloat16m1_t, vfloat16m2_t, vfloat16m1_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vfredmin_vs_m)))
vfloat16m1_t vfredmin(vbool8_t, vfloat16m1_t, vfloat16m2_t, vfloat16m1_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vfredmin_vs)))
vfloat16m1_t vfredmin(vfloat16m1_t, vfloat16m4_t, vfloat16m1_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vfredmin_vs_m)))
vfloat16m1_t vfredmin(vbool4_t, vfloat16m1_t, vfloat16m4_t, vfloat16m1_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vfredmin_vs)))
vfloat16m1_t vfredmin(vfloat16m1_t, vfloat16m8_t, vfloat16m1_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vfredmin_vs_m)))
vfloat16m1_t vfredmin(vbool2_t, vfloat16m1_t, vfloat16m8_t, vfloat16m1_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vfredmin_vs)))
vfloat16m1_t vfredmin(vfloat16m1_t, vfloat16mf2_t, vfloat16m1_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vfredmin_vs_m)))
vfloat16m1_t vfredmin(vbool32_t, vfloat16m1_t, vfloat16mf2_t, vfloat16m1_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vfredmin_vs)))
vfloat16m1_t vfredmin(vfloat16m1_t, vfloat16mf4_t, vfloat16m1_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vfredmin_vs_m)))
vfloat16m1_t vfredmin(vbool64_t, vfloat16m1_t, vfloat16mf4_t, vfloat16m1_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vfredusum_vs)))
vfloat16m1_t vfredusum(vfloat16m1_t, vfloat16m1_t, vfloat16m1_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vfredusum_vs_m)))
vfloat16m1_t vfredusum(vbool16_t, vfloat16m1_t, vfloat16m1_t, vfloat16m1_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vfredusum_vs)))
vfloat16m1_t vfredusum(vfloat16m1_t, vfloat16m2_t, vfloat16m1_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vfredusum_vs_m)))
vfloat16m1_t vfredusum(vbool8_t, vfloat16m1_t, vfloat16m2_t, vfloat16m1_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vfredusum_vs)))
vfloat16m1_t vfredusum(vfloat16m1_t, vfloat16m4_t, vfloat16m1_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vfredusum_vs_m)))
vfloat16m1_t vfredusum(vbool4_t, vfloat16m1_t, vfloat16m4_t, vfloat16m1_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vfredusum_vs)))
vfloat16m1_t vfredusum(vfloat16m1_t, vfloat16m8_t, vfloat16m1_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vfredusum_vs_m)))
vfloat16m1_t vfredusum(vbool2_t, vfloat16m1_t, vfloat16m8_t, vfloat16m1_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vfredusum_vs)))
vfloat16m1_t vfredusum(vfloat16m1_t, vfloat16mf2_t, vfloat16m1_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vfredusum_vs_m)))
vfloat16m1_t vfredusum(vbool32_t, vfloat16m1_t, vfloat16mf2_t, vfloat16m1_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vfredusum_vs)))
vfloat16m1_t vfredusum(vfloat16m1_t, vfloat16mf4_t, vfloat16m1_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vfredusum_vs_m)))
vfloat16m1_t vfredusum(vbool64_t, vfloat16m1_t, vfloat16mf4_t, vfloat16m1_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vfredosum_vs)))
vfloat16m1_t vfredosum(vfloat16m1_t, vfloat16m1_t, vfloat16m1_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vfredosum_vs_m)))
vfloat16m1_t vfredosum(vbool16_t, vfloat16m1_t, vfloat16m1_t, vfloat16m1_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vfredosum_vs)))
vfloat16m1_t vfredosum(vfloat16m1_t, vfloat16m2_t, vfloat16m1_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vfredosum_vs_m)))
vfloat16m1_t vfredosum(vbool8_t, vfloat16m1_t, vfloat16m2_t, vfloat16m1_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vfredosum_vs)))
vfloat16m1_t vfredosum(vfloat16m1_t, vfloat16m4_t, vfloat16m1_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vfredosum_vs_m)))
vfloat16m1_t vfredosum(vbool4_t, vfloat16m1_t, vfloat16m4_t, vfloat16m1_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vfredosum_vs)))
vfloat16m1_t vfredosum(vfloat16m1_t, vfloat16m8_t, vfloat16m1_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vfredosum_vs_m)))
vfloat16m1_t vfredosum(vbool2_t, vfloat16m1_t, vfloat16m8_t, vfloat16m1_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vfredosum_vs)))
vfloat16m1_t vfredosum(vfloat16m1_t, vfloat16mf2_t, vfloat16m1_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vfredosum_vs_m)))
vfloat16m1_t vfredosum(vbool32_t, vfloat16m1_t, vfloat16mf2_t, vfloat16m1_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vfredosum_vs)))
vfloat16m1_t vfredosum(vfloat16m1_t, vfloat16mf4_t, vfloat16m1_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vfredosum_vs_m)))
vfloat16m1_t vfredosum(vbool64_t, vfloat16m1_t, vfloat16mf4_t, vfloat16m1_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vfmv_f_s)))
_Float16 vfmv_f(vfloat16m1_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vfmv_f_s)))
_Float16 vfmv_f(vfloat16m2_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vfmv_f_s)))
_Float16 vfmv_f(vfloat16m4_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vfmv_f_s)))
_Float16 vfmv_f(vfloat16m8_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vfmv_f_s)))
_Float16 vfmv_f(vfloat16mf2_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vfmv_f_s)))
_Float16 vfmv_f(vfloat16mf4_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vfmv_s_f)))
vfloat16m1_t vfmv_s(vfloat16m1_t, _Float16, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vfmv_s_f)))
vfloat16m2_t vfmv_s(vfloat16m2_t, _Float16, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vfmv_s_f)))
vfloat16m4_t vfmv_s(vfloat16m4_t, _Float16, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vfmv_s_f)))
vfloat16m8_t vfmv_s(vfloat16m8_t, _Float16, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vfmv_s_f)))
vfloat16mf2_t vfmv_s(vfloat16mf2_t, _Float16, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vfmv_s_f)))
vfloat16mf4_t vfmv_s(vfloat16mf4_t, _Float16, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vslideup_vx)))
vfloat16m1_t vslideup(vfloat16m1_t, vfloat16m1_t, size_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vslideup_vx_m)))
vfloat16m1_t vslideup(vbool16_t, vfloat16m1_t, vfloat16m1_t, size_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vslideup_vx)))
vfloat16m2_t vslideup(vfloat16m2_t, vfloat16m2_t, size_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vslideup_vx_m)))
vfloat16m2_t vslideup(vbool8_t, vfloat16m2_t, vfloat16m2_t, size_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vslideup_vx)))
vfloat16m4_t vslideup(vfloat16m4_t, vfloat16m4_t, size_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vslideup_vx_m)))
vfloat16m4_t vslideup(vbool4_t, vfloat16m4_t, vfloat16m4_t, size_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vslideup_vx)))
vfloat16m8_t vslideup(vfloat16m8_t, vfloat16m8_t, size_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vslideup_vx_m)))
vfloat16m8_t vslideup(vbool2_t, vfloat16m8_t, vfloat16m8_t, size_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vslideup_vx)))
vfloat16mf2_t vslideup(vfloat16mf2_t, vfloat16mf2_t, size_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vslideup_vx_m)))
vfloat16mf2_t vslideup(vbool32_t, vfloat16mf2_t, vfloat16mf2_t, size_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vslideup_vx)))
vfloat16mf4_t vslideup(vfloat16mf4_t, vfloat16mf4_t, size_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vslideup_vx_m)))
vfloat16mf4_t vslideup(vbool64_t, vfloat16mf4_t, vfloat16mf4_t, size_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vslidedown_vx)))
vfloat16m1_t vslidedown(vfloat16m1_t, vfloat16m1_t, size_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vslidedown_vx_m)))
vfloat16m1_t vslidedown(vbool16_t, vfloat16m1_t, vfloat16m1_t, size_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vslidedown_vx)))
vfloat16m2_t vslidedown(vfloat16m2_t, vfloat16m2_t, size_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vslidedown_vx_m)))
vfloat16m2_t vslidedown(vbool8_t, vfloat16m2_t, vfloat16m2_t, size_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vslidedown_vx)))
vfloat16m4_t vslidedown(vfloat16m4_t, vfloat16m4_t, size_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vslidedown_vx_m)))
vfloat16m4_t vslidedown(vbool4_t, vfloat16m4_t, vfloat16m4_t, size_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vslidedown_vx)))
vfloat16m8_t vslidedown(vfloat16m8_t, vfloat16m8_t, size_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vslidedown_vx_m)))
vfloat16m8_t vslidedown(vbool2_t, vfloat16m8_t, vfloat16m8_t, size_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vslidedown_vx)))
vfloat16mf2_t vslidedown(vfloat16mf2_t, vfloat16mf2_t, size_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vslidedown_vx_m)))
vfloat16mf2_t vslidedown(vbool32_t, vfloat16mf2_t, vfloat16mf2_t, size_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vslidedown_vx)))
vfloat16mf4_t vslidedown(vfloat16mf4_t, vfloat16mf4_t, size_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vslidedown_vx_m)))
vfloat16mf4_t vslidedown(vbool64_t, vfloat16mf4_t, vfloat16mf4_t, size_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vfslide1up_vf)))
vfloat16m1_t vfslide1up(vfloat16m1_t, _Float16, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vfslide1up_vf_m)))
vfloat16m1_t vfslide1up(vbool16_t, vfloat16m1_t, vfloat16m1_t, _Float16, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vfslide1up_vf)))
vfloat16m2_t vfslide1up(vfloat16m2_t, _Float16, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vfslide1up_vf_m)))
vfloat16m2_t vfslide1up(vbool8_t, vfloat16m2_t, vfloat16m2_t, _Float16, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vfslide1up_vf)))
vfloat16m4_t vfslide1up(vfloat16m4_t, _Float16, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vfslide1up_vf_m)))
vfloat16m4_t vfslide1up(vbool4_t, vfloat16m4_t, vfloat16m4_t, _Float16, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vfslide1up_vf)))
vfloat16m8_t vfslide1up(vfloat16m8_t, _Float16, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vfslide1up_vf_m)))
vfloat16m8_t vfslide1up(vbool2_t, vfloat16m8_t, vfloat16m8_t, _Float16, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vfslide1up_vf)))
vfloat16mf2_t vfslide1up(vfloat16mf2_t, _Float16, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vfslide1up_vf_m)))
vfloat16mf2_t vfslide1up(vbool32_t, vfloat16mf2_t, vfloat16mf2_t, _Float16, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vfslide1up_vf)))
vfloat16mf4_t vfslide1up(vfloat16mf4_t, _Float16, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vfslide1up_vf_m)))
vfloat16mf4_t vfslide1up(vbool64_t, vfloat16mf4_t, vfloat16mf4_t, _Float16, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vfslide1down_vf)))
vfloat16m1_t vfslide1down(vfloat16m1_t, _Float16, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vfslide1down_vf_m)))
vfloat16m1_t vfslide1down(vbool16_t, vfloat16m1_t, vfloat16m1_t, _Float16, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vfslide1down_vf)))
vfloat16m2_t vfslide1down(vfloat16m2_t, _Float16, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vfslide1down_vf_m)))
vfloat16m2_t vfslide1down(vbool8_t, vfloat16m2_t, vfloat16m2_t, _Float16, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vfslide1down_vf)))
vfloat16m4_t vfslide1down(vfloat16m4_t, _Float16, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vfslide1down_vf_m)))
vfloat16m4_t vfslide1down(vbool4_t, vfloat16m4_t, vfloat16m4_t, _Float16, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vfslide1down_vf)))
vfloat16m8_t vfslide1down(vfloat16m8_t, _Float16, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vfslide1down_vf_m)))
vfloat16m8_t vfslide1down(vbool2_t, vfloat16m8_t, vfloat16m8_t, _Float16, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vfslide1down_vf)))
vfloat16mf2_t vfslide1down(vfloat16mf2_t, _Float16, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vfslide1down_vf_m)))
vfloat16mf2_t vfslide1down(vbool32_t, vfloat16mf2_t, vfloat16mf2_t, _Float16, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vfslide1down_vf)))
vfloat16mf4_t vfslide1down(vfloat16mf4_t, _Float16, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vfslide1down_vf_m)))
vfloat16mf4_t vfslide1down(vbool64_t, vfloat16mf4_t, vfloat16mf4_t, _Float16, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vrgather_vv)))
vfloat16m1_t vrgather(vfloat16m1_t, vuint16m1_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vrgather_vv_m)))
vfloat16m1_t vrgather(vbool16_t, vfloat16m1_t, vfloat16m1_t, vuint16m1_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vrgather_vv)))
vfloat16m2_t vrgather(vfloat16m2_t, vuint16m2_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vrgather_vv_m)))
vfloat16m2_t vrgather(vbool8_t, vfloat16m2_t, vfloat16m2_t, vuint16m2_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vrgather_vv)))
vfloat16m4_t vrgather(vfloat16m4_t, vuint16m4_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vrgather_vv_m)))
vfloat16m4_t vrgather(vbool4_t, vfloat16m4_t, vfloat16m4_t, vuint16m4_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vrgather_vv)))
vfloat16m8_t vrgather(vfloat16m8_t, vuint16m8_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vrgather_vv_m)))
vfloat16m8_t vrgather(vbool2_t, vfloat16m8_t, vfloat16m8_t, vuint16m8_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vrgather_vv)))
vfloat16mf2_t vrgather(vfloat16mf2_t, vuint16mf2_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vrgather_vv_m)))
vfloat16mf2_t vrgather(vbool32_t, vfloat16mf2_t, vfloat16mf2_t, vuint16mf2_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vrgather_vv)))
vfloat16mf4_t vrgather(vfloat16mf4_t, vuint16mf4_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vrgather_vv_m)))
vfloat16mf4_t vrgather(vbool64_t, vfloat16mf4_t, vfloat16mf4_t, vuint16mf4_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vrgather_vx)))
vfloat16m1_t vrgather(vfloat16m1_t, size_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vrgather_vx_m)))
vfloat16m1_t vrgather(vbool16_t, vfloat16m1_t, vfloat16m1_t, size_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vrgather_vx)))
vfloat16m2_t vrgather(vfloat16m2_t, size_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vrgather_vx_m)))
vfloat16m2_t vrgather(vbool8_t, vfloat16m2_t, vfloat16m2_t, size_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vrgather_vx)))
vfloat16m4_t vrgather(vfloat16m4_t, size_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vrgather_vx_m)))
vfloat16m4_t vrgather(vbool4_t, vfloat16m4_t, vfloat16m4_t, size_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vrgather_vx)))
vfloat16m8_t vrgather(vfloat16m8_t, size_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vrgather_vx_m)))
vfloat16m8_t vrgather(vbool2_t, vfloat16m8_t, vfloat16m8_t, size_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vrgather_vx)))
vfloat16mf2_t vrgather(vfloat16mf2_t, size_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vrgather_vx_m)))
vfloat16mf2_t vrgather(vbool32_t, vfloat16mf2_t, vfloat16mf2_t, size_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vrgather_vx)))
vfloat16mf4_t vrgather(vfloat16mf4_t, size_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vrgather_vx_m)))
vfloat16mf4_t vrgather(vbool64_t, vfloat16mf4_t, vfloat16mf4_t, size_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vrgatherei16_vv)))
vfloat16m1_t vrgatherei16(vfloat16m1_t, vuint16m1_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vrgatherei16_vv_m)))
vfloat16m1_t vrgatherei16(vbool16_t, vfloat16m1_t, vfloat16m1_t, vuint16m1_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vrgatherei16_vv)))
vfloat16m2_t vrgatherei16(vfloat16m2_t, vuint16m2_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vrgatherei16_vv_m)))
vfloat16m2_t vrgatherei16(vbool8_t, vfloat16m2_t, vfloat16m2_t, vuint16m2_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vrgatherei16_vv)))
vfloat16m4_t vrgatherei16(vfloat16m4_t, vuint16m4_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vrgatherei16_vv_m)))
vfloat16m4_t vrgatherei16(vbool4_t, vfloat16m4_t, vfloat16m4_t, vuint16m4_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vrgatherei16_vv)))
vfloat16m8_t vrgatherei16(vfloat16m8_t, vuint16m8_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vrgatherei16_vv_m)))
vfloat16m8_t vrgatherei16(vbool2_t, vfloat16m8_t, vfloat16m8_t, vuint16m8_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vrgatherei16_vv)))
vfloat16mf2_t vrgatherei16(vfloat16mf2_t, vuint16mf2_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vrgatherei16_vv_m)))
vfloat16mf2_t vrgatherei16(vbool32_t, vfloat16mf2_t, vfloat16mf2_t, vuint16mf2_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vrgatherei16_vv)))
vfloat16mf4_t vrgatherei16(vfloat16mf4_t, vuint16mf4_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vrgatherei16_vv_m)))
vfloat16mf4_t vrgatherei16(vbool64_t, vfloat16mf4_t, vfloat16mf4_t, vuint16mf4_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vcompress_vm)))
vfloat16m1_t vcompress(vbool16_t, vfloat16m1_t, vfloat16m1_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vcompress_vm)))
vfloat16m2_t vcompress(vbool8_t, vfloat16m2_t, vfloat16m2_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vcompress_vm)))
vfloat16m4_t vcompress(vbool4_t, vfloat16m4_t, vfloat16m4_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vcompress_vm)))
vfloat16m8_t vcompress(vbool2_t, vfloat16m8_t, vfloat16m8_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vcompress_vm)))
vfloat16mf2_t vcompress(vbool32_t, vfloat16mf2_t, vfloat16mf2_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vcompress_vm)))
vfloat16mf4_t vcompress(vbool64_t, vfloat16mf4_t, vfloat16mf4_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vget_v)))
vfloat16m1_t vget_f16m1(vfloat16m2_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vget_v)))
vfloat16m1_t vget_f16m1(vfloat16m4_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vget_v)))
vfloat16m1_t vget_f16m1(vfloat16m8_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vget_v)))
vfloat16m2_t vget_f16m2(vfloat16m4_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vget_v)))
vfloat16m2_t vget_f16m2(vfloat16m8_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vget_v)))
vfloat16m4_t vget_f16m4(vfloat16m8_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vset_v)))
vfloat16m2_t vset(vfloat16m2_t, size_t, vfloat16m1_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vset_v)))
vfloat16m4_t vset(vfloat16m4_t, size_t, vfloat16m1_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vset_v)))
vfloat16m4_t vset(vfloat16m4_t, size_t, vfloat16m2_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vset_v)))
vfloat16m8_t vset(vfloat16m8_t, size_t, vfloat16m1_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vset_v)))
vfloat16m8_t vset(vfloat16m8_t, size_t, vfloat16m2_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vset_v)))
vfloat16m8_t vset(vfloat16m8_t, size_t, vfloat16m4_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vsuxei8_v)))
void vsuxei8(_Float16 *, vuint8mf2_t, vfloat16m1_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vsuxei8_v_m)))
void vsuxei8(vbool16_t, _Float16 *, vuint8mf2_t, vfloat16m1_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vsuxei8_v)))
void vsuxei8(_Float16 *, vuint8m1_t, vfloat16m2_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vsuxei8_v_m)))
void vsuxei8(vbool8_t, _Float16 *, vuint8m1_t, vfloat16m2_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vsuxei8_v)))
void vsuxei8(_Float16 *, vuint8m2_t, vfloat16m4_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vsuxei8_v_m)))
void vsuxei8(vbool4_t, _Float16 *, vuint8m2_t, vfloat16m4_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vsuxei8_v)))
void vsuxei8(_Float16 *, vuint8m4_t, vfloat16m8_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vsuxei8_v_m)))
void vsuxei8(vbool2_t, _Float16 *, vuint8m4_t, vfloat16m8_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vsuxei8_v)))
void vsuxei8(_Float16 *, vuint8mf4_t, vfloat16mf2_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vsuxei8_v_m)))
void vsuxei8(vbool32_t, _Float16 *, vuint8mf4_t, vfloat16mf2_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vsuxei8_v)))
void vsuxei8(_Float16 *, vuint8mf8_t, vfloat16mf4_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vsuxei8_v_m)))
void vsuxei8(vbool64_t, _Float16 *, vuint8mf8_t, vfloat16mf4_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vsuxei16_v)))
void vsuxei16(_Float16 *, vuint16m1_t, vfloat16m1_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vsuxei16_v_m)))
void vsuxei16(vbool16_t, _Float16 *, vuint16m1_t, vfloat16m1_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vsuxei16_v)))
void vsuxei16(_Float16 *, vuint16m2_t, vfloat16m2_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vsuxei16_v_m)))
void vsuxei16(vbool8_t, _Float16 *, vuint16m2_t, vfloat16m2_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vsuxei16_v)))
void vsuxei16(_Float16 *, vuint16m4_t, vfloat16m4_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vsuxei16_v_m)))
void vsuxei16(vbool4_t, _Float16 *, vuint16m4_t, vfloat16m4_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vsuxei16_v)))
void vsuxei16(_Float16 *, vuint16m8_t, vfloat16m8_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vsuxei16_v_m)))
void vsuxei16(vbool2_t, _Float16 *, vuint16m8_t, vfloat16m8_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vsuxei16_v)))
void vsuxei16(_Float16 *, vuint16mf2_t, vfloat16mf2_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vsuxei16_v_m)))
void vsuxei16(vbool32_t, _Float16 *, vuint16mf2_t, vfloat16mf2_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vsuxei16_v)))
void vsuxei16(_Float16 *, vuint16mf4_t, vfloat16mf4_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vsuxei16_v_m)))
void vsuxei16(vbool64_t, _Float16 *, vuint16mf4_t, vfloat16mf4_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vsuxei32_v)))
void vsuxei32(_Float16 *, vuint32m2_t, vfloat16m1_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vsuxei32_v_m)))
void vsuxei32(vbool16_t, _Float16 *, vuint32m2_t, vfloat16m1_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vsuxei32_v)))
void vsuxei32(_Float16 *, vuint32m4_t, vfloat16m2_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vsuxei32_v_m)))
void vsuxei32(vbool8_t, _Float16 *, vuint32m4_t, vfloat16m2_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vsuxei32_v)))
void vsuxei32(_Float16 *, vuint32m8_t, vfloat16m4_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vsuxei32_v_m)))
void vsuxei32(vbool4_t, _Float16 *, vuint32m8_t, vfloat16m4_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vsuxei32_v)))
void vsuxei32(_Float16 *, vuint32m1_t, vfloat16mf2_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vsuxei32_v_m)))
void vsuxei32(vbool32_t, _Float16 *, vuint32m1_t, vfloat16mf2_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vsuxei32_v)))
void vsuxei32(_Float16 *, vuint32mf2_t, vfloat16mf4_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vsuxei32_v_m)))
void vsuxei32(vbool64_t, _Float16 *, vuint32mf2_t, vfloat16mf4_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vsoxei8_v)))
void vsoxei8(_Float16 *, vuint8mf2_t, vfloat16m1_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vsoxei8_v_m)))
void vsoxei8(vbool16_t, _Float16 *, vuint8mf2_t, vfloat16m1_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vsoxei8_v)))
void vsoxei8(_Float16 *, vuint8m1_t, vfloat16m2_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vsoxei8_v_m)))
void vsoxei8(vbool8_t, _Float16 *, vuint8m1_t, vfloat16m2_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vsoxei8_v)))
void vsoxei8(_Float16 *, vuint8m2_t, vfloat16m4_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vsoxei8_v_m)))
void vsoxei8(vbool4_t, _Float16 *, vuint8m2_t, vfloat16m4_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vsoxei8_v)))
void vsoxei8(_Float16 *, vuint8m4_t, vfloat16m8_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vsoxei8_v_m)))
void vsoxei8(vbool2_t, _Float16 *, vuint8m4_t, vfloat16m8_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vsoxei8_v)))
void vsoxei8(_Float16 *, vuint8mf4_t, vfloat16mf2_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vsoxei8_v_m)))
void vsoxei8(vbool32_t, _Float16 *, vuint8mf4_t, vfloat16mf2_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vsoxei8_v)))
void vsoxei8(_Float16 *, vuint8mf8_t, vfloat16mf4_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vsoxei8_v_m)))
void vsoxei8(vbool64_t, _Float16 *, vuint8mf8_t, vfloat16mf4_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vsoxei16_v)))
void vsoxei16(_Float16 *, vuint16m1_t, vfloat16m1_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vsoxei16_v_m)))
void vsoxei16(vbool16_t, _Float16 *, vuint16m1_t, vfloat16m1_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vsoxei16_v)))
void vsoxei16(_Float16 *, vuint16m2_t, vfloat16m2_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vsoxei16_v_m)))
void vsoxei16(vbool8_t, _Float16 *, vuint16m2_t, vfloat16m2_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vsoxei16_v)))
void vsoxei16(_Float16 *, vuint16m4_t, vfloat16m4_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vsoxei16_v_m)))
void vsoxei16(vbool4_t, _Float16 *, vuint16m4_t, vfloat16m4_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vsoxei16_v)))
void vsoxei16(_Float16 *, vuint16m8_t, vfloat16m8_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vsoxei16_v_m)))
void vsoxei16(vbool2_t, _Float16 *, vuint16m8_t, vfloat16m8_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vsoxei16_v)))
void vsoxei16(_Float16 *, vuint16mf2_t, vfloat16mf2_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vsoxei16_v_m)))
void vsoxei16(vbool32_t, _Float16 *, vuint16mf2_t, vfloat16mf2_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vsoxei16_v)))
void vsoxei16(_Float16 *, vuint16mf4_t, vfloat16mf4_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vsoxei16_v_m)))
void vsoxei16(vbool64_t, _Float16 *, vuint16mf4_t, vfloat16mf4_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vsoxei32_v)))
void vsoxei32(_Float16 *, vuint32m2_t, vfloat16m1_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vsoxei32_v_m)))
void vsoxei32(vbool16_t, _Float16 *, vuint32m2_t, vfloat16m1_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vsoxei32_v)))
void vsoxei32(_Float16 *, vuint32m4_t, vfloat16m2_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vsoxei32_v_m)))
void vsoxei32(vbool8_t, _Float16 *, vuint32m4_t, vfloat16m2_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vsoxei32_v)))
void vsoxei32(_Float16 *, vuint32m8_t, vfloat16m4_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vsoxei32_v_m)))
void vsoxei32(vbool4_t, _Float16 *, vuint32m8_t, vfloat16m4_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vsoxei32_v)))
void vsoxei32(_Float16 *, vuint32m1_t, vfloat16mf2_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vsoxei32_v_m)))
void vsoxei32(vbool32_t, _Float16 *, vuint32m1_t, vfloat16mf2_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vsoxei32_v)))
void vsoxei32(_Float16 *, vuint32mf2_t, vfloat16mf4_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vsoxei32_v_m)))
void vsoxei32(vbool64_t, _Float16 *, vuint32mf2_t, vfloat16mf4_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vle16ff_v_m)))
vfloat16m1_t vle16ff(vbool16_t, vfloat16m1_t, const _Float16 *, size_t *, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vle16ff_v_m)))
vfloat16m2_t vle16ff(vbool8_t, vfloat16m2_t, const _Float16 *, size_t *, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vle16ff_v_m)))
vfloat16m4_t vle16ff(vbool4_t, vfloat16m4_t, const _Float16 *, size_t *, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vle16ff_v_m)))
vfloat16m8_t vle16ff(vbool2_t, vfloat16m8_t, const _Float16 *, size_t *, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vle16ff_v_m)))
vfloat16mf2_t vle16ff(vbool32_t, vfloat16mf2_t, const _Float16 *, size_t *, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vle16ff_v_m)))
vfloat16mf4_t vle16ff(vbool64_t, vfloat16mf4_t, const _Float16 *, size_t *, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vlseg2e16_v_m)))
void vlseg2e16(vfloat16m1_t *, vfloat16m1_t *, vbool16_t, vfloat16m1_t, vfloat16m1_t, const _Float16 *, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vlseg2e16_v_m)))
void vlseg2e16(vfloat16m2_t *, vfloat16m2_t *, vbool8_t, vfloat16m2_t, vfloat16m2_t, const _Float16 *, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vlseg2e16_v_m)))
void vlseg2e16(vfloat16m4_t *, vfloat16m4_t *, vbool4_t, vfloat16m4_t, vfloat16m4_t, const _Float16 *, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vlseg2e16_v_m)))
void vlseg2e16(vfloat16mf2_t *, vfloat16mf2_t *, vbool32_t, vfloat16mf2_t, vfloat16mf2_t, const _Float16 *, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vlseg2e16_v_m)))
void vlseg2e16(vfloat16mf4_t *, vfloat16mf4_t *, vbool64_t, vfloat16mf4_t, vfloat16mf4_t, const _Float16 *, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vlseg3e16_v_m)))
void vlseg3e16(vfloat16m1_t *, vfloat16m1_t *, vfloat16m1_t *, vbool16_t, vfloat16m1_t, vfloat16m1_t, vfloat16m1_t, const _Float16 *, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vlseg3e16_v_m)))
void vlseg3e16(vfloat16m2_t *, vfloat16m2_t *, vfloat16m2_t *, vbool8_t, vfloat16m2_t, vfloat16m2_t, vfloat16m2_t, const _Float16 *, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vlseg3e16_v_m)))
void vlseg3e16(vfloat16mf2_t *, vfloat16mf2_t *, vfloat16mf2_t *, vbool32_t, vfloat16mf2_t, vfloat16mf2_t, vfloat16mf2_t, const _Float16 *, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vlseg3e16_v_m)))
void vlseg3e16(vfloat16mf4_t *, vfloat16mf4_t *, vfloat16mf4_t *, vbool64_t, vfloat16mf4_t, vfloat16mf4_t, vfloat16mf4_t, const _Float16 *, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vlseg4e16_v_m)))
void vlseg4e16(vfloat16m1_t *, vfloat16m1_t *, vfloat16m1_t *, vfloat16m1_t *, vbool16_t, vfloat16m1_t, vfloat16m1_t, vfloat16m1_t, vfloat16m1_t, const _Float16 *, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vlseg4e16_v_m)))
void vlseg4e16(vfloat16m2_t *, vfloat16m2_t *, vfloat16m2_t *, vfloat16m2_t *, vbool8_t, vfloat16m2_t, vfloat16m2_t, vfloat16m2_t, vfloat16m2_t, const _Float16 *, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vlseg4e16_v_m)))
void vlseg4e16(vfloat16mf2_t *, vfloat16mf2_t *, vfloat16mf2_t *, vfloat16mf2_t *, vbool32_t, vfloat16mf2_t, vfloat16mf2_t, vfloat16mf2_t, vfloat16mf2_t, const _Float16 *, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vlseg4e16_v_m)))
void vlseg4e16(vfloat16mf4_t *, vfloat16mf4_t *, vfloat16mf4_t *, vfloat16mf4_t *, vbool64_t, vfloat16mf4_t, vfloat16mf4_t, vfloat16mf4_t, vfloat16mf4_t, const _Float16 *, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vlseg5e16_v_m)))
void vlseg5e16(vfloat16m1_t *, vfloat16m1_t *, vfloat16m1_t *, vfloat16m1_t *, vfloat16m1_t *, vbool16_t, vfloat16m1_t, vfloat16m1_t, vfloat16m1_t, vfloat16m1_t, vfloat16m1_t, const _Float16 *, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vlseg5e16_v_m)))
void vlseg5e16(vfloat16mf2_t *, vfloat16mf2_t *, vfloat16mf2_t *, vfloat16mf2_t *, vfloat16mf2_t *, vbool32_t, vfloat16mf2_t, vfloat16mf2_t, vfloat16mf2_t, vfloat16mf2_t, vfloat16mf2_t, const _Float16 *, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vlseg5e16_v_m)))
void vlseg5e16(vfloat16mf4_t *, vfloat16mf4_t *, vfloat16mf4_t *, vfloat16mf4_t *, vfloat16mf4_t *, vbool64_t, vfloat16mf4_t, vfloat16mf4_t, vfloat16mf4_t, vfloat16mf4_t, vfloat16mf4_t, const _Float16 *, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vlseg6e16_v_m)))
void vlseg6e16(vfloat16m1_t *, vfloat16m1_t *, vfloat16m1_t *, vfloat16m1_t *, vfloat16m1_t *, vfloat16m1_t *, vbool16_t, vfloat16m1_t, vfloat16m1_t, vfloat16m1_t, vfloat16m1_t, vfloat16m1_t, vfloat16m1_t, const _Float16 *, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vlseg6e16_v_m)))
void vlseg6e16(vfloat16mf2_t *, vfloat16mf2_t *, vfloat16mf2_t *, vfloat16mf2_t *, vfloat16mf2_t *, vfloat16mf2_t *, vbool32_t, vfloat16mf2_t, vfloat16mf2_t, vfloat16mf2_t, vfloat16mf2_t, vfloat16mf2_t, vfloat16mf2_t, const _Float16 *, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vlseg6e16_v_m)))
void vlseg6e16(vfloat16mf4_t *, vfloat16mf4_t *, vfloat16mf4_t *, vfloat16mf4_t *, vfloat16mf4_t *, vfloat16mf4_t *, vbool64_t, vfloat16mf4_t, vfloat16mf4_t, vfloat16mf4_t, vfloat16mf4_t, vfloat16mf4_t, vfloat16mf4_t, const _Float16 *, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vlseg7e16_v_m)))
void vlseg7e16(vfloat16m1_t *, vfloat16m1_t *, vfloat16m1_t *, vfloat16m1_t *, vfloat16m1_t *, vfloat16m1_t *, vfloat16m1_t *, vbool16_t, vfloat16m1_t, vfloat16m1_t, vfloat16m1_t, vfloat16m1_t, vfloat16m1_t, vfloat16m1_t, vfloat16m1_t, const _Float16 *, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vlseg7e16_v_m)))
void vlseg7e16(vfloat16mf2_t *, vfloat16mf2_t *, vfloat16mf2_t *, vfloat16mf2_t *, vfloat16mf2_t *, vfloat16mf2_t *, vfloat16mf2_t *, vbool32_t, vfloat16mf2_t, vfloat16mf2_t, vfloat16mf2_t, vfloat16mf2_t, vfloat16mf2_t, vfloat16mf2_t, vfloat16mf2_t, const _Float16 *, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vlseg7e16_v_m)))
void vlseg7e16(vfloat16mf4_t *, vfloat16mf4_t *, vfloat16mf4_t *, vfloat16mf4_t *, vfloat16mf4_t *, vfloat16mf4_t *, vfloat16mf4_t *, vbool64_t, vfloat16mf4_t, vfloat16mf4_t, vfloat16mf4_t, vfloat16mf4_t, vfloat16mf4_t, vfloat16mf4_t, vfloat16mf4_t, const _Float16 *, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vlseg8e16_v_m)))
void vlseg8e16(vfloat16m1_t *, vfloat16m1_t *, vfloat16m1_t *, vfloat16m1_t *, vfloat16m1_t *, vfloat16m1_t *, vfloat16m1_t *, vfloat16m1_t *, vbool16_t, vfloat16m1_t, vfloat16m1_t, vfloat16m1_t, vfloat16m1_t, vfloat16m1_t, vfloat16m1_t, vfloat16m1_t, vfloat16m1_t, const _Float16 *, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vlseg8e16_v_m)))
void vlseg8e16(vfloat16mf2_t *, vfloat16mf2_t *, vfloat16mf2_t *, vfloat16mf2_t *, vfloat16mf2_t *, vfloat16mf2_t *, vfloat16mf2_t *, vfloat16mf2_t *, vbool32_t, vfloat16mf2_t, vfloat16mf2_t, vfloat16mf2_t, vfloat16mf2_t, vfloat16mf2_t, vfloat16mf2_t, vfloat16mf2_t, vfloat16mf2_t, const _Float16 *, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vlseg8e16_v_m)))
void vlseg8e16(vfloat16mf4_t *, vfloat16mf4_t *, vfloat16mf4_t *, vfloat16mf4_t *, vfloat16mf4_t *, vfloat16mf4_t *, vfloat16mf4_t *, vfloat16mf4_t *, vbool64_t, vfloat16mf4_t, vfloat16mf4_t, vfloat16mf4_t, vfloat16mf4_t, vfloat16mf4_t, vfloat16mf4_t, vfloat16mf4_t, vfloat16mf4_t, const _Float16 *, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vlseg2e16ff_v_m)))
void vlseg2e16ff(vfloat16m1_t *, vfloat16m1_t *, vbool16_t, vfloat16m1_t, vfloat16m1_t, const _Float16 *, size_t *, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vlseg2e16ff_v_m)))
void vlseg2e16ff(vfloat16m2_t *, vfloat16m2_t *, vbool8_t, vfloat16m2_t, vfloat16m2_t, const _Float16 *, size_t *, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vlseg2e16ff_v_m)))
void vlseg2e16ff(vfloat16m4_t *, vfloat16m4_t *, vbool4_t, vfloat16m4_t, vfloat16m4_t, const _Float16 *, size_t *, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vlseg2e16ff_v_m)))
void vlseg2e16ff(vfloat16mf2_t *, vfloat16mf2_t *, vbool32_t, vfloat16mf2_t, vfloat16mf2_t, const _Float16 *, size_t *, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vlseg2e16ff_v_m)))
void vlseg2e16ff(vfloat16mf4_t *, vfloat16mf4_t *, vbool64_t, vfloat16mf4_t, vfloat16mf4_t, const _Float16 *, size_t *, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vlseg3e16ff_v_m)))
void vlseg3e16ff(vfloat16m1_t *, vfloat16m1_t *, vfloat16m1_t *, vbool16_t, vfloat16m1_t, vfloat16m1_t, vfloat16m1_t, const _Float16 *, size_t *, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vlseg3e16ff_v_m)))
void vlseg3e16ff(vfloat16m2_t *, vfloat16m2_t *, vfloat16m2_t *, vbool8_t, vfloat16m2_t, vfloat16m2_t, vfloat16m2_t, const _Float16 *, size_t *, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vlseg3e16ff_v_m)))
void vlseg3e16ff(vfloat16mf2_t *, vfloat16mf2_t *, vfloat16mf2_t *, vbool32_t, vfloat16mf2_t, vfloat16mf2_t, vfloat16mf2_t, const _Float16 *, size_t *, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vlseg3e16ff_v_m)))
void vlseg3e16ff(vfloat16mf4_t *, vfloat16mf4_t *, vfloat16mf4_t *, vbool64_t, vfloat16mf4_t, vfloat16mf4_t, vfloat16mf4_t, const _Float16 *, size_t *, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vlseg4e16ff_v_m)))
void vlseg4e16ff(vfloat16m1_t *, vfloat16m1_t *, vfloat16m1_t *, vfloat16m1_t *, vbool16_t, vfloat16m1_t, vfloat16m1_t, vfloat16m1_t, vfloat16m1_t, const _Float16 *, size_t *, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vlseg4e16ff_v_m)))
void vlseg4e16ff(vfloat16m2_t *, vfloat16m2_t *, vfloat16m2_t *, vfloat16m2_t *, vbool8_t, vfloat16m2_t, vfloat16m2_t, vfloat16m2_t, vfloat16m2_t, const _Float16 *, size_t *, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vlseg4e16ff_v_m)))
void vlseg4e16ff(vfloat16mf2_t *, vfloat16mf2_t *, vfloat16mf2_t *, vfloat16mf2_t *, vbool32_t, vfloat16mf2_t, vfloat16mf2_t, vfloat16mf2_t, vfloat16mf2_t, const _Float16 *, size_t *, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vlseg4e16ff_v_m)))
void vlseg4e16ff(vfloat16mf4_t *, vfloat16mf4_t *, vfloat16mf4_t *, vfloat16mf4_t *, vbool64_t, vfloat16mf4_t, vfloat16mf4_t, vfloat16mf4_t, vfloat16mf4_t, const _Float16 *, size_t *, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vlseg5e16ff_v_m)))
void vlseg5e16ff(vfloat16m1_t *, vfloat16m1_t *, vfloat16m1_t *, vfloat16m1_t *, vfloat16m1_t *, vbool16_t, vfloat16m1_t, vfloat16m1_t, vfloat16m1_t, vfloat16m1_t, vfloat16m1_t, const _Float16 *, size_t *, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vlseg5e16ff_v_m)))
void vlseg5e16ff(vfloat16mf2_t *, vfloat16mf2_t *, vfloat16mf2_t *, vfloat16mf2_t *, vfloat16mf2_t *, vbool32_t, vfloat16mf2_t, vfloat16mf2_t, vfloat16mf2_t, vfloat16mf2_t, vfloat16mf2_t, const _Float16 *, size_t *, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vlseg5e16ff_v_m)))
void vlseg5e16ff(vfloat16mf4_t *, vfloat16mf4_t *, vfloat16mf4_t *, vfloat16mf4_t *, vfloat16mf4_t *, vbool64_t, vfloat16mf4_t, vfloat16mf4_t, vfloat16mf4_t, vfloat16mf4_t, vfloat16mf4_t, const _Float16 *, size_t *, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vlseg6e16ff_v_m)))
void vlseg6e16ff(vfloat16m1_t *, vfloat16m1_t *, vfloat16m1_t *, vfloat16m1_t *, vfloat16m1_t *, vfloat16m1_t *, vbool16_t, vfloat16m1_t, vfloat16m1_t, vfloat16m1_t, vfloat16m1_t, vfloat16m1_t, vfloat16m1_t, const _Float16 *, size_t *, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vlseg6e16ff_v_m)))
void vlseg6e16ff(vfloat16mf2_t *, vfloat16mf2_t *, vfloat16mf2_t *, vfloat16mf2_t *, vfloat16mf2_t *, vfloat16mf2_t *, vbool32_t, vfloat16mf2_t, vfloat16mf2_t, vfloat16mf2_t, vfloat16mf2_t, vfloat16mf2_t, vfloat16mf2_t, const _Float16 *, size_t *, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vlseg6e16ff_v_m)))
void vlseg6e16ff(vfloat16mf4_t *, vfloat16mf4_t *, vfloat16mf4_t *, vfloat16mf4_t *, vfloat16mf4_t *, vfloat16mf4_t *, vbool64_t, vfloat16mf4_t, vfloat16mf4_t, vfloat16mf4_t, vfloat16mf4_t, vfloat16mf4_t, vfloat16mf4_t, const _Float16 *, size_t *, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vlseg7e16ff_v_m)))
void vlseg7e16ff(vfloat16m1_t *, vfloat16m1_t *, vfloat16m1_t *, vfloat16m1_t *, vfloat16m1_t *, vfloat16m1_t *, vfloat16m1_t *, vbool16_t, vfloat16m1_t, vfloat16m1_t, vfloat16m1_t, vfloat16m1_t, vfloat16m1_t, vfloat16m1_t, vfloat16m1_t, const _Float16 *, size_t *, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vlseg7e16ff_v_m)))
void vlseg7e16ff(vfloat16mf2_t *, vfloat16mf2_t *, vfloat16mf2_t *, vfloat16mf2_t *, vfloat16mf2_t *, vfloat16mf2_t *, vfloat16mf2_t *, vbool32_t, vfloat16mf2_t, vfloat16mf2_t, vfloat16mf2_t, vfloat16mf2_t, vfloat16mf2_t, vfloat16mf2_t, vfloat16mf2_t, const _Float16 *, size_t *, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vlseg7e16ff_v_m)))
void vlseg7e16ff(vfloat16mf4_t *, vfloat16mf4_t *, vfloat16mf4_t *, vfloat16mf4_t *, vfloat16mf4_t *, vfloat16mf4_t *, vfloat16mf4_t *, vbool64_t, vfloat16mf4_t, vfloat16mf4_t, vfloat16mf4_t, vfloat16mf4_t, vfloat16mf4_t, vfloat16mf4_t, vfloat16mf4_t, const _Float16 *, size_t *, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vlseg8e16ff_v_m)))
void vlseg8e16ff(vfloat16m1_t *, vfloat16m1_t *, vfloat16m1_t *, vfloat16m1_t *, vfloat16m1_t *, vfloat16m1_t *, vfloat16m1_t *, vfloat16m1_t *, vbool16_t, vfloat16m1_t, vfloat16m1_t, vfloat16m1_t, vfloat16m1_t, vfloat16m1_t, vfloat16m1_t, vfloat16m1_t, vfloat16m1_t, const _Float16 *, size_t *, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vlseg8e16ff_v_m)))
void vlseg8e16ff(vfloat16mf2_t *, vfloat16mf2_t *, vfloat16mf2_t *, vfloat16mf2_t *, vfloat16mf2_t *, vfloat16mf2_t *, vfloat16mf2_t *, vfloat16mf2_t *, vbool32_t, vfloat16mf2_t, vfloat16mf2_t, vfloat16mf2_t, vfloat16mf2_t, vfloat16mf2_t, vfloat16mf2_t, vfloat16mf2_t, vfloat16mf2_t, const _Float16 *, size_t *, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vlseg8e16ff_v_m)))
void vlseg8e16ff(vfloat16mf4_t *, vfloat16mf4_t *, vfloat16mf4_t *, vfloat16mf4_t *, vfloat16mf4_t *, vfloat16mf4_t *, vfloat16mf4_t *, vfloat16mf4_t *, vbool64_t, vfloat16mf4_t, vfloat16mf4_t, vfloat16mf4_t, vfloat16mf4_t, vfloat16mf4_t, vfloat16mf4_t, vfloat16mf4_t, vfloat16mf4_t, const _Float16 *, size_t *, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vlsseg2e16_v_m)))
void vlsseg2e16(vfloat16m1_t *, vfloat16m1_t *, vbool16_t, vfloat16m1_t, vfloat16m1_t, const _Float16 *, ptrdiff_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vlsseg2e16_v_m)))
void vlsseg2e16(vfloat16m2_t *, vfloat16m2_t *, vbool8_t, vfloat16m2_t, vfloat16m2_t, const _Float16 *, ptrdiff_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vlsseg2e16_v_m)))
void vlsseg2e16(vfloat16m4_t *, vfloat16m4_t *, vbool4_t, vfloat16m4_t, vfloat16m4_t, const _Float16 *, ptrdiff_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vlsseg2e16_v_m)))
void vlsseg2e16(vfloat16mf2_t *, vfloat16mf2_t *, vbool32_t, vfloat16mf2_t, vfloat16mf2_t, const _Float16 *, ptrdiff_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vlsseg2e16_v_m)))
void vlsseg2e16(vfloat16mf4_t *, vfloat16mf4_t *, vbool64_t, vfloat16mf4_t, vfloat16mf4_t, const _Float16 *, ptrdiff_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vlsseg3e16_v_m)))
void vlsseg3e16(vfloat16m1_t *, vfloat16m1_t *, vfloat16m1_t *, vbool16_t, vfloat16m1_t, vfloat16m1_t, vfloat16m1_t, const _Float16 *, ptrdiff_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vlsseg3e16_v_m)))
void vlsseg3e16(vfloat16m2_t *, vfloat16m2_t *, vfloat16m2_t *, vbool8_t, vfloat16m2_t, vfloat16m2_t, vfloat16m2_t, const _Float16 *, ptrdiff_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vlsseg3e16_v_m)))
void vlsseg3e16(vfloat16mf2_t *, vfloat16mf2_t *, vfloat16mf2_t *, vbool32_t, vfloat16mf2_t, vfloat16mf2_t, vfloat16mf2_t, const _Float16 *, ptrdiff_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vlsseg3e16_v_m)))
void vlsseg3e16(vfloat16mf4_t *, vfloat16mf4_t *, vfloat16mf4_t *, vbool64_t, vfloat16mf4_t, vfloat16mf4_t, vfloat16mf4_t, const _Float16 *, ptrdiff_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vlsseg4e16_v_m)))
void vlsseg4e16(vfloat16m1_t *, vfloat16m1_t *, vfloat16m1_t *, vfloat16m1_t *, vbool16_t, vfloat16m1_t, vfloat16m1_t, vfloat16m1_t, vfloat16m1_t, const _Float16 *, ptrdiff_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vlsseg4e16_v_m)))
void vlsseg4e16(vfloat16m2_t *, vfloat16m2_t *, vfloat16m2_t *, vfloat16m2_t *, vbool8_t, vfloat16m2_t, vfloat16m2_t, vfloat16m2_t, vfloat16m2_t, const _Float16 *, ptrdiff_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vlsseg4e16_v_m)))
void vlsseg4e16(vfloat16mf2_t *, vfloat16mf2_t *, vfloat16mf2_t *, vfloat16mf2_t *, vbool32_t, vfloat16mf2_t, vfloat16mf2_t, vfloat16mf2_t, vfloat16mf2_t, const _Float16 *, ptrdiff_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vlsseg4e16_v_m)))
void vlsseg4e16(vfloat16mf4_t *, vfloat16mf4_t *, vfloat16mf4_t *, vfloat16mf4_t *, vbool64_t, vfloat16mf4_t, vfloat16mf4_t, vfloat16mf4_t, vfloat16mf4_t, const _Float16 *, ptrdiff_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vlsseg5e16_v_m)))
void vlsseg5e16(vfloat16m1_t *, vfloat16m1_t *, vfloat16m1_t *, vfloat16m1_t *, vfloat16m1_t *, vbool16_t, vfloat16m1_t, vfloat16m1_t, vfloat16m1_t, vfloat16m1_t, vfloat16m1_t, const _Float16 *, ptrdiff_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vlsseg5e16_v_m)))
void vlsseg5e16(vfloat16mf2_t *, vfloat16mf2_t *, vfloat16mf2_t *, vfloat16mf2_t *, vfloat16mf2_t *, vbool32_t, vfloat16mf2_t, vfloat16mf2_t, vfloat16mf2_t, vfloat16mf2_t, vfloat16mf2_t, const _Float16 *, ptrdiff_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vlsseg5e16_v_m)))
void vlsseg5e16(vfloat16mf4_t *, vfloat16mf4_t *, vfloat16mf4_t *, vfloat16mf4_t *, vfloat16mf4_t *, vbool64_t, vfloat16mf4_t, vfloat16mf4_t, vfloat16mf4_t, vfloat16mf4_t, vfloat16mf4_t, const _Float16 *, ptrdiff_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vlsseg6e16_v_m)))
void vlsseg6e16(vfloat16m1_t *, vfloat16m1_t *, vfloat16m1_t *, vfloat16m1_t *, vfloat16m1_t *, vfloat16m1_t *, vbool16_t, vfloat16m1_t, vfloat16m1_t, vfloat16m1_t, vfloat16m1_t, vfloat16m1_t, vfloat16m1_t, const _Float16 *, ptrdiff_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vlsseg6e16_v_m)))
void vlsseg6e16(vfloat16mf2_t *, vfloat16mf2_t *, vfloat16mf2_t *, vfloat16mf2_t *, vfloat16mf2_t *, vfloat16mf2_t *, vbool32_t, vfloat16mf2_t, vfloat16mf2_t, vfloat16mf2_t, vfloat16mf2_t, vfloat16mf2_t, vfloat16mf2_t, const _Float16 *, ptrdiff_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vlsseg6e16_v_m)))
void vlsseg6e16(vfloat16mf4_t *, vfloat16mf4_t *, vfloat16mf4_t *, vfloat16mf4_t *, vfloat16mf4_t *, vfloat16mf4_t *, vbool64_t, vfloat16mf4_t, vfloat16mf4_t, vfloat16mf4_t, vfloat16mf4_t, vfloat16mf4_t, vfloat16mf4_t, const _Float16 *, ptrdiff_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vlsseg7e16_v_m)))
void vlsseg7e16(vfloat16m1_t *, vfloat16m1_t *, vfloat16m1_t *, vfloat16m1_t *, vfloat16m1_t *, vfloat16m1_t *, vfloat16m1_t *, vbool16_t, vfloat16m1_t, vfloat16m1_t, vfloat16m1_t, vfloat16m1_t, vfloat16m1_t, vfloat16m1_t, vfloat16m1_t, const _Float16 *, ptrdiff_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vlsseg7e16_v_m)))
void vlsseg7e16(vfloat16mf2_t *, vfloat16mf2_t *, vfloat16mf2_t *, vfloat16mf2_t *, vfloat16mf2_t *, vfloat16mf2_t *, vfloat16mf2_t *, vbool32_t, vfloat16mf2_t, vfloat16mf2_t, vfloat16mf2_t, vfloat16mf2_t, vfloat16mf2_t, vfloat16mf2_t, vfloat16mf2_t, const _Float16 *, ptrdiff_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vlsseg7e16_v_m)))
void vlsseg7e16(vfloat16mf4_t *, vfloat16mf4_t *, vfloat16mf4_t *, vfloat16mf4_t *, vfloat16mf4_t *, vfloat16mf4_t *, vfloat16mf4_t *, vbool64_t, vfloat16mf4_t, vfloat16mf4_t, vfloat16mf4_t, vfloat16mf4_t, vfloat16mf4_t, vfloat16mf4_t, vfloat16mf4_t, const _Float16 *, ptrdiff_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vlsseg8e16_v_m)))
void vlsseg8e16(vfloat16m1_t *, vfloat16m1_t *, vfloat16m1_t *, vfloat16m1_t *, vfloat16m1_t *, vfloat16m1_t *, vfloat16m1_t *, vfloat16m1_t *, vbool16_t, vfloat16m1_t, vfloat16m1_t, vfloat16m1_t, vfloat16m1_t, vfloat16m1_t, vfloat16m1_t, vfloat16m1_t, vfloat16m1_t, const _Float16 *, ptrdiff_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vlsseg8e16_v_m)))
void vlsseg8e16(vfloat16mf2_t *, vfloat16mf2_t *, vfloat16mf2_t *, vfloat16mf2_t *, vfloat16mf2_t *, vfloat16mf2_t *, vfloat16mf2_t *, vfloat16mf2_t *, vbool32_t, vfloat16mf2_t, vfloat16mf2_t, vfloat16mf2_t, vfloat16mf2_t, vfloat16mf2_t, vfloat16mf2_t, vfloat16mf2_t, vfloat16mf2_t, const _Float16 *, ptrdiff_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vlsseg8e16_v_m)))
void vlsseg8e16(vfloat16mf4_t *, vfloat16mf4_t *, vfloat16mf4_t *, vfloat16mf4_t *, vfloat16mf4_t *, vfloat16mf4_t *, vfloat16mf4_t *, vfloat16mf4_t *, vbool64_t, vfloat16mf4_t, vfloat16mf4_t, vfloat16mf4_t, vfloat16mf4_t, vfloat16mf4_t, vfloat16mf4_t, vfloat16mf4_t, vfloat16mf4_t, const _Float16 *, ptrdiff_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vfneg_v)))
vfloat16m1_t vfneg(vfloat16m1_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vfneg_v_m)))
vfloat16m1_t vfneg(vbool16_t, vfloat16m1_t, vfloat16m1_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vfneg_v)))
vfloat16m2_t vfneg(vfloat16m2_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vfneg_v_m)))
vfloat16m2_t vfneg(vbool8_t, vfloat16m2_t, vfloat16m2_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vfneg_v)))
vfloat16m4_t vfneg(vfloat16m4_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vfneg_v_m)))
vfloat16m4_t vfneg(vbool4_t, vfloat16m4_t, vfloat16m4_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vfneg_v)))
vfloat16m8_t vfneg(vfloat16m8_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vfneg_v_m)))
vfloat16m8_t vfneg(vbool2_t, vfloat16m8_t, vfloat16m8_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vfneg_v)))
vfloat16mf2_t vfneg(vfloat16mf2_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vfneg_v_m)))
vfloat16mf2_t vfneg(vbool32_t, vfloat16mf2_t, vfloat16mf2_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vfneg_v)))
vfloat16mf4_t vfneg(vfloat16mf4_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vfneg_v_m)))
vfloat16mf4_t vfneg(vbool64_t, vfloat16mf4_t, vfloat16mf4_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vluxseg2ei8_v)))
void vluxseg2ei8(vfloat16m1_t *, vfloat16m1_t *, const _Float16 *, vuint8mf2_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vluxseg2ei8_v_m)))
void vluxseg2ei8(vfloat16m1_t *, vfloat16m1_t *, vbool16_t, vfloat16m1_t, vfloat16m1_t, const _Float16 *, vuint8mf2_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vluxseg2ei8_v)))
void vluxseg2ei8(vfloat16m2_t *, vfloat16m2_t *, const _Float16 *, vuint8m1_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vluxseg2ei8_v_m)))
void vluxseg2ei8(vfloat16m2_t *, vfloat16m2_t *, vbool8_t, vfloat16m2_t, vfloat16m2_t, const _Float16 *, vuint8m1_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vluxseg2ei8_v)))
void vluxseg2ei8(vfloat16m4_t *, vfloat16m4_t *, const _Float16 *, vuint8m2_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vluxseg2ei8_v_m)))
void vluxseg2ei8(vfloat16m4_t *, vfloat16m4_t *, vbool4_t, vfloat16m4_t, vfloat16m4_t, const _Float16 *, vuint8m2_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vluxseg2ei8_v)))
void vluxseg2ei8(vfloat16mf2_t *, vfloat16mf2_t *, const _Float16 *, vuint8mf4_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vluxseg2ei8_v_m)))
void vluxseg2ei8(vfloat16mf2_t *, vfloat16mf2_t *, vbool32_t, vfloat16mf2_t, vfloat16mf2_t, const _Float16 *, vuint8mf4_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vluxseg2ei8_v)))
void vluxseg2ei8(vfloat16mf4_t *, vfloat16mf4_t *, const _Float16 *, vuint8mf8_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vluxseg2ei8_v_m)))
void vluxseg2ei8(vfloat16mf4_t *, vfloat16mf4_t *, vbool64_t, vfloat16mf4_t, vfloat16mf4_t, const _Float16 *, vuint8mf8_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vluxseg3ei8_v)))
void vluxseg3ei8(vfloat16m1_t *, vfloat16m1_t *, vfloat16m1_t *, const _Float16 *, vuint8mf2_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vluxseg3ei8_v_m)))
void vluxseg3ei8(vfloat16m1_t *, vfloat16m1_t *, vfloat16m1_t *, vbool16_t, vfloat16m1_t, vfloat16m1_t, vfloat16m1_t, const _Float16 *, vuint8mf2_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vluxseg3ei8_v)))
void vluxseg3ei8(vfloat16m2_t *, vfloat16m2_t *, vfloat16m2_t *, const _Float16 *, vuint8m1_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vluxseg3ei8_v_m)))
void vluxseg3ei8(vfloat16m2_t *, vfloat16m2_t *, vfloat16m2_t *, vbool8_t, vfloat16m2_t, vfloat16m2_t, vfloat16m2_t, const _Float16 *, vuint8m1_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vluxseg3ei8_v)))
void vluxseg3ei8(vfloat16mf2_t *, vfloat16mf2_t *, vfloat16mf2_t *, const _Float16 *, vuint8mf4_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vluxseg3ei8_v_m)))
void vluxseg3ei8(vfloat16mf2_t *, vfloat16mf2_t *, vfloat16mf2_t *, vbool32_t, vfloat16mf2_t, vfloat16mf2_t, vfloat16mf2_t, const _Float16 *, vuint8mf4_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vluxseg3ei8_v)))
void vluxseg3ei8(vfloat16mf4_t *, vfloat16mf4_t *, vfloat16mf4_t *, const _Float16 *, vuint8mf8_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vluxseg3ei8_v_m)))
void vluxseg3ei8(vfloat16mf4_t *, vfloat16mf4_t *, vfloat16mf4_t *, vbool64_t, vfloat16mf4_t, vfloat16mf4_t, vfloat16mf4_t, const _Float16 *, vuint8mf8_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vluxseg4ei8_v)))
void vluxseg4ei8(vfloat16m1_t *, vfloat16m1_t *, vfloat16m1_t *, vfloat16m1_t *, const _Float16 *, vuint8mf2_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vluxseg4ei8_v_m)))
void vluxseg4ei8(vfloat16m1_t *, vfloat16m1_t *, vfloat16m1_t *, vfloat16m1_t *, vbool16_t, vfloat16m1_t, vfloat16m1_t, vfloat16m1_t, vfloat16m1_t, const _Float16 *, vuint8mf2_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vluxseg4ei8_v)))
void vluxseg4ei8(vfloat16m2_t *, vfloat16m2_t *, vfloat16m2_t *, vfloat16m2_t *, const _Float16 *, vuint8m1_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vluxseg4ei8_v_m)))
void vluxseg4ei8(vfloat16m2_t *, vfloat16m2_t *, vfloat16m2_t *, vfloat16m2_t *, vbool8_t, vfloat16m2_t, vfloat16m2_t, vfloat16m2_t, vfloat16m2_t, const _Float16 *, vuint8m1_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vluxseg4ei8_v)))
void vluxseg4ei8(vfloat16mf2_t *, vfloat16mf2_t *, vfloat16mf2_t *, vfloat16mf2_t *, const _Float16 *, vuint8mf4_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vluxseg4ei8_v_m)))
void vluxseg4ei8(vfloat16mf2_t *, vfloat16mf2_t *, vfloat16mf2_t *, vfloat16mf2_t *, vbool32_t, vfloat16mf2_t, vfloat16mf2_t, vfloat16mf2_t, vfloat16mf2_t, const _Float16 *, vuint8mf4_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vluxseg4ei8_v)))
void vluxseg4ei8(vfloat16mf4_t *, vfloat16mf4_t *, vfloat16mf4_t *, vfloat16mf4_t *, const _Float16 *, vuint8mf8_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vluxseg4ei8_v_m)))
void vluxseg4ei8(vfloat16mf4_t *, vfloat16mf4_t *, vfloat16mf4_t *, vfloat16mf4_t *, vbool64_t, vfloat16mf4_t, vfloat16mf4_t, vfloat16mf4_t, vfloat16mf4_t, const _Float16 *, vuint8mf8_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vluxseg5ei8_v)))
void vluxseg5ei8(vfloat16m1_t *, vfloat16m1_t *, vfloat16m1_t *, vfloat16m1_t *, vfloat16m1_t *, const _Float16 *, vuint8mf2_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vluxseg5ei8_v_m)))
void vluxseg5ei8(vfloat16m1_t *, vfloat16m1_t *, vfloat16m1_t *, vfloat16m1_t *, vfloat16m1_t *, vbool16_t, vfloat16m1_t, vfloat16m1_t, vfloat16m1_t, vfloat16m1_t, vfloat16m1_t, const _Float16 *, vuint8mf2_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vluxseg5ei8_v)))
void vluxseg5ei8(vfloat16mf2_t *, vfloat16mf2_t *, vfloat16mf2_t *, vfloat16mf2_t *, vfloat16mf2_t *, const _Float16 *, vuint8mf4_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vluxseg5ei8_v_m)))
void vluxseg5ei8(vfloat16mf2_t *, vfloat16mf2_t *, vfloat16mf2_t *, vfloat16mf2_t *, vfloat16mf2_t *, vbool32_t, vfloat16mf2_t, vfloat16mf2_t, vfloat16mf2_t, vfloat16mf2_t, vfloat16mf2_t, const _Float16 *, vuint8mf4_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vluxseg5ei8_v)))
void vluxseg5ei8(vfloat16mf4_t *, vfloat16mf4_t *, vfloat16mf4_t *, vfloat16mf4_t *, vfloat16mf4_t *, const _Float16 *, vuint8mf8_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vluxseg5ei8_v_m)))
void vluxseg5ei8(vfloat16mf4_t *, vfloat16mf4_t *, vfloat16mf4_t *, vfloat16mf4_t *, vfloat16mf4_t *, vbool64_t, vfloat16mf4_t, vfloat16mf4_t, vfloat16mf4_t, vfloat16mf4_t, vfloat16mf4_t, const _Float16 *, vuint8mf8_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vluxseg6ei8_v)))
void vluxseg6ei8(vfloat16m1_t *, vfloat16m1_t *, vfloat16m1_t *, vfloat16m1_t *, vfloat16m1_t *, vfloat16m1_t *, const _Float16 *, vuint8mf2_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vluxseg6ei8_v_m)))
void vluxseg6ei8(vfloat16m1_t *, vfloat16m1_t *, vfloat16m1_t *, vfloat16m1_t *, vfloat16m1_t *, vfloat16m1_t *, vbool16_t, vfloat16m1_t, vfloat16m1_t, vfloat16m1_t, vfloat16m1_t, vfloat16m1_t, vfloat16m1_t, const _Float16 *, vuint8mf2_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vluxseg6ei8_v)))
void vluxseg6ei8(vfloat16mf2_t *, vfloat16mf2_t *, vfloat16mf2_t *, vfloat16mf2_t *, vfloat16mf2_t *, vfloat16mf2_t *, const _Float16 *, vuint8mf4_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vluxseg6ei8_v_m)))
void vluxseg6ei8(vfloat16mf2_t *, vfloat16mf2_t *, vfloat16mf2_t *, vfloat16mf2_t *, vfloat16mf2_t *, vfloat16mf2_t *, vbool32_t, vfloat16mf2_t, vfloat16mf2_t, vfloat16mf2_t, vfloat16mf2_t, vfloat16mf2_t, vfloat16mf2_t, const _Float16 *, vuint8mf4_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vluxseg6ei8_v)))
void vluxseg6ei8(vfloat16mf4_t *, vfloat16mf4_t *, vfloat16mf4_t *, vfloat16mf4_t *, vfloat16mf4_t *, vfloat16mf4_t *, const _Float16 *, vuint8mf8_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vluxseg6ei8_v_m)))
void vluxseg6ei8(vfloat16mf4_t *, vfloat16mf4_t *, vfloat16mf4_t *, vfloat16mf4_t *, vfloat16mf4_t *, vfloat16mf4_t *, vbool64_t, vfloat16mf4_t, vfloat16mf4_t, vfloat16mf4_t, vfloat16mf4_t, vfloat16mf4_t, vfloat16mf4_t, const _Float16 *, vuint8mf8_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vluxseg7ei8_v)))
void vluxseg7ei8(vfloat16m1_t *, vfloat16m1_t *, vfloat16m1_t *, vfloat16m1_t *, vfloat16m1_t *, vfloat16m1_t *, vfloat16m1_t *, const _Float16 *, vuint8mf2_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vluxseg7ei8_v_m)))
void vluxseg7ei8(vfloat16m1_t *, vfloat16m1_t *, vfloat16m1_t *, vfloat16m1_t *, vfloat16m1_t *, vfloat16m1_t *, vfloat16m1_t *, vbool16_t, vfloat16m1_t, vfloat16m1_t, vfloat16m1_t, vfloat16m1_t, vfloat16m1_t, vfloat16m1_t, vfloat16m1_t, const _Float16 *, vuint8mf2_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vluxseg7ei8_v)))
void vluxseg7ei8(vfloat16mf2_t *, vfloat16mf2_t *, vfloat16mf2_t *, vfloat16mf2_t *, vfloat16mf2_t *, vfloat16mf2_t *, vfloat16mf2_t *, const _Float16 *, vuint8mf4_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vluxseg7ei8_v_m)))
void vluxseg7ei8(vfloat16mf2_t *, vfloat16mf2_t *, vfloat16mf2_t *, vfloat16mf2_t *, vfloat16mf2_t *, vfloat16mf2_t *, vfloat16mf2_t *, vbool32_t, vfloat16mf2_t, vfloat16mf2_t, vfloat16mf2_t, vfloat16mf2_t, vfloat16mf2_t, vfloat16mf2_t, vfloat16mf2_t, const _Float16 *, vuint8mf4_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vluxseg7ei8_v)))
void vluxseg7ei8(vfloat16mf4_t *, vfloat16mf4_t *, vfloat16mf4_t *, vfloat16mf4_t *, vfloat16mf4_t *, vfloat16mf4_t *, vfloat16mf4_t *, const _Float16 *, vuint8mf8_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vluxseg7ei8_v_m)))
void vluxseg7ei8(vfloat16mf4_t *, vfloat16mf4_t *, vfloat16mf4_t *, vfloat16mf4_t *, vfloat16mf4_t *, vfloat16mf4_t *, vfloat16mf4_t *, vbool64_t, vfloat16mf4_t, vfloat16mf4_t, vfloat16mf4_t, vfloat16mf4_t, vfloat16mf4_t, vfloat16mf4_t, vfloat16mf4_t, const _Float16 *, vuint8mf8_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vluxseg8ei8_v)))
void vluxseg8ei8(vfloat16m1_t *, vfloat16m1_t *, vfloat16m1_t *, vfloat16m1_t *, vfloat16m1_t *, vfloat16m1_t *, vfloat16m1_t *, vfloat16m1_t *, const _Float16 *, vuint8mf2_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vluxseg8ei8_v_m)))
void vluxseg8ei8(vfloat16m1_t *, vfloat16m1_t *, vfloat16m1_t *, vfloat16m1_t *, vfloat16m1_t *, vfloat16m1_t *, vfloat16m1_t *, vfloat16m1_t *, vbool16_t, vfloat16m1_t, vfloat16m1_t, vfloat16m1_t, vfloat16m1_t, vfloat16m1_t, vfloat16m1_t, vfloat16m1_t, vfloat16m1_t, const _Float16 *, vuint8mf2_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vluxseg8ei8_v)))
void vluxseg8ei8(vfloat16mf2_t *, vfloat16mf2_t *, vfloat16mf2_t *, vfloat16mf2_t *, vfloat16mf2_t *, vfloat16mf2_t *, vfloat16mf2_t *, vfloat16mf2_t *, const _Float16 *, vuint8mf4_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vluxseg8ei8_v_m)))
void vluxseg8ei8(vfloat16mf2_t *, vfloat16mf2_t *, vfloat16mf2_t *, vfloat16mf2_t *, vfloat16mf2_t *, vfloat16mf2_t *, vfloat16mf2_t *, vfloat16mf2_t *, vbool32_t, vfloat16mf2_t, vfloat16mf2_t, vfloat16mf2_t, vfloat16mf2_t, vfloat16mf2_t, vfloat16mf2_t, vfloat16mf2_t, vfloat16mf2_t, const _Float16 *, vuint8mf4_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vluxseg8ei8_v)))
void vluxseg8ei8(vfloat16mf4_t *, vfloat16mf4_t *, vfloat16mf4_t *, vfloat16mf4_t *, vfloat16mf4_t *, vfloat16mf4_t *, vfloat16mf4_t *, vfloat16mf4_t *, const _Float16 *, vuint8mf8_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vluxseg8ei8_v_m)))
void vluxseg8ei8(vfloat16mf4_t *, vfloat16mf4_t *, vfloat16mf4_t *, vfloat16mf4_t *, vfloat16mf4_t *, vfloat16mf4_t *, vfloat16mf4_t *, vfloat16mf4_t *, vbool64_t, vfloat16mf4_t, vfloat16mf4_t, vfloat16mf4_t, vfloat16mf4_t, vfloat16mf4_t, vfloat16mf4_t, vfloat16mf4_t, vfloat16mf4_t, const _Float16 *, vuint8mf8_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vluxseg2ei16_v)))
void vluxseg2ei16(vfloat16m1_t *, vfloat16m1_t *, const _Float16 *, vuint16m1_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vluxseg2ei16_v_m)))
void vluxseg2ei16(vfloat16m1_t *, vfloat16m1_t *, vbool16_t, vfloat16m1_t, vfloat16m1_t, const _Float16 *, vuint16m1_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vluxseg2ei16_v)))
void vluxseg2ei16(vfloat16m2_t *, vfloat16m2_t *, const _Float16 *, vuint16m2_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vluxseg2ei16_v_m)))
void vluxseg2ei16(vfloat16m2_t *, vfloat16m2_t *, vbool8_t, vfloat16m2_t, vfloat16m2_t, const _Float16 *, vuint16m2_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vluxseg2ei16_v)))
void vluxseg2ei16(vfloat16m4_t *, vfloat16m4_t *, const _Float16 *, vuint16m4_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vluxseg2ei16_v_m)))
void vluxseg2ei16(vfloat16m4_t *, vfloat16m4_t *, vbool4_t, vfloat16m4_t, vfloat16m4_t, const _Float16 *, vuint16m4_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vluxseg2ei16_v)))
void vluxseg2ei16(vfloat16mf2_t *, vfloat16mf2_t *, const _Float16 *, vuint16mf2_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vluxseg2ei16_v_m)))
void vluxseg2ei16(vfloat16mf2_t *, vfloat16mf2_t *, vbool32_t, vfloat16mf2_t, vfloat16mf2_t, const _Float16 *, vuint16mf2_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vluxseg2ei16_v)))
void vluxseg2ei16(vfloat16mf4_t *, vfloat16mf4_t *, const _Float16 *, vuint16mf4_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vluxseg2ei16_v_m)))
void vluxseg2ei16(vfloat16mf4_t *, vfloat16mf4_t *, vbool64_t, vfloat16mf4_t, vfloat16mf4_t, const _Float16 *, vuint16mf4_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vluxseg3ei16_v)))
void vluxseg3ei16(vfloat16m1_t *, vfloat16m1_t *, vfloat16m1_t *, const _Float16 *, vuint16m1_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vluxseg3ei16_v_m)))
void vluxseg3ei16(vfloat16m1_t *, vfloat16m1_t *, vfloat16m1_t *, vbool16_t, vfloat16m1_t, vfloat16m1_t, vfloat16m1_t, const _Float16 *, vuint16m1_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vluxseg3ei16_v)))
void vluxseg3ei16(vfloat16m2_t *, vfloat16m2_t *, vfloat16m2_t *, const _Float16 *, vuint16m2_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vluxseg3ei16_v_m)))
void vluxseg3ei16(vfloat16m2_t *, vfloat16m2_t *, vfloat16m2_t *, vbool8_t, vfloat16m2_t, vfloat16m2_t, vfloat16m2_t, const _Float16 *, vuint16m2_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vluxseg3ei16_v)))
void vluxseg3ei16(vfloat16mf2_t *, vfloat16mf2_t *, vfloat16mf2_t *, const _Float16 *, vuint16mf2_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vluxseg3ei16_v_m)))
void vluxseg3ei16(vfloat16mf2_t *, vfloat16mf2_t *, vfloat16mf2_t *, vbool32_t, vfloat16mf2_t, vfloat16mf2_t, vfloat16mf2_t, const _Float16 *, vuint16mf2_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vluxseg3ei16_v)))
void vluxseg3ei16(vfloat16mf4_t *, vfloat16mf4_t *, vfloat16mf4_t *, const _Float16 *, vuint16mf4_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vluxseg3ei16_v_m)))
void vluxseg3ei16(vfloat16mf4_t *, vfloat16mf4_t *, vfloat16mf4_t *, vbool64_t, vfloat16mf4_t, vfloat16mf4_t, vfloat16mf4_t, const _Float16 *, vuint16mf4_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vluxseg4ei16_v)))
void vluxseg4ei16(vfloat16m1_t *, vfloat16m1_t *, vfloat16m1_t *, vfloat16m1_t *, const _Float16 *, vuint16m1_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vluxseg4ei16_v_m)))
void vluxseg4ei16(vfloat16m1_t *, vfloat16m1_t *, vfloat16m1_t *, vfloat16m1_t *, vbool16_t, vfloat16m1_t, vfloat16m1_t, vfloat16m1_t, vfloat16m1_t, const _Float16 *, vuint16m1_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vluxseg4ei16_v)))
void vluxseg4ei16(vfloat16m2_t *, vfloat16m2_t *, vfloat16m2_t *, vfloat16m2_t *, const _Float16 *, vuint16m2_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vluxseg4ei16_v_m)))
void vluxseg4ei16(vfloat16m2_t *, vfloat16m2_t *, vfloat16m2_t *, vfloat16m2_t *, vbool8_t, vfloat16m2_t, vfloat16m2_t, vfloat16m2_t, vfloat16m2_t, const _Float16 *, vuint16m2_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vluxseg4ei16_v)))
void vluxseg4ei16(vfloat16mf2_t *, vfloat16mf2_t *, vfloat16mf2_t *, vfloat16mf2_t *, const _Float16 *, vuint16mf2_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vluxseg4ei16_v_m)))
void vluxseg4ei16(vfloat16mf2_t *, vfloat16mf2_t *, vfloat16mf2_t *, vfloat16mf2_t *, vbool32_t, vfloat16mf2_t, vfloat16mf2_t, vfloat16mf2_t, vfloat16mf2_t, const _Float16 *, vuint16mf2_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vluxseg4ei16_v)))
void vluxseg4ei16(vfloat16mf4_t *, vfloat16mf4_t *, vfloat16mf4_t *, vfloat16mf4_t *, const _Float16 *, vuint16mf4_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vluxseg4ei16_v_m)))
void vluxseg4ei16(vfloat16mf4_t *, vfloat16mf4_t *, vfloat16mf4_t *, vfloat16mf4_t *, vbool64_t, vfloat16mf4_t, vfloat16mf4_t, vfloat16mf4_t, vfloat16mf4_t, const _Float16 *, vuint16mf4_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vluxseg5ei16_v)))
void vluxseg5ei16(vfloat16m1_t *, vfloat16m1_t *, vfloat16m1_t *, vfloat16m1_t *, vfloat16m1_t *, const _Float16 *, vuint16m1_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vluxseg5ei16_v_m)))
void vluxseg5ei16(vfloat16m1_t *, vfloat16m1_t *, vfloat16m1_t *, vfloat16m1_t *, vfloat16m1_t *, vbool16_t, vfloat16m1_t, vfloat16m1_t, vfloat16m1_t, vfloat16m1_t, vfloat16m1_t, const _Float16 *, vuint16m1_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vluxseg5ei16_v)))
void vluxseg5ei16(vfloat16mf2_t *, vfloat16mf2_t *, vfloat16mf2_t *, vfloat16mf2_t *, vfloat16mf2_t *, const _Float16 *, vuint16mf2_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vluxseg5ei16_v_m)))
void vluxseg5ei16(vfloat16mf2_t *, vfloat16mf2_t *, vfloat16mf2_t *, vfloat16mf2_t *, vfloat16mf2_t *, vbool32_t, vfloat16mf2_t, vfloat16mf2_t, vfloat16mf2_t, vfloat16mf2_t, vfloat16mf2_t, const _Float16 *, vuint16mf2_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vluxseg5ei16_v)))
void vluxseg5ei16(vfloat16mf4_t *, vfloat16mf4_t *, vfloat16mf4_t *, vfloat16mf4_t *, vfloat16mf4_t *, const _Float16 *, vuint16mf4_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vluxseg5ei16_v_m)))
void vluxseg5ei16(vfloat16mf4_t *, vfloat16mf4_t *, vfloat16mf4_t *, vfloat16mf4_t *, vfloat16mf4_t *, vbool64_t, vfloat16mf4_t, vfloat16mf4_t, vfloat16mf4_t, vfloat16mf4_t, vfloat16mf4_t, const _Float16 *, vuint16mf4_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vluxseg6ei16_v)))
void vluxseg6ei16(vfloat16m1_t *, vfloat16m1_t *, vfloat16m1_t *, vfloat16m1_t *, vfloat16m1_t *, vfloat16m1_t *, const _Float16 *, vuint16m1_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vluxseg6ei16_v_m)))
void vluxseg6ei16(vfloat16m1_t *, vfloat16m1_t *, vfloat16m1_t *, vfloat16m1_t *, vfloat16m1_t *, vfloat16m1_t *, vbool16_t, vfloat16m1_t, vfloat16m1_t, vfloat16m1_t, vfloat16m1_t, vfloat16m1_t, vfloat16m1_t, const _Float16 *, vuint16m1_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vluxseg6ei16_v)))
void vluxseg6ei16(vfloat16mf2_t *, vfloat16mf2_t *, vfloat16mf2_t *, vfloat16mf2_t *, vfloat16mf2_t *, vfloat16mf2_t *, const _Float16 *, vuint16mf2_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vluxseg6ei16_v_m)))
void vluxseg6ei16(vfloat16mf2_t *, vfloat16mf2_t *, vfloat16mf2_t *, vfloat16mf2_t *, vfloat16mf2_t *, vfloat16mf2_t *, vbool32_t, vfloat16mf2_t, vfloat16mf2_t, vfloat16mf2_t, vfloat16mf2_t, vfloat16mf2_t, vfloat16mf2_t, const _Float16 *, vuint16mf2_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vluxseg6ei16_v)))
void vluxseg6ei16(vfloat16mf4_t *, vfloat16mf4_t *, vfloat16mf4_t *, vfloat16mf4_t *, vfloat16mf4_t *, vfloat16mf4_t *, const _Float16 *, vuint16mf4_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vluxseg6ei16_v_m)))
void vluxseg6ei16(vfloat16mf4_t *, vfloat16mf4_t *, vfloat16mf4_t *, vfloat16mf4_t *, vfloat16mf4_t *, vfloat16mf4_t *, vbool64_t, vfloat16mf4_t, vfloat16mf4_t, vfloat16mf4_t, vfloat16mf4_t, vfloat16mf4_t, vfloat16mf4_t, const _Float16 *, vuint16mf4_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vluxseg7ei16_v)))
void vluxseg7ei16(vfloat16m1_t *, vfloat16m1_t *, vfloat16m1_t *, vfloat16m1_t *, vfloat16m1_t *, vfloat16m1_t *, vfloat16m1_t *, const _Float16 *, vuint16m1_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vluxseg7ei16_v_m)))
void vluxseg7ei16(vfloat16m1_t *, vfloat16m1_t *, vfloat16m1_t *, vfloat16m1_t *, vfloat16m1_t *, vfloat16m1_t *, vfloat16m1_t *, vbool16_t, vfloat16m1_t, vfloat16m1_t, vfloat16m1_t, vfloat16m1_t, vfloat16m1_t, vfloat16m1_t, vfloat16m1_t, const _Float16 *, vuint16m1_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vluxseg7ei16_v)))
void vluxseg7ei16(vfloat16mf2_t *, vfloat16mf2_t *, vfloat16mf2_t *, vfloat16mf2_t *, vfloat16mf2_t *, vfloat16mf2_t *, vfloat16mf2_t *, const _Float16 *, vuint16mf2_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vluxseg7ei16_v_m)))
void vluxseg7ei16(vfloat16mf2_t *, vfloat16mf2_t *, vfloat16mf2_t *, vfloat16mf2_t *, vfloat16mf2_t *, vfloat16mf2_t *, vfloat16mf2_t *, vbool32_t, vfloat16mf2_t, vfloat16mf2_t, vfloat16mf2_t, vfloat16mf2_t, vfloat16mf2_t, vfloat16mf2_t, vfloat16mf2_t, const _Float16 *, vuint16mf2_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vluxseg7ei16_v)))
void vluxseg7ei16(vfloat16mf4_t *, vfloat16mf4_t *, vfloat16mf4_t *, vfloat16mf4_t *, vfloat16mf4_t *, vfloat16mf4_t *, vfloat16mf4_t *, const _Float16 *, vuint16mf4_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vluxseg7ei16_v_m)))
void vluxseg7ei16(vfloat16mf4_t *, vfloat16mf4_t *, vfloat16mf4_t *, vfloat16mf4_t *, vfloat16mf4_t *, vfloat16mf4_t *, vfloat16mf4_t *, vbool64_t, vfloat16mf4_t, vfloat16mf4_t, vfloat16mf4_t, vfloat16mf4_t, vfloat16mf4_t, vfloat16mf4_t, vfloat16mf4_t, const _Float16 *, vuint16mf4_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vluxseg8ei16_v)))
void vluxseg8ei16(vfloat16m1_t *, vfloat16m1_t *, vfloat16m1_t *, vfloat16m1_t *, vfloat16m1_t *, vfloat16m1_t *, vfloat16m1_t *, vfloat16m1_t *, const _Float16 *, vuint16m1_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vluxseg8ei16_v_m)))
void vluxseg8ei16(vfloat16m1_t *, vfloat16m1_t *, vfloat16m1_t *, vfloat16m1_t *, vfloat16m1_t *, vfloat16m1_t *, vfloat16m1_t *, vfloat16m1_t *, vbool16_t, vfloat16m1_t, vfloat16m1_t, vfloat16m1_t, vfloat16m1_t, vfloat16m1_t, vfloat16m1_t, vfloat16m1_t, vfloat16m1_t, const _Float16 *, vuint16m1_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vluxseg8ei16_v)))
void vluxseg8ei16(vfloat16mf2_t *, vfloat16mf2_t *, vfloat16mf2_t *, vfloat16mf2_t *, vfloat16mf2_t *, vfloat16mf2_t *, vfloat16mf2_t *, vfloat16mf2_t *, const _Float16 *, vuint16mf2_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vluxseg8ei16_v_m)))
void vluxseg8ei16(vfloat16mf2_t *, vfloat16mf2_t *, vfloat16mf2_t *, vfloat16mf2_t *, vfloat16mf2_t *, vfloat16mf2_t *, vfloat16mf2_t *, vfloat16mf2_t *, vbool32_t, vfloat16mf2_t, vfloat16mf2_t, vfloat16mf2_t, vfloat16mf2_t, vfloat16mf2_t, vfloat16mf2_t, vfloat16mf2_t, vfloat16mf2_t, const _Float16 *, vuint16mf2_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vluxseg8ei16_v)))
void vluxseg8ei16(vfloat16mf4_t *, vfloat16mf4_t *, vfloat16mf4_t *, vfloat16mf4_t *, vfloat16mf4_t *, vfloat16mf4_t *, vfloat16mf4_t *, vfloat16mf4_t *, const _Float16 *, vuint16mf4_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vluxseg8ei16_v_m)))
void vluxseg8ei16(vfloat16mf4_t *, vfloat16mf4_t *, vfloat16mf4_t *, vfloat16mf4_t *, vfloat16mf4_t *, vfloat16mf4_t *, vfloat16mf4_t *, vfloat16mf4_t *, vbool64_t, vfloat16mf4_t, vfloat16mf4_t, vfloat16mf4_t, vfloat16mf4_t, vfloat16mf4_t, vfloat16mf4_t, vfloat16mf4_t, vfloat16mf4_t, const _Float16 *, vuint16mf4_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vluxseg2ei32_v)))
void vluxseg2ei32(vfloat16m1_t *, vfloat16m1_t *, const _Float16 *, vuint32m2_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vluxseg2ei32_v_m)))
void vluxseg2ei32(vfloat16m1_t *, vfloat16m1_t *, vbool16_t, vfloat16m1_t, vfloat16m1_t, const _Float16 *, vuint32m2_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vluxseg2ei32_v)))
void vluxseg2ei32(vfloat16m2_t *, vfloat16m2_t *, const _Float16 *, vuint32m4_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vluxseg2ei32_v_m)))
void vluxseg2ei32(vfloat16m2_t *, vfloat16m2_t *, vbool8_t, vfloat16m2_t, vfloat16m2_t, const _Float16 *, vuint32m4_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vluxseg2ei32_v)))
void vluxseg2ei32(vfloat16m4_t *, vfloat16m4_t *, const _Float16 *, vuint32m8_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vluxseg2ei32_v_m)))
void vluxseg2ei32(vfloat16m4_t *, vfloat16m4_t *, vbool4_t, vfloat16m4_t, vfloat16m4_t, const _Float16 *, vuint32m8_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vluxseg2ei32_v)))
void vluxseg2ei32(vfloat16mf2_t *, vfloat16mf2_t *, const _Float16 *, vuint32m1_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vluxseg2ei32_v_m)))
void vluxseg2ei32(vfloat16mf2_t *, vfloat16mf2_t *, vbool32_t, vfloat16mf2_t, vfloat16mf2_t, const _Float16 *, vuint32m1_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vluxseg2ei32_v)))
void vluxseg2ei32(vfloat16mf4_t *, vfloat16mf4_t *, const _Float16 *, vuint32mf2_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vluxseg2ei32_v_m)))
void vluxseg2ei32(vfloat16mf4_t *, vfloat16mf4_t *, vbool64_t, vfloat16mf4_t, vfloat16mf4_t, const _Float16 *, vuint32mf2_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vluxseg3ei32_v)))
void vluxseg3ei32(vfloat16m1_t *, vfloat16m1_t *, vfloat16m1_t *, const _Float16 *, vuint32m2_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vluxseg3ei32_v_m)))
void vluxseg3ei32(vfloat16m1_t *, vfloat16m1_t *, vfloat16m1_t *, vbool16_t, vfloat16m1_t, vfloat16m1_t, vfloat16m1_t, const _Float16 *, vuint32m2_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vluxseg3ei32_v)))
void vluxseg3ei32(vfloat16m2_t *, vfloat16m2_t *, vfloat16m2_t *, const _Float16 *, vuint32m4_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vluxseg3ei32_v_m)))
void vluxseg3ei32(vfloat16m2_t *, vfloat16m2_t *, vfloat16m2_t *, vbool8_t, vfloat16m2_t, vfloat16m2_t, vfloat16m2_t, const _Float16 *, vuint32m4_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vluxseg3ei32_v)))
void vluxseg3ei32(vfloat16mf2_t *, vfloat16mf2_t *, vfloat16mf2_t *, const _Float16 *, vuint32m1_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vluxseg3ei32_v_m)))
void vluxseg3ei32(vfloat16mf2_t *, vfloat16mf2_t *, vfloat16mf2_t *, vbool32_t, vfloat16mf2_t, vfloat16mf2_t, vfloat16mf2_t, const _Float16 *, vuint32m1_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vluxseg3ei32_v)))
void vluxseg3ei32(vfloat16mf4_t *, vfloat16mf4_t *, vfloat16mf4_t *, const _Float16 *, vuint32mf2_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vluxseg3ei32_v_m)))
void vluxseg3ei32(vfloat16mf4_t *, vfloat16mf4_t *, vfloat16mf4_t *, vbool64_t, vfloat16mf4_t, vfloat16mf4_t, vfloat16mf4_t, const _Float16 *, vuint32mf2_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vluxseg4ei32_v)))
void vluxseg4ei32(vfloat16m1_t *, vfloat16m1_t *, vfloat16m1_t *, vfloat16m1_t *, const _Float16 *, vuint32m2_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vluxseg4ei32_v_m)))
void vluxseg4ei32(vfloat16m1_t *, vfloat16m1_t *, vfloat16m1_t *, vfloat16m1_t *, vbool16_t, vfloat16m1_t, vfloat16m1_t, vfloat16m1_t, vfloat16m1_t, const _Float16 *, vuint32m2_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vluxseg4ei32_v)))
void vluxseg4ei32(vfloat16m2_t *, vfloat16m2_t *, vfloat16m2_t *, vfloat16m2_t *, const _Float16 *, vuint32m4_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vluxseg4ei32_v_m)))
void vluxseg4ei32(vfloat16m2_t *, vfloat16m2_t *, vfloat16m2_t *, vfloat16m2_t *, vbool8_t, vfloat16m2_t, vfloat16m2_t, vfloat16m2_t, vfloat16m2_t, const _Float16 *, vuint32m4_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vluxseg4ei32_v)))
void vluxseg4ei32(vfloat16mf2_t *, vfloat16mf2_t *, vfloat16mf2_t *, vfloat16mf2_t *, const _Float16 *, vuint32m1_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vluxseg4ei32_v_m)))
void vluxseg4ei32(vfloat16mf2_t *, vfloat16mf2_t *, vfloat16mf2_t *, vfloat16mf2_t *, vbool32_t, vfloat16mf2_t, vfloat16mf2_t, vfloat16mf2_t, vfloat16mf2_t, const _Float16 *, vuint32m1_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vluxseg4ei32_v)))
void vluxseg4ei32(vfloat16mf4_t *, vfloat16mf4_t *, vfloat16mf4_t *, vfloat16mf4_t *, const _Float16 *, vuint32mf2_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vluxseg4ei32_v_m)))
void vluxseg4ei32(vfloat16mf4_t *, vfloat16mf4_t *, vfloat16mf4_t *, vfloat16mf4_t *, vbool64_t, vfloat16mf4_t, vfloat16mf4_t, vfloat16mf4_t, vfloat16mf4_t, const _Float16 *, vuint32mf2_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vluxseg5ei32_v)))
void vluxseg5ei32(vfloat16m1_t *, vfloat16m1_t *, vfloat16m1_t *, vfloat16m1_t *, vfloat16m1_t *, const _Float16 *, vuint32m2_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vluxseg5ei32_v_m)))
void vluxseg5ei32(vfloat16m1_t *, vfloat16m1_t *, vfloat16m1_t *, vfloat16m1_t *, vfloat16m1_t *, vbool16_t, vfloat16m1_t, vfloat16m1_t, vfloat16m1_t, vfloat16m1_t, vfloat16m1_t, const _Float16 *, vuint32m2_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vluxseg5ei32_v)))
void vluxseg5ei32(vfloat16mf2_t *, vfloat16mf2_t *, vfloat16mf2_t *, vfloat16mf2_t *, vfloat16mf2_t *, const _Float16 *, vuint32m1_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vluxseg5ei32_v_m)))
void vluxseg5ei32(vfloat16mf2_t *, vfloat16mf2_t *, vfloat16mf2_t *, vfloat16mf2_t *, vfloat16mf2_t *, vbool32_t, vfloat16mf2_t, vfloat16mf2_t, vfloat16mf2_t, vfloat16mf2_t, vfloat16mf2_t, const _Float16 *, vuint32m1_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vluxseg5ei32_v)))
void vluxseg5ei32(vfloat16mf4_t *, vfloat16mf4_t *, vfloat16mf4_t *, vfloat16mf4_t *, vfloat16mf4_t *, const _Float16 *, vuint32mf2_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vluxseg5ei32_v_m)))
void vluxseg5ei32(vfloat16mf4_t *, vfloat16mf4_t *, vfloat16mf4_t *, vfloat16mf4_t *, vfloat16mf4_t *, vbool64_t, vfloat16mf4_t, vfloat16mf4_t, vfloat16mf4_t, vfloat16mf4_t, vfloat16mf4_t, const _Float16 *, vuint32mf2_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vluxseg6ei32_v)))
void vluxseg6ei32(vfloat16m1_t *, vfloat16m1_t *, vfloat16m1_t *, vfloat16m1_t *, vfloat16m1_t *, vfloat16m1_t *, const _Float16 *, vuint32m2_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vluxseg6ei32_v_m)))
void vluxseg6ei32(vfloat16m1_t *, vfloat16m1_t *, vfloat16m1_t *, vfloat16m1_t *, vfloat16m1_t *, vfloat16m1_t *, vbool16_t, vfloat16m1_t, vfloat16m1_t, vfloat16m1_t, vfloat16m1_t, vfloat16m1_t, vfloat16m1_t, const _Float16 *, vuint32m2_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vluxseg6ei32_v)))
void vluxseg6ei32(vfloat16mf2_t *, vfloat16mf2_t *, vfloat16mf2_t *, vfloat16mf2_t *, vfloat16mf2_t *, vfloat16mf2_t *, const _Float16 *, vuint32m1_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vluxseg6ei32_v_m)))
void vluxseg6ei32(vfloat16mf2_t *, vfloat16mf2_t *, vfloat16mf2_t *, vfloat16mf2_t *, vfloat16mf2_t *, vfloat16mf2_t *, vbool32_t, vfloat16mf2_t, vfloat16mf2_t, vfloat16mf2_t, vfloat16mf2_t, vfloat16mf2_t, vfloat16mf2_t, const _Float16 *, vuint32m1_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vluxseg6ei32_v)))
void vluxseg6ei32(vfloat16mf4_t *, vfloat16mf4_t *, vfloat16mf4_t *, vfloat16mf4_t *, vfloat16mf4_t *, vfloat16mf4_t *, const _Float16 *, vuint32mf2_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vluxseg6ei32_v_m)))
void vluxseg6ei32(vfloat16mf4_t *, vfloat16mf4_t *, vfloat16mf4_t *, vfloat16mf4_t *, vfloat16mf4_t *, vfloat16mf4_t *, vbool64_t, vfloat16mf4_t, vfloat16mf4_t, vfloat16mf4_t, vfloat16mf4_t, vfloat16mf4_t, vfloat16mf4_t, const _Float16 *, vuint32mf2_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vluxseg7ei32_v)))
void vluxseg7ei32(vfloat16m1_t *, vfloat16m1_t *, vfloat16m1_t *, vfloat16m1_t *, vfloat16m1_t *, vfloat16m1_t *, vfloat16m1_t *, const _Float16 *, vuint32m2_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vluxseg7ei32_v_m)))
void vluxseg7ei32(vfloat16m1_t *, vfloat16m1_t *, vfloat16m1_t *, vfloat16m1_t *, vfloat16m1_t *, vfloat16m1_t *, vfloat16m1_t *, vbool16_t, vfloat16m1_t, vfloat16m1_t, vfloat16m1_t, vfloat16m1_t, vfloat16m1_t, vfloat16m1_t, vfloat16m1_t, const _Float16 *, vuint32m2_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vluxseg7ei32_v)))
void vluxseg7ei32(vfloat16mf2_t *, vfloat16mf2_t *, vfloat16mf2_t *, vfloat16mf2_t *, vfloat16mf2_t *, vfloat16mf2_t *, vfloat16mf2_t *, const _Float16 *, vuint32m1_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vluxseg7ei32_v_m)))
void vluxseg7ei32(vfloat16mf2_t *, vfloat16mf2_t *, vfloat16mf2_t *, vfloat16mf2_t *, vfloat16mf2_t *, vfloat16mf2_t *, vfloat16mf2_t *, vbool32_t, vfloat16mf2_t, vfloat16mf2_t, vfloat16mf2_t, vfloat16mf2_t, vfloat16mf2_t, vfloat16mf2_t, vfloat16mf2_t, const _Float16 *, vuint32m1_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vluxseg7ei32_v)))
void vluxseg7ei32(vfloat16mf4_t *, vfloat16mf4_t *, vfloat16mf4_t *, vfloat16mf4_t *, vfloat16mf4_t *, vfloat16mf4_t *, vfloat16mf4_t *, const _Float16 *, vuint32mf2_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vluxseg7ei32_v_m)))
void vluxseg7ei32(vfloat16mf4_t *, vfloat16mf4_t *, vfloat16mf4_t *, vfloat16mf4_t *, vfloat16mf4_t *, vfloat16mf4_t *, vfloat16mf4_t *, vbool64_t, vfloat16mf4_t, vfloat16mf4_t, vfloat16mf4_t, vfloat16mf4_t, vfloat16mf4_t, vfloat16mf4_t, vfloat16mf4_t, const _Float16 *, vuint32mf2_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vluxseg8ei32_v)))
void vluxseg8ei32(vfloat16m1_t *, vfloat16m1_t *, vfloat16m1_t *, vfloat16m1_t *, vfloat16m1_t *, vfloat16m1_t *, vfloat16m1_t *, vfloat16m1_t *, const _Float16 *, vuint32m2_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vluxseg8ei32_v_m)))
void vluxseg8ei32(vfloat16m1_t *, vfloat16m1_t *, vfloat16m1_t *, vfloat16m1_t *, vfloat16m1_t *, vfloat16m1_t *, vfloat16m1_t *, vfloat16m1_t *, vbool16_t, vfloat16m1_t, vfloat16m1_t, vfloat16m1_t, vfloat16m1_t, vfloat16m1_t, vfloat16m1_t, vfloat16m1_t, vfloat16m1_t, const _Float16 *, vuint32m2_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vluxseg8ei32_v)))
void vluxseg8ei32(vfloat16mf2_t *, vfloat16mf2_t *, vfloat16mf2_t *, vfloat16mf2_t *, vfloat16mf2_t *, vfloat16mf2_t *, vfloat16mf2_t *, vfloat16mf2_t *, const _Float16 *, vuint32m1_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vluxseg8ei32_v_m)))
void vluxseg8ei32(vfloat16mf2_t *, vfloat16mf2_t *, vfloat16mf2_t *, vfloat16mf2_t *, vfloat16mf2_t *, vfloat16mf2_t *, vfloat16mf2_t *, vfloat16mf2_t *, vbool32_t, vfloat16mf2_t, vfloat16mf2_t, vfloat16mf2_t, vfloat16mf2_t, vfloat16mf2_t, vfloat16mf2_t, vfloat16mf2_t, vfloat16mf2_t, const _Float16 *, vuint32m1_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vluxseg8ei32_v)))
void vluxseg8ei32(vfloat16mf4_t *, vfloat16mf4_t *, vfloat16mf4_t *, vfloat16mf4_t *, vfloat16mf4_t *, vfloat16mf4_t *, vfloat16mf4_t *, vfloat16mf4_t *, const _Float16 *, vuint32mf2_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vluxseg8ei32_v_m)))
void vluxseg8ei32(vfloat16mf4_t *, vfloat16mf4_t *, vfloat16mf4_t *, vfloat16mf4_t *, vfloat16mf4_t *, vfloat16mf4_t *, vfloat16mf4_t *, vfloat16mf4_t *, vbool64_t, vfloat16mf4_t, vfloat16mf4_t, vfloat16mf4_t, vfloat16mf4_t, vfloat16mf4_t, vfloat16mf4_t, vfloat16mf4_t, vfloat16mf4_t, const _Float16 *, vuint32mf2_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vle16_v_m)))
vfloat16m1_t vle16(vbool16_t, vfloat16m1_t, const _Float16 *, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vle16_v_m)))
vfloat16m2_t vle16(vbool8_t, vfloat16m2_t, const _Float16 *, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vle16_v_m)))
vfloat16m4_t vle16(vbool4_t, vfloat16m4_t, const _Float16 *, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vle16_v_m)))
vfloat16m8_t vle16(vbool2_t, vfloat16m8_t, const _Float16 *, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vle16_v_m)))
vfloat16mf2_t vle16(vbool32_t, vfloat16mf2_t, const _Float16 *, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vle16_v_m)))
vfloat16mf4_t vle16(vbool64_t, vfloat16mf4_t, const _Float16 *, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vse16_v)))
void vse16(_Float16 *, vfloat16m1_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vse16_v_m)))
void vse16(vbool16_t, _Float16 *, vfloat16m1_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vse16_v)))
void vse16(_Float16 *, vfloat16m2_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vse16_v_m)))
void vse16(vbool8_t, _Float16 *, vfloat16m2_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vse16_v)))
void vse16(_Float16 *, vfloat16m4_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vse16_v_m)))
void vse16(vbool4_t, _Float16 *, vfloat16m4_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vse16_v)))
void vse16(_Float16 *, vfloat16m8_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vse16_v_m)))
void vse16(vbool2_t, _Float16 *, vfloat16m8_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vse16_v)))
void vse16(_Float16 *, vfloat16mf2_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vse16_v_m)))
void vse16(vbool32_t, _Float16 *, vfloat16mf2_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vse16_v)))
void vse16(_Float16 *, vfloat16mf4_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vse16_v_m)))
void vse16(vbool64_t, _Float16 *, vfloat16mf4_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vlse16_v_m)))
vfloat16m1_t vlse16(vbool16_t, vfloat16m1_t, const _Float16 *, ptrdiff_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vlse16_v_m)))
vfloat16m2_t vlse16(vbool8_t, vfloat16m2_t, const _Float16 *, ptrdiff_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vlse16_v_m)))
vfloat16m4_t vlse16(vbool4_t, vfloat16m4_t, const _Float16 *, ptrdiff_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vlse16_v_m)))
vfloat16m8_t vlse16(vbool2_t, vfloat16m8_t, const _Float16 *, ptrdiff_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vlse16_v_m)))
vfloat16mf2_t vlse16(vbool32_t, vfloat16mf2_t, const _Float16 *, ptrdiff_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vlse16_v_m)))
vfloat16mf4_t vlse16(vbool64_t, vfloat16mf4_t, const _Float16 *, ptrdiff_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vfclass_v)))
vuint16m1_t vfclass(vfloat16m1_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vfclass_v_m)))
vuint16m1_t vfclass(vbool16_t, vuint16m1_t, vfloat16m1_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vfclass_v)))
vuint16m2_t vfclass(vfloat16m2_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vfclass_v_m)))
vuint16m2_t vfclass(vbool8_t, vuint16m2_t, vfloat16m2_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vfclass_v)))
vuint16m4_t vfclass(vfloat16m4_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vfclass_v_m)))
vuint16m4_t vfclass(vbool4_t, vuint16m4_t, vfloat16m4_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vfclass_v)))
vuint16m8_t vfclass(vfloat16m8_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vfclass_v_m)))
vuint16m8_t vfclass(vbool2_t, vuint16m8_t, vfloat16m8_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vfclass_v)))
vuint16mf2_t vfclass(vfloat16mf2_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vfclass_v_m)))
vuint16mf2_t vfclass(vbool32_t, vuint16mf2_t, vfloat16mf2_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vfclass_v)))
vuint16mf4_t vfclass(vfloat16mf4_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vfclass_v_m)))
vuint16mf4_t vfclass(vbool64_t, vuint16mf4_t, vfloat16mf4_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vfcvt_f_x_v)))
vfloat16m1_t vfcvt_f(vint16m1_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vfcvt_f_x_v_m)))
vfloat16m1_t vfcvt_f(vbool16_t, vfloat16m1_t, vint16m1_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vfcvt_f_x_v)))
vfloat16m2_t vfcvt_f(vint16m2_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vfcvt_f_x_v_m)))
vfloat16m2_t vfcvt_f(vbool8_t, vfloat16m2_t, vint16m2_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vfcvt_f_x_v)))
vfloat16m4_t vfcvt_f(vint16m4_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vfcvt_f_x_v_m)))
vfloat16m4_t vfcvt_f(vbool4_t, vfloat16m4_t, vint16m4_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vfcvt_f_x_v)))
vfloat16m8_t vfcvt_f(vint16m8_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vfcvt_f_x_v_m)))
vfloat16m8_t vfcvt_f(vbool2_t, vfloat16m8_t, vint16m8_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vfcvt_f_x_v)))
vfloat16mf2_t vfcvt_f(vint16mf2_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vfcvt_f_x_v_m)))
vfloat16mf2_t vfcvt_f(vbool32_t, vfloat16mf2_t, vint16mf2_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vfcvt_f_x_v)))
vfloat16mf4_t vfcvt_f(vint16mf4_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vfcvt_f_x_v_m)))
vfloat16mf4_t vfcvt_f(vbool64_t, vfloat16mf4_t, vint16mf4_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vfcvt_f_xu_v)))
vfloat16m1_t vfcvt_f(vuint16m1_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vfcvt_f_xu_v_m)))
vfloat16m1_t vfcvt_f(vbool16_t, vfloat16m1_t, vuint16m1_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vfcvt_f_xu_v)))
vfloat16m2_t vfcvt_f(vuint16m2_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vfcvt_f_xu_v_m)))
vfloat16m2_t vfcvt_f(vbool8_t, vfloat16m2_t, vuint16m2_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vfcvt_f_xu_v)))
vfloat16m4_t vfcvt_f(vuint16m4_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vfcvt_f_xu_v_m)))
vfloat16m4_t vfcvt_f(vbool4_t, vfloat16m4_t, vuint16m4_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vfcvt_f_xu_v)))
vfloat16m8_t vfcvt_f(vuint16m8_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vfcvt_f_xu_v_m)))
vfloat16m8_t vfcvt_f(vbool2_t, vfloat16m8_t, vuint16m8_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vfcvt_f_xu_v)))
vfloat16mf2_t vfcvt_f(vuint16mf2_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vfcvt_f_xu_v_m)))
vfloat16mf2_t vfcvt_f(vbool32_t, vfloat16mf2_t, vuint16mf2_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vfcvt_f_xu_v)))
vfloat16mf4_t vfcvt_f(vuint16mf4_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vfcvt_f_xu_v_m)))
vfloat16mf4_t vfcvt_f(vbool64_t, vfloat16mf4_t, vuint16mf4_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vfcvt_rtz_x_f_v)))
vint16m1_t vfcvt_rtz_x(vfloat16m1_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vfcvt_rtz_x_f_v_m)))
vint16m1_t vfcvt_rtz_x(vbool16_t, vint16m1_t, vfloat16m1_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vfcvt_rtz_x_f_v)))
vint16m2_t vfcvt_rtz_x(vfloat16m2_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vfcvt_rtz_x_f_v_m)))
vint16m2_t vfcvt_rtz_x(vbool8_t, vint16m2_t, vfloat16m2_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vfcvt_rtz_x_f_v)))
vint16m4_t vfcvt_rtz_x(vfloat16m4_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vfcvt_rtz_x_f_v_m)))
vint16m4_t vfcvt_rtz_x(vbool4_t, vint16m4_t, vfloat16m4_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vfcvt_rtz_x_f_v)))
vint16m8_t vfcvt_rtz_x(vfloat16m8_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vfcvt_rtz_x_f_v_m)))
vint16m8_t vfcvt_rtz_x(vbool2_t, vint16m8_t, vfloat16m8_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vfcvt_rtz_x_f_v)))
vint16mf2_t vfcvt_rtz_x(vfloat16mf2_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vfcvt_rtz_x_f_v_m)))
vint16mf2_t vfcvt_rtz_x(vbool32_t, vint16mf2_t, vfloat16mf2_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vfcvt_rtz_x_f_v)))
vint16mf4_t vfcvt_rtz_x(vfloat16mf4_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vfcvt_rtz_x_f_v_m)))
vint16mf4_t vfcvt_rtz_x(vbool64_t, vint16mf4_t, vfloat16mf4_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vfcvt_rtz_xu_f_v)))
vuint16m1_t vfcvt_rtz_xu(vfloat16m1_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vfcvt_rtz_xu_f_v_m)))
vuint16m1_t vfcvt_rtz_xu(vbool16_t, vuint16m1_t, vfloat16m1_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vfcvt_rtz_xu_f_v)))
vuint16m2_t vfcvt_rtz_xu(vfloat16m2_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vfcvt_rtz_xu_f_v_m)))
vuint16m2_t vfcvt_rtz_xu(vbool8_t, vuint16m2_t, vfloat16m2_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vfcvt_rtz_xu_f_v)))
vuint16m4_t vfcvt_rtz_xu(vfloat16m4_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vfcvt_rtz_xu_f_v_m)))
vuint16m4_t vfcvt_rtz_xu(vbool4_t, vuint16m4_t, vfloat16m4_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vfcvt_rtz_xu_f_v)))
vuint16m8_t vfcvt_rtz_xu(vfloat16m8_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vfcvt_rtz_xu_f_v_m)))
vuint16m8_t vfcvt_rtz_xu(vbool2_t, vuint16m8_t, vfloat16m8_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vfcvt_rtz_xu_f_v)))
vuint16mf2_t vfcvt_rtz_xu(vfloat16mf2_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vfcvt_rtz_xu_f_v_m)))
vuint16mf2_t vfcvt_rtz_xu(vbool32_t, vuint16mf2_t, vfloat16mf2_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vfcvt_rtz_xu_f_v)))
vuint16mf4_t vfcvt_rtz_xu(vfloat16mf4_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vfcvt_rtz_xu_f_v_m)))
vuint16mf4_t vfcvt_rtz_xu(vbool64_t, vuint16mf4_t, vfloat16mf4_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vfcvt_x_f_v)))
vint16m1_t vfcvt_x(vfloat16m1_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vfcvt_x_f_v_m)))
vint16m1_t vfcvt_x(vbool16_t, vint16m1_t, vfloat16m1_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vfcvt_x_f_v)))
vint16m2_t vfcvt_x(vfloat16m2_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vfcvt_x_f_v_m)))
vint16m2_t vfcvt_x(vbool8_t, vint16m2_t, vfloat16m2_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vfcvt_x_f_v)))
vint16m4_t vfcvt_x(vfloat16m4_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vfcvt_x_f_v_m)))
vint16m4_t vfcvt_x(vbool4_t, vint16m4_t, vfloat16m4_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vfcvt_x_f_v)))
vint16m8_t vfcvt_x(vfloat16m8_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vfcvt_x_f_v_m)))
vint16m8_t vfcvt_x(vbool2_t, vint16m8_t, vfloat16m8_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vfcvt_x_f_v)))
vint16mf2_t vfcvt_x(vfloat16mf2_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vfcvt_x_f_v_m)))
vint16mf2_t vfcvt_x(vbool32_t, vint16mf2_t, vfloat16mf2_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vfcvt_x_f_v)))
vint16mf4_t vfcvt_x(vfloat16mf4_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vfcvt_x_f_v_m)))
vint16mf4_t vfcvt_x(vbool64_t, vint16mf4_t, vfloat16mf4_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vfcvt_xu_f_v)))
vuint16m1_t vfcvt_xu(vfloat16m1_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vfcvt_xu_f_v_m)))
vuint16m1_t vfcvt_xu(vbool16_t, vuint16m1_t, vfloat16m1_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vfcvt_xu_f_v)))
vuint16m2_t vfcvt_xu(vfloat16m2_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vfcvt_xu_f_v_m)))
vuint16m2_t vfcvt_xu(vbool8_t, vuint16m2_t, vfloat16m2_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vfcvt_xu_f_v)))
vuint16m4_t vfcvt_xu(vfloat16m4_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vfcvt_xu_f_v_m)))
vuint16m4_t vfcvt_xu(vbool4_t, vuint16m4_t, vfloat16m4_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vfcvt_xu_f_v)))
vuint16m8_t vfcvt_xu(vfloat16m8_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vfcvt_xu_f_v_m)))
vuint16m8_t vfcvt_xu(vbool2_t, vuint16m8_t, vfloat16m8_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vfcvt_xu_f_v)))
vuint16mf2_t vfcvt_xu(vfloat16mf2_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vfcvt_xu_f_v_m)))
vuint16mf2_t vfcvt_xu(vbool32_t, vuint16mf2_t, vfloat16mf2_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vfcvt_xu_f_v)))
vuint16mf4_t vfcvt_xu(vfloat16mf4_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vfcvt_xu_f_v_m)))
vuint16mf4_t vfcvt_xu(vbool64_t, vuint16mf4_t, vfloat16mf4_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vfncvt_f_x_w)))
vfloat16mf4_t vfncvt_f(vint32mf2_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vfncvt_f_x_w_m)))
vfloat16mf4_t vfncvt_f(vbool64_t, vfloat16mf4_t, vint32mf2_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vfncvt_f_x_w)))
vfloat16mf2_t vfncvt_f(vint32m1_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vfncvt_f_x_w_m)))
vfloat16mf2_t vfncvt_f(vbool32_t, vfloat16mf2_t, vint32m1_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vfncvt_f_x_w)))
vfloat16m1_t vfncvt_f(vint32m2_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vfncvt_f_x_w_m)))
vfloat16m1_t vfncvt_f(vbool16_t, vfloat16m1_t, vint32m2_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vfncvt_f_x_w)))
vfloat16m2_t vfncvt_f(vint32m4_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vfncvt_f_x_w_m)))
vfloat16m2_t vfncvt_f(vbool8_t, vfloat16m2_t, vint32m4_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vfncvt_f_x_w)))
vfloat16m4_t vfncvt_f(vint32m8_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vfncvt_f_x_w_m)))
vfloat16m4_t vfncvt_f(vbool4_t, vfloat16m4_t, vint32m8_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vfncvt_f_xu_w)))
vfloat16mf4_t vfncvt_f(vuint32mf2_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vfncvt_f_xu_w_m)))
vfloat16mf4_t vfncvt_f(vbool64_t, vfloat16mf4_t, vuint32mf2_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vfncvt_f_xu_w)))
vfloat16mf2_t vfncvt_f(vuint32m1_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vfncvt_f_xu_w_m)))
vfloat16mf2_t vfncvt_f(vbool32_t, vfloat16mf2_t, vuint32m1_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vfncvt_f_xu_w)))
vfloat16m1_t vfncvt_f(vuint32m2_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vfncvt_f_xu_w_m)))
vfloat16m1_t vfncvt_f(vbool16_t, vfloat16m1_t, vuint32m2_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vfncvt_f_xu_w)))
vfloat16m2_t vfncvt_f(vuint32m4_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vfncvt_f_xu_w_m)))
vfloat16m2_t vfncvt_f(vbool8_t, vfloat16m2_t, vuint32m4_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vfncvt_f_xu_w)))
vfloat16m4_t vfncvt_f(vuint32m8_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vfncvt_f_xu_w_m)))
vfloat16m4_t vfncvt_f(vbool4_t, vfloat16m4_t, vuint32m8_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vfncvt_rtz_x_f_w)))
vint8mf8_t vfncvt_rtz_x(vfloat16mf4_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vfncvt_rtz_x_f_w_m)))
vint8mf8_t vfncvt_rtz_x(vbool64_t, vint8mf8_t, vfloat16mf4_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vfncvt_rtz_x_f_w)))
vint8mf4_t vfncvt_rtz_x(vfloat16mf2_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vfncvt_rtz_x_f_w_m)))
vint8mf4_t vfncvt_rtz_x(vbool32_t, vint8mf4_t, vfloat16mf2_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vfncvt_rtz_x_f_w)))
vint8mf2_t vfncvt_rtz_x(vfloat16m1_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vfncvt_rtz_x_f_w_m)))
vint8mf2_t vfncvt_rtz_x(vbool16_t, vint8mf2_t, vfloat16m1_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vfncvt_rtz_x_f_w)))
vint8m1_t vfncvt_rtz_x(vfloat16m2_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vfncvt_rtz_x_f_w_m)))
vint8m1_t vfncvt_rtz_x(vbool8_t, vint8m1_t, vfloat16m2_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vfncvt_rtz_x_f_w)))
vint8m2_t vfncvt_rtz_x(vfloat16m4_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vfncvt_rtz_x_f_w_m)))
vint8m2_t vfncvt_rtz_x(vbool4_t, vint8m2_t, vfloat16m4_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vfncvt_rtz_x_f_w)))
vint8m4_t vfncvt_rtz_x(vfloat16m8_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vfncvt_rtz_x_f_w_m)))
vint8m4_t vfncvt_rtz_x(vbool2_t, vint8m4_t, vfloat16m8_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vfncvt_rtz_xu_f_w)))
vuint8mf8_t vfncvt_rtz_xu(vfloat16mf4_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vfncvt_rtz_xu_f_w_m)))
vuint8mf8_t vfncvt_rtz_xu(vbool64_t, vuint8mf8_t, vfloat16mf4_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vfncvt_rtz_xu_f_w)))
vuint8mf4_t vfncvt_rtz_xu(vfloat16mf2_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vfncvt_rtz_xu_f_w_m)))
vuint8mf4_t vfncvt_rtz_xu(vbool32_t, vuint8mf4_t, vfloat16mf2_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vfncvt_rtz_xu_f_w)))
vuint8mf2_t vfncvt_rtz_xu(vfloat16m1_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vfncvt_rtz_xu_f_w_m)))
vuint8mf2_t vfncvt_rtz_xu(vbool16_t, vuint8mf2_t, vfloat16m1_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vfncvt_rtz_xu_f_w)))
vuint8m1_t vfncvt_rtz_xu(vfloat16m2_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vfncvt_rtz_xu_f_w_m)))
vuint8m1_t vfncvt_rtz_xu(vbool8_t, vuint8m1_t, vfloat16m2_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vfncvt_rtz_xu_f_w)))
vuint8m2_t vfncvt_rtz_xu(vfloat16m4_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vfncvt_rtz_xu_f_w_m)))
vuint8m2_t vfncvt_rtz_xu(vbool4_t, vuint8m2_t, vfloat16m4_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vfncvt_rtz_xu_f_w)))
vuint8m4_t vfncvt_rtz_xu(vfloat16m8_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vfncvt_rtz_xu_f_w_m)))
vuint8m4_t vfncvt_rtz_xu(vbool2_t, vuint8m4_t, vfloat16m8_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vfncvt_x_f_w)))
vint8mf8_t vfncvt_x(vfloat16mf4_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vfncvt_x_f_w_m)))
vint8mf8_t vfncvt_x(vbool64_t, vint8mf8_t, vfloat16mf4_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vfncvt_x_f_w)))
vint8mf4_t vfncvt_x(vfloat16mf2_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vfncvt_x_f_w_m)))
vint8mf4_t vfncvt_x(vbool32_t, vint8mf4_t, vfloat16mf2_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vfncvt_x_f_w)))
vint8mf2_t vfncvt_x(vfloat16m1_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vfncvt_x_f_w_m)))
vint8mf2_t vfncvt_x(vbool16_t, vint8mf2_t, vfloat16m1_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vfncvt_x_f_w)))
vint8m1_t vfncvt_x(vfloat16m2_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vfncvt_x_f_w_m)))
vint8m1_t vfncvt_x(vbool8_t, vint8m1_t, vfloat16m2_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vfncvt_x_f_w)))
vint8m2_t vfncvt_x(vfloat16m4_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vfncvt_x_f_w_m)))
vint8m2_t vfncvt_x(vbool4_t, vint8m2_t, vfloat16m4_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vfncvt_x_f_w)))
vint8m4_t vfncvt_x(vfloat16m8_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vfncvt_x_f_w_m)))
vint8m4_t vfncvt_x(vbool2_t, vint8m4_t, vfloat16m8_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vfncvt_xu_f_w)))
vuint8mf8_t vfncvt_xu(vfloat16mf4_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vfncvt_xu_f_w_m)))
vuint8mf8_t vfncvt_xu(vbool64_t, vuint8mf8_t, vfloat16mf4_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vfncvt_xu_f_w)))
vuint8mf4_t vfncvt_xu(vfloat16mf2_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vfncvt_xu_f_w_m)))
vuint8mf4_t vfncvt_xu(vbool32_t, vuint8mf4_t, vfloat16mf2_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vfncvt_xu_f_w)))
vuint8mf2_t vfncvt_xu(vfloat16m1_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vfncvt_xu_f_w_m)))
vuint8mf2_t vfncvt_xu(vbool16_t, vuint8mf2_t, vfloat16m1_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vfncvt_xu_f_w)))
vuint8m1_t vfncvt_xu(vfloat16m2_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vfncvt_xu_f_w_m)))
vuint8m1_t vfncvt_xu(vbool8_t, vuint8m1_t, vfloat16m2_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vfncvt_xu_f_w)))
vuint8m2_t vfncvt_xu(vfloat16m4_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vfncvt_xu_f_w_m)))
vuint8m2_t vfncvt_xu(vbool4_t, vuint8m2_t, vfloat16m4_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vfncvt_xu_f_w)))
vuint8m4_t vfncvt_xu(vfloat16m8_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vfncvt_xu_f_w_m)))
vuint8m4_t vfncvt_xu(vbool2_t, vuint8m4_t, vfloat16m8_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vfrec7_v)))
vfloat16m1_t vfrec7(vfloat16m1_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vfrec7_v_m)))
vfloat16m1_t vfrec7(vbool16_t, vfloat16m1_t, vfloat16m1_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vfrec7_v)))
vfloat16m2_t vfrec7(vfloat16m2_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vfrec7_v_m)))
vfloat16m2_t vfrec7(vbool8_t, vfloat16m2_t, vfloat16m2_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vfrec7_v)))
vfloat16m4_t vfrec7(vfloat16m4_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vfrec7_v_m)))
vfloat16m4_t vfrec7(vbool4_t, vfloat16m4_t, vfloat16m4_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vfrec7_v)))
vfloat16m8_t vfrec7(vfloat16m8_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vfrec7_v_m)))
vfloat16m8_t vfrec7(vbool2_t, vfloat16m8_t, vfloat16m8_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vfrec7_v)))
vfloat16mf2_t vfrec7(vfloat16mf2_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vfrec7_v_m)))
vfloat16mf2_t vfrec7(vbool32_t, vfloat16mf2_t, vfloat16mf2_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vfrec7_v)))
vfloat16mf4_t vfrec7(vfloat16mf4_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vfrec7_v_m)))
vfloat16mf4_t vfrec7(vbool64_t, vfloat16mf4_t, vfloat16mf4_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vfrsqrt7_v)))
vfloat16m1_t vfrsqrt7(vfloat16m1_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vfrsqrt7_v_m)))
vfloat16m1_t vfrsqrt7(vbool16_t, vfloat16m1_t, vfloat16m1_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vfrsqrt7_v)))
vfloat16m2_t vfrsqrt7(vfloat16m2_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vfrsqrt7_v_m)))
vfloat16m2_t vfrsqrt7(vbool8_t, vfloat16m2_t, vfloat16m2_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vfrsqrt7_v)))
vfloat16m4_t vfrsqrt7(vfloat16m4_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vfrsqrt7_v_m)))
vfloat16m4_t vfrsqrt7(vbool4_t, vfloat16m4_t, vfloat16m4_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vfrsqrt7_v)))
vfloat16m8_t vfrsqrt7(vfloat16m8_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vfrsqrt7_v_m)))
vfloat16m8_t vfrsqrt7(vbool2_t, vfloat16m8_t, vfloat16m8_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vfrsqrt7_v)))
vfloat16mf2_t vfrsqrt7(vfloat16mf2_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vfrsqrt7_v_m)))
vfloat16mf2_t vfrsqrt7(vbool32_t, vfloat16mf2_t, vfloat16mf2_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vfrsqrt7_v)))
vfloat16mf4_t vfrsqrt7(vfloat16mf4_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vfrsqrt7_v_m)))
vfloat16mf4_t vfrsqrt7(vbool64_t, vfloat16mf4_t, vfloat16mf4_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vfsqrt_v)))
vfloat16m1_t vfsqrt(vfloat16m1_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vfsqrt_v_m)))
vfloat16m1_t vfsqrt(vbool16_t, vfloat16m1_t, vfloat16m1_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vfsqrt_v)))
vfloat16m2_t vfsqrt(vfloat16m2_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vfsqrt_v_m)))
vfloat16m2_t vfsqrt(vbool8_t, vfloat16m2_t, vfloat16m2_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vfsqrt_v)))
vfloat16m4_t vfsqrt(vfloat16m4_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vfsqrt_v_m)))
vfloat16m4_t vfsqrt(vbool4_t, vfloat16m4_t, vfloat16m4_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vfsqrt_v)))
vfloat16m8_t vfsqrt(vfloat16m8_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vfsqrt_v_m)))
vfloat16m8_t vfsqrt(vbool2_t, vfloat16m8_t, vfloat16m8_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vfsqrt_v)))
vfloat16mf2_t vfsqrt(vfloat16mf2_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vfsqrt_v_m)))
vfloat16mf2_t vfsqrt(vbool32_t, vfloat16mf2_t, vfloat16mf2_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vfsqrt_v)))
vfloat16mf4_t vfsqrt(vfloat16mf4_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vfsqrt_v_m)))
vfloat16mf4_t vfsqrt(vbool64_t, vfloat16mf4_t, vfloat16mf4_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vfwcvt_f_x_v)))
vfloat16mf4_t vfwcvt_f(vint8mf8_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vfwcvt_f_x_v_m)))
vfloat16mf4_t vfwcvt_f(vbool64_t, vfloat16mf4_t, vint8mf8_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vfwcvt_f_x_v)))
vfloat16mf2_t vfwcvt_f(vint8mf4_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vfwcvt_f_x_v_m)))
vfloat16mf2_t vfwcvt_f(vbool32_t, vfloat16mf2_t, vint8mf4_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vfwcvt_f_x_v)))
vfloat16m1_t vfwcvt_f(vint8mf2_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vfwcvt_f_x_v_m)))
vfloat16m1_t vfwcvt_f(vbool16_t, vfloat16m1_t, vint8mf2_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vfwcvt_f_x_v)))
vfloat16m2_t vfwcvt_f(vint8m1_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vfwcvt_f_x_v_m)))
vfloat16m2_t vfwcvt_f(vbool8_t, vfloat16m2_t, vint8m1_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vfwcvt_f_x_v)))
vfloat16m4_t vfwcvt_f(vint8m2_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vfwcvt_f_x_v_m)))
vfloat16m4_t vfwcvt_f(vbool4_t, vfloat16m4_t, vint8m2_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vfwcvt_f_x_v)))
vfloat16m8_t vfwcvt_f(vint8m4_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vfwcvt_f_x_v_m)))
vfloat16m8_t vfwcvt_f(vbool2_t, vfloat16m8_t, vint8m4_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vfwcvt_f_xu_v)))
vfloat16mf4_t vfwcvt_f(vuint8mf8_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vfwcvt_f_xu_v_m)))
vfloat16mf4_t vfwcvt_f(vbool64_t, vfloat16mf4_t, vuint8mf8_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vfwcvt_f_xu_v)))
vfloat16mf2_t vfwcvt_f(vuint8mf4_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vfwcvt_f_xu_v_m)))
vfloat16mf2_t vfwcvt_f(vbool32_t, vfloat16mf2_t, vuint8mf4_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vfwcvt_f_xu_v)))
vfloat16m1_t vfwcvt_f(vuint8mf2_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vfwcvt_f_xu_v_m)))
vfloat16m1_t vfwcvt_f(vbool16_t, vfloat16m1_t, vuint8mf2_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vfwcvt_f_xu_v)))
vfloat16m2_t vfwcvt_f(vuint8m1_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vfwcvt_f_xu_v_m)))
vfloat16m2_t vfwcvt_f(vbool8_t, vfloat16m2_t, vuint8m1_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vfwcvt_f_xu_v)))
vfloat16m4_t vfwcvt_f(vuint8m2_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vfwcvt_f_xu_v_m)))
vfloat16m4_t vfwcvt_f(vbool4_t, vfloat16m4_t, vuint8m2_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vfwcvt_f_xu_v)))
vfloat16m8_t vfwcvt_f(vuint8m4_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vfwcvt_f_xu_v_m)))
vfloat16m8_t vfwcvt_f(vbool2_t, vfloat16m8_t, vuint8m4_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vfwcvt_rtz_x_f_v)))
vint32mf2_t vfwcvt_rtz_x(vfloat16mf4_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vfwcvt_rtz_x_f_v_m)))
vint32mf2_t vfwcvt_rtz_x(vbool64_t, vint32mf2_t, vfloat16mf4_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vfwcvt_rtz_x_f_v)))
vint32m1_t vfwcvt_rtz_x(vfloat16mf2_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vfwcvt_rtz_x_f_v_m)))
vint32m1_t vfwcvt_rtz_x(vbool32_t, vint32m1_t, vfloat16mf2_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vfwcvt_rtz_x_f_v)))
vint32m2_t vfwcvt_rtz_x(vfloat16m1_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vfwcvt_rtz_x_f_v_m)))
vint32m2_t vfwcvt_rtz_x(vbool16_t, vint32m2_t, vfloat16m1_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vfwcvt_rtz_x_f_v)))
vint32m4_t vfwcvt_rtz_x(vfloat16m2_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vfwcvt_rtz_x_f_v_m)))
vint32m4_t vfwcvt_rtz_x(vbool8_t, vint32m4_t, vfloat16m2_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vfwcvt_rtz_x_f_v)))
vint32m8_t vfwcvt_rtz_x(vfloat16m4_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vfwcvt_rtz_x_f_v_m)))
vint32m8_t vfwcvt_rtz_x(vbool4_t, vint32m8_t, vfloat16m4_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vfwcvt_rtz_xu_f_v)))
vuint32mf2_t vfwcvt_rtz_xu(vfloat16mf4_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vfwcvt_rtz_xu_f_v_m)))
vuint32mf2_t vfwcvt_rtz_xu(vbool64_t, vuint32mf2_t, vfloat16mf4_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vfwcvt_rtz_xu_f_v)))
vuint32m1_t vfwcvt_rtz_xu(vfloat16mf2_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vfwcvt_rtz_xu_f_v_m)))
vuint32m1_t vfwcvt_rtz_xu(vbool32_t, vuint32m1_t, vfloat16mf2_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vfwcvt_rtz_xu_f_v)))
vuint32m2_t vfwcvt_rtz_xu(vfloat16m1_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vfwcvt_rtz_xu_f_v_m)))
vuint32m2_t vfwcvt_rtz_xu(vbool16_t, vuint32m2_t, vfloat16m1_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vfwcvt_rtz_xu_f_v)))
vuint32m4_t vfwcvt_rtz_xu(vfloat16m2_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vfwcvt_rtz_xu_f_v_m)))
vuint32m4_t vfwcvt_rtz_xu(vbool8_t, vuint32m4_t, vfloat16m2_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vfwcvt_rtz_xu_f_v)))
vuint32m8_t vfwcvt_rtz_xu(vfloat16m4_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vfwcvt_rtz_xu_f_v_m)))
vuint32m8_t vfwcvt_rtz_xu(vbool4_t, vuint32m8_t, vfloat16m4_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vfwcvt_x_f_v)))
vint32mf2_t vfwcvt_x(vfloat16mf4_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vfwcvt_x_f_v_m)))
vint32mf2_t vfwcvt_x(vbool64_t, vint32mf2_t, vfloat16mf4_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vfwcvt_x_f_v)))
vint32m1_t vfwcvt_x(vfloat16mf2_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vfwcvt_x_f_v_m)))
vint32m1_t vfwcvt_x(vbool32_t, vint32m1_t, vfloat16mf2_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vfwcvt_x_f_v)))
vint32m2_t vfwcvt_x(vfloat16m1_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vfwcvt_x_f_v_m)))
vint32m2_t vfwcvt_x(vbool16_t, vint32m2_t, vfloat16m1_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vfwcvt_x_f_v)))
vint32m4_t vfwcvt_x(vfloat16m2_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vfwcvt_x_f_v_m)))
vint32m4_t vfwcvt_x(vbool8_t, vint32m4_t, vfloat16m2_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vfwcvt_x_f_v)))
vint32m8_t vfwcvt_x(vfloat16m4_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vfwcvt_x_f_v_m)))
vint32m8_t vfwcvt_x(vbool4_t, vint32m8_t, vfloat16m4_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vfwcvt_xu_f_v)))
vuint32mf2_t vfwcvt_xu(vfloat16mf4_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vfwcvt_xu_f_v_m)))
vuint32mf2_t vfwcvt_xu(vbool64_t, vuint32mf2_t, vfloat16mf4_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vfwcvt_xu_f_v)))
vuint32m1_t vfwcvt_xu(vfloat16mf2_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vfwcvt_xu_f_v_m)))
vuint32m1_t vfwcvt_xu(vbool32_t, vuint32m1_t, vfloat16mf2_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vfwcvt_xu_f_v)))
vuint32m2_t vfwcvt_xu(vfloat16m1_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vfwcvt_xu_f_v_m)))
vuint32m2_t vfwcvt_xu(vbool16_t, vuint32m2_t, vfloat16m1_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vfwcvt_xu_f_v)))
vuint32m4_t vfwcvt_xu(vfloat16m2_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vfwcvt_xu_f_v_m)))
vuint32m4_t vfwcvt_xu(vbool8_t, vuint32m4_t, vfloat16m2_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vfwcvt_xu_f_v)))
vuint32m8_t vfwcvt_xu(vfloat16m4_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vfwcvt_xu_f_v_m)))
vuint32m8_t vfwcvt_xu(vbool4_t, vuint32m8_t, vfloat16m4_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vlmul_ext_v)))
vfloat16m1_t vlmul_ext_f16m1(vfloat16mf2_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vlmul_ext_v)))
vfloat16m1_t vlmul_ext_f16m1(vfloat16mf4_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vlmul_ext_v)))
vfloat16mf2_t vlmul_ext_f16mf2(vfloat16mf4_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vlmul_ext_v)))
vfloat16m2_t vlmul_ext_f16m2(vfloat16m1_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vlmul_ext_v)))
vfloat16m2_t vlmul_ext_f16m2(vfloat16mf2_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vlmul_ext_v)))
vfloat16m2_t vlmul_ext_f16m2(vfloat16mf4_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vlmul_ext_v)))
vfloat16m4_t vlmul_ext_f16m4(vfloat16m1_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vlmul_ext_v)))
vfloat16m4_t vlmul_ext_f16m4(vfloat16m2_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vlmul_ext_v)))
vfloat16m4_t vlmul_ext_f16m4(vfloat16mf2_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vlmul_ext_v)))
vfloat16m4_t vlmul_ext_f16m4(vfloat16mf4_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vlmul_ext_v)))
vfloat16m8_t vlmul_ext_f16m8(vfloat16m1_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vlmul_ext_v)))
vfloat16m8_t vlmul_ext_f16m8(vfloat16m2_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vlmul_ext_v)))
vfloat16m8_t vlmul_ext_f16m8(vfloat16m4_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vlmul_ext_v)))
vfloat16m8_t vlmul_ext_f16m8(vfloat16mf2_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vlmul_ext_v)))
vfloat16m8_t vlmul_ext_f16m8(vfloat16mf4_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vlmul_trunc_v)))
vfloat16mf2_t vlmul_trunc_f16mf2(vfloat16m1_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vlmul_trunc_v)))
vfloat16mf2_t vlmul_trunc_f16mf2(vfloat16m2_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vlmul_trunc_v)))
vfloat16mf2_t vlmul_trunc_f16mf2(vfloat16m4_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vlmul_trunc_v)))
vfloat16mf2_t vlmul_trunc_f16mf2(vfloat16m8_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vlmul_trunc_v)))
vfloat16mf4_t vlmul_trunc_f16mf4(vfloat16m1_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vlmul_trunc_v)))
vfloat16mf4_t vlmul_trunc_f16mf4(vfloat16m2_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vlmul_trunc_v)))
vfloat16mf4_t vlmul_trunc_f16mf4(vfloat16m4_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vlmul_trunc_v)))
vfloat16mf4_t vlmul_trunc_f16mf4(vfloat16m8_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vlmul_trunc_v)))
vfloat16mf4_t vlmul_trunc_f16mf4(vfloat16mf2_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vlmul_trunc_v)))
vfloat16m1_t vlmul_trunc_f16m1(vfloat16m2_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vlmul_trunc_v)))
vfloat16m1_t vlmul_trunc_f16m1(vfloat16m4_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vlmul_trunc_v)))
vfloat16m1_t vlmul_trunc_f16m1(vfloat16m8_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vlmul_trunc_v)))
vfloat16m2_t vlmul_trunc_f16m2(vfloat16m4_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vlmul_trunc_v)))
vfloat16m2_t vlmul_trunc_f16m2(vfloat16m8_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vlmul_trunc_v)))
vfloat16m4_t vlmul_trunc_f16m4(vfloat16m8_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vreinterpret_v)))
vfloat16m1_t vreinterpret_f16m1(vint16m1_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vreinterpret_v)))
vfloat16m2_t vreinterpret_f16m2(vint16m2_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vreinterpret_v)))
vfloat16m4_t vreinterpret_f16m4(vint16m4_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vreinterpret_v)))
vfloat16m8_t vreinterpret_f16m8(vint16m8_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vreinterpret_v)))
vfloat16mf2_t vreinterpret_f16mf2(vint16mf2_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vreinterpret_v)))
vfloat16mf4_t vreinterpret_f16mf4(vint16mf4_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vreinterpret_v)))
vfloat16m1_t vreinterpret_f16m1(vuint16m1_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vreinterpret_v)))
vfloat16m2_t vreinterpret_f16m2(vuint16m2_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vreinterpret_v)))
vfloat16m4_t vreinterpret_f16m4(vuint16m4_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vreinterpret_v)))
vfloat16m8_t vreinterpret_f16m8(vuint16m8_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vreinterpret_v)))
vfloat16mf2_t vreinterpret_f16mf2(vuint16mf2_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vreinterpret_v)))
vfloat16mf4_t vreinterpret_f16mf4(vuint16mf4_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vreinterpret_v)))
vint16m1_t vreinterpret_i16m1(vfloat16m1_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vreinterpret_v)))
vint16m2_t vreinterpret_i16m2(vfloat16m2_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vreinterpret_v)))
vint16m4_t vreinterpret_i16m4(vfloat16m4_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vreinterpret_v)))
vint16m8_t vreinterpret_i16m8(vfloat16m8_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vreinterpret_v)))
vint16mf2_t vreinterpret_i16mf2(vfloat16mf2_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vreinterpret_v)))
vint16mf4_t vreinterpret_i16mf4(vfloat16mf4_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vreinterpret_v)))
vuint16m1_t vreinterpret_u16m1(vfloat16m1_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vreinterpret_v)))
vuint16m2_t vreinterpret_u16m2(vfloat16m2_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vreinterpret_v)))
vuint16m4_t vreinterpret_u16m4(vfloat16m4_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vreinterpret_v)))
vuint16m8_t vreinterpret_u16m8(vfloat16m8_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vreinterpret_v)))
vuint16mf2_t vreinterpret_u16mf2(vfloat16mf2_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vreinterpret_v)))
vuint16mf4_t vreinterpret_u16mf4(vfloat16mf4_t);
#endif

#if (__riscv_v_elen >= 64)
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vadd_vv)))
vint64m1_t vadd(vint64m1_t, vint64m1_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vadd_vv_m)))
vint64m1_t vadd(vbool64_t, vint64m1_t, vint64m1_t, vint64m1_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vadd_vv)))
vint64m2_t vadd(vint64m2_t, vint64m2_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vadd_vv_m)))
vint64m2_t vadd(vbool32_t, vint64m2_t, vint64m2_t, vint64m2_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vadd_vv)))
vint64m4_t vadd(vint64m4_t, vint64m4_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vadd_vv_m)))
vint64m4_t vadd(vbool16_t, vint64m4_t, vint64m4_t, vint64m4_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vadd_vv)))
vint64m8_t vadd(vint64m8_t, vint64m8_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vadd_vv_m)))
vint64m8_t vadd(vbool8_t, vint64m8_t, vint64m8_t, vint64m8_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vwaddu_vv)))
vuint64m1_t vwaddu_vv(vuint32mf2_t, vuint32mf2_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vwaddu_vv_m)))
vuint64m1_t vwaddu_vv(vbool64_t, vuint64m1_t, vuint32mf2_t, vuint32mf2_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vwaddu_vv)))
vuint64m2_t vwaddu_vv(vuint32m1_t, vuint32m1_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vwaddu_vv_m)))
vuint64m2_t vwaddu_vv(vbool32_t, vuint64m2_t, vuint32m1_t, vuint32m1_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vwaddu_vv)))
vuint64m4_t vwaddu_vv(vuint32m2_t, vuint32m2_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vwaddu_vv_m)))
vuint64m4_t vwaddu_vv(vbool16_t, vuint64m4_t, vuint32m2_t, vuint32m2_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vwaddu_vv)))
vuint64m8_t vwaddu_vv(vuint32m4_t, vuint32m4_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vwaddu_vv_m)))
vuint64m8_t vwaddu_vv(vbool8_t, vuint64m8_t, vuint32m4_t, vuint32m4_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vloxseg3ei8_v)))
void vloxseg3ei8(vint64m1_t *, vint64m1_t *, vint64m1_t *, const int64_t *, vuint8mf8_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vloxseg3ei8_v_m)))
void vloxseg3ei8(vint64m1_t *, vint64m1_t *, vint64m1_t *, vbool64_t, vint64m1_t, vint64m1_t, vint64m1_t, const int64_t *, vuint8mf8_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vloxseg3ei8_v)))
void vloxseg3ei8(vint64m2_t *, vint64m2_t *, vint64m2_t *, const int64_t *, vuint8mf4_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vloxseg3ei8_v_m)))
void vloxseg3ei8(vint64m2_t *, vint64m2_t *, vint64m2_t *, vbool32_t, vint64m2_t, vint64m2_t, vint64m2_t, const int64_t *, vuint8mf4_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vloxseg3ei8_v)))
void vloxseg3ei8(vuint64m1_t *, vuint64m1_t *, vuint64m1_t *, const uint64_t *, vuint8mf8_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vloxseg3ei8_v_m)))
void vloxseg3ei8(vuint64m1_t *, vuint64m1_t *, vuint64m1_t *, vbool64_t, vuint64m1_t, vuint64m1_t, vuint64m1_t, const uint64_t *, vuint8mf8_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vloxseg3ei8_v)))
void vloxseg3ei8(vuint64m2_t *, vuint64m2_t *, vuint64m2_t *, const uint64_t *, vuint8mf4_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vloxseg3ei8_v_m)))
void vloxseg3ei8(vuint64m2_t *, vuint64m2_t *, vuint64m2_t *, vbool32_t, vuint64m2_t, vuint64m2_t, vuint64m2_t, const uint64_t *, vuint8mf4_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vloxseg4ei8_v)))
void vloxseg4ei8(vint64m1_t *, vint64m1_t *, vint64m1_t *, vint64m1_t *, const int64_t *, vuint8mf8_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vloxseg4ei8_v_m)))
void vloxseg4ei8(vint64m1_t *, vint64m1_t *, vint64m1_t *, vint64m1_t *, vbool64_t, vint64m1_t, vint64m1_t, vint64m1_t, vint64m1_t, const int64_t *, vuint8mf8_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vloxseg4ei8_v)))
void vloxseg4ei8(vint64m2_t *, vint64m2_t *, vint64m2_t *, vint64m2_t *, const int64_t *, vuint8mf4_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vloxseg4ei8_v_m)))
void vloxseg4ei8(vint64m2_t *, vint64m2_t *, vint64m2_t *, vint64m2_t *, vbool32_t, vint64m2_t, vint64m2_t, vint64m2_t, vint64m2_t, const int64_t *, vuint8mf4_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vloxseg4ei8_v)))
void vloxseg4ei8(vuint64m1_t *, vuint64m1_t *, vuint64m1_t *, vuint64m1_t *, const uint64_t *, vuint8mf8_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vloxseg4ei8_v_m)))
void vloxseg4ei8(vuint64m1_t *, vuint64m1_t *, vuint64m1_t *, vuint64m1_t *, vbool64_t, vuint64m1_t, vuint64m1_t, vuint64m1_t, vuint64m1_t, const uint64_t *, vuint8mf8_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vloxseg4ei8_v)))
void vloxseg4ei8(vuint64m2_t *, vuint64m2_t *, vuint64m2_t *, vuint64m2_t *, const uint64_t *, vuint8mf4_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vloxseg4ei8_v_m)))
void vloxseg4ei8(vuint64m2_t *, vuint64m2_t *, vuint64m2_t *, vuint64m2_t *, vbool32_t, vuint64m2_t, vuint64m2_t, vuint64m2_t, vuint64m2_t, const uint64_t *, vuint8mf4_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vloxseg5ei8_v)))
void vloxseg5ei8(vint64m1_t *, vint64m1_t *, vint64m1_t *, vint64m1_t *, vint64m1_t *, const int64_t *, vuint8mf8_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vloxseg5ei8_v_m)))
void vloxseg5ei8(vint64m1_t *, vint64m1_t *, vint64m1_t *, vint64m1_t *, vint64m1_t *, vbool64_t, vint64m1_t, vint64m1_t, vint64m1_t, vint64m1_t, vint64m1_t, const int64_t *, vuint8mf8_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vloxseg5ei8_v)))
void vloxseg5ei8(vuint64m1_t *, vuint64m1_t *, vuint64m1_t *, vuint64m1_t *, vuint64m1_t *, const uint64_t *, vuint8mf8_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vloxseg5ei8_v_m)))
void vloxseg5ei8(vuint64m1_t *, vuint64m1_t *, vuint64m1_t *, vuint64m1_t *, vuint64m1_t *, vbool64_t, vuint64m1_t, vuint64m1_t, vuint64m1_t, vuint64m1_t, vuint64m1_t, const uint64_t *, vuint8mf8_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vloxseg6ei8_v)))
void vloxseg6ei8(vint64m1_t *, vint64m1_t *, vint64m1_t *, vint64m1_t *, vint64m1_t *, vint64m1_t *, const int64_t *, vuint8mf8_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vloxseg6ei8_v_m)))
void vloxseg6ei8(vint64m1_t *, vint64m1_t *, vint64m1_t *, vint64m1_t *, vint64m1_t *, vint64m1_t *, vbool64_t, vint64m1_t, vint64m1_t, vint64m1_t, vint64m1_t, vint64m1_t, vint64m1_t, const int64_t *, vuint8mf8_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vloxseg6ei8_v)))
void vloxseg6ei8(vuint64m1_t *, vuint64m1_t *, vuint64m1_t *, vuint64m1_t *, vuint64m1_t *, vuint64m1_t *, const uint64_t *, vuint8mf8_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vloxseg6ei8_v_m)))
void vloxseg6ei8(vuint64m1_t *, vuint64m1_t *, vuint64m1_t *, vuint64m1_t *, vuint64m1_t *, vuint64m1_t *, vbool64_t, vuint64m1_t, vuint64m1_t, vuint64m1_t, vuint64m1_t, vuint64m1_t, vuint64m1_t, const uint64_t *, vuint8mf8_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vloxseg7ei8_v)))
void vloxseg7ei8(vint64m1_t *, vint64m1_t *, vint64m1_t *, vint64m1_t *, vint64m1_t *, vint64m1_t *, vint64m1_t *, const int64_t *, vuint8mf8_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vloxseg7ei8_v_m)))
void vloxseg7ei8(vint64m1_t *, vint64m1_t *, vint64m1_t *, vint64m1_t *, vint64m1_t *, vint64m1_t *, vint64m1_t *, vbool64_t, vint64m1_t, vint64m1_t, vint64m1_t, vint64m1_t, vint64m1_t, vint64m1_t, vint64m1_t, const int64_t *, vuint8mf8_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vloxseg7ei8_v)))
void vloxseg7ei8(vuint64m1_t *, vuint64m1_t *, vuint64m1_t *, vuint64m1_t *, vuint64m1_t *, vuint64m1_t *, vuint64m1_t *, const uint64_t *, vuint8mf8_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vloxseg7ei8_v_m)))
void vloxseg7ei8(vuint64m1_t *, vuint64m1_t *, vuint64m1_t *, vuint64m1_t *, vuint64m1_t *, vuint64m1_t *, vuint64m1_t *, vbool64_t, vuint64m1_t, vuint64m1_t, vuint64m1_t, vuint64m1_t, vuint64m1_t, vuint64m1_t, vuint64m1_t, const uint64_t *, vuint8mf8_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vlse64_v_m)))
vint64m1_t vlse64(vbool64_t, vint64m1_t, const int64_t *, ptrdiff_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vlse64_v_m)))
vint64m2_t vlse64(vbool32_t, vint64m2_t, const int64_t *, ptrdiff_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vlse64_v_m)))
vint64m4_t vlse64(vbool16_t, vint64m4_t, const int64_t *, ptrdiff_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vlse64_v_m)))
vint64m8_t vlse64(vbool8_t, vint64m8_t, const int64_t *, ptrdiff_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vloxseg8ei8_v)))
void vloxseg8ei8(vint64m1_t *, vint64m1_t *, vint64m1_t *, vint64m1_t *, vint64m1_t *, vint64m1_t *, vint64m1_t *, vint64m1_t *, const int64_t *, vuint8mf8_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vloxseg8ei8_v_m)))
void vloxseg8ei8(vint64m1_t *, vint64m1_t *, vint64m1_t *, vint64m1_t *, vint64m1_t *, vint64m1_t *, vint64m1_t *, vint64m1_t *, vbool64_t, vint64m1_t, vint64m1_t, vint64m1_t, vint64m1_t, vint64m1_t, vint64m1_t, vint64m1_t, vint64m1_t, const int64_t *, vuint8mf8_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vloxseg8ei8_v)))
void vloxseg8ei8(vuint64m1_t *, vuint64m1_t *, vuint64m1_t *, vuint64m1_t *, vuint64m1_t *, vuint64m1_t *, vuint64m1_t *, vuint64m1_t *, const uint64_t *, vuint8mf8_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vloxseg8ei8_v_m)))
void vloxseg8ei8(vuint64m1_t *, vuint64m1_t *, vuint64m1_t *, vuint64m1_t *, vuint64m1_t *, vuint64m1_t *, vuint64m1_t *, vuint64m1_t *, vbool64_t, vuint64m1_t, vuint64m1_t, vuint64m1_t, vuint64m1_t, vuint64m1_t, vuint64m1_t, vuint64m1_t, vuint64m1_t, const uint64_t *, vuint8mf8_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vloxseg2ei16_v)))
void vloxseg2ei16(vint64m1_t *, vint64m1_t *, const int64_t *, vuint16mf4_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vloxseg2ei16_v_m)))
void vloxseg2ei16(vint64m1_t *, vint64m1_t *, vbool64_t, vint64m1_t, vint64m1_t, const int64_t *, vuint16mf4_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vloxseg2ei16_v)))
void vloxseg2ei16(vint64m2_t *, vint64m2_t *, const int64_t *, vuint16mf2_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vloxseg2ei16_v_m)))
void vloxseg2ei16(vint64m2_t *, vint64m2_t *, vbool32_t, vint64m2_t, vint64m2_t, const int64_t *, vuint16mf2_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vloxseg2ei16_v)))
void vloxseg2ei16(vint64m4_t *, vint64m4_t *, const int64_t *, vuint16m1_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vloxseg2ei16_v_m)))
void vloxseg2ei16(vint64m4_t *, vint64m4_t *, vbool16_t, vint64m4_t, vint64m4_t, const int64_t *, vuint16m1_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vloxseg2ei16_v)))
void vloxseg2ei16(vuint64m1_t *, vuint64m1_t *, const uint64_t *, vuint16mf4_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vloxseg2ei16_v_m)))
void vloxseg2ei16(vuint64m1_t *, vuint64m1_t *, vbool64_t, vuint64m1_t, vuint64m1_t, const uint64_t *, vuint16mf4_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vloxseg2ei16_v)))
void vloxseg2ei16(vuint64m2_t *, vuint64m2_t *, const uint64_t *, vuint16mf2_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vloxseg2ei16_v_m)))
void vloxseg2ei16(vuint64m2_t *, vuint64m2_t *, vbool32_t, vuint64m2_t, vuint64m2_t, const uint64_t *, vuint16mf2_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vloxseg2ei16_v)))
void vloxseg2ei16(vuint64m4_t *, vuint64m4_t *, const uint64_t *, vuint16m1_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vloxseg2ei16_v_m)))
void vloxseg2ei16(vuint64m4_t *, vuint64m4_t *, vbool16_t, vuint64m4_t, vuint64m4_t, const uint64_t *, vuint16m1_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vloxseg3ei16_v)))
void vloxseg3ei16(vint64m1_t *, vint64m1_t *, vint64m1_t *, const int64_t *, vuint16mf4_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vloxseg3ei16_v_m)))
void vloxseg3ei16(vint64m1_t *, vint64m1_t *, vint64m1_t *, vbool64_t, vint64m1_t, vint64m1_t, vint64m1_t, const int64_t *, vuint16mf4_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vloxseg3ei16_v)))
void vloxseg3ei16(vint64m2_t *, vint64m2_t *, vint64m2_t *, const int64_t *, vuint16mf2_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vloxseg3ei16_v_m)))
void vloxseg3ei16(vint64m2_t *, vint64m2_t *, vint64m2_t *, vbool32_t, vint64m2_t, vint64m2_t, vint64m2_t, const int64_t *, vuint16mf2_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vloxseg3ei16_v)))
void vloxseg3ei16(vuint64m1_t *, vuint64m1_t *, vuint64m1_t *, const uint64_t *, vuint16mf4_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vloxseg3ei16_v_m)))
void vloxseg3ei16(vuint64m1_t *, vuint64m1_t *, vuint64m1_t *, vbool64_t, vuint64m1_t, vuint64m1_t, vuint64m1_t, const uint64_t *, vuint16mf4_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vloxseg3ei16_v)))
void vloxseg3ei16(vuint64m2_t *, vuint64m2_t *, vuint64m2_t *, const uint64_t *, vuint16mf2_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vloxseg3ei16_v_m)))
void vloxseg3ei16(vuint64m2_t *, vuint64m2_t *, vuint64m2_t *, vbool32_t, vuint64m2_t, vuint64m2_t, vuint64m2_t, const uint64_t *, vuint16mf2_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vloxseg4ei16_v)))
void vloxseg4ei16(vint64m1_t *, vint64m1_t *, vint64m1_t *, vint64m1_t *, const int64_t *, vuint16mf4_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vloxseg4ei16_v_m)))
void vloxseg4ei16(vint64m1_t *, vint64m1_t *, vint64m1_t *, vint64m1_t *, vbool64_t, vint64m1_t, vint64m1_t, vint64m1_t, vint64m1_t, const int64_t *, vuint16mf4_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vloxseg4ei16_v)))
void vloxseg4ei16(vint64m2_t *, vint64m2_t *, vint64m2_t *, vint64m2_t *, const int64_t *, vuint16mf2_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vloxseg4ei16_v_m)))
void vloxseg4ei16(vint64m2_t *, vint64m2_t *, vint64m2_t *, vint64m2_t *, vbool32_t, vint64m2_t, vint64m2_t, vint64m2_t, vint64m2_t, const int64_t *, vuint16mf2_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vloxseg4ei16_v)))
void vloxseg4ei16(vuint64m1_t *, vuint64m1_t *, vuint64m1_t *, vuint64m1_t *, const uint64_t *, vuint16mf4_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vloxseg4ei16_v_m)))
void vloxseg4ei16(vuint64m1_t *, vuint64m1_t *, vuint64m1_t *, vuint64m1_t *, vbool64_t, vuint64m1_t, vuint64m1_t, vuint64m1_t, vuint64m1_t, const uint64_t *, vuint16mf4_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vloxseg4ei16_v)))
void vloxseg4ei16(vuint64m2_t *, vuint64m2_t *, vuint64m2_t *, vuint64m2_t *, const uint64_t *, vuint16mf2_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vloxseg4ei16_v_m)))
void vloxseg4ei16(vuint64m2_t *, vuint64m2_t *, vuint64m2_t *, vuint64m2_t *, vbool32_t, vuint64m2_t, vuint64m2_t, vuint64m2_t, vuint64m2_t, const uint64_t *, vuint16mf2_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vloxseg5ei16_v)))
void vloxseg5ei16(vint64m1_t *, vint64m1_t *, vint64m1_t *, vint64m1_t *, vint64m1_t *, const int64_t *, vuint16mf4_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vloxseg5ei16_v_m)))
void vloxseg5ei16(vint64m1_t *, vint64m1_t *, vint64m1_t *, vint64m1_t *, vint64m1_t *, vbool64_t, vint64m1_t, vint64m1_t, vint64m1_t, vint64m1_t, vint64m1_t, const int64_t *, vuint16mf4_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vloxseg5ei16_v)))
void vloxseg5ei16(vuint64m1_t *, vuint64m1_t *, vuint64m1_t *, vuint64m1_t *, vuint64m1_t *, const uint64_t *, vuint16mf4_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vloxseg5ei16_v_m)))
void vloxseg5ei16(vuint64m1_t *, vuint64m1_t *, vuint64m1_t *, vuint64m1_t *, vuint64m1_t *, vbool64_t, vuint64m1_t, vuint64m1_t, vuint64m1_t, vuint64m1_t, vuint64m1_t, const uint64_t *, vuint16mf4_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vlse64_v_m)))
vuint64m1_t vlse64(vbool64_t, vuint64m1_t, const uint64_t *, ptrdiff_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vlse64_v_m)))
vuint64m2_t vlse64(vbool32_t, vuint64m2_t, const uint64_t *, ptrdiff_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vlse64_v_m)))
vuint64m4_t vlse64(vbool16_t, vuint64m4_t, const uint64_t *, ptrdiff_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vlse64_v_m)))
vuint64m8_t vlse64(vbool8_t, vuint64m8_t, const uint64_t *, ptrdiff_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vloxseg6ei16_v)))
void vloxseg6ei16(vint64m1_t *, vint64m1_t *, vint64m1_t *, vint64m1_t *, vint64m1_t *, vint64m1_t *, const int64_t *, vuint16mf4_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vloxseg6ei16_v_m)))
void vloxseg6ei16(vint64m1_t *, vint64m1_t *, vint64m1_t *, vint64m1_t *, vint64m1_t *, vint64m1_t *, vbool64_t, vint64m1_t, vint64m1_t, vint64m1_t, vint64m1_t, vint64m1_t, vint64m1_t, const int64_t *, vuint16mf4_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vloxseg6ei16_v)))
void vloxseg6ei16(vuint64m1_t *, vuint64m1_t *, vuint64m1_t *, vuint64m1_t *, vuint64m1_t *, vuint64m1_t *, const uint64_t *, vuint16mf4_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vloxseg6ei16_v_m)))
void vloxseg6ei16(vuint64m1_t *, vuint64m1_t *, vuint64m1_t *, vuint64m1_t *, vuint64m1_t *, vuint64m1_t *, vbool64_t, vuint64m1_t, vuint64m1_t, vuint64m1_t, vuint64m1_t, vuint64m1_t, vuint64m1_t, const uint64_t *, vuint16mf4_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vloxseg7ei16_v)))
void vloxseg7ei16(vint64m1_t *, vint64m1_t *, vint64m1_t *, vint64m1_t *, vint64m1_t *, vint64m1_t *, vint64m1_t *, const int64_t *, vuint16mf4_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vloxseg7ei16_v_m)))
void vloxseg7ei16(vint64m1_t *, vint64m1_t *, vint64m1_t *, vint64m1_t *, vint64m1_t *, vint64m1_t *, vint64m1_t *, vbool64_t, vint64m1_t, vint64m1_t, vint64m1_t, vint64m1_t, vint64m1_t, vint64m1_t, vint64m1_t, const int64_t *, vuint16mf4_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vloxseg7ei16_v)))
void vloxseg7ei16(vuint64m1_t *, vuint64m1_t *, vuint64m1_t *, vuint64m1_t *, vuint64m1_t *, vuint64m1_t *, vuint64m1_t *, const uint64_t *, vuint16mf4_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vloxseg7ei16_v_m)))
void vloxseg7ei16(vuint64m1_t *, vuint64m1_t *, vuint64m1_t *, vuint64m1_t *, vuint64m1_t *, vuint64m1_t *, vuint64m1_t *, vbool64_t, vuint64m1_t, vuint64m1_t, vuint64m1_t, vuint64m1_t, vuint64m1_t, vuint64m1_t, vuint64m1_t, const uint64_t *, vuint16mf4_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vloxseg8ei16_v)))
void vloxseg8ei16(vint64m1_t *, vint64m1_t *, vint64m1_t *, vint64m1_t *, vint64m1_t *, vint64m1_t *, vint64m1_t *, vint64m1_t *, const int64_t *, vuint16mf4_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vloxseg8ei16_v_m)))
void vloxseg8ei16(vint64m1_t *, vint64m1_t *, vint64m1_t *, vint64m1_t *, vint64m1_t *, vint64m1_t *, vint64m1_t *, vint64m1_t *, vbool64_t, vint64m1_t, vint64m1_t, vint64m1_t, vint64m1_t, vint64m1_t, vint64m1_t, vint64m1_t, vint64m1_t, const int64_t *, vuint16mf4_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vloxseg8ei16_v)))
void vloxseg8ei16(vuint64m1_t *, vuint64m1_t *, vuint64m1_t *, vuint64m1_t *, vuint64m1_t *, vuint64m1_t *, vuint64m1_t *, vuint64m1_t *, const uint64_t *, vuint16mf4_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vloxseg8ei16_v_m)))
void vloxseg8ei16(vuint64m1_t *, vuint64m1_t *, vuint64m1_t *, vuint64m1_t *, vuint64m1_t *, vuint64m1_t *, vuint64m1_t *, vuint64m1_t *, vbool64_t, vuint64m1_t, vuint64m1_t, vuint64m1_t, vuint64m1_t, vuint64m1_t, vuint64m1_t, vuint64m1_t, vuint64m1_t, const uint64_t *, vuint16mf4_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vloxseg2ei32_v)))
void vloxseg2ei32(vint64m1_t *, vint64m1_t *, const int64_t *, vuint32mf2_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vloxseg2ei32_v_m)))
void vloxseg2ei32(vint64m1_t *, vint64m1_t *, vbool64_t, vint64m1_t, vint64m1_t, const int64_t *, vuint32mf2_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vloxseg2ei32_v)))
void vloxseg2ei32(vint64m2_t *, vint64m2_t *, const int64_t *, vuint32m1_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vloxseg2ei32_v_m)))
void vloxseg2ei32(vint64m2_t *, vint64m2_t *, vbool32_t, vint64m2_t, vint64m2_t, const int64_t *, vuint32m1_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vloxseg2ei32_v)))
void vloxseg2ei32(vint64m4_t *, vint64m4_t *, const int64_t *, vuint32m2_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vloxseg2ei32_v_m)))
void vloxseg2ei32(vint64m4_t *, vint64m4_t *, vbool16_t, vint64m4_t, vint64m4_t, const int64_t *, vuint32m2_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vloxseg2ei32_v)))
void vloxseg2ei32(vuint64m1_t *, vuint64m1_t *, const uint64_t *, vuint32mf2_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vloxseg2ei32_v_m)))
void vloxseg2ei32(vuint64m1_t *, vuint64m1_t *, vbool64_t, vuint64m1_t, vuint64m1_t, const uint64_t *, vuint32mf2_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vloxseg2ei32_v)))
void vloxseg2ei32(vuint64m2_t *, vuint64m2_t *, const uint64_t *, vuint32m1_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vloxseg2ei32_v_m)))
void vloxseg2ei32(vuint64m2_t *, vuint64m2_t *, vbool32_t, vuint64m2_t, vuint64m2_t, const uint64_t *, vuint32m1_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vloxseg2ei32_v)))
void vloxseg2ei32(vuint64m4_t *, vuint64m4_t *, const uint64_t *, vuint32m2_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vloxseg2ei32_v_m)))
void vloxseg2ei32(vuint64m4_t *, vuint64m4_t *, vbool16_t, vuint64m4_t, vuint64m4_t, const uint64_t *, vuint32m2_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vloxseg3ei32_v)))
void vloxseg3ei32(vint64m1_t *, vint64m1_t *, vint64m1_t *, const int64_t *, vuint32mf2_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vloxseg3ei32_v_m)))
void vloxseg3ei32(vint64m1_t *, vint64m1_t *, vint64m1_t *, vbool64_t, vint64m1_t, vint64m1_t, vint64m1_t, const int64_t *, vuint32mf2_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vloxseg3ei32_v)))
void vloxseg3ei32(vint64m2_t *, vint64m2_t *, vint64m2_t *, const int64_t *, vuint32m1_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vloxseg3ei32_v_m)))
void vloxseg3ei32(vint64m2_t *, vint64m2_t *, vint64m2_t *, vbool32_t, vint64m2_t, vint64m2_t, vint64m2_t, const int64_t *, vuint32m1_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vloxseg3ei32_v)))
void vloxseg3ei32(vuint64m1_t *, vuint64m1_t *, vuint64m1_t *, const uint64_t *, vuint32mf2_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vloxseg3ei32_v_m)))
void vloxseg3ei32(vuint64m1_t *, vuint64m1_t *, vuint64m1_t *, vbool64_t, vuint64m1_t, vuint64m1_t, vuint64m1_t, const uint64_t *, vuint32mf2_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vloxseg3ei32_v)))
void vloxseg3ei32(vuint64m2_t *, vuint64m2_t *, vuint64m2_t *, const uint64_t *, vuint32m1_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vloxseg3ei32_v_m)))
void vloxseg3ei32(vuint64m2_t *, vuint64m2_t *, vuint64m2_t *, vbool32_t, vuint64m2_t, vuint64m2_t, vuint64m2_t, const uint64_t *, vuint32m1_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vloxseg4ei32_v)))
void vloxseg4ei32(vint64m1_t *, vint64m1_t *, vint64m1_t *, vint64m1_t *, const int64_t *, vuint32mf2_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vloxseg4ei32_v_m)))
void vloxseg4ei32(vint64m1_t *, vint64m1_t *, vint64m1_t *, vint64m1_t *, vbool64_t, vint64m1_t, vint64m1_t, vint64m1_t, vint64m1_t, const int64_t *, vuint32mf2_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vloxseg4ei32_v)))
void vloxseg4ei32(vint64m2_t *, vint64m2_t *, vint64m2_t *, vint64m2_t *, const int64_t *, vuint32m1_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vloxseg4ei32_v_m)))
void vloxseg4ei32(vint64m2_t *, vint64m2_t *, vint64m2_t *, vint64m2_t *, vbool32_t, vint64m2_t, vint64m2_t, vint64m2_t, vint64m2_t, const int64_t *, vuint32m1_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vloxseg4ei32_v)))
void vloxseg4ei32(vuint64m1_t *, vuint64m1_t *, vuint64m1_t *, vuint64m1_t *, const uint64_t *, vuint32mf2_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vloxseg4ei32_v_m)))
void vloxseg4ei32(vuint64m1_t *, vuint64m1_t *, vuint64m1_t *, vuint64m1_t *, vbool64_t, vuint64m1_t, vuint64m1_t, vuint64m1_t, vuint64m1_t, const uint64_t *, vuint32mf2_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vloxseg4ei32_v)))
void vloxseg4ei32(vuint64m2_t *, vuint64m2_t *, vuint64m2_t *, vuint64m2_t *, const uint64_t *, vuint32m1_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vloxseg4ei32_v_m)))
void vloxseg4ei32(vuint64m2_t *, vuint64m2_t *, vuint64m2_t *, vuint64m2_t *, vbool32_t, vuint64m2_t, vuint64m2_t, vuint64m2_t, vuint64m2_t, const uint64_t *, vuint32m1_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vloxseg5ei32_v)))
void vloxseg5ei32(vint64m1_t *, vint64m1_t *, vint64m1_t *, vint64m1_t *, vint64m1_t *, const int64_t *, vuint32mf2_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vloxseg5ei32_v_m)))
void vloxseg5ei32(vint64m1_t *, vint64m1_t *, vint64m1_t *, vint64m1_t *, vint64m1_t *, vbool64_t, vint64m1_t, vint64m1_t, vint64m1_t, vint64m1_t, vint64m1_t, const int64_t *, vuint32mf2_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vloxseg5ei32_v)))
void vloxseg5ei32(vuint64m1_t *, vuint64m1_t *, vuint64m1_t *, vuint64m1_t *, vuint64m1_t *, const uint64_t *, vuint32mf2_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vloxseg5ei32_v_m)))
void vloxseg5ei32(vuint64m1_t *, vuint64m1_t *, vuint64m1_t *, vuint64m1_t *, vuint64m1_t *, vbool64_t, vuint64m1_t, vuint64m1_t, vuint64m1_t, vuint64m1_t, vuint64m1_t, const uint64_t *, vuint32mf2_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vloxseg6ei32_v)))
void vloxseg6ei32(vint64m1_t *, vint64m1_t *, vint64m1_t *, vint64m1_t *, vint64m1_t *, vint64m1_t *, const int64_t *, vuint32mf2_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vloxseg6ei32_v_m)))
void vloxseg6ei32(vint64m1_t *, vint64m1_t *, vint64m1_t *, vint64m1_t *, vint64m1_t *, vint64m1_t *, vbool64_t, vint64m1_t, vint64m1_t, vint64m1_t, vint64m1_t, vint64m1_t, vint64m1_t, const int64_t *, vuint32mf2_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vloxseg6ei32_v)))
void vloxseg6ei32(vuint64m1_t *, vuint64m1_t *, vuint64m1_t *, vuint64m1_t *, vuint64m1_t *, vuint64m1_t *, const uint64_t *, vuint32mf2_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vloxseg6ei32_v_m)))
void vloxseg6ei32(vuint64m1_t *, vuint64m1_t *, vuint64m1_t *, vuint64m1_t *, vuint64m1_t *, vuint64m1_t *, vbool64_t, vuint64m1_t, vuint64m1_t, vuint64m1_t, vuint64m1_t, vuint64m1_t, vuint64m1_t, const uint64_t *, vuint32mf2_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vloxseg7ei32_v)))
void vloxseg7ei32(vint64m1_t *, vint64m1_t *, vint64m1_t *, vint64m1_t *, vint64m1_t *, vint64m1_t *, vint64m1_t *, const int64_t *, vuint32mf2_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vloxseg7ei32_v_m)))
void vloxseg7ei32(vint64m1_t *, vint64m1_t *, vint64m1_t *, vint64m1_t *, vint64m1_t *, vint64m1_t *, vint64m1_t *, vbool64_t, vint64m1_t, vint64m1_t, vint64m1_t, vint64m1_t, vint64m1_t, vint64m1_t, vint64m1_t, const int64_t *, vuint32mf2_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vloxseg7ei32_v)))
void vloxseg7ei32(vuint64m1_t *, vuint64m1_t *, vuint64m1_t *, vuint64m1_t *, vuint64m1_t *, vuint64m1_t *, vuint64m1_t *, const uint64_t *, vuint32mf2_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vloxseg7ei32_v_m)))
void vloxseg7ei32(vuint64m1_t *, vuint64m1_t *, vuint64m1_t *, vuint64m1_t *, vuint64m1_t *, vuint64m1_t *, vuint64m1_t *, vbool64_t, vuint64m1_t, vuint64m1_t, vuint64m1_t, vuint64m1_t, vuint64m1_t, vuint64m1_t, vuint64m1_t, const uint64_t *, vuint32mf2_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vloxseg8ei32_v)))
void vloxseg8ei32(vint64m1_t *, vint64m1_t *, vint64m1_t *, vint64m1_t *, vint64m1_t *, vint64m1_t *, vint64m1_t *, vint64m1_t *, const int64_t *, vuint32mf2_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vloxseg8ei32_v_m)))
void vloxseg8ei32(vint64m1_t *, vint64m1_t *, vint64m1_t *, vint64m1_t *, vint64m1_t *, vint64m1_t *, vint64m1_t *, vint64m1_t *, vbool64_t, vint64m1_t, vint64m1_t, vint64m1_t, vint64m1_t, vint64m1_t, vint64m1_t, vint64m1_t, vint64m1_t, const int64_t *, vuint32mf2_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vloxseg8ei32_v)))
void vloxseg8ei32(vuint64m1_t *, vuint64m1_t *, vuint64m1_t *, vuint64m1_t *, vuint64m1_t *, vuint64m1_t *, vuint64m1_t *, vuint64m1_t *, const uint64_t *, vuint32mf2_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vloxseg8ei32_v_m)))
void vloxseg8ei32(vuint64m1_t *, vuint64m1_t *, vuint64m1_t *, vuint64m1_t *, vuint64m1_t *, vuint64m1_t *, vuint64m1_t *, vuint64m1_t *, vbool64_t, vuint64m1_t, vuint64m1_t, vuint64m1_t, vuint64m1_t, vuint64m1_t, vuint64m1_t, vuint64m1_t, vuint64m1_t, const uint64_t *, vuint32mf2_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vloxseg2ei64_v)))
void vloxseg2ei64(vint64m1_t *, vint64m1_t *, const int64_t *, vuint64m1_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vloxseg2ei64_v_m)))
void vloxseg2ei64(vint64m1_t *, vint64m1_t *, vbool64_t, vint64m1_t, vint64m1_t, const int64_t *, vuint64m1_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vloxseg2ei64_v)))
void vloxseg2ei64(vint64m2_t *, vint64m2_t *, const int64_t *, vuint64m2_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vloxseg2ei64_v_m)))
void vloxseg2ei64(vint64m2_t *, vint64m2_t *, vbool32_t, vint64m2_t, vint64m2_t, const int64_t *, vuint64m2_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vloxseg2ei64_v)))
void vloxseg2ei64(vint64m4_t *, vint64m4_t *, const int64_t *, vuint64m4_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vloxseg2ei64_v_m)))
void vloxseg2ei64(vint64m4_t *, vint64m4_t *, vbool16_t, vint64m4_t, vint64m4_t, const int64_t *, vuint64m4_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vloxseg2ei64_v)))
void vloxseg2ei64(vuint64m1_t *, vuint64m1_t *, const uint64_t *, vuint64m1_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vloxseg2ei64_v_m)))
void vloxseg2ei64(vuint64m1_t *, vuint64m1_t *, vbool64_t, vuint64m1_t, vuint64m1_t, const uint64_t *, vuint64m1_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vloxseg2ei64_v)))
void vloxseg2ei64(vuint64m2_t *, vuint64m2_t *, const uint64_t *, vuint64m2_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vloxseg2ei64_v_m)))
void vloxseg2ei64(vuint64m2_t *, vuint64m2_t *, vbool32_t, vuint64m2_t, vuint64m2_t, const uint64_t *, vuint64m2_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vloxseg2ei64_v)))
void vloxseg2ei64(vuint64m4_t *, vuint64m4_t *, const uint64_t *, vuint64m4_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vloxseg2ei64_v_m)))
void vloxseg2ei64(vuint64m4_t *, vuint64m4_t *, vbool16_t, vuint64m4_t, vuint64m4_t, const uint64_t *, vuint64m4_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vloxseg3ei64_v)))
void vloxseg3ei64(vint64m1_t *, vint64m1_t *, vint64m1_t *, const int64_t *, vuint64m1_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vloxseg3ei64_v_m)))
void vloxseg3ei64(vint64m1_t *, vint64m1_t *, vint64m1_t *, vbool64_t, vint64m1_t, vint64m1_t, vint64m1_t, const int64_t *, vuint64m1_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vloxseg3ei64_v)))
void vloxseg3ei64(vint64m2_t *, vint64m2_t *, vint64m2_t *, const int64_t *, vuint64m2_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vloxseg3ei64_v_m)))
void vloxseg3ei64(vint64m2_t *, vint64m2_t *, vint64m2_t *, vbool32_t, vint64m2_t, vint64m2_t, vint64m2_t, const int64_t *, vuint64m2_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vloxseg3ei64_v)))
void vloxseg3ei64(vuint64m1_t *, vuint64m1_t *, vuint64m1_t *, const uint64_t *, vuint64m1_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vloxseg3ei64_v_m)))
void vloxseg3ei64(vuint64m1_t *, vuint64m1_t *, vuint64m1_t *, vbool64_t, vuint64m1_t, vuint64m1_t, vuint64m1_t, const uint64_t *, vuint64m1_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vloxseg3ei64_v)))
void vloxseg3ei64(vuint64m2_t *, vuint64m2_t *, vuint64m2_t *, const uint64_t *, vuint64m2_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vloxseg3ei64_v_m)))
void vloxseg3ei64(vuint64m2_t *, vuint64m2_t *, vuint64m2_t *, vbool32_t, vuint64m2_t, vuint64m2_t, vuint64m2_t, const uint64_t *, vuint64m2_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vloxseg4ei64_v)))
void vloxseg4ei64(vint64m1_t *, vint64m1_t *, vint64m1_t *, vint64m1_t *, const int64_t *, vuint64m1_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vloxseg4ei64_v_m)))
void vloxseg4ei64(vint64m1_t *, vint64m1_t *, vint64m1_t *, vint64m1_t *, vbool64_t, vint64m1_t, vint64m1_t, vint64m1_t, vint64m1_t, const int64_t *, vuint64m1_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vloxseg4ei64_v)))
void vloxseg4ei64(vint64m2_t *, vint64m2_t *, vint64m2_t *, vint64m2_t *, const int64_t *, vuint64m2_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vloxseg4ei64_v_m)))
void vloxseg4ei64(vint64m2_t *, vint64m2_t *, vint64m2_t *, vint64m2_t *, vbool32_t, vint64m2_t, vint64m2_t, vint64m2_t, vint64m2_t, const int64_t *, vuint64m2_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vloxseg4ei64_v)))
void vloxseg4ei64(vuint64m1_t *, vuint64m1_t *, vuint64m1_t *, vuint64m1_t *, const uint64_t *, vuint64m1_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vloxseg4ei64_v_m)))
void vloxseg4ei64(vuint64m1_t *, vuint64m1_t *, vuint64m1_t *, vuint64m1_t *, vbool64_t, vuint64m1_t, vuint64m1_t, vuint64m1_t, vuint64m1_t, const uint64_t *, vuint64m1_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vloxseg4ei64_v)))
void vloxseg4ei64(vuint64m2_t *, vuint64m2_t *, vuint64m2_t *, vuint64m2_t *, const uint64_t *, vuint64m2_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vloxseg4ei64_v_m)))
void vloxseg4ei64(vuint64m2_t *, vuint64m2_t *, vuint64m2_t *, vuint64m2_t *, vbool32_t, vuint64m2_t, vuint64m2_t, vuint64m2_t, vuint64m2_t, const uint64_t *, vuint64m2_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vloxseg5ei64_v)))
void vloxseg5ei64(vint64m1_t *, vint64m1_t *, vint64m1_t *, vint64m1_t *, vint64m1_t *, const int64_t *, vuint64m1_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vloxseg5ei64_v_m)))
void vloxseg5ei64(vint64m1_t *, vint64m1_t *, vint64m1_t *, vint64m1_t *, vint64m1_t *, vbool64_t, vint64m1_t, vint64m1_t, vint64m1_t, vint64m1_t, vint64m1_t, const int64_t *, vuint64m1_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vloxseg5ei64_v)))
void vloxseg5ei64(vuint64m1_t *, vuint64m1_t *, vuint64m1_t *, vuint64m1_t *, vuint64m1_t *, const uint64_t *, vuint64m1_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vloxseg5ei64_v_m)))
void vloxseg5ei64(vuint64m1_t *, vuint64m1_t *, vuint64m1_t *, vuint64m1_t *, vuint64m1_t *, vbool64_t, vuint64m1_t, vuint64m1_t, vuint64m1_t, vuint64m1_t, vuint64m1_t, const uint64_t *, vuint64m1_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vloxseg6ei64_v)))
void vloxseg6ei64(vint64m1_t *, vint64m1_t *, vint64m1_t *, vint64m1_t *, vint64m1_t *, vint64m1_t *, const int64_t *, vuint64m1_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vloxseg6ei64_v_m)))
void vloxseg6ei64(vint64m1_t *, vint64m1_t *, vint64m1_t *, vint64m1_t *, vint64m1_t *, vint64m1_t *, vbool64_t, vint64m1_t, vint64m1_t, vint64m1_t, vint64m1_t, vint64m1_t, vint64m1_t, const int64_t *, vuint64m1_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vloxseg6ei64_v)))
void vloxseg6ei64(vuint64m1_t *, vuint64m1_t *, vuint64m1_t *, vuint64m1_t *, vuint64m1_t *, vuint64m1_t *, const uint64_t *, vuint64m1_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vloxseg6ei64_v_m)))
void vloxseg6ei64(vuint64m1_t *, vuint64m1_t *, vuint64m1_t *, vuint64m1_t *, vuint64m1_t *, vuint64m1_t *, vbool64_t, vuint64m1_t, vuint64m1_t, vuint64m1_t, vuint64m1_t, vuint64m1_t, vuint64m1_t, const uint64_t *, vuint64m1_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vloxseg7ei64_v)))
void vloxseg7ei64(vint64m1_t *, vint64m1_t *, vint64m1_t *, vint64m1_t *, vint64m1_t *, vint64m1_t *, vint64m1_t *, const int64_t *, vuint64m1_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vloxseg7ei64_v_m)))
void vloxseg7ei64(vint64m1_t *, vint64m1_t *, vint64m1_t *, vint64m1_t *, vint64m1_t *, vint64m1_t *, vint64m1_t *, vbool64_t, vint64m1_t, vint64m1_t, vint64m1_t, vint64m1_t, vint64m1_t, vint64m1_t, vint64m1_t, const int64_t *, vuint64m1_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vloxseg7ei64_v)))
void vloxseg7ei64(vuint64m1_t *, vuint64m1_t *, vuint64m1_t *, vuint64m1_t *, vuint64m1_t *, vuint64m1_t *, vuint64m1_t *, const uint64_t *, vuint64m1_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vloxseg7ei64_v_m)))
void vloxseg7ei64(vuint64m1_t *, vuint64m1_t *, vuint64m1_t *, vuint64m1_t *, vuint64m1_t *, vuint64m1_t *, vuint64m1_t *, vbool64_t, vuint64m1_t, vuint64m1_t, vuint64m1_t, vuint64m1_t, vuint64m1_t, vuint64m1_t, vuint64m1_t, const uint64_t *, vuint64m1_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vloxseg8ei64_v)))
void vloxseg8ei64(vint64m1_t *, vint64m1_t *, vint64m1_t *, vint64m1_t *, vint64m1_t *, vint64m1_t *, vint64m1_t *, vint64m1_t *, const int64_t *, vuint64m1_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vloxseg8ei64_v_m)))
void vloxseg8ei64(vint64m1_t *, vint64m1_t *, vint64m1_t *, vint64m1_t *, vint64m1_t *, vint64m1_t *, vint64m1_t *, vint64m1_t *, vbool64_t, vint64m1_t, vint64m1_t, vint64m1_t, vint64m1_t, vint64m1_t, vint64m1_t, vint64m1_t, vint64m1_t, const int64_t *, vuint64m1_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vloxseg8ei64_v)))
void vloxseg8ei64(vuint64m1_t *, vuint64m1_t *, vuint64m1_t *, vuint64m1_t *, vuint64m1_t *, vuint64m1_t *, vuint64m1_t *, vuint64m1_t *, const uint64_t *, vuint64m1_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vloxseg8ei64_v_m)))
void vloxseg8ei64(vuint64m1_t *, vuint64m1_t *, vuint64m1_t *, vuint64m1_t *, vuint64m1_t *, vuint64m1_t *, vuint64m1_t *, vuint64m1_t *, vbool64_t, vuint64m1_t, vuint64m1_t, vuint64m1_t, vuint64m1_t, vuint64m1_t, vuint64m1_t, vuint64m1_t, vuint64m1_t, const uint64_t *, vuint64m1_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vsse64_v)))
void vsse64(int64_t *, ptrdiff_t, vint64m1_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vsse64_v_m)))
void vsse64(vbool64_t, int64_t *, ptrdiff_t, vint64m1_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vsse64_v)))
void vsse64(int64_t *, ptrdiff_t, vint64m2_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vsse64_v_m)))
void vsse64(vbool32_t, int64_t *, ptrdiff_t, vint64m2_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vsse64_v)))
void vsse64(int64_t *, ptrdiff_t, vint64m4_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vsse64_v_m)))
void vsse64(vbool16_t, int64_t *, ptrdiff_t, vint64m4_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vsse64_v)))
void vsse64(int64_t *, ptrdiff_t, vint64m8_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vsse64_v_m)))
void vsse64(vbool8_t, int64_t *, ptrdiff_t, vint64m8_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vsse64_v)))
void vsse64(uint64_t *, ptrdiff_t, vuint64m1_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vsse64_v_m)))
void vsse64(vbool64_t, uint64_t *, ptrdiff_t, vuint64m1_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vsse64_v)))
void vsse64(uint64_t *, ptrdiff_t, vuint64m2_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vsse64_v_m)))
void vsse64(vbool32_t, uint64_t *, ptrdiff_t, vuint64m2_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vsse64_v)))
void vsse64(uint64_t *, ptrdiff_t, vuint64m4_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vsse64_v_m)))
void vsse64(vbool16_t, uint64_t *, ptrdiff_t, vuint64m4_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vsse64_v)))
void vsse64(uint64_t *, ptrdiff_t, vuint64m8_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vsse64_v_m)))
void vsse64(vbool8_t, uint64_t *, ptrdiff_t, vuint64m8_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vsseg2e64_v)))
void vsseg2e64(int64_t *, vint64m1_t, vint64m1_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vsseg2e64_v_m)))
void vsseg2e64(vbool64_t, int64_t *, vint64m1_t, vint64m1_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vsseg2e64_v)))
void vsseg2e64(int64_t *, vint64m2_t, vint64m2_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vsseg2e64_v_m)))
void vsseg2e64(vbool32_t, int64_t *, vint64m2_t, vint64m2_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vsseg2e64_v)))
void vsseg2e64(int64_t *, vint64m4_t, vint64m4_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vsseg2e64_v_m)))
void vsseg2e64(vbool16_t, int64_t *, vint64m4_t, vint64m4_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vsseg2e64_v)))
void vsseg2e64(uint64_t *, vuint64m1_t, vuint64m1_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vsseg2e64_v_m)))
void vsseg2e64(vbool64_t, uint64_t *, vuint64m1_t, vuint64m1_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vsseg2e64_v)))
void vsseg2e64(uint64_t *, vuint64m2_t, vuint64m2_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vsseg2e64_v_m)))
void vsseg2e64(vbool32_t, uint64_t *, vuint64m2_t, vuint64m2_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vsseg2e64_v)))
void vsseg2e64(uint64_t *, vuint64m4_t, vuint64m4_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vsseg2e64_v_m)))
void vsseg2e64(vbool16_t, uint64_t *, vuint64m4_t, vuint64m4_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vsseg3e64_v)))
void vsseg3e64(int64_t *, vint64m1_t, vint64m1_t, vint64m1_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vsseg3e64_v_m)))
void vsseg3e64(vbool64_t, int64_t *, vint64m1_t, vint64m1_t, vint64m1_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vsseg3e64_v)))
void vsseg3e64(int64_t *, vint64m2_t, vint64m2_t, vint64m2_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vsseg3e64_v_m)))
void vsseg3e64(vbool32_t, int64_t *, vint64m2_t, vint64m2_t, vint64m2_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vsseg3e64_v)))
void vsseg3e64(uint64_t *, vuint64m1_t, vuint64m1_t, vuint64m1_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vsseg3e64_v_m)))
void vsseg3e64(vbool64_t, uint64_t *, vuint64m1_t, vuint64m1_t, vuint64m1_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vsseg3e64_v)))
void vsseg3e64(uint64_t *, vuint64m2_t, vuint64m2_t, vuint64m2_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vsseg3e64_v_m)))
void vsseg3e64(vbool32_t, uint64_t *, vuint64m2_t, vuint64m2_t, vuint64m2_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vsseg4e64_v)))
void vsseg4e64(int64_t *, vint64m1_t, vint64m1_t, vint64m1_t, vint64m1_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vsseg4e64_v_m)))
void vsseg4e64(vbool64_t, int64_t *, vint64m1_t, vint64m1_t, vint64m1_t, vint64m1_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vsseg4e64_v)))
void vsseg4e64(int64_t *, vint64m2_t, vint64m2_t, vint64m2_t, vint64m2_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vsseg4e64_v_m)))
void vsseg4e64(vbool32_t, int64_t *, vint64m2_t, vint64m2_t, vint64m2_t, vint64m2_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vsseg4e64_v)))
void vsseg4e64(uint64_t *, vuint64m1_t, vuint64m1_t, vuint64m1_t, vuint64m1_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vsseg4e64_v_m)))
void vsseg4e64(vbool64_t, uint64_t *, vuint64m1_t, vuint64m1_t, vuint64m1_t, vuint64m1_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vsseg4e64_v)))
void vsseg4e64(uint64_t *, vuint64m2_t, vuint64m2_t, vuint64m2_t, vuint64m2_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vsseg4e64_v_m)))
void vsseg4e64(vbool32_t, uint64_t *, vuint64m2_t, vuint64m2_t, vuint64m2_t, vuint64m2_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vsseg5e64_v)))
void vsseg5e64(int64_t *, vint64m1_t, vint64m1_t, vint64m1_t, vint64m1_t, vint64m1_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vsseg5e64_v_m)))
void vsseg5e64(vbool64_t, int64_t *, vint64m1_t, vint64m1_t, vint64m1_t, vint64m1_t, vint64m1_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vsseg5e64_v)))
void vsseg5e64(uint64_t *, vuint64m1_t, vuint64m1_t, vuint64m1_t, vuint64m1_t, vuint64m1_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vsseg5e64_v_m)))
void vsseg5e64(vbool64_t, uint64_t *, vuint64m1_t, vuint64m1_t, vuint64m1_t, vuint64m1_t, vuint64m1_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vsseg6e64_v)))
void vsseg6e64(int64_t *, vint64m1_t, vint64m1_t, vint64m1_t, vint64m1_t, vint64m1_t, vint64m1_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vsseg6e64_v_m)))
void vsseg6e64(vbool64_t, int64_t *, vint64m1_t, vint64m1_t, vint64m1_t, vint64m1_t, vint64m1_t, vint64m1_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vsseg6e64_v)))
void vsseg6e64(uint64_t *, vuint64m1_t, vuint64m1_t, vuint64m1_t, vuint64m1_t, vuint64m1_t, vuint64m1_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vsseg6e64_v_m)))
void vsseg6e64(vbool64_t, uint64_t *, vuint64m1_t, vuint64m1_t, vuint64m1_t, vuint64m1_t, vuint64m1_t, vuint64m1_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vsseg7e64_v)))
void vsseg7e64(int64_t *, vint64m1_t, vint64m1_t, vint64m1_t, vint64m1_t, vint64m1_t, vint64m1_t, vint64m1_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vsseg7e64_v_m)))
void vsseg7e64(vbool64_t, int64_t *, vint64m1_t, vint64m1_t, vint64m1_t, vint64m1_t, vint64m1_t, vint64m1_t, vint64m1_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vsseg7e64_v)))
void vsseg7e64(uint64_t *, vuint64m1_t, vuint64m1_t, vuint64m1_t, vuint64m1_t, vuint64m1_t, vuint64m1_t, vuint64m1_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vsseg7e64_v_m)))
void vsseg7e64(vbool64_t, uint64_t *, vuint64m1_t, vuint64m1_t, vuint64m1_t, vuint64m1_t, vuint64m1_t, vuint64m1_t, vuint64m1_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vsseg8e64_v)))
void vsseg8e64(int64_t *, vint64m1_t, vint64m1_t, vint64m1_t, vint64m1_t, vint64m1_t, vint64m1_t, vint64m1_t, vint64m1_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vsseg8e64_v_m)))
void vsseg8e64(vbool64_t, int64_t *, vint64m1_t, vint64m1_t, vint64m1_t, vint64m1_t, vint64m1_t, vint64m1_t, vint64m1_t, vint64m1_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vsseg8e64_v)))
void vsseg8e64(uint64_t *, vuint64m1_t, vuint64m1_t, vuint64m1_t, vuint64m1_t, vuint64m1_t, vuint64m1_t, vuint64m1_t, vuint64m1_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vsseg8e64_v_m)))
void vsseg8e64(vbool64_t, uint64_t *, vuint64m1_t, vuint64m1_t, vuint64m1_t, vuint64m1_t, vuint64m1_t, vuint64m1_t, vuint64m1_t, vuint64m1_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vssseg2e64_v)))
void vssseg2e64(int64_t *, ptrdiff_t, vint64m1_t, vint64m1_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vssseg2e64_v_m)))
void vssseg2e64(vbool64_t, int64_t *, ptrdiff_t, vint64m1_t, vint64m1_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vssseg2e64_v)))
void vssseg2e64(int64_t *, ptrdiff_t, vint64m2_t, vint64m2_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vssseg2e64_v_m)))
void vssseg2e64(vbool32_t, int64_t *, ptrdiff_t, vint64m2_t, vint64m2_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vssseg2e64_v)))
void vssseg2e64(int64_t *, ptrdiff_t, vint64m4_t, vint64m4_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vssseg2e64_v_m)))
void vssseg2e64(vbool16_t, int64_t *, ptrdiff_t, vint64m4_t, vint64m4_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vssseg2e64_v)))
void vssseg2e64(uint64_t *, ptrdiff_t, vuint64m1_t, vuint64m1_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vssseg2e64_v_m)))
void vssseg2e64(vbool64_t, uint64_t *, ptrdiff_t, vuint64m1_t, vuint64m1_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vssseg2e64_v)))
void vssseg2e64(uint64_t *, ptrdiff_t, vuint64m2_t, vuint64m2_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vssseg2e64_v_m)))
void vssseg2e64(vbool32_t, uint64_t *, ptrdiff_t, vuint64m2_t, vuint64m2_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vssseg2e64_v)))
void vssseg2e64(uint64_t *, ptrdiff_t, vuint64m4_t, vuint64m4_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vssseg2e64_v_m)))
void vssseg2e64(vbool16_t, uint64_t *, ptrdiff_t, vuint64m4_t, vuint64m4_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vssseg3e64_v)))
void vssseg3e64(int64_t *, ptrdiff_t, vint64m1_t, vint64m1_t, vint64m1_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vssseg3e64_v_m)))
void vssseg3e64(vbool64_t, int64_t *, ptrdiff_t, vint64m1_t, vint64m1_t, vint64m1_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vssseg3e64_v)))
void vssseg3e64(int64_t *, ptrdiff_t, vint64m2_t, vint64m2_t, vint64m2_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vssseg3e64_v_m)))
void vssseg3e64(vbool32_t, int64_t *, ptrdiff_t, vint64m2_t, vint64m2_t, vint64m2_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vssseg3e64_v)))
void vssseg3e64(uint64_t *, ptrdiff_t, vuint64m1_t, vuint64m1_t, vuint64m1_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vssseg3e64_v_m)))
void vssseg3e64(vbool64_t, uint64_t *, ptrdiff_t, vuint64m1_t, vuint64m1_t, vuint64m1_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vssseg3e64_v)))
void vssseg3e64(uint64_t *, ptrdiff_t, vuint64m2_t, vuint64m2_t, vuint64m2_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vssseg3e64_v_m)))
void vssseg3e64(vbool32_t, uint64_t *, ptrdiff_t, vuint64m2_t, vuint64m2_t, vuint64m2_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vssseg4e64_v)))
void vssseg4e64(int64_t *, ptrdiff_t, vint64m1_t, vint64m1_t, vint64m1_t, vint64m1_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vssseg4e64_v_m)))
void vssseg4e64(vbool64_t, int64_t *, ptrdiff_t, vint64m1_t, vint64m1_t, vint64m1_t, vint64m1_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vssseg4e64_v)))
void vssseg4e64(int64_t *, ptrdiff_t, vint64m2_t, vint64m2_t, vint64m2_t, vint64m2_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vssseg4e64_v_m)))
void vssseg4e64(vbool32_t, int64_t *, ptrdiff_t, vint64m2_t, vint64m2_t, vint64m2_t, vint64m2_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vssseg4e64_v)))
void vssseg4e64(uint64_t *, ptrdiff_t, vuint64m1_t, vuint64m1_t, vuint64m1_t, vuint64m1_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vssseg4e64_v_m)))
void vssseg4e64(vbool64_t, uint64_t *, ptrdiff_t, vuint64m1_t, vuint64m1_t, vuint64m1_t, vuint64m1_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vssseg4e64_v)))
void vssseg4e64(uint64_t *, ptrdiff_t, vuint64m2_t, vuint64m2_t, vuint64m2_t, vuint64m2_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vssseg4e64_v_m)))
void vssseg4e64(vbool32_t, uint64_t *, ptrdiff_t, vuint64m2_t, vuint64m2_t, vuint64m2_t, vuint64m2_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vssseg5e64_v)))
void vssseg5e64(int64_t *, ptrdiff_t, vint64m1_t, vint64m1_t, vint64m1_t, vint64m1_t, vint64m1_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vssseg5e64_v_m)))
void vssseg5e64(vbool64_t, int64_t *, ptrdiff_t, vint64m1_t, vint64m1_t, vint64m1_t, vint64m1_t, vint64m1_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vssseg5e64_v)))
void vssseg5e64(uint64_t *, ptrdiff_t, vuint64m1_t, vuint64m1_t, vuint64m1_t, vuint64m1_t, vuint64m1_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vssseg5e64_v_m)))
void vssseg5e64(vbool64_t, uint64_t *, ptrdiff_t, vuint64m1_t, vuint64m1_t, vuint64m1_t, vuint64m1_t, vuint64m1_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vssseg6e64_v)))
void vssseg6e64(int64_t *, ptrdiff_t, vint64m1_t, vint64m1_t, vint64m1_t, vint64m1_t, vint64m1_t, vint64m1_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vssseg6e64_v_m)))
void vssseg6e64(vbool64_t, int64_t *, ptrdiff_t, vint64m1_t, vint64m1_t, vint64m1_t, vint64m1_t, vint64m1_t, vint64m1_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vssseg6e64_v)))
void vssseg6e64(uint64_t *, ptrdiff_t, vuint64m1_t, vuint64m1_t, vuint64m1_t, vuint64m1_t, vuint64m1_t, vuint64m1_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vssseg6e64_v_m)))
void vssseg6e64(vbool64_t, uint64_t *, ptrdiff_t, vuint64m1_t, vuint64m1_t, vuint64m1_t, vuint64m1_t, vuint64m1_t, vuint64m1_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vssseg7e64_v)))
void vssseg7e64(int64_t *, ptrdiff_t, vint64m1_t, vint64m1_t, vint64m1_t, vint64m1_t, vint64m1_t, vint64m1_t, vint64m1_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vssseg7e64_v_m)))
void vssseg7e64(vbool64_t, int64_t *, ptrdiff_t, vint64m1_t, vint64m1_t, vint64m1_t, vint64m1_t, vint64m1_t, vint64m1_t, vint64m1_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vssseg7e64_v)))
void vssseg7e64(uint64_t *, ptrdiff_t, vuint64m1_t, vuint64m1_t, vuint64m1_t, vuint64m1_t, vuint64m1_t, vuint64m1_t, vuint64m1_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vssseg7e64_v_m)))
void vssseg7e64(vbool64_t, uint64_t *, ptrdiff_t, vuint64m1_t, vuint64m1_t, vuint64m1_t, vuint64m1_t, vuint64m1_t, vuint64m1_t, vuint64m1_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vssseg8e64_v)))
void vssseg8e64(int64_t *, ptrdiff_t, vint64m1_t, vint64m1_t, vint64m1_t, vint64m1_t, vint64m1_t, vint64m1_t, vint64m1_t, vint64m1_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vssseg8e64_v_m)))
void vssseg8e64(vbool64_t, int64_t *, ptrdiff_t, vint64m1_t, vint64m1_t, vint64m1_t, vint64m1_t, vint64m1_t, vint64m1_t, vint64m1_t, vint64m1_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vssseg8e64_v)))
void vssseg8e64(uint64_t *, ptrdiff_t, vuint64m1_t, vuint64m1_t, vuint64m1_t, vuint64m1_t, vuint64m1_t, vuint64m1_t, vuint64m1_t, vuint64m1_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vssseg8e64_v_m)))
void vssseg8e64(vbool64_t, uint64_t *, ptrdiff_t, vuint64m1_t, vuint64m1_t, vuint64m1_t, vuint64m1_t, vuint64m1_t, vuint64m1_t, vuint64m1_t, vuint64m1_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vsuxseg2ei64_v)))
void vsuxseg2ei64(int8_t *, vuint64m8_t, vint8m1_t, vint8m1_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vsuxseg2ei64_v_m)))
void vsuxseg2ei64(vbool8_t, int8_t *, vuint64m8_t, vint8m1_t, vint8m1_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vsuxseg2ei64_v)))
void vsuxseg2ei64(int8_t *, vuint64m4_t, vint8mf2_t, vint8mf2_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vsuxseg2ei64_v_m)))
void vsuxseg2ei64(vbool16_t, int8_t *, vuint64m4_t, vint8mf2_t, vint8mf2_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vsuxseg2ei64_v)))
void vsuxseg2ei64(int8_t *, vuint64m2_t, vint8mf4_t, vint8mf4_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vsuxseg2ei64_v_m)))
void vsuxseg2ei64(vbool32_t, int8_t *, vuint64m2_t, vint8mf4_t, vint8mf4_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vsuxseg2ei64_v)))
void vsuxseg2ei64(int8_t *, vuint64m1_t, vint8mf8_t, vint8mf8_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vsuxseg2ei64_v_m)))
void vsuxseg2ei64(vbool64_t, int8_t *, vuint64m1_t, vint8mf8_t, vint8mf8_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vsuxseg2ei64_v)))
void vsuxseg2ei64(uint8_t *, vuint64m8_t, vuint8m1_t, vuint8m1_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vsuxseg2ei64_v_m)))
void vsuxseg2ei64(vbool8_t, uint8_t *, vuint64m8_t, vuint8m1_t, vuint8m1_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vsuxseg2ei64_v)))
void vsuxseg2ei64(uint8_t *, vuint64m4_t, vuint8mf2_t, vuint8mf2_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vsuxseg2ei64_v_m)))
void vsuxseg2ei64(vbool16_t, uint8_t *, vuint64m4_t, vuint8mf2_t, vuint8mf2_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vsuxseg2ei64_v)))
void vsuxseg2ei64(uint8_t *, vuint64m2_t, vuint8mf4_t, vuint8mf4_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vsuxseg2ei64_v_m)))
void vsuxseg2ei64(vbool32_t, uint8_t *, vuint64m2_t, vuint8mf4_t, vuint8mf4_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vsuxseg2ei64_v)))
void vsuxseg2ei64(uint8_t *, vuint64m1_t, vuint8mf8_t, vuint8mf8_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vsuxseg2ei64_v_m)))
void vsuxseg2ei64(vbool64_t, uint8_t *, vuint64m1_t, vuint8mf8_t, vuint8mf8_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vsuxseg3ei64_v)))
void vsuxseg3ei64(int8_t *, vuint64m8_t, vint8m1_t, vint8m1_t, vint8m1_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vsuxseg3ei64_v_m)))
void vsuxseg3ei64(vbool8_t, int8_t *, vuint64m8_t, vint8m1_t, vint8m1_t, vint8m1_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vsuxseg3ei64_v)))
void vsuxseg3ei64(int8_t *, vuint64m4_t, vint8mf2_t, vint8mf2_t, vint8mf2_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vsuxseg3ei64_v_m)))
void vsuxseg3ei64(vbool16_t, int8_t *, vuint64m4_t, vint8mf2_t, vint8mf2_t, vint8mf2_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vsuxseg3ei64_v)))
void vsuxseg3ei64(int8_t *, vuint64m2_t, vint8mf4_t, vint8mf4_t, vint8mf4_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vsuxseg3ei64_v_m)))
void vsuxseg3ei64(vbool32_t, int8_t *, vuint64m2_t, vint8mf4_t, vint8mf4_t, vint8mf4_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vsuxseg3ei64_v)))
void vsuxseg3ei64(int8_t *, vuint64m1_t, vint8mf8_t, vint8mf8_t, vint8mf8_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vsuxseg3ei64_v_m)))
void vsuxseg3ei64(vbool64_t, int8_t *, vuint64m1_t, vint8mf8_t, vint8mf8_t, vint8mf8_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vsuxseg3ei64_v)))
void vsuxseg3ei64(uint8_t *, vuint64m8_t, vuint8m1_t, vuint8m1_t, vuint8m1_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vsuxseg3ei64_v_m)))
void vsuxseg3ei64(vbool8_t, uint8_t *, vuint64m8_t, vuint8m1_t, vuint8m1_t, vuint8m1_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vsuxseg3ei64_v)))
void vsuxseg3ei64(uint8_t *, vuint64m4_t, vuint8mf2_t, vuint8mf2_t, vuint8mf2_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vsuxseg3ei64_v_m)))
void vsuxseg3ei64(vbool16_t, uint8_t *, vuint64m4_t, vuint8mf2_t, vuint8mf2_t, vuint8mf2_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vsuxseg3ei64_v)))
void vsuxseg3ei64(uint8_t *, vuint64m2_t, vuint8mf4_t, vuint8mf4_t, vuint8mf4_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vsuxseg3ei64_v_m)))
void vsuxseg3ei64(vbool32_t, uint8_t *, vuint64m2_t, vuint8mf4_t, vuint8mf4_t, vuint8mf4_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vsuxseg3ei64_v)))
void vsuxseg3ei64(uint8_t *, vuint64m1_t, vuint8mf8_t, vuint8mf8_t, vuint8mf8_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vsuxseg3ei64_v_m)))
void vsuxseg3ei64(vbool64_t, uint8_t *, vuint64m1_t, vuint8mf8_t, vuint8mf8_t, vuint8mf8_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vsuxseg4ei64_v)))
void vsuxseg4ei64(int8_t *, vuint64m8_t, vint8m1_t, vint8m1_t, vint8m1_t, vint8m1_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vsuxseg4ei64_v_m)))
void vsuxseg4ei64(vbool8_t, int8_t *, vuint64m8_t, vint8m1_t, vint8m1_t, vint8m1_t, vint8m1_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vsuxseg4ei64_v)))
void vsuxseg4ei64(int8_t *, vuint64m4_t, vint8mf2_t, vint8mf2_t, vint8mf2_t, vint8mf2_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vsuxseg4ei64_v_m)))
void vsuxseg4ei64(vbool16_t, int8_t *, vuint64m4_t, vint8mf2_t, vint8mf2_t, vint8mf2_t, vint8mf2_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vsuxseg4ei64_v)))
void vsuxseg4ei64(int8_t *, vuint64m2_t, vint8mf4_t, vint8mf4_t, vint8mf4_t, vint8mf4_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vsuxseg4ei64_v_m)))
void vsuxseg4ei64(vbool32_t, int8_t *, vuint64m2_t, vint8mf4_t, vint8mf4_t, vint8mf4_t, vint8mf4_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vsuxseg4ei64_v)))
void vsuxseg4ei64(int8_t *, vuint64m1_t, vint8mf8_t, vint8mf8_t, vint8mf8_t, vint8mf8_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vsuxseg4ei64_v_m)))
void vsuxseg4ei64(vbool64_t, int8_t *, vuint64m1_t, vint8mf8_t, vint8mf8_t, vint8mf8_t, vint8mf8_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vsuxseg4ei64_v)))
void vsuxseg4ei64(uint8_t *, vuint64m8_t, vuint8m1_t, vuint8m1_t, vuint8m1_t, vuint8m1_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vsuxseg4ei64_v_m)))
void vsuxseg4ei64(vbool8_t, uint8_t *, vuint64m8_t, vuint8m1_t, vuint8m1_t, vuint8m1_t, vuint8m1_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vsuxseg4ei64_v)))
void vsuxseg4ei64(uint8_t *, vuint64m4_t, vuint8mf2_t, vuint8mf2_t, vuint8mf2_t, vuint8mf2_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vsuxseg4ei64_v_m)))
void vsuxseg4ei64(vbool16_t, uint8_t *, vuint64m4_t, vuint8mf2_t, vuint8mf2_t, vuint8mf2_t, vuint8mf2_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vsuxseg4ei64_v)))
void vsuxseg4ei64(uint8_t *, vuint64m2_t, vuint8mf4_t, vuint8mf4_t, vuint8mf4_t, vuint8mf4_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vsuxseg4ei64_v_m)))
void vsuxseg4ei64(vbool32_t, uint8_t *, vuint64m2_t, vuint8mf4_t, vuint8mf4_t, vuint8mf4_t, vuint8mf4_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vsuxseg4ei64_v)))
void vsuxseg4ei64(uint8_t *, vuint64m1_t, vuint8mf8_t, vuint8mf8_t, vuint8mf8_t, vuint8mf8_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vsuxseg4ei64_v_m)))
void vsuxseg4ei64(vbool64_t, uint8_t *, vuint64m1_t, vuint8mf8_t, vuint8mf8_t, vuint8mf8_t, vuint8mf8_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vsuxseg5ei64_v)))
void vsuxseg5ei64(int8_t *, vuint64m8_t, vint8m1_t, vint8m1_t, vint8m1_t, vint8m1_t, vint8m1_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vsuxseg5ei64_v_m)))
void vsuxseg5ei64(vbool8_t, int8_t *, vuint64m8_t, vint8m1_t, vint8m1_t, vint8m1_t, vint8m1_t, vint8m1_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vsuxseg5ei64_v)))
void vsuxseg5ei64(int8_t *, vuint64m4_t, vint8mf2_t, vint8mf2_t, vint8mf2_t, vint8mf2_t, vint8mf2_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vsuxseg5ei64_v_m)))
void vsuxseg5ei64(vbool16_t, int8_t *, vuint64m4_t, vint8mf2_t, vint8mf2_t, vint8mf2_t, vint8mf2_t, vint8mf2_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vsuxseg5ei64_v)))
void vsuxseg5ei64(int8_t *, vuint64m2_t, vint8mf4_t, vint8mf4_t, vint8mf4_t, vint8mf4_t, vint8mf4_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vsuxseg5ei64_v_m)))
void vsuxseg5ei64(vbool32_t, int8_t *, vuint64m2_t, vint8mf4_t, vint8mf4_t, vint8mf4_t, vint8mf4_t, vint8mf4_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vsuxseg5ei64_v)))
void vsuxseg5ei64(int8_t *, vuint64m1_t, vint8mf8_t, vint8mf8_t, vint8mf8_t, vint8mf8_t, vint8mf8_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vsuxseg5ei64_v_m)))
void vsuxseg5ei64(vbool64_t, int8_t *, vuint64m1_t, vint8mf8_t, vint8mf8_t, vint8mf8_t, vint8mf8_t, vint8mf8_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vsuxseg5ei64_v)))
void vsuxseg5ei64(uint8_t *, vuint64m8_t, vuint8m1_t, vuint8m1_t, vuint8m1_t, vuint8m1_t, vuint8m1_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vsuxseg5ei64_v_m)))
void vsuxseg5ei64(vbool8_t, uint8_t *, vuint64m8_t, vuint8m1_t, vuint8m1_t, vuint8m1_t, vuint8m1_t, vuint8m1_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vsuxseg5ei64_v)))
void vsuxseg5ei64(uint8_t *, vuint64m4_t, vuint8mf2_t, vuint8mf2_t, vuint8mf2_t, vuint8mf2_t, vuint8mf2_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vsuxseg5ei64_v_m)))
void vsuxseg5ei64(vbool16_t, uint8_t *, vuint64m4_t, vuint8mf2_t, vuint8mf2_t, vuint8mf2_t, vuint8mf2_t, vuint8mf2_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vsuxseg5ei64_v)))
void vsuxseg5ei64(uint8_t *, vuint64m2_t, vuint8mf4_t, vuint8mf4_t, vuint8mf4_t, vuint8mf4_t, vuint8mf4_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vsuxseg5ei64_v_m)))
void vsuxseg5ei64(vbool32_t, uint8_t *, vuint64m2_t, vuint8mf4_t, vuint8mf4_t, vuint8mf4_t, vuint8mf4_t, vuint8mf4_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vsuxseg5ei64_v)))
void vsuxseg5ei64(uint8_t *, vuint64m1_t, vuint8mf8_t, vuint8mf8_t, vuint8mf8_t, vuint8mf8_t, vuint8mf8_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vsuxseg5ei64_v_m)))
void vsuxseg5ei64(vbool64_t, uint8_t *, vuint64m1_t, vuint8mf8_t, vuint8mf8_t, vuint8mf8_t, vuint8mf8_t, vuint8mf8_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vsuxseg6ei64_v)))
void vsuxseg6ei64(int8_t *, vuint64m8_t, vint8m1_t, vint8m1_t, vint8m1_t, vint8m1_t, vint8m1_t, vint8m1_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vsuxseg6ei64_v_m)))
void vsuxseg6ei64(vbool8_t, int8_t *, vuint64m8_t, vint8m1_t, vint8m1_t, vint8m1_t, vint8m1_t, vint8m1_t, vint8m1_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vsuxseg6ei64_v)))
void vsuxseg6ei64(int8_t *, vuint64m4_t, vint8mf2_t, vint8mf2_t, vint8mf2_t, vint8mf2_t, vint8mf2_t, vint8mf2_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vsuxseg6ei64_v_m)))
void vsuxseg6ei64(vbool16_t, int8_t *, vuint64m4_t, vint8mf2_t, vint8mf2_t, vint8mf2_t, vint8mf2_t, vint8mf2_t, vint8mf2_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vsuxseg6ei64_v)))
void vsuxseg6ei64(int8_t *, vuint64m2_t, vint8mf4_t, vint8mf4_t, vint8mf4_t, vint8mf4_t, vint8mf4_t, vint8mf4_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vsuxseg6ei64_v_m)))
void vsuxseg6ei64(vbool32_t, int8_t *, vuint64m2_t, vint8mf4_t, vint8mf4_t, vint8mf4_t, vint8mf4_t, vint8mf4_t, vint8mf4_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vsuxseg6ei64_v)))
void vsuxseg6ei64(int8_t *, vuint64m1_t, vint8mf8_t, vint8mf8_t, vint8mf8_t, vint8mf8_t, vint8mf8_t, vint8mf8_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vsuxseg6ei64_v_m)))
void vsuxseg6ei64(vbool64_t, int8_t *, vuint64m1_t, vint8mf8_t, vint8mf8_t, vint8mf8_t, vint8mf8_t, vint8mf8_t, vint8mf8_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vluxei8_v)))
vint64m1_t vluxei8(const int64_t *, vuint8mf8_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vluxei8_v_m)))
vint64m1_t vluxei8(vbool64_t, vint64m1_t, const int64_t *, vuint8mf8_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vluxei8_v)))
vint64m2_t vluxei8(const int64_t *, vuint8mf4_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vluxei8_v_m)))
vint64m2_t vluxei8(vbool32_t, vint64m2_t, const int64_t *, vuint8mf4_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vluxei8_v)))
vint64m4_t vluxei8(const int64_t *, vuint8mf2_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vluxei8_v_m)))
vint64m4_t vluxei8(vbool16_t, vint64m4_t, const int64_t *, vuint8mf2_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vluxei8_v)))
vint64m8_t vluxei8(const int64_t *, vuint8m1_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vluxei8_v_m)))
vint64m8_t vluxei8(vbool8_t, vint64m8_t, const int64_t *, vuint8m1_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vsuxseg6ei64_v)))
void vsuxseg6ei64(uint8_t *, vuint64m8_t, vuint8m1_t, vuint8m1_t, vuint8m1_t, vuint8m1_t, vuint8m1_t, vuint8m1_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vsuxseg6ei64_v_m)))
void vsuxseg6ei64(vbool8_t, uint8_t *, vuint64m8_t, vuint8m1_t, vuint8m1_t, vuint8m1_t, vuint8m1_t, vuint8m1_t, vuint8m1_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vsuxseg6ei64_v)))
void vsuxseg6ei64(uint8_t *, vuint64m4_t, vuint8mf2_t, vuint8mf2_t, vuint8mf2_t, vuint8mf2_t, vuint8mf2_t, vuint8mf2_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vsuxseg6ei64_v_m)))
void vsuxseg6ei64(vbool16_t, uint8_t *, vuint64m4_t, vuint8mf2_t, vuint8mf2_t, vuint8mf2_t, vuint8mf2_t, vuint8mf2_t, vuint8mf2_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vsuxseg6ei64_v)))
void vsuxseg6ei64(uint8_t *, vuint64m2_t, vuint8mf4_t, vuint8mf4_t, vuint8mf4_t, vuint8mf4_t, vuint8mf4_t, vuint8mf4_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vsuxseg6ei64_v_m)))
void vsuxseg6ei64(vbool32_t, uint8_t *, vuint64m2_t, vuint8mf4_t, vuint8mf4_t, vuint8mf4_t, vuint8mf4_t, vuint8mf4_t, vuint8mf4_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vsuxseg6ei64_v)))
void vsuxseg6ei64(uint8_t *, vuint64m1_t, vuint8mf8_t, vuint8mf8_t, vuint8mf8_t, vuint8mf8_t, vuint8mf8_t, vuint8mf8_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vsuxseg6ei64_v_m)))
void vsuxseg6ei64(vbool64_t, uint8_t *, vuint64m1_t, vuint8mf8_t, vuint8mf8_t, vuint8mf8_t, vuint8mf8_t, vuint8mf8_t, vuint8mf8_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vsuxseg7ei64_v)))
void vsuxseg7ei64(int8_t *, vuint64m8_t, vint8m1_t, vint8m1_t, vint8m1_t, vint8m1_t, vint8m1_t, vint8m1_t, vint8m1_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vsuxseg7ei64_v_m)))
void vsuxseg7ei64(vbool8_t, int8_t *, vuint64m8_t, vint8m1_t, vint8m1_t, vint8m1_t, vint8m1_t, vint8m1_t, vint8m1_t, vint8m1_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vsuxseg7ei64_v)))
void vsuxseg7ei64(int8_t *, vuint64m4_t, vint8mf2_t, vint8mf2_t, vint8mf2_t, vint8mf2_t, vint8mf2_t, vint8mf2_t, vint8mf2_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vsuxseg7ei64_v_m)))
void vsuxseg7ei64(vbool16_t, int8_t *, vuint64m4_t, vint8mf2_t, vint8mf2_t, vint8mf2_t, vint8mf2_t, vint8mf2_t, vint8mf2_t, vint8mf2_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vsuxseg7ei64_v)))
void vsuxseg7ei64(int8_t *, vuint64m2_t, vint8mf4_t, vint8mf4_t, vint8mf4_t, vint8mf4_t, vint8mf4_t, vint8mf4_t, vint8mf4_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vsuxseg7ei64_v_m)))
void vsuxseg7ei64(vbool32_t, int8_t *, vuint64m2_t, vint8mf4_t, vint8mf4_t, vint8mf4_t, vint8mf4_t, vint8mf4_t, vint8mf4_t, vint8mf4_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vsuxseg7ei64_v)))
void vsuxseg7ei64(int8_t *, vuint64m1_t, vint8mf8_t, vint8mf8_t, vint8mf8_t, vint8mf8_t, vint8mf8_t, vint8mf8_t, vint8mf8_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vsuxseg7ei64_v_m)))
void vsuxseg7ei64(vbool64_t, int8_t *, vuint64m1_t, vint8mf8_t, vint8mf8_t, vint8mf8_t, vint8mf8_t, vint8mf8_t, vint8mf8_t, vint8mf8_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vsuxseg7ei64_v)))
void vsuxseg7ei64(uint8_t *, vuint64m8_t, vuint8m1_t, vuint8m1_t, vuint8m1_t, vuint8m1_t, vuint8m1_t, vuint8m1_t, vuint8m1_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vsuxseg7ei64_v_m)))
void vsuxseg7ei64(vbool8_t, uint8_t *, vuint64m8_t, vuint8m1_t, vuint8m1_t, vuint8m1_t, vuint8m1_t, vuint8m1_t, vuint8m1_t, vuint8m1_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vsuxseg7ei64_v)))
void vsuxseg7ei64(uint8_t *, vuint64m4_t, vuint8mf2_t, vuint8mf2_t, vuint8mf2_t, vuint8mf2_t, vuint8mf2_t, vuint8mf2_t, vuint8mf2_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vsuxseg7ei64_v_m)))
void vsuxseg7ei64(vbool16_t, uint8_t *, vuint64m4_t, vuint8mf2_t, vuint8mf2_t, vuint8mf2_t, vuint8mf2_t, vuint8mf2_t, vuint8mf2_t, vuint8mf2_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vsuxseg7ei64_v)))
void vsuxseg7ei64(uint8_t *, vuint64m2_t, vuint8mf4_t, vuint8mf4_t, vuint8mf4_t, vuint8mf4_t, vuint8mf4_t, vuint8mf4_t, vuint8mf4_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vsuxseg7ei64_v_m)))
void vsuxseg7ei64(vbool32_t, uint8_t *, vuint64m2_t, vuint8mf4_t, vuint8mf4_t, vuint8mf4_t, vuint8mf4_t, vuint8mf4_t, vuint8mf4_t, vuint8mf4_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vsuxseg7ei64_v)))
void vsuxseg7ei64(uint8_t *, vuint64m1_t, vuint8mf8_t, vuint8mf8_t, vuint8mf8_t, vuint8mf8_t, vuint8mf8_t, vuint8mf8_t, vuint8mf8_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vsuxseg7ei64_v_m)))
void vsuxseg7ei64(vbool64_t, uint8_t *, vuint64m1_t, vuint8mf8_t, vuint8mf8_t, vuint8mf8_t, vuint8mf8_t, vuint8mf8_t, vuint8mf8_t, vuint8mf8_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vsuxseg8ei64_v)))
void vsuxseg8ei64(int8_t *, vuint64m8_t, vint8m1_t, vint8m1_t, vint8m1_t, vint8m1_t, vint8m1_t, vint8m1_t, vint8m1_t, vint8m1_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vsuxseg8ei64_v_m)))
void vsuxseg8ei64(vbool8_t, int8_t *, vuint64m8_t, vint8m1_t, vint8m1_t, vint8m1_t, vint8m1_t, vint8m1_t, vint8m1_t, vint8m1_t, vint8m1_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vsuxseg8ei64_v)))
void vsuxseg8ei64(int8_t *, vuint64m4_t, vint8mf2_t, vint8mf2_t, vint8mf2_t, vint8mf2_t, vint8mf2_t, vint8mf2_t, vint8mf2_t, vint8mf2_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vsuxseg8ei64_v_m)))
void vsuxseg8ei64(vbool16_t, int8_t *, vuint64m4_t, vint8mf2_t, vint8mf2_t, vint8mf2_t, vint8mf2_t, vint8mf2_t, vint8mf2_t, vint8mf2_t, vint8mf2_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vsuxseg8ei64_v)))
void vsuxseg8ei64(int8_t *, vuint64m2_t, vint8mf4_t, vint8mf4_t, vint8mf4_t, vint8mf4_t, vint8mf4_t, vint8mf4_t, vint8mf4_t, vint8mf4_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vsuxseg8ei64_v_m)))
void vsuxseg8ei64(vbool32_t, int8_t *, vuint64m2_t, vint8mf4_t, vint8mf4_t, vint8mf4_t, vint8mf4_t, vint8mf4_t, vint8mf4_t, vint8mf4_t, vint8mf4_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vsuxseg8ei64_v)))
void vsuxseg8ei64(int8_t *, vuint64m1_t, vint8mf8_t, vint8mf8_t, vint8mf8_t, vint8mf8_t, vint8mf8_t, vint8mf8_t, vint8mf8_t, vint8mf8_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vsuxseg8ei64_v_m)))
void vsuxseg8ei64(vbool64_t, int8_t *, vuint64m1_t, vint8mf8_t, vint8mf8_t, vint8mf8_t, vint8mf8_t, vint8mf8_t, vint8mf8_t, vint8mf8_t, vint8mf8_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vsuxseg8ei64_v)))
void vsuxseg8ei64(uint8_t *, vuint64m8_t, vuint8m1_t, vuint8m1_t, vuint8m1_t, vuint8m1_t, vuint8m1_t, vuint8m1_t, vuint8m1_t, vuint8m1_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vsuxseg8ei64_v_m)))
void vsuxseg8ei64(vbool8_t, uint8_t *, vuint64m8_t, vuint8m1_t, vuint8m1_t, vuint8m1_t, vuint8m1_t, vuint8m1_t, vuint8m1_t, vuint8m1_t, vuint8m1_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vsuxseg8ei64_v)))
void vsuxseg8ei64(uint8_t *, vuint64m4_t, vuint8mf2_t, vuint8mf2_t, vuint8mf2_t, vuint8mf2_t, vuint8mf2_t, vuint8mf2_t, vuint8mf2_t, vuint8mf2_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vsuxseg8ei64_v_m)))
void vsuxseg8ei64(vbool16_t, uint8_t *, vuint64m4_t, vuint8mf2_t, vuint8mf2_t, vuint8mf2_t, vuint8mf2_t, vuint8mf2_t, vuint8mf2_t, vuint8mf2_t, vuint8mf2_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vsuxseg8ei64_v)))
void vsuxseg8ei64(uint8_t *, vuint64m2_t, vuint8mf4_t, vuint8mf4_t, vuint8mf4_t, vuint8mf4_t, vuint8mf4_t, vuint8mf4_t, vuint8mf4_t, vuint8mf4_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vsuxseg8ei64_v_m)))
void vsuxseg8ei64(vbool32_t, uint8_t *, vuint64m2_t, vuint8mf4_t, vuint8mf4_t, vuint8mf4_t, vuint8mf4_t, vuint8mf4_t, vuint8mf4_t, vuint8mf4_t, vuint8mf4_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vsuxseg8ei64_v)))
void vsuxseg8ei64(uint8_t *, vuint64m1_t, vuint8mf8_t, vuint8mf8_t, vuint8mf8_t, vuint8mf8_t, vuint8mf8_t, vuint8mf8_t, vuint8mf8_t, vuint8mf8_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vsuxseg8ei64_v_m)))
void vsuxseg8ei64(vbool64_t, uint8_t *, vuint64m1_t, vuint8mf8_t, vuint8mf8_t, vuint8mf8_t, vuint8mf8_t, vuint8mf8_t, vuint8mf8_t, vuint8mf8_t, vuint8mf8_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vluxei8_v)))
vuint64m1_t vluxei8(const uint64_t *, vuint8mf8_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vluxei8_v_m)))
vuint64m1_t vluxei8(vbool64_t, vuint64m1_t, const uint64_t *, vuint8mf8_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vluxei8_v)))
vuint64m2_t vluxei8(const uint64_t *, vuint8mf4_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vluxei8_v_m)))
vuint64m2_t vluxei8(vbool32_t, vuint64m2_t, const uint64_t *, vuint8mf4_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vluxei8_v)))
vuint64m4_t vluxei8(const uint64_t *, vuint8mf2_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vluxei8_v_m)))
vuint64m4_t vluxei8(vbool16_t, vuint64m4_t, const uint64_t *, vuint8mf2_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vluxei8_v)))
vuint64m8_t vluxei8(const uint64_t *, vuint8m1_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vluxei8_v_m)))
vuint64m8_t vluxei8(vbool8_t, vuint64m8_t, const uint64_t *, vuint8m1_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vluxei16_v)))
vint64m1_t vluxei16(const int64_t *, vuint16mf4_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vluxei16_v_m)))
vint64m1_t vluxei16(vbool64_t, vint64m1_t, const int64_t *, vuint16mf4_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vluxei16_v)))
vint64m2_t vluxei16(const int64_t *, vuint16mf2_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vluxei16_v_m)))
vint64m2_t vluxei16(vbool32_t, vint64m2_t, const int64_t *, vuint16mf2_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vluxei16_v)))
vint64m4_t vluxei16(const int64_t *, vuint16m1_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vluxei16_v_m)))
vint64m4_t vluxei16(vbool16_t, vint64m4_t, const int64_t *, vuint16m1_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vluxei16_v)))
vint64m8_t vluxei16(const int64_t *, vuint16m2_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vluxei16_v_m)))
vint64m8_t vluxei16(vbool8_t, vint64m8_t, const int64_t *, vuint16m2_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vluxei16_v)))
vuint64m1_t vluxei16(const uint64_t *, vuint16mf4_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vluxei16_v_m)))
vuint64m1_t vluxei16(vbool64_t, vuint64m1_t, const uint64_t *, vuint16mf4_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vluxei16_v)))
vuint64m2_t vluxei16(const uint64_t *, vuint16mf2_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vluxei16_v_m)))
vuint64m2_t vluxei16(vbool32_t, vuint64m2_t, const uint64_t *, vuint16mf2_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vluxei16_v)))
vuint64m4_t vluxei16(const uint64_t *, vuint16m1_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vluxei16_v_m)))
vuint64m4_t vluxei16(vbool16_t, vuint64m4_t, const uint64_t *, vuint16m1_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vluxei16_v)))
vuint64m8_t vluxei16(const uint64_t *, vuint16m2_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vluxei16_v_m)))
vuint64m8_t vluxei16(vbool8_t, vuint64m8_t, const uint64_t *, vuint16m2_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vluxei32_v)))
vint64m1_t vluxei32(const int64_t *, vuint32mf2_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vluxei32_v_m)))
vint64m1_t vluxei32(vbool64_t, vint64m1_t, const int64_t *, vuint32mf2_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vluxei32_v)))
vint64m2_t vluxei32(const int64_t *, vuint32m1_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vluxei32_v_m)))
vint64m2_t vluxei32(vbool32_t, vint64m2_t, const int64_t *, vuint32m1_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vluxei32_v)))
vint64m4_t vluxei32(const int64_t *, vuint32m2_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vluxei32_v_m)))
vint64m4_t vluxei32(vbool16_t, vint64m4_t, const int64_t *, vuint32m2_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vluxei32_v)))
vint64m8_t vluxei32(const int64_t *, vuint32m4_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vluxei32_v_m)))
vint64m8_t vluxei32(vbool8_t, vint64m8_t, const int64_t *, vuint32m4_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vsuxseg2ei64_v)))
void vsuxseg2ei64(int16_t *, vuint64m4_t, vint16m1_t, vint16m1_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vsuxseg2ei64_v_m)))
void vsuxseg2ei64(vbool16_t, int16_t *, vuint64m4_t, vint16m1_t, vint16m1_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vsuxseg2ei64_v)))
void vsuxseg2ei64(int16_t *, vuint64m8_t, vint16m2_t, vint16m2_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vsuxseg2ei64_v_m)))
void vsuxseg2ei64(vbool8_t, int16_t *, vuint64m8_t, vint16m2_t, vint16m2_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vsuxseg2ei64_v)))
void vsuxseg2ei64(int16_t *, vuint64m2_t, vint16mf2_t, vint16mf2_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vsuxseg2ei64_v_m)))
void vsuxseg2ei64(vbool32_t, int16_t *, vuint64m2_t, vint16mf2_t, vint16mf2_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vsuxseg2ei64_v)))
void vsuxseg2ei64(int16_t *, vuint64m1_t, vint16mf4_t, vint16mf4_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vsuxseg2ei64_v_m)))
void vsuxseg2ei64(vbool64_t, int16_t *, vuint64m1_t, vint16mf4_t, vint16mf4_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vsuxseg2ei64_v)))
void vsuxseg2ei64(uint16_t *, vuint64m4_t, vuint16m1_t, vuint16m1_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vsuxseg2ei64_v_m)))
void vsuxseg2ei64(vbool16_t, uint16_t *, vuint64m4_t, vuint16m1_t, vuint16m1_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vsuxseg2ei64_v)))
void vsuxseg2ei64(uint16_t *, vuint64m8_t, vuint16m2_t, vuint16m2_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vsuxseg2ei64_v_m)))
void vsuxseg2ei64(vbool8_t, uint16_t *, vuint64m8_t, vuint16m2_t, vuint16m2_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vsuxseg2ei64_v)))
void vsuxseg2ei64(uint16_t *, vuint64m2_t, vuint16mf2_t, vuint16mf2_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vsuxseg2ei64_v_m)))
void vsuxseg2ei64(vbool32_t, uint16_t *, vuint64m2_t, vuint16mf2_t, vuint16mf2_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vsuxseg2ei64_v)))
void vsuxseg2ei64(uint16_t *, vuint64m1_t, vuint16mf4_t, vuint16mf4_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vsuxseg2ei64_v_m)))
void vsuxseg2ei64(vbool64_t, uint16_t *, vuint64m1_t, vuint16mf4_t, vuint16mf4_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vsuxseg3ei64_v)))
void vsuxseg3ei64(int16_t *, vuint64m4_t, vint16m1_t, vint16m1_t, vint16m1_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vsuxseg3ei64_v_m)))
void vsuxseg3ei64(vbool16_t, int16_t *, vuint64m4_t, vint16m1_t, vint16m1_t, vint16m1_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vsuxseg3ei64_v)))
void vsuxseg3ei64(int16_t *, vuint64m8_t, vint16m2_t, vint16m2_t, vint16m2_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vsuxseg3ei64_v_m)))
void vsuxseg3ei64(vbool8_t, int16_t *, vuint64m8_t, vint16m2_t, vint16m2_t, vint16m2_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vsuxseg3ei64_v)))
void vsuxseg3ei64(int16_t *, vuint64m2_t, vint16mf2_t, vint16mf2_t, vint16mf2_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vsuxseg3ei64_v_m)))
void vsuxseg3ei64(vbool32_t, int16_t *, vuint64m2_t, vint16mf2_t, vint16mf2_t, vint16mf2_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vsuxseg3ei64_v)))
void vsuxseg3ei64(int16_t *, vuint64m1_t, vint16mf4_t, vint16mf4_t, vint16mf4_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vsuxseg3ei64_v_m)))
void vsuxseg3ei64(vbool64_t, int16_t *, vuint64m1_t, vint16mf4_t, vint16mf4_t, vint16mf4_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vluxei32_v)))
vuint64m1_t vluxei32(const uint64_t *, vuint32mf2_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vluxei32_v_m)))
vuint64m1_t vluxei32(vbool64_t, vuint64m1_t, const uint64_t *, vuint32mf2_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vluxei32_v)))
vuint64m2_t vluxei32(const uint64_t *, vuint32m1_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vluxei32_v_m)))
vuint64m2_t vluxei32(vbool32_t, vuint64m2_t, const uint64_t *, vuint32m1_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vluxei32_v)))
vuint64m4_t vluxei32(const uint64_t *, vuint32m2_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vluxei32_v_m)))
vuint64m4_t vluxei32(vbool16_t, vuint64m4_t, const uint64_t *, vuint32m2_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vluxei32_v)))
vuint64m8_t vluxei32(const uint64_t *, vuint32m4_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vluxei32_v_m)))
vuint64m8_t vluxei32(vbool8_t, vuint64m8_t, const uint64_t *, vuint32m4_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vsuxseg3ei64_v)))
void vsuxseg3ei64(uint16_t *, vuint64m4_t, vuint16m1_t, vuint16m1_t, vuint16m1_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vsuxseg3ei64_v_m)))
void vsuxseg3ei64(vbool16_t, uint16_t *, vuint64m4_t, vuint16m1_t, vuint16m1_t, vuint16m1_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vsuxseg3ei64_v)))
void vsuxseg3ei64(uint16_t *, vuint64m8_t, vuint16m2_t, vuint16m2_t, vuint16m2_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vsuxseg3ei64_v_m)))
void vsuxseg3ei64(vbool8_t, uint16_t *, vuint64m8_t, vuint16m2_t, vuint16m2_t, vuint16m2_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vsuxseg3ei64_v)))
void vsuxseg3ei64(uint16_t *, vuint64m2_t, vuint16mf2_t, vuint16mf2_t, vuint16mf2_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vsuxseg3ei64_v_m)))
void vsuxseg3ei64(vbool32_t, uint16_t *, vuint64m2_t, vuint16mf2_t, vuint16mf2_t, vuint16mf2_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vsuxseg3ei64_v)))
void vsuxseg3ei64(uint16_t *, vuint64m1_t, vuint16mf4_t, vuint16mf4_t, vuint16mf4_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vsuxseg3ei64_v_m)))
void vsuxseg3ei64(vbool64_t, uint16_t *, vuint64m1_t, vuint16mf4_t, vuint16mf4_t, vuint16mf4_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vsuxseg4ei64_v)))
void vsuxseg4ei64(int16_t *, vuint64m4_t, vint16m1_t, vint16m1_t, vint16m1_t, vint16m1_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vsuxseg4ei64_v_m)))
void vsuxseg4ei64(vbool16_t, int16_t *, vuint64m4_t, vint16m1_t, vint16m1_t, vint16m1_t, vint16m1_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vsuxseg4ei64_v)))
void vsuxseg4ei64(int16_t *, vuint64m8_t, vint16m2_t, vint16m2_t, vint16m2_t, vint16m2_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vsuxseg4ei64_v_m)))
void vsuxseg4ei64(vbool8_t, int16_t *, vuint64m8_t, vint16m2_t, vint16m2_t, vint16m2_t, vint16m2_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vsuxseg4ei64_v)))
void vsuxseg4ei64(int16_t *, vuint64m2_t, vint16mf2_t, vint16mf2_t, vint16mf2_t, vint16mf2_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vsuxseg4ei64_v_m)))
void vsuxseg4ei64(vbool32_t, int16_t *, vuint64m2_t, vint16mf2_t, vint16mf2_t, vint16mf2_t, vint16mf2_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vsuxseg4ei64_v)))
void vsuxseg4ei64(int16_t *, vuint64m1_t, vint16mf4_t, vint16mf4_t, vint16mf4_t, vint16mf4_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vsuxseg4ei64_v_m)))
void vsuxseg4ei64(vbool64_t, int16_t *, vuint64m1_t, vint16mf4_t, vint16mf4_t, vint16mf4_t, vint16mf4_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vsuxseg4ei64_v)))
void vsuxseg4ei64(uint16_t *, vuint64m4_t, vuint16m1_t, vuint16m1_t, vuint16m1_t, vuint16m1_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vsuxseg4ei64_v_m)))
void vsuxseg4ei64(vbool16_t, uint16_t *, vuint64m4_t, vuint16m1_t, vuint16m1_t, vuint16m1_t, vuint16m1_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vsuxseg4ei64_v)))
void vsuxseg4ei64(uint16_t *, vuint64m8_t, vuint16m2_t, vuint16m2_t, vuint16m2_t, vuint16m2_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vsuxseg4ei64_v_m)))
void vsuxseg4ei64(vbool8_t, uint16_t *, vuint64m8_t, vuint16m2_t, vuint16m2_t, vuint16m2_t, vuint16m2_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vsuxseg4ei64_v)))
void vsuxseg4ei64(uint16_t *, vuint64m2_t, vuint16mf2_t, vuint16mf2_t, vuint16mf2_t, vuint16mf2_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vsuxseg4ei64_v_m)))
void vsuxseg4ei64(vbool32_t, uint16_t *, vuint64m2_t, vuint16mf2_t, vuint16mf2_t, vuint16mf2_t, vuint16mf2_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vsuxseg4ei64_v)))
void vsuxseg4ei64(uint16_t *, vuint64m1_t, vuint16mf4_t, vuint16mf4_t, vuint16mf4_t, vuint16mf4_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vsuxseg4ei64_v_m)))
void vsuxseg4ei64(vbool64_t, uint16_t *, vuint64m1_t, vuint16mf4_t, vuint16mf4_t, vuint16mf4_t, vuint16mf4_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vsuxseg5ei64_v)))
void vsuxseg5ei64(int16_t *, vuint64m4_t, vint16m1_t, vint16m1_t, vint16m1_t, vint16m1_t, vint16m1_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vsuxseg5ei64_v_m)))
void vsuxseg5ei64(vbool16_t, int16_t *, vuint64m4_t, vint16m1_t, vint16m1_t, vint16m1_t, vint16m1_t, vint16m1_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vsuxseg5ei64_v)))
void vsuxseg5ei64(int16_t *, vuint64m2_t, vint16mf2_t, vint16mf2_t, vint16mf2_t, vint16mf2_t, vint16mf2_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vsuxseg5ei64_v_m)))
void vsuxseg5ei64(vbool32_t, int16_t *, vuint64m2_t, vint16mf2_t, vint16mf2_t, vint16mf2_t, vint16mf2_t, vint16mf2_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vsuxseg5ei64_v)))
void vsuxseg5ei64(int16_t *, vuint64m1_t, vint16mf4_t, vint16mf4_t, vint16mf4_t, vint16mf4_t, vint16mf4_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vsuxseg5ei64_v_m)))
void vsuxseg5ei64(vbool64_t, int16_t *, vuint64m1_t, vint16mf4_t, vint16mf4_t, vint16mf4_t, vint16mf4_t, vint16mf4_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vsuxseg5ei64_v)))
void vsuxseg5ei64(uint16_t *, vuint64m4_t, vuint16m1_t, vuint16m1_t, vuint16m1_t, vuint16m1_t, vuint16m1_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vsuxseg5ei64_v_m)))
void vsuxseg5ei64(vbool16_t, uint16_t *, vuint64m4_t, vuint16m1_t, vuint16m1_t, vuint16m1_t, vuint16m1_t, vuint16m1_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vsuxseg5ei64_v)))
void vsuxseg5ei64(uint16_t *, vuint64m2_t, vuint16mf2_t, vuint16mf2_t, vuint16mf2_t, vuint16mf2_t, vuint16mf2_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vsuxseg5ei64_v_m)))
void vsuxseg5ei64(vbool32_t, uint16_t *, vuint64m2_t, vuint16mf2_t, vuint16mf2_t, vuint16mf2_t, vuint16mf2_t, vuint16mf2_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vsuxseg5ei64_v)))
void vsuxseg5ei64(uint16_t *, vuint64m1_t, vuint16mf4_t, vuint16mf4_t, vuint16mf4_t, vuint16mf4_t, vuint16mf4_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vsuxseg5ei64_v_m)))
void vsuxseg5ei64(vbool64_t, uint16_t *, vuint64m1_t, vuint16mf4_t, vuint16mf4_t, vuint16mf4_t, vuint16mf4_t, vuint16mf4_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vsuxseg6ei64_v)))
void vsuxseg6ei64(int16_t *, vuint64m4_t, vint16m1_t, vint16m1_t, vint16m1_t, vint16m1_t, vint16m1_t, vint16m1_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vsuxseg6ei64_v_m)))
void vsuxseg6ei64(vbool16_t, int16_t *, vuint64m4_t, vint16m1_t, vint16m1_t, vint16m1_t, vint16m1_t, vint16m1_t, vint16m1_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vsuxseg6ei64_v)))
void vsuxseg6ei64(int16_t *, vuint64m2_t, vint16mf2_t, vint16mf2_t, vint16mf2_t, vint16mf2_t, vint16mf2_t, vint16mf2_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vsuxseg6ei64_v_m)))
void vsuxseg6ei64(vbool32_t, int16_t *, vuint64m2_t, vint16mf2_t, vint16mf2_t, vint16mf2_t, vint16mf2_t, vint16mf2_t, vint16mf2_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vsuxseg6ei64_v)))
void vsuxseg6ei64(int16_t *, vuint64m1_t, vint16mf4_t, vint16mf4_t, vint16mf4_t, vint16mf4_t, vint16mf4_t, vint16mf4_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vsuxseg6ei64_v_m)))
void vsuxseg6ei64(vbool64_t, int16_t *, vuint64m1_t, vint16mf4_t, vint16mf4_t, vint16mf4_t, vint16mf4_t, vint16mf4_t, vint16mf4_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vsuxseg6ei64_v)))
void vsuxseg6ei64(uint16_t *, vuint64m4_t, vuint16m1_t, vuint16m1_t, vuint16m1_t, vuint16m1_t, vuint16m1_t, vuint16m1_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vsuxseg6ei64_v_m)))
void vsuxseg6ei64(vbool16_t, uint16_t *, vuint64m4_t, vuint16m1_t, vuint16m1_t, vuint16m1_t, vuint16m1_t, vuint16m1_t, vuint16m1_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vsuxseg6ei64_v)))
void vsuxseg6ei64(uint16_t *, vuint64m2_t, vuint16mf2_t, vuint16mf2_t, vuint16mf2_t, vuint16mf2_t, vuint16mf2_t, vuint16mf2_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vsuxseg6ei64_v_m)))
void vsuxseg6ei64(vbool32_t, uint16_t *, vuint64m2_t, vuint16mf2_t, vuint16mf2_t, vuint16mf2_t, vuint16mf2_t, vuint16mf2_t, vuint16mf2_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vsuxseg6ei64_v)))
void vsuxseg6ei64(uint16_t *, vuint64m1_t, vuint16mf4_t, vuint16mf4_t, vuint16mf4_t, vuint16mf4_t, vuint16mf4_t, vuint16mf4_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vsuxseg6ei64_v_m)))
void vsuxseg6ei64(vbool64_t, uint16_t *, vuint64m1_t, vuint16mf4_t, vuint16mf4_t, vuint16mf4_t, vuint16mf4_t, vuint16mf4_t, vuint16mf4_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vsuxseg7ei64_v)))
void vsuxseg7ei64(int16_t *, vuint64m4_t, vint16m1_t, vint16m1_t, vint16m1_t, vint16m1_t, vint16m1_t, vint16m1_t, vint16m1_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vsuxseg7ei64_v_m)))
void vsuxseg7ei64(vbool16_t, int16_t *, vuint64m4_t, vint16m1_t, vint16m1_t, vint16m1_t, vint16m1_t, vint16m1_t, vint16m1_t, vint16m1_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vsuxseg7ei64_v)))
void vsuxseg7ei64(int16_t *, vuint64m2_t, vint16mf2_t, vint16mf2_t, vint16mf2_t, vint16mf2_t, vint16mf2_t, vint16mf2_t, vint16mf2_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vsuxseg7ei64_v_m)))
void vsuxseg7ei64(vbool32_t, int16_t *, vuint64m2_t, vint16mf2_t, vint16mf2_t, vint16mf2_t, vint16mf2_t, vint16mf2_t, vint16mf2_t, vint16mf2_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vsuxseg7ei64_v)))
void vsuxseg7ei64(int16_t *, vuint64m1_t, vint16mf4_t, vint16mf4_t, vint16mf4_t, vint16mf4_t, vint16mf4_t, vint16mf4_t, vint16mf4_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vsuxseg7ei64_v_m)))
void vsuxseg7ei64(vbool64_t, int16_t *, vuint64m1_t, vint16mf4_t, vint16mf4_t, vint16mf4_t, vint16mf4_t, vint16mf4_t, vint16mf4_t, vint16mf4_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vsuxseg7ei64_v)))
void vsuxseg7ei64(uint16_t *, vuint64m4_t, vuint16m1_t, vuint16m1_t, vuint16m1_t, vuint16m1_t, vuint16m1_t, vuint16m1_t, vuint16m1_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vsuxseg7ei64_v_m)))
void vsuxseg7ei64(vbool16_t, uint16_t *, vuint64m4_t, vuint16m1_t, vuint16m1_t, vuint16m1_t, vuint16m1_t, vuint16m1_t, vuint16m1_t, vuint16m1_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vsuxseg7ei64_v)))
void vsuxseg7ei64(uint16_t *, vuint64m2_t, vuint16mf2_t, vuint16mf2_t, vuint16mf2_t, vuint16mf2_t, vuint16mf2_t, vuint16mf2_t, vuint16mf2_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vsuxseg7ei64_v_m)))
void vsuxseg7ei64(vbool32_t, uint16_t *, vuint64m2_t, vuint16mf2_t, vuint16mf2_t, vuint16mf2_t, vuint16mf2_t, vuint16mf2_t, vuint16mf2_t, vuint16mf2_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vsuxseg7ei64_v)))
void vsuxseg7ei64(uint16_t *, vuint64m1_t, vuint16mf4_t, vuint16mf4_t, vuint16mf4_t, vuint16mf4_t, vuint16mf4_t, vuint16mf4_t, vuint16mf4_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vsuxseg7ei64_v_m)))
void vsuxseg7ei64(vbool64_t, uint16_t *, vuint64m1_t, vuint16mf4_t, vuint16mf4_t, vuint16mf4_t, vuint16mf4_t, vuint16mf4_t, vuint16mf4_t, vuint16mf4_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vsuxseg8ei64_v)))
void vsuxseg8ei64(int16_t *, vuint64m4_t, vint16m1_t, vint16m1_t, vint16m1_t, vint16m1_t, vint16m1_t, vint16m1_t, vint16m1_t, vint16m1_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vsuxseg8ei64_v_m)))
void vsuxseg8ei64(vbool16_t, int16_t *, vuint64m4_t, vint16m1_t, vint16m1_t, vint16m1_t, vint16m1_t, vint16m1_t, vint16m1_t, vint16m1_t, vint16m1_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vsuxseg8ei64_v)))
void vsuxseg8ei64(int16_t *, vuint64m2_t, vint16mf2_t, vint16mf2_t, vint16mf2_t, vint16mf2_t, vint16mf2_t, vint16mf2_t, vint16mf2_t, vint16mf2_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vsuxseg8ei64_v_m)))
void vsuxseg8ei64(vbool32_t, int16_t *, vuint64m2_t, vint16mf2_t, vint16mf2_t, vint16mf2_t, vint16mf2_t, vint16mf2_t, vint16mf2_t, vint16mf2_t, vint16mf2_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vsuxseg8ei64_v)))
void vsuxseg8ei64(int16_t *, vuint64m1_t, vint16mf4_t, vint16mf4_t, vint16mf4_t, vint16mf4_t, vint16mf4_t, vint16mf4_t, vint16mf4_t, vint16mf4_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vsuxseg8ei64_v_m)))
void vsuxseg8ei64(vbool64_t, int16_t *, vuint64m1_t, vint16mf4_t, vint16mf4_t, vint16mf4_t, vint16mf4_t, vint16mf4_t, vint16mf4_t, vint16mf4_t, vint16mf4_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vsuxseg8ei64_v)))
void vsuxseg8ei64(uint16_t *, vuint64m4_t, vuint16m1_t, vuint16m1_t, vuint16m1_t, vuint16m1_t, vuint16m1_t, vuint16m1_t, vuint16m1_t, vuint16m1_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vsuxseg8ei64_v_m)))
void vsuxseg8ei64(vbool16_t, uint16_t *, vuint64m4_t, vuint16m1_t, vuint16m1_t, vuint16m1_t, vuint16m1_t, vuint16m1_t, vuint16m1_t, vuint16m1_t, vuint16m1_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vsuxseg8ei64_v)))
void vsuxseg8ei64(uint16_t *, vuint64m2_t, vuint16mf2_t, vuint16mf2_t, vuint16mf2_t, vuint16mf2_t, vuint16mf2_t, vuint16mf2_t, vuint16mf2_t, vuint16mf2_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vsuxseg8ei64_v_m)))
void vsuxseg8ei64(vbool32_t, uint16_t *, vuint64m2_t, vuint16mf2_t, vuint16mf2_t, vuint16mf2_t, vuint16mf2_t, vuint16mf2_t, vuint16mf2_t, vuint16mf2_t, vuint16mf2_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vsuxseg8ei64_v)))
void vsuxseg8ei64(uint16_t *, vuint64m1_t, vuint16mf4_t, vuint16mf4_t, vuint16mf4_t, vuint16mf4_t, vuint16mf4_t, vuint16mf4_t, vuint16mf4_t, vuint16mf4_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vsuxseg8ei64_v_m)))
void vsuxseg8ei64(vbool64_t, uint16_t *, vuint64m1_t, vuint16mf4_t, vuint16mf4_t, vuint16mf4_t, vuint16mf4_t, vuint16mf4_t, vuint16mf4_t, vuint16mf4_t, vuint16mf4_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vsuxseg2ei64_v)))
void vsuxseg2ei64(int32_t *, vuint64m2_t, vint32m1_t, vint32m1_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vsuxseg2ei64_v_m)))
void vsuxseg2ei64(vbool32_t, int32_t *, vuint64m2_t, vint32m1_t, vint32m1_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vsuxseg2ei64_v)))
void vsuxseg2ei64(int32_t *, vuint64m4_t, vint32m2_t, vint32m2_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vsuxseg2ei64_v_m)))
void vsuxseg2ei64(vbool16_t, int32_t *, vuint64m4_t, vint32m2_t, vint32m2_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vsuxseg2ei64_v)))
void vsuxseg2ei64(int32_t *, vuint64m8_t, vint32m4_t, vint32m4_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vsuxseg2ei64_v_m)))
void vsuxseg2ei64(vbool8_t, int32_t *, vuint64m8_t, vint32m4_t, vint32m4_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vsuxseg2ei64_v)))
void vsuxseg2ei64(int32_t *, vuint64m1_t, vint32mf2_t, vint32mf2_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vsuxseg2ei64_v_m)))
void vsuxseg2ei64(vbool64_t, int32_t *, vuint64m1_t, vint32mf2_t, vint32mf2_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vsuxseg2ei64_v)))
void vsuxseg2ei64(uint32_t *, vuint64m2_t, vuint32m1_t, vuint32m1_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vsuxseg2ei64_v_m)))
void vsuxseg2ei64(vbool32_t, uint32_t *, vuint64m2_t, vuint32m1_t, vuint32m1_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vsuxseg2ei64_v)))
void vsuxseg2ei64(uint32_t *, vuint64m4_t, vuint32m2_t, vuint32m2_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vsuxseg2ei64_v_m)))
void vsuxseg2ei64(vbool16_t, uint32_t *, vuint64m4_t, vuint32m2_t, vuint32m2_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vsuxseg2ei64_v)))
void vsuxseg2ei64(uint32_t *, vuint64m8_t, vuint32m4_t, vuint32m4_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vsuxseg2ei64_v_m)))
void vsuxseg2ei64(vbool8_t, uint32_t *, vuint64m8_t, vuint32m4_t, vuint32m4_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vsuxseg2ei64_v)))
void vsuxseg2ei64(uint32_t *, vuint64m1_t, vuint32mf2_t, vuint32mf2_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vsuxseg2ei64_v_m)))
void vsuxseg2ei64(vbool64_t, uint32_t *, vuint64m1_t, vuint32mf2_t, vuint32mf2_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vsuxseg3ei64_v)))
void vsuxseg3ei64(int32_t *, vuint64m2_t, vint32m1_t, vint32m1_t, vint32m1_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vsuxseg3ei64_v_m)))
void vsuxseg3ei64(vbool32_t, int32_t *, vuint64m2_t, vint32m1_t, vint32m1_t, vint32m1_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vsuxseg3ei64_v)))
void vsuxseg3ei64(int32_t *, vuint64m4_t, vint32m2_t, vint32m2_t, vint32m2_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vsuxseg3ei64_v_m)))
void vsuxseg3ei64(vbool16_t, int32_t *, vuint64m4_t, vint32m2_t, vint32m2_t, vint32m2_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vsuxseg3ei64_v)))
void vsuxseg3ei64(int32_t *, vuint64m1_t, vint32mf2_t, vint32mf2_t, vint32mf2_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vsuxseg3ei64_v_m)))
void vsuxseg3ei64(vbool64_t, int32_t *, vuint64m1_t, vint32mf2_t, vint32mf2_t, vint32mf2_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vsuxseg3ei64_v)))
void vsuxseg3ei64(uint32_t *, vuint64m2_t, vuint32m1_t, vuint32m1_t, vuint32m1_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vsuxseg3ei64_v_m)))
void vsuxseg3ei64(vbool32_t, uint32_t *, vuint64m2_t, vuint32m1_t, vuint32m1_t, vuint32m1_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vsuxseg3ei64_v)))
void vsuxseg3ei64(uint32_t *, vuint64m4_t, vuint32m2_t, vuint32m2_t, vuint32m2_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vsuxseg3ei64_v_m)))
void vsuxseg3ei64(vbool16_t, uint32_t *, vuint64m4_t, vuint32m2_t, vuint32m2_t, vuint32m2_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vsuxseg3ei64_v)))
void vsuxseg3ei64(uint32_t *, vuint64m1_t, vuint32mf2_t, vuint32mf2_t, vuint32mf2_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vsuxseg3ei64_v_m)))
void vsuxseg3ei64(vbool64_t, uint32_t *, vuint64m1_t, vuint32mf2_t, vuint32mf2_t, vuint32mf2_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vsuxseg4ei64_v)))
void vsuxseg4ei64(int32_t *, vuint64m2_t, vint32m1_t, vint32m1_t, vint32m1_t, vint32m1_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vsuxseg4ei64_v_m)))
void vsuxseg4ei64(vbool32_t, int32_t *, vuint64m2_t, vint32m1_t, vint32m1_t, vint32m1_t, vint32m1_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vsuxseg4ei64_v)))
void vsuxseg4ei64(int32_t *, vuint64m4_t, vint32m2_t, vint32m2_t, vint32m2_t, vint32m2_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vsuxseg4ei64_v_m)))
void vsuxseg4ei64(vbool16_t, int32_t *, vuint64m4_t, vint32m2_t, vint32m2_t, vint32m2_t, vint32m2_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vsuxseg4ei64_v)))
void vsuxseg4ei64(int32_t *, vuint64m1_t, vint32mf2_t, vint32mf2_t, vint32mf2_t, vint32mf2_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vsuxseg4ei64_v_m)))
void vsuxseg4ei64(vbool64_t, int32_t *, vuint64m1_t, vint32mf2_t, vint32mf2_t, vint32mf2_t, vint32mf2_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vsuxseg4ei64_v)))
void vsuxseg4ei64(uint32_t *, vuint64m2_t, vuint32m1_t, vuint32m1_t, vuint32m1_t, vuint32m1_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vsuxseg4ei64_v_m)))
void vsuxseg4ei64(vbool32_t, uint32_t *, vuint64m2_t, vuint32m1_t, vuint32m1_t, vuint32m1_t, vuint32m1_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vsuxseg4ei64_v)))
void vsuxseg4ei64(uint32_t *, vuint64m4_t, vuint32m2_t, vuint32m2_t, vuint32m2_t, vuint32m2_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vsuxseg4ei64_v_m)))
void vsuxseg4ei64(vbool16_t, uint32_t *, vuint64m4_t, vuint32m2_t, vuint32m2_t, vuint32m2_t, vuint32m2_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vsuxseg4ei64_v)))
void vsuxseg4ei64(uint32_t *, vuint64m1_t, vuint32mf2_t, vuint32mf2_t, vuint32mf2_t, vuint32mf2_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vsuxseg4ei64_v_m)))
void vsuxseg4ei64(vbool64_t, uint32_t *, vuint64m1_t, vuint32mf2_t, vuint32mf2_t, vuint32mf2_t, vuint32mf2_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vsuxseg5ei64_v)))
void vsuxseg5ei64(int32_t *, vuint64m2_t, vint32m1_t, vint32m1_t, vint32m1_t, vint32m1_t, vint32m1_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vsuxseg5ei64_v_m)))
void vsuxseg5ei64(vbool32_t, int32_t *, vuint64m2_t, vint32m1_t, vint32m1_t, vint32m1_t, vint32m1_t, vint32m1_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vsuxseg5ei64_v)))
void vsuxseg5ei64(int32_t *, vuint64m1_t, vint32mf2_t, vint32mf2_t, vint32mf2_t, vint32mf2_t, vint32mf2_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vsuxseg5ei64_v_m)))
void vsuxseg5ei64(vbool64_t, int32_t *, vuint64m1_t, vint32mf2_t, vint32mf2_t, vint32mf2_t, vint32mf2_t, vint32mf2_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vsuxseg5ei64_v)))
void vsuxseg5ei64(uint32_t *, vuint64m2_t, vuint32m1_t, vuint32m1_t, vuint32m1_t, vuint32m1_t, vuint32m1_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vsuxseg5ei64_v_m)))
void vsuxseg5ei64(vbool32_t, uint32_t *, vuint64m2_t, vuint32m1_t, vuint32m1_t, vuint32m1_t, vuint32m1_t, vuint32m1_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vsuxseg5ei64_v)))
void vsuxseg5ei64(uint32_t *, vuint64m1_t, vuint32mf2_t, vuint32mf2_t, vuint32mf2_t, vuint32mf2_t, vuint32mf2_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vsuxseg5ei64_v_m)))
void vsuxseg5ei64(vbool64_t, uint32_t *, vuint64m1_t, vuint32mf2_t, vuint32mf2_t, vuint32mf2_t, vuint32mf2_t, vuint32mf2_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vsuxseg6ei64_v)))
void vsuxseg6ei64(int32_t *, vuint64m2_t, vint32m1_t, vint32m1_t, vint32m1_t, vint32m1_t, vint32m1_t, vint32m1_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vsuxseg6ei64_v_m)))
void vsuxseg6ei64(vbool32_t, int32_t *, vuint64m2_t, vint32m1_t, vint32m1_t, vint32m1_t, vint32m1_t, vint32m1_t, vint32m1_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vsuxseg6ei64_v)))
void vsuxseg6ei64(int32_t *, vuint64m1_t, vint32mf2_t, vint32mf2_t, vint32mf2_t, vint32mf2_t, vint32mf2_t, vint32mf2_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vsuxseg6ei64_v_m)))
void vsuxseg6ei64(vbool64_t, int32_t *, vuint64m1_t, vint32mf2_t, vint32mf2_t, vint32mf2_t, vint32mf2_t, vint32mf2_t, vint32mf2_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vsuxseg6ei64_v)))
void vsuxseg6ei64(uint32_t *, vuint64m2_t, vuint32m1_t, vuint32m1_t, vuint32m1_t, vuint32m1_t, vuint32m1_t, vuint32m1_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vsuxseg6ei64_v_m)))
void vsuxseg6ei64(vbool32_t, uint32_t *, vuint64m2_t, vuint32m1_t, vuint32m1_t, vuint32m1_t, vuint32m1_t, vuint32m1_t, vuint32m1_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vsuxseg6ei64_v)))
void vsuxseg6ei64(uint32_t *, vuint64m1_t, vuint32mf2_t, vuint32mf2_t, vuint32mf2_t, vuint32mf2_t, vuint32mf2_t, vuint32mf2_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vsuxseg6ei64_v_m)))
void vsuxseg6ei64(vbool64_t, uint32_t *, vuint64m1_t, vuint32mf2_t, vuint32mf2_t, vuint32mf2_t, vuint32mf2_t, vuint32mf2_t, vuint32mf2_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vsuxseg7ei64_v)))
void vsuxseg7ei64(int32_t *, vuint64m2_t, vint32m1_t, vint32m1_t, vint32m1_t, vint32m1_t, vint32m1_t, vint32m1_t, vint32m1_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vsuxseg7ei64_v_m)))
void vsuxseg7ei64(vbool32_t, int32_t *, vuint64m2_t, vint32m1_t, vint32m1_t, vint32m1_t, vint32m1_t, vint32m1_t, vint32m1_t, vint32m1_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vsuxseg7ei64_v)))
void vsuxseg7ei64(int32_t *, vuint64m1_t, vint32mf2_t, vint32mf2_t, vint32mf2_t, vint32mf2_t, vint32mf2_t, vint32mf2_t, vint32mf2_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vsuxseg7ei64_v_m)))
void vsuxseg7ei64(vbool64_t, int32_t *, vuint64m1_t, vint32mf2_t, vint32mf2_t, vint32mf2_t, vint32mf2_t, vint32mf2_t, vint32mf2_t, vint32mf2_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vsuxseg7ei64_v)))
void vsuxseg7ei64(uint32_t *, vuint64m2_t, vuint32m1_t, vuint32m1_t, vuint32m1_t, vuint32m1_t, vuint32m1_t, vuint32m1_t, vuint32m1_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vsuxseg7ei64_v_m)))
void vsuxseg7ei64(vbool32_t, uint32_t *, vuint64m2_t, vuint32m1_t, vuint32m1_t, vuint32m1_t, vuint32m1_t, vuint32m1_t, vuint32m1_t, vuint32m1_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vsuxseg7ei64_v)))
void vsuxseg7ei64(uint32_t *, vuint64m1_t, vuint32mf2_t, vuint32mf2_t, vuint32mf2_t, vuint32mf2_t, vuint32mf2_t, vuint32mf2_t, vuint32mf2_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vsuxseg7ei64_v_m)))
void vsuxseg7ei64(vbool64_t, uint32_t *, vuint64m1_t, vuint32mf2_t, vuint32mf2_t, vuint32mf2_t, vuint32mf2_t, vuint32mf2_t, vuint32mf2_t, vuint32mf2_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vsuxseg8ei64_v)))
void vsuxseg8ei64(int32_t *, vuint64m2_t, vint32m1_t, vint32m1_t, vint32m1_t, vint32m1_t, vint32m1_t, vint32m1_t, vint32m1_t, vint32m1_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vsuxseg8ei64_v_m)))
void vsuxseg8ei64(vbool32_t, int32_t *, vuint64m2_t, vint32m1_t, vint32m1_t, vint32m1_t, vint32m1_t, vint32m1_t, vint32m1_t, vint32m1_t, vint32m1_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vsuxseg8ei64_v)))
void vsuxseg8ei64(int32_t *, vuint64m1_t, vint32mf2_t, vint32mf2_t, vint32mf2_t, vint32mf2_t, vint32mf2_t, vint32mf2_t, vint32mf2_t, vint32mf2_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vsuxseg8ei64_v_m)))
void vsuxseg8ei64(vbool64_t, int32_t *, vuint64m1_t, vint32mf2_t, vint32mf2_t, vint32mf2_t, vint32mf2_t, vint32mf2_t, vint32mf2_t, vint32mf2_t, vint32mf2_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vsuxseg8ei64_v)))
void vsuxseg8ei64(uint32_t *, vuint64m2_t, vuint32m1_t, vuint32m1_t, vuint32m1_t, vuint32m1_t, vuint32m1_t, vuint32m1_t, vuint32m1_t, vuint32m1_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vsuxseg8ei64_v_m)))
void vsuxseg8ei64(vbool32_t, uint32_t *, vuint64m2_t, vuint32m1_t, vuint32m1_t, vuint32m1_t, vuint32m1_t, vuint32m1_t, vuint32m1_t, vuint32m1_t, vuint32m1_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vsuxseg8ei64_v)))
void vsuxseg8ei64(uint32_t *, vuint64m1_t, vuint32mf2_t, vuint32mf2_t, vuint32mf2_t, vuint32mf2_t, vuint32mf2_t, vuint32mf2_t, vuint32mf2_t, vuint32mf2_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vsuxseg8ei64_v_m)))
void vsuxseg8ei64(vbool64_t, uint32_t *, vuint64m1_t, vuint32mf2_t, vuint32mf2_t, vuint32mf2_t, vuint32mf2_t, vuint32mf2_t, vuint32mf2_t, vuint32mf2_t, vuint32mf2_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vsuxseg2ei8_v)))
void vsuxseg2ei8(int64_t *, vuint8mf8_t, vint64m1_t, vint64m1_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vsuxseg2ei8_v_m)))
void vsuxseg2ei8(vbool64_t, int64_t *, vuint8mf8_t, vint64m1_t, vint64m1_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vsuxseg2ei8_v)))
void vsuxseg2ei8(int64_t *, vuint8mf4_t, vint64m2_t, vint64m2_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vsuxseg2ei8_v_m)))
void vsuxseg2ei8(vbool32_t, int64_t *, vuint8mf4_t, vint64m2_t, vint64m2_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vsuxseg2ei8_v)))
void vsuxseg2ei8(int64_t *, vuint8mf2_t, vint64m4_t, vint64m4_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vsuxseg2ei8_v_m)))
void vsuxseg2ei8(vbool16_t, int64_t *, vuint8mf2_t, vint64m4_t, vint64m4_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vsuxseg2ei8_v)))
void vsuxseg2ei8(uint64_t *, vuint8mf8_t, vuint64m1_t, vuint64m1_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vsuxseg2ei8_v_m)))
void vsuxseg2ei8(vbool64_t, uint64_t *, vuint8mf8_t, vuint64m1_t, vuint64m1_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vsuxseg2ei8_v)))
void vsuxseg2ei8(uint64_t *, vuint8mf4_t, vuint64m2_t, vuint64m2_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vsuxseg2ei8_v_m)))
void vsuxseg2ei8(vbool32_t, uint64_t *, vuint8mf4_t, vuint64m2_t, vuint64m2_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vsuxseg2ei8_v)))
void vsuxseg2ei8(uint64_t *, vuint8mf2_t, vuint64m4_t, vuint64m4_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vsuxseg2ei8_v_m)))
void vsuxseg2ei8(vbool16_t, uint64_t *, vuint8mf2_t, vuint64m4_t, vuint64m4_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vsuxseg3ei8_v)))
void vsuxseg3ei8(int64_t *, vuint8mf8_t, vint64m1_t, vint64m1_t, vint64m1_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vsuxseg3ei8_v_m)))
void vsuxseg3ei8(vbool64_t, int64_t *, vuint8mf8_t, vint64m1_t, vint64m1_t, vint64m1_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vsuxseg3ei8_v)))
void vsuxseg3ei8(int64_t *, vuint8mf4_t, vint64m2_t, vint64m2_t, vint64m2_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vsuxseg3ei8_v_m)))
void vsuxseg3ei8(vbool32_t, int64_t *, vuint8mf4_t, vint64m2_t, vint64m2_t, vint64m2_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vsuxseg3ei8_v)))
void vsuxseg3ei8(uint64_t *, vuint8mf8_t, vuint64m1_t, vuint64m1_t, vuint64m1_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vsuxseg3ei8_v_m)))
void vsuxseg3ei8(vbool64_t, uint64_t *, vuint8mf8_t, vuint64m1_t, vuint64m1_t, vuint64m1_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vsuxseg3ei8_v)))
void vsuxseg3ei8(uint64_t *, vuint8mf4_t, vuint64m2_t, vuint64m2_t, vuint64m2_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vsuxseg3ei8_v_m)))
void vsuxseg3ei8(vbool32_t, uint64_t *, vuint8mf4_t, vuint64m2_t, vuint64m2_t, vuint64m2_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vsuxseg4ei8_v)))
void vsuxseg4ei8(int64_t *, vuint8mf8_t, vint64m1_t, vint64m1_t, vint64m1_t, vint64m1_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vsuxseg4ei8_v_m)))
void vsuxseg4ei8(vbool64_t, int64_t *, vuint8mf8_t, vint64m1_t, vint64m1_t, vint64m1_t, vint64m1_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vsuxseg4ei8_v)))
void vsuxseg4ei8(int64_t *, vuint8mf4_t, vint64m2_t, vint64m2_t, vint64m2_t, vint64m2_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vsuxseg4ei8_v_m)))
void vsuxseg4ei8(vbool32_t, int64_t *, vuint8mf4_t, vint64m2_t, vint64m2_t, vint64m2_t, vint64m2_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vsuxseg4ei8_v)))
void vsuxseg4ei8(uint64_t *, vuint8mf8_t, vuint64m1_t, vuint64m1_t, vuint64m1_t, vuint64m1_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vsuxseg4ei8_v_m)))
void vsuxseg4ei8(vbool64_t, uint64_t *, vuint8mf8_t, vuint64m1_t, vuint64m1_t, vuint64m1_t, vuint64m1_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vsuxseg4ei8_v)))
void vsuxseg4ei8(uint64_t *, vuint8mf4_t, vuint64m2_t, vuint64m2_t, vuint64m2_t, vuint64m2_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vsuxseg4ei8_v_m)))
void vsuxseg4ei8(vbool32_t, uint64_t *, vuint8mf4_t, vuint64m2_t, vuint64m2_t, vuint64m2_t, vuint64m2_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vsuxseg5ei8_v)))
void vsuxseg5ei8(int64_t *, vuint8mf8_t, vint64m1_t, vint64m1_t, vint64m1_t, vint64m1_t, vint64m1_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vsuxseg5ei8_v_m)))
void vsuxseg5ei8(vbool64_t, int64_t *, vuint8mf8_t, vint64m1_t, vint64m1_t, vint64m1_t, vint64m1_t, vint64m1_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vsuxseg5ei8_v)))
void vsuxseg5ei8(uint64_t *, vuint8mf8_t, vuint64m1_t, vuint64m1_t, vuint64m1_t, vuint64m1_t, vuint64m1_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vsuxseg5ei8_v_m)))
void vsuxseg5ei8(vbool64_t, uint64_t *, vuint8mf8_t, vuint64m1_t, vuint64m1_t, vuint64m1_t, vuint64m1_t, vuint64m1_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vsuxseg6ei8_v)))
void vsuxseg6ei8(int64_t *, vuint8mf8_t, vint64m1_t, vint64m1_t, vint64m1_t, vint64m1_t, vint64m1_t, vint64m1_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vsuxseg6ei8_v_m)))
void vsuxseg6ei8(vbool64_t, int64_t *, vuint8mf8_t, vint64m1_t, vint64m1_t, vint64m1_t, vint64m1_t, vint64m1_t, vint64m1_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vsuxseg6ei8_v)))
void vsuxseg6ei8(uint64_t *, vuint8mf8_t, vuint64m1_t, vuint64m1_t, vuint64m1_t, vuint64m1_t, vuint64m1_t, vuint64m1_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vsuxseg6ei8_v_m)))
void vsuxseg6ei8(vbool64_t, uint64_t *, vuint8mf8_t, vuint64m1_t, vuint64m1_t, vuint64m1_t, vuint64m1_t, vuint64m1_t, vuint64m1_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vsuxseg7ei8_v)))
void vsuxseg7ei8(int64_t *, vuint8mf8_t, vint64m1_t, vint64m1_t, vint64m1_t, vint64m1_t, vint64m1_t, vint64m1_t, vint64m1_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vsuxseg7ei8_v_m)))
void vsuxseg7ei8(vbool64_t, int64_t *, vuint8mf8_t, vint64m1_t, vint64m1_t, vint64m1_t, vint64m1_t, vint64m1_t, vint64m1_t, vint64m1_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vsuxseg7ei8_v)))
void vsuxseg7ei8(uint64_t *, vuint8mf8_t, vuint64m1_t, vuint64m1_t, vuint64m1_t, vuint64m1_t, vuint64m1_t, vuint64m1_t, vuint64m1_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vsuxseg7ei8_v_m)))
void vsuxseg7ei8(vbool64_t, uint64_t *, vuint8mf8_t, vuint64m1_t, vuint64m1_t, vuint64m1_t, vuint64m1_t, vuint64m1_t, vuint64m1_t, vuint64m1_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vsuxseg8ei8_v)))
void vsuxseg8ei8(int64_t *, vuint8mf8_t, vint64m1_t, vint64m1_t, vint64m1_t, vint64m1_t, vint64m1_t, vint64m1_t, vint64m1_t, vint64m1_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vsuxseg8ei8_v_m)))
void vsuxseg8ei8(vbool64_t, int64_t *, vuint8mf8_t, vint64m1_t, vint64m1_t, vint64m1_t, vint64m1_t, vint64m1_t, vint64m1_t, vint64m1_t, vint64m1_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vsuxseg8ei8_v)))
void vsuxseg8ei8(uint64_t *, vuint8mf8_t, vuint64m1_t, vuint64m1_t, vuint64m1_t, vuint64m1_t, vuint64m1_t, vuint64m1_t, vuint64m1_t, vuint64m1_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vsuxseg8ei8_v_m)))
void vsuxseg8ei8(vbool64_t, uint64_t *, vuint8mf8_t, vuint64m1_t, vuint64m1_t, vuint64m1_t, vuint64m1_t, vuint64m1_t, vuint64m1_t, vuint64m1_t, vuint64m1_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vsuxseg2ei16_v)))
void vsuxseg2ei16(int64_t *, vuint16mf4_t, vint64m1_t, vint64m1_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vsuxseg2ei16_v_m)))
void vsuxseg2ei16(vbool64_t, int64_t *, vuint16mf4_t, vint64m1_t, vint64m1_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vsuxseg2ei16_v)))
void vsuxseg2ei16(int64_t *, vuint16mf2_t, vint64m2_t, vint64m2_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vsuxseg2ei16_v_m)))
void vsuxseg2ei16(vbool32_t, int64_t *, vuint16mf2_t, vint64m2_t, vint64m2_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vsuxseg2ei16_v)))
void vsuxseg2ei16(int64_t *, vuint16m1_t, vint64m4_t, vint64m4_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vsuxseg2ei16_v_m)))
void vsuxseg2ei16(vbool16_t, int64_t *, vuint16m1_t, vint64m4_t, vint64m4_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vsuxseg2ei16_v)))
void vsuxseg2ei16(uint64_t *, vuint16mf4_t, vuint64m1_t, vuint64m1_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vsuxseg2ei16_v_m)))
void vsuxseg2ei16(vbool64_t, uint64_t *, vuint16mf4_t, vuint64m1_t, vuint64m1_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vsuxseg2ei16_v)))
void vsuxseg2ei16(uint64_t *, vuint16mf2_t, vuint64m2_t, vuint64m2_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vsuxseg2ei16_v_m)))
void vsuxseg2ei16(vbool32_t, uint64_t *, vuint16mf2_t, vuint64m2_t, vuint64m2_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vsuxseg2ei16_v)))
void vsuxseg2ei16(uint64_t *, vuint16m1_t, vuint64m4_t, vuint64m4_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vsuxseg2ei16_v_m)))
void vsuxseg2ei16(vbool16_t, uint64_t *, vuint16m1_t, vuint64m4_t, vuint64m4_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vsuxseg3ei16_v)))
void vsuxseg3ei16(int64_t *, vuint16mf4_t, vint64m1_t, vint64m1_t, vint64m1_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vsuxseg3ei16_v_m)))
void vsuxseg3ei16(vbool64_t, int64_t *, vuint16mf4_t, vint64m1_t, vint64m1_t, vint64m1_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vsuxseg3ei16_v)))
void vsuxseg3ei16(int64_t *, vuint16mf2_t, vint64m2_t, vint64m2_t, vint64m2_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vsuxseg3ei16_v_m)))
void vsuxseg3ei16(vbool32_t, int64_t *, vuint16mf2_t, vint64m2_t, vint64m2_t, vint64m2_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vsuxseg3ei16_v)))
void vsuxseg3ei16(uint64_t *, vuint16mf4_t, vuint64m1_t, vuint64m1_t, vuint64m1_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vsuxseg3ei16_v_m)))
void vsuxseg3ei16(vbool64_t, uint64_t *, vuint16mf4_t, vuint64m1_t, vuint64m1_t, vuint64m1_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vsuxseg3ei16_v)))
void vsuxseg3ei16(uint64_t *, vuint16mf2_t, vuint64m2_t, vuint64m2_t, vuint64m2_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vsuxseg3ei16_v_m)))
void vsuxseg3ei16(vbool32_t, uint64_t *, vuint16mf2_t, vuint64m2_t, vuint64m2_t, vuint64m2_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vsuxseg4ei16_v)))
void vsuxseg4ei16(int64_t *, vuint16mf4_t, vint64m1_t, vint64m1_t, vint64m1_t, vint64m1_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vsuxseg4ei16_v_m)))
void vsuxseg4ei16(vbool64_t, int64_t *, vuint16mf4_t, vint64m1_t, vint64m1_t, vint64m1_t, vint64m1_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vsuxseg4ei16_v)))
void vsuxseg4ei16(int64_t *, vuint16mf2_t, vint64m2_t, vint64m2_t, vint64m2_t, vint64m2_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vsuxseg4ei16_v_m)))
void vsuxseg4ei16(vbool32_t, int64_t *, vuint16mf2_t, vint64m2_t, vint64m2_t, vint64m2_t, vint64m2_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vsuxseg4ei16_v)))
void vsuxseg4ei16(uint64_t *, vuint16mf4_t, vuint64m1_t, vuint64m1_t, vuint64m1_t, vuint64m1_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vsuxseg4ei16_v_m)))
void vsuxseg4ei16(vbool64_t, uint64_t *, vuint16mf4_t, vuint64m1_t, vuint64m1_t, vuint64m1_t, vuint64m1_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vsuxseg4ei16_v)))
void vsuxseg4ei16(uint64_t *, vuint16mf2_t, vuint64m2_t, vuint64m2_t, vuint64m2_t, vuint64m2_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vsuxseg4ei16_v_m)))
void vsuxseg4ei16(vbool32_t, uint64_t *, vuint16mf2_t, vuint64m2_t, vuint64m2_t, vuint64m2_t, vuint64m2_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vsuxseg5ei16_v)))
void vsuxseg5ei16(int64_t *, vuint16mf4_t, vint64m1_t, vint64m1_t, vint64m1_t, vint64m1_t, vint64m1_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vsuxseg5ei16_v_m)))
void vsuxseg5ei16(vbool64_t, int64_t *, vuint16mf4_t, vint64m1_t, vint64m1_t, vint64m1_t, vint64m1_t, vint64m1_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vsuxseg5ei16_v)))
void vsuxseg5ei16(uint64_t *, vuint16mf4_t, vuint64m1_t, vuint64m1_t, vuint64m1_t, vuint64m1_t, vuint64m1_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vsuxseg5ei16_v_m)))
void vsuxseg5ei16(vbool64_t, uint64_t *, vuint16mf4_t, vuint64m1_t, vuint64m1_t, vuint64m1_t, vuint64m1_t, vuint64m1_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vsuxseg6ei16_v)))
void vsuxseg6ei16(int64_t *, vuint16mf4_t, vint64m1_t, vint64m1_t, vint64m1_t, vint64m1_t, vint64m1_t, vint64m1_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vsuxseg6ei16_v_m)))
void vsuxseg6ei16(vbool64_t, int64_t *, vuint16mf4_t, vint64m1_t, vint64m1_t, vint64m1_t, vint64m1_t, vint64m1_t, vint64m1_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vsuxseg6ei16_v)))
void vsuxseg6ei16(uint64_t *, vuint16mf4_t, vuint64m1_t, vuint64m1_t, vuint64m1_t, vuint64m1_t, vuint64m1_t, vuint64m1_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vsuxseg6ei16_v_m)))
void vsuxseg6ei16(vbool64_t, uint64_t *, vuint16mf4_t, vuint64m1_t, vuint64m1_t, vuint64m1_t, vuint64m1_t, vuint64m1_t, vuint64m1_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vsuxseg7ei16_v)))
void vsuxseg7ei16(int64_t *, vuint16mf4_t, vint64m1_t, vint64m1_t, vint64m1_t, vint64m1_t, vint64m1_t, vint64m1_t, vint64m1_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vsuxseg7ei16_v_m)))
void vsuxseg7ei16(vbool64_t, int64_t *, vuint16mf4_t, vint64m1_t, vint64m1_t, vint64m1_t, vint64m1_t, vint64m1_t, vint64m1_t, vint64m1_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vsuxseg7ei16_v)))
void vsuxseg7ei16(uint64_t *, vuint16mf4_t, vuint64m1_t, vuint64m1_t, vuint64m1_t, vuint64m1_t, vuint64m1_t, vuint64m1_t, vuint64m1_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vsuxseg7ei16_v_m)))
void vsuxseg7ei16(vbool64_t, uint64_t *, vuint16mf4_t, vuint64m1_t, vuint64m1_t, vuint64m1_t, vuint64m1_t, vuint64m1_t, vuint64m1_t, vuint64m1_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vsuxseg8ei16_v)))
void vsuxseg8ei16(int64_t *, vuint16mf4_t, vint64m1_t, vint64m1_t, vint64m1_t, vint64m1_t, vint64m1_t, vint64m1_t, vint64m1_t, vint64m1_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vsuxseg8ei16_v_m)))
void vsuxseg8ei16(vbool64_t, int64_t *, vuint16mf4_t, vint64m1_t, vint64m1_t, vint64m1_t, vint64m1_t, vint64m1_t, vint64m1_t, vint64m1_t, vint64m1_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vsuxseg8ei16_v)))
void vsuxseg8ei16(uint64_t *, vuint16mf4_t, vuint64m1_t, vuint64m1_t, vuint64m1_t, vuint64m1_t, vuint64m1_t, vuint64m1_t, vuint64m1_t, vuint64m1_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vsuxseg8ei16_v_m)))
void vsuxseg8ei16(vbool64_t, uint64_t *, vuint16mf4_t, vuint64m1_t, vuint64m1_t, vuint64m1_t, vuint64m1_t, vuint64m1_t, vuint64m1_t, vuint64m1_t, vuint64m1_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vsuxseg2ei32_v)))
void vsuxseg2ei32(int64_t *, vuint32mf2_t, vint64m1_t, vint64m1_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vsuxseg2ei32_v_m)))
void vsuxseg2ei32(vbool64_t, int64_t *, vuint32mf2_t, vint64m1_t, vint64m1_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vsuxseg2ei32_v)))
void vsuxseg2ei32(int64_t *, vuint32m1_t, vint64m2_t, vint64m2_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vsuxseg2ei32_v_m)))
void vsuxseg2ei32(vbool32_t, int64_t *, vuint32m1_t, vint64m2_t, vint64m2_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vsuxseg2ei32_v)))
void vsuxseg2ei32(int64_t *, vuint32m2_t, vint64m4_t, vint64m4_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vsuxseg2ei32_v_m)))
void vsuxseg2ei32(vbool16_t, int64_t *, vuint32m2_t, vint64m4_t, vint64m4_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vsuxseg2ei32_v)))
void vsuxseg2ei32(uint64_t *, vuint32mf2_t, vuint64m1_t, vuint64m1_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vsuxseg2ei32_v_m)))
void vsuxseg2ei32(vbool64_t, uint64_t *, vuint32mf2_t, vuint64m1_t, vuint64m1_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vsuxseg2ei32_v)))
void vsuxseg2ei32(uint64_t *, vuint32m1_t, vuint64m2_t, vuint64m2_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vsuxseg2ei32_v_m)))
void vsuxseg2ei32(vbool32_t, uint64_t *, vuint32m1_t, vuint64m2_t, vuint64m2_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vsuxseg2ei32_v)))
void vsuxseg2ei32(uint64_t *, vuint32m2_t, vuint64m4_t, vuint64m4_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vsuxseg2ei32_v_m)))
void vsuxseg2ei32(vbool16_t, uint64_t *, vuint32m2_t, vuint64m4_t, vuint64m4_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vsuxseg3ei32_v)))
void vsuxseg3ei32(int64_t *, vuint32mf2_t, vint64m1_t, vint64m1_t, vint64m1_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vsuxseg3ei32_v_m)))
void vsuxseg3ei32(vbool64_t, int64_t *, vuint32mf2_t, vint64m1_t, vint64m1_t, vint64m1_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vsuxseg3ei32_v)))
void vsuxseg3ei32(int64_t *, vuint32m1_t, vint64m2_t, vint64m2_t, vint64m2_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vsuxseg3ei32_v_m)))
void vsuxseg3ei32(vbool32_t, int64_t *, vuint32m1_t, vint64m2_t, vint64m2_t, vint64m2_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vsuxseg3ei32_v)))
void vsuxseg3ei32(uint64_t *, vuint32mf2_t, vuint64m1_t, vuint64m1_t, vuint64m1_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vsuxseg3ei32_v_m)))
void vsuxseg3ei32(vbool64_t, uint64_t *, vuint32mf2_t, vuint64m1_t, vuint64m1_t, vuint64m1_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vsuxseg3ei32_v)))
void vsuxseg3ei32(uint64_t *, vuint32m1_t, vuint64m2_t, vuint64m2_t, vuint64m2_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vsuxseg3ei32_v_m)))
void vsuxseg3ei32(vbool32_t, uint64_t *, vuint32m1_t, vuint64m2_t, vuint64m2_t, vuint64m2_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vsuxseg4ei32_v)))
void vsuxseg4ei32(int64_t *, vuint32mf2_t, vint64m1_t, vint64m1_t, vint64m1_t, vint64m1_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vsuxseg4ei32_v_m)))
void vsuxseg4ei32(vbool64_t, int64_t *, vuint32mf2_t, vint64m1_t, vint64m1_t, vint64m1_t, vint64m1_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vsuxseg4ei32_v)))
void vsuxseg4ei32(int64_t *, vuint32m1_t, vint64m2_t, vint64m2_t, vint64m2_t, vint64m2_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vsuxseg4ei32_v_m)))
void vsuxseg4ei32(vbool32_t, int64_t *, vuint32m1_t, vint64m2_t, vint64m2_t, vint64m2_t, vint64m2_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vsuxseg4ei32_v)))
void vsuxseg4ei32(uint64_t *, vuint32mf2_t, vuint64m1_t, vuint64m1_t, vuint64m1_t, vuint64m1_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vsuxseg4ei32_v_m)))
void vsuxseg4ei32(vbool64_t, uint64_t *, vuint32mf2_t, vuint64m1_t, vuint64m1_t, vuint64m1_t, vuint64m1_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vsuxseg4ei32_v)))
void vsuxseg4ei32(uint64_t *, vuint32m1_t, vuint64m2_t, vuint64m2_t, vuint64m2_t, vuint64m2_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vsuxseg4ei32_v_m)))
void vsuxseg4ei32(vbool32_t, uint64_t *, vuint32m1_t, vuint64m2_t, vuint64m2_t, vuint64m2_t, vuint64m2_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vsuxseg5ei32_v)))
void vsuxseg5ei32(int64_t *, vuint32mf2_t, vint64m1_t, vint64m1_t, vint64m1_t, vint64m1_t, vint64m1_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vsuxseg5ei32_v_m)))
void vsuxseg5ei32(vbool64_t, int64_t *, vuint32mf2_t, vint64m1_t, vint64m1_t, vint64m1_t, vint64m1_t, vint64m1_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vsuxseg5ei32_v)))
void vsuxseg5ei32(uint64_t *, vuint32mf2_t, vuint64m1_t, vuint64m1_t, vuint64m1_t, vuint64m1_t, vuint64m1_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vsuxseg5ei32_v_m)))
void vsuxseg5ei32(vbool64_t, uint64_t *, vuint32mf2_t, vuint64m1_t, vuint64m1_t, vuint64m1_t, vuint64m1_t, vuint64m1_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vsuxseg6ei32_v)))
void vsuxseg6ei32(int64_t *, vuint32mf2_t, vint64m1_t, vint64m1_t, vint64m1_t, vint64m1_t, vint64m1_t, vint64m1_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vsuxseg6ei32_v_m)))
void vsuxseg6ei32(vbool64_t, int64_t *, vuint32mf2_t, vint64m1_t, vint64m1_t, vint64m1_t, vint64m1_t, vint64m1_t, vint64m1_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vsuxseg6ei32_v)))
void vsuxseg6ei32(uint64_t *, vuint32mf2_t, vuint64m1_t, vuint64m1_t, vuint64m1_t, vuint64m1_t, vuint64m1_t, vuint64m1_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vsuxseg6ei32_v_m)))
void vsuxseg6ei32(vbool64_t, uint64_t *, vuint32mf2_t, vuint64m1_t, vuint64m1_t, vuint64m1_t, vuint64m1_t, vuint64m1_t, vuint64m1_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vsuxseg7ei32_v)))
void vsuxseg7ei32(int64_t *, vuint32mf2_t, vint64m1_t, vint64m1_t, vint64m1_t, vint64m1_t, vint64m1_t, vint64m1_t, vint64m1_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vsuxseg7ei32_v_m)))
void vsuxseg7ei32(vbool64_t, int64_t *, vuint32mf2_t, vint64m1_t, vint64m1_t, vint64m1_t, vint64m1_t, vint64m1_t, vint64m1_t, vint64m1_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vsuxseg7ei32_v)))
void vsuxseg7ei32(uint64_t *, vuint32mf2_t, vuint64m1_t, vuint64m1_t, vuint64m1_t, vuint64m1_t, vuint64m1_t, vuint64m1_t, vuint64m1_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vsuxseg7ei32_v_m)))
void vsuxseg7ei32(vbool64_t, uint64_t *, vuint32mf2_t, vuint64m1_t, vuint64m1_t, vuint64m1_t, vuint64m1_t, vuint64m1_t, vuint64m1_t, vuint64m1_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vsuxseg8ei32_v)))
void vsuxseg8ei32(int64_t *, vuint32mf2_t, vint64m1_t, vint64m1_t, vint64m1_t, vint64m1_t, vint64m1_t, vint64m1_t, vint64m1_t, vint64m1_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vsuxseg8ei32_v_m)))
void vsuxseg8ei32(vbool64_t, int64_t *, vuint32mf2_t, vint64m1_t, vint64m1_t, vint64m1_t, vint64m1_t, vint64m1_t, vint64m1_t, vint64m1_t, vint64m1_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vsuxseg8ei32_v)))
void vsuxseg8ei32(uint64_t *, vuint32mf2_t, vuint64m1_t, vuint64m1_t, vuint64m1_t, vuint64m1_t, vuint64m1_t, vuint64m1_t, vuint64m1_t, vuint64m1_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vsuxseg8ei32_v_m)))
void vsuxseg8ei32(vbool64_t, uint64_t *, vuint32mf2_t, vuint64m1_t, vuint64m1_t, vuint64m1_t, vuint64m1_t, vuint64m1_t, vuint64m1_t, vuint64m1_t, vuint64m1_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vsuxseg2ei64_v)))
void vsuxseg2ei64(int64_t *, vuint64m1_t, vint64m1_t, vint64m1_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vsuxseg2ei64_v_m)))
void vsuxseg2ei64(vbool64_t, int64_t *, vuint64m1_t, vint64m1_t, vint64m1_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vsuxseg2ei64_v)))
void vsuxseg2ei64(int64_t *, vuint64m2_t, vint64m2_t, vint64m2_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vsuxseg2ei64_v_m)))
void vsuxseg2ei64(vbool32_t, int64_t *, vuint64m2_t, vint64m2_t, vint64m2_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vsuxseg2ei64_v)))
void vsuxseg2ei64(int64_t *, vuint64m4_t, vint64m4_t, vint64m4_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vsuxseg2ei64_v_m)))
void vsuxseg2ei64(vbool16_t, int64_t *, vuint64m4_t, vint64m4_t, vint64m4_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vsuxseg2ei64_v)))
void vsuxseg2ei64(uint64_t *, vuint64m1_t, vuint64m1_t, vuint64m1_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vsuxseg2ei64_v_m)))
void vsuxseg2ei64(vbool64_t, uint64_t *, vuint64m1_t, vuint64m1_t, vuint64m1_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vsuxseg2ei64_v)))
void vsuxseg2ei64(uint64_t *, vuint64m2_t, vuint64m2_t, vuint64m2_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vsuxseg2ei64_v_m)))
void vsuxseg2ei64(vbool32_t, uint64_t *, vuint64m2_t, vuint64m2_t, vuint64m2_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vsuxseg2ei64_v)))
void vsuxseg2ei64(uint64_t *, vuint64m4_t, vuint64m4_t, vuint64m4_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vsuxseg2ei64_v_m)))
void vsuxseg2ei64(vbool16_t, uint64_t *, vuint64m4_t, vuint64m4_t, vuint64m4_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vsuxseg3ei64_v)))
void vsuxseg3ei64(int64_t *, vuint64m1_t, vint64m1_t, vint64m1_t, vint64m1_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vsuxseg3ei64_v_m)))
void vsuxseg3ei64(vbool64_t, int64_t *, vuint64m1_t, vint64m1_t, vint64m1_t, vint64m1_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vsuxseg3ei64_v)))
void vsuxseg3ei64(int64_t *, vuint64m2_t, vint64m2_t, vint64m2_t, vint64m2_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vsuxseg3ei64_v_m)))
void vsuxseg3ei64(vbool32_t, int64_t *, vuint64m2_t, vint64m2_t, vint64m2_t, vint64m2_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vsuxseg3ei64_v)))
void vsuxseg3ei64(uint64_t *, vuint64m1_t, vuint64m1_t, vuint64m1_t, vuint64m1_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vsuxseg3ei64_v_m)))
void vsuxseg3ei64(vbool64_t, uint64_t *, vuint64m1_t, vuint64m1_t, vuint64m1_t, vuint64m1_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vsuxseg3ei64_v)))
void vsuxseg3ei64(uint64_t *, vuint64m2_t, vuint64m2_t, vuint64m2_t, vuint64m2_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vsuxseg3ei64_v_m)))
void vsuxseg3ei64(vbool32_t, uint64_t *, vuint64m2_t, vuint64m2_t, vuint64m2_t, vuint64m2_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vsuxseg4ei64_v)))
void vsuxseg4ei64(int64_t *, vuint64m1_t, vint64m1_t, vint64m1_t, vint64m1_t, vint64m1_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vsuxseg4ei64_v_m)))
void vsuxseg4ei64(vbool64_t, int64_t *, vuint64m1_t, vint64m1_t, vint64m1_t, vint64m1_t, vint64m1_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vsuxseg4ei64_v)))
void vsuxseg4ei64(int64_t *, vuint64m2_t, vint64m2_t, vint64m2_t, vint64m2_t, vint64m2_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vsuxseg4ei64_v_m)))
void vsuxseg4ei64(vbool32_t, int64_t *, vuint64m2_t, vint64m2_t, vint64m2_t, vint64m2_t, vint64m2_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vsuxseg4ei64_v)))
void vsuxseg4ei64(uint64_t *, vuint64m1_t, vuint64m1_t, vuint64m1_t, vuint64m1_t, vuint64m1_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vsuxseg4ei64_v_m)))
void vsuxseg4ei64(vbool64_t, uint64_t *, vuint64m1_t, vuint64m1_t, vuint64m1_t, vuint64m1_t, vuint64m1_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vsuxseg4ei64_v)))
void vsuxseg4ei64(uint64_t *, vuint64m2_t, vuint64m2_t, vuint64m2_t, vuint64m2_t, vuint64m2_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vsuxseg4ei64_v_m)))
void vsuxseg4ei64(vbool32_t, uint64_t *, vuint64m2_t, vuint64m2_t, vuint64m2_t, vuint64m2_t, vuint64m2_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vsuxseg5ei64_v)))
void vsuxseg5ei64(int64_t *, vuint64m1_t, vint64m1_t, vint64m1_t, vint64m1_t, vint64m1_t, vint64m1_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vsuxseg5ei64_v_m)))
void vsuxseg5ei64(vbool64_t, int64_t *, vuint64m1_t, vint64m1_t, vint64m1_t, vint64m1_t, vint64m1_t, vint64m1_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vsuxseg5ei64_v)))
void vsuxseg5ei64(uint64_t *, vuint64m1_t, vuint64m1_t, vuint64m1_t, vuint64m1_t, vuint64m1_t, vuint64m1_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vsuxseg5ei64_v_m)))
void vsuxseg5ei64(vbool64_t, uint64_t *, vuint64m1_t, vuint64m1_t, vuint64m1_t, vuint64m1_t, vuint64m1_t, vuint64m1_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vsuxseg6ei64_v)))
void vsuxseg6ei64(int64_t *, vuint64m1_t, vint64m1_t, vint64m1_t, vint64m1_t, vint64m1_t, vint64m1_t, vint64m1_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vsuxseg6ei64_v_m)))
void vsuxseg6ei64(vbool64_t, int64_t *, vuint64m1_t, vint64m1_t, vint64m1_t, vint64m1_t, vint64m1_t, vint64m1_t, vint64m1_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vsuxseg6ei64_v)))
void vsuxseg6ei64(uint64_t *, vuint64m1_t, vuint64m1_t, vuint64m1_t, vuint64m1_t, vuint64m1_t, vuint64m1_t, vuint64m1_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vsuxseg6ei64_v_m)))
void vsuxseg6ei64(vbool64_t, uint64_t *, vuint64m1_t, vuint64m1_t, vuint64m1_t, vuint64m1_t, vuint64m1_t, vuint64m1_t, vuint64m1_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vsuxseg7ei64_v)))
void vsuxseg7ei64(int64_t *, vuint64m1_t, vint64m1_t, vint64m1_t, vint64m1_t, vint64m1_t, vint64m1_t, vint64m1_t, vint64m1_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vsuxseg7ei64_v_m)))
void vsuxseg7ei64(vbool64_t, int64_t *, vuint64m1_t, vint64m1_t, vint64m1_t, vint64m1_t, vint64m1_t, vint64m1_t, vint64m1_t, vint64m1_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vsuxseg7ei64_v)))
void vsuxseg7ei64(uint64_t *, vuint64m1_t, vuint64m1_t, vuint64m1_t, vuint64m1_t, vuint64m1_t, vuint64m1_t, vuint64m1_t, vuint64m1_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vsuxseg7ei64_v_m)))
void vsuxseg7ei64(vbool64_t, uint64_t *, vuint64m1_t, vuint64m1_t, vuint64m1_t, vuint64m1_t, vuint64m1_t, vuint64m1_t, vuint64m1_t, vuint64m1_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vsuxseg8ei64_v)))
void vsuxseg8ei64(int64_t *, vuint64m1_t, vint64m1_t, vint64m1_t, vint64m1_t, vint64m1_t, vint64m1_t, vint64m1_t, vint64m1_t, vint64m1_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vsuxseg8ei64_v_m)))
void vsuxseg8ei64(vbool64_t, int64_t *, vuint64m1_t, vint64m1_t, vint64m1_t, vint64m1_t, vint64m1_t, vint64m1_t, vint64m1_t, vint64m1_t, vint64m1_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vsuxseg8ei64_v)))
void vsuxseg8ei64(uint64_t *, vuint64m1_t, vuint64m1_t, vuint64m1_t, vuint64m1_t, vuint64m1_t, vuint64m1_t, vuint64m1_t, vuint64m1_t, vuint64m1_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vsuxseg8ei64_v_m)))
void vsuxseg8ei64(vbool64_t, uint64_t *, vuint64m1_t, vuint64m1_t, vuint64m1_t, vuint64m1_t, vuint64m1_t, vuint64m1_t, vuint64m1_t, vuint64m1_t, vuint64m1_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vsoxseg2ei64_v)))
void vsoxseg2ei64(int8_t *, vuint64m8_t, vint8m1_t, vint8m1_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vsoxseg2ei64_v_m)))
void vsoxseg2ei64(vbool8_t, int8_t *, vuint64m8_t, vint8m1_t, vint8m1_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vsoxseg2ei64_v)))
void vsoxseg2ei64(int8_t *, vuint64m4_t, vint8mf2_t, vint8mf2_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vsoxseg2ei64_v_m)))
void vsoxseg2ei64(vbool16_t, int8_t *, vuint64m4_t, vint8mf2_t, vint8mf2_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vsoxseg2ei64_v)))
void vsoxseg2ei64(int8_t *, vuint64m2_t, vint8mf4_t, vint8mf4_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vsoxseg2ei64_v_m)))
void vsoxseg2ei64(vbool32_t, int8_t *, vuint64m2_t, vint8mf4_t, vint8mf4_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vsoxseg2ei64_v)))
void vsoxseg2ei64(int8_t *, vuint64m1_t, vint8mf8_t, vint8mf8_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vsoxseg2ei64_v_m)))
void vsoxseg2ei64(vbool64_t, int8_t *, vuint64m1_t, vint8mf8_t, vint8mf8_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vsoxseg2ei64_v)))
void vsoxseg2ei64(uint8_t *, vuint64m8_t, vuint8m1_t, vuint8m1_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vsoxseg2ei64_v_m)))
void vsoxseg2ei64(vbool8_t, uint8_t *, vuint64m8_t, vuint8m1_t, vuint8m1_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vsoxseg2ei64_v)))
void vsoxseg2ei64(uint8_t *, vuint64m4_t, vuint8mf2_t, vuint8mf2_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vsoxseg2ei64_v_m)))
void vsoxseg2ei64(vbool16_t, uint8_t *, vuint64m4_t, vuint8mf2_t, vuint8mf2_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vsoxseg2ei64_v)))
void vsoxseg2ei64(uint8_t *, vuint64m2_t, vuint8mf4_t, vuint8mf4_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vsoxseg2ei64_v_m)))
void vsoxseg2ei64(vbool32_t, uint8_t *, vuint64m2_t, vuint8mf4_t, vuint8mf4_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vsoxseg2ei64_v)))
void vsoxseg2ei64(uint8_t *, vuint64m1_t, vuint8mf8_t, vuint8mf8_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vsoxseg2ei64_v_m)))
void vsoxseg2ei64(vbool64_t, uint8_t *, vuint64m1_t, vuint8mf8_t, vuint8mf8_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vsoxseg3ei64_v)))
void vsoxseg3ei64(int8_t *, vuint64m8_t, vint8m1_t, vint8m1_t, vint8m1_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vsoxseg3ei64_v_m)))
void vsoxseg3ei64(vbool8_t, int8_t *, vuint64m8_t, vint8m1_t, vint8m1_t, vint8m1_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vsoxseg3ei64_v)))
void vsoxseg3ei64(int8_t *, vuint64m4_t, vint8mf2_t, vint8mf2_t, vint8mf2_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vsoxseg3ei64_v_m)))
void vsoxseg3ei64(vbool16_t, int8_t *, vuint64m4_t, vint8mf2_t, vint8mf2_t, vint8mf2_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vsoxseg3ei64_v)))
void vsoxseg3ei64(int8_t *, vuint64m2_t, vint8mf4_t, vint8mf4_t, vint8mf4_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vsoxseg3ei64_v_m)))
void vsoxseg3ei64(vbool32_t, int8_t *, vuint64m2_t, vint8mf4_t, vint8mf4_t, vint8mf4_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vsoxseg3ei64_v)))
void vsoxseg3ei64(int8_t *, vuint64m1_t, vint8mf8_t, vint8mf8_t, vint8mf8_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vsoxseg3ei64_v_m)))
void vsoxseg3ei64(vbool64_t, int8_t *, vuint64m1_t, vint8mf8_t, vint8mf8_t, vint8mf8_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vsoxseg3ei64_v)))
void vsoxseg3ei64(uint8_t *, vuint64m8_t, vuint8m1_t, vuint8m1_t, vuint8m1_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vsoxseg3ei64_v_m)))
void vsoxseg3ei64(vbool8_t, uint8_t *, vuint64m8_t, vuint8m1_t, vuint8m1_t, vuint8m1_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vsoxseg3ei64_v)))
void vsoxseg3ei64(uint8_t *, vuint64m4_t, vuint8mf2_t, vuint8mf2_t, vuint8mf2_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vsoxseg3ei64_v_m)))
void vsoxseg3ei64(vbool16_t, uint8_t *, vuint64m4_t, vuint8mf2_t, vuint8mf2_t, vuint8mf2_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vsoxseg3ei64_v)))
void vsoxseg3ei64(uint8_t *, vuint64m2_t, vuint8mf4_t, vuint8mf4_t, vuint8mf4_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vsoxseg3ei64_v_m)))
void vsoxseg3ei64(vbool32_t, uint8_t *, vuint64m2_t, vuint8mf4_t, vuint8mf4_t, vuint8mf4_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vsoxseg3ei64_v)))
void vsoxseg3ei64(uint8_t *, vuint64m1_t, vuint8mf8_t, vuint8mf8_t, vuint8mf8_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vsoxseg3ei64_v_m)))
void vsoxseg3ei64(vbool64_t, uint8_t *, vuint64m1_t, vuint8mf8_t, vuint8mf8_t, vuint8mf8_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vsoxseg4ei64_v)))
void vsoxseg4ei64(int8_t *, vuint64m8_t, vint8m1_t, vint8m1_t, vint8m1_t, vint8m1_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vsoxseg4ei64_v_m)))
void vsoxseg4ei64(vbool8_t, int8_t *, vuint64m8_t, vint8m1_t, vint8m1_t, vint8m1_t, vint8m1_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vsoxseg4ei64_v)))
void vsoxseg4ei64(int8_t *, vuint64m4_t, vint8mf2_t, vint8mf2_t, vint8mf2_t, vint8mf2_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vsoxseg4ei64_v_m)))
void vsoxseg4ei64(vbool16_t, int8_t *, vuint64m4_t, vint8mf2_t, vint8mf2_t, vint8mf2_t, vint8mf2_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vsoxseg4ei64_v)))
void vsoxseg4ei64(int8_t *, vuint64m2_t, vint8mf4_t, vint8mf4_t, vint8mf4_t, vint8mf4_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vsoxseg4ei64_v_m)))
void vsoxseg4ei64(vbool32_t, int8_t *, vuint64m2_t, vint8mf4_t, vint8mf4_t, vint8mf4_t, vint8mf4_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vsoxseg4ei64_v)))
void vsoxseg4ei64(int8_t *, vuint64m1_t, vint8mf8_t, vint8mf8_t, vint8mf8_t, vint8mf8_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vsoxseg4ei64_v_m)))
void vsoxseg4ei64(vbool64_t, int8_t *, vuint64m1_t, vint8mf8_t, vint8mf8_t, vint8mf8_t, vint8mf8_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vsoxseg4ei64_v)))
void vsoxseg4ei64(uint8_t *, vuint64m8_t, vuint8m1_t, vuint8m1_t, vuint8m1_t, vuint8m1_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vsoxseg4ei64_v_m)))
void vsoxseg4ei64(vbool8_t, uint8_t *, vuint64m8_t, vuint8m1_t, vuint8m1_t, vuint8m1_t, vuint8m1_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vsoxseg4ei64_v)))
void vsoxseg4ei64(uint8_t *, vuint64m4_t, vuint8mf2_t, vuint8mf2_t, vuint8mf2_t, vuint8mf2_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vsoxseg4ei64_v_m)))
void vsoxseg4ei64(vbool16_t, uint8_t *, vuint64m4_t, vuint8mf2_t, vuint8mf2_t, vuint8mf2_t, vuint8mf2_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vsoxseg4ei64_v)))
void vsoxseg4ei64(uint8_t *, vuint64m2_t, vuint8mf4_t, vuint8mf4_t, vuint8mf4_t, vuint8mf4_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vsoxseg4ei64_v_m)))
void vsoxseg4ei64(vbool32_t, uint8_t *, vuint64m2_t, vuint8mf4_t, vuint8mf4_t, vuint8mf4_t, vuint8mf4_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vsoxseg4ei64_v)))
void vsoxseg4ei64(uint8_t *, vuint64m1_t, vuint8mf8_t, vuint8mf8_t, vuint8mf8_t, vuint8mf8_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vsoxseg4ei64_v_m)))
void vsoxseg4ei64(vbool64_t, uint8_t *, vuint64m1_t, vuint8mf8_t, vuint8mf8_t, vuint8mf8_t, vuint8mf8_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vsoxseg5ei64_v)))
void vsoxseg5ei64(int8_t *, vuint64m8_t, vint8m1_t, vint8m1_t, vint8m1_t, vint8m1_t, vint8m1_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vsoxseg5ei64_v_m)))
void vsoxseg5ei64(vbool8_t, int8_t *, vuint64m8_t, vint8m1_t, vint8m1_t, vint8m1_t, vint8m1_t, vint8m1_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vsoxseg5ei64_v)))
void vsoxseg5ei64(int8_t *, vuint64m4_t, vint8mf2_t, vint8mf2_t, vint8mf2_t, vint8mf2_t, vint8mf2_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vsoxseg5ei64_v_m)))
void vsoxseg5ei64(vbool16_t, int8_t *, vuint64m4_t, vint8mf2_t, vint8mf2_t, vint8mf2_t, vint8mf2_t, vint8mf2_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vsoxseg5ei64_v)))
void vsoxseg5ei64(int8_t *, vuint64m2_t, vint8mf4_t, vint8mf4_t, vint8mf4_t, vint8mf4_t, vint8mf4_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vsoxseg5ei64_v_m)))
void vsoxseg5ei64(vbool32_t, int8_t *, vuint64m2_t, vint8mf4_t, vint8mf4_t, vint8mf4_t, vint8mf4_t, vint8mf4_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vsoxseg5ei64_v)))
void vsoxseg5ei64(int8_t *, vuint64m1_t, vint8mf8_t, vint8mf8_t, vint8mf8_t, vint8mf8_t, vint8mf8_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vsoxseg5ei64_v_m)))
void vsoxseg5ei64(vbool64_t, int8_t *, vuint64m1_t, vint8mf8_t, vint8mf8_t, vint8mf8_t, vint8mf8_t, vint8mf8_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vsoxseg5ei64_v)))
void vsoxseg5ei64(uint8_t *, vuint64m8_t, vuint8m1_t, vuint8m1_t, vuint8m1_t, vuint8m1_t, vuint8m1_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vsoxseg5ei64_v_m)))
void vsoxseg5ei64(vbool8_t, uint8_t *, vuint64m8_t, vuint8m1_t, vuint8m1_t, vuint8m1_t, vuint8m1_t, vuint8m1_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vsoxseg5ei64_v)))
void vsoxseg5ei64(uint8_t *, vuint64m4_t, vuint8mf2_t, vuint8mf2_t, vuint8mf2_t, vuint8mf2_t, vuint8mf2_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vsoxseg5ei64_v_m)))
void vsoxseg5ei64(vbool16_t, uint8_t *, vuint64m4_t, vuint8mf2_t, vuint8mf2_t, vuint8mf2_t, vuint8mf2_t, vuint8mf2_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vsoxseg5ei64_v)))
void vsoxseg5ei64(uint8_t *, vuint64m2_t, vuint8mf4_t, vuint8mf4_t, vuint8mf4_t, vuint8mf4_t, vuint8mf4_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vsoxseg5ei64_v_m)))
void vsoxseg5ei64(vbool32_t, uint8_t *, vuint64m2_t, vuint8mf4_t, vuint8mf4_t, vuint8mf4_t, vuint8mf4_t, vuint8mf4_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vsoxseg5ei64_v)))
void vsoxseg5ei64(uint8_t *, vuint64m1_t, vuint8mf8_t, vuint8mf8_t, vuint8mf8_t, vuint8mf8_t, vuint8mf8_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vsoxseg5ei64_v_m)))
void vsoxseg5ei64(vbool64_t, uint8_t *, vuint64m1_t, vuint8mf8_t, vuint8mf8_t, vuint8mf8_t, vuint8mf8_t, vuint8mf8_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vsoxseg6ei64_v)))
void vsoxseg6ei64(int8_t *, vuint64m8_t, vint8m1_t, vint8m1_t, vint8m1_t, vint8m1_t, vint8m1_t, vint8m1_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vsoxseg6ei64_v_m)))
void vsoxseg6ei64(vbool8_t, int8_t *, vuint64m8_t, vint8m1_t, vint8m1_t, vint8m1_t, vint8m1_t, vint8m1_t, vint8m1_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vsoxseg6ei64_v)))
void vsoxseg6ei64(int8_t *, vuint64m4_t, vint8mf2_t, vint8mf2_t, vint8mf2_t, vint8mf2_t, vint8mf2_t, vint8mf2_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vsoxseg6ei64_v_m)))
void vsoxseg6ei64(vbool16_t, int8_t *, vuint64m4_t, vint8mf2_t, vint8mf2_t, vint8mf2_t, vint8mf2_t, vint8mf2_t, vint8mf2_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vsoxseg6ei64_v)))
void vsoxseg6ei64(int8_t *, vuint64m2_t, vint8mf4_t, vint8mf4_t, vint8mf4_t, vint8mf4_t, vint8mf4_t, vint8mf4_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vsoxseg6ei64_v_m)))
void vsoxseg6ei64(vbool32_t, int8_t *, vuint64m2_t, vint8mf4_t, vint8mf4_t, vint8mf4_t, vint8mf4_t, vint8mf4_t, vint8mf4_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vsoxseg6ei64_v)))
void vsoxseg6ei64(int8_t *, vuint64m1_t, vint8mf8_t, vint8mf8_t, vint8mf8_t, vint8mf8_t, vint8mf8_t, vint8mf8_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vsoxseg6ei64_v_m)))
void vsoxseg6ei64(vbool64_t, int8_t *, vuint64m1_t, vint8mf8_t, vint8mf8_t, vint8mf8_t, vint8mf8_t, vint8mf8_t, vint8mf8_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vsoxseg6ei64_v)))
void vsoxseg6ei64(uint8_t *, vuint64m8_t, vuint8m1_t, vuint8m1_t, vuint8m1_t, vuint8m1_t, vuint8m1_t, vuint8m1_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vsoxseg6ei64_v_m)))
void vsoxseg6ei64(vbool8_t, uint8_t *, vuint64m8_t, vuint8m1_t, vuint8m1_t, vuint8m1_t, vuint8m1_t, vuint8m1_t, vuint8m1_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vsoxseg6ei64_v)))
void vsoxseg6ei64(uint8_t *, vuint64m4_t, vuint8mf2_t, vuint8mf2_t, vuint8mf2_t, vuint8mf2_t, vuint8mf2_t, vuint8mf2_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vsoxseg6ei64_v_m)))
void vsoxseg6ei64(vbool16_t, uint8_t *, vuint64m4_t, vuint8mf2_t, vuint8mf2_t, vuint8mf2_t, vuint8mf2_t, vuint8mf2_t, vuint8mf2_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vsoxseg6ei64_v)))
void vsoxseg6ei64(uint8_t *, vuint64m2_t, vuint8mf4_t, vuint8mf4_t, vuint8mf4_t, vuint8mf4_t, vuint8mf4_t, vuint8mf4_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vsoxseg6ei64_v_m)))
void vsoxseg6ei64(vbool32_t, uint8_t *, vuint64m2_t, vuint8mf4_t, vuint8mf4_t, vuint8mf4_t, vuint8mf4_t, vuint8mf4_t, vuint8mf4_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vsoxseg6ei64_v)))
void vsoxseg6ei64(uint8_t *, vuint64m1_t, vuint8mf8_t, vuint8mf8_t, vuint8mf8_t, vuint8mf8_t, vuint8mf8_t, vuint8mf8_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vsoxseg6ei64_v_m)))
void vsoxseg6ei64(vbool64_t, uint8_t *, vuint64m1_t, vuint8mf8_t, vuint8mf8_t, vuint8mf8_t, vuint8mf8_t, vuint8mf8_t, vuint8mf8_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vsoxseg7ei64_v)))
void vsoxseg7ei64(int8_t *, vuint64m8_t, vint8m1_t, vint8m1_t, vint8m1_t, vint8m1_t, vint8m1_t, vint8m1_t, vint8m1_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vsoxseg7ei64_v_m)))
void vsoxseg7ei64(vbool8_t, int8_t *, vuint64m8_t, vint8m1_t, vint8m1_t, vint8m1_t, vint8m1_t, vint8m1_t, vint8m1_t, vint8m1_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vsoxseg7ei64_v)))
void vsoxseg7ei64(int8_t *, vuint64m4_t, vint8mf2_t, vint8mf2_t, vint8mf2_t, vint8mf2_t, vint8mf2_t, vint8mf2_t, vint8mf2_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vsoxseg7ei64_v_m)))
void vsoxseg7ei64(vbool16_t, int8_t *, vuint64m4_t, vint8mf2_t, vint8mf2_t, vint8mf2_t, vint8mf2_t, vint8mf2_t, vint8mf2_t, vint8mf2_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vsoxseg7ei64_v)))
void vsoxseg7ei64(int8_t *, vuint64m2_t, vint8mf4_t, vint8mf4_t, vint8mf4_t, vint8mf4_t, vint8mf4_t, vint8mf4_t, vint8mf4_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vsoxseg7ei64_v_m)))
void vsoxseg7ei64(vbool32_t, int8_t *, vuint64m2_t, vint8mf4_t, vint8mf4_t, vint8mf4_t, vint8mf4_t, vint8mf4_t, vint8mf4_t, vint8mf4_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vsoxseg7ei64_v)))
void vsoxseg7ei64(int8_t *, vuint64m1_t, vint8mf8_t, vint8mf8_t, vint8mf8_t, vint8mf8_t, vint8mf8_t, vint8mf8_t, vint8mf8_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vsoxseg7ei64_v_m)))
void vsoxseg7ei64(vbool64_t, int8_t *, vuint64m1_t, vint8mf8_t, vint8mf8_t, vint8mf8_t, vint8mf8_t, vint8mf8_t, vint8mf8_t, vint8mf8_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vsoxseg7ei64_v)))
void vsoxseg7ei64(uint8_t *, vuint64m8_t, vuint8m1_t, vuint8m1_t, vuint8m1_t, vuint8m1_t, vuint8m1_t, vuint8m1_t, vuint8m1_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vsoxseg7ei64_v_m)))
void vsoxseg7ei64(vbool8_t, uint8_t *, vuint64m8_t, vuint8m1_t, vuint8m1_t, vuint8m1_t, vuint8m1_t, vuint8m1_t, vuint8m1_t, vuint8m1_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vsoxseg7ei64_v)))
void vsoxseg7ei64(uint8_t *, vuint64m4_t, vuint8mf2_t, vuint8mf2_t, vuint8mf2_t, vuint8mf2_t, vuint8mf2_t, vuint8mf2_t, vuint8mf2_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vsoxseg7ei64_v_m)))
void vsoxseg7ei64(vbool16_t, uint8_t *, vuint64m4_t, vuint8mf2_t, vuint8mf2_t, vuint8mf2_t, vuint8mf2_t, vuint8mf2_t, vuint8mf2_t, vuint8mf2_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vsoxseg7ei64_v)))
void vsoxseg7ei64(uint8_t *, vuint64m2_t, vuint8mf4_t, vuint8mf4_t, vuint8mf4_t, vuint8mf4_t, vuint8mf4_t, vuint8mf4_t, vuint8mf4_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vsoxseg7ei64_v_m)))
void vsoxseg7ei64(vbool32_t, uint8_t *, vuint64m2_t, vuint8mf4_t, vuint8mf4_t, vuint8mf4_t, vuint8mf4_t, vuint8mf4_t, vuint8mf4_t, vuint8mf4_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vsoxseg7ei64_v)))
void vsoxseg7ei64(uint8_t *, vuint64m1_t, vuint8mf8_t, vuint8mf8_t, vuint8mf8_t, vuint8mf8_t, vuint8mf8_t, vuint8mf8_t, vuint8mf8_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vsoxseg7ei64_v_m)))
void vsoxseg7ei64(vbool64_t, uint8_t *, vuint64m1_t, vuint8mf8_t, vuint8mf8_t, vuint8mf8_t, vuint8mf8_t, vuint8mf8_t, vuint8mf8_t, vuint8mf8_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vsoxseg8ei64_v)))
void vsoxseg8ei64(int8_t *, vuint64m8_t, vint8m1_t, vint8m1_t, vint8m1_t, vint8m1_t, vint8m1_t, vint8m1_t, vint8m1_t, vint8m1_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vsoxseg8ei64_v_m)))
void vsoxseg8ei64(vbool8_t, int8_t *, vuint64m8_t, vint8m1_t, vint8m1_t, vint8m1_t, vint8m1_t, vint8m1_t, vint8m1_t, vint8m1_t, vint8m1_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vsoxseg8ei64_v)))
void vsoxseg8ei64(int8_t *, vuint64m4_t, vint8mf2_t, vint8mf2_t, vint8mf2_t, vint8mf2_t, vint8mf2_t, vint8mf2_t, vint8mf2_t, vint8mf2_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vsoxseg8ei64_v_m)))
void vsoxseg8ei64(vbool16_t, int8_t *, vuint64m4_t, vint8mf2_t, vint8mf2_t, vint8mf2_t, vint8mf2_t, vint8mf2_t, vint8mf2_t, vint8mf2_t, vint8mf2_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vsoxseg8ei64_v)))
void vsoxseg8ei64(int8_t *, vuint64m2_t, vint8mf4_t, vint8mf4_t, vint8mf4_t, vint8mf4_t, vint8mf4_t, vint8mf4_t, vint8mf4_t, vint8mf4_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vsoxseg8ei64_v_m)))
void vsoxseg8ei64(vbool32_t, int8_t *, vuint64m2_t, vint8mf4_t, vint8mf4_t, vint8mf4_t, vint8mf4_t, vint8mf4_t, vint8mf4_t, vint8mf4_t, vint8mf4_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vsoxseg8ei64_v)))
void vsoxseg8ei64(int8_t *, vuint64m1_t, vint8mf8_t, vint8mf8_t, vint8mf8_t, vint8mf8_t, vint8mf8_t, vint8mf8_t, vint8mf8_t, vint8mf8_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vsoxseg8ei64_v_m)))
void vsoxseg8ei64(vbool64_t, int8_t *, vuint64m1_t, vint8mf8_t, vint8mf8_t, vint8mf8_t, vint8mf8_t, vint8mf8_t, vint8mf8_t, vint8mf8_t, vint8mf8_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vsoxseg8ei64_v)))
void vsoxseg8ei64(uint8_t *, vuint64m8_t, vuint8m1_t, vuint8m1_t, vuint8m1_t, vuint8m1_t, vuint8m1_t, vuint8m1_t, vuint8m1_t, vuint8m1_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vsoxseg8ei64_v_m)))
void vsoxseg8ei64(vbool8_t, uint8_t *, vuint64m8_t, vuint8m1_t, vuint8m1_t, vuint8m1_t, vuint8m1_t, vuint8m1_t, vuint8m1_t, vuint8m1_t, vuint8m1_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vsoxseg8ei64_v)))
void vsoxseg8ei64(uint8_t *, vuint64m4_t, vuint8mf2_t, vuint8mf2_t, vuint8mf2_t, vuint8mf2_t, vuint8mf2_t, vuint8mf2_t, vuint8mf2_t, vuint8mf2_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vsoxseg8ei64_v_m)))
void vsoxseg8ei64(vbool16_t, uint8_t *, vuint64m4_t, vuint8mf2_t, vuint8mf2_t, vuint8mf2_t, vuint8mf2_t, vuint8mf2_t, vuint8mf2_t, vuint8mf2_t, vuint8mf2_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vsoxseg8ei64_v)))
void vsoxseg8ei64(uint8_t *, vuint64m2_t, vuint8mf4_t, vuint8mf4_t, vuint8mf4_t, vuint8mf4_t, vuint8mf4_t, vuint8mf4_t, vuint8mf4_t, vuint8mf4_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vsoxseg8ei64_v_m)))
void vsoxseg8ei64(vbool32_t, uint8_t *, vuint64m2_t, vuint8mf4_t, vuint8mf4_t, vuint8mf4_t, vuint8mf4_t, vuint8mf4_t, vuint8mf4_t, vuint8mf4_t, vuint8mf4_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vsoxseg8ei64_v)))
void vsoxseg8ei64(uint8_t *, vuint64m1_t, vuint8mf8_t, vuint8mf8_t, vuint8mf8_t, vuint8mf8_t, vuint8mf8_t, vuint8mf8_t, vuint8mf8_t, vuint8mf8_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vsoxseg8ei64_v_m)))
void vsoxseg8ei64(vbool64_t, uint8_t *, vuint64m1_t, vuint8mf8_t, vuint8mf8_t, vuint8mf8_t, vuint8mf8_t, vuint8mf8_t, vuint8mf8_t, vuint8mf8_t, vuint8mf8_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vsoxseg2ei64_v)))
void vsoxseg2ei64(int16_t *, vuint64m4_t, vint16m1_t, vint16m1_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vsoxseg2ei64_v_m)))
void vsoxseg2ei64(vbool16_t, int16_t *, vuint64m4_t, vint16m1_t, vint16m1_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vsoxseg2ei64_v)))
void vsoxseg2ei64(int16_t *, vuint64m8_t, vint16m2_t, vint16m2_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vsoxseg2ei64_v_m)))
void vsoxseg2ei64(vbool8_t, int16_t *, vuint64m8_t, vint16m2_t, vint16m2_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vsoxseg2ei64_v)))
void vsoxseg2ei64(int16_t *, vuint64m2_t, vint16mf2_t, vint16mf2_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vsoxseg2ei64_v_m)))
void vsoxseg2ei64(vbool32_t, int16_t *, vuint64m2_t, vint16mf2_t, vint16mf2_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vsoxseg2ei64_v)))
void vsoxseg2ei64(int16_t *, vuint64m1_t, vint16mf4_t, vint16mf4_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vsoxseg2ei64_v_m)))
void vsoxseg2ei64(vbool64_t, int16_t *, vuint64m1_t, vint16mf4_t, vint16mf4_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vsoxseg2ei64_v)))
void vsoxseg2ei64(uint16_t *, vuint64m4_t, vuint16m1_t, vuint16m1_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vsoxseg2ei64_v_m)))
void vsoxseg2ei64(vbool16_t, uint16_t *, vuint64m4_t, vuint16m1_t, vuint16m1_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vsoxseg2ei64_v)))
void vsoxseg2ei64(uint16_t *, vuint64m8_t, vuint16m2_t, vuint16m2_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vsoxseg2ei64_v_m)))
void vsoxseg2ei64(vbool8_t, uint16_t *, vuint64m8_t, vuint16m2_t, vuint16m2_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vsoxseg2ei64_v)))
void vsoxseg2ei64(uint16_t *, vuint64m2_t, vuint16mf2_t, vuint16mf2_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vsoxseg2ei64_v_m)))
void vsoxseg2ei64(vbool32_t, uint16_t *, vuint64m2_t, vuint16mf2_t, vuint16mf2_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vsoxseg2ei64_v)))
void vsoxseg2ei64(uint16_t *, vuint64m1_t, vuint16mf4_t, vuint16mf4_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vsoxseg2ei64_v_m)))
void vsoxseg2ei64(vbool64_t, uint16_t *, vuint64m1_t, vuint16mf4_t, vuint16mf4_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vsoxseg3ei64_v)))
void vsoxseg3ei64(int16_t *, vuint64m4_t, vint16m1_t, vint16m1_t, vint16m1_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vsoxseg3ei64_v_m)))
void vsoxseg3ei64(vbool16_t, int16_t *, vuint64m4_t, vint16m1_t, vint16m1_t, vint16m1_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vsoxseg3ei64_v)))
void vsoxseg3ei64(int16_t *, vuint64m8_t, vint16m2_t, vint16m2_t, vint16m2_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vsoxseg3ei64_v_m)))
void vsoxseg3ei64(vbool8_t, int16_t *, vuint64m8_t, vint16m2_t, vint16m2_t, vint16m2_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vsoxseg3ei64_v)))
void vsoxseg3ei64(int16_t *, vuint64m2_t, vint16mf2_t, vint16mf2_t, vint16mf2_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vsoxseg3ei64_v_m)))
void vsoxseg3ei64(vbool32_t, int16_t *, vuint64m2_t, vint16mf2_t, vint16mf2_t, vint16mf2_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vsoxseg3ei64_v)))
void vsoxseg3ei64(int16_t *, vuint64m1_t, vint16mf4_t, vint16mf4_t, vint16mf4_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vsoxseg3ei64_v_m)))
void vsoxseg3ei64(vbool64_t, int16_t *, vuint64m1_t, vint16mf4_t, vint16mf4_t, vint16mf4_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vsoxseg3ei64_v)))
void vsoxseg3ei64(uint16_t *, vuint64m4_t, vuint16m1_t, vuint16m1_t, vuint16m1_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vsoxseg3ei64_v_m)))
void vsoxseg3ei64(vbool16_t, uint16_t *, vuint64m4_t, vuint16m1_t, vuint16m1_t, vuint16m1_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vsoxseg3ei64_v)))
void vsoxseg3ei64(uint16_t *, vuint64m8_t, vuint16m2_t, vuint16m2_t, vuint16m2_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vsoxseg3ei64_v_m)))
void vsoxseg3ei64(vbool8_t, uint16_t *, vuint64m8_t, vuint16m2_t, vuint16m2_t, vuint16m2_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vsoxseg3ei64_v)))
void vsoxseg3ei64(uint16_t *, vuint64m2_t, vuint16mf2_t, vuint16mf2_t, vuint16mf2_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vsoxseg3ei64_v_m)))
void vsoxseg3ei64(vbool32_t, uint16_t *, vuint64m2_t, vuint16mf2_t, vuint16mf2_t, vuint16mf2_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vsoxseg3ei64_v)))
void vsoxseg3ei64(uint16_t *, vuint64m1_t, vuint16mf4_t, vuint16mf4_t, vuint16mf4_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vsoxseg3ei64_v_m)))
void vsoxseg3ei64(vbool64_t, uint16_t *, vuint64m1_t, vuint16mf4_t, vuint16mf4_t, vuint16mf4_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vsoxseg4ei64_v)))
void vsoxseg4ei64(int16_t *, vuint64m4_t, vint16m1_t, vint16m1_t, vint16m1_t, vint16m1_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vsoxseg4ei64_v_m)))
void vsoxseg4ei64(vbool16_t, int16_t *, vuint64m4_t, vint16m1_t, vint16m1_t, vint16m1_t, vint16m1_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vsoxseg4ei64_v)))
void vsoxseg4ei64(int16_t *, vuint64m8_t, vint16m2_t, vint16m2_t, vint16m2_t, vint16m2_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vsoxseg4ei64_v_m)))
void vsoxseg4ei64(vbool8_t, int16_t *, vuint64m8_t, vint16m2_t, vint16m2_t, vint16m2_t, vint16m2_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vsoxseg4ei64_v)))
void vsoxseg4ei64(int16_t *, vuint64m2_t, vint16mf2_t, vint16mf2_t, vint16mf2_t, vint16mf2_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vsoxseg4ei64_v_m)))
void vsoxseg4ei64(vbool32_t, int16_t *, vuint64m2_t, vint16mf2_t, vint16mf2_t, vint16mf2_t, vint16mf2_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vsoxseg4ei64_v)))
void vsoxseg4ei64(int16_t *, vuint64m1_t, vint16mf4_t, vint16mf4_t, vint16mf4_t, vint16mf4_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vsoxseg4ei64_v_m)))
void vsoxseg4ei64(vbool64_t, int16_t *, vuint64m1_t, vint16mf4_t, vint16mf4_t, vint16mf4_t, vint16mf4_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vsoxseg4ei64_v)))
void vsoxseg4ei64(uint16_t *, vuint64m4_t, vuint16m1_t, vuint16m1_t, vuint16m1_t, vuint16m1_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vsoxseg4ei64_v_m)))
void vsoxseg4ei64(vbool16_t, uint16_t *, vuint64m4_t, vuint16m1_t, vuint16m1_t, vuint16m1_t, vuint16m1_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vsoxseg4ei64_v)))
void vsoxseg4ei64(uint16_t *, vuint64m8_t, vuint16m2_t, vuint16m2_t, vuint16m2_t, vuint16m2_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vsoxseg4ei64_v_m)))
void vsoxseg4ei64(vbool8_t, uint16_t *, vuint64m8_t, vuint16m2_t, vuint16m2_t, vuint16m2_t, vuint16m2_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vsoxseg4ei64_v)))
void vsoxseg4ei64(uint16_t *, vuint64m2_t, vuint16mf2_t, vuint16mf2_t, vuint16mf2_t, vuint16mf2_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vsoxseg4ei64_v_m)))
void vsoxseg4ei64(vbool32_t, uint16_t *, vuint64m2_t, vuint16mf2_t, vuint16mf2_t, vuint16mf2_t, vuint16mf2_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vsoxseg4ei64_v)))
void vsoxseg4ei64(uint16_t *, vuint64m1_t, vuint16mf4_t, vuint16mf4_t, vuint16mf4_t, vuint16mf4_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vsoxseg4ei64_v_m)))
void vsoxseg4ei64(vbool64_t, uint16_t *, vuint64m1_t, vuint16mf4_t, vuint16mf4_t, vuint16mf4_t, vuint16mf4_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vsoxseg5ei64_v)))
void vsoxseg5ei64(int16_t *, vuint64m4_t, vint16m1_t, vint16m1_t, vint16m1_t, vint16m1_t, vint16m1_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vsoxseg5ei64_v_m)))
void vsoxseg5ei64(vbool16_t, int16_t *, vuint64m4_t, vint16m1_t, vint16m1_t, vint16m1_t, vint16m1_t, vint16m1_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vsoxseg5ei64_v)))
void vsoxseg5ei64(int16_t *, vuint64m2_t, vint16mf2_t, vint16mf2_t, vint16mf2_t, vint16mf2_t, vint16mf2_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vsoxseg5ei64_v_m)))
void vsoxseg5ei64(vbool32_t, int16_t *, vuint64m2_t, vint16mf2_t, vint16mf2_t, vint16mf2_t, vint16mf2_t, vint16mf2_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vsoxseg5ei64_v)))
void vsoxseg5ei64(int16_t *, vuint64m1_t, vint16mf4_t, vint16mf4_t, vint16mf4_t, vint16mf4_t, vint16mf4_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vsoxseg5ei64_v_m)))
void vsoxseg5ei64(vbool64_t, int16_t *, vuint64m1_t, vint16mf4_t, vint16mf4_t, vint16mf4_t, vint16mf4_t, vint16mf4_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vsoxseg5ei64_v)))
void vsoxseg5ei64(uint16_t *, vuint64m4_t, vuint16m1_t, vuint16m1_t, vuint16m1_t, vuint16m1_t, vuint16m1_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vsoxseg5ei64_v_m)))
void vsoxseg5ei64(vbool16_t, uint16_t *, vuint64m4_t, vuint16m1_t, vuint16m1_t, vuint16m1_t, vuint16m1_t, vuint16m1_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vsoxseg5ei64_v)))
void vsoxseg5ei64(uint16_t *, vuint64m2_t, vuint16mf2_t, vuint16mf2_t, vuint16mf2_t, vuint16mf2_t, vuint16mf2_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vsoxseg5ei64_v_m)))
void vsoxseg5ei64(vbool32_t, uint16_t *, vuint64m2_t, vuint16mf2_t, vuint16mf2_t, vuint16mf2_t, vuint16mf2_t, vuint16mf2_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vsoxseg5ei64_v)))
void vsoxseg5ei64(uint16_t *, vuint64m1_t, vuint16mf4_t, vuint16mf4_t, vuint16mf4_t, vuint16mf4_t, vuint16mf4_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vsoxseg5ei64_v_m)))
void vsoxseg5ei64(vbool64_t, uint16_t *, vuint64m1_t, vuint16mf4_t, vuint16mf4_t, vuint16mf4_t, vuint16mf4_t, vuint16mf4_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vsoxseg6ei64_v)))
void vsoxseg6ei64(int16_t *, vuint64m4_t, vint16m1_t, vint16m1_t, vint16m1_t, vint16m1_t, vint16m1_t, vint16m1_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vsoxseg6ei64_v_m)))
void vsoxseg6ei64(vbool16_t, int16_t *, vuint64m4_t, vint16m1_t, vint16m1_t, vint16m1_t, vint16m1_t, vint16m1_t, vint16m1_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vsoxseg6ei64_v)))
void vsoxseg6ei64(int16_t *, vuint64m2_t, vint16mf2_t, vint16mf2_t, vint16mf2_t, vint16mf2_t, vint16mf2_t, vint16mf2_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vsoxseg6ei64_v_m)))
void vsoxseg6ei64(vbool32_t, int16_t *, vuint64m2_t, vint16mf2_t, vint16mf2_t, vint16mf2_t, vint16mf2_t, vint16mf2_t, vint16mf2_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vsoxseg6ei64_v)))
void vsoxseg6ei64(int16_t *, vuint64m1_t, vint16mf4_t, vint16mf4_t, vint16mf4_t, vint16mf4_t, vint16mf4_t, vint16mf4_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vsoxseg6ei64_v_m)))
void vsoxseg6ei64(vbool64_t, int16_t *, vuint64m1_t, vint16mf4_t, vint16mf4_t, vint16mf4_t, vint16mf4_t, vint16mf4_t, vint16mf4_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vsoxseg6ei64_v)))
void vsoxseg6ei64(uint16_t *, vuint64m4_t, vuint16m1_t, vuint16m1_t, vuint16m1_t, vuint16m1_t, vuint16m1_t, vuint16m1_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vsoxseg6ei64_v_m)))
void vsoxseg6ei64(vbool16_t, uint16_t *, vuint64m4_t, vuint16m1_t, vuint16m1_t, vuint16m1_t, vuint16m1_t, vuint16m1_t, vuint16m1_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vsoxseg6ei64_v)))
void vsoxseg6ei64(uint16_t *, vuint64m2_t, vuint16mf2_t, vuint16mf2_t, vuint16mf2_t, vuint16mf2_t, vuint16mf2_t, vuint16mf2_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vsoxseg6ei64_v_m)))
void vsoxseg6ei64(vbool32_t, uint16_t *, vuint64m2_t, vuint16mf2_t, vuint16mf2_t, vuint16mf2_t, vuint16mf2_t, vuint16mf2_t, vuint16mf2_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vsoxseg6ei64_v)))
void vsoxseg6ei64(uint16_t *, vuint64m1_t, vuint16mf4_t, vuint16mf4_t, vuint16mf4_t, vuint16mf4_t, vuint16mf4_t, vuint16mf4_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vsoxseg6ei64_v_m)))
void vsoxseg6ei64(vbool64_t, uint16_t *, vuint64m1_t, vuint16mf4_t, vuint16mf4_t, vuint16mf4_t, vuint16mf4_t, vuint16mf4_t, vuint16mf4_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vsoxseg7ei64_v)))
void vsoxseg7ei64(int16_t *, vuint64m4_t, vint16m1_t, vint16m1_t, vint16m1_t, vint16m1_t, vint16m1_t, vint16m1_t, vint16m1_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vsoxseg7ei64_v_m)))
void vsoxseg7ei64(vbool16_t, int16_t *, vuint64m4_t, vint16m1_t, vint16m1_t, vint16m1_t, vint16m1_t, vint16m1_t, vint16m1_t, vint16m1_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vsoxseg7ei64_v)))
void vsoxseg7ei64(int16_t *, vuint64m2_t, vint16mf2_t, vint16mf2_t, vint16mf2_t, vint16mf2_t, vint16mf2_t, vint16mf2_t, vint16mf2_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vsoxseg7ei64_v_m)))
void vsoxseg7ei64(vbool32_t, int16_t *, vuint64m2_t, vint16mf2_t, vint16mf2_t, vint16mf2_t, vint16mf2_t, vint16mf2_t, vint16mf2_t, vint16mf2_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vsoxseg7ei64_v)))
void vsoxseg7ei64(int16_t *, vuint64m1_t, vint16mf4_t, vint16mf4_t, vint16mf4_t, vint16mf4_t, vint16mf4_t, vint16mf4_t, vint16mf4_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vsoxseg7ei64_v_m)))
void vsoxseg7ei64(vbool64_t, int16_t *, vuint64m1_t, vint16mf4_t, vint16mf4_t, vint16mf4_t, vint16mf4_t, vint16mf4_t, vint16mf4_t, vint16mf4_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vsoxseg7ei64_v)))
void vsoxseg7ei64(uint16_t *, vuint64m4_t, vuint16m1_t, vuint16m1_t, vuint16m1_t, vuint16m1_t, vuint16m1_t, vuint16m1_t, vuint16m1_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vsoxseg7ei64_v_m)))
void vsoxseg7ei64(vbool16_t, uint16_t *, vuint64m4_t, vuint16m1_t, vuint16m1_t, vuint16m1_t, vuint16m1_t, vuint16m1_t, vuint16m1_t, vuint16m1_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vsoxseg7ei64_v)))
void vsoxseg7ei64(uint16_t *, vuint64m2_t, vuint16mf2_t, vuint16mf2_t, vuint16mf2_t, vuint16mf2_t, vuint16mf2_t, vuint16mf2_t, vuint16mf2_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vsoxseg7ei64_v_m)))
void vsoxseg7ei64(vbool32_t, uint16_t *, vuint64m2_t, vuint16mf2_t, vuint16mf2_t, vuint16mf2_t, vuint16mf2_t, vuint16mf2_t, vuint16mf2_t, vuint16mf2_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vsoxseg7ei64_v)))
void vsoxseg7ei64(uint16_t *, vuint64m1_t, vuint16mf4_t, vuint16mf4_t, vuint16mf4_t, vuint16mf4_t, vuint16mf4_t, vuint16mf4_t, vuint16mf4_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vsoxseg7ei64_v_m)))
void vsoxseg7ei64(vbool64_t, uint16_t *, vuint64m1_t, vuint16mf4_t, vuint16mf4_t, vuint16mf4_t, vuint16mf4_t, vuint16mf4_t, vuint16mf4_t, vuint16mf4_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vsoxseg8ei64_v)))
void vsoxseg8ei64(int16_t *, vuint64m4_t, vint16m1_t, vint16m1_t, vint16m1_t, vint16m1_t, vint16m1_t, vint16m1_t, vint16m1_t, vint16m1_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vsoxseg8ei64_v_m)))
void vsoxseg8ei64(vbool16_t, int16_t *, vuint64m4_t, vint16m1_t, vint16m1_t, vint16m1_t, vint16m1_t, vint16m1_t, vint16m1_t, vint16m1_t, vint16m1_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vsoxseg8ei64_v)))
void vsoxseg8ei64(int16_t *, vuint64m2_t, vint16mf2_t, vint16mf2_t, vint16mf2_t, vint16mf2_t, vint16mf2_t, vint16mf2_t, vint16mf2_t, vint16mf2_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vsoxseg8ei64_v_m)))
void vsoxseg8ei64(vbool32_t, int16_t *, vuint64m2_t, vint16mf2_t, vint16mf2_t, vint16mf2_t, vint16mf2_t, vint16mf2_t, vint16mf2_t, vint16mf2_t, vint16mf2_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vsoxseg8ei64_v)))
void vsoxseg8ei64(int16_t *, vuint64m1_t, vint16mf4_t, vint16mf4_t, vint16mf4_t, vint16mf4_t, vint16mf4_t, vint16mf4_t, vint16mf4_t, vint16mf4_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vsoxseg8ei64_v_m)))
void vsoxseg8ei64(vbool64_t, int16_t *, vuint64m1_t, vint16mf4_t, vint16mf4_t, vint16mf4_t, vint16mf4_t, vint16mf4_t, vint16mf4_t, vint16mf4_t, vint16mf4_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vsoxseg8ei64_v)))
void vsoxseg8ei64(uint16_t *, vuint64m4_t, vuint16m1_t, vuint16m1_t, vuint16m1_t, vuint16m1_t, vuint16m1_t, vuint16m1_t, vuint16m1_t, vuint16m1_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vsoxseg8ei64_v_m)))
void vsoxseg8ei64(vbool16_t, uint16_t *, vuint64m4_t, vuint16m1_t, vuint16m1_t, vuint16m1_t, vuint16m1_t, vuint16m1_t, vuint16m1_t, vuint16m1_t, vuint16m1_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vsoxseg8ei64_v)))
void vsoxseg8ei64(uint16_t *, vuint64m2_t, vuint16mf2_t, vuint16mf2_t, vuint16mf2_t, vuint16mf2_t, vuint16mf2_t, vuint16mf2_t, vuint16mf2_t, vuint16mf2_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vsoxseg8ei64_v_m)))
void vsoxseg8ei64(vbool32_t, uint16_t *, vuint64m2_t, vuint16mf2_t, vuint16mf2_t, vuint16mf2_t, vuint16mf2_t, vuint16mf2_t, vuint16mf2_t, vuint16mf2_t, vuint16mf2_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vsoxseg8ei64_v)))
void vsoxseg8ei64(uint16_t *, vuint64m1_t, vuint16mf4_t, vuint16mf4_t, vuint16mf4_t, vuint16mf4_t, vuint16mf4_t, vuint16mf4_t, vuint16mf4_t, vuint16mf4_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vsoxseg8ei64_v_m)))
void vsoxseg8ei64(vbool64_t, uint16_t *, vuint64m1_t, vuint16mf4_t, vuint16mf4_t, vuint16mf4_t, vuint16mf4_t, vuint16mf4_t, vuint16mf4_t, vuint16mf4_t, vuint16mf4_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vsoxseg2ei64_v)))
void vsoxseg2ei64(int32_t *, vuint64m2_t, vint32m1_t, vint32m1_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vsoxseg2ei64_v_m)))
void vsoxseg2ei64(vbool32_t, int32_t *, vuint64m2_t, vint32m1_t, vint32m1_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vsoxseg2ei64_v)))
void vsoxseg2ei64(int32_t *, vuint64m4_t, vint32m2_t, vint32m2_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vsoxseg2ei64_v_m)))
void vsoxseg2ei64(vbool16_t, int32_t *, vuint64m4_t, vint32m2_t, vint32m2_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vsoxseg2ei64_v)))
void vsoxseg2ei64(int32_t *, vuint64m8_t, vint32m4_t, vint32m4_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vsoxseg2ei64_v_m)))
void vsoxseg2ei64(vbool8_t, int32_t *, vuint64m8_t, vint32m4_t, vint32m4_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vsoxseg2ei64_v)))
void vsoxseg2ei64(int32_t *, vuint64m1_t, vint32mf2_t, vint32mf2_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vsoxseg2ei64_v_m)))
void vsoxseg2ei64(vbool64_t, int32_t *, vuint64m1_t, vint32mf2_t, vint32mf2_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vsoxseg2ei64_v)))
void vsoxseg2ei64(uint32_t *, vuint64m2_t, vuint32m1_t, vuint32m1_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vsoxseg2ei64_v_m)))
void vsoxseg2ei64(vbool32_t, uint32_t *, vuint64m2_t, vuint32m1_t, vuint32m1_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vsoxseg2ei64_v)))
void vsoxseg2ei64(uint32_t *, vuint64m4_t, vuint32m2_t, vuint32m2_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vsoxseg2ei64_v_m)))
void vsoxseg2ei64(vbool16_t, uint32_t *, vuint64m4_t, vuint32m2_t, vuint32m2_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vsoxseg2ei64_v)))
void vsoxseg2ei64(uint32_t *, vuint64m8_t, vuint32m4_t, vuint32m4_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vsoxseg2ei64_v_m)))
void vsoxseg2ei64(vbool8_t, uint32_t *, vuint64m8_t, vuint32m4_t, vuint32m4_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vsoxseg2ei64_v)))
void vsoxseg2ei64(uint32_t *, vuint64m1_t, vuint32mf2_t, vuint32mf2_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vsoxseg2ei64_v_m)))
void vsoxseg2ei64(vbool64_t, uint32_t *, vuint64m1_t, vuint32mf2_t, vuint32mf2_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vsoxseg3ei64_v)))
void vsoxseg3ei64(int32_t *, vuint64m2_t, vint32m1_t, vint32m1_t, vint32m1_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vsoxseg3ei64_v_m)))
void vsoxseg3ei64(vbool32_t, int32_t *, vuint64m2_t, vint32m1_t, vint32m1_t, vint32m1_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vsoxseg3ei64_v)))
void vsoxseg3ei64(int32_t *, vuint64m4_t, vint32m2_t, vint32m2_t, vint32m2_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vsoxseg3ei64_v_m)))
void vsoxseg3ei64(vbool16_t, int32_t *, vuint64m4_t, vint32m2_t, vint32m2_t, vint32m2_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vsoxseg3ei64_v)))
void vsoxseg3ei64(int32_t *, vuint64m1_t, vint32mf2_t, vint32mf2_t, vint32mf2_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vsoxseg3ei64_v_m)))
void vsoxseg3ei64(vbool64_t, int32_t *, vuint64m1_t, vint32mf2_t, vint32mf2_t, vint32mf2_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vsoxseg3ei64_v)))
void vsoxseg3ei64(uint32_t *, vuint64m2_t, vuint32m1_t, vuint32m1_t, vuint32m1_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vsoxseg3ei64_v_m)))
void vsoxseg3ei64(vbool32_t, uint32_t *, vuint64m2_t, vuint32m1_t, vuint32m1_t, vuint32m1_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vsoxseg3ei64_v)))
void vsoxseg3ei64(uint32_t *, vuint64m4_t, vuint32m2_t, vuint32m2_t, vuint32m2_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vsoxseg3ei64_v_m)))
void vsoxseg3ei64(vbool16_t, uint32_t *, vuint64m4_t, vuint32m2_t, vuint32m2_t, vuint32m2_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vsoxseg3ei64_v)))
void vsoxseg3ei64(uint32_t *, vuint64m1_t, vuint32mf2_t, vuint32mf2_t, vuint32mf2_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vsoxseg3ei64_v_m)))
void vsoxseg3ei64(vbool64_t, uint32_t *, vuint64m1_t, vuint32mf2_t, vuint32mf2_t, vuint32mf2_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vsoxseg4ei64_v)))
void vsoxseg4ei64(int32_t *, vuint64m2_t, vint32m1_t, vint32m1_t, vint32m1_t, vint32m1_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vsoxseg4ei64_v_m)))
void vsoxseg4ei64(vbool32_t, int32_t *, vuint64m2_t, vint32m1_t, vint32m1_t, vint32m1_t, vint32m1_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vsoxseg4ei64_v)))
void vsoxseg4ei64(int32_t *, vuint64m4_t, vint32m2_t, vint32m2_t, vint32m2_t, vint32m2_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vsoxseg4ei64_v_m)))
void vsoxseg4ei64(vbool16_t, int32_t *, vuint64m4_t, vint32m2_t, vint32m2_t, vint32m2_t, vint32m2_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vsoxseg4ei64_v)))
void vsoxseg4ei64(int32_t *, vuint64m1_t, vint32mf2_t, vint32mf2_t, vint32mf2_t, vint32mf2_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vsoxseg4ei64_v_m)))
void vsoxseg4ei64(vbool64_t, int32_t *, vuint64m1_t, vint32mf2_t, vint32mf2_t, vint32mf2_t, vint32mf2_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vsoxseg4ei64_v)))
void vsoxseg4ei64(uint32_t *, vuint64m2_t, vuint32m1_t, vuint32m1_t, vuint32m1_t, vuint32m1_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vsoxseg4ei64_v_m)))
void vsoxseg4ei64(vbool32_t, uint32_t *, vuint64m2_t, vuint32m1_t, vuint32m1_t, vuint32m1_t, vuint32m1_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vsoxseg4ei64_v)))
void vsoxseg4ei64(uint32_t *, vuint64m4_t, vuint32m2_t, vuint32m2_t, vuint32m2_t, vuint32m2_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vsoxseg4ei64_v_m)))
void vsoxseg4ei64(vbool16_t, uint32_t *, vuint64m4_t, vuint32m2_t, vuint32m2_t, vuint32m2_t, vuint32m2_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vsoxseg4ei64_v)))
void vsoxseg4ei64(uint32_t *, vuint64m1_t, vuint32mf2_t, vuint32mf2_t, vuint32mf2_t, vuint32mf2_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vsoxseg4ei64_v_m)))
void vsoxseg4ei64(vbool64_t, uint32_t *, vuint64m1_t, vuint32mf2_t, vuint32mf2_t, vuint32mf2_t, vuint32mf2_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vsoxseg5ei64_v)))
void vsoxseg5ei64(int32_t *, vuint64m2_t, vint32m1_t, vint32m1_t, vint32m1_t, vint32m1_t, vint32m1_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vsoxseg5ei64_v_m)))
void vsoxseg5ei64(vbool32_t, int32_t *, vuint64m2_t, vint32m1_t, vint32m1_t, vint32m1_t, vint32m1_t, vint32m1_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vsoxseg5ei64_v)))
void vsoxseg5ei64(int32_t *, vuint64m1_t, vint32mf2_t, vint32mf2_t, vint32mf2_t, vint32mf2_t, vint32mf2_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vsoxseg5ei64_v_m)))
void vsoxseg5ei64(vbool64_t, int32_t *, vuint64m1_t, vint32mf2_t, vint32mf2_t, vint32mf2_t, vint32mf2_t, vint32mf2_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vsoxseg5ei64_v)))
void vsoxseg5ei64(uint32_t *, vuint64m2_t, vuint32m1_t, vuint32m1_t, vuint32m1_t, vuint32m1_t, vuint32m1_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vsoxseg5ei64_v_m)))
void vsoxseg5ei64(vbool32_t, uint32_t *, vuint64m2_t, vuint32m1_t, vuint32m1_t, vuint32m1_t, vuint32m1_t, vuint32m1_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vsoxseg5ei64_v)))
void vsoxseg5ei64(uint32_t *, vuint64m1_t, vuint32mf2_t, vuint32mf2_t, vuint32mf2_t, vuint32mf2_t, vuint32mf2_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vsoxseg5ei64_v_m)))
void vsoxseg5ei64(vbool64_t, uint32_t *, vuint64m1_t, vuint32mf2_t, vuint32mf2_t, vuint32mf2_t, vuint32mf2_t, vuint32mf2_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vsoxseg6ei64_v)))
void vsoxseg6ei64(int32_t *, vuint64m2_t, vint32m1_t, vint32m1_t, vint32m1_t, vint32m1_t, vint32m1_t, vint32m1_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vsoxseg6ei64_v_m)))
void vsoxseg6ei64(vbool32_t, int32_t *, vuint64m2_t, vint32m1_t, vint32m1_t, vint32m1_t, vint32m1_t, vint32m1_t, vint32m1_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vsoxseg6ei64_v)))
void vsoxseg6ei64(int32_t *, vuint64m1_t, vint32mf2_t, vint32mf2_t, vint32mf2_t, vint32mf2_t, vint32mf2_t, vint32mf2_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vsoxseg6ei64_v_m)))
void vsoxseg6ei64(vbool64_t, int32_t *, vuint64m1_t, vint32mf2_t, vint32mf2_t, vint32mf2_t, vint32mf2_t, vint32mf2_t, vint32mf2_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vsoxseg6ei64_v)))
void vsoxseg6ei64(uint32_t *, vuint64m2_t, vuint32m1_t, vuint32m1_t, vuint32m1_t, vuint32m1_t, vuint32m1_t, vuint32m1_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vsoxseg6ei64_v_m)))
void vsoxseg6ei64(vbool32_t, uint32_t *, vuint64m2_t, vuint32m1_t, vuint32m1_t, vuint32m1_t, vuint32m1_t, vuint32m1_t, vuint32m1_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vsoxseg6ei64_v)))
void vsoxseg6ei64(uint32_t *, vuint64m1_t, vuint32mf2_t, vuint32mf2_t, vuint32mf2_t, vuint32mf2_t, vuint32mf2_t, vuint32mf2_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vsoxseg6ei64_v_m)))
void vsoxseg6ei64(vbool64_t, uint32_t *, vuint64m1_t, vuint32mf2_t, vuint32mf2_t, vuint32mf2_t, vuint32mf2_t, vuint32mf2_t, vuint32mf2_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vsoxseg7ei64_v)))
void vsoxseg7ei64(int32_t *, vuint64m2_t, vint32m1_t, vint32m1_t, vint32m1_t, vint32m1_t, vint32m1_t, vint32m1_t, vint32m1_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vsoxseg7ei64_v_m)))
void vsoxseg7ei64(vbool32_t, int32_t *, vuint64m2_t, vint32m1_t, vint32m1_t, vint32m1_t, vint32m1_t, vint32m1_t, vint32m1_t, vint32m1_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vsoxseg7ei64_v)))
void vsoxseg7ei64(int32_t *, vuint64m1_t, vint32mf2_t, vint32mf2_t, vint32mf2_t, vint32mf2_t, vint32mf2_t, vint32mf2_t, vint32mf2_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vsoxseg7ei64_v_m)))
void vsoxseg7ei64(vbool64_t, int32_t *, vuint64m1_t, vint32mf2_t, vint32mf2_t, vint32mf2_t, vint32mf2_t, vint32mf2_t, vint32mf2_t, vint32mf2_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vsoxseg7ei64_v)))
void vsoxseg7ei64(uint32_t *, vuint64m2_t, vuint32m1_t, vuint32m1_t, vuint32m1_t, vuint32m1_t, vuint32m1_t, vuint32m1_t, vuint32m1_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vsoxseg7ei64_v_m)))
void vsoxseg7ei64(vbool32_t, uint32_t *, vuint64m2_t, vuint32m1_t, vuint32m1_t, vuint32m1_t, vuint32m1_t, vuint32m1_t, vuint32m1_t, vuint32m1_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vsoxseg7ei64_v)))
void vsoxseg7ei64(uint32_t *, vuint64m1_t, vuint32mf2_t, vuint32mf2_t, vuint32mf2_t, vuint32mf2_t, vuint32mf2_t, vuint32mf2_t, vuint32mf2_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vsoxseg7ei64_v_m)))
void vsoxseg7ei64(vbool64_t, uint32_t *, vuint64m1_t, vuint32mf2_t, vuint32mf2_t, vuint32mf2_t, vuint32mf2_t, vuint32mf2_t, vuint32mf2_t, vuint32mf2_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vsoxseg8ei64_v)))
void vsoxseg8ei64(int32_t *, vuint64m2_t, vint32m1_t, vint32m1_t, vint32m1_t, vint32m1_t, vint32m1_t, vint32m1_t, vint32m1_t, vint32m1_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vsoxseg8ei64_v_m)))
void vsoxseg8ei64(vbool32_t, int32_t *, vuint64m2_t, vint32m1_t, vint32m1_t, vint32m1_t, vint32m1_t, vint32m1_t, vint32m1_t, vint32m1_t, vint32m1_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vsoxseg8ei64_v)))
void vsoxseg8ei64(int32_t *, vuint64m1_t, vint32mf2_t, vint32mf2_t, vint32mf2_t, vint32mf2_t, vint32mf2_t, vint32mf2_t, vint32mf2_t, vint32mf2_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vsoxseg8ei64_v_m)))
void vsoxseg8ei64(vbool64_t, int32_t *, vuint64m1_t, vint32mf2_t, vint32mf2_t, vint32mf2_t, vint32mf2_t, vint32mf2_t, vint32mf2_t, vint32mf2_t, vint32mf2_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vsoxseg8ei64_v)))
void vsoxseg8ei64(uint32_t *, vuint64m2_t, vuint32m1_t, vuint32m1_t, vuint32m1_t, vuint32m1_t, vuint32m1_t, vuint32m1_t, vuint32m1_t, vuint32m1_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vsoxseg8ei64_v_m)))
void vsoxseg8ei64(vbool32_t, uint32_t *, vuint64m2_t, vuint32m1_t, vuint32m1_t, vuint32m1_t, vuint32m1_t, vuint32m1_t, vuint32m1_t, vuint32m1_t, vuint32m1_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vsoxseg8ei64_v)))
void vsoxseg8ei64(uint32_t *, vuint64m1_t, vuint32mf2_t, vuint32mf2_t, vuint32mf2_t, vuint32mf2_t, vuint32mf2_t, vuint32mf2_t, vuint32mf2_t, vuint32mf2_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vsoxseg8ei64_v_m)))
void vsoxseg8ei64(vbool64_t, uint32_t *, vuint64m1_t, vuint32mf2_t, vuint32mf2_t, vuint32mf2_t, vuint32mf2_t, vuint32mf2_t, vuint32mf2_t, vuint32mf2_t, vuint32mf2_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vsoxseg2ei8_v)))
void vsoxseg2ei8(int64_t *, vuint8mf8_t, vint64m1_t, vint64m1_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vsoxseg2ei8_v_m)))
void vsoxseg2ei8(vbool64_t, int64_t *, vuint8mf8_t, vint64m1_t, vint64m1_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vsoxseg2ei8_v)))
void vsoxseg2ei8(int64_t *, vuint8mf4_t, vint64m2_t, vint64m2_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vsoxseg2ei8_v_m)))
void vsoxseg2ei8(vbool32_t, int64_t *, vuint8mf4_t, vint64m2_t, vint64m2_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vsoxseg2ei8_v)))
void vsoxseg2ei8(int64_t *, vuint8mf2_t, vint64m4_t, vint64m4_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vsoxseg2ei8_v_m)))
void vsoxseg2ei8(vbool16_t, int64_t *, vuint8mf2_t, vint64m4_t, vint64m4_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vsoxseg2ei8_v)))
void vsoxseg2ei8(uint64_t *, vuint8mf8_t, vuint64m1_t, vuint64m1_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vsoxseg2ei8_v_m)))
void vsoxseg2ei8(vbool64_t, uint64_t *, vuint8mf8_t, vuint64m1_t, vuint64m1_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vsoxseg2ei8_v)))
void vsoxseg2ei8(uint64_t *, vuint8mf4_t, vuint64m2_t, vuint64m2_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vsoxseg2ei8_v_m)))
void vsoxseg2ei8(vbool32_t, uint64_t *, vuint8mf4_t, vuint64m2_t, vuint64m2_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vsoxseg2ei8_v)))
void vsoxseg2ei8(uint64_t *, vuint8mf2_t, vuint64m4_t, vuint64m4_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vsoxseg2ei8_v_m)))
void vsoxseg2ei8(vbool16_t, uint64_t *, vuint8mf2_t, vuint64m4_t, vuint64m4_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vsoxseg3ei8_v)))
void vsoxseg3ei8(int64_t *, vuint8mf8_t, vint64m1_t, vint64m1_t, vint64m1_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vsoxseg3ei8_v_m)))
void vsoxseg3ei8(vbool64_t, int64_t *, vuint8mf8_t, vint64m1_t, vint64m1_t, vint64m1_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vsoxseg3ei8_v)))
void vsoxseg3ei8(int64_t *, vuint8mf4_t, vint64m2_t, vint64m2_t, vint64m2_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vsoxseg3ei8_v_m)))
void vsoxseg3ei8(vbool32_t, int64_t *, vuint8mf4_t, vint64m2_t, vint64m2_t, vint64m2_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vsoxseg3ei8_v)))
void vsoxseg3ei8(uint64_t *, vuint8mf8_t, vuint64m1_t, vuint64m1_t, vuint64m1_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vsoxseg3ei8_v_m)))
void vsoxseg3ei8(vbool64_t, uint64_t *, vuint8mf8_t, vuint64m1_t, vuint64m1_t, vuint64m1_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vsoxseg3ei8_v)))
void vsoxseg3ei8(uint64_t *, vuint8mf4_t, vuint64m2_t, vuint64m2_t, vuint64m2_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vsoxseg3ei8_v_m)))
void vsoxseg3ei8(vbool32_t, uint64_t *, vuint8mf4_t, vuint64m2_t, vuint64m2_t, vuint64m2_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vsoxseg4ei8_v)))
void vsoxseg4ei8(int64_t *, vuint8mf8_t, vint64m1_t, vint64m1_t, vint64m1_t, vint64m1_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vsoxseg4ei8_v_m)))
void vsoxseg4ei8(vbool64_t, int64_t *, vuint8mf8_t, vint64m1_t, vint64m1_t, vint64m1_t, vint64m1_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vsoxseg4ei8_v)))
void vsoxseg4ei8(int64_t *, vuint8mf4_t, vint64m2_t, vint64m2_t, vint64m2_t, vint64m2_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vsoxseg4ei8_v_m)))
void vsoxseg4ei8(vbool32_t, int64_t *, vuint8mf4_t, vint64m2_t, vint64m2_t, vint64m2_t, vint64m2_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vsoxseg4ei8_v)))
void vsoxseg4ei8(uint64_t *, vuint8mf8_t, vuint64m1_t, vuint64m1_t, vuint64m1_t, vuint64m1_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vsoxseg4ei8_v_m)))
void vsoxseg4ei8(vbool64_t, uint64_t *, vuint8mf8_t, vuint64m1_t, vuint64m1_t, vuint64m1_t, vuint64m1_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vsoxseg4ei8_v)))
void vsoxseg4ei8(uint64_t *, vuint8mf4_t, vuint64m2_t, vuint64m2_t, vuint64m2_t, vuint64m2_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vsoxseg4ei8_v_m)))
void vsoxseg4ei8(vbool32_t, uint64_t *, vuint8mf4_t, vuint64m2_t, vuint64m2_t, vuint64m2_t, vuint64m2_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vsoxseg5ei8_v)))
void vsoxseg5ei8(int64_t *, vuint8mf8_t, vint64m1_t, vint64m1_t, vint64m1_t, vint64m1_t, vint64m1_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vsoxseg5ei8_v_m)))
void vsoxseg5ei8(vbool64_t, int64_t *, vuint8mf8_t, vint64m1_t, vint64m1_t, vint64m1_t, vint64m1_t, vint64m1_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vsoxseg5ei8_v)))
void vsoxseg5ei8(uint64_t *, vuint8mf8_t, vuint64m1_t, vuint64m1_t, vuint64m1_t, vuint64m1_t, vuint64m1_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vsoxseg5ei8_v_m)))
void vsoxseg5ei8(vbool64_t, uint64_t *, vuint8mf8_t, vuint64m1_t, vuint64m1_t, vuint64m1_t, vuint64m1_t, vuint64m1_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vsoxseg6ei8_v)))
void vsoxseg6ei8(int64_t *, vuint8mf8_t, vint64m1_t, vint64m1_t, vint64m1_t, vint64m1_t, vint64m1_t, vint64m1_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vsoxseg6ei8_v_m)))
void vsoxseg6ei8(vbool64_t, int64_t *, vuint8mf8_t, vint64m1_t, vint64m1_t, vint64m1_t, vint64m1_t, vint64m1_t, vint64m1_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vsoxseg6ei8_v)))
void vsoxseg6ei8(uint64_t *, vuint8mf8_t, vuint64m1_t, vuint64m1_t, vuint64m1_t, vuint64m1_t, vuint64m1_t, vuint64m1_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vsoxseg6ei8_v_m)))
void vsoxseg6ei8(vbool64_t, uint64_t *, vuint8mf8_t, vuint64m1_t, vuint64m1_t, vuint64m1_t, vuint64m1_t, vuint64m1_t, vuint64m1_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vsoxseg7ei8_v)))
void vsoxseg7ei8(int64_t *, vuint8mf8_t, vint64m1_t, vint64m1_t, vint64m1_t, vint64m1_t, vint64m1_t, vint64m1_t, vint64m1_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vsoxseg7ei8_v_m)))
void vsoxseg7ei8(vbool64_t, int64_t *, vuint8mf8_t, vint64m1_t, vint64m1_t, vint64m1_t, vint64m1_t, vint64m1_t, vint64m1_t, vint64m1_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vsoxseg7ei8_v)))
void vsoxseg7ei8(uint64_t *, vuint8mf8_t, vuint64m1_t, vuint64m1_t, vuint64m1_t, vuint64m1_t, vuint64m1_t, vuint64m1_t, vuint64m1_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vsoxseg7ei8_v_m)))
void vsoxseg7ei8(vbool64_t, uint64_t *, vuint8mf8_t, vuint64m1_t, vuint64m1_t, vuint64m1_t, vuint64m1_t, vuint64m1_t, vuint64m1_t, vuint64m1_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vsoxseg8ei8_v)))
void vsoxseg8ei8(int64_t *, vuint8mf8_t, vint64m1_t, vint64m1_t, vint64m1_t, vint64m1_t, vint64m1_t, vint64m1_t, vint64m1_t, vint64m1_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vsoxseg8ei8_v_m)))
void vsoxseg8ei8(vbool64_t, int64_t *, vuint8mf8_t, vint64m1_t, vint64m1_t, vint64m1_t, vint64m1_t, vint64m1_t, vint64m1_t, vint64m1_t, vint64m1_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vsoxseg8ei8_v)))
void vsoxseg8ei8(uint64_t *, vuint8mf8_t, vuint64m1_t, vuint64m1_t, vuint64m1_t, vuint64m1_t, vuint64m1_t, vuint64m1_t, vuint64m1_t, vuint64m1_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vsoxseg8ei8_v_m)))
void vsoxseg8ei8(vbool64_t, uint64_t *, vuint8mf8_t, vuint64m1_t, vuint64m1_t, vuint64m1_t, vuint64m1_t, vuint64m1_t, vuint64m1_t, vuint64m1_t, vuint64m1_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vsoxseg2ei16_v)))
void vsoxseg2ei16(int64_t *, vuint16mf4_t, vint64m1_t, vint64m1_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vsoxseg2ei16_v_m)))
void vsoxseg2ei16(vbool64_t, int64_t *, vuint16mf4_t, vint64m1_t, vint64m1_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vsoxseg2ei16_v)))
void vsoxseg2ei16(int64_t *, vuint16mf2_t, vint64m2_t, vint64m2_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vsoxseg2ei16_v_m)))
void vsoxseg2ei16(vbool32_t, int64_t *, vuint16mf2_t, vint64m2_t, vint64m2_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vsoxseg2ei16_v)))
void vsoxseg2ei16(int64_t *, vuint16m1_t, vint64m4_t, vint64m4_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vsoxseg2ei16_v_m)))
void vsoxseg2ei16(vbool16_t, int64_t *, vuint16m1_t, vint64m4_t, vint64m4_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vsoxseg2ei16_v)))
void vsoxseg2ei16(uint64_t *, vuint16mf4_t, vuint64m1_t, vuint64m1_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vsoxseg2ei16_v_m)))
void vsoxseg2ei16(vbool64_t, uint64_t *, vuint16mf4_t, vuint64m1_t, vuint64m1_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vsoxseg2ei16_v)))
void vsoxseg2ei16(uint64_t *, vuint16mf2_t, vuint64m2_t, vuint64m2_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vsoxseg2ei16_v_m)))
void vsoxseg2ei16(vbool32_t, uint64_t *, vuint16mf2_t, vuint64m2_t, vuint64m2_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vsoxseg2ei16_v)))
void vsoxseg2ei16(uint64_t *, vuint16m1_t, vuint64m4_t, vuint64m4_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vsoxseg2ei16_v_m)))
void vsoxseg2ei16(vbool16_t, uint64_t *, vuint16m1_t, vuint64m4_t, vuint64m4_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vsoxseg3ei16_v)))
void vsoxseg3ei16(int64_t *, vuint16mf4_t, vint64m1_t, vint64m1_t, vint64m1_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vsoxseg3ei16_v_m)))
void vsoxseg3ei16(vbool64_t, int64_t *, vuint16mf4_t, vint64m1_t, vint64m1_t, vint64m1_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vsoxseg3ei16_v)))
void vsoxseg3ei16(int64_t *, vuint16mf2_t, vint64m2_t, vint64m2_t, vint64m2_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vsoxseg3ei16_v_m)))
void vsoxseg3ei16(vbool32_t, int64_t *, vuint16mf2_t, vint64m2_t, vint64m2_t, vint64m2_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vsoxseg3ei16_v)))
void vsoxseg3ei16(uint64_t *, vuint16mf4_t, vuint64m1_t, vuint64m1_t, vuint64m1_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vsoxseg3ei16_v_m)))
void vsoxseg3ei16(vbool64_t, uint64_t *, vuint16mf4_t, vuint64m1_t, vuint64m1_t, vuint64m1_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vsoxseg3ei16_v)))
void vsoxseg3ei16(uint64_t *, vuint16mf2_t, vuint64m2_t, vuint64m2_t, vuint64m2_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vsoxseg3ei16_v_m)))
void vsoxseg3ei16(vbool32_t, uint64_t *, vuint16mf2_t, vuint64m2_t, vuint64m2_t, vuint64m2_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vsoxseg4ei16_v)))
void vsoxseg4ei16(int64_t *, vuint16mf4_t, vint64m1_t, vint64m1_t, vint64m1_t, vint64m1_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vsoxseg4ei16_v_m)))
void vsoxseg4ei16(vbool64_t, int64_t *, vuint16mf4_t, vint64m1_t, vint64m1_t, vint64m1_t, vint64m1_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vsoxseg4ei16_v)))
void vsoxseg4ei16(int64_t *, vuint16mf2_t, vint64m2_t, vint64m2_t, vint64m2_t, vint64m2_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vsoxseg4ei16_v_m)))
void vsoxseg4ei16(vbool32_t, int64_t *, vuint16mf2_t, vint64m2_t, vint64m2_t, vint64m2_t, vint64m2_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vsoxseg4ei16_v)))
void vsoxseg4ei16(uint64_t *, vuint16mf4_t, vuint64m1_t, vuint64m1_t, vuint64m1_t, vuint64m1_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vsoxseg4ei16_v_m)))
void vsoxseg4ei16(vbool64_t, uint64_t *, vuint16mf4_t, vuint64m1_t, vuint64m1_t, vuint64m1_t, vuint64m1_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vsoxseg4ei16_v)))
void vsoxseg4ei16(uint64_t *, vuint16mf2_t, vuint64m2_t, vuint64m2_t, vuint64m2_t, vuint64m2_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vsoxseg4ei16_v_m)))
void vsoxseg4ei16(vbool32_t, uint64_t *, vuint16mf2_t, vuint64m2_t, vuint64m2_t, vuint64m2_t, vuint64m2_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vsoxseg5ei16_v)))
void vsoxseg5ei16(int64_t *, vuint16mf4_t, vint64m1_t, vint64m1_t, vint64m1_t, vint64m1_t, vint64m1_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vsoxseg5ei16_v_m)))
void vsoxseg5ei16(vbool64_t, int64_t *, vuint16mf4_t, vint64m1_t, vint64m1_t, vint64m1_t, vint64m1_t, vint64m1_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vsoxseg5ei16_v)))
void vsoxseg5ei16(uint64_t *, vuint16mf4_t, vuint64m1_t, vuint64m1_t, vuint64m1_t, vuint64m1_t, vuint64m1_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vsoxseg5ei16_v_m)))
void vsoxseg5ei16(vbool64_t, uint64_t *, vuint16mf4_t, vuint64m1_t, vuint64m1_t, vuint64m1_t, vuint64m1_t, vuint64m1_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vsoxseg6ei16_v)))
void vsoxseg6ei16(int64_t *, vuint16mf4_t, vint64m1_t, vint64m1_t, vint64m1_t, vint64m1_t, vint64m1_t, vint64m1_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vsoxseg6ei16_v_m)))
void vsoxseg6ei16(vbool64_t, int64_t *, vuint16mf4_t, vint64m1_t, vint64m1_t, vint64m1_t, vint64m1_t, vint64m1_t, vint64m1_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vsoxseg6ei16_v)))
void vsoxseg6ei16(uint64_t *, vuint16mf4_t, vuint64m1_t, vuint64m1_t, vuint64m1_t, vuint64m1_t, vuint64m1_t, vuint64m1_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vsoxseg6ei16_v_m)))
void vsoxseg6ei16(vbool64_t, uint64_t *, vuint16mf4_t, vuint64m1_t, vuint64m1_t, vuint64m1_t, vuint64m1_t, vuint64m1_t, vuint64m1_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vloxei8_v)))
vint64m1_t vloxei8(const int64_t *, vuint8mf8_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vloxei8_v_m)))
vint64m1_t vloxei8(vbool64_t, vint64m1_t, const int64_t *, vuint8mf8_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vloxei8_v)))
vint64m2_t vloxei8(const int64_t *, vuint8mf4_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vloxei8_v_m)))
vint64m2_t vloxei8(vbool32_t, vint64m2_t, const int64_t *, vuint8mf4_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vloxei8_v)))
vint64m4_t vloxei8(const int64_t *, vuint8mf2_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vloxei8_v_m)))
vint64m4_t vloxei8(vbool16_t, vint64m4_t, const int64_t *, vuint8mf2_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vloxei8_v)))
vint64m8_t vloxei8(const int64_t *, vuint8m1_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vloxei8_v_m)))
vint64m8_t vloxei8(vbool8_t, vint64m8_t, const int64_t *, vuint8m1_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vsoxseg7ei16_v)))
void vsoxseg7ei16(int64_t *, vuint16mf4_t, vint64m1_t, vint64m1_t, vint64m1_t, vint64m1_t, vint64m1_t, vint64m1_t, vint64m1_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vsoxseg7ei16_v_m)))
void vsoxseg7ei16(vbool64_t, int64_t *, vuint16mf4_t, vint64m1_t, vint64m1_t, vint64m1_t, vint64m1_t, vint64m1_t, vint64m1_t, vint64m1_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vsoxseg7ei16_v)))
void vsoxseg7ei16(uint64_t *, vuint16mf4_t, vuint64m1_t, vuint64m1_t, vuint64m1_t, vuint64m1_t, vuint64m1_t, vuint64m1_t, vuint64m1_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vsoxseg7ei16_v_m)))
void vsoxseg7ei16(vbool64_t, uint64_t *, vuint16mf4_t, vuint64m1_t, vuint64m1_t, vuint64m1_t, vuint64m1_t, vuint64m1_t, vuint64m1_t, vuint64m1_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vsoxseg8ei16_v)))
void vsoxseg8ei16(int64_t *, vuint16mf4_t, vint64m1_t, vint64m1_t, vint64m1_t, vint64m1_t, vint64m1_t, vint64m1_t, vint64m1_t, vint64m1_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vsoxseg8ei16_v_m)))
void vsoxseg8ei16(vbool64_t, int64_t *, vuint16mf4_t, vint64m1_t, vint64m1_t, vint64m1_t, vint64m1_t, vint64m1_t, vint64m1_t, vint64m1_t, vint64m1_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vsoxseg8ei16_v)))
void vsoxseg8ei16(uint64_t *, vuint16mf4_t, vuint64m1_t, vuint64m1_t, vuint64m1_t, vuint64m1_t, vuint64m1_t, vuint64m1_t, vuint64m1_t, vuint64m1_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vsoxseg8ei16_v_m)))
void vsoxseg8ei16(vbool64_t, uint64_t *, vuint16mf4_t, vuint64m1_t, vuint64m1_t, vuint64m1_t, vuint64m1_t, vuint64m1_t, vuint64m1_t, vuint64m1_t, vuint64m1_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vsoxseg2ei32_v)))
void vsoxseg2ei32(int64_t *, vuint32mf2_t, vint64m1_t, vint64m1_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vsoxseg2ei32_v_m)))
void vsoxseg2ei32(vbool64_t, int64_t *, vuint32mf2_t, vint64m1_t, vint64m1_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vsoxseg2ei32_v)))
void vsoxseg2ei32(int64_t *, vuint32m1_t, vint64m2_t, vint64m2_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vsoxseg2ei32_v_m)))
void vsoxseg2ei32(vbool32_t, int64_t *, vuint32m1_t, vint64m2_t, vint64m2_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vsoxseg2ei32_v)))
void vsoxseg2ei32(int64_t *, vuint32m2_t, vint64m4_t, vint64m4_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vsoxseg2ei32_v_m)))
void vsoxseg2ei32(vbool16_t, int64_t *, vuint32m2_t, vint64m4_t, vint64m4_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vsoxseg2ei32_v)))
void vsoxseg2ei32(uint64_t *, vuint32mf2_t, vuint64m1_t, vuint64m1_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vsoxseg2ei32_v_m)))
void vsoxseg2ei32(vbool64_t, uint64_t *, vuint32mf2_t, vuint64m1_t, vuint64m1_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vsoxseg2ei32_v)))
void vsoxseg2ei32(uint64_t *, vuint32m1_t, vuint64m2_t, vuint64m2_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vsoxseg2ei32_v_m)))
void vsoxseg2ei32(vbool32_t, uint64_t *, vuint32m1_t, vuint64m2_t, vuint64m2_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vsoxseg2ei32_v)))
void vsoxseg2ei32(uint64_t *, vuint32m2_t, vuint64m4_t, vuint64m4_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vsoxseg2ei32_v_m)))
void vsoxseg2ei32(vbool16_t, uint64_t *, vuint32m2_t, vuint64m4_t, vuint64m4_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vsoxseg3ei32_v)))
void vsoxseg3ei32(int64_t *, vuint32mf2_t, vint64m1_t, vint64m1_t, vint64m1_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vsoxseg3ei32_v_m)))
void vsoxseg3ei32(vbool64_t, int64_t *, vuint32mf2_t, vint64m1_t, vint64m1_t, vint64m1_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vsoxseg3ei32_v)))
void vsoxseg3ei32(int64_t *, vuint32m1_t, vint64m2_t, vint64m2_t, vint64m2_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vsoxseg3ei32_v_m)))
void vsoxseg3ei32(vbool32_t, int64_t *, vuint32m1_t, vint64m2_t, vint64m2_t, vint64m2_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vsoxseg3ei32_v)))
void vsoxseg3ei32(uint64_t *, vuint32mf2_t, vuint64m1_t, vuint64m1_t, vuint64m1_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vsoxseg3ei32_v_m)))
void vsoxseg3ei32(vbool64_t, uint64_t *, vuint32mf2_t, vuint64m1_t, vuint64m1_t, vuint64m1_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vsoxseg3ei32_v)))
void vsoxseg3ei32(uint64_t *, vuint32m1_t, vuint64m2_t, vuint64m2_t, vuint64m2_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vsoxseg3ei32_v_m)))
void vsoxseg3ei32(vbool32_t, uint64_t *, vuint32m1_t, vuint64m2_t, vuint64m2_t, vuint64m2_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vsoxseg4ei32_v)))
void vsoxseg4ei32(int64_t *, vuint32mf2_t, vint64m1_t, vint64m1_t, vint64m1_t, vint64m1_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vsoxseg4ei32_v_m)))
void vsoxseg4ei32(vbool64_t, int64_t *, vuint32mf2_t, vint64m1_t, vint64m1_t, vint64m1_t, vint64m1_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vsoxseg4ei32_v)))
void vsoxseg4ei32(int64_t *, vuint32m1_t, vint64m2_t, vint64m2_t, vint64m2_t, vint64m2_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vsoxseg4ei32_v_m)))
void vsoxseg4ei32(vbool32_t, int64_t *, vuint32m1_t, vint64m2_t, vint64m2_t, vint64m2_t, vint64m2_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vsoxseg4ei32_v)))
void vsoxseg4ei32(uint64_t *, vuint32mf2_t, vuint64m1_t, vuint64m1_t, vuint64m1_t, vuint64m1_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vsoxseg4ei32_v_m)))
void vsoxseg4ei32(vbool64_t, uint64_t *, vuint32mf2_t, vuint64m1_t, vuint64m1_t, vuint64m1_t, vuint64m1_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vsoxseg4ei32_v)))
void vsoxseg4ei32(uint64_t *, vuint32m1_t, vuint64m2_t, vuint64m2_t, vuint64m2_t, vuint64m2_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vsoxseg4ei32_v_m)))
void vsoxseg4ei32(vbool32_t, uint64_t *, vuint32m1_t, vuint64m2_t, vuint64m2_t, vuint64m2_t, vuint64m2_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vloxei8_v)))
vuint64m1_t vloxei8(const uint64_t *, vuint8mf8_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vloxei8_v_m)))
vuint64m1_t vloxei8(vbool64_t, vuint64m1_t, const uint64_t *, vuint8mf8_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vloxei8_v)))
vuint64m2_t vloxei8(const uint64_t *, vuint8mf4_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vloxei8_v_m)))
vuint64m2_t vloxei8(vbool32_t, vuint64m2_t, const uint64_t *, vuint8mf4_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vloxei8_v)))
vuint64m4_t vloxei8(const uint64_t *, vuint8mf2_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vloxei8_v_m)))
vuint64m4_t vloxei8(vbool16_t, vuint64m4_t, const uint64_t *, vuint8mf2_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vloxei8_v)))
vuint64m8_t vloxei8(const uint64_t *, vuint8m1_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vloxei8_v_m)))
vuint64m8_t vloxei8(vbool8_t, vuint64m8_t, const uint64_t *, vuint8m1_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vsoxseg5ei32_v)))
void vsoxseg5ei32(int64_t *, vuint32mf2_t, vint64m1_t, vint64m1_t, vint64m1_t, vint64m1_t, vint64m1_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vsoxseg5ei32_v_m)))
void vsoxseg5ei32(vbool64_t, int64_t *, vuint32mf2_t, vint64m1_t, vint64m1_t, vint64m1_t, vint64m1_t, vint64m1_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vsoxseg5ei32_v)))
void vsoxseg5ei32(uint64_t *, vuint32mf2_t, vuint64m1_t, vuint64m1_t, vuint64m1_t, vuint64m1_t, vuint64m1_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vsoxseg5ei32_v_m)))
void vsoxseg5ei32(vbool64_t, uint64_t *, vuint32mf2_t, vuint64m1_t, vuint64m1_t, vuint64m1_t, vuint64m1_t, vuint64m1_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vsoxseg6ei32_v)))
void vsoxseg6ei32(int64_t *, vuint32mf2_t, vint64m1_t, vint64m1_t, vint64m1_t, vint64m1_t, vint64m1_t, vint64m1_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vsoxseg6ei32_v_m)))
void vsoxseg6ei32(vbool64_t, int64_t *, vuint32mf2_t, vint64m1_t, vint64m1_t, vint64m1_t, vint64m1_t, vint64m1_t, vint64m1_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vsoxseg6ei32_v)))
void vsoxseg6ei32(uint64_t *, vuint32mf2_t, vuint64m1_t, vuint64m1_t, vuint64m1_t, vuint64m1_t, vuint64m1_t, vuint64m1_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vsoxseg6ei32_v_m)))
void vsoxseg6ei32(vbool64_t, uint64_t *, vuint32mf2_t, vuint64m1_t, vuint64m1_t, vuint64m1_t, vuint64m1_t, vuint64m1_t, vuint64m1_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vsoxseg7ei32_v)))
void vsoxseg7ei32(int64_t *, vuint32mf2_t, vint64m1_t, vint64m1_t, vint64m1_t, vint64m1_t, vint64m1_t, vint64m1_t, vint64m1_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vsoxseg7ei32_v_m)))
void vsoxseg7ei32(vbool64_t, int64_t *, vuint32mf2_t, vint64m1_t, vint64m1_t, vint64m1_t, vint64m1_t, vint64m1_t, vint64m1_t, vint64m1_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vsoxseg7ei32_v)))
void vsoxseg7ei32(uint64_t *, vuint32mf2_t, vuint64m1_t, vuint64m1_t, vuint64m1_t, vuint64m1_t, vuint64m1_t, vuint64m1_t, vuint64m1_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vsoxseg7ei32_v_m)))
void vsoxseg7ei32(vbool64_t, uint64_t *, vuint32mf2_t, vuint64m1_t, vuint64m1_t, vuint64m1_t, vuint64m1_t, vuint64m1_t, vuint64m1_t, vuint64m1_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vsoxseg8ei32_v)))
void vsoxseg8ei32(int64_t *, vuint32mf2_t, vint64m1_t, vint64m1_t, vint64m1_t, vint64m1_t, vint64m1_t, vint64m1_t, vint64m1_t, vint64m1_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vsoxseg8ei32_v_m)))
void vsoxseg8ei32(vbool64_t, int64_t *, vuint32mf2_t, vint64m1_t, vint64m1_t, vint64m1_t, vint64m1_t, vint64m1_t, vint64m1_t, vint64m1_t, vint64m1_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vsoxseg8ei32_v)))
void vsoxseg8ei32(uint64_t *, vuint32mf2_t, vuint64m1_t, vuint64m1_t, vuint64m1_t, vuint64m1_t, vuint64m1_t, vuint64m1_t, vuint64m1_t, vuint64m1_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vsoxseg8ei32_v_m)))
void vsoxseg8ei32(vbool64_t, uint64_t *, vuint32mf2_t, vuint64m1_t, vuint64m1_t, vuint64m1_t, vuint64m1_t, vuint64m1_t, vuint64m1_t, vuint64m1_t, vuint64m1_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vsoxseg2ei64_v)))
void vsoxseg2ei64(int64_t *, vuint64m1_t, vint64m1_t, vint64m1_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vsoxseg2ei64_v_m)))
void vsoxseg2ei64(vbool64_t, int64_t *, vuint64m1_t, vint64m1_t, vint64m1_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vsoxseg2ei64_v)))
void vsoxseg2ei64(int64_t *, vuint64m2_t, vint64m2_t, vint64m2_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vsoxseg2ei64_v_m)))
void vsoxseg2ei64(vbool32_t, int64_t *, vuint64m2_t, vint64m2_t, vint64m2_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vsoxseg2ei64_v)))
void vsoxseg2ei64(int64_t *, vuint64m4_t, vint64m4_t, vint64m4_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vsoxseg2ei64_v_m)))
void vsoxseg2ei64(vbool16_t, int64_t *, vuint64m4_t, vint64m4_t, vint64m4_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vsoxseg2ei64_v)))
void vsoxseg2ei64(uint64_t *, vuint64m1_t, vuint64m1_t, vuint64m1_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vsoxseg2ei64_v_m)))
void vsoxseg2ei64(vbool64_t, uint64_t *, vuint64m1_t, vuint64m1_t, vuint64m1_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vsoxseg2ei64_v)))
void vsoxseg2ei64(uint64_t *, vuint64m2_t, vuint64m2_t, vuint64m2_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vsoxseg2ei64_v_m)))
void vsoxseg2ei64(vbool32_t, uint64_t *, vuint64m2_t, vuint64m2_t, vuint64m2_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vsoxseg2ei64_v)))
void vsoxseg2ei64(uint64_t *, vuint64m4_t, vuint64m4_t, vuint64m4_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vsoxseg2ei64_v_m)))
void vsoxseg2ei64(vbool16_t, uint64_t *, vuint64m4_t, vuint64m4_t, vuint64m4_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vloxei16_v)))
vint64m1_t vloxei16(const int64_t *, vuint16mf4_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vloxei16_v_m)))
vint64m1_t vloxei16(vbool64_t, vint64m1_t, const int64_t *, vuint16mf4_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vloxei16_v)))
vint64m2_t vloxei16(const int64_t *, vuint16mf2_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vloxei16_v_m)))
vint64m2_t vloxei16(vbool32_t, vint64m2_t, const int64_t *, vuint16mf2_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vloxei16_v)))
vint64m4_t vloxei16(const int64_t *, vuint16m1_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vloxei16_v_m)))
vint64m4_t vloxei16(vbool16_t, vint64m4_t, const int64_t *, vuint16m1_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vloxei16_v)))
vint64m8_t vloxei16(const int64_t *, vuint16m2_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vloxei16_v_m)))
vint64m8_t vloxei16(vbool8_t, vint64m8_t, const int64_t *, vuint16m2_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vsoxseg3ei64_v)))
void vsoxseg3ei64(int64_t *, vuint64m1_t, vint64m1_t, vint64m1_t, vint64m1_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vsoxseg3ei64_v_m)))
void vsoxseg3ei64(vbool64_t, int64_t *, vuint64m1_t, vint64m1_t, vint64m1_t, vint64m1_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vsoxseg3ei64_v)))
void vsoxseg3ei64(int64_t *, vuint64m2_t, vint64m2_t, vint64m2_t, vint64m2_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vsoxseg3ei64_v_m)))
void vsoxseg3ei64(vbool32_t, int64_t *, vuint64m2_t, vint64m2_t, vint64m2_t, vint64m2_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vsoxseg3ei64_v)))
void vsoxseg3ei64(uint64_t *, vuint64m1_t, vuint64m1_t, vuint64m1_t, vuint64m1_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vsoxseg3ei64_v_m)))
void vsoxseg3ei64(vbool64_t, uint64_t *, vuint64m1_t, vuint64m1_t, vuint64m1_t, vuint64m1_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vsoxseg3ei64_v)))
void vsoxseg3ei64(uint64_t *, vuint64m2_t, vuint64m2_t, vuint64m2_t, vuint64m2_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vsoxseg3ei64_v_m)))
void vsoxseg3ei64(vbool32_t, uint64_t *, vuint64m2_t, vuint64m2_t, vuint64m2_t, vuint64m2_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vsoxseg4ei64_v)))
void vsoxseg4ei64(int64_t *, vuint64m1_t, vint64m1_t, vint64m1_t, vint64m1_t, vint64m1_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vsoxseg4ei64_v_m)))
void vsoxseg4ei64(vbool64_t, int64_t *, vuint64m1_t, vint64m1_t, vint64m1_t, vint64m1_t, vint64m1_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vsoxseg4ei64_v)))
void vsoxseg4ei64(int64_t *, vuint64m2_t, vint64m2_t, vint64m2_t, vint64m2_t, vint64m2_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vsoxseg4ei64_v_m)))
void vsoxseg4ei64(vbool32_t, int64_t *, vuint64m2_t, vint64m2_t, vint64m2_t, vint64m2_t, vint64m2_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vsoxseg4ei64_v)))
void vsoxseg4ei64(uint64_t *, vuint64m1_t, vuint64m1_t, vuint64m1_t, vuint64m1_t, vuint64m1_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vsoxseg4ei64_v_m)))
void vsoxseg4ei64(vbool64_t, uint64_t *, vuint64m1_t, vuint64m1_t, vuint64m1_t, vuint64m1_t, vuint64m1_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vsoxseg4ei64_v)))
void vsoxseg4ei64(uint64_t *, vuint64m2_t, vuint64m2_t, vuint64m2_t, vuint64m2_t, vuint64m2_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vsoxseg4ei64_v_m)))
void vsoxseg4ei64(vbool32_t, uint64_t *, vuint64m2_t, vuint64m2_t, vuint64m2_t, vuint64m2_t, vuint64m2_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vsoxseg5ei64_v)))
void vsoxseg5ei64(int64_t *, vuint64m1_t, vint64m1_t, vint64m1_t, vint64m1_t, vint64m1_t, vint64m1_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vsoxseg5ei64_v_m)))
void vsoxseg5ei64(vbool64_t, int64_t *, vuint64m1_t, vint64m1_t, vint64m1_t, vint64m1_t, vint64m1_t, vint64m1_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vsoxseg5ei64_v)))
void vsoxseg5ei64(uint64_t *, vuint64m1_t, vuint64m1_t, vuint64m1_t, vuint64m1_t, vuint64m1_t, vuint64m1_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vsoxseg5ei64_v_m)))
void vsoxseg5ei64(vbool64_t, uint64_t *, vuint64m1_t, vuint64m1_t, vuint64m1_t, vuint64m1_t, vuint64m1_t, vuint64m1_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vsoxseg6ei64_v)))
void vsoxseg6ei64(int64_t *, vuint64m1_t, vint64m1_t, vint64m1_t, vint64m1_t, vint64m1_t, vint64m1_t, vint64m1_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vsoxseg6ei64_v_m)))
void vsoxseg6ei64(vbool64_t, int64_t *, vuint64m1_t, vint64m1_t, vint64m1_t, vint64m1_t, vint64m1_t, vint64m1_t, vint64m1_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vsoxseg6ei64_v)))
void vsoxseg6ei64(uint64_t *, vuint64m1_t, vuint64m1_t, vuint64m1_t, vuint64m1_t, vuint64m1_t, vuint64m1_t, vuint64m1_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vsoxseg6ei64_v_m)))
void vsoxseg6ei64(vbool64_t, uint64_t *, vuint64m1_t, vuint64m1_t, vuint64m1_t, vuint64m1_t, vuint64m1_t, vuint64m1_t, vuint64m1_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vsoxseg7ei64_v)))
void vsoxseg7ei64(int64_t *, vuint64m1_t, vint64m1_t, vint64m1_t, vint64m1_t, vint64m1_t, vint64m1_t, vint64m1_t, vint64m1_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vsoxseg7ei64_v_m)))
void vsoxseg7ei64(vbool64_t, int64_t *, vuint64m1_t, vint64m1_t, vint64m1_t, vint64m1_t, vint64m1_t, vint64m1_t, vint64m1_t, vint64m1_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vsoxseg7ei64_v)))
void vsoxseg7ei64(uint64_t *, vuint64m1_t, vuint64m1_t, vuint64m1_t, vuint64m1_t, vuint64m1_t, vuint64m1_t, vuint64m1_t, vuint64m1_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vsoxseg7ei64_v_m)))
void vsoxseg7ei64(vbool64_t, uint64_t *, vuint64m1_t, vuint64m1_t, vuint64m1_t, vuint64m1_t, vuint64m1_t, vuint64m1_t, vuint64m1_t, vuint64m1_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vloxei16_v)))
vuint64m1_t vloxei16(const uint64_t *, vuint16mf4_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vloxei16_v_m)))
vuint64m1_t vloxei16(vbool64_t, vuint64m1_t, const uint64_t *, vuint16mf4_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vloxei16_v)))
vuint64m2_t vloxei16(const uint64_t *, vuint16mf2_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vloxei16_v_m)))
vuint64m2_t vloxei16(vbool32_t, vuint64m2_t, const uint64_t *, vuint16mf2_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vloxei16_v)))
vuint64m4_t vloxei16(const uint64_t *, vuint16m1_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vloxei16_v_m)))
vuint64m4_t vloxei16(vbool16_t, vuint64m4_t, const uint64_t *, vuint16m1_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vloxei16_v)))
vuint64m8_t vloxei16(const uint64_t *, vuint16m2_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vloxei16_v_m)))
vuint64m8_t vloxei16(vbool8_t, vuint64m8_t, const uint64_t *, vuint16m2_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vsoxseg8ei64_v)))
void vsoxseg8ei64(int64_t *, vuint64m1_t, vint64m1_t, vint64m1_t, vint64m1_t, vint64m1_t, vint64m1_t, vint64m1_t, vint64m1_t, vint64m1_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vsoxseg8ei64_v_m)))
void vsoxseg8ei64(vbool64_t, int64_t *, vuint64m1_t, vint64m1_t, vint64m1_t, vint64m1_t, vint64m1_t, vint64m1_t, vint64m1_t, vint64m1_t, vint64m1_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vsoxseg8ei64_v)))
void vsoxseg8ei64(uint64_t *, vuint64m1_t, vuint64m1_t, vuint64m1_t, vuint64m1_t, vuint64m1_t, vuint64m1_t, vuint64m1_t, vuint64m1_t, vuint64m1_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vsoxseg8ei64_v_m)))
void vsoxseg8ei64(vbool64_t, uint64_t *, vuint64m1_t, vuint64m1_t, vuint64m1_t, vuint64m1_t, vuint64m1_t, vuint64m1_t, vuint64m1_t, vuint64m1_t, vuint64m1_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vloxei32_v)))
vint64m1_t vloxei32(const int64_t *, vuint32mf2_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vloxei32_v_m)))
vint64m1_t vloxei32(vbool64_t, vint64m1_t, const int64_t *, vuint32mf2_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vloxei32_v)))
vint64m2_t vloxei32(const int64_t *, vuint32m1_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vloxei32_v_m)))
vint64m2_t vloxei32(vbool32_t, vint64m2_t, const int64_t *, vuint32m1_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vloxei32_v)))
vint64m4_t vloxei32(const int64_t *, vuint32m2_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vloxei32_v_m)))
vint64m4_t vloxei32(vbool16_t, vint64m4_t, const int64_t *, vuint32m2_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vloxei32_v)))
vint64m8_t vloxei32(const int64_t *, vuint32m4_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vloxei32_v_m)))
vint64m8_t vloxei32(vbool8_t, vint64m8_t, const int64_t *, vuint32m4_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vloxei32_v)))
vuint64m1_t vloxei32(const uint64_t *, vuint32mf2_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vloxei32_v_m)))
vuint64m1_t vloxei32(vbool64_t, vuint64m1_t, const uint64_t *, vuint32mf2_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vloxei32_v)))
vuint64m2_t vloxei32(const uint64_t *, vuint32m1_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vloxei32_v_m)))
vuint64m2_t vloxei32(vbool32_t, vuint64m2_t, const uint64_t *, vuint32m1_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vloxei32_v)))
vuint64m4_t vloxei32(const uint64_t *, vuint32m2_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vloxei32_v_m)))
vuint64m4_t vloxei32(vbool16_t, vuint64m4_t, const uint64_t *, vuint32m2_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vloxei32_v)))
vuint64m8_t vloxei32(const uint64_t *, vuint32m4_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vloxei32_v_m)))
vuint64m8_t vloxei32(vbool8_t, vuint64m8_t, const uint64_t *, vuint32m4_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vadd_vx)))
vint64m1_t vadd(vint64m1_t, int64_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vadd_vx_m)))
vint64m1_t vadd(vbool64_t, vint64m1_t, vint64m1_t, int64_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vadd_vx)))
vint64m2_t vadd(vint64m2_t, int64_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vadd_vx_m)))
vint64m2_t vadd(vbool32_t, vint64m2_t, vint64m2_t, int64_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vadd_vx)))
vint64m4_t vadd(vint64m4_t, int64_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vadd_vx_m)))
vint64m4_t vadd(vbool16_t, vint64m4_t, vint64m4_t, int64_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vadd_vx)))
vint64m8_t vadd(vint64m8_t, int64_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vadd_vx_m)))
vint64m8_t vadd(vbool8_t, vint64m8_t, vint64m8_t, int64_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vadd_vv)))
vuint64m1_t vadd(vuint64m1_t, vuint64m1_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vadd_vv_m)))
vuint64m1_t vadd(vbool64_t, vuint64m1_t, vuint64m1_t, vuint64m1_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vadd_vv)))
vuint64m2_t vadd(vuint64m2_t, vuint64m2_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vadd_vv_m)))
vuint64m2_t vadd(vbool32_t, vuint64m2_t, vuint64m2_t, vuint64m2_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vadd_vv)))
vuint64m4_t vadd(vuint64m4_t, vuint64m4_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vadd_vv_m)))
vuint64m4_t vadd(vbool16_t, vuint64m4_t, vuint64m4_t, vuint64m4_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vadd_vv)))
vuint64m8_t vadd(vuint64m8_t, vuint64m8_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vadd_vv_m)))
vuint64m8_t vadd(vbool8_t, vuint64m8_t, vuint64m8_t, vuint64m8_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vadd_vx)))
vuint64m1_t vadd(vuint64m1_t, uint64_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vadd_vx_m)))
vuint64m1_t vadd(vbool64_t, vuint64m1_t, vuint64m1_t, uint64_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vadd_vx)))
vuint64m2_t vadd(vuint64m2_t, uint64_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vadd_vx_m)))
vuint64m2_t vadd(vbool32_t, vuint64m2_t, vuint64m2_t, uint64_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vadd_vx)))
vuint64m4_t vadd(vuint64m4_t, uint64_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vadd_vx_m)))
vuint64m4_t vadd(vbool16_t, vuint64m4_t, vuint64m4_t, uint64_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vadd_vx)))
vuint64m8_t vadd(vuint64m8_t, uint64_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vadd_vx_m)))
vuint64m8_t vadd(vbool8_t, vuint64m8_t, vuint64m8_t, uint64_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vsub_vv)))
vint64m1_t vsub(vint64m1_t, vint64m1_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vsub_vv_m)))
vint64m1_t vsub(vbool64_t, vint64m1_t, vint64m1_t, vint64m1_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vsub_vv)))
vint64m2_t vsub(vint64m2_t, vint64m2_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vsub_vv_m)))
vint64m2_t vsub(vbool32_t, vint64m2_t, vint64m2_t, vint64m2_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vsub_vv)))
vint64m4_t vsub(vint64m4_t, vint64m4_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vsub_vv_m)))
vint64m4_t vsub(vbool16_t, vint64m4_t, vint64m4_t, vint64m4_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vsub_vv)))
vint64m8_t vsub(vint64m8_t, vint64m8_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vsub_vv_m)))
vint64m8_t vsub(vbool8_t, vint64m8_t, vint64m8_t, vint64m8_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vsub_vx)))
vint64m1_t vsub(vint64m1_t, int64_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vsub_vx_m)))
vint64m1_t vsub(vbool64_t, vint64m1_t, vint64m1_t, int64_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vsub_vx)))
vint64m2_t vsub(vint64m2_t, int64_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vsub_vx_m)))
vint64m2_t vsub(vbool32_t, vint64m2_t, vint64m2_t, int64_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vsub_vx)))
vint64m4_t vsub(vint64m4_t, int64_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vsub_vx_m)))
vint64m4_t vsub(vbool16_t, vint64m4_t, vint64m4_t, int64_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vsub_vx)))
vint64m8_t vsub(vint64m8_t, int64_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vsub_vx_m)))
vint64m8_t vsub(vbool8_t, vint64m8_t, vint64m8_t, int64_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vsub_vv)))
vuint64m1_t vsub(vuint64m1_t, vuint64m1_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vsub_vv_m)))
vuint64m1_t vsub(vbool64_t, vuint64m1_t, vuint64m1_t, vuint64m1_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vsub_vv)))
vuint64m2_t vsub(vuint64m2_t, vuint64m2_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vsub_vv_m)))
vuint64m2_t vsub(vbool32_t, vuint64m2_t, vuint64m2_t, vuint64m2_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vsub_vv)))
vuint64m4_t vsub(vuint64m4_t, vuint64m4_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vsub_vv_m)))
vuint64m4_t vsub(vbool16_t, vuint64m4_t, vuint64m4_t, vuint64m4_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vsub_vv)))
vuint64m8_t vsub(vuint64m8_t, vuint64m8_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vsub_vv_m)))
vuint64m8_t vsub(vbool8_t, vuint64m8_t, vuint64m8_t, vuint64m8_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vsub_vx)))
vuint64m1_t vsub(vuint64m1_t, uint64_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vsub_vx_m)))
vuint64m1_t vsub(vbool64_t, vuint64m1_t, vuint64m1_t, uint64_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vsub_vx)))
vuint64m2_t vsub(vuint64m2_t, uint64_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vsub_vx_m)))
vuint64m2_t vsub(vbool32_t, vuint64m2_t, vuint64m2_t, uint64_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vsub_vx)))
vuint64m4_t vsub(vuint64m4_t, uint64_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vsub_vx_m)))
vuint64m4_t vsub(vbool16_t, vuint64m4_t, vuint64m4_t, uint64_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vsub_vx)))
vuint64m8_t vsub(vuint64m8_t, uint64_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vsub_vx_m)))
vuint64m8_t vsub(vbool8_t, vuint64m8_t, vuint64m8_t, uint64_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vrsub_vx)))
vint64m1_t vrsub(vint64m1_t, int64_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vrsub_vx_m)))
vint64m1_t vrsub(vbool64_t, vint64m1_t, vint64m1_t, int64_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vrsub_vx)))
vint64m2_t vrsub(vint64m2_t, int64_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vrsub_vx_m)))
vint64m2_t vrsub(vbool32_t, vint64m2_t, vint64m2_t, int64_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vrsub_vx)))
vint64m4_t vrsub(vint64m4_t, int64_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vrsub_vx_m)))
vint64m4_t vrsub(vbool16_t, vint64m4_t, vint64m4_t, int64_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vrsub_vx)))
vint64m8_t vrsub(vint64m8_t, int64_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vrsub_vx_m)))
vint64m8_t vrsub(vbool8_t, vint64m8_t, vint64m8_t, int64_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vrsub_vx)))
vuint64m1_t vrsub(vuint64m1_t, uint64_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vrsub_vx_m)))
vuint64m1_t vrsub(vbool64_t, vuint64m1_t, vuint64m1_t, uint64_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vrsub_vx)))
vuint64m2_t vrsub(vuint64m2_t, uint64_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vrsub_vx_m)))
vuint64m2_t vrsub(vbool32_t, vuint64m2_t, vuint64m2_t, uint64_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vrsub_vx)))
vuint64m4_t vrsub(vuint64m4_t, uint64_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vrsub_vx_m)))
vuint64m4_t vrsub(vbool16_t, vuint64m4_t, vuint64m4_t, uint64_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vrsub_vx)))
vuint64m8_t vrsub(vuint64m8_t, uint64_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vrsub_vx_m)))
vuint64m8_t vrsub(vbool8_t, vuint64m8_t, vuint64m8_t, uint64_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vwaddu_vx)))
vuint64m1_t vwaddu_vx(vuint32mf2_t, uint32_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vwaddu_vx_m)))
vuint64m1_t vwaddu_vx(vbool64_t, vuint64m1_t, vuint32mf2_t, uint32_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vwaddu_vx)))
vuint64m2_t vwaddu_vx(vuint32m1_t, uint32_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vwaddu_vx_m)))
vuint64m2_t vwaddu_vx(vbool32_t, vuint64m2_t, vuint32m1_t, uint32_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vwaddu_vx)))
vuint64m4_t vwaddu_vx(vuint32m2_t, uint32_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vwaddu_vx_m)))
vuint64m4_t vwaddu_vx(vbool16_t, vuint64m4_t, vuint32m2_t, uint32_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vwaddu_vx)))
vuint64m8_t vwaddu_vx(vuint32m4_t, uint32_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vwaddu_vx_m)))
vuint64m8_t vwaddu_vx(vbool8_t, vuint64m8_t, vuint32m4_t, uint32_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vwsubu_vv)))
vuint64m1_t vwsubu_vv(vuint32mf2_t, vuint32mf2_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vwsubu_vv_m)))
vuint64m1_t vwsubu_vv(vbool64_t, vuint64m1_t, vuint32mf2_t, vuint32mf2_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vwsubu_vv)))
vuint64m2_t vwsubu_vv(vuint32m1_t, vuint32m1_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vwsubu_vv_m)))
vuint64m2_t vwsubu_vv(vbool32_t, vuint64m2_t, vuint32m1_t, vuint32m1_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vwsubu_vv)))
vuint64m4_t vwsubu_vv(vuint32m2_t, vuint32m2_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vwsubu_vv_m)))
vuint64m4_t vwsubu_vv(vbool16_t, vuint64m4_t, vuint32m2_t, vuint32m2_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vwsubu_vv)))
vuint64m8_t vwsubu_vv(vuint32m4_t, vuint32m4_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vwsubu_vv_m)))
vuint64m8_t vwsubu_vv(vbool8_t, vuint64m8_t, vuint32m4_t, vuint32m4_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vwsubu_vx)))
vuint64m1_t vwsubu_vx(vuint32mf2_t, uint32_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vwsubu_vx_m)))
vuint64m1_t vwsubu_vx(vbool64_t, vuint64m1_t, vuint32mf2_t, uint32_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vwsubu_vx)))
vuint64m2_t vwsubu_vx(vuint32m1_t, uint32_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vwsubu_vx_m)))
vuint64m2_t vwsubu_vx(vbool32_t, vuint64m2_t, vuint32m1_t, uint32_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vwsubu_vx)))
vuint64m4_t vwsubu_vx(vuint32m2_t, uint32_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vwsubu_vx_m)))
vuint64m4_t vwsubu_vx(vbool16_t, vuint64m4_t, vuint32m2_t, uint32_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vwsubu_vx)))
vuint64m8_t vwsubu_vx(vuint32m4_t, uint32_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vwsubu_vx_m)))
vuint64m8_t vwsubu_vx(vbool8_t, vuint64m8_t, vuint32m4_t, uint32_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vwadd_vv)))
vint64m1_t vwadd_vv(vint32mf2_t, vint32mf2_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vwadd_vv_m)))
vint64m1_t vwadd_vv(vbool64_t, vint64m1_t, vint32mf2_t, vint32mf2_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vwadd_vv)))
vint64m2_t vwadd_vv(vint32m1_t, vint32m1_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vwadd_vv_m)))
vint64m2_t vwadd_vv(vbool32_t, vint64m2_t, vint32m1_t, vint32m1_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vwadd_vv)))
vint64m4_t vwadd_vv(vint32m2_t, vint32m2_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vwadd_vv_m)))
vint64m4_t vwadd_vv(vbool16_t, vint64m4_t, vint32m2_t, vint32m2_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vwadd_vv)))
vint64m8_t vwadd_vv(vint32m4_t, vint32m4_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vwadd_vv_m)))
vint64m8_t vwadd_vv(vbool8_t, vint64m8_t, vint32m4_t, vint32m4_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vwadd_vx)))
vint64m1_t vwadd_vx(vint32mf2_t, int32_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vwadd_vx_m)))
vint64m1_t vwadd_vx(vbool64_t, vint64m1_t, vint32mf2_t, int32_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vwadd_vx)))
vint64m2_t vwadd_vx(vint32m1_t, int32_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vwadd_vx_m)))
vint64m2_t vwadd_vx(vbool32_t, vint64m2_t, vint32m1_t, int32_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vwadd_vx)))
vint64m4_t vwadd_vx(vint32m2_t, int32_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vwadd_vx_m)))
vint64m4_t vwadd_vx(vbool16_t, vint64m4_t, vint32m2_t, int32_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vwadd_vx)))
vint64m8_t vwadd_vx(vint32m4_t, int32_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vwadd_vx_m)))
vint64m8_t vwadd_vx(vbool8_t, vint64m8_t, vint32m4_t, int32_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vwsub_vv)))
vint64m1_t vwsub_vv(vint32mf2_t, vint32mf2_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vwsub_vv_m)))
vint64m1_t vwsub_vv(vbool64_t, vint64m1_t, vint32mf2_t, vint32mf2_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vwsub_vv)))
vint64m2_t vwsub_vv(vint32m1_t, vint32m1_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vwsub_vv_m)))
vint64m2_t vwsub_vv(vbool32_t, vint64m2_t, vint32m1_t, vint32m1_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vwsub_vv)))
vint64m4_t vwsub_vv(vint32m2_t, vint32m2_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vwsub_vv_m)))
vint64m4_t vwsub_vv(vbool16_t, vint64m4_t, vint32m2_t, vint32m2_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vwsub_vv)))
vint64m8_t vwsub_vv(vint32m4_t, vint32m4_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vwsub_vv_m)))
vint64m8_t vwsub_vv(vbool8_t, vint64m8_t, vint32m4_t, vint32m4_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vwsub_vx)))
vint64m1_t vwsub_vx(vint32mf2_t, int32_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vwsub_vx_m)))
vint64m1_t vwsub_vx(vbool64_t, vint64m1_t, vint32mf2_t, int32_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vwsub_vx)))
vint64m2_t vwsub_vx(vint32m1_t, int32_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vwsub_vx_m)))
vint64m2_t vwsub_vx(vbool32_t, vint64m2_t, vint32m1_t, int32_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vwsub_vx)))
vint64m4_t vwsub_vx(vint32m2_t, int32_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vwsub_vx_m)))
vint64m4_t vwsub_vx(vbool16_t, vint64m4_t, vint32m2_t, int32_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vwsub_vx)))
vint64m8_t vwsub_vx(vint32m4_t, int32_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vwsub_vx_m)))
vint64m8_t vwsub_vx(vbool8_t, vint64m8_t, vint32m4_t, int32_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vwaddu_wx)))
vuint64m1_t vwaddu_wx(vuint64m1_t, uint32_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vwaddu_wx_m)))
vuint64m1_t vwaddu_wx(vbool64_t, vuint64m1_t, vuint64m1_t, uint32_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vwaddu_wx)))
vuint64m2_t vwaddu_wx(vuint64m2_t, uint32_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vwaddu_wx_m)))
vuint64m2_t vwaddu_wx(vbool32_t, vuint64m2_t, vuint64m2_t, uint32_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vwaddu_wx)))
vuint64m4_t vwaddu_wx(vuint64m4_t, uint32_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vwaddu_wx_m)))
vuint64m4_t vwaddu_wx(vbool16_t, vuint64m4_t, vuint64m4_t, uint32_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vwaddu_wx)))
vuint64m8_t vwaddu_wx(vuint64m8_t, uint32_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vwaddu_wx_m)))
vuint64m8_t vwaddu_wx(vbool8_t, vuint64m8_t, vuint64m8_t, uint32_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vwsubu_wv)))
vuint64m1_t vwsubu_wv(vuint64m1_t, vuint32mf2_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vwsubu_wv_m)))
vuint64m1_t vwsubu_wv(vbool64_t, vuint64m1_t, vuint64m1_t, vuint32mf2_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vwsubu_wv)))
vuint64m2_t vwsubu_wv(vuint64m2_t, vuint32m1_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vwsubu_wv_m)))
vuint64m2_t vwsubu_wv(vbool32_t, vuint64m2_t, vuint64m2_t, vuint32m1_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vwsubu_wv)))
vuint64m4_t vwsubu_wv(vuint64m4_t, vuint32m2_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vwsubu_wv_m)))
vuint64m4_t vwsubu_wv(vbool16_t, vuint64m4_t, vuint64m4_t, vuint32m2_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vwsubu_wv)))
vuint64m8_t vwsubu_wv(vuint64m8_t, vuint32m4_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vwsubu_wv_m)))
vuint64m8_t vwsubu_wv(vbool8_t, vuint64m8_t, vuint64m8_t, vuint32m4_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vwsubu_wx)))
vuint64m1_t vwsubu_wx(vuint64m1_t, uint32_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vwsubu_wx_m)))
vuint64m1_t vwsubu_wx(vbool64_t, vuint64m1_t, vuint64m1_t, uint32_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vwsubu_wx)))
vuint64m2_t vwsubu_wx(vuint64m2_t, uint32_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vwsubu_wx_m)))
vuint64m2_t vwsubu_wx(vbool32_t, vuint64m2_t, vuint64m2_t, uint32_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vwsubu_wx)))
vuint64m4_t vwsubu_wx(vuint64m4_t, uint32_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vwsubu_wx_m)))
vuint64m4_t vwsubu_wx(vbool16_t, vuint64m4_t, vuint64m4_t, uint32_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vwsubu_wx)))
vuint64m8_t vwsubu_wx(vuint64m8_t, uint32_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vwsubu_wx_m)))
vuint64m8_t vwsubu_wx(vbool8_t, vuint64m8_t, vuint64m8_t, uint32_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vwadd_wv)))
vint64m1_t vwadd_wv(vint64m1_t, vint32mf2_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vwadd_wv_m)))
vint64m1_t vwadd_wv(vbool64_t, vint64m1_t, vint64m1_t, vint32mf2_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vwadd_wv)))
vint64m2_t vwadd_wv(vint64m2_t, vint32m1_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vwadd_wv_m)))
vint64m2_t vwadd_wv(vbool32_t, vint64m2_t, vint64m2_t, vint32m1_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vwadd_wv)))
vint64m4_t vwadd_wv(vint64m4_t, vint32m2_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vwadd_wv_m)))
vint64m4_t vwadd_wv(vbool16_t, vint64m4_t, vint64m4_t, vint32m2_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vwadd_wv)))
vint64m8_t vwadd_wv(vint64m8_t, vint32m4_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vwadd_wv_m)))
vint64m8_t vwadd_wv(vbool8_t, vint64m8_t, vint64m8_t, vint32m4_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vwadd_wx)))
vint64m1_t vwadd_wx(vint64m1_t, int32_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vwadd_wx_m)))
vint64m1_t vwadd_wx(vbool64_t, vint64m1_t, vint64m1_t, int32_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vwadd_wx)))
vint64m2_t vwadd_wx(vint64m2_t, int32_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vwadd_wx_m)))
vint64m2_t vwadd_wx(vbool32_t, vint64m2_t, vint64m2_t, int32_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vwadd_wx)))
vint64m4_t vwadd_wx(vint64m4_t, int32_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vwadd_wx_m)))
vint64m4_t vwadd_wx(vbool16_t, vint64m4_t, vint64m4_t, int32_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vwadd_wx)))
vint64m8_t vwadd_wx(vint64m8_t, int32_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vwadd_wx_m)))
vint64m8_t vwadd_wx(vbool8_t, vint64m8_t, vint64m8_t, int32_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vwsub_wv)))
vint64m1_t vwsub_wv(vint64m1_t, vint32mf2_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vwsub_wv_m)))
vint64m1_t vwsub_wv(vbool64_t, vint64m1_t, vint64m1_t, vint32mf2_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vwsub_wv)))
vint64m2_t vwsub_wv(vint64m2_t, vint32m1_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vwsub_wv_m)))
vint64m2_t vwsub_wv(vbool32_t, vint64m2_t, vint64m2_t, vint32m1_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vwsub_wv)))
vint64m4_t vwsub_wv(vint64m4_t, vint32m2_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vwsub_wv_m)))
vint64m4_t vwsub_wv(vbool16_t, vint64m4_t, vint64m4_t, vint32m2_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vwsub_wv)))
vint64m8_t vwsub_wv(vint64m8_t, vint32m4_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vwsub_wv_m)))
vint64m8_t vwsub_wv(vbool8_t, vint64m8_t, vint64m8_t, vint32m4_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vwsub_wx)))
vint64m1_t vwsub_wx(vint64m1_t, int32_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vwsub_wx_m)))
vint64m1_t vwsub_wx(vbool64_t, vint64m1_t, vint64m1_t, int32_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vwsub_wx)))
vint64m2_t vwsub_wx(vint64m2_t, int32_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vwsub_wx_m)))
vint64m2_t vwsub_wx(vbool32_t, vint64m2_t, vint64m2_t, int32_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vwsub_wx)))
vint64m4_t vwsub_wx(vint64m4_t, int32_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vwsub_wx_m)))
vint64m4_t vwsub_wx(vbool16_t, vint64m4_t, vint64m4_t, int32_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vwsub_wx)))
vint64m8_t vwsub_wx(vint64m8_t, int32_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vwsub_wx_m)))
vint64m8_t vwsub_wx(vbool8_t, vint64m8_t, vint64m8_t, int32_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vwcvt_x_x_v)))
vint64m2_t vwcvt_x(vint32m1_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vwcvt_x_x_v_m)))
vint64m2_t vwcvt_x(vbool32_t, vint64m2_t, vint32m1_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vwcvt_x_x_v)))
vint64m4_t vwcvt_x(vint32m2_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vwcvt_x_x_v_m)))
vint64m4_t vwcvt_x(vbool16_t, vint64m4_t, vint32m2_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vwcvt_x_x_v)))
vint64m8_t vwcvt_x(vint32m4_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vwcvt_x_x_v_m)))
vint64m8_t vwcvt_x(vbool8_t, vint64m8_t, vint32m4_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vwcvt_x_x_v)))
vint64m1_t vwcvt_x(vint32mf2_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vwcvt_x_x_v_m)))
vint64m1_t vwcvt_x(vbool64_t, vint64m1_t, vint32mf2_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vadc_vvm)))
vint64m1_t vadc(vint64m1_t, vint64m1_t, vbool64_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vadc_vvm)))
vint64m2_t vadc(vint64m2_t, vint64m2_t, vbool32_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vadc_vvm)))
vint64m4_t vadc(vint64m4_t, vint64m4_t, vbool16_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vadc_vvm)))
vint64m8_t vadc(vint64m8_t, vint64m8_t, vbool8_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vadc_vxm)))
vint64m1_t vadc(vint64m1_t, int64_t, vbool64_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vadc_vxm)))
vint64m2_t vadc(vint64m2_t, int64_t, vbool32_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vadc_vxm)))
vint64m4_t vadc(vint64m4_t, int64_t, vbool16_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vadc_vxm)))
vint64m8_t vadc(vint64m8_t, int64_t, vbool8_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vadc_vvm)))
vuint64m1_t vadc(vuint64m1_t, vuint64m1_t, vbool64_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vadc_vvm)))
vuint64m2_t vadc(vuint64m2_t, vuint64m2_t, vbool32_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vadc_vvm)))
vuint64m4_t vadc(vuint64m4_t, vuint64m4_t, vbool16_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vadc_vvm)))
vuint64m8_t vadc(vuint64m8_t, vuint64m8_t, vbool8_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vadc_vxm)))
vuint64m1_t vadc(vuint64m1_t, uint64_t, vbool64_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vadc_vxm)))
vuint64m2_t vadc(vuint64m2_t, uint64_t, vbool32_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vadc_vxm)))
vuint64m4_t vadc(vuint64m4_t, uint64_t, vbool16_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vadc_vxm)))
vuint64m8_t vadc(vuint64m8_t, uint64_t, vbool8_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vmadc_vvm)))
vbool64_t vmadc(vint64m1_t, vint64m1_t, vbool64_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vmadc_vvm)))
vbool32_t vmadc(vint64m2_t, vint64m2_t, vbool32_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vmadc_vvm)))
vbool16_t vmadc(vint64m4_t, vint64m4_t, vbool16_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vmadc_vvm)))
vbool8_t vmadc(vint64m8_t, vint64m8_t, vbool8_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vmadc_vxm)))
vbool64_t vmadc(vint64m1_t, int64_t, vbool64_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vmadc_vxm)))
vbool32_t vmadc(vint64m2_t, int64_t, vbool32_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vmadc_vxm)))
vbool16_t vmadc(vint64m4_t, int64_t, vbool16_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vmadc_vxm)))
vbool8_t vmadc(vint64m8_t, int64_t, vbool8_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vmadc_vvm)))
vbool64_t vmadc(vuint64m1_t, vuint64m1_t, vbool64_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vmadc_vvm)))
vbool32_t vmadc(vuint64m2_t, vuint64m2_t, vbool32_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vmadc_vvm)))
vbool16_t vmadc(vuint64m4_t, vuint64m4_t, vbool16_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vmadc_vvm)))
vbool8_t vmadc(vuint64m8_t, vuint64m8_t, vbool8_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vmadc_vxm)))
vbool64_t vmadc(vuint64m1_t, uint64_t, vbool64_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vmadc_vxm)))
vbool32_t vmadc(vuint64m2_t, uint64_t, vbool32_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vmadc_vxm)))
vbool16_t vmadc(vuint64m4_t, uint64_t, vbool16_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vmadc_vxm)))
vbool8_t vmadc(vuint64m8_t, uint64_t, vbool8_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vmadc_vv)))
vbool64_t vmadc(vint64m1_t, vint64m1_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vmadc_vv)))
vbool32_t vmadc(vint64m2_t, vint64m2_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vmadc_vv)))
vbool16_t vmadc(vint64m4_t, vint64m4_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vmadc_vv)))
vbool8_t vmadc(vint64m8_t, vint64m8_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vmadc_vx)))
vbool64_t vmadc(vint64m1_t, int64_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vmadc_vx)))
vbool32_t vmadc(vint64m2_t, int64_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vmadc_vx)))
vbool16_t vmadc(vint64m4_t, int64_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vmadc_vx)))
vbool8_t vmadc(vint64m8_t, int64_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vmadc_vv)))
vbool64_t vmadc(vuint64m1_t, vuint64m1_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vmadc_vv)))
vbool32_t vmadc(vuint64m2_t, vuint64m2_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vmadc_vv)))
vbool16_t vmadc(vuint64m4_t, vuint64m4_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vmadc_vv)))
vbool8_t vmadc(vuint64m8_t, vuint64m8_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vmadc_vx)))
vbool64_t vmadc(vuint64m1_t, uint64_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vmadc_vx)))
vbool32_t vmadc(vuint64m2_t, uint64_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vmadc_vx)))
vbool16_t vmadc(vuint64m4_t, uint64_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vmadc_vx)))
vbool8_t vmadc(vuint64m8_t, uint64_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vsbc_vvm)))
vint64m1_t vsbc(vint64m1_t, vint64m1_t, vbool64_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vsbc_vvm)))
vint64m2_t vsbc(vint64m2_t, vint64m2_t, vbool32_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vsbc_vvm)))
vint64m4_t vsbc(vint64m4_t, vint64m4_t, vbool16_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vsbc_vvm)))
vint64m8_t vsbc(vint64m8_t, vint64m8_t, vbool8_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vsbc_vxm)))
vint64m1_t vsbc(vint64m1_t, int64_t, vbool64_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vsbc_vxm)))
vint64m2_t vsbc(vint64m2_t, int64_t, vbool32_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vsbc_vxm)))
vint64m4_t vsbc(vint64m4_t, int64_t, vbool16_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vsbc_vxm)))
vint64m8_t vsbc(vint64m8_t, int64_t, vbool8_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vsbc_vvm)))
vuint64m1_t vsbc(vuint64m1_t, vuint64m1_t, vbool64_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vsbc_vvm)))
vuint64m2_t vsbc(vuint64m2_t, vuint64m2_t, vbool32_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vsbc_vvm)))
vuint64m4_t vsbc(vuint64m4_t, vuint64m4_t, vbool16_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vsbc_vvm)))
vuint64m8_t vsbc(vuint64m8_t, vuint64m8_t, vbool8_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vsbc_vxm)))
vuint64m1_t vsbc(vuint64m1_t, uint64_t, vbool64_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vsbc_vxm)))
vuint64m2_t vsbc(vuint64m2_t, uint64_t, vbool32_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vsbc_vxm)))
vuint64m4_t vsbc(vuint64m4_t, uint64_t, vbool16_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vsbc_vxm)))
vuint64m8_t vsbc(vuint64m8_t, uint64_t, vbool8_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vmsbc_vvm)))
vbool64_t vmsbc(vint64m1_t, vint64m1_t, vbool64_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vmsbc_vvm)))
vbool32_t vmsbc(vint64m2_t, vint64m2_t, vbool32_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vmsbc_vvm)))
vbool16_t vmsbc(vint64m4_t, vint64m4_t, vbool16_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vmsbc_vvm)))
vbool8_t vmsbc(vint64m8_t, vint64m8_t, vbool8_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vmsbc_vxm)))
vbool64_t vmsbc(vint64m1_t, int64_t, vbool64_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vmsbc_vxm)))
vbool32_t vmsbc(vint64m2_t, int64_t, vbool32_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vmsbc_vxm)))
vbool16_t vmsbc(vint64m4_t, int64_t, vbool16_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vmsbc_vxm)))
vbool8_t vmsbc(vint64m8_t, int64_t, vbool8_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vmsbc_vvm)))
vbool64_t vmsbc(vuint64m1_t, vuint64m1_t, vbool64_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vmsbc_vvm)))
vbool32_t vmsbc(vuint64m2_t, vuint64m2_t, vbool32_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vmsbc_vvm)))
vbool16_t vmsbc(vuint64m4_t, vuint64m4_t, vbool16_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vmsbc_vvm)))
vbool8_t vmsbc(vuint64m8_t, vuint64m8_t, vbool8_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vmsbc_vxm)))
vbool64_t vmsbc(vuint64m1_t, uint64_t, vbool64_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vmsbc_vxm)))
vbool32_t vmsbc(vuint64m2_t, uint64_t, vbool32_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vmsbc_vxm)))
vbool16_t vmsbc(vuint64m4_t, uint64_t, vbool16_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vmsbc_vxm)))
vbool8_t vmsbc(vuint64m8_t, uint64_t, vbool8_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vmsbc_vv)))
vbool64_t vmsbc(vint64m1_t, vint64m1_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vmsbc_vv)))
vbool32_t vmsbc(vint64m2_t, vint64m2_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vmsbc_vv)))
vbool16_t vmsbc(vint64m4_t, vint64m4_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vmsbc_vv)))
vbool8_t vmsbc(vint64m8_t, vint64m8_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vmsbc_vx)))
vbool64_t vmsbc(vint64m1_t, int64_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vmsbc_vx)))
vbool32_t vmsbc(vint64m2_t, int64_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vmsbc_vx)))
vbool16_t vmsbc(vint64m4_t, int64_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vmsbc_vx)))
vbool8_t vmsbc(vint64m8_t, int64_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vmsbc_vv)))
vbool64_t vmsbc(vuint64m1_t, vuint64m1_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vmsbc_vv)))
vbool32_t vmsbc(vuint64m2_t, vuint64m2_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vmsbc_vv)))
vbool16_t vmsbc(vuint64m4_t, vuint64m4_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vmsbc_vv)))
vbool8_t vmsbc(vuint64m8_t, vuint64m8_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vmsbc_vx)))
vbool64_t vmsbc(vuint64m1_t, uint64_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vmsbc_vx)))
vbool32_t vmsbc(vuint64m2_t, uint64_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vmsbc_vx)))
vbool16_t vmsbc(vuint64m4_t, uint64_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vmsbc_vx)))
vbool8_t vmsbc(vuint64m8_t, uint64_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vand_vv)))
vint64m1_t vand(vint64m1_t, vint64m1_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vand_vv_m)))
vint64m1_t vand(vbool64_t, vint64m1_t, vint64m1_t, vint64m1_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vand_vv)))
vint64m2_t vand(vint64m2_t, vint64m2_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vand_vv_m)))
vint64m2_t vand(vbool32_t, vint64m2_t, vint64m2_t, vint64m2_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vand_vv)))
vint64m4_t vand(vint64m4_t, vint64m4_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vand_vv_m)))
vint64m4_t vand(vbool16_t, vint64m4_t, vint64m4_t, vint64m4_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vand_vv)))
vint64m8_t vand(vint64m8_t, vint64m8_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vand_vv_m)))
vint64m8_t vand(vbool8_t, vint64m8_t, vint64m8_t, vint64m8_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vand_vx)))
vint64m1_t vand(vint64m1_t, int64_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vand_vx_m)))
vint64m1_t vand(vbool64_t, vint64m1_t, vint64m1_t, int64_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vand_vx)))
vint64m2_t vand(vint64m2_t, int64_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vand_vx_m)))
vint64m2_t vand(vbool32_t, vint64m2_t, vint64m2_t, int64_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vand_vx)))
vint64m4_t vand(vint64m4_t, int64_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vand_vx_m)))
vint64m4_t vand(vbool16_t, vint64m4_t, vint64m4_t, int64_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vand_vx)))
vint64m8_t vand(vint64m8_t, int64_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vand_vx_m)))
vint64m8_t vand(vbool8_t, vint64m8_t, vint64m8_t, int64_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vand_vv)))
vuint64m1_t vand(vuint64m1_t, vuint64m1_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vand_vv_m)))
vuint64m1_t vand(vbool64_t, vuint64m1_t, vuint64m1_t, vuint64m1_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vand_vv)))
vuint64m2_t vand(vuint64m2_t, vuint64m2_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vand_vv_m)))
vuint64m2_t vand(vbool32_t, vuint64m2_t, vuint64m2_t, vuint64m2_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vand_vv)))
vuint64m4_t vand(vuint64m4_t, vuint64m4_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vand_vv_m)))
vuint64m4_t vand(vbool16_t, vuint64m4_t, vuint64m4_t, vuint64m4_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vand_vv)))
vuint64m8_t vand(vuint64m8_t, vuint64m8_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vand_vv_m)))
vuint64m8_t vand(vbool8_t, vuint64m8_t, vuint64m8_t, vuint64m8_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vand_vx)))
vuint64m1_t vand(vuint64m1_t, uint64_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vand_vx_m)))
vuint64m1_t vand(vbool64_t, vuint64m1_t, vuint64m1_t, uint64_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vand_vx)))
vuint64m2_t vand(vuint64m2_t, uint64_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vand_vx_m)))
vuint64m2_t vand(vbool32_t, vuint64m2_t, vuint64m2_t, uint64_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vand_vx)))
vuint64m4_t vand(vuint64m4_t, uint64_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vand_vx_m)))
vuint64m4_t vand(vbool16_t, vuint64m4_t, vuint64m4_t, uint64_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vand_vx)))
vuint64m8_t vand(vuint64m8_t, uint64_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vand_vx_m)))
vuint64m8_t vand(vbool8_t, vuint64m8_t, vuint64m8_t, uint64_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vxor_vv)))
vint64m1_t vxor(vint64m1_t, vint64m1_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vxor_vv_m)))
vint64m1_t vxor(vbool64_t, vint64m1_t, vint64m1_t, vint64m1_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vxor_vv)))
vint64m2_t vxor(vint64m2_t, vint64m2_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vxor_vv_m)))
vint64m2_t vxor(vbool32_t, vint64m2_t, vint64m2_t, vint64m2_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vxor_vv)))
vint64m4_t vxor(vint64m4_t, vint64m4_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vxor_vv_m)))
vint64m4_t vxor(vbool16_t, vint64m4_t, vint64m4_t, vint64m4_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vxor_vv)))
vint64m8_t vxor(vint64m8_t, vint64m8_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vxor_vv_m)))
vint64m8_t vxor(vbool8_t, vint64m8_t, vint64m8_t, vint64m8_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vxor_vx)))
vint64m1_t vxor(vint64m1_t, int64_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vxor_vx_m)))
vint64m1_t vxor(vbool64_t, vint64m1_t, vint64m1_t, int64_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vxor_vx)))
vint64m2_t vxor(vint64m2_t, int64_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vxor_vx_m)))
vint64m2_t vxor(vbool32_t, vint64m2_t, vint64m2_t, int64_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vxor_vx)))
vint64m4_t vxor(vint64m4_t, int64_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vxor_vx_m)))
vint64m4_t vxor(vbool16_t, vint64m4_t, vint64m4_t, int64_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vxor_vx)))
vint64m8_t vxor(vint64m8_t, int64_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vxor_vx_m)))
vint64m8_t vxor(vbool8_t, vint64m8_t, vint64m8_t, int64_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vxor_vv)))
vuint64m1_t vxor(vuint64m1_t, vuint64m1_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vxor_vv_m)))
vuint64m1_t vxor(vbool64_t, vuint64m1_t, vuint64m1_t, vuint64m1_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vxor_vv)))
vuint64m2_t vxor(vuint64m2_t, vuint64m2_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vxor_vv_m)))
vuint64m2_t vxor(vbool32_t, vuint64m2_t, vuint64m2_t, vuint64m2_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vxor_vv)))
vuint64m4_t vxor(vuint64m4_t, vuint64m4_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vxor_vv_m)))
vuint64m4_t vxor(vbool16_t, vuint64m4_t, vuint64m4_t, vuint64m4_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vxor_vv)))
vuint64m8_t vxor(vuint64m8_t, vuint64m8_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vxor_vv_m)))
vuint64m8_t vxor(vbool8_t, vuint64m8_t, vuint64m8_t, vuint64m8_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vxor_vx)))
vuint64m1_t vxor(vuint64m1_t, uint64_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vxor_vx_m)))
vuint64m1_t vxor(vbool64_t, vuint64m1_t, vuint64m1_t, uint64_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vxor_vx)))
vuint64m2_t vxor(vuint64m2_t, uint64_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vxor_vx_m)))
vuint64m2_t vxor(vbool32_t, vuint64m2_t, vuint64m2_t, uint64_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vxor_vx)))
vuint64m4_t vxor(vuint64m4_t, uint64_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vxor_vx_m)))
vuint64m4_t vxor(vbool16_t, vuint64m4_t, vuint64m4_t, uint64_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vxor_vx)))
vuint64m8_t vxor(vuint64m8_t, uint64_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vxor_vx_m)))
vuint64m8_t vxor(vbool8_t, vuint64m8_t, vuint64m8_t, uint64_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vor_vv)))
vint64m1_t vor(vint64m1_t, vint64m1_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vor_vv_m)))
vint64m1_t vor(vbool64_t, vint64m1_t, vint64m1_t, vint64m1_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vor_vv)))
vint64m2_t vor(vint64m2_t, vint64m2_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vor_vv_m)))
vint64m2_t vor(vbool32_t, vint64m2_t, vint64m2_t, vint64m2_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vor_vv)))
vint64m4_t vor(vint64m4_t, vint64m4_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vor_vv_m)))
vint64m4_t vor(vbool16_t, vint64m4_t, vint64m4_t, vint64m4_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vor_vv)))
vint64m8_t vor(vint64m8_t, vint64m8_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vor_vv_m)))
vint64m8_t vor(vbool8_t, vint64m8_t, vint64m8_t, vint64m8_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vor_vx)))
vint64m1_t vor(vint64m1_t, int64_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vor_vx_m)))
vint64m1_t vor(vbool64_t, vint64m1_t, vint64m1_t, int64_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vor_vx)))
vint64m2_t vor(vint64m2_t, int64_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vor_vx_m)))
vint64m2_t vor(vbool32_t, vint64m2_t, vint64m2_t, int64_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vor_vx)))
vint64m4_t vor(vint64m4_t, int64_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vor_vx_m)))
vint64m4_t vor(vbool16_t, vint64m4_t, vint64m4_t, int64_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vor_vx)))
vint64m8_t vor(vint64m8_t, int64_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vor_vx_m)))
vint64m8_t vor(vbool8_t, vint64m8_t, vint64m8_t, int64_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vor_vv)))
vuint64m1_t vor(vuint64m1_t, vuint64m1_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vor_vv_m)))
vuint64m1_t vor(vbool64_t, vuint64m1_t, vuint64m1_t, vuint64m1_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vor_vv)))
vuint64m2_t vor(vuint64m2_t, vuint64m2_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vor_vv_m)))
vuint64m2_t vor(vbool32_t, vuint64m2_t, vuint64m2_t, vuint64m2_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vor_vv)))
vuint64m4_t vor(vuint64m4_t, vuint64m4_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vor_vv_m)))
vuint64m4_t vor(vbool16_t, vuint64m4_t, vuint64m4_t, vuint64m4_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vor_vv)))
vuint64m8_t vor(vuint64m8_t, vuint64m8_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vor_vv_m)))
vuint64m8_t vor(vbool8_t, vuint64m8_t, vuint64m8_t, vuint64m8_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vor_vx)))
vuint64m1_t vor(vuint64m1_t, uint64_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vor_vx_m)))
vuint64m1_t vor(vbool64_t, vuint64m1_t, vuint64m1_t, uint64_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vor_vx)))
vuint64m2_t vor(vuint64m2_t, uint64_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vor_vx_m)))
vuint64m2_t vor(vbool32_t, vuint64m2_t, vuint64m2_t, uint64_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vor_vx)))
vuint64m4_t vor(vuint64m4_t, uint64_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vor_vx_m)))
vuint64m4_t vor(vbool16_t, vuint64m4_t, vuint64m4_t, uint64_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vor_vx)))
vuint64m8_t vor(vuint64m8_t, uint64_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vor_vx_m)))
vuint64m8_t vor(vbool8_t, vuint64m8_t, vuint64m8_t, uint64_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vsll_vv)))
vint64m1_t vsll(vint64m1_t, vuint64m1_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vsll_vv_m)))
vint64m1_t vsll(vbool64_t, vint64m1_t, vint64m1_t, vuint64m1_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vsll_vv)))
vint64m2_t vsll(vint64m2_t, vuint64m2_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vsll_vv_m)))
vint64m2_t vsll(vbool32_t, vint64m2_t, vint64m2_t, vuint64m2_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vsll_vv)))
vint64m4_t vsll(vint64m4_t, vuint64m4_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vsll_vv_m)))
vint64m4_t vsll(vbool16_t, vint64m4_t, vint64m4_t, vuint64m4_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vsll_vv)))
vint64m8_t vsll(vint64m8_t, vuint64m8_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vsll_vv_m)))
vint64m8_t vsll(vbool8_t, vint64m8_t, vint64m8_t, vuint64m8_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vsll_vx)))
vint64m1_t vsll(vint64m1_t, size_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vsll_vx_m)))
vint64m1_t vsll(vbool64_t, vint64m1_t, vint64m1_t, size_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vsll_vx)))
vint64m2_t vsll(vint64m2_t, size_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vsll_vx_m)))
vint64m2_t vsll(vbool32_t, vint64m2_t, vint64m2_t, size_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vsll_vx)))
vint64m4_t vsll(vint64m4_t, size_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vsll_vx_m)))
vint64m4_t vsll(vbool16_t, vint64m4_t, vint64m4_t, size_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vsll_vx)))
vint64m8_t vsll(vint64m8_t, size_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vsll_vx_m)))
vint64m8_t vsll(vbool8_t, vint64m8_t, vint64m8_t, size_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vsll_vv)))
vuint64m1_t vsll(vuint64m1_t, vuint64m1_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vsll_vv_m)))
vuint64m1_t vsll(vbool64_t, vuint64m1_t, vuint64m1_t, vuint64m1_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vsll_vv)))
vuint64m2_t vsll(vuint64m2_t, vuint64m2_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vsll_vv_m)))
vuint64m2_t vsll(vbool32_t, vuint64m2_t, vuint64m2_t, vuint64m2_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vsll_vv)))
vuint64m4_t vsll(vuint64m4_t, vuint64m4_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vsll_vv_m)))
vuint64m4_t vsll(vbool16_t, vuint64m4_t, vuint64m4_t, vuint64m4_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vsll_vv)))
vuint64m8_t vsll(vuint64m8_t, vuint64m8_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vsll_vv_m)))
vuint64m8_t vsll(vbool8_t, vuint64m8_t, vuint64m8_t, vuint64m8_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vsll_vx)))
vuint64m1_t vsll(vuint64m1_t, size_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vsll_vx_m)))
vuint64m1_t vsll(vbool64_t, vuint64m1_t, vuint64m1_t, size_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vsll_vx)))
vuint64m2_t vsll(vuint64m2_t, size_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vsll_vx_m)))
vuint64m2_t vsll(vbool32_t, vuint64m2_t, vuint64m2_t, size_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vsll_vx)))
vuint64m4_t vsll(vuint64m4_t, size_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vsll_vx_m)))
vuint64m4_t vsll(vbool16_t, vuint64m4_t, vuint64m4_t, size_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vsll_vx)))
vuint64m8_t vsll(vuint64m8_t, size_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vsll_vx_m)))
vuint64m8_t vsll(vbool8_t, vuint64m8_t, vuint64m8_t, size_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vsrl_vv)))
vuint64m1_t vsrl(vuint64m1_t, vuint64m1_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vsrl_vv_m)))
vuint64m1_t vsrl(vbool64_t, vuint64m1_t, vuint64m1_t, vuint64m1_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vsrl_vv)))
vuint64m2_t vsrl(vuint64m2_t, vuint64m2_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vsrl_vv_m)))
vuint64m2_t vsrl(vbool32_t, vuint64m2_t, vuint64m2_t, vuint64m2_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vsrl_vv)))
vuint64m4_t vsrl(vuint64m4_t, vuint64m4_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vsrl_vv_m)))
vuint64m4_t vsrl(vbool16_t, vuint64m4_t, vuint64m4_t, vuint64m4_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vsrl_vv)))
vuint64m8_t vsrl(vuint64m8_t, vuint64m8_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vsrl_vv_m)))
vuint64m8_t vsrl(vbool8_t, vuint64m8_t, vuint64m8_t, vuint64m8_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vsrl_vx)))
vuint64m1_t vsrl(vuint64m1_t, size_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vsrl_vx_m)))
vuint64m1_t vsrl(vbool64_t, vuint64m1_t, vuint64m1_t, size_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vsrl_vx)))
vuint64m2_t vsrl(vuint64m2_t, size_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vsrl_vx_m)))
vuint64m2_t vsrl(vbool32_t, vuint64m2_t, vuint64m2_t, size_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vsrl_vx)))
vuint64m4_t vsrl(vuint64m4_t, size_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vsrl_vx_m)))
vuint64m4_t vsrl(vbool16_t, vuint64m4_t, vuint64m4_t, size_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vsrl_vx)))
vuint64m8_t vsrl(vuint64m8_t, size_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vsrl_vx_m)))
vuint64m8_t vsrl(vbool8_t, vuint64m8_t, vuint64m8_t, size_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vsra_vv)))
vint64m1_t vsra(vint64m1_t, vuint64m1_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vsra_vv_m)))
vint64m1_t vsra(vbool64_t, vint64m1_t, vint64m1_t, vuint64m1_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vsra_vv)))
vint64m2_t vsra(vint64m2_t, vuint64m2_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vsra_vv_m)))
vint64m2_t vsra(vbool32_t, vint64m2_t, vint64m2_t, vuint64m2_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vsra_vv)))
vint64m4_t vsra(vint64m4_t, vuint64m4_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vsra_vv_m)))
vint64m4_t vsra(vbool16_t, vint64m4_t, vint64m4_t, vuint64m4_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vsra_vv)))
vint64m8_t vsra(vint64m8_t, vuint64m8_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vsra_vv_m)))
vint64m8_t vsra(vbool8_t, vint64m8_t, vint64m8_t, vuint64m8_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vsra_vx)))
vint64m1_t vsra(vint64m1_t, size_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vsra_vx_m)))
vint64m1_t vsra(vbool64_t, vint64m1_t, vint64m1_t, size_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vsra_vx)))
vint64m2_t vsra(vint64m2_t, size_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vsra_vx_m)))
vint64m2_t vsra(vbool32_t, vint64m2_t, vint64m2_t, size_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vsra_vx)))
vint64m4_t vsra(vint64m4_t, size_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vsra_vx_m)))
vint64m4_t vsra(vbool16_t, vint64m4_t, vint64m4_t, size_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vsra_vx)))
vint64m8_t vsra(vint64m8_t, size_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vsra_vx_m)))
vint64m8_t vsra(vbool8_t, vint64m8_t, vint64m8_t, size_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vnsrl_wv)))
vuint32m1_t vnsrl(vuint64m2_t, vuint32m1_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vnsrl_wv_m)))
vuint32m1_t vnsrl(vbool32_t, vuint32m1_t, vuint64m2_t, vuint32m1_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vnsrl_wv)))
vuint32m2_t vnsrl(vuint64m4_t, vuint32m2_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vnsrl_wv_m)))
vuint32m2_t vnsrl(vbool16_t, vuint32m2_t, vuint64m4_t, vuint32m2_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vnsrl_wv)))
vuint32m4_t vnsrl(vuint64m8_t, vuint32m4_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vnsrl_wv_m)))
vuint32m4_t vnsrl(vbool8_t, vuint32m4_t, vuint64m8_t, vuint32m4_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vnsrl_wv)))
vuint32mf2_t vnsrl(vuint64m1_t, vuint32mf2_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vnsrl_wv_m)))
vuint32mf2_t vnsrl(vbool64_t, vuint32mf2_t, vuint64m1_t, vuint32mf2_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vnsrl_wx)))
vuint32m1_t vnsrl(vuint64m2_t, size_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vnsrl_wx_m)))
vuint32m1_t vnsrl(vbool32_t, vuint32m1_t, vuint64m2_t, size_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vnsrl_wx)))
vuint32m2_t vnsrl(vuint64m4_t, size_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vnsrl_wx_m)))
vuint32m2_t vnsrl(vbool16_t, vuint32m2_t, vuint64m4_t, size_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vnsrl_wx)))
vuint32m4_t vnsrl(vuint64m8_t, size_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vnsrl_wx_m)))
vuint32m4_t vnsrl(vbool8_t, vuint32m4_t, vuint64m8_t, size_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vnsrl_wx)))
vuint32mf2_t vnsrl(vuint64m1_t, size_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vnsrl_wx_m)))
vuint32mf2_t vnsrl(vbool64_t, vuint32mf2_t, vuint64m1_t, size_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vnsra_wv)))
vint32m1_t vnsra(vint64m2_t, vuint32m1_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vnsra_wv_m)))
vint32m1_t vnsra(vbool32_t, vint32m1_t, vint64m2_t, vuint32m1_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vnsra_wv)))
vint32m2_t vnsra(vint64m4_t, vuint32m2_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vnsra_wv_m)))
vint32m2_t vnsra(vbool16_t, vint32m2_t, vint64m4_t, vuint32m2_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vnsra_wv)))
vint32m4_t vnsra(vint64m8_t, vuint32m4_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vnsra_wv_m)))
vint32m4_t vnsra(vbool8_t, vint32m4_t, vint64m8_t, vuint32m4_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vnsra_wv)))
vint32mf2_t vnsra(vint64m1_t, vuint32mf2_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vnsra_wv_m)))
vint32mf2_t vnsra(vbool64_t, vint32mf2_t, vint64m1_t, vuint32mf2_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vnsra_wx)))
vint32m1_t vnsra(vint64m2_t, size_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vnsra_wx_m)))
vint32m1_t vnsra(vbool32_t, vint32m1_t, vint64m2_t, size_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vnsra_wx)))
vint32m2_t vnsra(vint64m4_t, size_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vnsra_wx_m)))
vint32m2_t vnsra(vbool16_t, vint32m2_t, vint64m4_t, size_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vnsra_wx)))
vint32m4_t vnsra(vint64m8_t, size_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vnsra_wx_m)))
vint32m4_t vnsra(vbool8_t, vint32m4_t, vint64m8_t, size_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vnsra_wx)))
vint32mf2_t vnsra(vint64m1_t, size_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vnsra_wx_m)))
vint32mf2_t vnsra(vbool64_t, vint32mf2_t, vint64m1_t, size_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vncvt_x_x_w)))
vuint32m1_t vncvt_x(vuint64m2_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vncvt_x_x_w_m)))
vuint32m1_t vncvt_x(vbool32_t, vuint32m1_t, vuint64m2_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vncvt_x_x_w)))
vuint32m2_t vncvt_x(vuint64m4_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vncvt_x_x_w_m)))
vuint32m2_t vncvt_x(vbool16_t, vuint32m2_t, vuint64m4_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vncvt_x_x_w)))
vuint32m4_t vncvt_x(vuint64m8_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vncvt_x_x_w_m)))
vuint32m4_t vncvt_x(vbool8_t, vuint32m4_t, vuint64m8_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vncvt_x_x_w)))
vuint32mf2_t vncvt_x(vuint64m1_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vncvt_x_x_w_m)))
vuint32mf2_t vncvt_x(vbool64_t, vuint32mf2_t, vuint64m1_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vmseq_vv)))
vbool64_t vmseq(vint64m1_t, vint64m1_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vmseq_vv_m)))
vbool64_t vmseq(vbool64_t, vbool64_t, vint64m1_t, vint64m1_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vmseq_vv)))
vbool32_t vmseq(vint64m2_t, vint64m2_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vmseq_vv_m)))
vbool32_t vmseq(vbool32_t, vbool32_t, vint64m2_t, vint64m2_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vmseq_vv)))
vbool16_t vmseq(vint64m4_t, vint64m4_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vmseq_vv_m)))
vbool16_t vmseq(vbool16_t, vbool16_t, vint64m4_t, vint64m4_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vmseq_vv)))
vbool8_t vmseq(vint64m8_t, vint64m8_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vmseq_vv_m)))
vbool8_t vmseq(vbool8_t, vbool8_t, vint64m8_t, vint64m8_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vmseq_vx)))
vbool64_t vmseq(vint64m1_t, int64_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vmseq_vx_m)))
vbool64_t vmseq(vbool64_t, vbool64_t, vint64m1_t, int64_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vmseq_vx)))
vbool32_t vmseq(vint64m2_t, int64_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vmseq_vx_m)))
vbool32_t vmseq(vbool32_t, vbool32_t, vint64m2_t, int64_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vmseq_vx)))
vbool16_t vmseq(vint64m4_t, int64_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vmseq_vx_m)))
vbool16_t vmseq(vbool16_t, vbool16_t, vint64m4_t, int64_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vmseq_vx)))
vbool8_t vmseq(vint64m8_t, int64_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vmseq_vx_m)))
vbool8_t vmseq(vbool8_t, vbool8_t, vint64m8_t, int64_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vmseq_vv)))
vbool64_t vmseq(vuint64m1_t, vuint64m1_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vmseq_vv_m)))
vbool64_t vmseq(vbool64_t, vbool64_t, vuint64m1_t, vuint64m1_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vmseq_vv)))
vbool32_t vmseq(vuint64m2_t, vuint64m2_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vmseq_vv_m)))
vbool32_t vmseq(vbool32_t, vbool32_t, vuint64m2_t, vuint64m2_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vmseq_vv)))
vbool16_t vmseq(vuint64m4_t, vuint64m4_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vmseq_vv_m)))
vbool16_t vmseq(vbool16_t, vbool16_t, vuint64m4_t, vuint64m4_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vmseq_vv)))
vbool8_t vmseq(vuint64m8_t, vuint64m8_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vmseq_vv_m)))
vbool8_t vmseq(vbool8_t, vbool8_t, vuint64m8_t, vuint64m8_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vmseq_vx)))
vbool64_t vmseq(vuint64m1_t, uint64_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vmseq_vx_m)))
vbool64_t vmseq(vbool64_t, vbool64_t, vuint64m1_t, uint64_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vmseq_vx)))
vbool32_t vmseq(vuint64m2_t, uint64_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vmseq_vx_m)))
vbool32_t vmseq(vbool32_t, vbool32_t, vuint64m2_t, uint64_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vmseq_vx)))
vbool16_t vmseq(vuint64m4_t, uint64_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vmseq_vx_m)))
vbool16_t vmseq(vbool16_t, vbool16_t, vuint64m4_t, uint64_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vmseq_vx)))
vbool8_t vmseq(vuint64m8_t, uint64_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vmseq_vx_m)))
vbool8_t vmseq(vbool8_t, vbool8_t, vuint64m8_t, uint64_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vmsne_vv)))
vbool64_t vmsne(vint64m1_t, vint64m1_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vmsne_vv_m)))
vbool64_t vmsne(vbool64_t, vbool64_t, vint64m1_t, vint64m1_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vmsne_vv)))
vbool32_t vmsne(vint64m2_t, vint64m2_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vmsne_vv_m)))
vbool32_t vmsne(vbool32_t, vbool32_t, vint64m2_t, vint64m2_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vmsne_vv)))
vbool16_t vmsne(vint64m4_t, vint64m4_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vmsne_vv_m)))
vbool16_t vmsne(vbool16_t, vbool16_t, vint64m4_t, vint64m4_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vmsne_vv)))
vbool8_t vmsne(vint64m8_t, vint64m8_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vmsne_vv_m)))
vbool8_t vmsne(vbool8_t, vbool8_t, vint64m8_t, vint64m8_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vmsne_vx)))
vbool64_t vmsne(vint64m1_t, int64_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vmsne_vx_m)))
vbool64_t vmsne(vbool64_t, vbool64_t, vint64m1_t, int64_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vmsne_vx)))
vbool32_t vmsne(vint64m2_t, int64_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vmsne_vx_m)))
vbool32_t vmsne(vbool32_t, vbool32_t, vint64m2_t, int64_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vmsne_vx)))
vbool16_t vmsne(vint64m4_t, int64_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vmsne_vx_m)))
vbool16_t vmsne(vbool16_t, vbool16_t, vint64m4_t, int64_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vmsne_vx)))
vbool8_t vmsne(vint64m8_t, int64_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vmsne_vx_m)))
vbool8_t vmsne(vbool8_t, vbool8_t, vint64m8_t, int64_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vmsne_vv)))
vbool64_t vmsne(vuint64m1_t, vuint64m1_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vmsne_vv_m)))
vbool64_t vmsne(vbool64_t, vbool64_t, vuint64m1_t, vuint64m1_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vmsne_vv)))
vbool32_t vmsne(vuint64m2_t, vuint64m2_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vmsne_vv_m)))
vbool32_t vmsne(vbool32_t, vbool32_t, vuint64m2_t, vuint64m2_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vmsne_vv)))
vbool16_t vmsne(vuint64m4_t, vuint64m4_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vmsne_vv_m)))
vbool16_t vmsne(vbool16_t, vbool16_t, vuint64m4_t, vuint64m4_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vmsne_vv)))
vbool8_t vmsne(vuint64m8_t, vuint64m8_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vmsne_vv_m)))
vbool8_t vmsne(vbool8_t, vbool8_t, vuint64m8_t, vuint64m8_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vmsne_vx)))
vbool64_t vmsne(vuint64m1_t, uint64_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vmsne_vx_m)))
vbool64_t vmsne(vbool64_t, vbool64_t, vuint64m1_t, uint64_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vmsne_vx)))
vbool32_t vmsne(vuint64m2_t, uint64_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vmsne_vx_m)))
vbool32_t vmsne(vbool32_t, vbool32_t, vuint64m2_t, uint64_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vmsne_vx)))
vbool16_t vmsne(vuint64m4_t, uint64_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vmsne_vx_m)))
vbool16_t vmsne(vbool16_t, vbool16_t, vuint64m4_t, uint64_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vmsne_vx)))
vbool8_t vmsne(vuint64m8_t, uint64_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vmsne_vx_m)))
vbool8_t vmsne(vbool8_t, vbool8_t, vuint64m8_t, uint64_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vmsltu_vv)))
vbool64_t vmsltu(vuint64m1_t, vuint64m1_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vmsltu_vv_m)))
vbool64_t vmsltu(vbool64_t, vbool64_t, vuint64m1_t, vuint64m1_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vmsltu_vv)))
vbool32_t vmsltu(vuint64m2_t, vuint64m2_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vmsltu_vv_m)))
vbool32_t vmsltu(vbool32_t, vbool32_t, vuint64m2_t, vuint64m2_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vmsltu_vv)))
vbool16_t vmsltu(vuint64m4_t, vuint64m4_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vmsltu_vv_m)))
vbool16_t vmsltu(vbool16_t, vbool16_t, vuint64m4_t, vuint64m4_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vmsltu_vv)))
vbool8_t vmsltu(vuint64m8_t, vuint64m8_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vmsltu_vv_m)))
vbool8_t vmsltu(vbool8_t, vbool8_t, vuint64m8_t, vuint64m8_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vmsltu_vx)))
vbool64_t vmsltu(vuint64m1_t, uint64_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vmsltu_vx_m)))
vbool64_t vmsltu(vbool64_t, vbool64_t, vuint64m1_t, uint64_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vmsltu_vx)))
vbool32_t vmsltu(vuint64m2_t, uint64_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vmsltu_vx_m)))
vbool32_t vmsltu(vbool32_t, vbool32_t, vuint64m2_t, uint64_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vmsltu_vx)))
vbool16_t vmsltu(vuint64m4_t, uint64_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vmsltu_vx_m)))
vbool16_t vmsltu(vbool16_t, vbool16_t, vuint64m4_t, uint64_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vmsltu_vx)))
vbool8_t vmsltu(vuint64m8_t, uint64_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vmsltu_vx_m)))
vbool8_t vmsltu(vbool8_t, vbool8_t, vuint64m8_t, uint64_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vmslt_vv)))
vbool64_t vmslt(vint64m1_t, vint64m1_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vmslt_vv_m)))
vbool64_t vmslt(vbool64_t, vbool64_t, vint64m1_t, vint64m1_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vmslt_vv)))
vbool32_t vmslt(vint64m2_t, vint64m2_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vmslt_vv_m)))
vbool32_t vmslt(vbool32_t, vbool32_t, vint64m2_t, vint64m2_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vmslt_vv)))
vbool16_t vmslt(vint64m4_t, vint64m4_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vmslt_vv_m)))
vbool16_t vmslt(vbool16_t, vbool16_t, vint64m4_t, vint64m4_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vmslt_vv)))
vbool8_t vmslt(vint64m8_t, vint64m8_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vmslt_vv_m)))
vbool8_t vmslt(vbool8_t, vbool8_t, vint64m8_t, vint64m8_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vmslt_vx)))
vbool64_t vmslt(vint64m1_t, int64_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vmslt_vx_m)))
vbool64_t vmslt(vbool64_t, vbool64_t, vint64m1_t, int64_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vmslt_vx)))
vbool32_t vmslt(vint64m2_t, int64_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vmslt_vx_m)))
vbool32_t vmslt(vbool32_t, vbool32_t, vint64m2_t, int64_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vmslt_vx)))
vbool16_t vmslt(vint64m4_t, int64_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vmslt_vx_m)))
vbool16_t vmslt(vbool16_t, vbool16_t, vint64m4_t, int64_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vmslt_vx)))
vbool8_t vmslt(vint64m8_t, int64_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vmslt_vx_m)))
vbool8_t vmslt(vbool8_t, vbool8_t, vint64m8_t, int64_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vmsleu_vv)))
vbool64_t vmsleu(vuint64m1_t, vuint64m1_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vmsleu_vv_m)))
vbool64_t vmsleu(vbool64_t, vbool64_t, vuint64m1_t, vuint64m1_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vmsleu_vv)))
vbool32_t vmsleu(vuint64m2_t, vuint64m2_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vmsleu_vv_m)))
vbool32_t vmsleu(vbool32_t, vbool32_t, vuint64m2_t, vuint64m2_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vmsleu_vv)))
vbool16_t vmsleu(vuint64m4_t, vuint64m4_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vmsleu_vv_m)))
vbool16_t vmsleu(vbool16_t, vbool16_t, vuint64m4_t, vuint64m4_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vmsleu_vv)))
vbool8_t vmsleu(vuint64m8_t, vuint64m8_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vmsleu_vv_m)))
vbool8_t vmsleu(vbool8_t, vbool8_t, vuint64m8_t, vuint64m8_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vmsleu_vx)))
vbool64_t vmsleu(vuint64m1_t, uint64_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vmsleu_vx_m)))
vbool64_t vmsleu(vbool64_t, vbool64_t, vuint64m1_t, uint64_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vmsleu_vx)))
vbool32_t vmsleu(vuint64m2_t, uint64_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vmsleu_vx_m)))
vbool32_t vmsleu(vbool32_t, vbool32_t, vuint64m2_t, uint64_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vmsleu_vx)))
vbool16_t vmsleu(vuint64m4_t, uint64_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vmsleu_vx_m)))
vbool16_t vmsleu(vbool16_t, vbool16_t, vuint64m4_t, uint64_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vmsleu_vx)))
vbool8_t vmsleu(vuint64m8_t, uint64_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vmsleu_vx_m)))
vbool8_t vmsleu(vbool8_t, vbool8_t, vuint64m8_t, uint64_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vmsle_vv)))
vbool64_t vmsle(vint64m1_t, vint64m1_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vmsle_vv_m)))
vbool64_t vmsle(vbool64_t, vbool64_t, vint64m1_t, vint64m1_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vmsle_vv)))
vbool32_t vmsle(vint64m2_t, vint64m2_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vmsle_vv_m)))
vbool32_t vmsle(vbool32_t, vbool32_t, vint64m2_t, vint64m2_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vmsle_vv)))
vbool16_t vmsle(vint64m4_t, vint64m4_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vmsle_vv_m)))
vbool16_t vmsle(vbool16_t, vbool16_t, vint64m4_t, vint64m4_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vmsle_vv)))
vbool8_t vmsle(vint64m8_t, vint64m8_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vmsle_vv_m)))
vbool8_t vmsle(vbool8_t, vbool8_t, vint64m8_t, vint64m8_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vmsle_vx)))
vbool64_t vmsle(vint64m1_t, int64_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vmsle_vx_m)))
vbool64_t vmsle(vbool64_t, vbool64_t, vint64m1_t, int64_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vmsle_vx)))
vbool32_t vmsle(vint64m2_t, int64_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vmsle_vx_m)))
vbool32_t vmsle(vbool32_t, vbool32_t, vint64m2_t, int64_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vmsle_vx)))
vbool16_t vmsle(vint64m4_t, int64_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vmsle_vx_m)))
vbool16_t vmsle(vbool16_t, vbool16_t, vint64m4_t, int64_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vmsle_vx)))
vbool8_t vmsle(vint64m8_t, int64_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vmsle_vx_m)))
vbool8_t vmsle(vbool8_t, vbool8_t, vint64m8_t, int64_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vmsgtu_vv)))
vbool64_t vmsgtu(vuint64m1_t, vuint64m1_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vmsgtu_vv_m)))
vbool64_t vmsgtu(vbool64_t, vbool64_t, vuint64m1_t, vuint64m1_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vmsgtu_vv)))
vbool32_t vmsgtu(vuint64m2_t, vuint64m2_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vmsgtu_vv_m)))
vbool32_t vmsgtu(vbool32_t, vbool32_t, vuint64m2_t, vuint64m2_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vmsgtu_vv)))
vbool16_t vmsgtu(vuint64m4_t, vuint64m4_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vmsgtu_vv_m)))
vbool16_t vmsgtu(vbool16_t, vbool16_t, vuint64m4_t, vuint64m4_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vmsgtu_vv)))
vbool8_t vmsgtu(vuint64m8_t, vuint64m8_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vmsgtu_vv_m)))
vbool8_t vmsgtu(vbool8_t, vbool8_t, vuint64m8_t, vuint64m8_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vmsgtu_vx)))
vbool64_t vmsgtu(vuint64m1_t, uint64_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vmsgtu_vx_m)))
vbool64_t vmsgtu(vbool64_t, vbool64_t, vuint64m1_t, uint64_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vmsgtu_vx)))
vbool32_t vmsgtu(vuint64m2_t, uint64_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vmsgtu_vx_m)))
vbool32_t vmsgtu(vbool32_t, vbool32_t, vuint64m2_t, uint64_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vmsgtu_vx)))
vbool16_t vmsgtu(vuint64m4_t, uint64_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vmsgtu_vx_m)))
vbool16_t vmsgtu(vbool16_t, vbool16_t, vuint64m4_t, uint64_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vmsgtu_vx)))
vbool8_t vmsgtu(vuint64m8_t, uint64_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vmsgtu_vx_m)))
vbool8_t vmsgtu(vbool8_t, vbool8_t, vuint64m8_t, uint64_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vmsgt_vv)))
vbool64_t vmsgt(vint64m1_t, vint64m1_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vmsgt_vv_m)))
vbool64_t vmsgt(vbool64_t, vbool64_t, vint64m1_t, vint64m1_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vmsgt_vv)))
vbool32_t vmsgt(vint64m2_t, vint64m2_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vmsgt_vv_m)))
vbool32_t vmsgt(vbool32_t, vbool32_t, vint64m2_t, vint64m2_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vmsgt_vv)))
vbool16_t vmsgt(vint64m4_t, vint64m4_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vmsgt_vv_m)))
vbool16_t vmsgt(vbool16_t, vbool16_t, vint64m4_t, vint64m4_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vmsgt_vv)))
vbool8_t vmsgt(vint64m8_t, vint64m8_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vmsgt_vv_m)))
vbool8_t vmsgt(vbool8_t, vbool8_t, vint64m8_t, vint64m8_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vmsgt_vx)))
vbool64_t vmsgt(vint64m1_t, int64_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vmsgt_vx_m)))
vbool64_t vmsgt(vbool64_t, vbool64_t, vint64m1_t, int64_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vmsgt_vx)))
vbool32_t vmsgt(vint64m2_t, int64_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vmsgt_vx_m)))
vbool32_t vmsgt(vbool32_t, vbool32_t, vint64m2_t, int64_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vmsgt_vx)))
vbool16_t vmsgt(vint64m4_t, int64_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vmsgt_vx_m)))
vbool16_t vmsgt(vbool16_t, vbool16_t, vint64m4_t, int64_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vmsgt_vx)))
vbool8_t vmsgt(vint64m8_t, int64_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vmsgt_vx_m)))
vbool8_t vmsgt(vbool8_t, vbool8_t, vint64m8_t, int64_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vmsgeu_vv)))
vbool64_t vmsgeu(vuint64m1_t, vuint64m1_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vmsgeu_vv_m)))
vbool64_t vmsgeu(vbool64_t, vbool64_t, vuint64m1_t, vuint64m1_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vmsgeu_vv)))
vbool32_t vmsgeu(vuint64m2_t, vuint64m2_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vmsgeu_vv_m)))
vbool32_t vmsgeu(vbool32_t, vbool32_t, vuint64m2_t, vuint64m2_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vmsgeu_vv)))
vbool16_t vmsgeu(vuint64m4_t, vuint64m4_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vmsgeu_vv_m)))
vbool16_t vmsgeu(vbool16_t, vbool16_t, vuint64m4_t, vuint64m4_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vmsgeu_vv)))
vbool8_t vmsgeu(vuint64m8_t, vuint64m8_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vmsgeu_vv_m)))
vbool8_t vmsgeu(vbool8_t, vbool8_t, vuint64m8_t, vuint64m8_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vwaddu_wv)))
vuint64m1_t vwaddu_wv(vuint64m1_t, vuint32mf2_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vwaddu_wv_m)))
vuint64m1_t vwaddu_wv(vbool64_t, vuint64m1_t, vuint64m1_t, vuint32mf2_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vwaddu_wv)))
vuint64m2_t vwaddu_wv(vuint64m2_t, vuint32m1_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vwaddu_wv_m)))
vuint64m2_t vwaddu_wv(vbool32_t, vuint64m2_t, vuint64m2_t, vuint32m1_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vwaddu_wv)))
vuint64m4_t vwaddu_wv(vuint64m4_t, vuint32m2_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vwaddu_wv_m)))
vuint64m4_t vwaddu_wv(vbool16_t, vuint64m4_t, vuint64m4_t, vuint32m2_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vwaddu_wv)))
vuint64m8_t vwaddu_wv(vuint64m8_t, vuint32m4_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vwaddu_wv_m)))
vuint64m8_t vwaddu_wv(vbool8_t, vuint64m8_t, vuint64m8_t, vuint32m4_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vmsgeu_vx)))
vbool64_t vmsgeu(vuint64m1_t, uint64_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vmsgeu_vx_m)))
vbool64_t vmsgeu(vbool64_t, vbool64_t, vuint64m1_t, uint64_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vmsgeu_vx)))
vbool32_t vmsgeu(vuint64m2_t, uint64_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vmsgeu_vx_m)))
vbool32_t vmsgeu(vbool32_t, vbool32_t, vuint64m2_t, uint64_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vmsgeu_vx)))
vbool16_t vmsgeu(vuint64m4_t, uint64_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vmsgeu_vx_m)))
vbool16_t vmsgeu(vbool16_t, vbool16_t, vuint64m4_t, uint64_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vmsgeu_vx)))
vbool8_t vmsgeu(vuint64m8_t, uint64_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vmsgeu_vx_m)))
vbool8_t vmsgeu(vbool8_t, vbool8_t, vuint64m8_t, uint64_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vmsge_vv)))
vbool64_t vmsge(vint64m1_t, vint64m1_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vmsge_vv_m)))
vbool64_t vmsge(vbool64_t, vbool64_t, vint64m1_t, vint64m1_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vmsge_vv)))
vbool32_t vmsge(vint64m2_t, vint64m2_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vmsge_vv_m)))
vbool32_t vmsge(vbool32_t, vbool32_t, vint64m2_t, vint64m2_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vmsge_vv)))
vbool16_t vmsge(vint64m4_t, vint64m4_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vmsge_vv_m)))
vbool16_t vmsge(vbool16_t, vbool16_t, vint64m4_t, vint64m4_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vmsge_vv)))
vbool8_t vmsge(vint64m8_t, vint64m8_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vmsge_vv_m)))
vbool8_t vmsge(vbool8_t, vbool8_t, vint64m8_t, vint64m8_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vmsge_vx)))
vbool64_t vmsge(vint64m1_t, int64_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vmsge_vx_m)))
vbool64_t vmsge(vbool64_t, vbool64_t, vint64m1_t, int64_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vmsge_vx)))
vbool32_t vmsge(vint64m2_t, int64_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vmsge_vx_m)))
vbool32_t vmsge(vbool32_t, vbool32_t, vint64m2_t, int64_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vmsge_vx)))
vbool16_t vmsge(vint64m4_t, int64_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vmsge_vx_m)))
vbool16_t vmsge(vbool16_t, vbool16_t, vint64m4_t, int64_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vmsge_vx)))
vbool8_t vmsge(vint64m8_t, int64_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vmsge_vx_m)))
vbool8_t vmsge(vbool8_t, vbool8_t, vint64m8_t, int64_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vminu_vv)))
vuint64m1_t vminu(vuint64m1_t, vuint64m1_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vminu_vv_m)))
vuint64m1_t vminu(vbool64_t, vuint64m1_t, vuint64m1_t, vuint64m1_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vminu_vv)))
vuint64m2_t vminu(vuint64m2_t, vuint64m2_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vminu_vv_m)))
vuint64m2_t vminu(vbool32_t, vuint64m2_t, vuint64m2_t, vuint64m2_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vminu_vv)))
vuint64m4_t vminu(vuint64m4_t, vuint64m4_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vminu_vv_m)))
vuint64m4_t vminu(vbool16_t, vuint64m4_t, vuint64m4_t, vuint64m4_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vminu_vv)))
vuint64m8_t vminu(vuint64m8_t, vuint64m8_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vminu_vv_m)))
vuint64m8_t vminu(vbool8_t, vuint64m8_t, vuint64m8_t, vuint64m8_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vminu_vx)))
vuint64m1_t vminu(vuint64m1_t, uint64_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vminu_vx_m)))
vuint64m1_t vminu(vbool64_t, vuint64m1_t, vuint64m1_t, uint64_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vminu_vx)))
vuint64m2_t vminu(vuint64m2_t, uint64_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vminu_vx_m)))
vuint64m2_t vminu(vbool32_t, vuint64m2_t, vuint64m2_t, uint64_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vminu_vx)))
vuint64m4_t vminu(vuint64m4_t, uint64_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vminu_vx_m)))
vuint64m4_t vminu(vbool16_t, vuint64m4_t, vuint64m4_t, uint64_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vminu_vx)))
vuint64m8_t vminu(vuint64m8_t, uint64_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vminu_vx_m)))
vuint64m8_t vminu(vbool8_t, vuint64m8_t, vuint64m8_t, uint64_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vmin_vv)))
vint64m1_t vmin(vint64m1_t, vint64m1_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vmin_vv_m)))
vint64m1_t vmin(vbool64_t, vint64m1_t, vint64m1_t, vint64m1_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vmin_vv)))
vint64m2_t vmin(vint64m2_t, vint64m2_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vmin_vv_m)))
vint64m2_t vmin(vbool32_t, vint64m2_t, vint64m2_t, vint64m2_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vmin_vv)))
vint64m4_t vmin(vint64m4_t, vint64m4_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vmin_vv_m)))
vint64m4_t vmin(vbool16_t, vint64m4_t, vint64m4_t, vint64m4_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vmin_vv)))
vint64m8_t vmin(vint64m8_t, vint64m8_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vmin_vv_m)))
vint64m8_t vmin(vbool8_t, vint64m8_t, vint64m8_t, vint64m8_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vmin_vx)))
vint64m1_t vmin(vint64m1_t, int64_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vmin_vx_m)))
vint64m1_t vmin(vbool64_t, vint64m1_t, vint64m1_t, int64_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vmin_vx)))
vint64m2_t vmin(vint64m2_t, int64_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vmin_vx_m)))
vint64m2_t vmin(vbool32_t, vint64m2_t, vint64m2_t, int64_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vmin_vx)))
vint64m4_t vmin(vint64m4_t, int64_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vmin_vx_m)))
vint64m4_t vmin(vbool16_t, vint64m4_t, vint64m4_t, int64_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vmin_vx)))
vint64m8_t vmin(vint64m8_t, int64_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vmin_vx_m)))
vint64m8_t vmin(vbool8_t, vint64m8_t, vint64m8_t, int64_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vmaxu_vv)))
vuint64m1_t vmaxu(vuint64m1_t, vuint64m1_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vmaxu_vv_m)))
vuint64m1_t vmaxu(vbool64_t, vuint64m1_t, vuint64m1_t, vuint64m1_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vmaxu_vv)))
vuint64m2_t vmaxu(vuint64m2_t, vuint64m2_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vmaxu_vv_m)))
vuint64m2_t vmaxu(vbool32_t, vuint64m2_t, vuint64m2_t, vuint64m2_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vmaxu_vv)))
vuint64m4_t vmaxu(vuint64m4_t, vuint64m4_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vmaxu_vv_m)))
vuint64m4_t vmaxu(vbool16_t, vuint64m4_t, vuint64m4_t, vuint64m4_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vmaxu_vv)))
vuint64m8_t vmaxu(vuint64m8_t, vuint64m8_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vmaxu_vv_m)))
vuint64m8_t vmaxu(vbool8_t, vuint64m8_t, vuint64m8_t, vuint64m8_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vmaxu_vx)))
vuint64m1_t vmaxu(vuint64m1_t, uint64_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vmaxu_vx_m)))
vuint64m1_t vmaxu(vbool64_t, vuint64m1_t, vuint64m1_t, uint64_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vmaxu_vx)))
vuint64m2_t vmaxu(vuint64m2_t, uint64_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vmaxu_vx_m)))
vuint64m2_t vmaxu(vbool32_t, vuint64m2_t, vuint64m2_t, uint64_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vmaxu_vx)))
vuint64m4_t vmaxu(vuint64m4_t, uint64_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vmaxu_vx_m)))
vuint64m4_t vmaxu(vbool16_t, vuint64m4_t, vuint64m4_t, uint64_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vmaxu_vx)))
vuint64m8_t vmaxu(vuint64m8_t, uint64_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vmaxu_vx_m)))
vuint64m8_t vmaxu(vbool8_t, vuint64m8_t, vuint64m8_t, uint64_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vmax_vv)))
vint64m1_t vmax(vint64m1_t, vint64m1_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vmax_vv_m)))
vint64m1_t vmax(vbool64_t, vint64m1_t, vint64m1_t, vint64m1_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vmax_vv)))
vint64m2_t vmax(vint64m2_t, vint64m2_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vmax_vv_m)))
vint64m2_t vmax(vbool32_t, vint64m2_t, vint64m2_t, vint64m2_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vmax_vv)))
vint64m4_t vmax(vint64m4_t, vint64m4_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vmax_vv_m)))
vint64m4_t vmax(vbool16_t, vint64m4_t, vint64m4_t, vint64m4_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vmax_vv)))
vint64m8_t vmax(vint64m8_t, vint64m8_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vmax_vv_m)))
vint64m8_t vmax(vbool8_t, vint64m8_t, vint64m8_t, vint64m8_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vmax_vx)))
vint64m1_t vmax(vint64m1_t, int64_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vmax_vx_m)))
vint64m1_t vmax(vbool64_t, vint64m1_t, vint64m1_t, int64_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vmax_vx)))
vint64m2_t vmax(vint64m2_t, int64_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vmax_vx_m)))
vint64m2_t vmax(vbool32_t, vint64m2_t, vint64m2_t, int64_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vmax_vx)))
vint64m4_t vmax(vint64m4_t, int64_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vmax_vx_m)))
vint64m4_t vmax(vbool16_t, vint64m4_t, vint64m4_t, int64_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vmax_vx)))
vint64m8_t vmax(vint64m8_t, int64_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vmax_vx_m)))
vint64m8_t vmax(vbool8_t, vint64m8_t, vint64m8_t, int64_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vmul_vv)))
vint64m1_t vmul(vint64m1_t, vint64m1_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vmul_vv_m)))
vint64m1_t vmul(vbool64_t, vint64m1_t, vint64m1_t, vint64m1_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vmul_vv)))
vint64m2_t vmul(vint64m2_t, vint64m2_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vmul_vv_m)))
vint64m2_t vmul(vbool32_t, vint64m2_t, vint64m2_t, vint64m2_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vmul_vv)))
vint64m4_t vmul(vint64m4_t, vint64m4_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vmul_vv_m)))
vint64m4_t vmul(vbool16_t, vint64m4_t, vint64m4_t, vint64m4_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vmul_vv)))
vint64m8_t vmul(vint64m8_t, vint64m8_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vmul_vv_m)))
vint64m8_t vmul(vbool8_t, vint64m8_t, vint64m8_t, vint64m8_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vmul_vx)))
vint64m1_t vmul(vint64m1_t, int64_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vmul_vx_m)))
vint64m1_t vmul(vbool64_t, vint64m1_t, vint64m1_t, int64_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vmul_vx)))
vint64m2_t vmul(vint64m2_t, int64_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vmul_vx_m)))
vint64m2_t vmul(vbool32_t, vint64m2_t, vint64m2_t, int64_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vmul_vx)))
vint64m4_t vmul(vint64m4_t, int64_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vmul_vx_m)))
vint64m4_t vmul(vbool16_t, vint64m4_t, vint64m4_t, int64_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vmul_vx)))
vint64m8_t vmul(vint64m8_t, int64_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vmul_vx_m)))
vint64m8_t vmul(vbool8_t, vint64m8_t, vint64m8_t, int64_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vmul_vv)))
vuint64m1_t vmul(vuint64m1_t, vuint64m1_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vmul_vv_m)))
vuint64m1_t vmul(vbool64_t, vuint64m1_t, vuint64m1_t, vuint64m1_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vmul_vv)))
vuint64m2_t vmul(vuint64m2_t, vuint64m2_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vmul_vv_m)))
vuint64m2_t vmul(vbool32_t, vuint64m2_t, vuint64m2_t, vuint64m2_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vmul_vv)))
vuint64m4_t vmul(vuint64m4_t, vuint64m4_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vmul_vv_m)))
vuint64m4_t vmul(vbool16_t, vuint64m4_t, vuint64m4_t, vuint64m4_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vmul_vv)))
vuint64m8_t vmul(vuint64m8_t, vuint64m8_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vmul_vv_m)))
vuint64m8_t vmul(vbool8_t, vuint64m8_t, vuint64m8_t, vuint64m8_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vmul_vx)))
vuint64m1_t vmul(vuint64m1_t, uint64_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vmul_vx_m)))
vuint64m1_t vmul(vbool64_t, vuint64m1_t, vuint64m1_t, uint64_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vmul_vx)))
vuint64m2_t vmul(vuint64m2_t, uint64_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vmul_vx_m)))
vuint64m2_t vmul(vbool32_t, vuint64m2_t, vuint64m2_t, uint64_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vmul_vx)))
vuint64m4_t vmul(vuint64m4_t, uint64_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vmul_vx_m)))
vuint64m4_t vmul(vbool16_t, vuint64m4_t, vuint64m4_t, uint64_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vmul_vx)))
vuint64m8_t vmul(vuint64m8_t, uint64_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vmul_vx_m)))
vuint64m8_t vmul(vbool8_t, vuint64m8_t, vuint64m8_t, uint64_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vdivu_vv)))
vuint64m1_t vdivu(vuint64m1_t, vuint64m1_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vdivu_vv_m)))
vuint64m1_t vdivu(vbool64_t, vuint64m1_t, vuint64m1_t, vuint64m1_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vdivu_vv)))
vuint64m2_t vdivu(vuint64m2_t, vuint64m2_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vdivu_vv_m)))
vuint64m2_t vdivu(vbool32_t, vuint64m2_t, vuint64m2_t, vuint64m2_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vdivu_vv)))
vuint64m4_t vdivu(vuint64m4_t, vuint64m4_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vdivu_vv_m)))
vuint64m4_t vdivu(vbool16_t, vuint64m4_t, vuint64m4_t, vuint64m4_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vdivu_vv)))
vuint64m8_t vdivu(vuint64m8_t, vuint64m8_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vdivu_vv_m)))
vuint64m8_t vdivu(vbool8_t, vuint64m8_t, vuint64m8_t, vuint64m8_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vdivu_vx)))
vuint64m1_t vdivu(vuint64m1_t, uint64_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vdivu_vx_m)))
vuint64m1_t vdivu(vbool64_t, vuint64m1_t, vuint64m1_t, uint64_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vdivu_vx)))
vuint64m2_t vdivu(vuint64m2_t, uint64_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vdivu_vx_m)))
vuint64m2_t vdivu(vbool32_t, vuint64m2_t, vuint64m2_t, uint64_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vdivu_vx)))
vuint64m4_t vdivu(vuint64m4_t, uint64_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vdivu_vx_m)))
vuint64m4_t vdivu(vbool16_t, vuint64m4_t, vuint64m4_t, uint64_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vdivu_vx)))
vuint64m8_t vdivu(vuint64m8_t, uint64_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vdivu_vx_m)))
vuint64m8_t vdivu(vbool8_t, vuint64m8_t, vuint64m8_t, uint64_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vdiv_vv)))
vint64m1_t vdiv(vint64m1_t, vint64m1_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vdiv_vv_m)))
vint64m1_t vdiv(vbool64_t, vint64m1_t, vint64m1_t, vint64m1_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vdiv_vv)))
vint64m2_t vdiv(vint64m2_t, vint64m2_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vdiv_vv_m)))
vint64m2_t vdiv(vbool32_t, vint64m2_t, vint64m2_t, vint64m2_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vdiv_vv)))
vint64m4_t vdiv(vint64m4_t, vint64m4_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vdiv_vv_m)))
vint64m4_t vdiv(vbool16_t, vint64m4_t, vint64m4_t, vint64m4_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vdiv_vv)))
vint64m8_t vdiv(vint64m8_t, vint64m8_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vdiv_vv_m)))
vint64m8_t vdiv(vbool8_t, vint64m8_t, vint64m8_t, vint64m8_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vdiv_vx)))
vint64m1_t vdiv(vint64m1_t, int64_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vdiv_vx_m)))
vint64m1_t vdiv(vbool64_t, vint64m1_t, vint64m1_t, int64_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vdiv_vx)))
vint64m2_t vdiv(vint64m2_t, int64_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vdiv_vx_m)))
vint64m2_t vdiv(vbool32_t, vint64m2_t, vint64m2_t, int64_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vdiv_vx)))
vint64m4_t vdiv(vint64m4_t, int64_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vdiv_vx_m)))
vint64m4_t vdiv(vbool16_t, vint64m4_t, vint64m4_t, int64_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vdiv_vx)))
vint64m8_t vdiv(vint64m8_t, int64_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vdiv_vx_m)))
vint64m8_t vdiv(vbool8_t, vint64m8_t, vint64m8_t, int64_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vremu_vv)))
vuint64m1_t vremu(vuint64m1_t, vuint64m1_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vremu_vv_m)))
vuint64m1_t vremu(vbool64_t, vuint64m1_t, vuint64m1_t, vuint64m1_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vremu_vv)))
vuint64m2_t vremu(vuint64m2_t, vuint64m2_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vremu_vv_m)))
vuint64m2_t vremu(vbool32_t, vuint64m2_t, vuint64m2_t, vuint64m2_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vremu_vv)))
vuint64m4_t vremu(vuint64m4_t, vuint64m4_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vremu_vv_m)))
vuint64m4_t vremu(vbool16_t, vuint64m4_t, vuint64m4_t, vuint64m4_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vremu_vv)))
vuint64m8_t vremu(vuint64m8_t, vuint64m8_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vremu_vv_m)))
vuint64m8_t vremu(vbool8_t, vuint64m8_t, vuint64m8_t, vuint64m8_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vremu_vx)))
vuint64m1_t vremu(vuint64m1_t, uint64_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vremu_vx_m)))
vuint64m1_t vremu(vbool64_t, vuint64m1_t, vuint64m1_t, uint64_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vremu_vx)))
vuint64m2_t vremu(vuint64m2_t, uint64_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vremu_vx_m)))
vuint64m2_t vremu(vbool32_t, vuint64m2_t, vuint64m2_t, uint64_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vremu_vx)))
vuint64m4_t vremu(vuint64m4_t, uint64_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vremu_vx_m)))
vuint64m4_t vremu(vbool16_t, vuint64m4_t, vuint64m4_t, uint64_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vremu_vx)))
vuint64m8_t vremu(vuint64m8_t, uint64_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vremu_vx_m)))
vuint64m8_t vremu(vbool8_t, vuint64m8_t, vuint64m8_t, uint64_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vrem_vv)))
vint64m1_t vrem(vint64m1_t, vint64m1_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vrem_vv_m)))
vint64m1_t vrem(vbool64_t, vint64m1_t, vint64m1_t, vint64m1_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vrem_vv)))
vint64m2_t vrem(vint64m2_t, vint64m2_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vrem_vv_m)))
vint64m2_t vrem(vbool32_t, vint64m2_t, vint64m2_t, vint64m2_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vrem_vv)))
vint64m4_t vrem(vint64m4_t, vint64m4_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vrem_vv_m)))
vint64m4_t vrem(vbool16_t, vint64m4_t, vint64m4_t, vint64m4_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vrem_vv)))
vint64m8_t vrem(vint64m8_t, vint64m8_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vrem_vv_m)))
vint64m8_t vrem(vbool8_t, vint64m8_t, vint64m8_t, vint64m8_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vrem_vx)))
vint64m1_t vrem(vint64m1_t, int64_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vrem_vx_m)))
vint64m1_t vrem(vbool64_t, vint64m1_t, vint64m1_t, int64_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vrem_vx)))
vint64m2_t vrem(vint64m2_t, int64_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vrem_vx_m)))
vint64m2_t vrem(vbool32_t, vint64m2_t, vint64m2_t, int64_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vrem_vx)))
vint64m4_t vrem(vint64m4_t, int64_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vrem_vx_m)))
vint64m4_t vrem(vbool16_t, vint64m4_t, vint64m4_t, int64_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vrem_vx)))
vint64m8_t vrem(vint64m8_t, int64_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vrem_vx_m)))
vint64m8_t vrem(vbool8_t, vint64m8_t, vint64m8_t, int64_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vwmul_vv)))
vint64m1_t vwmul(vint32mf2_t, vint32mf2_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vwmul_vv_m)))
vint64m1_t vwmul(vbool64_t, vint64m1_t, vint32mf2_t, vint32mf2_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vwmul_vv)))
vint64m2_t vwmul(vint32m1_t, vint32m1_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vwmul_vv_m)))
vint64m2_t vwmul(vbool32_t, vint64m2_t, vint32m1_t, vint32m1_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vwmul_vv)))
vint64m4_t vwmul(vint32m2_t, vint32m2_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vwmul_vv_m)))
vint64m4_t vwmul(vbool16_t, vint64m4_t, vint32m2_t, vint32m2_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vwmul_vv)))
vint64m8_t vwmul(vint32m4_t, vint32m4_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vwmul_vv_m)))
vint64m8_t vwmul(vbool8_t, vint64m8_t, vint32m4_t, vint32m4_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vwmul_vx)))
vint64m1_t vwmul(vint32mf2_t, int32_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vwmul_vx_m)))
vint64m1_t vwmul(vbool64_t, vint64m1_t, vint32mf2_t, int32_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vwmul_vx)))
vint64m2_t vwmul(vint32m1_t, int32_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vwmul_vx_m)))
vint64m2_t vwmul(vbool32_t, vint64m2_t, vint32m1_t, int32_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vwmul_vx)))
vint64m4_t vwmul(vint32m2_t, int32_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vwmul_vx_m)))
vint64m4_t vwmul(vbool16_t, vint64m4_t, vint32m2_t, int32_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vwmul_vx)))
vint64m8_t vwmul(vint32m4_t, int32_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vwmul_vx_m)))
vint64m8_t vwmul(vbool8_t, vint64m8_t, vint32m4_t, int32_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vwmulu_vv)))
vuint64m1_t vwmulu(vuint32mf2_t, vuint32mf2_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vwmulu_vv_m)))
vuint64m1_t vwmulu(vbool64_t, vuint64m1_t, vuint32mf2_t, vuint32mf2_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vwmulu_vv)))
vuint64m2_t vwmulu(vuint32m1_t, vuint32m1_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vwmulu_vv_m)))
vuint64m2_t vwmulu(vbool32_t, vuint64m2_t, vuint32m1_t, vuint32m1_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vwmulu_vv)))
vuint64m4_t vwmulu(vuint32m2_t, vuint32m2_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vwmulu_vv_m)))
vuint64m4_t vwmulu(vbool16_t, vuint64m4_t, vuint32m2_t, vuint32m2_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vwmulu_vv)))
vuint64m8_t vwmulu(vuint32m4_t, vuint32m4_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vwmulu_vv_m)))
vuint64m8_t vwmulu(vbool8_t, vuint64m8_t, vuint32m4_t, vuint32m4_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vwmulu_vx)))
vuint64m1_t vwmulu(vuint32mf2_t, uint32_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vwmulu_vx_m)))
vuint64m1_t vwmulu(vbool64_t, vuint64m1_t, vuint32mf2_t, uint32_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vwmulu_vx)))
vuint64m2_t vwmulu(vuint32m1_t, uint32_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vwmulu_vx_m)))
vuint64m2_t vwmulu(vbool32_t, vuint64m2_t, vuint32m1_t, uint32_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vwmulu_vx)))
vuint64m4_t vwmulu(vuint32m2_t, uint32_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vwmulu_vx_m)))
vuint64m4_t vwmulu(vbool16_t, vuint64m4_t, vuint32m2_t, uint32_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vwmulu_vx)))
vuint64m8_t vwmulu(vuint32m4_t, uint32_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vwmulu_vx_m)))
vuint64m8_t vwmulu(vbool8_t, vuint64m8_t, vuint32m4_t, uint32_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vwmulsu_vv)))
vint64m1_t vwmulsu(vint32mf2_t, vuint32mf2_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vwmulsu_vv_m)))
vint64m1_t vwmulsu(vbool64_t, vint64m1_t, vint32mf2_t, vuint32mf2_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vwmulsu_vv)))
vint64m2_t vwmulsu(vint32m1_t, vuint32m1_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vwmulsu_vv_m)))
vint64m2_t vwmulsu(vbool32_t, vint64m2_t, vint32m1_t, vuint32m1_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vwmulsu_vv)))
vint64m4_t vwmulsu(vint32m2_t, vuint32m2_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vwmulsu_vv_m)))
vint64m4_t vwmulsu(vbool16_t, vint64m4_t, vint32m2_t, vuint32m2_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vwmulsu_vv)))
vint64m8_t vwmulsu(vint32m4_t, vuint32m4_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vwmulsu_vv_m)))
vint64m8_t vwmulsu(vbool8_t, vint64m8_t, vint32m4_t, vuint32m4_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vwmulsu_vx)))
vint64m1_t vwmulsu(vint32mf2_t, uint32_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vwmulsu_vx_m)))
vint64m1_t vwmulsu(vbool64_t, vint64m1_t, vint32mf2_t, uint32_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vwmulsu_vx)))
vint64m2_t vwmulsu(vint32m1_t, uint32_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vwmulsu_vx_m)))
vint64m2_t vwmulsu(vbool32_t, vint64m2_t, vint32m1_t, uint32_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vwmulsu_vx)))
vint64m4_t vwmulsu(vint32m2_t, uint32_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vwmulsu_vx_m)))
vint64m4_t vwmulsu(vbool16_t, vint64m4_t, vint32m2_t, uint32_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vwmulsu_vx)))
vint64m8_t vwmulsu(vint32m4_t, uint32_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vwmulsu_vx_m)))
vint64m8_t vwmulsu(vbool8_t, vint64m8_t, vint32m4_t, uint32_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vmacc_vv)))
vint64m1_t vmacc(vint64m1_t, vint64m1_t, vint64m1_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vmacc_vv_m)))
vint64m1_t vmacc(vbool64_t, vint64m1_t, vint64m1_t, vint64m1_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vmacc_vv)))
vint64m2_t vmacc(vint64m2_t, vint64m2_t, vint64m2_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vmacc_vv_m)))
vint64m2_t vmacc(vbool32_t, vint64m2_t, vint64m2_t, vint64m2_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vmacc_vv)))
vint64m4_t vmacc(vint64m4_t, vint64m4_t, vint64m4_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vmacc_vv_m)))
vint64m4_t vmacc(vbool16_t, vint64m4_t, vint64m4_t, vint64m4_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vmacc_vv)))
vint64m8_t vmacc(vint64m8_t, vint64m8_t, vint64m8_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vmacc_vv_m)))
vint64m8_t vmacc(vbool8_t, vint64m8_t, vint64m8_t, vint64m8_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vmacc_vx)))
vint64m1_t vmacc(vint64m1_t, int64_t, vint64m1_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vmacc_vx_m)))
vint64m1_t vmacc(vbool64_t, vint64m1_t, int64_t, vint64m1_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vmacc_vx)))
vint64m2_t vmacc(vint64m2_t, int64_t, vint64m2_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vmacc_vx_m)))
vint64m2_t vmacc(vbool32_t, vint64m2_t, int64_t, vint64m2_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vmacc_vx)))
vint64m4_t vmacc(vint64m4_t, int64_t, vint64m4_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vmacc_vx_m)))
vint64m4_t vmacc(vbool16_t, vint64m4_t, int64_t, vint64m4_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vmacc_vx)))
vint64m8_t vmacc(vint64m8_t, int64_t, vint64m8_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vmacc_vx_m)))
vint64m8_t vmacc(vbool8_t, vint64m8_t, int64_t, vint64m8_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vmacc_vv)))
vuint64m1_t vmacc(vuint64m1_t, vuint64m1_t, vuint64m1_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vmacc_vv_m)))
vuint64m1_t vmacc(vbool64_t, vuint64m1_t, vuint64m1_t, vuint64m1_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vmacc_vv)))
vuint64m2_t vmacc(vuint64m2_t, vuint64m2_t, vuint64m2_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vmacc_vv_m)))
vuint64m2_t vmacc(vbool32_t, vuint64m2_t, vuint64m2_t, vuint64m2_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vmacc_vv)))
vuint64m4_t vmacc(vuint64m4_t, vuint64m4_t, vuint64m4_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vmacc_vv_m)))
vuint64m4_t vmacc(vbool16_t, vuint64m4_t, vuint64m4_t, vuint64m4_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vmacc_vv)))
vuint64m8_t vmacc(vuint64m8_t, vuint64m8_t, vuint64m8_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vmacc_vv_m)))
vuint64m8_t vmacc(vbool8_t, vuint64m8_t, vuint64m8_t, vuint64m8_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vmacc_vx)))
vuint64m1_t vmacc(vuint64m1_t, uint64_t, vuint64m1_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vmacc_vx_m)))
vuint64m1_t vmacc(vbool64_t, vuint64m1_t, uint64_t, vuint64m1_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vmacc_vx)))
vuint64m2_t vmacc(vuint64m2_t, uint64_t, vuint64m2_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vmacc_vx_m)))
vuint64m2_t vmacc(vbool32_t, vuint64m2_t, uint64_t, vuint64m2_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vmacc_vx)))
vuint64m4_t vmacc(vuint64m4_t, uint64_t, vuint64m4_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vmacc_vx_m)))
vuint64m4_t vmacc(vbool16_t, vuint64m4_t, uint64_t, vuint64m4_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vmacc_vx)))
vuint64m8_t vmacc(vuint64m8_t, uint64_t, vuint64m8_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vmacc_vx_m)))
vuint64m8_t vmacc(vbool8_t, vuint64m8_t, uint64_t, vuint64m8_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vnmsac_vv)))
vint64m1_t vnmsac(vint64m1_t, vint64m1_t, vint64m1_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vnmsac_vv_m)))
vint64m1_t vnmsac(vbool64_t, vint64m1_t, vint64m1_t, vint64m1_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vnmsac_vv)))
vint64m2_t vnmsac(vint64m2_t, vint64m2_t, vint64m2_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vnmsac_vv_m)))
vint64m2_t vnmsac(vbool32_t, vint64m2_t, vint64m2_t, vint64m2_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vnmsac_vv)))
vint64m4_t vnmsac(vint64m4_t, vint64m4_t, vint64m4_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vnmsac_vv_m)))
vint64m4_t vnmsac(vbool16_t, vint64m4_t, vint64m4_t, vint64m4_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vnmsac_vv)))
vint64m8_t vnmsac(vint64m8_t, vint64m8_t, vint64m8_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vnmsac_vv_m)))
vint64m8_t vnmsac(vbool8_t, vint64m8_t, vint64m8_t, vint64m8_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vnmsac_vx)))
vint64m1_t vnmsac(vint64m1_t, int64_t, vint64m1_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vnmsac_vx_m)))
vint64m1_t vnmsac(vbool64_t, vint64m1_t, int64_t, vint64m1_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vnmsac_vx)))
vint64m2_t vnmsac(vint64m2_t, int64_t, vint64m2_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vnmsac_vx_m)))
vint64m2_t vnmsac(vbool32_t, vint64m2_t, int64_t, vint64m2_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vnmsac_vx)))
vint64m4_t vnmsac(vint64m4_t, int64_t, vint64m4_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vnmsac_vx_m)))
vint64m4_t vnmsac(vbool16_t, vint64m4_t, int64_t, vint64m4_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vnmsac_vx)))
vint64m8_t vnmsac(vint64m8_t, int64_t, vint64m8_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vnmsac_vx_m)))
vint64m8_t vnmsac(vbool8_t, vint64m8_t, int64_t, vint64m8_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vnmsac_vv)))
vuint64m1_t vnmsac(vuint64m1_t, vuint64m1_t, vuint64m1_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vnmsac_vv_m)))
vuint64m1_t vnmsac(vbool64_t, vuint64m1_t, vuint64m1_t, vuint64m1_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vnmsac_vv)))
vuint64m2_t vnmsac(vuint64m2_t, vuint64m2_t, vuint64m2_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vnmsac_vv_m)))
vuint64m2_t vnmsac(vbool32_t, vuint64m2_t, vuint64m2_t, vuint64m2_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vnmsac_vv)))
vuint64m4_t vnmsac(vuint64m4_t, vuint64m4_t, vuint64m4_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vnmsac_vv_m)))
vuint64m4_t vnmsac(vbool16_t, vuint64m4_t, vuint64m4_t, vuint64m4_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vnmsac_vv)))
vuint64m8_t vnmsac(vuint64m8_t, vuint64m8_t, vuint64m8_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vnmsac_vv_m)))
vuint64m8_t vnmsac(vbool8_t, vuint64m8_t, vuint64m8_t, vuint64m8_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vnmsac_vx)))
vuint64m1_t vnmsac(vuint64m1_t, uint64_t, vuint64m1_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vnmsac_vx_m)))
vuint64m1_t vnmsac(vbool64_t, vuint64m1_t, uint64_t, vuint64m1_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vnmsac_vx)))
vuint64m2_t vnmsac(vuint64m2_t, uint64_t, vuint64m2_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vnmsac_vx_m)))
vuint64m2_t vnmsac(vbool32_t, vuint64m2_t, uint64_t, vuint64m2_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vnmsac_vx)))
vuint64m4_t vnmsac(vuint64m4_t, uint64_t, vuint64m4_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vnmsac_vx_m)))
vuint64m4_t vnmsac(vbool16_t, vuint64m4_t, uint64_t, vuint64m4_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vnmsac_vx)))
vuint64m8_t vnmsac(vuint64m8_t, uint64_t, vuint64m8_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vnmsac_vx_m)))
vuint64m8_t vnmsac(vbool8_t, vuint64m8_t, uint64_t, vuint64m8_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vmadd_vv)))
vint64m1_t vmadd(vint64m1_t, vint64m1_t, vint64m1_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vmadd_vv_m)))
vint64m1_t vmadd(vbool64_t, vint64m1_t, vint64m1_t, vint64m1_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vmadd_vv)))
vint64m2_t vmadd(vint64m2_t, vint64m2_t, vint64m2_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vmadd_vv_m)))
vint64m2_t vmadd(vbool32_t, vint64m2_t, vint64m2_t, vint64m2_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vmadd_vv)))
vint64m4_t vmadd(vint64m4_t, vint64m4_t, vint64m4_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vmadd_vv_m)))
vint64m4_t vmadd(vbool16_t, vint64m4_t, vint64m4_t, vint64m4_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vmadd_vv)))
vint64m8_t vmadd(vint64m8_t, vint64m8_t, vint64m8_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vmadd_vv_m)))
vint64m8_t vmadd(vbool8_t, vint64m8_t, vint64m8_t, vint64m8_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vmadd_vx)))
vint64m1_t vmadd(vint64m1_t, int64_t, vint64m1_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vmadd_vx_m)))
vint64m1_t vmadd(vbool64_t, vint64m1_t, int64_t, vint64m1_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vmadd_vx)))
vint64m2_t vmadd(vint64m2_t, int64_t, vint64m2_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vmadd_vx_m)))
vint64m2_t vmadd(vbool32_t, vint64m2_t, int64_t, vint64m2_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vmadd_vx)))
vint64m4_t vmadd(vint64m4_t, int64_t, vint64m4_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vmadd_vx_m)))
vint64m4_t vmadd(vbool16_t, vint64m4_t, int64_t, vint64m4_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vmadd_vx)))
vint64m8_t vmadd(vint64m8_t, int64_t, vint64m8_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vmadd_vx_m)))
vint64m8_t vmadd(vbool8_t, vint64m8_t, int64_t, vint64m8_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vmadd_vv)))
vuint64m1_t vmadd(vuint64m1_t, vuint64m1_t, vuint64m1_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vmadd_vv_m)))
vuint64m1_t vmadd(vbool64_t, vuint64m1_t, vuint64m1_t, vuint64m1_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vmadd_vv)))
vuint64m2_t vmadd(vuint64m2_t, vuint64m2_t, vuint64m2_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vmadd_vv_m)))
vuint64m2_t vmadd(vbool32_t, vuint64m2_t, vuint64m2_t, vuint64m2_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vmadd_vv)))
vuint64m4_t vmadd(vuint64m4_t, vuint64m4_t, vuint64m4_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vmadd_vv_m)))
vuint64m4_t vmadd(vbool16_t, vuint64m4_t, vuint64m4_t, vuint64m4_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vmadd_vv)))
vuint64m8_t vmadd(vuint64m8_t, vuint64m8_t, vuint64m8_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vmadd_vv_m)))
vuint64m8_t vmadd(vbool8_t, vuint64m8_t, vuint64m8_t, vuint64m8_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vmadd_vx)))
vuint64m1_t vmadd(vuint64m1_t, uint64_t, vuint64m1_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vmadd_vx_m)))
vuint64m1_t vmadd(vbool64_t, vuint64m1_t, uint64_t, vuint64m1_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vmadd_vx)))
vuint64m2_t vmadd(vuint64m2_t, uint64_t, vuint64m2_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vmadd_vx_m)))
vuint64m2_t vmadd(vbool32_t, vuint64m2_t, uint64_t, vuint64m2_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vmadd_vx)))
vuint64m4_t vmadd(vuint64m4_t, uint64_t, vuint64m4_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vmadd_vx_m)))
vuint64m4_t vmadd(vbool16_t, vuint64m4_t, uint64_t, vuint64m4_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vmadd_vx)))
vuint64m8_t vmadd(vuint64m8_t, uint64_t, vuint64m8_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vmadd_vx_m)))
vuint64m8_t vmadd(vbool8_t, vuint64m8_t, uint64_t, vuint64m8_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vnmsub_vv)))
vint64m1_t vnmsub(vint64m1_t, vint64m1_t, vint64m1_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vnmsub_vv_m)))
vint64m1_t vnmsub(vbool64_t, vint64m1_t, vint64m1_t, vint64m1_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vnmsub_vv)))
vint64m2_t vnmsub(vint64m2_t, vint64m2_t, vint64m2_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vnmsub_vv_m)))
vint64m2_t vnmsub(vbool32_t, vint64m2_t, vint64m2_t, vint64m2_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vnmsub_vv)))
vint64m4_t vnmsub(vint64m4_t, vint64m4_t, vint64m4_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vnmsub_vv_m)))
vint64m4_t vnmsub(vbool16_t, vint64m4_t, vint64m4_t, vint64m4_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vnmsub_vv)))
vint64m8_t vnmsub(vint64m8_t, vint64m8_t, vint64m8_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vnmsub_vv_m)))
vint64m8_t vnmsub(vbool8_t, vint64m8_t, vint64m8_t, vint64m8_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vnmsub_vx)))
vint64m1_t vnmsub(vint64m1_t, int64_t, vint64m1_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vnmsub_vx_m)))
vint64m1_t vnmsub(vbool64_t, vint64m1_t, int64_t, vint64m1_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vnmsub_vx)))
vint64m2_t vnmsub(vint64m2_t, int64_t, vint64m2_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vnmsub_vx_m)))
vint64m2_t vnmsub(vbool32_t, vint64m2_t, int64_t, vint64m2_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vnmsub_vx)))
vint64m4_t vnmsub(vint64m4_t, int64_t, vint64m4_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vnmsub_vx_m)))
vint64m4_t vnmsub(vbool16_t, vint64m4_t, int64_t, vint64m4_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vnmsub_vx)))
vint64m8_t vnmsub(vint64m8_t, int64_t, vint64m8_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vnmsub_vx_m)))
vint64m8_t vnmsub(vbool8_t, vint64m8_t, int64_t, vint64m8_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vnmsub_vv)))
vuint64m1_t vnmsub(vuint64m1_t, vuint64m1_t, vuint64m1_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vnmsub_vv_m)))
vuint64m1_t vnmsub(vbool64_t, vuint64m1_t, vuint64m1_t, vuint64m1_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vnmsub_vv)))
vuint64m2_t vnmsub(vuint64m2_t, vuint64m2_t, vuint64m2_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vnmsub_vv_m)))
vuint64m2_t vnmsub(vbool32_t, vuint64m2_t, vuint64m2_t, vuint64m2_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vnmsub_vv)))
vuint64m4_t vnmsub(vuint64m4_t, vuint64m4_t, vuint64m4_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vnmsub_vv_m)))
vuint64m4_t vnmsub(vbool16_t, vuint64m4_t, vuint64m4_t, vuint64m4_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vnmsub_vv)))
vuint64m8_t vnmsub(vuint64m8_t, vuint64m8_t, vuint64m8_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vnmsub_vv_m)))
vuint64m8_t vnmsub(vbool8_t, vuint64m8_t, vuint64m8_t, vuint64m8_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vnmsub_vx)))
vuint64m1_t vnmsub(vuint64m1_t, uint64_t, vuint64m1_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vnmsub_vx_m)))
vuint64m1_t vnmsub(vbool64_t, vuint64m1_t, uint64_t, vuint64m1_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vnmsub_vx)))
vuint64m2_t vnmsub(vuint64m2_t, uint64_t, vuint64m2_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vnmsub_vx_m)))
vuint64m2_t vnmsub(vbool32_t, vuint64m2_t, uint64_t, vuint64m2_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vnmsub_vx)))
vuint64m4_t vnmsub(vuint64m4_t, uint64_t, vuint64m4_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vnmsub_vx_m)))
vuint64m4_t vnmsub(vbool16_t, vuint64m4_t, uint64_t, vuint64m4_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vnmsub_vx)))
vuint64m8_t vnmsub(vuint64m8_t, uint64_t, vuint64m8_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vnmsub_vx_m)))
vuint64m8_t vnmsub(vbool8_t, vuint64m8_t, uint64_t, vuint64m8_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vwmaccu_vv)))
vuint64m1_t vwmaccu(vuint64m1_t, vuint32mf2_t, vuint32mf2_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vwmaccu_vv_m)))
vuint64m1_t vwmaccu(vbool64_t, vuint64m1_t, vuint32mf2_t, vuint32mf2_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vwmaccu_vv)))
vuint64m2_t vwmaccu(vuint64m2_t, vuint32m1_t, vuint32m1_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vwmaccu_vv_m)))
vuint64m2_t vwmaccu(vbool32_t, vuint64m2_t, vuint32m1_t, vuint32m1_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vwmaccu_vv)))
vuint64m4_t vwmaccu(vuint64m4_t, vuint32m2_t, vuint32m2_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vwmaccu_vv_m)))
vuint64m4_t vwmaccu(vbool16_t, vuint64m4_t, vuint32m2_t, vuint32m2_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vwmaccu_vv)))
vuint64m8_t vwmaccu(vuint64m8_t, vuint32m4_t, vuint32m4_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vwmaccu_vv_m)))
vuint64m8_t vwmaccu(vbool8_t, vuint64m8_t, vuint32m4_t, vuint32m4_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vwmaccu_vx)))
vuint64m1_t vwmaccu(vuint64m1_t, uint32_t, vuint32mf2_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vwmaccu_vx_m)))
vuint64m1_t vwmaccu(vbool64_t, vuint64m1_t, uint32_t, vuint32mf2_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vwmaccu_vx)))
vuint64m2_t vwmaccu(vuint64m2_t, uint32_t, vuint32m1_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vwmaccu_vx_m)))
vuint64m2_t vwmaccu(vbool32_t, vuint64m2_t, uint32_t, vuint32m1_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vwmaccu_vx)))
vuint64m4_t vwmaccu(vuint64m4_t, uint32_t, vuint32m2_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vwmaccu_vx_m)))
vuint64m4_t vwmaccu(vbool16_t, vuint64m4_t, uint32_t, vuint32m2_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vwmaccu_vx)))
vuint64m8_t vwmaccu(vuint64m8_t, uint32_t, vuint32m4_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vwmaccu_vx_m)))
vuint64m8_t vwmaccu(vbool8_t, vuint64m8_t, uint32_t, vuint32m4_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vwmacc_vv)))
vint64m1_t vwmacc(vint64m1_t, vint32mf2_t, vint32mf2_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vwmacc_vv_m)))
vint64m1_t vwmacc(vbool64_t, vint64m1_t, vint32mf2_t, vint32mf2_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vwmacc_vv)))
vint64m2_t vwmacc(vint64m2_t, vint32m1_t, vint32m1_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vwmacc_vv_m)))
vint64m2_t vwmacc(vbool32_t, vint64m2_t, vint32m1_t, vint32m1_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vwmacc_vv)))
vint64m4_t vwmacc(vint64m4_t, vint32m2_t, vint32m2_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vwmacc_vv_m)))
vint64m4_t vwmacc(vbool16_t, vint64m4_t, vint32m2_t, vint32m2_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vwmacc_vv)))
vint64m8_t vwmacc(vint64m8_t, vint32m4_t, vint32m4_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vwmacc_vv_m)))
vint64m8_t vwmacc(vbool8_t, vint64m8_t, vint32m4_t, vint32m4_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vwmacc_vx)))
vint64m1_t vwmacc(vint64m1_t, int32_t, vint32mf2_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vwmacc_vx_m)))
vint64m1_t vwmacc(vbool64_t, vint64m1_t, int32_t, vint32mf2_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vwmacc_vx)))
vint64m2_t vwmacc(vint64m2_t, int32_t, vint32m1_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vwmacc_vx_m)))
vint64m2_t vwmacc(vbool32_t, vint64m2_t, int32_t, vint32m1_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vwmacc_vx)))
vint64m4_t vwmacc(vint64m4_t, int32_t, vint32m2_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vwmacc_vx_m)))
vint64m4_t vwmacc(vbool16_t, vint64m4_t, int32_t, vint32m2_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vwmacc_vx)))
vint64m8_t vwmacc(vint64m8_t, int32_t, vint32m4_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vwmacc_vx_m)))
vint64m8_t vwmacc(vbool8_t, vint64m8_t, int32_t, vint32m4_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vwmaccsu_vv)))
vint64m1_t vwmaccsu(vint64m1_t, vint32mf2_t, vuint32mf2_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vwmaccsu_vv_m)))
vint64m1_t vwmaccsu(vbool64_t, vint64m1_t, vint32mf2_t, vuint32mf2_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vwmaccsu_vv)))
vint64m2_t vwmaccsu(vint64m2_t, vint32m1_t, vuint32m1_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vwmaccsu_vv_m)))
vint64m2_t vwmaccsu(vbool32_t, vint64m2_t, vint32m1_t, vuint32m1_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vwmaccsu_vv)))
vint64m4_t vwmaccsu(vint64m4_t, vint32m2_t, vuint32m2_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vwmaccsu_vv_m)))
vint64m4_t vwmaccsu(vbool16_t, vint64m4_t, vint32m2_t, vuint32m2_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vwmaccsu_vv)))
vint64m8_t vwmaccsu(vint64m8_t, vint32m4_t, vuint32m4_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vwmaccsu_vv_m)))
vint64m8_t vwmaccsu(vbool8_t, vint64m8_t, vint32m4_t, vuint32m4_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vwmaccsu_vx)))
vint64m1_t vwmaccsu(vint64m1_t, int32_t, vuint32mf2_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vwmaccsu_vx_m)))
vint64m1_t vwmaccsu(vbool64_t, vint64m1_t, int32_t, vuint32mf2_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vwmaccsu_vx)))
vint64m2_t vwmaccsu(vint64m2_t, int32_t, vuint32m1_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vwmaccsu_vx_m)))
vint64m2_t vwmaccsu(vbool32_t, vint64m2_t, int32_t, vuint32m1_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vwmaccsu_vx)))
vint64m4_t vwmaccsu(vint64m4_t, int32_t, vuint32m2_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vwmaccsu_vx_m)))
vint64m4_t vwmaccsu(vbool16_t, vint64m4_t, int32_t, vuint32m2_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vwmaccsu_vx)))
vint64m8_t vwmaccsu(vint64m8_t, int32_t, vuint32m4_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vwmaccsu_vx_m)))
vint64m8_t vwmaccsu(vbool8_t, vint64m8_t, int32_t, vuint32m4_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vwmaccus_vx)))
vint64m1_t vwmaccus(vint64m1_t, uint32_t, vint32mf2_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vwmaccus_vx_m)))
vint64m1_t vwmaccus(vbool64_t, vint64m1_t, uint32_t, vint32mf2_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vwmaccus_vx)))
vint64m2_t vwmaccus(vint64m2_t, uint32_t, vint32m1_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vwmaccus_vx_m)))
vint64m2_t vwmaccus(vbool32_t, vint64m2_t, uint32_t, vint32m1_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vwmaccus_vx)))
vint64m4_t vwmaccus(vint64m4_t, uint32_t, vint32m2_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vwmaccus_vx_m)))
vint64m4_t vwmaccus(vbool16_t, vint64m4_t, uint32_t, vint32m2_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vwmaccus_vx)))
vint64m8_t vwmaccus(vint64m8_t, uint32_t, vint32m4_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vwmaccus_vx_m)))
vint64m8_t vwmaccus(vbool8_t, vint64m8_t, uint32_t, vint32m4_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vmerge_vvm)))
vint64m1_t vmerge(vbool64_t, vint64m1_t, vint64m1_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vmerge_vvm)))
vint64m2_t vmerge(vbool32_t, vint64m2_t, vint64m2_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vmerge_vvm)))
vint64m4_t vmerge(vbool16_t, vint64m4_t, vint64m4_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vmerge_vvm)))
vint64m8_t vmerge(vbool8_t, vint64m8_t, vint64m8_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vmerge_vxm)))
vint64m1_t vmerge(vbool64_t, vint64m1_t, int64_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vmerge_vxm)))
vint64m2_t vmerge(vbool32_t, vint64m2_t, int64_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vmerge_vxm)))
vint64m4_t vmerge(vbool16_t, vint64m4_t, int64_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vmerge_vxm)))
vint64m8_t vmerge(vbool8_t, vint64m8_t, int64_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vmerge_vvm)))
vuint64m1_t vmerge(vbool64_t, vuint64m1_t, vuint64m1_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vmerge_vvm)))
vuint64m2_t vmerge(vbool32_t, vuint64m2_t, vuint64m2_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vmerge_vvm)))
vuint64m4_t vmerge(vbool16_t, vuint64m4_t, vuint64m4_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vmerge_vvm)))
vuint64m8_t vmerge(vbool8_t, vuint64m8_t, vuint64m8_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vmerge_vxm)))
vuint64m1_t vmerge(vbool64_t, vuint64m1_t, uint64_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vmerge_vxm)))
vuint64m2_t vmerge(vbool32_t, vuint64m2_t, uint64_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vmerge_vxm)))
vuint64m4_t vmerge(vbool16_t, vuint64m4_t, uint64_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vmerge_vxm)))
vuint64m8_t vmerge(vbool8_t, vuint64m8_t, uint64_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vmv_v_v)))
vuint64m1_t vmv_v(vuint64m1_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vmv_v_v)))
vuint64m2_t vmv_v(vuint64m2_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vmv_v_v)))
vuint64m4_t vmv_v(vuint64m4_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vmv_v_v)))
vuint64m8_t vmv_v(vuint64m8_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vmv_v_v)))
vint64m1_t vmv_v(vint64m1_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vmv_v_v)))
vint64m2_t vmv_v(vint64m2_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vmv_v_v)))
vint64m4_t vmv_v(vint64m4_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vmv_v_v)))
vint64m8_t vmv_v(vint64m8_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vsaddu_vv)))
vuint64m1_t vsaddu(vuint64m1_t, vuint64m1_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vsaddu_vv_m)))
vuint64m1_t vsaddu(vbool64_t, vuint64m1_t, vuint64m1_t, vuint64m1_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vsaddu_vv)))
vuint64m2_t vsaddu(vuint64m2_t, vuint64m2_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vsaddu_vv_m)))
vuint64m2_t vsaddu(vbool32_t, vuint64m2_t, vuint64m2_t, vuint64m2_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vsaddu_vv)))
vuint64m4_t vsaddu(vuint64m4_t, vuint64m4_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vsaddu_vv_m)))
vuint64m4_t vsaddu(vbool16_t, vuint64m4_t, vuint64m4_t, vuint64m4_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vsaddu_vv)))
vuint64m8_t vsaddu(vuint64m8_t, vuint64m8_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vsaddu_vv_m)))
vuint64m8_t vsaddu(vbool8_t, vuint64m8_t, vuint64m8_t, vuint64m8_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vsaddu_vx)))
vuint64m1_t vsaddu(vuint64m1_t, uint64_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vsaddu_vx_m)))
vuint64m1_t vsaddu(vbool64_t, vuint64m1_t, vuint64m1_t, uint64_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vsaddu_vx)))
vuint64m2_t vsaddu(vuint64m2_t, uint64_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vsaddu_vx_m)))
vuint64m2_t vsaddu(vbool32_t, vuint64m2_t, vuint64m2_t, uint64_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vsaddu_vx)))
vuint64m4_t vsaddu(vuint64m4_t, uint64_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vsaddu_vx_m)))
vuint64m4_t vsaddu(vbool16_t, vuint64m4_t, vuint64m4_t, uint64_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vsaddu_vx)))
vuint64m8_t vsaddu(vuint64m8_t, uint64_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vsaddu_vx_m)))
vuint64m8_t vsaddu(vbool8_t, vuint64m8_t, vuint64m8_t, uint64_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vsadd_vv)))
vint64m1_t vsadd(vint64m1_t, vint64m1_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vsadd_vv_m)))
vint64m1_t vsadd(vbool64_t, vint64m1_t, vint64m1_t, vint64m1_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vsadd_vv)))
vint64m2_t vsadd(vint64m2_t, vint64m2_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vsadd_vv_m)))
vint64m2_t vsadd(vbool32_t, vint64m2_t, vint64m2_t, vint64m2_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vsadd_vv)))
vint64m4_t vsadd(vint64m4_t, vint64m4_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vsadd_vv_m)))
vint64m4_t vsadd(vbool16_t, vint64m4_t, vint64m4_t, vint64m4_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vsadd_vv)))
vint64m8_t vsadd(vint64m8_t, vint64m8_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vsadd_vv_m)))
vint64m8_t vsadd(vbool8_t, vint64m8_t, vint64m8_t, vint64m8_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vsadd_vx)))
vint64m1_t vsadd(vint64m1_t, int64_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vsadd_vx_m)))
vint64m1_t vsadd(vbool64_t, vint64m1_t, vint64m1_t, int64_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vsadd_vx)))
vint64m2_t vsadd(vint64m2_t, int64_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vsadd_vx_m)))
vint64m2_t vsadd(vbool32_t, vint64m2_t, vint64m2_t, int64_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vsadd_vx)))
vint64m4_t vsadd(vint64m4_t, int64_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vsadd_vx_m)))
vint64m4_t vsadd(vbool16_t, vint64m4_t, vint64m4_t, int64_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vsadd_vx)))
vint64m8_t vsadd(vint64m8_t, int64_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vsadd_vx_m)))
vint64m8_t vsadd(vbool8_t, vint64m8_t, vint64m8_t, int64_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vssubu_vv)))
vuint64m1_t vssubu(vuint64m1_t, vuint64m1_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vssubu_vv_m)))
vuint64m1_t vssubu(vbool64_t, vuint64m1_t, vuint64m1_t, vuint64m1_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vssubu_vv)))
vuint64m2_t vssubu(vuint64m2_t, vuint64m2_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vssubu_vv_m)))
vuint64m2_t vssubu(vbool32_t, vuint64m2_t, vuint64m2_t, vuint64m2_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vssubu_vv)))
vuint64m4_t vssubu(vuint64m4_t, vuint64m4_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vssubu_vv_m)))
vuint64m4_t vssubu(vbool16_t, vuint64m4_t, vuint64m4_t, vuint64m4_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vssubu_vv)))
vuint64m8_t vssubu(vuint64m8_t, vuint64m8_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vssubu_vv_m)))
vuint64m8_t vssubu(vbool8_t, vuint64m8_t, vuint64m8_t, vuint64m8_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vssubu_vx)))
vuint64m1_t vssubu(vuint64m1_t, uint64_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vssubu_vx_m)))
vuint64m1_t vssubu(vbool64_t, vuint64m1_t, vuint64m1_t, uint64_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vssubu_vx)))
vuint64m2_t vssubu(vuint64m2_t, uint64_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vssubu_vx_m)))
vuint64m2_t vssubu(vbool32_t, vuint64m2_t, vuint64m2_t, uint64_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vssubu_vx)))
vuint64m4_t vssubu(vuint64m4_t, uint64_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vssubu_vx_m)))
vuint64m4_t vssubu(vbool16_t, vuint64m4_t, vuint64m4_t, uint64_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vssubu_vx)))
vuint64m8_t vssubu(vuint64m8_t, uint64_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vssubu_vx_m)))
vuint64m8_t vssubu(vbool8_t, vuint64m8_t, vuint64m8_t, uint64_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vssub_vv)))
vint64m1_t vssub(vint64m1_t, vint64m1_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vssub_vv_m)))
vint64m1_t vssub(vbool64_t, vint64m1_t, vint64m1_t, vint64m1_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vssub_vv)))
vint64m2_t vssub(vint64m2_t, vint64m2_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vssub_vv_m)))
vint64m2_t vssub(vbool32_t, vint64m2_t, vint64m2_t, vint64m2_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vssub_vv)))
vint64m4_t vssub(vint64m4_t, vint64m4_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vssub_vv_m)))
vint64m4_t vssub(vbool16_t, vint64m4_t, vint64m4_t, vint64m4_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vssub_vv)))
vint64m8_t vssub(vint64m8_t, vint64m8_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vssub_vv_m)))
vint64m8_t vssub(vbool8_t, vint64m8_t, vint64m8_t, vint64m8_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vssub_vx)))
vint64m1_t vssub(vint64m1_t, int64_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vssub_vx_m)))
vint64m1_t vssub(vbool64_t, vint64m1_t, vint64m1_t, int64_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vssub_vx)))
vint64m2_t vssub(vint64m2_t, int64_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vssub_vx_m)))
vint64m2_t vssub(vbool32_t, vint64m2_t, vint64m2_t, int64_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vssub_vx)))
vint64m4_t vssub(vint64m4_t, int64_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vssub_vx_m)))
vint64m4_t vssub(vbool16_t, vint64m4_t, vint64m4_t, int64_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vssub_vx)))
vint64m8_t vssub(vint64m8_t, int64_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vssub_vx_m)))
vint64m8_t vssub(vbool8_t, vint64m8_t, vint64m8_t, int64_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vaaddu_vv)))
vuint64m1_t vaaddu(vuint64m1_t, vuint64m1_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vaaddu_vv_m)))
vuint64m1_t vaaddu(vbool64_t, vuint64m1_t, vuint64m1_t, vuint64m1_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vaaddu_vv)))
vuint64m2_t vaaddu(vuint64m2_t, vuint64m2_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vaaddu_vv_m)))
vuint64m2_t vaaddu(vbool32_t, vuint64m2_t, vuint64m2_t, vuint64m2_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vaaddu_vv)))
vuint64m4_t vaaddu(vuint64m4_t, vuint64m4_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vaaddu_vv_m)))
vuint64m4_t vaaddu(vbool16_t, vuint64m4_t, vuint64m4_t, vuint64m4_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vaaddu_vv)))
vuint64m8_t vaaddu(vuint64m8_t, vuint64m8_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vaaddu_vv_m)))
vuint64m8_t vaaddu(vbool8_t, vuint64m8_t, vuint64m8_t, vuint64m8_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vaaddu_vx)))
vuint64m1_t vaaddu(vuint64m1_t, uint64_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vaaddu_vx_m)))
vuint64m1_t vaaddu(vbool64_t, vuint64m1_t, vuint64m1_t, uint64_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vaaddu_vx)))
vuint64m2_t vaaddu(vuint64m2_t, uint64_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vaaddu_vx_m)))
vuint64m2_t vaaddu(vbool32_t, vuint64m2_t, vuint64m2_t, uint64_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vaaddu_vx)))
vuint64m4_t vaaddu(vuint64m4_t, uint64_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vaaddu_vx_m)))
vuint64m4_t vaaddu(vbool16_t, vuint64m4_t, vuint64m4_t, uint64_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vaaddu_vx)))
vuint64m8_t vaaddu(vuint64m8_t, uint64_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vaaddu_vx_m)))
vuint64m8_t vaaddu(vbool8_t, vuint64m8_t, vuint64m8_t, uint64_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vaadd_vv)))
vint64m1_t vaadd(vint64m1_t, vint64m1_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vaadd_vv_m)))
vint64m1_t vaadd(vbool64_t, vint64m1_t, vint64m1_t, vint64m1_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vaadd_vv)))
vint64m2_t vaadd(vint64m2_t, vint64m2_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vaadd_vv_m)))
vint64m2_t vaadd(vbool32_t, vint64m2_t, vint64m2_t, vint64m2_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vaadd_vv)))
vint64m4_t vaadd(vint64m4_t, vint64m4_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vaadd_vv_m)))
vint64m4_t vaadd(vbool16_t, vint64m4_t, vint64m4_t, vint64m4_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vaadd_vv)))
vint64m8_t vaadd(vint64m8_t, vint64m8_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vaadd_vv_m)))
vint64m8_t vaadd(vbool8_t, vint64m8_t, vint64m8_t, vint64m8_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vaadd_vx)))
vint64m1_t vaadd(vint64m1_t, int64_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vaadd_vx_m)))
vint64m1_t vaadd(vbool64_t, vint64m1_t, vint64m1_t, int64_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vaadd_vx)))
vint64m2_t vaadd(vint64m2_t, int64_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vaadd_vx_m)))
vint64m2_t vaadd(vbool32_t, vint64m2_t, vint64m2_t, int64_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vaadd_vx)))
vint64m4_t vaadd(vint64m4_t, int64_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vaadd_vx_m)))
vint64m4_t vaadd(vbool16_t, vint64m4_t, vint64m4_t, int64_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vaadd_vx)))
vint64m8_t vaadd(vint64m8_t, int64_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vaadd_vx_m)))
vint64m8_t vaadd(vbool8_t, vint64m8_t, vint64m8_t, int64_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vasubu_vv)))
vuint64m1_t vasubu(vuint64m1_t, vuint64m1_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vasubu_vv_m)))
vuint64m1_t vasubu(vbool64_t, vuint64m1_t, vuint64m1_t, vuint64m1_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vasubu_vv)))
vuint64m2_t vasubu(vuint64m2_t, vuint64m2_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vasubu_vv_m)))
vuint64m2_t vasubu(vbool32_t, vuint64m2_t, vuint64m2_t, vuint64m2_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vasubu_vv)))
vuint64m4_t vasubu(vuint64m4_t, vuint64m4_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vasubu_vv_m)))
vuint64m4_t vasubu(vbool16_t, vuint64m4_t, vuint64m4_t, vuint64m4_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vasubu_vv)))
vuint64m8_t vasubu(vuint64m8_t, vuint64m8_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vasubu_vv_m)))
vuint64m8_t vasubu(vbool8_t, vuint64m8_t, vuint64m8_t, vuint64m8_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vasubu_vx)))
vuint64m1_t vasubu(vuint64m1_t, uint64_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vasubu_vx_m)))
vuint64m1_t vasubu(vbool64_t, vuint64m1_t, vuint64m1_t, uint64_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vasubu_vx)))
vuint64m2_t vasubu(vuint64m2_t, uint64_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vasubu_vx_m)))
vuint64m2_t vasubu(vbool32_t, vuint64m2_t, vuint64m2_t, uint64_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vasubu_vx)))
vuint64m4_t vasubu(vuint64m4_t, uint64_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vasubu_vx_m)))
vuint64m4_t vasubu(vbool16_t, vuint64m4_t, vuint64m4_t, uint64_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vasubu_vx)))
vuint64m8_t vasubu(vuint64m8_t, uint64_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vasubu_vx_m)))
vuint64m8_t vasubu(vbool8_t, vuint64m8_t, vuint64m8_t, uint64_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vasub_vv)))
vint64m1_t vasub(vint64m1_t, vint64m1_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vasub_vv_m)))
vint64m1_t vasub(vbool64_t, vint64m1_t, vint64m1_t, vint64m1_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vasub_vv)))
vint64m2_t vasub(vint64m2_t, vint64m2_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vasub_vv_m)))
vint64m2_t vasub(vbool32_t, vint64m2_t, vint64m2_t, vint64m2_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vasub_vv)))
vint64m4_t vasub(vint64m4_t, vint64m4_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vasub_vv_m)))
vint64m4_t vasub(vbool16_t, vint64m4_t, vint64m4_t, vint64m4_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vasub_vv)))
vint64m8_t vasub(vint64m8_t, vint64m8_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vasub_vv_m)))
vint64m8_t vasub(vbool8_t, vint64m8_t, vint64m8_t, vint64m8_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vasub_vx)))
vint64m1_t vasub(vint64m1_t, int64_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vasub_vx_m)))
vint64m1_t vasub(vbool64_t, vint64m1_t, vint64m1_t, int64_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vasub_vx)))
vint64m2_t vasub(vint64m2_t, int64_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vasub_vx_m)))
vint64m2_t vasub(vbool32_t, vint64m2_t, vint64m2_t, int64_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vasub_vx)))
vint64m4_t vasub(vint64m4_t, int64_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vasub_vx_m)))
vint64m4_t vasub(vbool16_t, vint64m4_t, vint64m4_t, int64_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vasub_vx)))
vint64m8_t vasub(vint64m8_t, int64_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vasub_vx_m)))
vint64m8_t vasub(vbool8_t, vint64m8_t, vint64m8_t, int64_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vssrl_vv)))
vuint64m1_t vssrl(vuint64m1_t, vuint64m1_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vssrl_vv_m)))
vuint64m1_t vssrl(vbool64_t, vuint64m1_t, vuint64m1_t, vuint64m1_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vssrl_vv)))
vuint64m2_t vssrl(vuint64m2_t, vuint64m2_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vssrl_vv_m)))
vuint64m2_t vssrl(vbool32_t, vuint64m2_t, vuint64m2_t, vuint64m2_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vssrl_vv)))
vuint64m4_t vssrl(vuint64m4_t, vuint64m4_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vssrl_vv_m)))
vuint64m4_t vssrl(vbool16_t, vuint64m4_t, vuint64m4_t, vuint64m4_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vssrl_vv)))
vuint64m8_t vssrl(vuint64m8_t, vuint64m8_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vssrl_vv_m)))
vuint64m8_t vssrl(vbool8_t, vuint64m8_t, vuint64m8_t, vuint64m8_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vssrl_vx)))
vuint64m1_t vssrl(vuint64m1_t, size_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vssrl_vx_m)))
vuint64m1_t vssrl(vbool64_t, vuint64m1_t, vuint64m1_t, size_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vssrl_vx)))
vuint64m2_t vssrl(vuint64m2_t, size_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vssrl_vx_m)))
vuint64m2_t vssrl(vbool32_t, vuint64m2_t, vuint64m2_t, size_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vssrl_vx)))
vuint64m4_t vssrl(vuint64m4_t, size_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vssrl_vx_m)))
vuint64m4_t vssrl(vbool16_t, vuint64m4_t, vuint64m4_t, size_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vssrl_vx)))
vuint64m8_t vssrl(vuint64m8_t, size_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vssrl_vx_m)))
vuint64m8_t vssrl(vbool8_t, vuint64m8_t, vuint64m8_t, size_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vssra_vv)))
vint64m1_t vssra(vint64m1_t, vuint64m1_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vssra_vv_m)))
vint64m1_t vssra(vbool64_t, vint64m1_t, vint64m1_t, vuint64m1_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vssra_vv)))
vint64m2_t vssra(vint64m2_t, vuint64m2_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vssra_vv_m)))
vint64m2_t vssra(vbool32_t, vint64m2_t, vint64m2_t, vuint64m2_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vssra_vv)))
vint64m4_t vssra(vint64m4_t, vuint64m4_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vssra_vv_m)))
vint64m4_t vssra(vbool16_t, vint64m4_t, vint64m4_t, vuint64m4_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vssra_vv)))
vint64m8_t vssra(vint64m8_t, vuint64m8_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vssra_vv_m)))
vint64m8_t vssra(vbool8_t, vint64m8_t, vint64m8_t, vuint64m8_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vssra_vx)))
vint64m1_t vssra(vint64m1_t, size_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vssra_vx_m)))
vint64m1_t vssra(vbool64_t, vint64m1_t, vint64m1_t, size_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vssra_vx)))
vint64m2_t vssra(vint64m2_t, size_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vssra_vx_m)))
vint64m2_t vssra(vbool32_t, vint64m2_t, vint64m2_t, size_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vssra_vx)))
vint64m4_t vssra(vint64m4_t, size_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vssra_vx_m)))
vint64m4_t vssra(vbool16_t, vint64m4_t, vint64m4_t, size_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vssra_vx)))
vint64m8_t vssra(vint64m8_t, size_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vssra_vx_m)))
vint64m8_t vssra(vbool8_t, vint64m8_t, vint64m8_t, size_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vnclipu_wv)))
vuint32m1_t vnclipu(vuint64m2_t, vuint32m1_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vnclipu_wv_m)))
vuint32m1_t vnclipu(vbool32_t, vuint32m1_t, vuint64m2_t, vuint32m1_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vnclipu_wv)))
vuint32m2_t vnclipu(vuint64m4_t, vuint32m2_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vnclipu_wv_m)))
vuint32m2_t vnclipu(vbool16_t, vuint32m2_t, vuint64m4_t, vuint32m2_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vnclipu_wv)))
vuint32m4_t vnclipu(vuint64m8_t, vuint32m4_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vnclipu_wv_m)))
vuint32m4_t vnclipu(vbool8_t, vuint32m4_t, vuint64m8_t, vuint32m4_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vnclipu_wv)))
vuint32mf2_t vnclipu(vuint64m1_t, vuint32mf2_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vnclipu_wv_m)))
vuint32mf2_t vnclipu(vbool64_t, vuint32mf2_t, vuint64m1_t, vuint32mf2_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vnclipu_wx)))
vuint32m1_t vnclipu(vuint64m2_t, size_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vnclipu_wx_m)))
vuint32m1_t vnclipu(vbool32_t, vuint32m1_t, vuint64m2_t, size_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vnclipu_wx)))
vuint32m2_t vnclipu(vuint64m4_t, size_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vnclipu_wx_m)))
vuint32m2_t vnclipu(vbool16_t, vuint32m2_t, vuint64m4_t, size_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vnclipu_wx)))
vuint32m4_t vnclipu(vuint64m8_t, size_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vnclipu_wx_m)))
vuint32m4_t vnclipu(vbool8_t, vuint32m4_t, vuint64m8_t, size_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vnclipu_wx)))
vuint32mf2_t vnclipu(vuint64m1_t, size_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vnclipu_wx_m)))
vuint32mf2_t vnclipu(vbool64_t, vuint32mf2_t, vuint64m1_t, size_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vnclip_wv)))
vint32m1_t vnclip(vint64m2_t, vuint32m1_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vnclip_wv_m)))
vint32m1_t vnclip(vbool32_t, vint32m1_t, vint64m2_t, vuint32m1_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vnclip_wv)))
vint32m2_t vnclip(vint64m4_t, vuint32m2_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vnclip_wv_m)))
vint32m2_t vnclip(vbool16_t, vint32m2_t, vint64m4_t, vuint32m2_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vnclip_wv)))
vint32m4_t vnclip(vint64m8_t, vuint32m4_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vnclip_wv_m)))
vint32m4_t vnclip(vbool8_t, vint32m4_t, vint64m8_t, vuint32m4_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vnclip_wv)))
vint32mf2_t vnclip(vint64m1_t, vuint32mf2_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vnclip_wv_m)))
vint32mf2_t vnclip(vbool64_t, vint32mf2_t, vint64m1_t, vuint32mf2_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vnclip_wx)))
vint32m1_t vnclip(vint64m2_t, size_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vnclip_wx_m)))
vint32m1_t vnclip(vbool32_t, vint32m1_t, vint64m2_t, size_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vnclip_wx)))
vint32m2_t vnclip(vint64m4_t, size_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vnclip_wx_m)))
vint32m2_t vnclip(vbool16_t, vint32m2_t, vint64m4_t, size_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vnclip_wx)))
vint32m4_t vnclip(vint64m8_t, size_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vnclip_wx_m)))
vint32m4_t vnclip(vbool8_t, vint32m4_t, vint64m8_t, size_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vnclip_wx)))
vint32mf2_t vnclip(vint64m1_t, size_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vnclip_wx_m)))
vint32mf2_t vnclip(vbool64_t, vint32mf2_t, vint64m1_t, size_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vredsum_vs)))
vint64m1_t vredsum(vint64m1_t, vint64m1_t, vint64m1_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vredsum_vs_m)))
vint64m1_t vredsum(vbool64_t, vint64m1_t, vint64m1_t, vint64m1_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vredsum_vs)))
vint64m1_t vredsum(vint64m1_t, vint64m2_t, vint64m1_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vredsum_vs_m)))
vint64m1_t vredsum(vbool32_t, vint64m1_t, vint64m2_t, vint64m1_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vredsum_vs)))
vint64m1_t vredsum(vint64m1_t, vint64m4_t, vint64m1_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vredsum_vs_m)))
vint64m1_t vredsum(vbool16_t, vint64m1_t, vint64m4_t, vint64m1_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vredsum_vs)))
vint64m1_t vredsum(vint64m1_t, vint64m8_t, vint64m1_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vredsum_vs_m)))
vint64m1_t vredsum(vbool8_t, vint64m1_t, vint64m8_t, vint64m1_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vredsum_vs)))
vuint64m1_t vredsum(vuint64m1_t, vuint64m1_t, vuint64m1_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vredsum_vs_m)))
vuint64m1_t vredsum(vbool64_t, vuint64m1_t, vuint64m1_t, vuint64m1_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vredsum_vs)))
vuint64m1_t vredsum(vuint64m1_t, vuint64m2_t, vuint64m1_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vredsum_vs_m)))
vuint64m1_t vredsum(vbool32_t, vuint64m1_t, vuint64m2_t, vuint64m1_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vredsum_vs)))
vuint64m1_t vredsum(vuint64m1_t, vuint64m4_t, vuint64m1_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vredsum_vs_m)))
vuint64m1_t vredsum(vbool16_t, vuint64m1_t, vuint64m4_t, vuint64m1_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vredsum_vs)))
vuint64m1_t vredsum(vuint64m1_t, vuint64m8_t, vuint64m1_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vredsum_vs_m)))
vuint64m1_t vredsum(vbool8_t, vuint64m1_t, vuint64m8_t, vuint64m1_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vredmaxu_vs)))
vuint64m1_t vredmaxu(vuint64m1_t, vuint64m1_t, vuint64m1_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vredmaxu_vs_m)))
vuint64m1_t vredmaxu(vbool64_t, vuint64m1_t, vuint64m1_t, vuint64m1_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vredmaxu_vs)))
vuint64m1_t vredmaxu(vuint64m1_t, vuint64m2_t, vuint64m1_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vredmaxu_vs_m)))
vuint64m1_t vredmaxu(vbool32_t, vuint64m1_t, vuint64m2_t, vuint64m1_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vredmaxu_vs)))
vuint64m1_t vredmaxu(vuint64m1_t, vuint64m4_t, vuint64m1_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vredmaxu_vs_m)))
vuint64m1_t vredmaxu(vbool16_t, vuint64m1_t, vuint64m4_t, vuint64m1_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vredmaxu_vs)))
vuint64m1_t vredmaxu(vuint64m1_t, vuint64m8_t, vuint64m1_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vredmaxu_vs_m)))
vuint64m1_t vredmaxu(vbool8_t, vuint64m1_t, vuint64m8_t, vuint64m1_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vredmax_vs)))
vint64m1_t vredmax(vint64m1_t, vint64m1_t, vint64m1_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vredmax_vs_m)))
vint64m1_t vredmax(vbool64_t, vint64m1_t, vint64m1_t, vint64m1_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vredmax_vs)))
vint64m1_t vredmax(vint64m1_t, vint64m2_t, vint64m1_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vredmax_vs_m)))
vint64m1_t vredmax(vbool32_t, vint64m1_t, vint64m2_t, vint64m1_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vredmax_vs)))
vint64m1_t vredmax(vint64m1_t, vint64m4_t, vint64m1_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vredmax_vs_m)))
vint64m1_t vredmax(vbool16_t, vint64m1_t, vint64m4_t, vint64m1_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vredmax_vs)))
vint64m1_t vredmax(vint64m1_t, vint64m8_t, vint64m1_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vredmax_vs_m)))
vint64m1_t vredmax(vbool8_t, vint64m1_t, vint64m8_t, vint64m1_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vredminu_vs)))
vuint64m1_t vredminu(vuint64m1_t, vuint64m1_t, vuint64m1_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vredminu_vs_m)))
vuint64m1_t vredminu(vbool64_t, vuint64m1_t, vuint64m1_t, vuint64m1_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vredminu_vs)))
vuint64m1_t vredminu(vuint64m1_t, vuint64m2_t, vuint64m1_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vredminu_vs_m)))
vuint64m1_t vredminu(vbool32_t, vuint64m1_t, vuint64m2_t, vuint64m1_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vredminu_vs)))
vuint64m1_t vredminu(vuint64m1_t, vuint64m4_t, vuint64m1_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vredminu_vs_m)))
vuint64m1_t vredminu(vbool16_t, vuint64m1_t, vuint64m4_t, vuint64m1_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vredminu_vs)))
vuint64m1_t vredminu(vuint64m1_t, vuint64m8_t, vuint64m1_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vredminu_vs_m)))
vuint64m1_t vredminu(vbool8_t, vuint64m1_t, vuint64m8_t, vuint64m1_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vredmin_vs)))
vint64m1_t vredmin(vint64m1_t, vint64m1_t, vint64m1_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vredmin_vs_m)))
vint64m1_t vredmin(vbool64_t, vint64m1_t, vint64m1_t, vint64m1_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vredmin_vs)))
vint64m1_t vredmin(vint64m1_t, vint64m2_t, vint64m1_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vredmin_vs_m)))
vint64m1_t vredmin(vbool32_t, vint64m1_t, vint64m2_t, vint64m1_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vredmin_vs)))
vint64m1_t vredmin(vint64m1_t, vint64m4_t, vint64m1_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vredmin_vs_m)))
vint64m1_t vredmin(vbool16_t, vint64m1_t, vint64m4_t, vint64m1_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vredmin_vs)))
vint64m1_t vredmin(vint64m1_t, vint64m8_t, vint64m1_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vredmin_vs_m)))
vint64m1_t vredmin(vbool8_t, vint64m1_t, vint64m8_t, vint64m1_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vredand_vs)))
vint64m1_t vredand(vint64m1_t, vint64m1_t, vint64m1_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vredand_vs_m)))
vint64m1_t vredand(vbool64_t, vint64m1_t, vint64m1_t, vint64m1_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vredand_vs)))
vint64m1_t vredand(vint64m1_t, vint64m2_t, vint64m1_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vredand_vs_m)))
vint64m1_t vredand(vbool32_t, vint64m1_t, vint64m2_t, vint64m1_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vredand_vs)))
vint64m1_t vredand(vint64m1_t, vint64m4_t, vint64m1_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vredand_vs_m)))
vint64m1_t vredand(vbool16_t, vint64m1_t, vint64m4_t, vint64m1_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vredand_vs)))
vint64m1_t vredand(vint64m1_t, vint64m8_t, vint64m1_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vredand_vs_m)))
vint64m1_t vredand(vbool8_t, vint64m1_t, vint64m8_t, vint64m1_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vredand_vs)))
vuint64m1_t vredand(vuint64m1_t, vuint64m1_t, vuint64m1_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vredand_vs_m)))
vuint64m1_t vredand(vbool64_t, vuint64m1_t, vuint64m1_t, vuint64m1_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vredand_vs)))
vuint64m1_t vredand(vuint64m1_t, vuint64m2_t, vuint64m1_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vredand_vs_m)))
vuint64m1_t vredand(vbool32_t, vuint64m1_t, vuint64m2_t, vuint64m1_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vredand_vs)))
vuint64m1_t vredand(vuint64m1_t, vuint64m4_t, vuint64m1_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vredand_vs_m)))
vuint64m1_t vredand(vbool16_t, vuint64m1_t, vuint64m4_t, vuint64m1_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vredand_vs)))
vuint64m1_t vredand(vuint64m1_t, vuint64m8_t, vuint64m1_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vredand_vs_m)))
vuint64m1_t vredand(vbool8_t, vuint64m1_t, vuint64m8_t, vuint64m1_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vredor_vs)))
vint64m1_t vredor(vint64m1_t, vint64m1_t, vint64m1_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vredor_vs_m)))
vint64m1_t vredor(vbool64_t, vint64m1_t, vint64m1_t, vint64m1_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vredor_vs)))
vint64m1_t vredor(vint64m1_t, vint64m2_t, vint64m1_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vredor_vs_m)))
vint64m1_t vredor(vbool32_t, vint64m1_t, vint64m2_t, vint64m1_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vredor_vs)))
vint64m1_t vredor(vint64m1_t, vint64m4_t, vint64m1_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vredor_vs_m)))
vint64m1_t vredor(vbool16_t, vint64m1_t, vint64m4_t, vint64m1_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vredor_vs)))
vint64m1_t vredor(vint64m1_t, vint64m8_t, vint64m1_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vredor_vs_m)))
vint64m1_t vredor(vbool8_t, vint64m1_t, vint64m8_t, vint64m1_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vredor_vs)))
vuint64m1_t vredor(vuint64m1_t, vuint64m1_t, vuint64m1_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vredor_vs_m)))
vuint64m1_t vredor(vbool64_t, vuint64m1_t, vuint64m1_t, vuint64m1_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vredor_vs)))
vuint64m1_t vredor(vuint64m1_t, vuint64m2_t, vuint64m1_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vredor_vs_m)))
vuint64m1_t vredor(vbool32_t, vuint64m1_t, vuint64m2_t, vuint64m1_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vredor_vs)))
vuint64m1_t vredor(vuint64m1_t, vuint64m4_t, vuint64m1_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vredor_vs_m)))
vuint64m1_t vredor(vbool16_t, vuint64m1_t, vuint64m4_t, vuint64m1_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vredor_vs)))
vuint64m1_t vredor(vuint64m1_t, vuint64m8_t, vuint64m1_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vredor_vs_m)))
vuint64m1_t vredor(vbool8_t, vuint64m1_t, vuint64m8_t, vuint64m1_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vredxor_vs)))
vint64m1_t vredxor(vint64m1_t, vint64m1_t, vint64m1_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vredxor_vs_m)))
vint64m1_t vredxor(vbool64_t, vint64m1_t, vint64m1_t, vint64m1_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vredxor_vs)))
vint64m1_t vredxor(vint64m1_t, vint64m2_t, vint64m1_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vredxor_vs_m)))
vint64m1_t vredxor(vbool32_t, vint64m1_t, vint64m2_t, vint64m1_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vredxor_vs)))
vint64m1_t vredxor(vint64m1_t, vint64m4_t, vint64m1_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vredxor_vs_m)))
vint64m1_t vredxor(vbool16_t, vint64m1_t, vint64m4_t, vint64m1_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vredxor_vs)))
vint64m1_t vredxor(vint64m1_t, vint64m8_t, vint64m1_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vredxor_vs_m)))
vint64m1_t vredxor(vbool8_t, vint64m1_t, vint64m8_t, vint64m1_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vredxor_vs)))
vuint64m1_t vredxor(vuint64m1_t, vuint64m1_t, vuint64m1_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vredxor_vs_m)))
vuint64m1_t vredxor(vbool64_t, vuint64m1_t, vuint64m1_t, vuint64m1_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vredxor_vs)))
vuint64m1_t vredxor(vuint64m1_t, vuint64m2_t, vuint64m1_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vredxor_vs_m)))
vuint64m1_t vredxor(vbool32_t, vuint64m1_t, vuint64m2_t, vuint64m1_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vredxor_vs)))
vuint64m1_t vredxor(vuint64m1_t, vuint64m4_t, vuint64m1_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vredxor_vs_m)))
vuint64m1_t vredxor(vbool16_t, vuint64m1_t, vuint64m4_t, vuint64m1_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vredxor_vs)))
vuint64m1_t vredxor(vuint64m1_t, vuint64m8_t, vuint64m1_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vredxor_vs_m)))
vuint64m1_t vredxor(vbool8_t, vuint64m1_t, vuint64m8_t, vuint64m1_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vwredsum_vs)))
vint64m1_t vwredsum(vint64m1_t, vint32m1_t, vint64m1_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vwredsum_vs_m)))
vint64m1_t vwredsum(vbool32_t, vint64m1_t, vint32m1_t, vint64m1_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vwredsum_vs)))
vint64m1_t vwredsum(vint64m1_t, vint32m2_t, vint64m1_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vwredsum_vs_m)))
vint64m1_t vwredsum(vbool16_t, vint64m1_t, vint32m2_t, vint64m1_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vwredsum_vs)))
vint64m1_t vwredsum(vint64m1_t, vint32m4_t, vint64m1_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vwredsum_vs_m)))
vint64m1_t vwredsum(vbool8_t, vint64m1_t, vint32m4_t, vint64m1_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vwredsum_vs)))
vint64m1_t vwredsum(vint64m1_t, vint32m8_t, vint64m1_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vwredsum_vs_m)))
vint64m1_t vwredsum(vbool4_t, vint64m1_t, vint32m8_t, vint64m1_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vwredsum_vs)))
vint64m1_t vwredsum(vint64m1_t, vint32mf2_t, vint64m1_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vwredsum_vs_m)))
vint64m1_t vwredsum(vbool64_t, vint64m1_t, vint32mf2_t, vint64m1_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vwredsumu_vs)))
vuint64m1_t vwredsumu(vuint64m1_t, vuint32m1_t, vuint64m1_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vwredsumu_vs_m)))
vuint64m1_t vwredsumu(vbool32_t, vuint64m1_t, vuint32m1_t, vuint64m1_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vwredsumu_vs)))
vuint64m1_t vwredsumu(vuint64m1_t, vuint32m2_t, vuint64m1_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vwredsumu_vs_m)))
vuint64m1_t vwredsumu(vbool16_t, vuint64m1_t, vuint32m2_t, vuint64m1_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vwredsumu_vs)))
vuint64m1_t vwredsumu(vuint64m1_t, vuint32m4_t, vuint64m1_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vwredsumu_vs_m)))
vuint64m1_t vwredsumu(vbool8_t, vuint64m1_t, vuint32m4_t, vuint64m1_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vwredsumu_vs)))
vuint64m1_t vwredsumu(vuint64m1_t, vuint32m8_t, vuint64m1_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vwredsumu_vs_m)))
vuint64m1_t vwredsumu(vbool4_t, vuint64m1_t, vuint32m8_t, vuint64m1_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vwredsumu_vs)))
vuint64m1_t vwredsumu(vuint64m1_t, vuint32mf2_t, vuint64m1_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vwredsumu_vs_m)))
vuint64m1_t vwredsumu(vbool64_t, vuint64m1_t, vuint32mf2_t, vuint64m1_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_viota_m_m)))
vuint64m1_t viota(vbool64_t, vuint64m1_t, vbool64_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_viota_m_m)))
vuint64m2_t viota(vbool32_t, vuint64m2_t, vbool32_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_viota_m_m)))
vuint64m4_t viota(vbool16_t, vuint64m4_t, vbool16_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_viota_m_m)))
vuint64m8_t viota(vbool8_t, vuint64m8_t, vbool8_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vid_v_m)))
vint64m1_t vid(vbool64_t, vint64m1_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vid_v_m)))
vint64m2_t vid(vbool32_t, vint64m2_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vid_v_m)))
vint64m4_t vid(vbool16_t, vint64m4_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vid_v_m)))
vint64m8_t vid(vbool8_t, vint64m8_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vid_v_m)))
vuint64m1_t vid(vbool64_t, vuint64m1_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vid_v_m)))
vuint64m2_t vid(vbool32_t, vuint64m2_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vid_v_m)))
vuint64m4_t vid(vbool16_t, vuint64m4_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vid_v_m)))
vuint64m8_t vid(vbool8_t, vuint64m8_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vmv_x_s)))
int64_t vmv_x(vint64m1_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vmv_x_s)))
int64_t vmv_x(vint64m2_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vmv_x_s)))
int64_t vmv_x(vint64m4_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vmv_x_s)))
int64_t vmv_x(vint64m8_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vmv_x_s)))
uint64_t vmv_x(vuint64m1_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vmv_x_s)))
uint64_t vmv_x(vuint64m2_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vmv_x_s)))
uint64_t vmv_x(vuint64m4_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vmv_x_s)))
uint64_t vmv_x(vuint64m8_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vmv_s_x)))
vint64m1_t vmv_s(vint64m1_t, int64_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vmv_s_x)))
vint64m2_t vmv_s(vint64m2_t, int64_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vmv_s_x)))
vint64m4_t vmv_s(vint64m4_t, int64_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vmv_s_x)))
vint64m8_t vmv_s(vint64m8_t, int64_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vmv_s_x)))
vuint64m1_t vmv_s(vuint64m1_t, uint64_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vmv_s_x)))
vuint64m2_t vmv_s(vuint64m2_t, uint64_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vmv_s_x)))
vuint64m4_t vmv_s(vuint64m4_t, uint64_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vmv_s_x)))
vuint64m8_t vmv_s(vuint64m8_t, uint64_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vfmv_s_x)))
vuint64m1_t vfmv_s(vuint64m1_t, uint64_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vfmv_s_x)))
vuint64m2_t vfmv_s(vuint64m2_t, uint64_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vfmv_s_x)))
vuint64m4_t vfmv_s(vuint64m4_t, uint64_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vfmv_s_x)))
vuint64m8_t vfmv_s(vuint64m8_t, uint64_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vslideup_vx)))
vint64m1_t vslideup(vint64m1_t, vint64m1_t, size_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vslideup_vx_m)))
vint64m1_t vslideup(vbool64_t, vint64m1_t, vint64m1_t, size_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vslideup_vx)))
vint64m2_t vslideup(vint64m2_t, vint64m2_t, size_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vslideup_vx_m)))
vint64m2_t vslideup(vbool32_t, vint64m2_t, vint64m2_t, size_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vslideup_vx)))
vint64m4_t vslideup(vint64m4_t, vint64m4_t, size_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vslideup_vx_m)))
vint64m4_t vslideup(vbool16_t, vint64m4_t, vint64m4_t, size_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vslideup_vx)))
vint64m8_t vslideup(vint64m8_t, vint64m8_t, size_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vslideup_vx_m)))
vint64m8_t vslideup(vbool8_t, vint64m8_t, vint64m8_t, size_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vslideup_vx)))
vuint64m1_t vslideup(vuint64m1_t, vuint64m1_t, size_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vslideup_vx_m)))
vuint64m1_t vslideup(vbool64_t, vuint64m1_t, vuint64m1_t, size_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vslideup_vx)))
vuint64m2_t vslideup(vuint64m2_t, vuint64m2_t, size_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vslideup_vx_m)))
vuint64m2_t vslideup(vbool32_t, vuint64m2_t, vuint64m2_t, size_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vslideup_vx)))
vuint64m4_t vslideup(vuint64m4_t, vuint64m4_t, size_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vslideup_vx_m)))
vuint64m4_t vslideup(vbool16_t, vuint64m4_t, vuint64m4_t, size_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vslideup_vx)))
vuint64m8_t vslideup(vuint64m8_t, vuint64m8_t, size_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vslideup_vx_m)))
vuint64m8_t vslideup(vbool8_t, vuint64m8_t, vuint64m8_t, size_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vslidedown_vx)))
vint64m1_t vslidedown(vint64m1_t, vint64m1_t, size_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vslidedown_vx_m)))
vint64m1_t vslidedown(vbool64_t, vint64m1_t, vint64m1_t, size_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vslidedown_vx)))
vint64m2_t vslidedown(vint64m2_t, vint64m2_t, size_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vslidedown_vx_m)))
vint64m2_t vslidedown(vbool32_t, vint64m2_t, vint64m2_t, size_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vslidedown_vx)))
vint64m4_t vslidedown(vint64m4_t, vint64m4_t, size_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vslidedown_vx_m)))
vint64m4_t vslidedown(vbool16_t, vint64m4_t, vint64m4_t, size_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vslidedown_vx)))
vint64m8_t vslidedown(vint64m8_t, vint64m8_t, size_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vslidedown_vx_m)))
vint64m8_t vslidedown(vbool8_t, vint64m8_t, vint64m8_t, size_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vslidedown_vx)))
vuint64m1_t vslidedown(vuint64m1_t, vuint64m1_t, size_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vslidedown_vx_m)))
vuint64m1_t vslidedown(vbool64_t, vuint64m1_t, vuint64m1_t, size_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vslidedown_vx)))
vuint64m2_t vslidedown(vuint64m2_t, vuint64m2_t, size_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vslidedown_vx_m)))
vuint64m2_t vslidedown(vbool32_t, vuint64m2_t, vuint64m2_t, size_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vslidedown_vx)))
vuint64m4_t vslidedown(vuint64m4_t, vuint64m4_t, size_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vslidedown_vx_m)))
vuint64m4_t vslidedown(vbool16_t, vuint64m4_t, vuint64m4_t, size_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vslidedown_vx)))
vuint64m8_t vslidedown(vuint64m8_t, vuint64m8_t, size_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vslidedown_vx_m)))
vuint64m8_t vslidedown(vbool8_t, vuint64m8_t, vuint64m8_t, size_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vslide1up_vx)))
vint64m1_t vslide1up(vint64m1_t, int64_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vslide1up_vx_m)))
vint64m1_t vslide1up(vbool64_t, vint64m1_t, vint64m1_t, int64_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vslide1up_vx)))
vint64m2_t vslide1up(vint64m2_t, int64_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vslide1up_vx_m)))
vint64m2_t vslide1up(vbool32_t, vint64m2_t, vint64m2_t, int64_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vslide1up_vx)))
vint64m4_t vslide1up(vint64m4_t, int64_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vslide1up_vx_m)))
vint64m4_t vslide1up(vbool16_t, vint64m4_t, vint64m4_t, int64_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vslide1up_vx)))
vint64m8_t vslide1up(vint64m8_t, int64_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vslide1up_vx_m)))
vint64m8_t vslide1up(vbool8_t, vint64m8_t, vint64m8_t, int64_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vslide1up_vx)))
vuint64m1_t vslide1up(vuint64m1_t, int64_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vslide1up_vx_m)))
vuint64m1_t vslide1up(vbool64_t, vuint64m1_t, vuint64m1_t, int64_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vslide1up_vx)))
vuint64m2_t vslide1up(vuint64m2_t, int64_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vslide1up_vx_m)))
vuint64m2_t vslide1up(vbool32_t, vuint64m2_t, vuint64m2_t, int64_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vslide1up_vx)))
vuint64m4_t vslide1up(vuint64m4_t, int64_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vslide1up_vx_m)))
vuint64m4_t vslide1up(vbool16_t, vuint64m4_t, vuint64m4_t, int64_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vslide1up_vx)))
vuint64m8_t vslide1up(vuint64m8_t, int64_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vslide1up_vx_m)))
vuint64m8_t vslide1up(vbool8_t, vuint64m8_t, vuint64m8_t, int64_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vsuxei8_v)))
void vsuxei8(int64_t *, vuint8mf8_t, vint64m1_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vsuxei8_v_m)))
void vsuxei8(vbool64_t, int64_t *, vuint8mf8_t, vint64m1_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vsuxei8_v)))
void vsuxei8(int64_t *, vuint8mf4_t, vint64m2_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vsuxei8_v_m)))
void vsuxei8(vbool32_t, int64_t *, vuint8mf4_t, vint64m2_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vsuxei8_v)))
void vsuxei8(int64_t *, vuint8mf2_t, vint64m4_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vsuxei8_v_m)))
void vsuxei8(vbool16_t, int64_t *, vuint8mf2_t, vint64m4_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vsuxei8_v)))
void vsuxei8(int64_t *, vuint8m1_t, vint64m8_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vsuxei8_v_m)))
void vsuxei8(vbool8_t, int64_t *, vuint8m1_t, vint64m8_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vslide1down_vx)))
vint64m1_t vslide1down(vint64m1_t, int64_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vslide1down_vx_m)))
vint64m1_t vslide1down(vbool64_t, vint64m1_t, vint64m1_t, int64_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vslide1down_vx)))
vint64m2_t vslide1down(vint64m2_t, int64_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vslide1down_vx_m)))
vint64m2_t vslide1down(vbool32_t, vint64m2_t, vint64m2_t, int64_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vslide1down_vx)))
vint64m4_t vslide1down(vint64m4_t, int64_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vslide1down_vx_m)))
vint64m4_t vslide1down(vbool16_t, vint64m4_t, vint64m4_t, int64_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vslide1down_vx)))
vint64m8_t vslide1down(vint64m8_t, int64_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vslide1down_vx_m)))
vint64m8_t vslide1down(vbool8_t, vint64m8_t, vint64m8_t, int64_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vslide1down_vx)))
vuint64m1_t vslide1down(vuint64m1_t, int64_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vslide1down_vx_m)))
vuint64m1_t vslide1down(vbool64_t, vuint64m1_t, vuint64m1_t, int64_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vslide1down_vx)))
vuint64m2_t vslide1down(vuint64m2_t, int64_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vslide1down_vx_m)))
vuint64m2_t vslide1down(vbool32_t, vuint64m2_t, vuint64m2_t, int64_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vslide1down_vx)))
vuint64m4_t vslide1down(vuint64m4_t, int64_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vslide1down_vx_m)))
vuint64m4_t vslide1down(vbool16_t, vuint64m4_t, vuint64m4_t, int64_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vslide1down_vx)))
vuint64m8_t vslide1down(vuint64m8_t, int64_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vslide1down_vx_m)))
vuint64m8_t vslide1down(vbool8_t, vuint64m8_t, vuint64m8_t, int64_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vrgather_vv)))
vint64m1_t vrgather(vint64m1_t, vuint64m1_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vrgather_vv_m)))
vint64m1_t vrgather(vbool64_t, vint64m1_t, vint64m1_t, vuint64m1_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vrgather_vv)))
vint64m2_t vrgather(vint64m2_t, vuint64m2_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vrgather_vv_m)))
vint64m2_t vrgather(vbool32_t, vint64m2_t, vint64m2_t, vuint64m2_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vrgather_vv)))
vint64m4_t vrgather(vint64m4_t, vuint64m4_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vrgather_vv_m)))
vint64m4_t vrgather(vbool16_t, vint64m4_t, vint64m4_t, vuint64m4_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vrgather_vv)))
vint64m8_t vrgather(vint64m8_t, vuint64m8_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vrgather_vv_m)))
vint64m8_t vrgather(vbool8_t, vint64m8_t, vint64m8_t, vuint64m8_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vrgather_vx)))
vint64m1_t vrgather(vint64m1_t, size_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vrgather_vx_m)))
vint64m1_t vrgather(vbool64_t, vint64m1_t, vint64m1_t, size_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vrgather_vx)))
vint64m2_t vrgather(vint64m2_t, size_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vrgather_vx_m)))
vint64m2_t vrgather(vbool32_t, vint64m2_t, vint64m2_t, size_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vrgather_vx)))
vint64m4_t vrgather(vint64m4_t, size_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vrgather_vx_m)))
vint64m4_t vrgather(vbool16_t, vint64m4_t, vint64m4_t, size_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vrgather_vx)))
vint64m8_t vrgather(vint64m8_t, size_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vrgather_vx_m)))
vint64m8_t vrgather(vbool8_t, vint64m8_t, vint64m8_t, size_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vrgatherei16_vv)))
vint64m1_t vrgatherei16(vint64m1_t, vuint16mf4_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vrgatherei16_vv_m)))
vint64m1_t vrgatherei16(vbool64_t, vint64m1_t, vint64m1_t, vuint16mf4_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vrgatherei16_vv)))
vint64m2_t vrgatherei16(vint64m2_t, vuint16mf2_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vrgatherei16_vv_m)))
vint64m2_t vrgatherei16(vbool32_t, vint64m2_t, vint64m2_t, vuint16mf2_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vrgatherei16_vv)))
vint64m4_t vrgatherei16(vint64m4_t, vuint16m1_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vrgatherei16_vv_m)))
vint64m4_t vrgatherei16(vbool16_t, vint64m4_t, vint64m4_t, vuint16m1_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vrgatherei16_vv)))
vint64m8_t vrgatherei16(vint64m8_t, vuint16m2_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vrgatherei16_vv_m)))
vint64m8_t vrgatherei16(vbool8_t, vint64m8_t, vint64m8_t, vuint16m2_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vrgather_vv)))
vuint64m1_t vrgather(vuint64m1_t, vuint64m1_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vrgather_vv_m)))
vuint64m1_t vrgather(vbool64_t, vuint64m1_t, vuint64m1_t, vuint64m1_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vrgather_vv)))
vuint64m2_t vrgather(vuint64m2_t, vuint64m2_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vrgather_vv_m)))
vuint64m2_t vrgather(vbool32_t, vuint64m2_t, vuint64m2_t, vuint64m2_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vrgather_vv)))
vuint64m4_t vrgather(vuint64m4_t, vuint64m4_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vrgather_vv_m)))
vuint64m4_t vrgather(vbool16_t, vuint64m4_t, vuint64m4_t, vuint64m4_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vrgather_vv)))
vuint64m8_t vrgather(vuint64m8_t, vuint64m8_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vrgather_vv_m)))
vuint64m8_t vrgather(vbool8_t, vuint64m8_t, vuint64m8_t, vuint64m8_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vrgather_vx)))
vuint64m1_t vrgather(vuint64m1_t, size_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vrgather_vx_m)))
vuint64m1_t vrgather(vbool64_t, vuint64m1_t, vuint64m1_t, size_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vrgather_vx)))
vuint64m2_t vrgather(vuint64m2_t, size_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vrgather_vx_m)))
vuint64m2_t vrgather(vbool32_t, vuint64m2_t, vuint64m2_t, size_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vrgather_vx)))
vuint64m4_t vrgather(vuint64m4_t, size_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vrgather_vx_m)))
vuint64m4_t vrgather(vbool16_t, vuint64m4_t, vuint64m4_t, size_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vrgather_vx)))
vuint64m8_t vrgather(vuint64m8_t, size_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vrgather_vx_m)))
vuint64m8_t vrgather(vbool8_t, vuint64m8_t, vuint64m8_t, size_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vrgatherei16_vv)))
vuint64m1_t vrgatherei16(vuint64m1_t, vuint16mf4_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vrgatherei16_vv_m)))
vuint64m1_t vrgatherei16(vbool64_t, vuint64m1_t, vuint64m1_t, vuint16mf4_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vrgatherei16_vv)))
vuint64m2_t vrgatherei16(vuint64m2_t, vuint16mf2_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vrgatherei16_vv_m)))
vuint64m2_t vrgatherei16(vbool32_t, vuint64m2_t, vuint64m2_t, vuint16mf2_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vrgatherei16_vv)))
vuint64m4_t vrgatherei16(vuint64m4_t, vuint16m1_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vrgatherei16_vv_m)))
vuint64m4_t vrgatherei16(vbool16_t, vuint64m4_t, vuint64m4_t, vuint16m1_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vrgatherei16_vv)))
vuint64m8_t vrgatherei16(vuint64m8_t, vuint16m2_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vrgatherei16_vv_m)))
vuint64m8_t vrgatherei16(vbool8_t, vuint64m8_t, vuint64m8_t, vuint16m2_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vcompress_vm)))
vint64m1_t vcompress(vbool64_t, vint64m1_t, vint64m1_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vcompress_vm)))
vint64m2_t vcompress(vbool32_t, vint64m2_t, vint64m2_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vcompress_vm)))
vint64m4_t vcompress(vbool16_t, vint64m4_t, vint64m4_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vcompress_vm)))
vint64m8_t vcompress(vbool8_t, vint64m8_t, vint64m8_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vsuxei8_v)))
void vsuxei8(uint64_t *, vuint8mf8_t, vuint64m1_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vsuxei8_v_m)))
void vsuxei8(vbool64_t, uint64_t *, vuint8mf8_t, vuint64m1_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vsuxei8_v)))
void vsuxei8(uint64_t *, vuint8mf4_t, vuint64m2_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vsuxei8_v_m)))
void vsuxei8(vbool32_t, uint64_t *, vuint8mf4_t, vuint64m2_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vsuxei8_v)))
void vsuxei8(uint64_t *, vuint8mf2_t, vuint64m4_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vsuxei8_v_m)))
void vsuxei8(vbool16_t, uint64_t *, vuint8mf2_t, vuint64m4_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vsuxei8_v)))
void vsuxei8(uint64_t *, vuint8m1_t, vuint64m8_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vsuxei8_v_m)))
void vsuxei8(vbool8_t, uint64_t *, vuint8m1_t, vuint64m8_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vcompress_vm)))
vuint64m1_t vcompress(vbool64_t, vuint64m1_t, vuint64m1_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vcompress_vm)))
vuint64m2_t vcompress(vbool32_t, vuint64m2_t, vuint64m2_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vcompress_vm)))
vuint64m4_t vcompress(vbool16_t, vuint64m4_t, vuint64m4_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vcompress_vm)))
vuint64m8_t vcompress(vbool8_t, vuint64m8_t, vuint64m8_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vget_v)))
vint64m1_t vget_i64m1(vint64m2_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vget_v)))
vint64m1_t vget_i64m1(vint64m4_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vget_v)))
vint64m1_t vget_i64m1(vint64m8_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vget_v)))
vuint64m1_t vget_u64m1(vuint64m2_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vget_v)))
vuint64m1_t vget_u64m1(vuint64m4_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vget_v)))
vuint64m1_t vget_u64m1(vuint64m8_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vget_v)))
vint64m2_t vget_i64m2(vint64m4_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vget_v)))
vint64m2_t vget_i64m2(vint64m8_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vget_v)))
vuint64m2_t vget_u64m2(vuint64m4_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vget_v)))
vuint64m2_t vget_u64m2(vuint64m8_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vget_v)))
vint64m4_t vget_i64m4(vint64m8_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vget_v)))
vuint64m4_t vget_u64m4(vuint64m8_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vset_v)))
vint64m2_t vset(vint64m2_t, size_t, vint64m1_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vset_v)))
vuint64m2_t vset(vuint64m2_t, size_t, vuint64m1_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vset_v)))
vint64m4_t vset(vint64m4_t, size_t, vint64m1_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vset_v)))
vint64m4_t vset(vint64m4_t, size_t, vint64m2_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vsuxei16_v)))
void vsuxei16(int64_t *, vuint16mf4_t, vint64m1_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vsuxei16_v_m)))
void vsuxei16(vbool64_t, int64_t *, vuint16mf4_t, vint64m1_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vsuxei16_v)))
void vsuxei16(int64_t *, vuint16mf2_t, vint64m2_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vsuxei16_v_m)))
void vsuxei16(vbool32_t, int64_t *, vuint16mf2_t, vint64m2_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vsuxei16_v)))
void vsuxei16(int64_t *, vuint16m1_t, vint64m4_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vsuxei16_v_m)))
void vsuxei16(vbool16_t, int64_t *, vuint16m1_t, vint64m4_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vsuxei16_v)))
void vsuxei16(int64_t *, vuint16m2_t, vint64m8_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vsuxei16_v_m)))
void vsuxei16(vbool8_t, int64_t *, vuint16m2_t, vint64m8_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vset_v)))
vuint64m4_t vset(vuint64m4_t, size_t, vuint64m1_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vset_v)))
vuint64m4_t vset(vuint64m4_t, size_t, vuint64m2_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vset_v)))
vint64m8_t vset(vint64m8_t, size_t, vint64m1_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vset_v)))
vint64m8_t vset(vint64m8_t, size_t, vint64m2_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vset_v)))
vint64m8_t vset(vint64m8_t, size_t, vint64m4_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vset_v)))
vuint64m8_t vset(vuint64m8_t, size_t, vuint64m1_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vset_v)))
vuint64m8_t vset(vuint64m8_t, size_t, vuint64m2_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vset_v)))
vuint64m8_t vset(vuint64m8_t, size_t, vuint64m4_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vsuxei16_v)))
void vsuxei16(uint64_t *, vuint16mf4_t, vuint64m1_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vsuxei16_v_m)))
void vsuxei16(vbool64_t, uint64_t *, vuint16mf4_t, vuint64m1_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vsuxei16_v)))
void vsuxei16(uint64_t *, vuint16mf2_t, vuint64m2_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vsuxei16_v_m)))
void vsuxei16(vbool32_t, uint64_t *, vuint16mf2_t, vuint64m2_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vsuxei16_v)))
void vsuxei16(uint64_t *, vuint16m1_t, vuint64m4_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vsuxei16_v_m)))
void vsuxei16(vbool16_t, uint64_t *, vuint16m1_t, vuint64m4_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vsuxei16_v)))
void vsuxei16(uint64_t *, vuint16m2_t, vuint64m8_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vsuxei16_v_m)))
void vsuxei16(vbool8_t, uint64_t *, vuint16m2_t, vuint64m8_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vsuxei32_v)))
void vsuxei32(int64_t *, vuint32mf2_t, vint64m1_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vsuxei32_v_m)))
void vsuxei32(vbool64_t, int64_t *, vuint32mf2_t, vint64m1_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vsuxei32_v)))
void vsuxei32(int64_t *, vuint32m1_t, vint64m2_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vsuxei32_v_m)))
void vsuxei32(vbool32_t, int64_t *, vuint32m1_t, vint64m2_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vsuxei32_v)))
void vsuxei32(int64_t *, vuint32m2_t, vint64m4_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vsuxei32_v_m)))
void vsuxei32(vbool16_t, int64_t *, vuint32m2_t, vint64m4_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vsuxei32_v)))
void vsuxei32(int64_t *, vuint32m4_t, vint64m8_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vsuxei32_v_m)))
void vsuxei32(vbool8_t, int64_t *, vuint32m4_t, vint64m8_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vsuxei32_v)))
void vsuxei32(uint64_t *, vuint32mf2_t, vuint64m1_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vsuxei32_v_m)))
void vsuxei32(vbool64_t, uint64_t *, vuint32mf2_t, vuint64m1_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vsuxei32_v)))
void vsuxei32(uint64_t *, vuint32m1_t, vuint64m2_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vsuxei32_v_m)))
void vsuxei32(vbool32_t, uint64_t *, vuint32m1_t, vuint64m2_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vsuxei32_v)))
void vsuxei32(uint64_t *, vuint32m2_t, vuint64m4_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vsuxei32_v_m)))
void vsuxei32(vbool16_t, uint64_t *, vuint32m2_t, vuint64m4_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vsuxei32_v)))
void vsuxei32(uint64_t *, vuint32m4_t, vuint64m8_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vsuxei32_v_m)))
void vsuxei32(vbool8_t, uint64_t *, vuint32m4_t, vuint64m8_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vsoxei8_v)))
void vsoxei8(int64_t *, vuint8mf8_t, vint64m1_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vsoxei8_v_m)))
void vsoxei8(vbool64_t, int64_t *, vuint8mf8_t, vint64m1_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vsoxei8_v)))
void vsoxei8(int64_t *, vuint8mf4_t, vint64m2_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vsoxei8_v_m)))
void vsoxei8(vbool32_t, int64_t *, vuint8mf4_t, vint64m2_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vsoxei8_v)))
void vsoxei8(int64_t *, vuint8mf2_t, vint64m4_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vsoxei8_v_m)))
void vsoxei8(vbool16_t, int64_t *, vuint8mf2_t, vint64m4_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vsoxei8_v)))
void vsoxei8(int64_t *, vuint8m1_t, vint64m8_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vsoxei8_v_m)))
void vsoxei8(vbool8_t, int64_t *, vuint8m1_t, vint64m8_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vsoxei8_v)))
void vsoxei8(uint64_t *, vuint8mf8_t, vuint64m1_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vsoxei8_v_m)))
void vsoxei8(vbool64_t, uint64_t *, vuint8mf8_t, vuint64m1_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vsoxei8_v)))
void vsoxei8(uint64_t *, vuint8mf4_t, vuint64m2_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vsoxei8_v_m)))
void vsoxei8(vbool32_t, uint64_t *, vuint8mf4_t, vuint64m2_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vsoxei8_v)))
void vsoxei8(uint64_t *, vuint8mf2_t, vuint64m4_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vsoxei8_v_m)))
void vsoxei8(vbool16_t, uint64_t *, vuint8mf2_t, vuint64m4_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vsoxei8_v)))
void vsoxei8(uint64_t *, vuint8m1_t, vuint64m8_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vsoxei8_v_m)))
void vsoxei8(vbool8_t, uint64_t *, vuint8m1_t, vuint64m8_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vsoxei16_v)))
void vsoxei16(int64_t *, vuint16mf4_t, vint64m1_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vsoxei16_v_m)))
void vsoxei16(vbool64_t, int64_t *, vuint16mf4_t, vint64m1_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vsoxei16_v)))
void vsoxei16(int64_t *, vuint16mf2_t, vint64m2_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vsoxei16_v_m)))
void vsoxei16(vbool32_t, int64_t *, vuint16mf2_t, vint64m2_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vsoxei16_v)))
void vsoxei16(int64_t *, vuint16m1_t, vint64m4_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vsoxei16_v_m)))
void vsoxei16(vbool16_t, int64_t *, vuint16m1_t, vint64m4_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vsoxei16_v)))
void vsoxei16(int64_t *, vuint16m2_t, vint64m8_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vsoxei16_v_m)))
void vsoxei16(vbool8_t, int64_t *, vuint16m2_t, vint64m8_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vsoxei16_v)))
void vsoxei16(uint64_t *, vuint16mf4_t, vuint64m1_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vsoxei16_v_m)))
void vsoxei16(vbool64_t, uint64_t *, vuint16mf4_t, vuint64m1_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vsoxei16_v)))
void vsoxei16(uint64_t *, vuint16mf2_t, vuint64m2_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vsoxei16_v_m)))
void vsoxei16(vbool32_t, uint64_t *, vuint16mf2_t, vuint64m2_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vsoxei16_v)))
void vsoxei16(uint64_t *, vuint16m1_t, vuint64m4_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vsoxei16_v_m)))
void vsoxei16(vbool16_t, uint64_t *, vuint16m1_t, vuint64m4_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vsoxei16_v)))
void vsoxei16(uint64_t *, vuint16m2_t, vuint64m8_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vsoxei16_v_m)))
void vsoxei16(vbool8_t, uint64_t *, vuint16m2_t, vuint64m8_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vsoxei32_v)))
void vsoxei32(int64_t *, vuint32mf2_t, vint64m1_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vsoxei32_v_m)))
void vsoxei32(vbool64_t, int64_t *, vuint32mf2_t, vint64m1_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vsoxei32_v)))
void vsoxei32(int64_t *, vuint32m1_t, vint64m2_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vsoxei32_v_m)))
void vsoxei32(vbool32_t, int64_t *, vuint32m1_t, vint64m2_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vsoxei32_v)))
void vsoxei32(int64_t *, vuint32m2_t, vint64m4_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vsoxei32_v_m)))
void vsoxei32(vbool16_t, int64_t *, vuint32m2_t, vint64m4_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vsoxei32_v)))
void vsoxei32(int64_t *, vuint32m4_t, vint64m8_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vsoxei32_v_m)))
void vsoxei32(vbool8_t, int64_t *, vuint32m4_t, vint64m8_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vsoxei32_v)))
void vsoxei32(uint64_t *, vuint32mf2_t, vuint64m1_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vsoxei32_v_m)))
void vsoxei32(vbool64_t, uint64_t *, vuint32mf2_t, vuint64m1_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vsoxei32_v)))
void vsoxei32(uint64_t *, vuint32m1_t, vuint64m2_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vsoxei32_v_m)))
void vsoxei32(vbool32_t, uint64_t *, vuint32m1_t, vuint64m2_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vsoxei32_v)))
void vsoxei32(uint64_t *, vuint32m2_t, vuint64m4_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vsoxei32_v_m)))
void vsoxei32(vbool16_t, uint64_t *, vuint32m2_t, vuint64m4_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vsoxei32_v)))
void vsoxei32(uint64_t *, vuint32m4_t, vuint64m8_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vsoxei32_v_m)))
void vsoxei32(vbool8_t, uint64_t *, vuint32m4_t, vuint64m8_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vle64ff_v_m)))
vint64m1_t vle64ff(vbool64_t, vint64m1_t, const int64_t *, size_t *, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vle64ff_v_m)))
vint64m2_t vle64ff(vbool32_t, vint64m2_t, const int64_t *, size_t *, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vle64ff_v_m)))
vint64m4_t vle64ff(vbool16_t, vint64m4_t, const int64_t *, size_t *, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vle64ff_v_m)))
vint64m8_t vle64ff(vbool8_t, vint64m8_t, const int64_t *, size_t *, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vle64ff_v_m)))
vuint64m1_t vle64ff(vbool64_t, vuint64m1_t, const uint64_t *, size_t *, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vle64ff_v_m)))
vuint64m2_t vle64ff(vbool32_t, vuint64m2_t, const uint64_t *, size_t *, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vle64ff_v_m)))
vuint64m4_t vle64ff(vbool16_t, vuint64m4_t, const uint64_t *, size_t *, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vle64ff_v_m)))
vuint64m8_t vle64ff(vbool8_t, vuint64m8_t, const uint64_t *, size_t *, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vlseg2e64_v_m)))
void vlseg2e64(vint64m1_t *, vint64m1_t *, vbool64_t, vint64m1_t, vint64m1_t, const int64_t *, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vlseg2e64_v_m)))
void vlseg2e64(vint64m2_t *, vint64m2_t *, vbool32_t, vint64m2_t, vint64m2_t, const int64_t *, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vlseg2e64_v_m)))
void vlseg2e64(vint64m4_t *, vint64m4_t *, vbool16_t, vint64m4_t, vint64m4_t, const int64_t *, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vlseg2e64_v_m)))
void vlseg2e64(vuint64m1_t *, vuint64m1_t *, vbool64_t, vuint64m1_t, vuint64m1_t, const uint64_t *, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vlseg2e64_v_m)))
void vlseg2e64(vuint64m2_t *, vuint64m2_t *, vbool32_t, vuint64m2_t, vuint64m2_t, const uint64_t *, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vlseg2e64_v_m)))
void vlseg2e64(vuint64m4_t *, vuint64m4_t *, vbool16_t, vuint64m4_t, vuint64m4_t, const uint64_t *, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vlseg3e64_v_m)))
void vlseg3e64(vint64m1_t *, vint64m1_t *, vint64m1_t *, vbool64_t, vint64m1_t, vint64m1_t, vint64m1_t, const int64_t *, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vlseg3e64_v_m)))
void vlseg3e64(vint64m2_t *, vint64m2_t *, vint64m2_t *, vbool32_t, vint64m2_t, vint64m2_t, vint64m2_t, const int64_t *, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vlseg3e64_v_m)))
void vlseg3e64(vuint64m1_t *, vuint64m1_t *, vuint64m1_t *, vbool64_t, vuint64m1_t, vuint64m1_t, vuint64m1_t, const uint64_t *, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vlseg3e64_v_m)))
void vlseg3e64(vuint64m2_t *, vuint64m2_t *, vuint64m2_t *, vbool32_t, vuint64m2_t, vuint64m2_t, vuint64m2_t, const uint64_t *, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vlseg4e64_v_m)))
void vlseg4e64(vint64m1_t *, vint64m1_t *, vint64m1_t *, vint64m1_t *, vbool64_t, vint64m1_t, vint64m1_t, vint64m1_t, vint64m1_t, const int64_t *, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vlseg4e64_v_m)))
void vlseg4e64(vint64m2_t *, vint64m2_t *, vint64m2_t *, vint64m2_t *, vbool32_t, vint64m2_t, vint64m2_t, vint64m2_t, vint64m2_t, const int64_t *, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vlseg4e64_v_m)))
void vlseg4e64(vuint64m1_t *, vuint64m1_t *, vuint64m1_t *, vuint64m1_t *, vbool64_t, vuint64m1_t, vuint64m1_t, vuint64m1_t, vuint64m1_t, const uint64_t *, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vlseg4e64_v_m)))
void vlseg4e64(vuint64m2_t *, vuint64m2_t *, vuint64m2_t *, vuint64m2_t *, vbool32_t, vuint64m2_t, vuint64m2_t, vuint64m2_t, vuint64m2_t, const uint64_t *, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vlseg5e64_v_m)))
void vlseg5e64(vint64m1_t *, vint64m1_t *, vint64m1_t *, vint64m1_t *, vint64m1_t *, vbool64_t, vint64m1_t, vint64m1_t, vint64m1_t, vint64m1_t, vint64m1_t, const int64_t *, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vlseg5e64_v_m)))
void vlseg5e64(vuint64m1_t *, vuint64m1_t *, vuint64m1_t *, vuint64m1_t *, vuint64m1_t *, vbool64_t, vuint64m1_t, vuint64m1_t, vuint64m1_t, vuint64m1_t, vuint64m1_t, const uint64_t *, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vlseg6e64_v_m)))
void vlseg6e64(vint64m1_t *, vint64m1_t *, vint64m1_t *, vint64m1_t *, vint64m1_t *, vint64m1_t *, vbool64_t, vint64m1_t, vint64m1_t, vint64m1_t, vint64m1_t, vint64m1_t, vint64m1_t, const int64_t *, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vlseg6e64_v_m)))
void vlseg6e64(vuint64m1_t *, vuint64m1_t *, vuint64m1_t *, vuint64m1_t *, vuint64m1_t *, vuint64m1_t *, vbool64_t, vuint64m1_t, vuint64m1_t, vuint64m1_t, vuint64m1_t, vuint64m1_t, vuint64m1_t, const uint64_t *, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vlseg7e64_v_m)))
void vlseg7e64(vint64m1_t *, vint64m1_t *, vint64m1_t *, vint64m1_t *, vint64m1_t *, vint64m1_t *, vint64m1_t *, vbool64_t, vint64m1_t, vint64m1_t, vint64m1_t, vint64m1_t, vint64m1_t, vint64m1_t, vint64m1_t, const int64_t *, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vlseg7e64_v_m)))
void vlseg7e64(vuint64m1_t *, vuint64m1_t *, vuint64m1_t *, vuint64m1_t *, vuint64m1_t *, vuint64m1_t *, vuint64m1_t *, vbool64_t, vuint64m1_t, vuint64m1_t, vuint64m1_t, vuint64m1_t, vuint64m1_t, vuint64m1_t, vuint64m1_t, const uint64_t *, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vlseg8e64_v_m)))
void vlseg8e64(vint64m1_t *, vint64m1_t *, vint64m1_t *, vint64m1_t *, vint64m1_t *, vint64m1_t *, vint64m1_t *, vint64m1_t *, vbool64_t, vint64m1_t, vint64m1_t, vint64m1_t, vint64m1_t, vint64m1_t, vint64m1_t, vint64m1_t, vint64m1_t, const int64_t *, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vlseg8e64_v_m)))
void vlseg8e64(vuint64m1_t *, vuint64m1_t *, vuint64m1_t *, vuint64m1_t *, vuint64m1_t *, vuint64m1_t *, vuint64m1_t *, vuint64m1_t *, vbool64_t, vuint64m1_t, vuint64m1_t, vuint64m1_t, vuint64m1_t, vuint64m1_t, vuint64m1_t, vuint64m1_t, vuint64m1_t, const uint64_t *, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vlseg2e64ff_v_m)))
void vlseg2e64ff(vint64m1_t *, vint64m1_t *, vbool64_t, vint64m1_t, vint64m1_t, const int64_t *, size_t *, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vlseg2e64ff_v_m)))
void vlseg2e64ff(vint64m2_t *, vint64m2_t *, vbool32_t, vint64m2_t, vint64m2_t, const int64_t *, size_t *, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vlseg2e64ff_v_m)))
void vlseg2e64ff(vint64m4_t *, vint64m4_t *, vbool16_t, vint64m4_t, vint64m4_t, const int64_t *, size_t *, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vlseg2e64ff_v_m)))
void vlseg2e64ff(vuint64m1_t *, vuint64m1_t *, vbool64_t, vuint64m1_t, vuint64m1_t, const uint64_t *, size_t *, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vlseg2e64ff_v_m)))
void vlseg2e64ff(vuint64m2_t *, vuint64m2_t *, vbool32_t, vuint64m2_t, vuint64m2_t, const uint64_t *, size_t *, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vlseg2e64ff_v_m)))
void vlseg2e64ff(vuint64m4_t *, vuint64m4_t *, vbool16_t, vuint64m4_t, vuint64m4_t, const uint64_t *, size_t *, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vlseg3e64ff_v_m)))
void vlseg3e64ff(vint64m1_t *, vint64m1_t *, vint64m1_t *, vbool64_t, vint64m1_t, vint64m1_t, vint64m1_t, const int64_t *, size_t *, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vlseg3e64ff_v_m)))
void vlseg3e64ff(vint64m2_t *, vint64m2_t *, vint64m2_t *, vbool32_t, vint64m2_t, vint64m2_t, vint64m2_t, const int64_t *, size_t *, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vlseg3e64ff_v_m)))
void vlseg3e64ff(vuint64m1_t *, vuint64m1_t *, vuint64m1_t *, vbool64_t, vuint64m1_t, vuint64m1_t, vuint64m1_t, const uint64_t *, size_t *, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vlseg3e64ff_v_m)))
void vlseg3e64ff(vuint64m2_t *, vuint64m2_t *, vuint64m2_t *, vbool32_t, vuint64m2_t, vuint64m2_t, vuint64m2_t, const uint64_t *, size_t *, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vlseg4e64ff_v_m)))
void vlseg4e64ff(vint64m1_t *, vint64m1_t *, vint64m1_t *, vint64m1_t *, vbool64_t, vint64m1_t, vint64m1_t, vint64m1_t, vint64m1_t, const int64_t *, size_t *, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vlseg4e64ff_v_m)))
void vlseg4e64ff(vint64m2_t *, vint64m2_t *, vint64m2_t *, vint64m2_t *, vbool32_t, vint64m2_t, vint64m2_t, vint64m2_t, vint64m2_t, const int64_t *, size_t *, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vlseg4e64ff_v_m)))
void vlseg4e64ff(vuint64m1_t *, vuint64m1_t *, vuint64m1_t *, vuint64m1_t *, vbool64_t, vuint64m1_t, vuint64m1_t, vuint64m1_t, vuint64m1_t, const uint64_t *, size_t *, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vlseg4e64ff_v_m)))
void vlseg4e64ff(vuint64m2_t *, vuint64m2_t *, vuint64m2_t *, vuint64m2_t *, vbool32_t, vuint64m2_t, vuint64m2_t, vuint64m2_t, vuint64m2_t, const uint64_t *, size_t *, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vlseg5e64ff_v_m)))
void vlseg5e64ff(vint64m1_t *, vint64m1_t *, vint64m1_t *, vint64m1_t *, vint64m1_t *, vbool64_t, vint64m1_t, vint64m1_t, vint64m1_t, vint64m1_t, vint64m1_t, const int64_t *, size_t *, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vlseg5e64ff_v_m)))
void vlseg5e64ff(vuint64m1_t *, vuint64m1_t *, vuint64m1_t *, vuint64m1_t *, vuint64m1_t *, vbool64_t, vuint64m1_t, vuint64m1_t, vuint64m1_t, vuint64m1_t, vuint64m1_t, const uint64_t *, size_t *, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vlseg6e64ff_v_m)))
void vlseg6e64ff(vint64m1_t *, vint64m1_t *, vint64m1_t *, vint64m1_t *, vint64m1_t *, vint64m1_t *, vbool64_t, vint64m1_t, vint64m1_t, vint64m1_t, vint64m1_t, vint64m1_t, vint64m1_t, const int64_t *, size_t *, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vlseg6e64ff_v_m)))
void vlseg6e64ff(vuint64m1_t *, vuint64m1_t *, vuint64m1_t *, vuint64m1_t *, vuint64m1_t *, vuint64m1_t *, vbool64_t, vuint64m1_t, vuint64m1_t, vuint64m1_t, vuint64m1_t, vuint64m1_t, vuint64m1_t, const uint64_t *, size_t *, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vlseg7e64ff_v_m)))
void vlseg7e64ff(vint64m1_t *, vint64m1_t *, vint64m1_t *, vint64m1_t *, vint64m1_t *, vint64m1_t *, vint64m1_t *, vbool64_t, vint64m1_t, vint64m1_t, vint64m1_t, vint64m1_t, vint64m1_t, vint64m1_t, vint64m1_t, const int64_t *, size_t *, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vlseg7e64ff_v_m)))
void vlseg7e64ff(vuint64m1_t *, vuint64m1_t *, vuint64m1_t *, vuint64m1_t *, vuint64m1_t *, vuint64m1_t *, vuint64m1_t *, vbool64_t, vuint64m1_t, vuint64m1_t, vuint64m1_t, vuint64m1_t, vuint64m1_t, vuint64m1_t, vuint64m1_t, const uint64_t *, size_t *, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vlseg8e64ff_v_m)))
void vlseg8e64ff(vint64m1_t *, vint64m1_t *, vint64m1_t *, vint64m1_t *, vint64m1_t *, vint64m1_t *, vint64m1_t *, vint64m1_t *, vbool64_t, vint64m1_t, vint64m1_t, vint64m1_t, vint64m1_t, vint64m1_t, vint64m1_t, vint64m1_t, vint64m1_t, const int64_t *, size_t *, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vlseg8e64ff_v_m)))
void vlseg8e64ff(vuint64m1_t *, vuint64m1_t *, vuint64m1_t *, vuint64m1_t *, vuint64m1_t *, vuint64m1_t *, vuint64m1_t *, vuint64m1_t *, vbool64_t, vuint64m1_t, vuint64m1_t, vuint64m1_t, vuint64m1_t, vuint64m1_t, vuint64m1_t, vuint64m1_t, vuint64m1_t, const uint64_t *, size_t *, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vlsseg2e64_v_m)))
void vlsseg2e64(vint64m1_t *, vint64m1_t *, vbool64_t, vint64m1_t, vint64m1_t, const int64_t *, ptrdiff_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vlsseg2e64_v_m)))
void vlsseg2e64(vint64m2_t *, vint64m2_t *, vbool32_t, vint64m2_t, vint64m2_t, const int64_t *, ptrdiff_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vlsseg2e64_v_m)))
void vlsseg2e64(vint64m4_t *, vint64m4_t *, vbool16_t, vint64m4_t, vint64m4_t, const int64_t *, ptrdiff_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vlsseg2e64_v_m)))
void vlsseg2e64(vuint64m1_t *, vuint64m1_t *, vbool64_t, vuint64m1_t, vuint64m1_t, const uint64_t *, ptrdiff_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vlsseg2e64_v_m)))
void vlsseg2e64(vuint64m2_t *, vuint64m2_t *, vbool32_t, vuint64m2_t, vuint64m2_t, const uint64_t *, ptrdiff_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vlsseg2e64_v_m)))
void vlsseg2e64(vuint64m4_t *, vuint64m4_t *, vbool16_t, vuint64m4_t, vuint64m4_t, const uint64_t *, ptrdiff_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vlsseg3e64_v_m)))
void vlsseg3e64(vint64m1_t *, vint64m1_t *, vint64m1_t *, vbool64_t, vint64m1_t, vint64m1_t, vint64m1_t, const int64_t *, ptrdiff_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vlsseg3e64_v_m)))
void vlsseg3e64(vint64m2_t *, vint64m2_t *, vint64m2_t *, vbool32_t, vint64m2_t, vint64m2_t, vint64m2_t, const int64_t *, ptrdiff_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vlsseg3e64_v_m)))
void vlsseg3e64(vuint64m1_t *, vuint64m1_t *, vuint64m1_t *, vbool64_t, vuint64m1_t, vuint64m1_t, vuint64m1_t, const uint64_t *, ptrdiff_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vlsseg3e64_v_m)))
void vlsseg3e64(vuint64m2_t *, vuint64m2_t *, vuint64m2_t *, vbool32_t, vuint64m2_t, vuint64m2_t, vuint64m2_t, const uint64_t *, ptrdiff_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vlsseg4e64_v_m)))
void vlsseg4e64(vint64m1_t *, vint64m1_t *, vint64m1_t *, vint64m1_t *, vbool64_t, vint64m1_t, vint64m1_t, vint64m1_t, vint64m1_t, const int64_t *, ptrdiff_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vlsseg4e64_v_m)))
void vlsseg4e64(vint64m2_t *, vint64m2_t *, vint64m2_t *, vint64m2_t *, vbool32_t, vint64m2_t, vint64m2_t, vint64m2_t, vint64m2_t, const int64_t *, ptrdiff_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vlsseg4e64_v_m)))
void vlsseg4e64(vuint64m1_t *, vuint64m1_t *, vuint64m1_t *, vuint64m1_t *, vbool64_t, vuint64m1_t, vuint64m1_t, vuint64m1_t, vuint64m1_t, const uint64_t *, ptrdiff_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vlsseg4e64_v_m)))
void vlsseg4e64(vuint64m2_t *, vuint64m2_t *, vuint64m2_t *, vuint64m2_t *, vbool32_t, vuint64m2_t, vuint64m2_t, vuint64m2_t, vuint64m2_t, const uint64_t *, ptrdiff_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vlsseg5e64_v_m)))
void vlsseg5e64(vint64m1_t *, vint64m1_t *, vint64m1_t *, vint64m1_t *, vint64m1_t *, vbool64_t, vint64m1_t, vint64m1_t, vint64m1_t, vint64m1_t, vint64m1_t, const int64_t *, ptrdiff_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vlsseg5e64_v_m)))
void vlsseg5e64(vuint64m1_t *, vuint64m1_t *, vuint64m1_t *, vuint64m1_t *, vuint64m1_t *, vbool64_t, vuint64m1_t, vuint64m1_t, vuint64m1_t, vuint64m1_t, vuint64m1_t, const uint64_t *, ptrdiff_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vlsseg6e64_v_m)))
void vlsseg6e64(vint64m1_t *, vint64m1_t *, vint64m1_t *, vint64m1_t *, vint64m1_t *, vint64m1_t *, vbool64_t, vint64m1_t, vint64m1_t, vint64m1_t, vint64m1_t, vint64m1_t, vint64m1_t, const int64_t *, ptrdiff_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vlsseg6e64_v_m)))
void vlsseg6e64(vuint64m1_t *, vuint64m1_t *, vuint64m1_t *, vuint64m1_t *, vuint64m1_t *, vuint64m1_t *, vbool64_t, vuint64m1_t, vuint64m1_t, vuint64m1_t, vuint64m1_t, vuint64m1_t, vuint64m1_t, const uint64_t *, ptrdiff_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vlsseg7e64_v_m)))
void vlsseg7e64(vint64m1_t *, vint64m1_t *, vint64m1_t *, vint64m1_t *, vint64m1_t *, vint64m1_t *, vint64m1_t *, vbool64_t, vint64m1_t, vint64m1_t, vint64m1_t, vint64m1_t, vint64m1_t, vint64m1_t, vint64m1_t, const int64_t *, ptrdiff_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vlsseg7e64_v_m)))
void vlsseg7e64(vuint64m1_t *, vuint64m1_t *, vuint64m1_t *, vuint64m1_t *, vuint64m1_t *, vuint64m1_t *, vuint64m1_t *, vbool64_t, vuint64m1_t, vuint64m1_t, vuint64m1_t, vuint64m1_t, vuint64m1_t, vuint64m1_t, vuint64m1_t, const uint64_t *, ptrdiff_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vlsseg8e64_v_m)))
void vlsseg8e64(vint64m1_t *, vint64m1_t *, vint64m1_t *, vint64m1_t *, vint64m1_t *, vint64m1_t *, vint64m1_t *, vint64m1_t *, vbool64_t, vint64m1_t, vint64m1_t, vint64m1_t, vint64m1_t, vint64m1_t, vint64m1_t, vint64m1_t, vint64m1_t, const int64_t *, ptrdiff_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vlsseg8e64_v_m)))
void vlsseg8e64(vuint64m1_t *, vuint64m1_t *, vuint64m1_t *, vuint64m1_t *, vuint64m1_t *, vuint64m1_t *, vuint64m1_t *, vuint64m1_t *, vbool64_t, vuint64m1_t, vuint64m1_t, vuint64m1_t, vuint64m1_t, vuint64m1_t, vuint64m1_t, vuint64m1_t, vuint64m1_t, const uint64_t *, ptrdiff_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vluxseg2ei64_v)))
void vluxseg2ei64(vint8m1_t *, vint8m1_t *, const int8_t *, vuint64m8_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vluxseg2ei64_v_m)))
void vluxseg2ei64(vint8m1_t *, vint8m1_t *, vbool8_t, vint8m1_t, vint8m1_t, const int8_t *, vuint64m8_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vluxseg2ei64_v)))
void vluxseg2ei64(vint8mf2_t *, vint8mf2_t *, const int8_t *, vuint64m4_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vluxseg2ei64_v_m)))
void vluxseg2ei64(vint8mf2_t *, vint8mf2_t *, vbool16_t, vint8mf2_t, vint8mf2_t, const int8_t *, vuint64m4_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vluxseg2ei64_v)))
void vluxseg2ei64(vint8mf4_t *, vint8mf4_t *, const int8_t *, vuint64m2_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vluxseg2ei64_v_m)))
void vluxseg2ei64(vint8mf4_t *, vint8mf4_t *, vbool32_t, vint8mf4_t, vint8mf4_t, const int8_t *, vuint64m2_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vluxseg2ei64_v)))
void vluxseg2ei64(vint8mf8_t *, vint8mf8_t *, const int8_t *, vuint64m1_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vluxseg2ei64_v_m)))
void vluxseg2ei64(vint8mf8_t *, vint8mf8_t *, vbool64_t, vint8mf8_t, vint8mf8_t, const int8_t *, vuint64m1_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vluxseg2ei64_v)))
void vluxseg2ei64(vuint8m1_t *, vuint8m1_t *, const uint8_t *, vuint64m8_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vluxseg2ei64_v_m)))
void vluxseg2ei64(vuint8m1_t *, vuint8m1_t *, vbool8_t, vuint8m1_t, vuint8m1_t, const uint8_t *, vuint64m8_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vluxseg2ei64_v)))
void vluxseg2ei64(vuint8mf2_t *, vuint8mf2_t *, const uint8_t *, vuint64m4_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vluxseg2ei64_v_m)))
void vluxseg2ei64(vuint8mf2_t *, vuint8mf2_t *, vbool16_t, vuint8mf2_t, vuint8mf2_t, const uint8_t *, vuint64m4_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vluxseg2ei64_v)))
void vluxseg2ei64(vuint8mf4_t *, vuint8mf4_t *, const uint8_t *, vuint64m2_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vluxseg2ei64_v_m)))
void vluxseg2ei64(vuint8mf4_t *, vuint8mf4_t *, vbool32_t, vuint8mf4_t, vuint8mf4_t, const uint8_t *, vuint64m2_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vluxseg2ei64_v)))
void vluxseg2ei64(vuint8mf8_t *, vuint8mf8_t *, const uint8_t *, vuint64m1_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vluxseg2ei64_v_m)))
void vluxseg2ei64(vuint8mf8_t *, vuint8mf8_t *, vbool64_t, vuint8mf8_t, vuint8mf8_t, const uint8_t *, vuint64m1_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vluxseg3ei64_v)))
void vluxseg3ei64(vint8m1_t *, vint8m1_t *, vint8m1_t *, const int8_t *, vuint64m8_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vluxseg3ei64_v_m)))
void vluxseg3ei64(vint8m1_t *, vint8m1_t *, vint8m1_t *, vbool8_t, vint8m1_t, vint8m1_t, vint8m1_t, const int8_t *, vuint64m8_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vluxseg3ei64_v)))
void vluxseg3ei64(vint8mf2_t *, vint8mf2_t *, vint8mf2_t *, const int8_t *, vuint64m4_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vluxseg3ei64_v_m)))
void vluxseg3ei64(vint8mf2_t *, vint8mf2_t *, vint8mf2_t *, vbool16_t, vint8mf2_t, vint8mf2_t, vint8mf2_t, const int8_t *, vuint64m4_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vluxseg3ei64_v)))
void vluxseg3ei64(vint8mf4_t *, vint8mf4_t *, vint8mf4_t *, const int8_t *, vuint64m2_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vluxseg3ei64_v_m)))
void vluxseg3ei64(vint8mf4_t *, vint8mf4_t *, vint8mf4_t *, vbool32_t, vint8mf4_t, vint8mf4_t, vint8mf4_t, const int8_t *, vuint64m2_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vluxseg3ei64_v)))
void vluxseg3ei64(vint8mf8_t *, vint8mf8_t *, vint8mf8_t *, const int8_t *, vuint64m1_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vluxseg3ei64_v_m)))
void vluxseg3ei64(vint8mf8_t *, vint8mf8_t *, vint8mf8_t *, vbool64_t, vint8mf8_t, vint8mf8_t, vint8mf8_t, const int8_t *, vuint64m1_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vluxseg3ei64_v)))
void vluxseg3ei64(vuint8m1_t *, vuint8m1_t *, vuint8m1_t *, const uint8_t *, vuint64m8_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vluxseg3ei64_v_m)))
void vluxseg3ei64(vuint8m1_t *, vuint8m1_t *, vuint8m1_t *, vbool8_t, vuint8m1_t, vuint8m1_t, vuint8m1_t, const uint8_t *, vuint64m8_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vluxseg3ei64_v)))
void vluxseg3ei64(vuint8mf2_t *, vuint8mf2_t *, vuint8mf2_t *, const uint8_t *, vuint64m4_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vluxseg3ei64_v_m)))
void vluxseg3ei64(vuint8mf2_t *, vuint8mf2_t *, vuint8mf2_t *, vbool16_t, vuint8mf2_t, vuint8mf2_t, vuint8mf2_t, const uint8_t *, vuint64m4_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vluxseg3ei64_v)))
void vluxseg3ei64(vuint8mf4_t *, vuint8mf4_t *, vuint8mf4_t *, const uint8_t *, vuint64m2_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vluxseg3ei64_v_m)))
void vluxseg3ei64(vuint8mf4_t *, vuint8mf4_t *, vuint8mf4_t *, vbool32_t, vuint8mf4_t, vuint8mf4_t, vuint8mf4_t, const uint8_t *, vuint64m2_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vluxseg3ei64_v)))
void vluxseg3ei64(vuint8mf8_t *, vuint8mf8_t *, vuint8mf8_t *, const uint8_t *, vuint64m1_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vluxseg3ei64_v_m)))
void vluxseg3ei64(vuint8mf8_t *, vuint8mf8_t *, vuint8mf8_t *, vbool64_t, vuint8mf8_t, vuint8mf8_t, vuint8mf8_t, const uint8_t *, vuint64m1_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vluxseg4ei64_v)))
void vluxseg4ei64(vint8m1_t *, vint8m1_t *, vint8m1_t *, vint8m1_t *, const int8_t *, vuint64m8_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vluxseg4ei64_v_m)))
void vluxseg4ei64(vint8m1_t *, vint8m1_t *, vint8m1_t *, vint8m1_t *, vbool8_t, vint8m1_t, vint8m1_t, vint8m1_t, vint8m1_t, const int8_t *, vuint64m8_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vluxseg4ei64_v)))
void vluxseg4ei64(vint8mf2_t *, vint8mf2_t *, vint8mf2_t *, vint8mf2_t *, const int8_t *, vuint64m4_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vluxseg4ei64_v_m)))
void vluxseg4ei64(vint8mf2_t *, vint8mf2_t *, vint8mf2_t *, vint8mf2_t *, vbool16_t, vint8mf2_t, vint8mf2_t, vint8mf2_t, vint8mf2_t, const int8_t *, vuint64m4_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vluxseg4ei64_v)))
void vluxseg4ei64(vint8mf4_t *, vint8mf4_t *, vint8mf4_t *, vint8mf4_t *, const int8_t *, vuint64m2_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vluxseg4ei64_v_m)))
void vluxseg4ei64(vint8mf4_t *, vint8mf4_t *, vint8mf4_t *, vint8mf4_t *, vbool32_t, vint8mf4_t, vint8mf4_t, vint8mf4_t, vint8mf4_t, const int8_t *, vuint64m2_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vluxseg4ei64_v)))
void vluxseg4ei64(vint8mf8_t *, vint8mf8_t *, vint8mf8_t *, vint8mf8_t *, const int8_t *, vuint64m1_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vluxseg4ei64_v_m)))
void vluxseg4ei64(vint8mf8_t *, vint8mf8_t *, vint8mf8_t *, vint8mf8_t *, vbool64_t, vint8mf8_t, vint8mf8_t, vint8mf8_t, vint8mf8_t, const int8_t *, vuint64m1_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vluxseg4ei64_v)))
void vluxseg4ei64(vuint8m1_t *, vuint8m1_t *, vuint8m1_t *, vuint8m1_t *, const uint8_t *, vuint64m8_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vluxseg4ei64_v_m)))
void vluxseg4ei64(vuint8m1_t *, vuint8m1_t *, vuint8m1_t *, vuint8m1_t *, vbool8_t, vuint8m1_t, vuint8m1_t, vuint8m1_t, vuint8m1_t, const uint8_t *, vuint64m8_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vluxseg4ei64_v)))
void vluxseg4ei64(vuint8mf2_t *, vuint8mf2_t *, vuint8mf2_t *, vuint8mf2_t *, const uint8_t *, vuint64m4_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vluxseg4ei64_v_m)))
void vluxseg4ei64(vuint8mf2_t *, vuint8mf2_t *, vuint8mf2_t *, vuint8mf2_t *, vbool16_t, vuint8mf2_t, vuint8mf2_t, vuint8mf2_t, vuint8mf2_t, const uint8_t *, vuint64m4_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vluxseg4ei64_v)))
void vluxseg4ei64(vuint8mf4_t *, vuint8mf4_t *, vuint8mf4_t *, vuint8mf4_t *, const uint8_t *, vuint64m2_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vluxseg4ei64_v_m)))
void vluxseg4ei64(vuint8mf4_t *, vuint8mf4_t *, vuint8mf4_t *, vuint8mf4_t *, vbool32_t, vuint8mf4_t, vuint8mf4_t, vuint8mf4_t, vuint8mf4_t, const uint8_t *, vuint64m2_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vluxseg4ei64_v)))
void vluxseg4ei64(vuint8mf8_t *, vuint8mf8_t *, vuint8mf8_t *, vuint8mf8_t *, const uint8_t *, vuint64m1_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vluxseg4ei64_v_m)))
void vluxseg4ei64(vuint8mf8_t *, vuint8mf8_t *, vuint8mf8_t *, vuint8mf8_t *, vbool64_t, vuint8mf8_t, vuint8mf8_t, vuint8mf8_t, vuint8mf8_t, const uint8_t *, vuint64m1_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vluxseg5ei64_v)))
void vluxseg5ei64(vint8m1_t *, vint8m1_t *, vint8m1_t *, vint8m1_t *, vint8m1_t *, const int8_t *, vuint64m8_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vluxseg5ei64_v_m)))
void vluxseg5ei64(vint8m1_t *, vint8m1_t *, vint8m1_t *, vint8m1_t *, vint8m1_t *, vbool8_t, vint8m1_t, vint8m1_t, vint8m1_t, vint8m1_t, vint8m1_t, const int8_t *, vuint64m8_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vluxseg5ei64_v)))
void vluxseg5ei64(vint8mf2_t *, vint8mf2_t *, vint8mf2_t *, vint8mf2_t *, vint8mf2_t *, const int8_t *, vuint64m4_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vluxseg5ei64_v_m)))
void vluxseg5ei64(vint8mf2_t *, vint8mf2_t *, vint8mf2_t *, vint8mf2_t *, vint8mf2_t *, vbool16_t, vint8mf2_t, vint8mf2_t, vint8mf2_t, vint8mf2_t, vint8mf2_t, const int8_t *, vuint64m4_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vluxseg5ei64_v)))
void vluxseg5ei64(vint8mf4_t *, vint8mf4_t *, vint8mf4_t *, vint8mf4_t *, vint8mf4_t *, const int8_t *, vuint64m2_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vluxseg5ei64_v_m)))
void vluxseg5ei64(vint8mf4_t *, vint8mf4_t *, vint8mf4_t *, vint8mf4_t *, vint8mf4_t *, vbool32_t, vint8mf4_t, vint8mf4_t, vint8mf4_t, vint8mf4_t, vint8mf4_t, const int8_t *, vuint64m2_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vluxseg5ei64_v)))
void vluxseg5ei64(vint8mf8_t *, vint8mf8_t *, vint8mf8_t *, vint8mf8_t *, vint8mf8_t *, const int8_t *, vuint64m1_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vluxseg5ei64_v_m)))
void vluxseg5ei64(vint8mf8_t *, vint8mf8_t *, vint8mf8_t *, vint8mf8_t *, vint8mf8_t *, vbool64_t, vint8mf8_t, vint8mf8_t, vint8mf8_t, vint8mf8_t, vint8mf8_t, const int8_t *, vuint64m1_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vluxseg5ei64_v)))
void vluxseg5ei64(vuint8m1_t *, vuint8m1_t *, vuint8m1_t *, vuint8m1_t *, vuint8m1_t *, const uint8_t *, vuint64m8_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vluxseg5ei64_v_m)))
void vluxseg5ei64(vuint8m1_t *, vuint8m1_t *, vuint8m1_t *, vuint8m1_t *, vuint8m1_t *, vbool8_t, vuint8m1_t, vuint8m1_t, vuint8m1_t, vuint8m1_t, vuint8m1_t, const uint8_t *, vuint64m8_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vluxseg5ei64_v)))
void vluxseg5ei64(vuint8mf2_t *, vuint8mf2_t *, vuint8mf2_t *, vuint8mf2_t *, vuint8mf2_t *, const uint8_t *, vuint64m4_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vluxseg5ei64_v_m)))
void vluxseg5ei64(vuint8mf2_t *, vuint8mf2_t *, vuint8mf2_t *, vuint8mf2_t *, vuint8mf2_t *, vbool16_t, vuint8mf2_t, vuint8mf2_t, vuint8mf2_t, vuint8mf2_t, vuint8mf2_t, const uint8_t *, vuint64m4_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vluxseg5ei64_v)))
void vluxseg5ei64(vuint8mf4_t *, vuint8mf4_t *, vuint8mf4_t *, vuint8mf4_t *, vuint8mf4_t *, const uint8_t *, vuint64m2_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vluxseg5ei64_v_m)))
void vluxseg5ei64(vuint8mf4_t *, vuint8mf4_t *, vuint8mf4_t *, vuint8mf4_t *, vuint8mf4_t *, vbool32_t, vuint8mf4_t, vuint8mf4_t, vuint8mf4_t, vuint8mf4_t, vuint8mf4_t, const uint8_t *, vuint64m2_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vluxseg5ei64_v)))
void vluxseg5ei64(vuint8mf8_t *, vuint8mf8_t *, vuint8mf8_t *, vuint8mf8_t *, vuint8mf8_t *, const uint8_t *, vuint64m1_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vluxseg5ei64_v_m)))
void vluxseg5ei64(vuint8mf8_t *, vuint8mf8_t *, vuint8mf8_t *, vuint8mf8_t *, vuint8mf8_t *, vbool64_t, vuint8mf8_t, vuint8mf8_t, vuint8mf8_t, vuint8mf8_t, vuint8mf8_t, const uint8_t *, vuint64m1_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vluxseg6ei64_v)))
void vluxseg6ei64(vint8m1_t *, vint8m1_t *, vint8m1_t *, vint8m1_t *, vint8m1_t *, vint8m1_t *, const int8_t *, vuint64m8_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vluxseg6ei64_v_m)))
void vluxseg6ei64(vint8m1_t *, vint8m1_t *, vint8m1_t *, vint8m1_t *, vint8m1_t *, vint8m1_t *, vbool8_t, vint8m1_t, vint8m1_t, vint8m1_t, vint8m1_t, vint8m1_t, vint8m1_t, const int8_t *, vuint64m8_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vluxseg6ei64_v)))
void vluxseg6ei64(vint8mf2_t *, vint8mf2_t *, vint8mf2_t *, vint8mf2_t *, vint8mf2_t *, vint8mf2_t *, const int8_t *, vuint64m4_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vluxseg6ei64_v_m)))
void vluxseg6ei64(vint8mf2_t *, vint8mf2_t *, vint8mf2_t *, vint8mf2_t *, vint8mf2_t *, vint8mf2_t *, vbool16_t, vint8mf2_t, vint8mf2_t, vint8mf2_t, vint8mf2_t, vint8mf2_t, vint8mf2_t, const int8_t *, vuint64m4_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vluxseg6ei64_v)))
void vluxseg6ei64(vint8mf4_t *, vint8mf4_t *, vint8mf4_t *, vint8mf4_t *, vint8mf4_t *, vint8mf4_t *, const int8_t *, vuint64m2_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vluxseg6ei64_v_m)))
void vluxseg6ei64(vint8mf4_t *, vint8mf4_t *, vint8mf4_t *, vint8mf4_t *, vint8mf4_t *, vint8mf4_t *, vbool32_t, vint8mf4_t, vint8mf4_t, vint8mf4_t, vint8mf4_t, vint8mf4_t, vint8mf4_t, const int8_t *, vuint64m2_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vluxseg6ei64_v)))
void vluxseg6ei64(vint8mf8_t *, vint8mf8_t *, vint8mf8_t *, vint8mf8_t *, vint8mf8_t *, vint8mf8_t *, const int8_t *, vuint64m1_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vluxseg6ei64_v_m)))
void vluxseg6ei64(vint8mf8_t *, vint8mf8_t *, vint8mf8_t *, vint8mf8_t *, vint8mf8_t *, vint8mf8_t *, vbool64_t, vint8mf8_t, vint8mf8_t, vint8mf8_t, vint8mf8_t, vint8mf8_t, vint8mf8_t, const int8_t *, vuint64m1_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vluxseg6ei64_v)))
void vluxseg6ei64(vuint8m1_t *, vuint8m1_t *, vuint8m1_t *, vuint8m1_t *, vuint8m1_t *, vuint8m1_t *, const uint8_t *, vuint64m8_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vluxseg6ei64_v_m)))
void vluxseg6ei64(vuint8m1_t *, vuint8m1_t *, vuint8m1_t *, vuint8m1_t *, vuint8m1_t *, vuint8m1_t *, vbool8_t, vuint8m1_t, vuint8m1_t, vuint8m1_t, vuint8m1_t, vuint8m1_t, vuint8m1_t, const uint8_t *, vuint64m8_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vluxseg6ei64_v)))
void vluxseg6ei64(vuint8mf2_t *, vuint8mf2_t *, vuint8mf2_t *, vuint8mf2_t *, vuint8mf2_t *, vuint8mf2_t *, const uint8_t *, vuint64m4_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vluxseg6ei64_v_m)))
void vluxseg6ei64(vuint8mf2_t *, vuint8mf2_t *, vuint8mf2_t *, vuint8mf2_t *, vuint8mf2_t *, vuint8mf2_t *, vbool16_t, vuint8mf2_t, vuint8mf2_t, vuint8mf2_t, vuint8mf2_t, vuint8mf2_t, vuint8mf2_t, const uint8_t *, vuint64m4_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vluxseg6ei64_v)))
void vluxseg6ei64(vuint8mf4_t *, vuint8mf4_t *, vuint8mf4_t *, vuint8mf4_t *, vuint8mf4_t *, vuint8mf4_t *, const uint8_t *, vuint64m2_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vluxseg6ei64_v_m)))
void vluxseg6ei64(vuint8mf4_t *, vuint8mf4_t *, vuint8mf4_t *, vuint8mf4_t *, vuint8mf4_t *, vuint8mf4_t *, vbool32_t, vuint8mf4_t, vuint8mf4_t, vuint8mf4_t, vuint8mf4_t, vuint8mf4_t, vuint8mf4_t, const uint8_t *, vuint64m2_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vluxseg6ei64_v)))
void vluxseg6ei64(vuint8mf8_t *, vuint8mf8_t *, vuint8mf8_t *, vuint8mf8_t *, vuint8mf8_t *, vuint8mf8_t *, const uint8_t *, vuint64m1_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vluxseg6ei64_v_m)))
void vluxseg6ei64(vuint8mf8_t *, vuint8mf8_t *, vuint8mf8_t *, vuint8mf8_t *, vuint8mf8_t *, vuint8mf8_t *, vbool64_t, vuint8mf8_t, vuint8mf8_t, vuint8mf8_t, vuint8mf8_t, vuint8mf8_t, vuint8mf8_t, const uint8_t *, vuint64m1_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vluxseg7ei64_v)))
void vluxseg7ei64(vint8m1_t *, vint8m1_t *, vint8m1_t *, vint8m1_t *, vint8m1_t *, vint8m1_t *, vint8m1_t *, const int8_t *, vuint64m8_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vluxseg7ei64_v_m)))
void vluxseg7ei64(vint8m1_t *, vint8m1_t *, vint8m1_t *, vint8m1_t *, vint8m1_t *, vint8m1_t *, vint8m1_t *, vbool8_t, vint8m1_t, vint8m1_t, vint8m1_t, vint8m1_t, vint8m1_t, vint8m1_t, vint8m1_t, const int8_t *, vuint64m8_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vluxseg7ei64_v)))
void vluxseg7ei64(vint8mf2_t *, vint8mf2_t *, vint8mf2_t *, vint8mf2_t *, vint8mf2_t *, vint8mf2_t *, vint8mf2_t *, const int8_t *, vuint64m4_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vluxseg7ei64_v_m)))
void vluxseg7ei64(vint8mf2_t *, vint8mf2_t *, vint8mf2_t *, vint8mf2_t *, vint8mf2_t *, vint8mf2_t *, vint8mf2_t *, vbool16_t, vint8mf2_t, vint8mf2_t, vint8mf2_t, vint8mf2_t, vint8mf2_t, vint8mf2_t, vint8mf2_t, const int8_t *, vuint64m4_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vluxseg7ei64_v)))
void vluxseg7ei64(vint8mf4_t *, vint8mf4_t *, vint8mf4_t *, vint8mf4_t *, vint8mf4_t *, vint8mf4_t *, vint8mf4_t *, const int8_t *, vuint64m2_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vluxseg7ei64_v_m)))
void vluxseg7ei64(vint8mf4_t *, vint8mf4_t *, vint8mf4_t *, vint8mf4_t *, vint8mf4_t *, vint8mf4_t *, vint8mf4_t *, vbool32_t, vint8mf4_t, vint8mf4_t, vint8mf4_t, vint8mf4_t, vint8mf4_t, vint8mf4_t, vint8mf4_t, const int8_t *, vuint64m2_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vluxseg7ei64_v)))
void vluxseg7ei64(vint8mf8_t *, vint8mf8_t *, vint8mf8_t *, vint8mf8_t *, vint8mf8_t *, vint8mf8_t *, vint8mf8_t *, const int8_t *, vuint64m1_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vluxseg7ei64_v_m)))
void vluxseg7ei64(vint8mf8_t *, vint8mf8_t *, vint8mf8_t *, vint8mf8_t *, vint8mf8_t *, vint8mf8_t *, vint8mf8_t *, vbool64_t, vint8mf8_t, vint8mf8_t, vint8mf8_t, vint8mf8_t, vint8mf8_t, vint8mf8_t, vint8mf8_t, const int8_t *, vuint64m1_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vluxseg7ei64_v)))
void vluxseg7ei64(vuint8m1_t *, vuint8m1_t *, vuint8m1_t *, vuint8m1_t *, vuint8m1_t *, vuint8m1_t *, vuint8m1_t *, const uint8_t *, vuint64m8_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vluxseg7ei64_v_m)))
void vluxseg7ei64(vuint8m1_t *, vuint8m1_t *, vuint8m1_t *, vuint8m1_t *, vuint8m1_t *, vuint8m1_t *, vuint8m1_t *, vbool8_t, vuint8m1_t, vuint8m1_t, vuint8m1_t, vuint8m1_t, vuint8m1_t, vuint8m1_t, vuint8m1_t, const uint8_t *, vuint64m8_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vluxseg7ei64_v)))
void vluxseg7ei64(vuint8mf2_t *, vuint8mf2_t *, vuint8mf2_t *, vuint8mf2_t *, vuint8mf2_t *, vuint8mf2_t *, vuint8mf2_t *, const uint8_t *, vuint64m4_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vluxseg7ei64_v_m)))
void vluxseg7ei64(vuint8mf2_t *, vuint8mf2_t *, vuint8mf2_t *, vuint8mf2_t *, vuint8mf2_t *, vuint8mf2_t *, vuint8mf2_t *, vbool16_t, vuint8mf2_t, vuint8mf2_t, vuint8mf2_t, vuint8mf2_t, vuint8mf2_t, vuint8mf2_t, vuint8mf2_t, const uint8_t *, vuint64m4_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vluxseg7ei64_v)))
void vluxseg7ei64(vuint8mf4_t *, vuint8mf4_t *, vuint8mf4_t *, vuint8mf4_t *, vuint8mf4_t *, vuint8mf4_t *, vuint8mf4_t *, const uint8_t *, vuint64m2_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vluxseg7ei64_v_m)))
void vluxseg7ei64(vuint8mf4_t *, vuint8mf4_t *, vuint8mf4_t *, vuint8mf4_t *, vuint8mf4_t *, vuint8mf4_t *, vuint8mf4_t *, vbool32_t, vuint8mf4_t, vuint8mf4_t, vuint8mf4_t, vuint8mf4_t, vuint8mf4_t, vuint8mf4_t, vuint8mf4_t, const uint8_t *, vuint64m2_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vluxseg7ei64_v)))
void vluxseg7ei64(vuint8mf8_t *, vuint8mf8_t *, vuint8mf8_t *, vuint8mf8_t *, vuint8mf8_t *, vuint8mf8_t *, vuint8mf8_t *, const uint8_t *, vuint64m1_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vluxseg7ei64_v_m)))
void vluxseg7ei64(vuint8mf8_t *, vuint8mf8_t *, vuint8mf8_t *, vuint8mf8_t *, vuint8mf8_t *, vuint8mf8_t *, vuint8mf8_t *, vbool64_t, vuint8mf8_t, vuint8mf8_t, vuint8mf8_t, vuint8mf8_t, vuint8mf8_t, vuint8mf8_t, vuint8mf8_t, const uint8_t *, vuint64m1_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vluxseg8ei64_v)))
void vluxseg8ei64(vint8m1_t *, vint8m1_t *, vint8m1_t *, vint8m1_t *, vint8m1_t *, vint8m1_t *, vint8m1_t *, vint8m1_t *, const int8_t *, vuint64m8_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vluxseg8ei64_v_m)))
void vluxseg8ei64(vint8m1_t *, vint8m1_t *, vint8m1_t *, vint8m1_t *, vint8m1_t *, vint8m1_t *, vint8m1_t *, vint8m1_t *, vbool8_t, vint8m1_t, vint8m1_t, vint8m1_t, vint8m1_t, vint8m1_t, vint8m1_t, vint8m1_t, vint8m1_t, const int8_t *, vuint64m8_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vluxseg8ei64_v)))
void vluxseg8ei64(vint8mf2_t *, vint8mf2_t *, vint8mf2_t *, vint8mf2_t *, vint8mf2_t *, vint8mf2_t *, vint8mf2_t *, vint8mf2_t *, const int8_t *, vuint64m4_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vluxseg8ei64_v_m)))
void vluxseg8ei64(vint8mf2_t *, vint8mf2_t *, vint8mf2_t *, vint8mf2_t *, vint8mf2_t *, vint8mf2_t *, vint8mf2_t *, vint8mf2_t *, vbool16_t, vint8mf2_t, vint8mf2_t, vint8mf2_t, vint8mf2_t, vint8mf2_t, vint8mf2_t, vint8mf2_t, vint8mf2_t, const int8_t *, vuint64m4_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vluxseg8ei64_v)))
void vluxseg8ei64(vint8mf4_t *, vint8mf4_t *, vint8mf4_t *, vint8mf4_t *, vint8mf4_t *, vint8mf4_t *, vint8mf4_t *, vint8mf4_t *, const int8_t *, vuint64m2_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vluxseg8ei64_v_m)))
void vluxseg8ei64(vint8mf4_t *, vint8mf4_t *, vint8mf4_t *, vint8mf4_t *, vint8mf4_t *, vint8mf4_t *, vint8mf4_t *, vint8mf4_t *, vbool32_t, vint8mf4_t, vint8mf4_t, vint8mf4_t, vint8mf4_t, vint8mf4_t, vint8mf4_t, vint8mf4_t, vint8mf4_t, const int8_t *, vuint64m2_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vluxseg8ei64_v)))
void vluxseg8ei64(vint8mf8_t *, vint8mf8_t *, vint8mf8_t *, vint8mf8_t *, vint8mf8_t *, vint8mf8_t *, vint8mf8_t *, vint8mf8_t *, const int8_t *, vuint64m1_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vluxseg8ei64_v_m)))
void vluxseg8ei64(vint8mf8_t *, vint8mf8_t *, vint8mf8_t *, vint8mf8_t *, vint8mf8_t *, vint8mf8_t *, vint8mf8_t *, vint8mf8_t *, vbool64_t, vint8mf8_t, vint8mf8_t, vint8mf8_t, vint8mf8_t, vint8mf8_t, vint8mf8_t, vint8mf8_t, vint8mf8_t, const int8_t *, vuint64m1_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vluxseg8ei64_v)))
void vluxseg8ei64(vuint8m1_t *, vuint8m1_t *, vuint8m1_t *, vuint8m1_t *, vuint8m1_t *, vuint8m1_t *, vuint8m1_t *, vuint8m1_t *, const uint8_t *, vuint64m8_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vluxseg8ei64_v_m)))
void vluxseg8ei64(vuint8m1_t *, vuint8m1_t *, vuint8m1_t *, vuint8m1_t *, vuint8m1_t *, vuint8m1_t *, vuint8m1_t *, vuint8m1_t *, vbool8_t, vuint8m1_t, vuint8m1_t, vuint8m1_t, vuint8m1_t, vuint8m1_t, vuint8m1_t, vuint8m1_t, vuint8m1_t, const uint8_t *, vuint64m8_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vluxseg8ei64_v)))
void vluxseg8ei64(vuint8mf2_t *, vuint8mf2_t *, vuint8mf2_t *, vuint8mf2_t *, vuint8mf2_t *, vuint8mf2_t *, vuint8mf2_t *, vuint8mf2_t *, const uint8_t *, vuint64m4_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vluxseg8ei64_v_m)))
void vluxseg8ei64(vuint8mf2_t *, vuint8mf2_t *, vuint8mf2_t *, vuint8mf2_t *, vuint8mf2_t *, vuint8mf2_t *, vuint8mf2_t *, vuint8mf2_t *, vbool16_t, vuint8mf2_t, vuint8mf2_t, vuint8mf2_t, vuint8mf2_t, vuint8mf2_t, vuint8mf2_t, vuint8mf2_t, vuint8mf2_t, const uint8_t *, vuint64m4_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vluxseg8ei64_v)))
void vluxseg8ei64(vuint8mf4_t *, vuint8mf4_t *, vuint8mf4_t *, vuint8mf4_t *, vuint8mf4_t *, vuint8mf4_t *, vuint8mf4_t *, vuint8mf4_t *, const uint8_t *, vuint64m2_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vluxseg8ei64_v_m)))
void vluxseg8ei64(vuint8mf4_t *, vuint8mf4_t *, vuint8mf4_t *, vuint8mf4_t *, vuint8mf4_t *, vuint8mf4_t *, vuint8mf4_t *, vuint8mf4_t *, vbool32_t, vuint8mf4_t, vuint8mf4_t, vuint8mf4_t, vuint8mf4_t, vuint8mf4_t, vuint8mf4_t, vuint8mf4_t, vuint8mf4_t, const uint8_t *, vuint64m2_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vluxseg8ei64_v)))
void vluxseg8ei64(vuint8mf8_t *, vuint8mf8_t *, vuint8mf8_t *, vuint8mf8_t *, vuint8mf8_t *, vuint8mf8_t *, vuint8mf8_t *, vuint8mf8_t *, const uint8_t *, vuint64m1_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vluxseg8ei64_v_m)))
void vluxseg8ei64(vuint8mf8_t *, vuint8mf8_t *, vuint8mf8_t *, vuint8mf8_t *, vuint8mf8_t *, vuint8mf8_t *, vuint8mf8_t *, vuint8mf8_t *, vbool64_t, vuint8mf8_t, vuint8mf8_t, vuint8mf8_t, vuint8mf8_t, vuint8mf8_t, vuint8mf8_t, vuint8mf8_t, vuint8mf8_t, const uint8_t *, vuint64m1_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vluxseg2ei64_v)))
void vluxseg2ei64(vint16m1_t *, vint16m1_t *, const int16_t *, vuint64m4_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vluxseg2ei64_v_m)))
void vluxseg2ei64(vint16m1_t *, vint16m1_t *, vbool16_t, vint16m1_t, vint16m1_t, const int16_t *, vuint64m4_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vluxseg2ei64_v)))
void vluxseg2ei64(vint16m2_t *, vint16m2_t *, const int16_t *, vuint64m8_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vluxseg2ei64_v_m)))
void vluxseg2ei64(vint16m2_t *, vint16m2_t *, vbool8_t, vint16m2_t, vint16m2_t, const int16_t *, vuint64m8_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vluxseg2ei64_v)))
void vluxseg2ei64(vint16mf2_t *, vint16mf2_t *, const int16_t *, vuint64m2_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vluxseg2ei64_v_m)))
void vluxseg2ei64(vint16mf2_t *, vint16mf2_t *, vbool32_t, vint16mf2_t, vint16mf2_t, const int16_t *, vuint64m2_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vluxseg2ei64_v)))
void vluxseg2ei64(vint16mf4_t *, vint16mf4_t *, const int16_t *, vuint64m1_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vluxseg2ei64_v_m)))
void vluxseg2ei64(vint16mf4_t *, vint16mf4_t *, vbool64_t, vint16mf4_t, vint16mf4_t, const int16_t *, vuint64m1_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vluxseg2ei64_v)))
void vluxseg2ei64(vuint16m1_t *, vuint16m1_t *, const uint16_t *, vuint64m4_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vluxseg2ei64_v_m)))
void vluxseg2ei64(vuint16m1_t *, vuint16m1_t *, vbool16_t, vuint16m1_t, vuint16m1_t, const uint16_t *, vuint64m4_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vluxseg2ei64_v)))
void vluxseg2ei64(vuint16m2_t *, vuint16m2_t *, const uint16_t *, vuint64m8_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vluxseg2ei64_v_m)))
void vluxseg2ei64(vuint16m2_t *, vuint16m2_t *, vbool8_t, vuint16m2_t, vuint16m2_t, const uint16_t *, vuint64m8_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vluxseg2ei64_v)))
void vluxseg2ei64(vuint16mf2_t *, vuint16mf2_t *, const uint16_t *, vuint64m2_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vluxseg2ei64_v_m)))
void vluxseg2ei64(vuint16mf2_t *, vuint16mf2_t *, vbool32_t, vuint16mf2_t, vuint16mf2_t, const uint16_t *, vuint64m2_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vluxseg2ei64_v)))
void vluxseg2ei64(vuint16mf4_t *, vuint16mf4_t *, const uint16_t *, vuint64m1_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vluxseg2ei64_v_m)))
void vluxseg2ei64(vuint16mf4_t *, vuint16mf4_t *, vbool64_t, vuint16mf4_t, vuint16mf4_t, const uint16_t *, vuint64m1_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vluxseg3ei64_v)))
void vluxseg3ei64(vint16m1_t *, vint16m1_t *, vint16m1_t *, const int16_t *, vuint64m4_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vluxseg3ei64_v_m)))
void vluxseg3ei64(vint16m1_t *, vint16m1_t *, vint16m1_t *, vbool16_t, vint16m1_t, vint16m1_t, vint16m1_t, const int16_t *, vuint64m4_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vluxseg3ei64_v)))
void vluxseg3ei64(vint16m2_t *, vint16m2_t *, vint16m2_t *, const int16_t *, vuint64m8_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vluxseg3ei64_v_m)))
void vluxseg3ei64(vint16m2_t *, vint16m2_t *, vint16m2_t *, vbool8_t, vint16m2_t, vint16m2_t, vint16m2_t, const int16_t *, vuint64m8_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vluxseg3ei64_v)))
void vluxseg3ei64(vint16mf2_t *, vint16mf2_t *, vint16mf2_t *, const int16_t *, vuint64m2_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vluxseg3ei64_v_m)))
void vluxseg3ei64(vint16mf2_t *, vint16mf2_t *, vint16mf2_t *, vbool32_t, vint16mf2_t, vint16mf2_t, vint16mf2_t, const int16_t *, vuint64m2_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vluxseg3ei64_v)))
void vluxseg3ei64(vint16mf4_t *, vint16mf4_t *, vint16mf4_t *, const int16_t *, vuint64m1_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vluxseg3ei64_v_m)))
void vluxseg3ei64(vint16mf4_t *, vint16mf4_t *, vint16mf4_t *, vbool64_t, vint16mf4_t, vint16mf4_t, vint16mf4_t, const int16_t *, vuint64m1_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vluxseg3ei64_v)))
void vluxseg3ei64(vuint16m1_t *, vuint16m1_t *, vuint16m1_t *, const uint16_t *, vuint64m4_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vluxseg3ei64_v_m)))
void vluxseg3ei64(vuint16m1_t *, vuint16m1_t *, vuint16m1_t *, vbool16_t, vuint16m1_t, vuint16m1_t, vuint16m1_t, const uint16_t *, vuint64m4_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vluxseg3ei64_v)))
void vluxseg3ei64(vuint16m2_t *, vuint16m2_t *, vuint16m2_t *, const uint16_t *, vuint64m8_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vluxseg3ei64_v_m)))
void vluxseg3ei64(vuint16m2_t *, vuint16m2_t *, vuint16m2_t *, vbool8_t, vuint16m2_t, vuint16m2_t, vuint16m2_t, const uint16_t *, vuint64m8_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vluxseg3ei64_v)))
void vluxseg3ei64(vuint16mf2_t *, vuint16mf2_t *, vuint16mf2_t *, const uint16_t *, vuint64m2_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vluxseg3ei64_v_m)))
void vluxseg3ei64(vuint16mf2_t *, vuint16mf2_t *, vuint16mf2_t *, vbool32_t, vuint16mf2_t, vuint16mf2_t, vuint16mf2_t, const uint16_t *, vuint64m2_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vluxseg3ei64_v)))
void vluxseg3ei64(vuint16mf4_t *, vuint16mf4_t *, vuint16mf4_t *, const uint16_t *, vuint64m1_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vluxseg3ei64_v_m)))
void vluxseg3ei64(vuint16mf4_t *, vuint16mf4_t *, vuint16mf4_t *, vbool64_t, vuint16mf4_t, vuint16mf4_t, vuint16mf4_t, const uint16_t *, vuint64m1_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vluxseg4ei64_v)))
void vluxseg4ei64(vint16m1_t *, vint16m1_t *, vint16m1_t *, vint16m1_t *, const int16_t *, vuint64m4_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vluxseg4ei64_v_m)))
void vluxseg4ei64(vint16m1_t *, vint16m1_t *, vint16m1_t *, vint16m1_t *, vbool16_t, vint16m1_t, vint16m1_t, vint16m1_t, vint16m1_t, const int16_t *, vuint64m4_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vluxseg4ei64_v)))
void vluxseg4ei64(vint16m2_t *, vint16m2_t *, vint16m2_t *, vint16m2_t *, const int16_t *, vuint64m8_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vluxseg4ei64_v_m)))
void vluxseg4ei64(vint16m2_t *, vint16m2_t *, vint16m2_t *, vint16m2_t *, vbool8_t, vint16m2_t, vint16m2_t, vint16m2_t, vint16m2_t, const int16_t *, vuint64m8_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vluxseg4ei64_v)))
void vluxseg4ei64(vint16mf2_t *, vint16mf2_t *, vint16mf2_t *, vint16mf2_t *, const int16_t *, vuint64m2_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vluxseg4ei64_v_m)))
void vluxseg4ei64(vint16mf2_t *, vint16mf2_t *, vint16mf2_t *, vint16mf2_t *, vbool32_t, vint16mf2_t, vint16mf2_t, vint16mf2_t, vint16mf2_t, const int16_t *, vuint64m2_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vluxseg4ei64_v)))
void vluxseg4ei64(vint16mf4_t *, vint16mf4_t *, vint16mf4_t *, vint16mf4_t *, const int16_t *, vuint64m1_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vluxseg4ei64_v_m)))
void vluxseg4ei64(vint16mf4_t *, vint16mf4_t *, vint16mf4_t *, vint16mf4_t *, vbool64_t, vint16mf4_t, vint16mf4_t, vint16mf4_t, vint16mf4_t, const int16_t *, vuint64m1_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vluxseg4ei64_v)))
void vluxseg4ei64(vuint16m1_t *, vuint16m1_t *, vuint16m1_t *, vuint16m1_t *, const uint16_t *, vuint64m4_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vluxseg4ei64_v_m)))
void vluxseg4ei64(vuint16m1_t *, vuint16m1_t *, vuint16m1_t *, vuint16m1_t *, vbool16_t, vuint16m1_t, vuint16m1_t, vuint16m1_t, vuint16m1_t, const uint16_t *, vuint64m4_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vluxseg4ei64_v)))
void vluxseg4ei64(vuint16m2_t *, vuint16m2_t *, vuint16m2_t *, vuint16m2_t *, const uint16_t *, vuint64m8_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vluxseg4ei64_v_m)))
void vluxseg4ei64(vuint16m2_t *, vuint16m2_t *, vuint16m2_t *, vuint16m2_t *, vbool8_t, vuint16m2_t, vuint16m2_t, vuint16m2_t, vuint16m2_t, const uint16_t *, vuint64m8_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vluxseg4ei64_v)))
void vluxseg4ei64(vuint16mf2_t *, vuint16mf2_t *, vuint16mf2_t *, vuint16mf2_t *, const uint16_t *, vuint64m2_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vluxseg4ei64_v_m)))
void vluxseg4ei64(vuint16mf2_t *, vuint16mf2_t *, vuint16mf2_t *, vuint16mf2_t *, vbool32_t, vuint16mf2_t, vuint16mf2_t, vuint16mf2_t, vuint16mf2_t, const uint16_t *, vuint64m2_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vluxseg4ei64_v)))
void vluxseg4ei64(vuint16mf4_t *, vuint16mf4_t *, vuint16mf4_t *, vuint16mf4_t *, const uint16_t *, vuint64m1_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vluxseg4ei64_v_m)))
void vluxseg4ei64(vuint16mf4_t *, vuint16mf4_t *, vuint16mf4_t *, vuint16mf4_t *, vbool64_t, vuint16mf4_t, vuint16mf4_t, vuint16mf4_t, vuint16mf4_t, const uint16_t *, vuint64m1_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vluxseg5ei64_v)))
void vluxseg5ei64(vint16m1_t *, vint16m1_t *, vint16m1_t *, vint16m1_t *, vint16m1_t *, const int16_t *, vuint64m4_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vluxseg5ei64_v_m)))
void vluxseg5ei64(vint16m1_t *, vint16m1_t *, vint16m1_t *, vint16m1_t *, vint16m1_t *, vbool16_t, vint16m1_t, vint16m1_t, vint16m1_t, vint16m1_t, vint16m1_t, const int16_t *, vuint64m4_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vluxseg5ei64_v)))
void vluxseg5ei64(vint16mf2_t *, vint16mf2_t *, vint16mf2_t *, vint16mf2_t *, vint16mf2_t *, const int16_t *, vuint64m2_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vluxseg5ei64_v_m)))
void vluxseg5ei64(vint16mf2_t *, vint16mf2_t *, vint16mf2_t *, vint16mf2_t *, vint16mf2_t *, vbool32_t, vint16mf2_t, vint16mf2_t, vint16mf2_t, vint16mf2_t, vint16mf2_t, const int16_t *, vuint64m2_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vluxseg5ei64_v)))
void vluxseg5ei64(vint16mf4_t *, vint16mf4_t *, vint16mf4_t *, vint16mf4_t *, vint16mf4_t *, const int16_t *, vuint64m1_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vluxseg5ei64_v_m)))
void vluxseg5ei64(vint16mf4_t *, vint16mf4_t *, vint16mf4_t *, vint16mf4_t *, vint16mf4_t *, vbool64_t, vint16mf4_t, vint16mf4_t, vint16mf4_t, vint16mf4_t, vint16mf4_t, const int16_t *, vuint64m1_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vluxseg5ei64_v)))
void vluxseg5ei64(vuint16m1_t *, vuint16m1_t *, vuint16m1_t *, vuint16m1_t *, vuint16m1_t *, const uint16_t *, vuint64m4_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vluxseg5ei64_v_m)))
void vluxseg5ei64(vuint16m1_t *, vuint16m1_t *, vuint16m1_t *, vuint16m1_t *, vuint16m1_t *, vbool16_t, vuint16m1_t, vuint16m1_t, vuint16m1_t, vuint16m1_t, vuint16m1_t, const uint16_t *, vuint64m4_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vluxseg5ei64_v)))
void vluxseg5ei64(vuint16mf2_t *, vuint16mf2_t *, vuint16mf2_t *, vuint16mf2_t *, vuint16mf2_t *, const uint16_t *, vuint64m2_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vluxseg5ei64_v_m)))
void vluxseg5ei64(vuint16mf2_t *, vuint16mf2_t *, vuint16mf2_t *, vuint16mf2_t *, vuint16mf2_t *, vbool32_t, vuint16mf2_t, vuint16mf2_t, vuint16mf2_t, vuint16mf2_t, vuint16mf2_t, const uint16_t *, vuint64m2_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vluxseg5ei64_v)))
void vluxseg5ei64(vuint16mf4_t *, vuint16mf4_t *, vuint16mf4_t *, vuint16mf4_t *, vuint16mf4_t *, const uint16_t *, vuint64m1_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vluxseg5ei64_v_m)))
void vluxseg5ei64(vuint16mf4_t *, vuint16mf4_t *, vuint16mf4_t *, vuint16mf4_t *, vuint16mf4_t *, vbool64_t, vuint16mf4_t, vuint16mf4_t, vuint16mf4_t, vuint16mf4_t, vuint16mf4_t, const uint16_t *, vuint64m1_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vluxseg6ei64_v)))
void vluxseg6ei64(vint16m1_t *, vint16m1_t *, vint16m1_t *, vint16m1_t *, vint16m1_t *, vint16m1_t *, const int16_t *, vuint64m4_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vluxseg6ei64_v_m)))
void vluxseg6ei64(vint16m1_t *, vint16m1_t *, vint16m1_t *, vint16m1_t *, vint16m1_t *, vint16m1_t *, vbool16_t, vint16m1_t, vint16m1_t, vint16m1_t, vint16m1_t, vint16m1_t, vint16m1_t, const int16_t *, vuint64m4_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vluxseg6ei64_v)))
void vluxseg6ei64(vint16mf2_t *, vint16mf2_t *, vint16mf2_t *, vint16mf2_t *, vint16mf2_t *, vint16mf2_t *, const int16_t *, vuint64m2_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vluxseg6ei64_v_m)))
void vluxseg6ei64(vint16mf2_t *, vint16mf2_t *, vint16mf2_t *, vint16mf2_t *, vint16mf2_t *, vint16mf2_t *, vbool32_t, vint16mf2_t, vint16mf2_t, vint16mf2_t, vint16mf2_t, vint16mf2_t, vint16mf2_t, const int16_t *, vuint64m2_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vluxseg6ei64_v)))
void vluxseg6ei64(vint16mf4_t *, vint16mf4_t *, vint16mf4_t *, vint16mf4_t *, vint16mf4_t *, vint16mf4_t *, const int16_t *, vuint64m1_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vluxseg6ei64_v_m)))
void vluxseg6ei64(vint16mf4_t *, vint16mf4_t *, vint16mf4_t *, vint16mf4_t *, vint16mf4_t *, vint16mf4_t *, vbool64_t, vint16mf4_t, vint16mf4_t, vint16mf4_t, vint16mf4_t, vint16mf4_t, vint16mf4_t, const int16_t *, vuint64m1_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vluxseg6ei64_v)))
void vluxseg6ei64(vuint16m1_t *, vuint16m1_t *, vuint16m1_t *, vuint16m1_t *, vuint16m1_t *, vuint16m1_t *, const uint16_t *, vuint64m4_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vluxseg6ei64_v_m)))
void vluxseg6ei64(vuint16m1_t *, vuint16m1_t *, vuint16m1_t *, vuint16m1_t *, vuint16m1_t *, vuint16m1_t *, vbool16_t, vuint16m1_t, vuint16m1_t, vuint16m1_t, vuint16m1_t, vuint16m1_t, vuint16m1_t, const uint16_t *, vuint64m4_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vluxseg6ei64_v)))
void vluxseg6ei64(vuint16mf2_t *, vuint16mf2_t *, vuint16mf2_t *, vuint16mf2_t *, vuint16mf2_t *, vuint16mf2_t *, const uint16_t *, vuint64m2_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vluxseg6ei64_v_m)))
void vluxseg6ei64(vuint16mf2_t *, vuint16mf2_t *, vuint16mf2_t *, vuint16mf2_t *, vuint16mf2_t *, vuint16mf2_t *, vbool32_t, vuint16mf2_t, vuint16mf2_t, vuint16mf2_t, vuint16mf2_t, vuint16mf2_t, vuint16mf2_t, const uint16_t *, vuint64m2_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vluxseg6ei64_v)))
void vluxseg6ei64(vuint16mf4_t *, vuint16mf4_t *, vuint16mf4_t *, vuint16mf4_t *, vuint16mf4_t *, vuint16mf4_t *, const uint16_t *, vuint64m1_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vluxseg6ei64_v_m)))
void vluxseg6ei64(vuint16mf4_t *, vuint16mf4_t *, vuint16mf4_t *, vuint16mf4_t *, vuint16mf4_t *, vuint16mf4_t *, vbool64_t, vuint16mf4_t, vuint16mf4_t, vuint16mf4_t, vuint16mf4_t, vuint16mf4_t, vuint16mf4_t, const uint16_t *, vuint64m1_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vluxseg7ei64_v)))
void vluxseg7ei64(vint16m1_t *, vint16m1_t *, vint16m1_t *, vint16m1_t *, vint16m1_t *, vint16m1_t *, vint16m1_t *, const int16_t *, vuint64m4_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vluxseg7ei64_v_m)))
void vluxseg7ei64(vint16m1_t *, vint16m1_t *, vint16m1_t *, vint16m1_t *, vint16m1_t *, vint16m1_t *, vint16m1_t *, vbool16_t, vint16m1_t, vint16m1_t, vint16m1_t, vint16m1_t, vint16m1_t, vint16m1_t, vint16m1_t, const int16_t *, vuint64m4_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vluxseg7ei64_v)))
void vluxseg7ei64(vint16mf2_t *, vint16mf2_t *, vint16mf2_t *, vint16mf2_t *, vint16mf2_t *, vint16mf2_t *, vint16mf2_t *, const int16_t *, vuint64m2_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vluxseg7ei64_v_m)))
void vluxseg7ei64(vint16mf2_t *, vint16mf2_t *, vint16mf2_t *, vint16mf2_t *, vint16mf2_t *, vint16mf2_t *, vint16mf2_t *, vbool32_t, vint16mf2_t, vint16mf2_t, vint16mf2_t, vint16mf2_t, vint16mf2_t, vint16mf2_t, vint16mf2_t, const int16_t *, vuint64m2_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vluxseg7ei64_v)))
void vluxseg7ei64(vint16mf4_t *, vint16mf4_t *, vint16mf4_t *, vint16mf4_t *, vint16mf4_t *, vint16mf4_t *, vint16mf4_t *, const int16_t *, vuint64m1_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vluxseg7ei64_v_m)))
void vluxseg7ei64(vint16mf4_t *, vint16mf4_t *, vint16mf4_t *, vint16mf4_t *, vint16mf4_t *, vint16mf4_t *, vint16mf4_t *, vbool64_t, vint16mf4_t, vint16mf4_t, vint16mf4_t, vint16mf4_t, vint16mf4_t, vint16mf4_t, vint16mf4_t, const int16_t *, vuint64m1_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vluxseg7ei64_v)))
void vluxseg7ei64(vuint16m1_t *, vuint16m1_t *, vuint16m1_t *, vuint16m1_t *, vuint16m1_t *, vuint16m1_t *, vuint16m1_t *, const uint16_t *, vuint64m4_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vluxseg7ei64_v_m)))
void vluxseg7ei64(vuint16m1_t *, vuint16m1_t *, vuint16m1_t *, vuint16m1_t *, vuint16m1_t *, vuint16m1_t *, vuint16m1_t *, vbool16_t, vuint16m1_t, vuint16m1_t, vuint16m1_t, vuint16m1_t, vuint16m1_t, vuint16m1_t, vuint16m1_t, const uint16_t *, vuint64m4_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vluxseg7ei64_v)))
void vluxseg7ei64(vuint16mf2_t *, vuint16mf2_t *, vuint16mf2_t *, vuint16mf2_t *, vuint16mf2_t *, vuint16mf2_t *, vuint16mf2_t *, const uint16_t *, vuint64m2_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vluxseg7ei64_v_m)))
void vluxseg7ei64(vuint16mf2_t *, vuint16mf2_t *, vuint16mf2_t *, vuint16mf2_t *, vuint16mf2_t *, vuint16mf2_t *, vuint16mf2_t *, vbool32_t, vuint16mf2_t, vuint16mf2_t, vuint16mf2_t, vuint16mf2_t, vuint16mf2_t, vuint16mf2_t, vuint16mf2_t, const uint16_t *, vuint64m2_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vluxseg7ei64_v)))
void vluxseg7ei64(vuint16mf4_t *, vuint16mf4_t *, vuint16mf4_t *, vuint16mf4_t *, vuint16mf4_t *, vuint16mf4_t *, vuint16mf4_t *, const uint16_t *, vuint64m1_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vluxseg7ei64_v_m)))
void vluxseg7ei64(vuint16mf4_t *, vuint16mf4_t *, vuint16mf4_t *, vuint16mf4_t *, vuint16mf4_t *, vuint16mf4_t *, vuint16mf4_t *, vbool64_t, vuint16mf4_t, vuint16mf4_t, vuint16mf4_t, vuint16mf4_t, vuint16mf4_t, vuint16mf4_t, vuint16mf4_t, const uint16_t *, vuint64m1_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vluxseg8ei64_v)))
void vluxseg8ei64(vint16m1_t *, vint16m1_t *, vint16m1_t *, vint16m1_t *, vint16m1_t *, vint16m1_t *, vint16m1_t *, vint16m1_t *, const int16_t *, vuint64m4_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vluxseg8ei64_v_m)))
void vluxseg8ei64(vint16m1_t *, vint16m1_t *, vint16m1_t *, vint16m1_t *, vint16m1_t *, vint16m1_t *, vint16m1_t *, vint16m1_t *, vbool16_t, vint16m1_t, vint16m1_t, vint16m1_t, vint16m1_t, vint16m1_t, vint16m1_t, vint16m1_t, vint16m1_t, const int16_t *, vuint64m4_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vluxseg8ei64_v)))
void vluxseg8ei64(vint16mf2_t *, vint16mf2_t *, vint16mf2_t *, vint16mf2_t *, vint16mf2_t *, vint16mf2_t *, vint16mf2_t *, vint16mf2_t *, const int16_t *, vuint64m2_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vluxseg8ei64_v_m)))
void vluxseg8ei64(vint16mf2_t *, vint16mf2_t *, vint16mf2_t *, vint16mf2_t *, vint16mf2_t *, vint16mf2_t *, vint16mf2_t *, vint16mf2_t *, vbool32_t, vint16mf2_t, vint16mf2_t, vint16mf2_t, vint16mf2_t, vint16mf2_t, vint16mf2_t, vint16mf2_t, vint16mf2_t, const int16_t *, vuint64m2_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vluxseg8ei64_v)))
void vluxseg8ei64(vint16mf4_t *, vint16mf4_t *, vint16mf4_t *, vint16mf4_t *, vint16mf4_t *, vint16mf4_t *, vint16mf4_t *, vint16mf4_t *, const int16_t *, vuint64m1_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vluxseg8ei64_v_m)))
void vluxseg8ei64(vint16mf4_t *, vint16mf4_t *, vint16mf4_t *, vint16mf4_t *, vint16mf4_t *, vint16mf4_t *, vint16mf4_t *, vint16mf4_t *, vbool64_t, vint16mf4_t, vint16mf4_t, vint16mf4_t, vint16mf4_t, vint16mf4_t, vint16mf4_t, vint16mf4_t, vint16mf4_t, const int16_t *, vuint64m1_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vluxseg8ei64_v)))
void vluxseg8ei64(vuint16m1_t *, vuint16m1_t *, vuint16m1_t *, vuint16m1_t *, vuint16m1_t *, vuint16m1_t *, vuint16m1_t *, vuint16m1_t *, const uint16_t *, vuint64m4_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vluxseg8ei64_v_m)))
void vluxseg8ei64(vuint16m1_t *, vuint16m1_t *, vuint16m1_t *, vuint16m1_t *, vuint16m1_t *, vuint16m1_t *, vuint16m1_t *, vuint16m1_t *, vbool16_t, vuint16m1_t, vuint16m1_t, vuint16m1_t, vuint16m1_t, vuint16m1_t, vuint16m1_t, vuint16m1_t, vuint16m1_t, const uint16_t *, vuint64m4_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vluxseg8ei64_v)))
void vluxseg8ei64(vuint16mf2_t *, vuint16mf2_t *, vuint16mf2_t *, vuint16mf2_t *, vuint16mf2_t *, vuint16mf2_t *, vuint16mf2_t *, vuint16mf2_t *, const uint16_t *, vuint64m2_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vluxseg8ei64_v_m)))
void vluxseg8ei64(vuint16mf2_t *, vuint16mf2_t *, vuint16mf2_t *, vuint16mf2_t *, vuint16mf2_t *, vuint16mf2_t *, vuint16mf2_t *, vuint16mf2_t *, vbool32_t, vuint16mf2_t, vuint16mf2_t, vuint16mf2_t, vuint16mf2_t, vuint16mf2_t, vuint16mf2_t, vuint16mf2_t, vuint16mf2_t, const uint16_t *, vuint64m2_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vluxseg8ei64_v)))
void vluxseg8ei64(vuint16mf4_t *, vuint16mf4_t *, vuint16mf4_t *, vuint16mf4_t *, vuint16mf4_t *, vuint16mf4_t *, vuint16mf4_t *, vuint16mf4_t *, const uint16_t *, vuint64m1_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vluxseg8ei64_v_m)))
void vluxseg8ei64(vuint16mf4_t *, vuint16mf4_t *, vuint16mf4_t *, vuint16mf4_t *, vuint16mf4_t *, vuint16mf4_t *, vuint16mf4_t *, vuint16mf4_t *, vbool64_t, vuint16mf4_t, vuint16mf4_t, vuint16mf4_t, vuint16mf4_t, vuint16mf4_t, vuint16mf4_t, vuint16mf4_t, vuint16mf4_t, const uint16_t *, vuint64m1_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vluxseg2ei64_v)))
void vluxseg2ei64(vint32m1_t *, vint32m1_t *, const int32_t *, vuint64m2_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vluxseg2ei64_v_m)))
void vluxseg2ei64(vint32m1_t *, vint32m1_t *, vbool32_t, vint32m1_t, vint32m1_t, const int32_t *, vuint64m2_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vluxseg2ei64_v)))
void vluxseg2ei64(vint32m2_t *, vint32m2_t *, const int32_t *, vuint64m4_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vluxseg2ei64_v_m)))
void vluxseg2ei64(vint32m2_t *, vint32m2_t *, vbool16_t, vint32m2_t, vint32m2_t, const int32_t *, vuint64m4_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vluxseg2ei64_v)))
void vluxseg2ei64(vint32m4_t *, vint32m4_t *, const int32_t *, vuint64m8_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vluxseg2ei64_v_m)))
void vluxseg2ei64(vint32m4_t *, vint32m4_t *, vbool8_t, vint32m4_t, vint32m4_t, const int32_t *, vuint64m8_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vluxseg2ei64_v)))
void vluxseg2ei64(vint32mf2_t *, vint32mf2_t *, const int32_t *, vuint64m1_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vluxseg2ei64_v_m)))
void vluxseg2ei64(vint32mf2_t *, vint32mf2_t *, vbool64_t, vint32mf2_t, vint32mf2_t, const int32_t *, vuint64m1_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vluxseg2ei64_v)))
void vluxseg2ei64(vuint32m1_t *, vuint32m1_t *, const uint32_t *, vuint64m2_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vluxseg2ei64_v_m)))
void vluxseg2ei64(vuint32m1_t *, vuint32m1_t *, vbool32_t, vuint32m1_t, vuint32m1_t, const uint32_t *, vuint64m2_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vluxseg2ei64_v)))
void vluxseg2ei64(vuint32m2_t *, vuint32m2_t *, const uint32_t *, vuint64m4_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vluxseg2ei64_v_m)))
void vluxseg2ei64(vuint32m2_t *, vuint32m2_t *, vbool16_t, vuint32m2_t, vuint32m2_t, const uint32_t *, vuint64m4_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vluxseg2ei64_v)))
void vluxseg2ei64(vuint32m4_t *, vuint32m4_t *, const uint32_t *, vuint64m8_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vluxseg2ei64_v_m)))
void vluxseg2ei64(vuint32m4_t *, vuint32m4_t *, vbool8_t, vuint32m4_t, vuint32m4_t, const uint32_t *, vuint64m8_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vluxseg2ei64_v)))
void vluxseg2ei64(vuint32mf2_t *, vuint32mf2_t *, const uint32_t *, vuint64m1_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vluxseg2ei64_v_m)))
void vluxseg2ei64(vuint32mf2_t *, vuint32mf2_t *, vbool64_t, vuint32mf2_t, vuint32mf2_t, const uint32_t *, vuint64m1_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vluxseg3ei64_v)))
void vluxseg3ei64(vint32m1_t *, vint32m1_t *, vint32m1_t *, const int32_t *, vuint64m2_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vluxseg3ei64_v_m)))
void vluxseg3ei64(vint32m1_t *, vint32m1_t *, vint32m1_t *, vbool32_t, vint32m1_t, vint32m1_t, vint32m1_t, const int32_t *, vuint64m2_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vluxseg3ei64_v)))
void vluxseg3ei64(vint32m2_t *, vint32m2_t *, vint32m2_t *, const int32_t *, vuint64m4_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vluxseg3ei64_v_m)))
void vluxseg3ei64(vint32m2_t *, vint32m2_t *, vint32m2_t *, vbool16_t, vint32m2_t, vint32m2_t, vint32m2_t, const int32_t *, vuint64m4_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vluxseg3ei64_v)))
void vluxseg3ei64(vint32mf2_t *, vint32mf2_t *, vint32mf2_t *, const int32_t *, vuint64m1_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vluxseg3ei64_v_m)))
void vluxseg3ei64(vint32mf2_t *, vint32mf2_t *, vint32mf2_t *, vbool64_t, vint32mf2_t, vint32mf2_t, vint32mf2_t, const int32_t *, vuint64m1_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vluxseg3ei64_v)))
void vluxseg3ei64(vuint32m1_t *, vuint32m1_t *, vuint32m1_t *, const uint32_t *, vuint64m2_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vluxseg3ei64_v_m)))
void vluxseg3ei64(vuint32m1_t *, vuint32m1_t *, vuint32m1_t *, vbool32_t, vuint32m1_t, vuint32m1_t, vuint32m1_t, const uint32_t *, vuint64m2_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vluxseg3ei64_v)))
void vluxseg3ei64(vuint32m2_t *, vuint32m2_t *, vuint32m2_t *, const uint32_t *, vuint64m4_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vluxseg3ei64_v_m)))
void vluxseg3ei64(vuint32m2_t *, vuint32m2_t *, vuint32m2_t *, vbool16_t, vuint32m2_t, vuint32m2_t, vuint32m2_t, const uint32_t *, vuint64m4_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vluxseg3ei64_v)))
void vluxseg3ei64(vuint32mf2_t *, vuint32mf2_t *, vuint32mf2_t *, const uint32_t *, vuint64m1_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vluxseg3ei64_v_m)))
void vluxseg3ei64(vuint32mf2_t *, vuint32mf2_t *, vuint32mf2_t *, vbool64_t, vuint32mf2_t, vuint32mf2_t, vuint32mf2_t, const uint32_t *, vuint64m1_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vluxseg4ei64_v)))
void vluxseg4ei64(vint32m1_t *, vint32m1_t *, vint32m1_t *, vint32m1_t *, const int32_t *, vuint64m2_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vluxseg4ei64_v_m)))
void vluxseg4ei64(vint32m1_t *, vint32m1_t *, vint32m1_t *, vint32m1_t *, vbool32_t, vint32m1_t, vint32m1_t, vint32m1_t, vint32m1_t, const int32_t *, vuint64m2_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vluxseg4ei64_v)))
void vluxseg4ei64(vint32m2_t *, vint32m2_t *, vint32m2_t *, vint32m2_t *, const int32_t *, vuint64m4_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vluxseg4ei64_v_m)))
void vluxseg4ei64(vint32m2_t *, vint32m2_t *, vint32m2_t *, vint32m2_t *, vbool16_t, vint32m2_t, vint32m2_t, vint32m2_t, vint32m2_t, const int32_t *, vuint64m4_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vluxseg4ei64_v)))
void vluxseg4ei64(vint32mf2_t *, vint32mf2_t *, vint32mf2_t *, vint32mf2_t *, const int32_t *, vuint64m1_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vluxseg4ei64_v_m)))
void vluxseg4ei64(vint32mf2_t *, vint32mf2_t *, vint32mf2_t *, vint32mf2_t *, vbool64_t, vint32mf2_t, vint32mf2_t, vint32mf2_t, vint32mf2_t, const int32_t *, vuint64m1_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vluxseg4ei64_v)))
void vluxseg4ei64(vuint32m1_t *, vuint32m1_t *, vuint32m1_t *, vuint32m1_t *, const uint32_t *, vuint64m2_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vluxseg4ei64_v_m)))
void vluxseg4ei64(vuint32m1_t *, vuint32m1_t *, vuint32m1_t *, vuint32m1_t *, vbool32_t, vuint32m1_t, vuint32m1_t, vuint32m1_t, vuint32m1_t, const uint32_t *, vuint64m2_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vluxseg4ei64_v)))
void vluxseg4ei64(vuint32m2_t *, vuint32m2_t *, vuint32m2_t *, vuint32m2_t *, const uint32_t *, vuint64m4_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vluxseg4ei64_v_m)))
void vluxseg4ei64(vuint32m2_t *, vuint32m2_t *, vuint32m2_t *, vuint32m2_t *, vbool16_t, vuint32m2_t, vuint32m2_t, vuint32m2_t, vuint32m2_t, const uint32_t *, vuint64m4_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vluxseg4ei64_v)))
void vluxseg4ei64(vuint32mf2_t *, vuint32mf2_t *, vuint32mf2_t *, vuint32mf2_t *, const uint32_t *, vuint64m1_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vluxseg4ei64_v_m)))
void vluxseg4ei64(vuint32mf2_t *, vuint32mf2_t *, vuint32mf2_t *, vuint32mf2_t *, vbool64_t, vuint32mf2_t, vuint32mf2_t, vuint32mf2_t, vuint32mf2_t, const uint32_t *, vuint64m1_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vluxseg5ei64_v)))
void vluxseg5ei64(vint32m1_t *, vint32m1_t *, vint32m1_t *, vint32m1_t *, vint32m1_t *, const int32_t *, vuint64m2_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vluxseg5ei64_v_m)))
void vluxseg5ei64(vint32m1_t *, vint32m1_t *, vint32m1_t *, vint32m1_t *, vint32m1_t *, vbool32_t, vint32m1_t, vint32m1_t, vint32m1_t, vint32m1_t, vint32m1_t, const int32_t *, vuint64m2_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vluxseg5ei64_v)))
void vluxseg5ei64(vint32mf2_t *, vint32mf2_t *, vint32mf2_t *, vint32mf2_t *, vint32mf2_t *, const int32_t *, vuint64m1_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vluxseg5ei64_v_m)))
void vluxseg5ei64(vint32mf2_t *, vint32mf2_t *, vint32mf2_t *, vint32mf2_t *, vint32mf2_t *, vbool64_t, vint32mf2_t, vint32mf2_t, vint32mf2_t, vint32mf2_t, vint32mf2_t, const int32_t *, vuint64m1_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vluxseg5ei64_v)))
void vluxseg5ei64(vuint32m1_t *, vuint32m1_t *, vuint32m1_t *, vuint32m1_t *, vuint32m1_t *, const uint32_t *, vuint64m2_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vluxseg5ei64_v_m)))
void vluxseg5ei64(vuint32m1_t *, vuint32m1_t *, vuint32m1_t *, vuint32m1_t *, vuint32m1_t *, vbool32_t, vuint32m1_t, vuint32m1_t, vuint32m1_t, vuint32m1_t, vuint32m1_t, const uint32_t *, vuint64m2_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vluxseg5ei64_v)))
void vluxseg5ei64(vuint32mf2_t *, vuint32mf2_t *, vuint32mf2_t *, vuint32mf2_t *, vuint32mf2_t *, const uint32_t *, vuint64m1_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vluxseg5ei64_v_m)))
void vluxseg5ei64(vuint32mf2_t *, vuint32mf2_t *, vuint32mf2_t *, vuint32mf2_t *, vuint32mf2_t *, vbool64_t, vuint32mf2_t, vuint32mf2_t, vuint32mf2_t, vuint32mf2_t, vuint32mf2_t, const uint32_t *, vuint64m1_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vluxseg6ei64_v)))
void vluxseg6ei64(vint32m1_t *, vint32m1_t *, vint32m1_t *, vint32m1_t *, vint32m1_t *, vint32m1_t *, const int32_t *, vuint64m2_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vluxseg6ei64_v_m)))
void vluxseg6ei64(vint32m1_t *, vint32m1_t *, vint32m1_t *, vint32m1_t *, vint32m1_t *, vint32m1_t *, vbool32_t, vint32m1_t, vint32m1_t, vint32m1_t, vint32m1_t, vint32m1_t, vint32m1_t, const int32_t *, vuint64m2_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vluxseg6ei64_v)))
void vluxseg6ei64(vint32mf2_t *, vint32mf2_t *, vint32mf2_t *, vint32mf2_t *, vint32mf2_t *, vint32mf2_t *, const int32_t *, vuint64m1_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vluxseg6ei64_v_m)))
void vluxseg6ei64(vint32mf2_t *, vint32mf2_t *, vint32mf2_t *, vint32mf2_t *, vint32mf2_t *, vint32mf2_t *, vbool64_t, vint32mf2_t, vint32mf2_t, vint32mf2_t, vint32mf2_t, vint32mf2_t, vint32mf2_t, const int32_t *, vuint64m1_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vluxseg6ei64_v)))
void vluxseg6ei64(vuint32m1_t *, vuint32m1_t *, vuint32m1_t *, vuint32m1_t *, vuint32m1_t *, vuint32m1_t *, const uint32_t *, vuint64m2_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vluxseg6ei64_v_m)))
void vluxseg6ei64(vuint32m1_t *, vuint32m1_t *, vuint32m1_t *, vuint32m1_t *, vuint32m1_t *, vuint32m1_t *, vbool32_t, vuint32m1_t, vuint32m1_t, vuint32m1_t, vuint32m1_t, vuint32m1_t, vuint32m1_t, const uint32_t *, vuint64m2_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vluxseg6ei64_v)))
void vluxseg6ei64(vuint32mf2_t *, vuint32mf2_t *, vuint32mf2_t *, vuint32mf2_t *, vuint32mf2_t *, vuint32mf2_t *, const uint32_t *, vuint64m1_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vluxseg6ei64_v_m)))
void vluxseg6ei64(vuint32mf2_t *, vuint32mf2_t *, vuint32mf2_t *, vuint32mf2_t *, vuint32mf2_t *, vuint32mf2_t *, vbool64_t, vuint32mf2_t, vuint32mf2_t, vuint32mf2_t, vuint32mf2_t, vuint32mf2_t, vuint32mf2_t, const uint32_t *, vuint64m1_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vluxseg7ei64_v)))
void vluxseg7ei64(vint32m1_t *, vint32m1_t *, vint32m1_t *, vint32m1_t *, vint32m1_t *, vint32m1_t *, vint32m1_t *, const int32_t *, vuint64m2_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vluxseg7ei64_v_m)))
void vluxseg7ei64(vint32m1_t *, vint32m1_t *, vint32m1_t *, vint32m1_t *, vint32m1_t *, vint32m1_t *, vint32m1_t *, vbool32_t, vint32m1_t, vint32m1_t, vint32m1_t, vint32m1_t, vint32m1_t, vint32m1_t, vint32m1_t, const int32_t *, vuint64m2_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vluxseg7ei64_v)))
void vluxseg7ei64(vint32mf2_t *, vint32mf2_t *, vint32mf2_t *, vint32mf2_t *, vint32mf2_t *, vint32mf2_t *, vint32mf2_t *, const int32_t *, vuint64m1_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vluxseg7ei64_v_m)))
void vluxseg7ei64(vint32mf2_t *, vint32mf2_t *, vint32mf2_t *, vint32mf2_t *, vint32mf2_t *, vint32mf2_t *, vint32mf2_t *, vbool64_t, vint32mf2_t, vint32mf2_t, vint32mf2_t, vint32mf2_t, vint32mf2_t, vint32mf2_t, vint32mf2_t, const int32_t *, vuint64m1_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vluxseg7ei64_v)))
void vluxseg7ei64(vuint32m1_t *, vuint32m1_t *, vuint32m1_t *, vuint32m1_t *, vuint32m1_t *, vuint32m1_t *, vuint32m1_t *, const uint32_t *, vuint64m2_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vluxseg7ei64_v_m)))
void vluxseg7ei64(vuint32m1_t *, vuint32m1_t *, vuint32m1_t *, vuint32m1_t *, vuint32m1_t *, vuint32m1_t *, vuint32m1_t *, vbool32_t, vuint32m1_t, vuint32m1_t, vuint32m1_t, vuint32m1_t, vuint32m1_t, vuint32m1_t, vuint32m1_t, const uint32_t *, vuint64m2_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vluxseg7ei64_v)))
void vluxseg7ei64(vuint32mf2_t *, vuint32mf2_t *, vuint32mf2_t *, vuint32mf2_t *, vuint32mf2_t *, vuint32mf2_t *, vuint32mf2_t *, const uint32_t *, vuint64m1_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vluxseg7ei64_v_m)))
void vluxseg7ei64(vuint32mf2_t *, vuint32mf2_t *, vuint32mf2_t *, vuint32mf2_t *, vuint32mf2_t *, vuint32mf2_t *, vuint32mf2_t *, vbool64_t, vuint32mf2_t, vuint32mf2_t, vuint32mf2_t, vuint32mf2_t, vuint32mf2_t, vuint32mf2_t, vuint32mf2_t, const uint32_t *, vuint64m1_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vluxseg8ei64_v)))
void vluxseg8ei64(vint32m1_t *, vint32m1_t *, vint32m1_t *, vint32m1_t *, vint32m1_t *, vint32m1_t *, vint32m1_t *, vint32m1_t *, const int32_t *, vuint64m2_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vluxseg8ei64_v_m)))
void vluxseg8ei64(vint32m1_t *, vint32m1_t *, vint32m1_t *, vint32m1_t *, vint32m1_t *, vint32m1_t *, vint32m1_t *, vint32m1_t *, vbool32_t, vint32m1_t, vint32m1_t, vint32m1_t, vint32m1_t, vint32m1_t, vint32m1_t, vint32m1_t, vint32m1_t, const int32_t *, vuint64m2_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vluxseg8ei64_v)))
void vluxseg8ei64(vint32mf2_t *, vint32mf2_t *, vint32mf2_t *, vint32mf2_t *, vint32mf2_t *, vint32mf2_t *, vint32mf2_t *, vint32mf2_t *, const int32_t *, vuint64m1_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vluxseg8ei64_v_m)))
void vluxseg8ei64(vint32mf2_t *, vint32mf2_t *, vint32mf2_t *, vint32mf2_t *, vint32mf2_t *, vint32mf2_t *, vint32mf2_t *, vint32mf2_t *, vbool64_t, vint32mf2_t, vint32mf2_t, vint32mf2_t, vint32mf2_t, vint32mf2_t, vint32mf2_t, vint32mf2_t, vint32mf2_t, const int32_t *, vuint64m1_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vluxseg8ei64_v)))
void vluxseg8ei64(vuint32m1_t *, vuint32m1_t *, vuint32m1_t *, vuint32m1_t *, vuint32m1_t *, vuint32m1_t *, vuint32m1_t *, vuint32m1_t *, const uint32_t *, vuint64m2_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vluxseg8ei64_v_m)))
void vluxseg8ei64(vuint32m1_t *, vuint32m1_t *, vuint32m1_t *, vuint32m1_t *, vuint32m1_t *, vuint32m1_t *, vuint32m1_t *, vuint32m1_t *, vbool32_t, vuint32m1_t, vuint32m1_t, vuint32m1_t, vuint32m1_t, vuint32m1_t, vuint32m1_t, vuint32m1_t, vuint32m1_t, const uint32_t *, vuint64m2_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vluxseg8ei64_v)))
void vluxseg8ei64(vuint32mf2_t *, vuint32mf2_t *, vuint32mf2_t *, vuint32mf2_t *, vuint32mf2_t *, vuint32mf2_t *, vuint32mf2_t *, vuint32mf2_t *, const uint32_t *, vuint64m1_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vluxseg8ei64_v_m)))
void vluxseg8ei64(vuint32mf2_t *, vuint32mf2_t *, vuint32mf2_t *, vuint32mf2_t *, vuint32mf2_t *, vuint32mf2_t *, vuint32mf2_t *, vuint32mf2_t *, vbool64_t, vuint32mf2_t, vuint32mf2_t, vuint32mf2_t, vuint32mf2_t, vuint32mf2_t, vuint32mf2_t, vuint32mf2_t, vuint32mf2_t, const uint32_t *, vuint64m1_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vluxseg2ei8_v)))
void vluxseg2ei8(vint64m1_t *, vint64m1_t *, const int64_t *, vuint8mf8_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vluxseg2ei8_v_m)))
void vluxseg2ei8(vint64m1_t *, vint64m1_t *, vbool64_t, vint64m1_t, vint64m1_t, const int64_t *, vuint8mf8_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vluxseg2ei8_v)))
void vluxseg2ei8(vint64m2_t *, vint64m2_t *, const int64_t *, vuint8mf4_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vluxseg2ei8_v_m)))
void vluxseg2ei8(vint64m2_t *, vint64m2_t *, vbool32_t, vint64m2_t, vint64m2_t, const int64_t *, vuint8mf4_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vluxseg2ei8_v)))
void vluxseg2ei8(vint64m4_t *, vint64m4_t *, const int64_t *, vuint8mf2_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vluxseg2ei8_v_m)))
void vluxseg2ei8(vint64m4_t *, vint64m4_t *, vbool16_t, vint64m4_t, vint64m4_t, const int64_t *, vuint8mf2_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vluxseg2ei8_v)))
void vluxseg2ei8(vuint64m1_t *, vuint64m1_t *, const uint64_t *, vuint8mf8_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vluxseg2ei8_v_m)))
void vluxseg2ei8(vuint64m1_t *, vuint64m1_t *, vbool64_t, vuint64m1_t, vuint64m1_t, const uint64_t *, vuint8mf8_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vluxseg2ei8_v)))
void vluxseg2ei8(vuint64m2_t *, vuint64m2_t *, const uint64_t *, vuint8mf4_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vluxseg2ei8_v_m)))
void vluxseg2ei8(vuint64m2_t *, vuint64m2_t *, vbool32_t, vuint64m2_t, vuint64m2_t, const uint64_t *, vuint8mf4_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vluxseg2ei8_v)))
void vluxseg2ei8(vuint64m4_t *, vuint64m4_t *, const uint64_t *, vuint8mf2_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vluxseg2ei8_v_m)))
void vluxseg2ei8(vuint64m4_t *, vuint64m4_t *, vbool16_t, vuint64m4_t, vuint64m4_t, const uint64_t *, vuint8mf2_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vluxseg3ei8_v)))
void vluxseg3ei8(vint64m1_t *, vint64m1_t *, vint64m1_t *, const int64_t *, vuint8mf8_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vluxseg3ei8_v_m)))
void vluxseg3ei8(vint64m1_t *, vint64m1_t *, vint64m1_t *, vbool64_t, vint64m1_t, vint64m1_t, vint64m1_t, const int64_t *, vuint8mf8_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vluxseg3ei8_v)))
void vluxseg3ei8(vint64m2_t *, vint64m2_t *, vint64m2_t *, const int64_t *, vuint8mf4_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vluxseg3ei8_v_m)))
void vluxseg3ei8(vint64m2_t *, vint64m2_t *, vint64m2_t *, vbool32_t, vint64m2_t, vint64m2_t, vint64m2_t, const int64_t *, vuint8mf4_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vluxseg3ei8_v)))
void vluxseg3ei8(vuint64m1_t *, vuint64m1_t *, vuint64m1_t *, const uint64_t *, vuint8mf8_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vluxseg3ei8_v_m)))
void vluxseg3ei8(vuint64m1_t *, vuint64m1_t *, vuint64m1_t *, vbool64_t, vuint64m1_t, vuint64m1_t, vuint64m1_t, const uint64_t *, vuint8mf8_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vluxseg3ei8_v)))
void vluxseg3ei8(vuint64m2_t *, vuint64m2_t *, vuint64m2_t *, const uint64_t *, vuint8mf4_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vluxseg3ei8_v_m)))
void vluxseg3ei8(vuint64m2_t *, vuint64m2_t *, vuint64m2_t *, vbool32_t, vuint64m2_t, vuint64m2_t, vuint64m2_t, const uint64_t *, vuint8mf4_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vluxseg4ei8_v)))
void vluxseg4ei8(vint64m1_t *, vint64m1_t *, vint64m1_t *, vint64m1_t *, const int64_t *, vuint8mf8_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vluxseg4ei8_v_m)))
void vluxseg4ei8(vint64m1_t *, vint64m1_t *, vint64m1_t *, vint64m1_t *, vbool64_t, vint64m1_t, vint64m1_t, vint64m1_t, vint64m1_t, const int64_t *, vuint8mf8_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vluxseg4ei8_v)))
void vluxseg4ei8(vint64m2_t *, vint64m2_t *, vint64m2_t *, vint64m2_t *, const int64_t *, vuint8mf4_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vluxseg4ei8_v_m)))
void vluxseg4ei8(vint64m2_t *, vint64m2_t *, vint64m2_t *, vint64m2_t *, vbool32_t, vint64m2_t, vint64m2_t, vint64m2_t, vint64m2_t, const int64_t *, vuint8mf4_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vluxseg4ei8_v)))
void vluxseg4ei8(vuint64m1_t *, vuint64m1_t *, vuint64m1_t *, vuint64m1_t *, const uint64_t *, vuint8mf8_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vluxseg4ei8_v_m)))
void vluxseg4ei8(vuint64m1_t *, vuint64m1_t *, vuint64m1_t *, vuint64m1_t *, vbool64_t, vuint64m1_t, vuint64m1_t, vuint64m1_t, vuint64m1_t, const uint64_t *, vuint8mf8_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vluxseg4ei8_v)))
void vluxseg4ei8(vuint64m2_t *, vuint64m2_t *, vuint64m2_t *, vuint64m2_t *, const uint64_t *, vuint8mf4_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vluxseg4ei8_v_m)))
void vluxseg4ei8(vuint64m2_t *, vuint64m2_t *, vuint64m2_t *, vuint64m2_t *, vbool32_t, vuint64m2_t, vuint64m2_t, vuint64m2_t, vuint64m2_t, const uint64_t *, vuint8mf4_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vluxseg5ei8_v)))
void vluxseg5ei8(vint64m1_t *, vint64m1_t *, vint64m1_t *, vint64m1_t *, vint64m1_t *, const int64_t *, vuint8mf8_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vluxseg5ei8_v_m)))
void vluxseg5ei8(vint64m1_t *, vint64m1_t *, vint64m1_t *, vint64m1_t *, vint64m1_t *, vbool64_t, vint64m1_t, vint64m1_t, vint64m1_t, vint64m1_t, vint64m1_t, const int64_t *, vuint8mf8_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vluxseg5ei8_v)))
void vluxseg5ei8(vuint64m1_t *, vuint64m1_t *, vuint64m1_t *, vuint64m1_t *, vuint64m1_t *, const uint64_t *, vuint8mf8_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vluxseg5ei8_v_m)))
void vluxseg5ei8(vuint64m1_t *, vuint64m1_t *, vuint64m1_t *, vuint64m1_t *, vuint64m1_t *, vbool64_t, vuint64m1_t, vuint64m1_t, vuint64m1_t, vuint64m1_t, vuint64m1_t, const uint64_t *, vuint8mf8_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vluxseg6ei8_v)))
void vluxseg6ei8(vint64m1_t *, vint64m1_t *, vint64m1_t *, vint64m1_t *, vint64m1_t *, vint64m1_t *, const int64_t *, vuint8mf8_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vluxseg6ei8_v_m)))
void vluxseg6ei8(vint64m1_t *, vint64m1_t *, vint64m1_t *, vint64m1_t *, vint64m1_t *, vint64m1_t *, vbool64_t, vint64m1_t, vint64m1_t, vint64m1_t, vint64m1_t, vint64m1_t, vint64m1_t, const int64_t *, vuint8mf8_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vluxseg6ei8_v)))
void vluxseg6ei8(vuint64m1_t *, vuint64m1_t *, vuint64m1_t *, vuint64m1_t *, vuint64m1_t *, vuint64m1_t *, const uint64_t *, vuint8mf8_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vluxseg6ei8_v_m)))
void vluxseg6ei8(vuint64m1_t *, vuint64m1_t *, vuint64m1_t *, vuint64m1_t *, vuint64m1_t *, vuint64m1_t *, vbool64_t, vuint64m1_t, vuint64m1_t, vuint64m1_t, vuint64m1_t, vuint64m1_t, vuint64m1_t, const uint64_t *, vuint8mf8_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vluxseg7ei8_v)))
void vluxseg7ei8(vint64m1_t *, vint64m1_t *, vint64m1_t *, vint64m1_t *, vint64m1_t *, vint64m1_t *, vint64m1_t *, const int64_t *, vuint8mf8_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vluxseg7ei8_v_m)))
void vluxseg7ei8(vint64m1_t *, vint64m1_t *, vint64m1_t *, vint64m1_t *, vint64m1_t *, vint64m1_t *, vint64m1_t *, vbool64_t, vint64m1_t, vint64m1_t, vint64m1_t, vint64m1_t, vint64m1_t, vint64m1_t, vint64m1_t, const int64_t *, vuint8mf8_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vneg_v)))
vint64m1_t vneg(vint64m1_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vneg_v_m)))
vint64m1_t vneg(vbool64_t, vint64m1_t, vint64m1_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vneg_v)))
vint64m2_t vneg(vint64m2_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vneg_v_m)))
vint64m2_t vneg(vbool32_t, vint64m2_t, vint64m2_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vneg_v)))
vint64m4_t vneg(vint64m4_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vneg_v_m)))
vint64m4_t vneg(vbool16_t, vint64m4_t, vint64m4_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vneg_v)))
vint64m8_t vneg(vint64m8_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vneg_v_m)))
vint64m8_t vneg(vbool8_t, vint64m8_t, vint64m8_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vluxseg7ei8_v)))
void vluxseg7ei8(vuint64m1_t *, vuint64m1_t *, vuint64m1_t *, vuint64m1_t *, vuint64m1_t *, vuint64m1_t *, vuint64m1_t *, const uint64_t *, vuint8mf8_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vluxseg7ei8_v_m)))
void vluxseg7ei8(vuint64m1_t *, vuint64m1_t *, vuint64m1_t *, vuint64m1_t *, vuint64m1_t *, vuint64m1_t *, vuint64m1_t *, vbool64_t, vuint64m1_t, vuint64m1_t, vuint64m1_t, vuint64m1_t, vuint64m1_t, vuint64m1_t, vuint64m1_t, const uint64_t *, vuint8mf8_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vluxseg8ei8_v)))
void vluxseg8ei8(vint64m1_t *, vint64m1_t *, vint64m1_t *, vint64m1_t *, vint64m1_t *, vint64m1_t *, vint64m1_t *, vint64m1_t *, const int64_t *, vuint8mf8_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vluxseg8ei8_v_m)))
void vluxseg8ei8(vint64m1_t *, vint64m1_t *, vint64m1_t *, vint64m1_t *, vint64m1_t *, vint64m1_t *, vint64m1_t *, vint64m1_t *, vbool64_t, vint64m1_t, vint64m1_t, vint64m1_t, vint64m1_t, vint64m1_t, vint64m1_t, vint64m1_t, vint64m1_t, const int64_t *, vuint8mf8_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vluxseg8ei8_v)))
void vluxseg8ei8(vuint64m1_t *, vuint64m1_t *, vuint64m1_t *, vuint64m1_t *, vuint64m1_t *, vuint64m1_t *, vuint64m1_t *, vuint64m1_t *, const uint64_t *, vuint8mf8_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vluxseg8ei8_v_m)))
void vluxseg8ei8(vuint64m1_t *, vuint64m1_t *, vuint64m1_t *, vuint64m1_t *, vuint64m1_t *, vuint64m1_t *, vuint64m1_t *, vuint64m1_t *, vbool64_t, vuint64m1_t, vuint64m1_t, vuint64m1_t, vuint64m1_t, vuint64m1_t, vuint64m1_t, vuint64m1_t, vuint64m1_t, const uint64_t *, vuint8mf8_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vluxseg2ei16_v)))
void vluxseg2ei16(vint64m1_t *, vint64m1_t *, const int64_t *, vuint16mf4_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vluxseg2ei16_v_m)))
void vluxseg2ei16(vint64m1_t *, vint64m1_t *, vbool64_t, vint64m1_t, vint64m1_t, const int64_t *, vuint16mf4_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vluxseg2ei16_v)))
void vluxseg2ei16(vint64m2_t *, vint64m2_t *, const int64_t *, vuint16mf2_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vluxseg2ei16_v_m)))
void vluxseg2ei16(vint64m2_t *, vint64m2_t *, vbool32_t, vint64m2_t, vint64m2_t, const int64_t *, vuint16mf2_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vluxseg2ei16_v)))
void vluxseg2ei16(vint64m4_t *, vint64m4_t *, const int64_t *, vuint16m1_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vluxseg2ei16_v_m)))
void vluxseg2ei16(vint64m4_t *, vint64m4_t *, vbool16_t, vint64m4_t, vint64m4_t, const int64_t *, vuint16m1_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vluxseg2ei16_v)))
void vluxseg2ei16(vuint64m1_t *, vuint64m1_t *, const uint64_t *, vuint16mf4_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vluxseg2ei16_v_m)))
void vluxseg2ei16(vuint64m1_t *, vuint64m1_t *, vbool64_t, vuint64m1_t, vuint64m1_t, const uint64_t *, vuint16mf4_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vluxseg2ei16_v)))
void vluxseg2ei16(vuint64m2_t *, vuint64m2_t *, const uint64_t *, vuint16mf2_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vluxseg2ei16_v_m)))
void vluxseg2ei16(vuint64m2_t *, vuint64m2_t *, vbool32_t, vuint64m2_t, vuint64m2_t, const uint64_t *, vuint16mf2_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vluxseg2ei16_v)))
void vluxseg2ei16(vuint64m4_t *, vuint64m4_t *, const uint64_t *, vuint16m1_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vluxseg2ei16_v_m)))
void vluxseg2ei16(vuint64m4_t *, vuint64m4_t *, vbool16_t, vuint64m4_t, vuint64m4_t, const uint64_t *, vuint16m1_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vluxseg3ei16_v)))
void vluxseg3ei16(vint64m1_t *, vint64m1_t *, vint64m1_t *, const int64_t *, vuint16mf4_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vluxseg3ei16_v_m)))
void vluxseg3ei16(vint64m1_t *, vint64m1_t *, vint64m1_t *, vbool64_t, vint64m1_t, vint64m1_t, vint64m1_t, const int64_t *, vuint16mf4_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vluxseg3ei16_v)))
void vluxseg3ei16(vint64m2_t *, vint64m2_t *, vint64m2_t *, const int64_t *, vuint16mf2_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vluxseg3ei16_v_m)))
void vluxseg3ei16(vint64m2_t *, vint64m2_t *, vint64m2_t *, vbool32_t, vint64m2_t, vint64m2_t, vint64m2_t, const int64_t *, vuint16mf2_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vluxseg3ei16_v)))
void vluxseg3ei16(vuint64m1_t *, vuint64m1_t *, vuint64m1_t *, const uint64_t *, vuint16mf4_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vluxseg3ei16_v_m)))
void vluxseg3ei16(vuint64m1_t *, vuint64m1_t *, vuint64m1_t *, vbool64_t, vuint64m1_t, vuint64m1_t, vuint64m1_t, const uint64_t *, vuint16mf4_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vluxseg3ei16_v)))
void vluxseg3ei16(vuint64m2_t *, vuint64m2_t *, vuint64m2_t *, const uint64_t *, vuint16mf2_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vluxseg3ei16_v_m)))
void vluxseg3ei16(vuint64m2_t *, vuint64m2_t *, vuint64m2_t *, vbool32_t, vuint64m2_t, vuint64m2_t, vuint64m2_t, const uint64_t *, vuint16mf2_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vluxseg4ei16_v)))
void vluxseg4ei16(vint64m1_t *, vint64m1_t *, vint64m1_t *, vint64m1_t *, const int64_t *, vuint16mf4_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vluxseg4ei16_v_m)))
void vluxseg4ei16(vint64m1_t *, vint64m1_t *, vint64m1_t *, vint64m1_t *, vbool64_t, vint64m1_t, vint64m1_t, vint64m1_t, vint64m1_t, const int64_t *, vuint16mf4_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vluxseg4ei16_v)))
void vluxseg4ei16(vint64m2_t *, vint64m2_t *, vint64m2_t *, vint64m2_t *, const int64_t *, vuint16mf2_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vluxseg4ei16_v_m)))
void vluxseg4ei16(vint64m2_t *, vint64m2_t *, vint64m2_t *, vint64m2_t *, vbool32_t, vint64m2_t, vint64m2_t, vint64m2_t, vint64m2_t, const int64_t *, vuint16mf2_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vluxseg4ei16_v)))
void vluxseg4ei16(vuint64m1_t *, vuint64m1_t *, vuint64m1_t *, vuint64m1_t *, const uint64_t *, vuint16mf4_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vluxseg4ei16_v_m)))
void vluxseg4ei16(vuint64m1_t *, vuint64m1_t *, vuint64m1_t *, vuint64m1_t *, vbool64_t, vuint64m1_t, vuint64m1_t, vuint64m1_t, vuint64m1_t, const uint64_t *, vuint16mf4_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vluxseg4ei16_v)))
void vluxseg4ei16(vuint64m2_t *, vuint64m2_t *, vuint64m2_t *, vuint64m2_t *, const uint64_t *, vuint16mf2_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vluxseg4ei16_v_m)))
void vluxseg4ei16(vuint64m2_t *, vuint64m2_t *, vuint64m2_t *, vuint64m2_t *, vbool32_t, vuint64m2_t, vuint64m2_t, vuint64m2_t, vuint64m2_t, const uint64_t *, vuint16mf2_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vluxseg5ei16_v)))
void vluxseg5ei16(vint64m1_t *, vint64m1_t *, vint64m1_t *, vint64m1_t *, vint64m1_t *, const int64_t *, vuint16mf4_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vluxseg5ei16_v_m)))
void vluxseg5ei16(vint64m1_t *, vint64m1_t *, vint64m1_t *, vint64m1_t *, vint64m1_t *, vbool64_t, vint64m1_t, vint64m1_t, vint64m1_t, vint64m1_t, vint64m1_t, const int64_t *, vuint16mf4_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vnot_v)))
vint64m1_t vnot(vint64m1_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vnot_v_m)))
vint64m1_t vnot(vbool64_t, vint64m1_t, vint64m1_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vnot_v)))
vint64m2_t vnot(vint64m2_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vnot_v_m)))
vint64m2_t vnot(vbool32_t, vint64m2_t, vint64m2_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vnot_v)))
vint64m4_t vnot(vint64m4_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vnot_v_m)))
vint64m4_t vnot(vbool16_t, vint64m4_t, vint64m4_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vnot_v)))
vint64m8_t vnot(vint64m8_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vnot_v_m)))
vint64m8_t vnot(vbool8_t, vint64m8_t, vint64m8_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vluxseg5ei16_v)))
void vluxseg5ei16(vuint64m1_t *, vuint64m1_t *, vuint64m1_t *, vuint64m1_t *, vuint64m1_t *, const uint64_t *, vuint16mf4_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vluxseg5ei16_v_m)))
void vluxseg5ei16(vuint64m1_t *, vuint64m1_t *, vuint64m1_t *, vuint64m1_t *, vuint64m1_t *, vbool64_t, vuint64m1_t, vuint64m1_t, vuint64m1_t, vuint64m1_t, vuint64m1_t, const uint64_t *, vuint16mf4_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vluxseg6ei16_v)))
void vluxseg6ei16(vint64m1_t *, vint64m1_t *, vint64m1_t *, vint64m1_t *, vint64m1_t *, vint64m1_t *, const int64_t *, vuint16mf4_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vluxseg6ei16_v_m)))
void vluxseg6ei16(vint64m1_t *, vint64m1_t *, vint64m1_t *, vint64m1_t *, vint64m1_t *, vint64m1_t *, vbool64_t, vint64m1_t, vint64m1_t, vint64m1_t, vint64m1_t, vint64m1_t, vint64m1_t, const int64_t *, vuint16mf4_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vluxseg6ei16_v)))
void vluxseg6ei16(vuint64m1_t *, vuint64m1_t *, vuint64m1_t *, vuint64m1_t *, vuint64m1_t *, vuint64m1_t *, const uint64_t *, vuint16mf4_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vluxseg6ei16_v_m)))
void vluxseg6ei16(vuint64m1_t *, vuint64m1_t *, vuint64m1_t *, vuint64m1_t *, vuint64m1_t *, vuint64m1_t *, vbool64_t, vuint64m1_t, vuint64m1_t, vuint64m1_t, vuint64m1_t, vuint64m1_t, vuint64m1_t, const uint64_t *, vuint16mf4_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vluxseg7ei16_v)))
void vluxseg7ei16(vint64m1_t *, vint64m1_t *, vint64m1_t *, vint64m1_t *, vint64m1_t *, vint64m1_t *, vint64m1_t *, const int64_t *, vuint16mf4_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vluxseg7ei16_v_m)))
void vluxseg7ei16(vint64m1_t *, vint64m1_t *, vint64m1_t *, vint64m1_t *, vint64m1_t *, vint64m1_t *, vint64m1_t *, vbool64_t, vint64m1_t, vint64m1_t, vint64m1_t, vint64m1_t, vint64m1_t, vint64m1_t, vint64m1_t, const int64_t *, vuint16mf4_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vluxseg7ei16_v)))
void vluxseg7ei16(vuint64m1_t *, vuint64m1_t *, vuint64m1_t *, vuint64m1_t *, vuint64m1_t *, vuint64m1_t *, vuint64m1_t *, const uint64_t *, vuint16mf4_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vluxseg7ei16_v_m)))
void vluxseg7ei16(vuint64m1_t *, vuint64m1_t *, vuint64m1_t *, vuint64m1_t *, vuint64m1_t *, vuint64m1_t *, vuint64m1_t *, vbool64_t, vuint64m1_t, vuint64m1_t, vuint64m1_t, vuint64m1_t, vuint64m1_t, vuint64m1_t, vuint64m1_t, const uint64_t *, vuint16mf4_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vluxseg8ei16_v)))
void vluxseg8ei16(vint64m1_t *, vint64m1_t *, vint64m1_t *, vint64m1_t *, vint64m1_t *, vint64m1_t *, vint64m1_t *, vint64m1_t *, const int64_t *, vuint16mf4_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vluxseg8ei16_v_m)))
void vluxseg8ei16(vint64m1_t *, vint64m1_t *, vint64m1_t *, vint64m1_t *, vint64m1_t *, vint64m1_t *, vint64m1_t *, vint64m1_t *, vbool64_t, vint64m1_t, vint64m1_t, vint64m1_t, vint64m1_t, vint64m1_t, vint64m1_t, vint64m1_t, vint64m1_t, const int64_t *, vuint16mf4_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vluxseg8ei16_v)))
void vluxseg8ei16(vuint64m1_t *, vuint64m1_t *, vuint64m1_t *, vuint64m1_t *, vuint64m1_t *, vuint64m1_t *, vuint64m1_t *, vuint64m1_t *, const uint64_t *, vuint16mf4_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vluxseg8ei16_v_m)))
void vluxseg8ei16(vuint64m1_t *, vuint64m1_t *, vuint64m1_t *, vuint64m1_t *, vuint64m1_t *, vuint64m1_t *, vuint64m1_t *, vuint64m1_t *, vbool64_t, vuint64m1_t, vuint64m1_t, vuint64m1_t, vuint64m1_t, vuint64m1_t, vuint64m1_t, vuint64m1_t, vuint64m1_t, const uint64_t *, vuint16mf4_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vluxseg2ei32_v)))
void vluxseg2ei32(vint64m1_t *, vint64m1_t *, const int64_t *, vuint32mf2_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vluxseg2ei32_v_m)))
void vluxseg2ei32(vint64m1_t *, vint64m1_t *, vbool64_t, vint64m1_t, vint64m1_t, const int64_t *, vuint32mf2_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vluxseg2ei32_v)))
void vluxseg2ei32(vint64m2_t *, vint64m2_t *, const int64_t *, vuint32m1_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vluxseg2ei32_v_m)))
void vluxseg2ei32(vint64m2_t *, vint64m2_t *, vbool32_t, vint64m2_t, vint64m2_t, const int64_t *, vuint32m1_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vluxseg2ei32_v)))
void vluxseg2ei32(vint64m4_t *, vint64m4_t *, const int64_t *, vuint32m2_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vluxseg2ei32_v_m)))
void vluxseg2ei32(vint64m4_t *, vint64m4_t *, vbool16_t, vint64m4_t, vint64m4_t, const int64_t *, vuint32m2_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vluxseg2ei32_v)))
void vluxseg2ei32(vuint64m1_t *, vuint64m1_t *, const uint64_t *, vuint32mf2_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vluxseg2ei32_v_m)))
void vluxseg2ei32(vuint64m1_t *, vuint64m1_t *, vbool64_t, vuint64m1_t, vuint64m1_t, const uint64_t *, vuint32mf2_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vluxseg2ei32_v)))
void vluxseg2ei32(vuint64m2_t *, vuint64m2_t *, const uint64_t *, vuint32m1_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vluxseg2ei32_v_m)))
void vluxseg2ei32(vuint64m2_t *, vuint64m2_t *, vbool32_t, vuint64m2_t, vuint64m2_t, const uint64_t *, vuint32m1_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vluxseg2ei32_v)))
void vluxseg2ei32(vuint64m4_t *, vuint64m4_t *, const uint64_t *, vuint32m2_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vluxseg2ei32_v_m)))
void vluxseg2ei32(vuint64m4_t *, vuint64m4_t *, vbool16_t, vuint64m4_t, vuint64m4_t, const uint64_t *, vuint32m2_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vluxseg3ei32_v)))
void vluxseg3ei32(vint64m1_t *, vint64m1_t *, vint64m1_t *, const int64_t *, vuint32mf2_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vluxseg3ei32_v_m)))
void vluxseg3ei32(vint64m1_t *, vint64m1_t *, vint64m1_t *, vbool64_t, vint64m1_t, vint64m1_t, vint64m1_t, const int64_t *, vuint32mf2_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vluxseg3ei32_v)))
void vluxseg3ei32(vint64m2_t *, vint64m2_t *, vint64m2_t *, const int64_t *, vuint32m1_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vluxseg3ei32_v_m)))
void vluxseg3ei32(vint64m2_t *, vint64m2_t *, vint64m2_t *, vbool32_t, vint64m2_t, vint64m2_t, vint64m2_t, const int64_t *, vuint32m1_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vnot_v)))
vuint64m1_t vnot(vuint64m1_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vnot_v_m)))
vuint64m1_t vnot(vbool64_t, vuint64m1_t, vuint64m1_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vnot_v)))
vuint64m2_t vnot(vuint64m2_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vnot_v_m)))
vuint64m2_t vnot(vbool32_t, vuint64m2_t, vuint64m2_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vnot_v)))
vuint64m4_t vnot(vuint64m4_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vnot_v_m)))
vuint64m4_t vnot(vbool16_t, vuint64m4_t, vuint64m4_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vnot_v)))
vuint64m8_t vnot(vuint64m8_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vnot_v_m)))
vuint64m8_t vnot(vbool8_t, vuint64m8_t, vuint64m8_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vluxseg3ei32_v)))
void vluxseg3ei32(vuint64m1_t *, vuint64m1_t *, vuint64m1_t *, const uint64_t *, vuint32mf2_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vluxseg3ei32_v_m)))
void vluxseg3ei32(vuint64m1_t *, vuint64m1_t *, vuint64m1_t *, vbool64_t, vuint64m1_t, vuint64m1_t, vuint64m1_t, const uint64_t *, vuint32mf2_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vluxseg3ei32_v)))
void vluxseg3ei32(vuint64m2_t *, vuint64m2_t *, vuint64m2_t *, const uint64_t *, vuint32m1_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vluxseg3ei32_v_m)))
void vluxseg3ei32(vuint64m2_t *, vuint64m2_t *, vuint64m2_t *, vbool32_t, vuint64m2_t, vuint64m2_t, vuint64m2_t, const uint64_t *, vuint32m1_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vluxseg4ei32_v)))
void vluxseg4ei32(vint64m1_t *, vint64m1_t *, vint64m1_t *, vint64m1_t *, const int64_t *, vuint32mf2_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vluxseg4ei32_v_m)))
void vluxseg4ei32(vint64m1_t *, vint64m1_t *, vint64m1_t *, vint64m1_t *, vbool64_t, vint64m1_t, vint64m1_t, vint64m1_t, vint64m1_t, const int64_t *, vuint32mf2_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vluxseg4ei32_v)))
void vluxseg4ei32(vint64m2_t *, vint64m2_t *, vint64m2_t *, vint64m2_t *, const int64_t *, vuint32m1_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vluxseg4ei32_v_m)))
void vluxseg4ei32(vint64m2_t *, vint64m2_t *, vint64m2_t *, vint64m2_t *, vbool32_t, vint64m2_t, vint64m2_t, vint64m2_t, vint64m2_t, const int64_t *, vuint32m1_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vluxseg4ei32_v)))
void vluxseg4ei32(vuint64m1_t *, vuint64m1_t *, vuint64m1_t *, vuint64m1_t *, const uint64_t *, vuint32mf2_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vluxseg4ei32_v_m)))
void vluxseg4ei32(vuint64m1_t *, vuint64m1_t *, vuint64m1_t *, vuint64m1_t *, vbool64_t, vuint64m1_t, vuint64m1_t, vuint64m1_t, vuint64m1_t, const uint64_t *, vuint32mf2_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vluxseg4ei32_v)))
void vluxseg4ei32(vuint64m2_t *, vuint64m2_t *, vuint64m2_t *, vuint64m2_t *, const uint64_t *, vuint32m1_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vluxseg4ei32_v_m)))
void vluxseg4ei32(vuint64m2_t *, vuint64m2_t *, vuint64m2_t *, vuint64m2_t *, vbool32_t, vuint64m2_t, vuint64m2_t, vuint64m2_t, vuint64m2_t, const uint64_t *, vuint32m1_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vluxseg5ei32_v)))
void vluxseg5ei32(vint64m1_t *, vint64m1_t *, vint64m1_t *, vint64m1_t *, vint64m1_t *, const int64_t *, vuint32mf2_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vluxseg5ei32_v_m)))
void vluxseg5ei32(vint64m1_t *, vint64m1_t *, vint64m1_t *, vint64m1_t *, vint64m1_t *, vbool64_t, vint64m1_t, vint64m1_t, vint64m1_t, vint64m1_t, vint64m1_t, const int64_t *, vuint32mf2_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vluxseg5ei32_v)))
void vluxseg5ei32(vuint64m1_t *, vuint64m1_t *, vuint64m1_t *, vuint64m1_t *, vuint64m1_t *, const uint64_t *, vuint32mf2_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vluxseg5ei32_v_m)))
void vluxseg5ei32(vuint64m1_t *, vuint64m1_t *, vuint64m1_t *, vuint64m1_t *, vuint64m1_t *, vbool64_t, vuint64m1_t, vuint64m1_t, vuint64m1_t, vuint64m1_t, vuint64m1_t, const uint64_t *, vuint32mf2_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vluxseg6ei32_v)))
void vluxseg6ei32(vint64m1_t *, vint64m1_t *, vint64m1_t *, vint64m1_t *, vint64m1_t *, vint64m1_t *, const int64_t *, vuint32mf2_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vluxseg6ei32_v_m)))
void vluxseg6ei32(vint64m1_t *, vint64m1_t *, vint64m1_t *, vint64m1_t *, vint64m1_t *, vint64m1_t *, vbool64_t, vint64m1_t, vint64m1_t, vint64m1_t, vint64m1_t, vint64m1_t, vint64m1_t, const int64_t *, vuint32mf2_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vluxseg6ei32_v)))
void vluxseg6ei32(vuint64m1_t *, vuint64m1_t *, vuint64m1_t *, vuint64m1_t *, vuint64m1_t *, vuint64m1_t *, const uint64_t *, vuint32mf2_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vluxseg6ei32_v_m)))
void vluxseg6ei32(vuint64m1_t *, vuint64m1_t *, vuint64m1_t *, vuint64m1_t *, vuint64m1_t *, vuint64m1_t *, vbool64_t, vuint64m1_t, vuint64m1_t, vuint64m1_t, vuint64m1_t, vuint64m1_t, vuint64m1_t, const uint64_t *, vuint32mf2_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vluxseg7ei32_v)))
void vluxseg7ei32(vint64m1_t *, vint64m1_t *, vint64m1_t *, vint64m1_t *, vint64m1_t *, vint64m1_t *, vint64m1_t *, const int64_t *, vuint32mf2_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vluxseg7ei32_v_m)))
void vluxseg7ei32(vint64m1_t *, vint64m1_t *, vint64m1_t *, vint64m1_t *, vint64m1_t *, vint64m1_t *, vint64m1_t *, vbool64_t, vint64m1_t, vint64m1_t, vint64m1_t, vint64m1_t, vint64m1_t, vint64m1_t, vint64m1_t, const int64_t *, vuint32mf2_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vluxseg7ei32_v)))
void vluxseg7ei32(vuint64m1_t *, vuint64m1_t *, vuint64m1_t *, vuint64m1_t *, vuint64m1_t *, vuint64m1_t *, vuint64m1_t *, const uint64_t *, vuint32mf2_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vluxseg7ei32_v_m)))
void vluxseg7ei32(vuint64m1_t *, vuint64m1_t *, vuint64m1_t *, vuint64m1_t *, vuint64m1_t *, vuint64m1_t *, vuint64m1_t *, vbool64_t, vuint64m1_t, vuint64m1_t, vuint64m1_t, vuint64m1_t, vuint64m1_t, vuint64m1_t, vuint64m1_t, const uint64_t *, vuint32mf2_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vluxseg8ei32_v)))
void vluxseg8ei32(vint64m1_t *, vint64m1_t *, vint64m1_t *, vint64m1_t *, vint64m1_t *, vint64m1_t *, vint64m1_t *, vint64m1_t *, const int64_t *, vuint32mf2_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vluxseg8ei32_v_m)))
void vluxseg8ei32(vint64m1_t *, vint64m1_t *, vint64m1_t *, vint64m1_t *, vint64m1_t *, vint64m1_t *, vint64m1_t *, vint64m1_t *, vbool64_t, vint64m1_t, vint64m1_t, vint64m1_t, vint64m1_t, vint64m1_t, vint64m1_t, vint64m1_t, vint64m1_t, const int64_t *, vuint32mf2_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vluxseg8ei32_v)))
void vluxseg8ei32(vuint64m1_t *, vuint64m1_t *, vuint64m1_t *, vuint64m1_t *, vuint64m1_t *, vuint64m1_t *, vuint64m1_t *, vuint64m1_t *, const uint64_t *, vuint32mf2_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vluxseg8ei32_v_m)))
void vluxseg8ei32(vuint64m1_t *, vuint64m1_t *, vuint64m1_t *, vuint64m1_t *, vuint64m1_t *, vuint64m1_t *, vuint64m1_t *, vuint64m1_t *, vbool64_t, vuint64m1_t, vuint64m1_t, vuint64m1_t, vuint64m1_t, vuint64m1_t, vuint64m1_t, vuint64m1_t, vuint64m1_t, const uint64_t *, vuint32mf2_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vluxseg2ei64_v)))
void vluxseg2ei64(vint64m1_t *, vint64m1_t *, const int64_t *, vuint64m1_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vluxseg2ei64_v_m)))
void vluxseg2ei64(vint64m1_t *, vint64m1_t *, vbool64_t, vint64m1_t, vint64m1_t, const int64_t *, vuint64m1_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vluxseg2ei64_v)))
void vluxseg2ei64(vint64m2_t *, vint64m2_t *, const int64_t *, vuint64m2_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vluxseg2ei64_v_m)))
void vluxseg2ei64(vint64m2_t *, vint64m2_t *, vbool32_t, vint64m2_t, vint64m2_t, const int64_t *, vuint64m2_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vluxseg2ei64_v)))
void vluxseg2ei64(vint64m4_t *, vint64m4_t *, const int64_t *, vuint64m4_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vluxseg2ei64_v_m)))
void vluxseg2ei64(vint64m4_t *, vint64m4_t *, vbool16_t, vint64m4_t, vint64m4_t, const int64_t *, vuint64m4_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vluxseg2ei64_v)))
void vluxseg2ei64(vuint64m1_t *, vuint64m1_t *, const uint64_t *, vuint64m1_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vluxseg2ei64_v_m)))
void vluxseg2ei64(vuint64m1_t *, vuint64m1_t *, vbool64_t, vuint64m1_t, vuint64m1_t, const uint64_t *, vuint64m1_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vluxseg2ei64_v)))
void vluxseg2ei64(vuint64m2_t *, vuint64m2_t *, const uint64_t *, vuint64m2_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vluxseg2ei64_v_m)))
void vluxseg2ei64(vuint64m2_t *, vuint64m2_t *, vbool32_t, vuint64m2_t, vuint64m2_t, const uint64_t *, vuint64m2_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vluxseg2ei64_v)))
void vluxseg2ei64(vuint64m4_t *, vuint64m4_t *, const uint64_t *, vuint64m4_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vluxseg2ei64_v_m)))
void vluxseg2ei64(vuint64m4_t *, vuint64m4_t *, vbool16_t, vuint64m4_t, vuint64m4_t, const uint64_t *, vuint64m4_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vluxseg3ei64_v)))
void vluxseg3ei64(vint64m1_t *, vint64m1_t *, vint64m1_t *, const int64_t *, vuint64m1_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vluxseg3ei64_v_m)))
void vluxseg3ei64(vint64m1_t *, vint64m1_t *, vint64m1_t *, vbool64_t, vint64m1_t, vint64m1_t, vint64m1_t, const int64_t *, vuint64m1_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vluxseg3ei64_v)))
void vluxseg3ei64(vint64m2_t *, vint64m2_t *, vint64m2_t *, const int64_t *, vuint64m2_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vluxseg3ei64_v_m)))
void vluxseg3ei64(vint64m2_t *, vint64m2_t *, vint64m2_t *, vbool32_t, vint64m2_t, vint64m2_t, vint64m2_t, const int64_t *, vuint64m2_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vluxseg3ei64_v)))
void vluxseg3ei64(vuint64m1_t *, vuint64m1_t *, vuint64m1_t *, const uint64_t *, vuint64m1_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vluxseg3ei64_v_m)))
void vluxseg3ei64(vuint64m1_t *, vuint64m1_t *, vuint64m1_t *, vbool64_t, vuint64m1_t, vuint64m1_t, vuint64m1_t, const uint64_t *, vuint64m1_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vluxseg3ei64_v)))
void vluxseg3ei64(vuint64m2_t *, vuint64m2_t *, vuint64m2_t *, const uint64_t *, vuint64m2_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vluxseg3ei64_v_m)))
void vluxseg3ei64(vuint64m2_t *, vuint64m2_t *, vuint64m2_t *, vbool32_t, vuint64m2_t, vuint64m2_t, vuint64m2_t, const uint64_t *, vuint64m2_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vluxseg4ei64_v)))
void vluxseg4ei64(vint64m1_t *, vint64m1_t *, vint64m1_t *, vint64m1_t *, const int64_t *, vuint64m1_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vluxseg4ei64_v_m)))
void vluxseg4ei64(vint64m1_t *, vint64m1_t *, vint64m1_t *, vint64m1_t *, vbool64_t, vint64m1_t, vint64m1_t, vint64m1_t, vint64m1_t, const int64_t *, vuint64m1_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vluxseg4ei64_v)))
void vluxseg4ei64(vint64m2_t *, vint64m2_t *, vint64m2_t *, vint64m2_t *, const int64_t *, vuint64m2_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vluxseg4ei64_v_m)))
void vluxseg4ei64(vint64m2_t *, vint64m2_t *, vint64m2_t *, vint64m2_t *, vbool32_t, vint64m2_t, vint64m2_t, vint64m2_t, vint64m2_t, const int64_t *, vuint64m2_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vluxseg4ei64_v)))
void vluxseg4ei64(vuint64m1_t *, vuint64m1_t *, vuint64m1_t *, vuint64m1_t *, const uint64_t *, vuint64m1_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vluxseg4ei64_v_m)))
void vluxseg4ei64(vuint64m1_t *, vuint64m1_t *, vuint64m1_t *, vuint64m1_t *, vbool64_t, vuint64m1_t, vuint64m1_t, vuint64m1_t, vuint64m1_t, const uint64_t *, vuint64m1_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vluxseg4ei64_v)))
void vluxseg4ei64(vuint64m2_t *, vuint64m2_t *, vuint64m2_t *, vuint64m2_t *, const uint64_t *, vuint64m2_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vluxseg4ei64_v_m)))
void vluxseg4ei64(vuint64m2_t *, vuint64m2_t *, vuint64m2_t *, vuint64m2_t *, vbool32_t, vuint64m2_t, vuint64m2_t, vuint64m2_t, vuint64m2_t, const uint64_t *, vuint64m2_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vluxseg5ei64_v)))
void vluxseg5ei64(vint64m1_t *, vint64m1_t *, vint64m1_t *, vint64m1_t *, vint64m1_t *, const int64_t *, vuint64m1_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vluxseg5ei64_v_m)))
void vluxseg5ei64(vint64m1_t *, vint64m1_t *, vint64m1_t *, vint64m1_t *, vint64m1_t *, vbool64_t, vint64m1_t, vint64m1_t, vint64m1_t, vint64m1_t, vint64m1_t, const int64_t *, vuint64m1_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vluxseg5ei64_v)))
void vluxseg5ei64(vuint64m1_t *, vuint64m1_t *, vuint64m1_t *, vuint64m1_t *, vuint64m1_t *, const uint64_t *, vuint64m1_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vluxseg5ei64_v_m)))
void vluxseg5ei64(vuint64m1_t *, vuint64m1_t *, vuint64m1_t *, vuint64m1_t *, vuint64m1_t *, vbool64_t, vuint64m1_t, vuint64m1_t, vuint64m1_t, vuint64m1_t, vuint64m1_t, const uint64_t *, vuint64m1_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vluxseg6ei64_v)))
void vluxseg6ei64(vint64m1_t *, vint64m1_t *, vint64m1_t *, vint64m1_t *, vint64m1_t *, vint64m1_t *, const int64_t *, vuint64m1_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vluxseg6ei64_v_m)))
void vluxseg6ei64(vint64m1_t *, vint64m1_t *, vint64m1_t *, vint64m1_t *, vint64m1_t *, vint64m1_t *, vbool64_t, vint64m1_t, vint64m1_t, vint64m1_t, vint64m1_t, vint64m1_t, vint64m1_t, const int64_t *, vuint64m1_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vluxseg6ei64_v)))
void vluxseg6ei64(vuint64m1_t *, vuint64m1_t *, vuint64m1_t *, vuint64m1_t *, vuint64m1_t *, vuint64m1_t *, const uint64_t *, vuint64m1_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vluxseg6ei64_v_m)))
void vluxseg6ei64(vuint64m1_t *, vuint64m1_t *, vuint64m1_t *, vuint64m1_t *, vuint64m1_t *, vuint64m1_t *, vbool64_t, vuint64m1_t, vuint64m1_t, vuint64m1_t, vuint64m1_t, vuint64m1_t, vuint64m1_t, const uint64_t *, vuint64m1_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vluxseg7ei64_v)))
void vluxseg7ei64(vint64m1_t *, vint64m1_t *, vint64m1_t *, vint64m1_t *, vint64m1_t *, vint64m1_t *, vint64m1_t *, const int64_t *, vuint64m1_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vluxseg7ei64_v_m)))
void vluxseg7ei64(vint64m1_t *, vint64m1_t *, vint64m1_t *, vint64m1_t *, vint64m1_t *, vint64m1_t *, vint64m1_t *, vbool64_t, vint64m1_t, vint64m1_t, vint64m1_t, vint64m1_t, vint64m1_t, vint64m1_t, vint64m1_t, const int64_t *, vuint64m1_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vluxseg7ei64_v)))
void vluxseg7ei64(vuint64m1_t *, vuint64m1_t *, vuint64m1_t *, vuint64m1_t *, vuint64m1_t *, vuint64m1_t *, vuint64m1_t *, const uint64_t *, vuint64m1_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vluxseg7ei64_v_m)))
void vluxseg7ei64(vuint64m1_t *, vuint64m1_t *, vuint64m1_t *, vuint64m1_t *, vuint64m1_t *, vuint64m1_t *, vuint64m1_t *, vbool64_t, vuint64m1_t, vuint64m1_t, vuint64m1_t, vuint64m1_t, vuint64m1_t, vuint64m1_t, vuint64m1_t, const uint64_t *, vuint64m1_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vluxseg8ei64_v)))
void vluxseg8ei64(vint64m1_t *, vint64m1_t *, vint64m1_t *, vint64m1_t *, vint64m1_t *, vint64m1_t *, vint64m1_t *, vint64m1_t *, const int64_t *, vuint64m1_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vluxseg8ei64_v_m)))
void vluxseg8ei64(vint64m1_t *, vint64m1_t *, vint64m1_t *, vint64m1_t *, vint64m1_t *, vint64m1_t *, vint64m1_t *, vint64m1_t *, vbool64_t, vint64m1_t, vint64m1_t, vint64m1_t, vint64m1_t, vint64m1_t, vint64m1_t, vint64m1_t, vint64m1_t, const int64_t *, vuint64m1_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vluxseg8ei64_v)))
void vluxseg8ei64(vuint64m1_t *, vuint64m1_t *, vuint64m1_t *, vuint64m1_t *, vuint64m1_t *, vuint64m1_t *, vuint64m1_t *, vuint64m1_t *, const uint64_t *, vuint64m1_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vluxseg8ei64_v_m)))
void vluxseg8ei64(vuint64m1_t *, vuint64m1_t *, vuint64m1_t *, vuint64m1_t *, vuint64m1_t *, vuint64m1_t *, vuint64m1_t *, vuint64m1_t *, vbool64_t, vuint64m1_t, vuint64m1_t, vuint64m1_t, vuint64m1_t, vuint64m1_t, vuint64m1_t, vuint64m1_t, vuint64m1_t, const uint64_t *, vuint64m1_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vwcvtu_x_x_v)))
vuint64m2_t vwcvtu_x(vuint32m1_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vwcvtu_x_x_v_m)))
vuint64m2_t vwcvtu_x(vbool32_t, vuint64m2_t, vuint32m1_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vwcvtu_x_x_v)))
vuint64m4_t vwcvtu_x(vuint32m2_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vwcvtu_x_x_v_m)))
vuint64m4_t vwcvtu_x(vbool16_t, vuint64m4_t, vuint32m2_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vwcvtu_x_x_v)))
vuint64m8_t vwcvtu_x(vuint32m4_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vwcvtu_x_x_v_m)))
vuint64m8_t vwcvtu_x(vbool8_t, vuint64m8_t, vuint32m4_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vwcvtu_x_x_v)))
vuint64m1_t vwcvtu_x(vuint32mf2_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vwcvtu_x_x_v_m)))
vuint64m1_t vwcvtu_x(vbool64_t, vuint64m1_t, vuint32mf2_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vncvt_x_x_w)))
vint32m1_t vncvt_x(vint64m2_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vncvt_x_x_w_m)))
vint32m1_t vncvt_x(vbool32_t, vint32m1_t, vint64m2_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vncvt_x_x_w)))
vint32m2_t vncvt_x(vint64m4_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vncvt_x_x_w_m)))
vint32m2_t vncvt_x(vbool16_t, vint32m2_t, vint64m4_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vncvt_x_x_w)))
vint32m4_t vncvt_x(vint64m8_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vncvt_x_x_w_m)))
vint32m4_t vncvt_x(vbool8_t, vint32m4_t, vint64m8_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vncvt_x_x_w)))
vint32mf2_t vncvt_x(vint64m1_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vncvt_x_x_w_m)))
vint32mf2_t vncvt_x(vbool64_t, vint32mf2_t, vint64m1_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vle64_v_m)))
vint64m1_t vle64(vbool64_t, vint64m1_t, const int64_t *, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vle64_v_m)))
vint64m2_t vle64(vbool32_t, vint64m2_t, const int64_t *, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vle64_v_m)))
vint64m4_t vle64(vbool16_t, vint64m4_t, const int64_t *, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vle64_v_m)))
vint64m8_t vle64(vbool8_t, vint64m8_t, const int64_t *, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vle64_v_m)))
vuint64m1_t vle64(vbool64_t, vuint64m1_t, const uint64_t *, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vle64_v_m)))
vuint64m2_t vle64(vbool32_t, vuint64m2_t, const uint64_t *, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vle64_v_m)))
vuint64m4_t vle64(vbool16_t, vuint64m4_t, const uint64_t *, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vle64_v_m)))
vuint64m8_t vle64(vbool8_t, vuint64m8_t, const uint64_t *, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vloxseg2ei64_v)))
void vloxseg2ei64(vint8m1_t *, vint8m1_t *, const int8_t *, vuint64m8_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vloxseg2ei64_v_m)))
void vloxseg2ei64(vint8m1_t *, vint8m1_t *, vbool8_t, vint8m1_t, vint8m1_t, const int8_t *, vuint64m8_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vloxseg2ei64_v)))
void vloxseg2ei64(vint8mf2_t *, vint8mf2_t *, const int8_t *, vuint64m4_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vloxseg2ei64_v_m)))
void vloxseg2ei64(vint8mf2_t *, vint8mf2_t *, vbool16_t, vint8mf2_t, vint8mf2_t, const int8_t *, vuint64m4_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vloxseg2ei64_v)))
void vloxseg2ei64(vint8mf4_t *, vint8mf4_t *, const int8_t *, vuint64m2_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vloxseg2ei64_v_m)))
void vloxseg2ei64(vint8mf4_t *, vint8mf4_t *, vbool32_t, vint8mf4_t, vint8mf4_t, const int8_t *, vuint64m2_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vloxseg2ei64_v)))
void vloxseg2ei64(vint8mf8_t *, vint8mf8_t *, const int8_t *, vuint64m1_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vloxseg2ei64_v_m)))
void vloxseg2ei64(vint8mf8_t *, vint8mf8_t *, vbool64_t, vint8mf8_t, vint8mf8_t, const int8_t *, vuint64m1_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vloxseg2ei64_v)))
void vloxseg2ei64(vuint8m1_t *, vuint8m1_t *, const uint8_t *, vuint64m8_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vloxseg2ei64_v_m)))
void vloxseg2ei64(vuint8m1_t *, vuint8m1_t *, vbool8_t, vuint8m1_t, vuint8m1_t, const uint8_t *, vuint64m8_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vloxseg2ei64_v)))
void vloxseg2ei64(vuint8mf2_t *, vuint8mf2_t *, const uint8_t *, vuint64m4_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vloxseg2ei64_v_m)))
void vloxseg2ei64(vuint8mf2_t *, vuint8mf2_t *, vbool16_t, vuint8mf2_t, vuint8mf2_t, const uint8_t *, vuint64m4_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vloxseg2ei64_v)))
void vloxseg2ei64(vuint8mf4_t *, vuint8mf4_t *, const uint8_t *, vuint64m2_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vloxseg2ei64_v_m)))
void vloxseg2ei64(vuint8mf4_t *, vuint8mf4_t *, vbool32_t, vuint8mf4_t, vuint8mf4_t, const uint8_t *, vuint64m2_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vloxseg2ei64_v)))
void vloxseg2ei64(vuint8mf8_t *, vuint8mf8_t *, const uint8_t *, vuint64m1_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vloxseg2ei64_v_m)))
void vloxseg2ei64(vuint8mf8_t *, vuint8mf8_t *, vbool64_t, vuint8mf8_t, vuint8mf8_t, const uint8_t *, vuint64m1_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vloxseg3ei64_v)))
void vloxseg3ei64(vint8m1_t *, vint8m1_t *, vint8m1_t *, const int8_t *, vuint64m8_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vloxseg3ei64_v_m)))
void vloxseg3ei64(vint8m1_t *, vint8m1_t *, vint8m1_t *, vbool8_t, vint8m1_t, vint8m1_t, vint8m1_t, const int8_t *, vuint64m8_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vloxseg3ei64_v)))
void vloxseg3ei64(vint8mf2_t *, vint8mf2_t *, vint8mf2_t *, const int8_t *, vuint64m4_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vloxseg3ei64_v_m)))
void vloxseg3ei64(vint8mf2_t *, vint8mf2_t *, vint8mf2_t *, vbool16_t, vint8mf2_t, vint8mf2_t, vint8mf2_t, const int8_t *, vuint64m4_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vloxseg3ei64_v)))
void vloxseg3ei64(vint8mf4_t *, vint8mf4_t *, vint8mf4_t *, const int8_t *, vuint64m2_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vloxseg3ei64_v_m)))
void vloxseg3ei64(vint8mf4_t *, vint8mf4_t *, vint8mf4_t *, vbool32_t, vint8mf4_t, vint8mf4_t, vint8mf4_t, const int8_t *, vuint64m2_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vloxseg3ei64_v)))
void vloxseg3ei64(vint8mf8_t *, vint8mf8_t *, vint8mf8_t *, const int8_t *, vuint64m1_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vloxseg3ei64_v_m)))
void vloxseg3ei64(vint8mf8_t *, vint8mf8_t *, vint8mf8_t *, vbool64_t, vint8mf8_t, vint8mf8_t, vint8mf8_t, const int8_t *, vuint64m1_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vloxseg3ei64_v)))
void vloxseg3ei64(vuint8m1_t *, vuint8m1_t *, vuint8m1_t *, const uint8_t *, vuint64m8_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vloxseg3ei64_v_m)))
void vloxseg3ei64(vuint8m1_t *, vuint8m1_t *, vuint8m1_t *, vbool8_t, vuint8m1_t, vuint8m1_t, vuint8m1_t, const uint8_t *, vuint64m8_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vloxseg3ei64_v)))
void vloxseg3ei64(vuint8mf2_t *, vuint8mf2_t *, vuint8mf2_t *, const uint8_t *, vuint64m4_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vloxseg3ei64_v_m)))
void vloxseg3ei64(vuint8mf2_t *, vuint8mf2_t *, vuint8mf2_t *, vbool16_t, vuint8mf2_t, vuint8mf2_t, vuint8mf2_t, const uint8_t *, vuint64m4_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vloxseg3ei64_v)))
void vloxseg3ei64(vuint8mf4_t *, vuint8mf4_t *, vuint8mf4_t *, const uint8_t *, vuint64m2_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vloxseg3ei64_v_m)))
void vloxseg3ei64(vuint8mf4_t *, vuint8mf4_t *, vuint8mf4_t *, vbool32_t, vuint8mf4_t, vuint8mf4_t, vuint8mf4_t, const uint8_t *, vuint64m2_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vloxseg3ei64_v)))
void vloxseg3ei64(vuint8mf8_t *, vuint8mf8_t *, vuint8mf8_t *, const uint8_t *, vuint64m1_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vloxseg3ei64_v_m)))
void vloxseg3ei64(vuint8mf8_t *, vuint8mf8_t *, vuint8mf8_t *, vbool64_t, vuint8mf8_t, vuint8mf8_t, vuint8mf8_t, const uint8_t *, vuint64m1_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vloxseg4ei64_v)))
void vloxseg4ei64(vint8m1_t *, vint8m1_t *, vint8m1_t *, vint8m1_t *, const int8_t *, vuint64m8_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vloxseg4ei64_v_m)))
void vloxseg4ei64(vint8m1_t *, vint8m1_t *, vint8m1_t *, vint8m1_t *, vbool8_t, vint8m1_t, vint8m1_t, vint8m1_t, vint8m1_t, const int8_t *, vuint64m8_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vloxseg4ei64_v)))
void vloxseg4ei64(vint8mf2_t *, vint8mf2_t *, vint8mf2_t *, vint8mf2_t *, const int8_t *, vuint64m4_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vloxseg4ei64_v_m)))
void vloxseg4ei64(vint8mf2_t *, vint8mf2_t *, vint8mf2_t *, vint8mf2_t *, vbool16_t, vint8mf2_t, vint8mf2_t, vint8mf2_t, vint8mf2_t, const int8_t *, vuint64m4_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vloxseg4ei64_v)))
void vloxseg4ei64(vint8mf4_t *, vint8mf4_t *, vint8mf4_t *, vint8mf4_t *, const int8_t *, vuint64m2_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vloxseg4ei64_v_m)))
void vloxseg4ei64(vint8mf4_t *, vint8mf4_t *, vint8mf4_t *, vint8mf4_t *, vbool32_t, vint8mf4_t, vint8mf4_t, vint8mf4_t, vint8mf4_t, const int8_t *, vuint64m2_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vloxseg4ei64_v)))
void vloxseg4ei64(vint8mf8_t *, vint8mf8_t *, vint8mf8_t *, vint8mf8_t *, const int8_t *, vuint64m1_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vloxseg4ei64_v_m)))
void vloxseg4ei64(vint8mf8_t *, vint8mf8_t *, vint8mf8_t *, vint8mf8_t *, vbool64_t, vint8mf8_t, vint8mf8_t, vint8mf8_t, vint8mf8_t, const int8_t *, vuint64m1_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vloxseg4ei64_v)))
void vloxseg4ei64(vuint8m1_t *, vuint8m1_t *, vuint8m1_t *, vuint8m1_t *, const uint8_t *, vuint64m8_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vloxseg4ei64_v_m)))
void vloxseg4ei64(vuint8m1_t *, vuint8m1_t *, vuint8m1_t *, vuint8m1_t *, vbool8_t, vuint8m1_t, vuint8m1_t, vuint8m1_t, vuint8m1_t, const uint8_t *, vuint64m8_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vloxseg4ei64_v)))
void vloxseg4ei64(vuint8mf2_t *, vuint8mf2_t *, vuint8mf2_t *, vuint8mf2_t *, const uint8_t *, vuint64m4_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vloxseg4ei64_v_m)))
void vloxseg4ei64(vuint8mf2_t *, vuint8mf2_t *, vuint8mf2_t *, vuint8mf2_t *, vbool16_t, vuint8mf2_t, vuint8mf2_t, vuint8mf2_t, vuint8mf2_t, const uint8_t *, vuint64m4_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vloxseg4ei64_v)))
void vloxseg4ei64(vuint8mf4_t *, vuint8mf4_t *, vuint8mf4_t *, vuint8mf4_t *, const uint8_t *, vuint64m2_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vloxseg4ei64_v_m)))
void vloxseg4ei64(vuint8mf4_t *, vuint8mf4_t *, vuint8mf4_t *, vuint8mf4_t *, vbool32_t, vuint8mf4_t, vuint8mf4_t, vuint8mf4_t, vuint8mf4_t, const uint8_t *, vuint64m2_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vloxseg4ei64_v)))
void vloxseg4ei64(vuint8mf8_t *, vuint8mf8_t *, vuint8mf8_t *, vuint8mf8_t *, const uint8_t *, vuint64m1_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vloxseg4ei64_v_m)))
void vloxseg4ei64(vuint8mf8_t *, vuint8mf8_t *, vuint8mf8_t *, vuint8mf8_t *, vbool64_t, vuint8mf8_t, vuint8mf8_t, vuint8mf8_t, vuint8mf8_t, const uint8_t *, vuint64m1_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vloxseg5ei64_v)))
void vloxseg5ei64(vint8m1_t *, vint8m1_t *, vint8m1_t *, vint8m1_t *, vint8m1_t *, const int8_t *, vuint64m8_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vloxseg5ei64_v_m)))
void vloxseg5ei64(vint8m1_t *, vint8m1_t *, vint8m1_t *, vint8m1_t *, vint8m1_t *, vbool8_t, vint8m1_t, vint8m1_t, vint8m1_t, vint8m1_t, vint8m1_t, const int8_t *, vuint64m8_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vloxseg5ei64_v)))
void vloxseg5ei64(vint8mf2_t *, vint8mf2_t *, vint8mf2_t *, vint8mf2_t *, vint8mf2_t *, const int8_t *, vuint64m4_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vloxseg5ei64_v_m)))
void vloxseg5ei64(vint8mf2_t *, vint8mf2_t *, vint8mf2_t *, vint8mf2_t *, vint8mf2_t *, vbool16_t, vint8mf2_t, vint8mf2_t, vint8mf2_t, vint8mf2_t, vint8mf2_t, const int8_t *, vuint64m4_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vloxseg5ei64_v)))
void vloxseg5ei64(vint8mf4_t *, vint8mf4_t *, vint8mf4_t *, vint8mf4_t *, vint8mf4_t *, const int8_t *, vuint64m2_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vloxseg5ei64_v_m)))
void vloxseg5ei64(vint8mf4_t *, vint8mf4_t *, vint8mf4_t *, vint8mf4_t *, vint8mf4_t *, vbool32_t, vint8mf4_t, vint8mf4_t, vint8mf4_t, vint8mf4_t, vint8mf4_t, const int8_t *, vuint64m2_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vloxseg5ei64_v)))
void vloxseg5ei64(vint8mf8_t *, vint8mf8_t *, vint8mf8_t *, vint8mf8_t *, vint8mf8_t *, const int8_t *, vuint64m1_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vloxseg5ei64_v_m)))
void vloxseg5ei64(vint8mf8_t *, vint8mf8_t *, vint8mf8_t *, vint8mf8_t *, vint8mf8_t *, vbool64_t, vint8mf8_t, vint8mf8_t, vint8mf8_t, vint8mf8_t, vint8mf8_t, const int8_t *, vuint64m1_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vloxseg5ei64_v)))
void vloxseg5ei64(vuint8m1_t *, vuint8m1_t *, vuint8m1_t *, vuint8m1_t *, vuint8m1_t *, const uint8_t *, vuint64m8_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vloxseg5ei64_v_m)))
void vloxseg5ei64(vuint8m1_t *, vuint8m1_t *, vuint8m1_t *, vuint8m1_t *, vuint8m1_t *, vbool8_t, vuint8m1_t, vuint8m1_t, vuint8m1_t, vuint8m1_t, vuint8m1_t, const uint8_t *, vuint64m8_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vloxseg5ei64_v)))
void vloxseg5ei64(vuint8mf2_t *, vuint8mf2_t *, vuint8mf2_t *, vuint8mf2_t *, vuint8mf2_t *, const uint8_t *, vuint64m4_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vloxseg5ei64_v_m)))
void vloxseg5ei64(vuint8mf2_t *, vuint8mf2_t *, vuint8mf2_t *, vuint8mf2_t *, vuint8mf2_t *, vbool16_t, vuint8mf2_t, vuint8mf2_t, vuint8mf2_t, vuint8mf2_t, vuint8mf2_t, const uint8_t *, vuint64m4_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vloxseg5ei64_v)))
void vloxseg5ei64(vuint8mf4_t *, vuint8mf4_t *, vuint8mf4_t *, vuint8mf4_t *, vuint8mf4_t *, const uint8_t *, vuint64m2_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vloxseg5ei64_v_m)))
void vloxseg5ei64(vuint8mf4_t *, vuint8mf4_t *, vuint8mf4_t *, vuint8mf4_t *, vuint8mf4_t *, vbool32_t, vuint8mf4_t, vuint8mf4_t, vuint8mf4_t, vuint8mf4_t, vuint8mf4_t, const uint8_t *, vuint64m2_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vloxseg5ei64_v)))
void vloxseg5ei64(vuint8mf8_t *, vuint8mf8_t *, vuint8mf8_t *, vuint8mf8_t *, vuint8mf8_t *, const uint8_t *, vuint64m1_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vloxseg5ei64_v_m)))
void vloxseg5ei64(vuint8mf8_t *, vuint8mf8_t *, vuint8mf8_t *, vuint8mf8_t *, vuint8mf8_t *, vbool64_t, vuint8mf8_t, vuint8mf8_t, vuint8mf8_t, vuint8mf8_t, vuint8mf8_t, const uint8_t *, vuint64m1_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vloxseg6ei64_v)))
void vloxseg6ei64(vint8m1_t *, vint8m1_t *, vint8m1_t *, vint8m1_t *, vint8m1_t *, vint8m1_t *, const int8_t *, vuint64m8_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vloxseg6ei64_v_m)))
void vloxseg6ei64(vint8m1_t *, vint8m1_t *, vint8m1_t *, vint8m1_t *, vint8m1_t *, vint8m1_t *, vbool8_t, vint8m1_t, vint8m1_t, vint8m1_t, vint8m1_t, vint8m1_t, vint8m1_t, const int8_t *, vuint64m8_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vloxseg6ei64_v)))
void vloxseg6ei64(vint8mf2_t *, vint8mf2_t *, vint8mf2_t *, vint8mf2_t *, vint8mf2_t *, vint8mf2_t *, const int8_t *, vuint64m4_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vloxseg6ei64_v_m)))
void vloxseg6ei64(vint8mf2_t *, vint8mf2_t *, vint8mf2_t *, vint8mf2_t *, vint8mf2_t *, vint8mf2_t *, vbool16_t, vint8mf2_t, vint8mf2_t, vint8mf2_t, vint8mf2_t, vint8mf2_t, vint8mf2_t, const int8_t *, vuint64m4_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vloxseg6ei64_v)))
void vloxseg6ei64(vint8mf4_t *, vint8mf4_t *, vint8mf4_t *, vint8mf4_t *, vint8mf4_t *, vint8mf4_t *, const int8_t *, vuint64m2_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vloxseg6ei64_v_m)))
void vloxseg6ei64(vint8mf4_t *, vint8mf4_t *, vint8mf4_t *, vint8mf4_t *, vint8mf4_t *, vint8mf4_t *, vbool32_t, vint8mf4_t, vint8mf4_t, vint8mf4_t, vint8mf4_t, vint8mf4_t, vint8mf4_t, const int8_t *, vuint64m2_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vloxseg6ei64_v)))
void vloxseg6ei64(vint8mf8_t *, vint8mf8_t *, vint8mf8_t *, vint8mf8_t *, vint8mf8_t *, vint8mf8_t *, const int8_t *, vuint64m1_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vloxseg6ei64_v_m)))
void vloxseg6ei64(vint8mf8_t *, vint8mf8_t *, vint8mf8_t *, vint8mf8_t *, vint8mf8_t *, vint8mf8_t *, vbool64_t, vint8mf8_t, vint8mf8_t, vint8mf8_t, vint8mf8_t, vint8mf8_t, vint8mf8_t, const int8_t *, vuint64m1_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vloxseg6ei64_v)))
void vloxseg6ei64(vuint8m1_t *, vuint8m1_t *, vuint8m1_t *, vuint8m1_t *, vuint8m1_t *, vuint8m1_t *, const uint8_t *, vuint64m8_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vloxseg6ei64_v_m)))
void vloxseg6ei64(vuint8m1_t *, vuint8m1_t *, vuint8m1_t *, vuint8m1_t *, vuint8m1_t *, vuint8m1_t *, vbool8_t, vuint8m1_t, vuint8m1_t, vuint8m1_t, vuint8m1_t, vuint8m1_t, vuint8m1_t, const uint8_t *, vuint64m8_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vloxseg6ei64_v)))
void vloxseg6ei64(vuint8mf2_t *, vuint8mf2_t *, vuint8mf2_t *, vuint8mf2_t *, vuint8mf2_t *, vuint8mf2_t *, const uint8_t *, vuint64m4_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vloxseg6ei64_v_m)))
void vloxseg6ei64(vuint8mf2_t *, vuint8mf2_t *, vuint8mf2_t *, vuint8mf2_t *, vuint8mf2_t *, vuint8mf2_t *, vbool16_t, vuint8mf2_t, vuint8mf2_t, vuint8mf2_t, vuint8mf2_t, vuint8mf2_t, vuint8mf2_t, const uint8_t *, vuint64m4_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vloxseg6ei64_v)))
void vloxseg6ei64(vuint8mf4_t *, vuint8mf4_t *, vuint8mf4_t *, vuint8mf4_t *, vuint8mf4_t *, vuint8mf4_t *, const uint8_t *, vuint64m2_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vloxseg6ei64_v_m)))
void vloxseg6ei64(vuint8mf4_t *, vuint8mf4_t *, vuint8mf4_t *, vuint8mf4_t *, vuint8mf4_t *, vuint8mf4_t *, vbool32_t, vuint8mf4_t, vuint8mf4_t, vuint8mf4_t, vuint8mf4_t, vuint8mf4_t, vuint8mf4_t, const uint8_t *, vuint64m2_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vloxseg6ei64_v)))
void vloxseg6ei64(vuint8mf8_t *, vuint8mf8_t *, vuint8mf8_t *, vuint8mf8_t *, vuint8mf8_t *, vuint8mf8_t *, const uint8_t *, vuint64m1_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vloxseg6ei64_v_m)))
void vloxseg6ei64(vuint8mf8_t *, vuint8mf8_t *, vuint8mf8_t *, vuint8mf8_t *, vuint8mf8_t *, vuint8mf8_t *, vbool64_t, vuint8mf8_t, vuint8mf8_t, vuint8mf8_t, vuint8mf8_t, vuint8mf8_t, vuint8mf8_t, const uint8_t *, vuint64m1_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vloxseg7ei64_v)))
void vloxseg7ei64(vint8m1_t *, vint8m1_t *, vint8m1_t *, vint8m1_t *, vint8m1_t *, vint8m1_t *, vint8m1_t *, const int8_t *, vuint64m8_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vloxseg7ei64_v_m)))
void vloxseg7ei64(vint8m1_t *, vint8m1_t *, vint8m1_t *, vint8m1_t *, vint8m1_t *, vint8m1_t *, vint8m1_t *, vbool8_t, vint8m1_t, vint8m1_t, vint8m1_t, vint8m1_t, vint8m1_t, vint8m1_t, vint8m1_t, const int8_t *, vuint64m8_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vloxseg7ei64_v)))
void vloxseg7ei64(vint8mf2_t *, vint8mf2_t *, vint8mf2_t *, vint8mf2_t *, vint8mf2_t *, vint8mf2_t *, vint8mf2_t *, const int8_t *, vuint64m4_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vloxseg7ei64_v_m)))
void vloxseg7ei64(vint8mf2_t *, vint8mf2_t *, vint8mf2_t *, vint8mf2_t *, vint8mf2_t *, vint8mf2_t *, vint8mf2_t *, vbool16_t, vint8mf2_t, vint8mf2_t, vint8mf2_t, vint8mf2_t, vint8mf2_t, vint8mf2_t, vint8mf2_t, const int8_t *, vuint64m4_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vloxseg7ei64_v)))
void vloxseg7ei64(vint8mf4_t *, vint8mf4_t *, vint8mf4_t *, vint8mf4_t *, vint8mf4_t *, vint8mf4_t *, vint8mf4_t *, const int8_t *, vuint64m2_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vloxseg7ei64_v_m)))
void vloxseg7ei64(vint8mf4_t *, vint8mf4_t *, vint8mf4_t *, vint8mf4_t *, vint8mf4_t *, vint8mf4_t *, vint8mf4_t *, vbool32_t, vint8mf4_t, vint8mf4_t, vint8mf4_t, vint8mf4_t, vint8mf4_t, vint8mf4_t, vint8mf4_t, const int8_t *, vuint64m2_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vloxseg7ei64_v)))
void vloxseg7ei64(vint8mf8_t *, vint8mf8_t *, vint8mf8_t *, vint8mf8_t *, vint8mf8_t *, vint8mf8_t *, vint8mf8_t *, const int8_t *, vuint64m1_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vloxseg7ei64_v_m)))
void vloxseg7ei64(vint8mf8_t *, vint8mf8_t *, vint8mf8_t *, vint8mf8_t *, vint8mf8_t *, vint8mf8_t *, vint8mf8_t *, vbool64_t, vint8mf8_t, vint8mf8_t, vint8mf8_t, vint8mf8_t, vint8mf8_t, vint8mf8_t, vint8mf8_t, const int8_t *, vuint64m1_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vloxseg7ei64_v)))
void vloxseg7ei64(vuint8m1_t *, vuint8m1_t *, vuint8m1_t *, vuint8m1_t *, vuint8m1_t *, vuint8m1_t *, vuint8m1_t *, const uint8_t *, vuint64m8_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vloxseg7ei64_v_m)))
void vloxseg7ei64(vuint8m1_t *, vuint8m1_t *, vuint8m1_t *, vuint8m1_t *, vuint8m1_t *, vuint8m1_t *, vuint8m1_t *, vbool8_t, vuint8m1_t, vuint8m1_t, vuint8m1_t, vuint8m1_t, vuint8m1_t, vuint8m1_t, vuint8m1_t, const uint8_t *, vuint64m8_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vloxseg7ei64_v)))
void vloxseg7ei64(vuint8mf2_t *, vuint8mf2_t *, vuint8mf2_t *, vuint8mf2_t *, vuint8mf2_t *, vuint8mf2_t *, vuint8mf2_t *, const uint8_t *, vuint64m4_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vloxseg7ei64_v_m)))
void vloxseg7ei64(vuint8mf2_t *, vuint8mf2_t *, vuint8mf2_t *, vuint8mf2_t *, vuint8mf2_t *, vuint8mf2_t *, vuint8mf2_t *, vbool16_t, vuint8mf2_t, vuint8mf2_t, vuint8mf2_t, vuint8mf2_t, vuint8mf2_t, vuint8mf2_t, vuint8mf2_t, const uint8_t *, vuint64m4_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vloxseg7ei64_v)))
void vloxseg7ei64(vuint8mf4_t *, vuint8mf4_t *, vuint8mf4_t *, vuint8mf4_t *, vuint8mf4_t *, vuint8mf4_t *, vuint8mf4_t *, const uint8_t *, vuint64m2_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vloxseg7ei64_v_m)))
void vloxseg7ei64(vuint8mf4_t *, vuint8mf4_t *, vuint8mf4_t *, vuint8mf4_t *, vuint8mf4_t *, vuint8mf4_t *, vuint8mf4_t *, vbool32_t, vuint8mf4_t, vuint8mf4_t, vuint8mf4_t, vuint8mf4_t, vuint8mf4_t, vuint8mf4_t, vuint8mf4_t, const uint8_t *, vuint64m2_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vloxseg7ei64_v)))
void vloxseg7ei64(vuint8mf8_t *, vuint8mf8_t *, vuint8mf8_t *, vuint8mf8_t *, vuint8mf8_t *, vuint8mf8_t *, vuint8mf8_t *, const uint8_t *, vuint64m1_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vloxseg7ei64_v_m)))
void vloxseg7ei64(vuint8mf8_t *, vuint8mf8_t *, vuint8mf8_t *, vuint8mf8_t *, vuint8mf8_t *, vuint8mf8_t *, vuint8mf8_t *, vbool64_t, vuint8mf8_t, vuint8mf8_t, vuint8mf8_t, vuint8mf8_t, vuint8mf8_t, vuint8mf8_t, vuint8mf8_t, const uint8_t *, vuint64m1_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vloxseg8ei64_v)))
void vloxseg8ei64(vint8m1_t *, vint8m1_t *, vint8m1_t *, vint8m1_t *, vint8m1_t *, vint8m1_t *, vint8m1_t *, vint8m1_t *, const int8_t *, vuint64m8_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vloxseg8ei64_v_m)))
void vloxseg8ei64(vint8m1_t *, vint8m1_t *, vint8m1_t *, vint8m1_t *, vint8m1_t *, vint8m1_t *, vint8m1_t *, vint8m1_t *, vbool8_t, vint8m1_t, vint8m1_t, vint8m1_t, vint8m1_t, vint8m1_t, vint8m1_t, vint8m1_t, vint8m1_t, const int8_t *, vuint64m8_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vloxseg8ei64_v)))
void vloxseg8ei64(vint8mf2_t *, vint8mf2_t *, vint8mf2_t *, vint8mf2_t *, vint8mf2_t *, vint8mf2_t *, vint8mf2_t *, vint8mf2_t *, const int8_t *, vuint64m4_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vloxseg8ei64_v_m)))
void vloxseg8ei64(vint8mf2_t *, vint8mf2_t *, vint8mf2_t *, vint8mf2_t *, vint8mf2_t *, vint8mf2_t *, vint8mf2_t *, vint8mf2_t *, vbool16_t, vint8mf2_t, vint8mf2_t, vint8mf2_t, vint8mf2_t, vint8mf2_t, vint8mf2_t, vint8mf2_t, vint8mf2_t, const int8_t *, vuint64m4_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vloxseg8ei64_v)))
void vloxseg8ei64(vint8mf4_t *, vint8mf4_t *, vint8mf4_t *, vint8mf4_t *, vint8mf4_t *, vint8mf4_t *, vint8mf4_t *, vint8mf4_t *, const int8_t *, vuint64m2_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vloxseg8ei64_v_m)))
void vloxseg8ei64(vint8mf4_t *, vint8mf4_t *, vint8mf4_t *, vint8mf4_t *, vint8mf4_t *, vint8mf4_t *, vint8mf4_t *, vint8mf4_t *, vbool32_t, vint8mf4_t, vint8mf4_t, vint8mf4_t, vint8mf4_t, vint8mf4_t, vint8mf4_t, vint8mf4_t, vint8mf4_t, const int8_t *, vuint64m2_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vloxseg8ei64_v)))
void vloxseg8ei64(vint8mf8_t *, vint8mf8_t *, vint8mf8_t *, vint8mf8_t *, vint8mf8_t *, vint8mf8_t *, vint8mf8_t *, vint8mf8_t *, const int8_t *, vuint64m1_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vloxseg8ei64_v_m)))
void vloxseg8ei64(vint8mf8_t *, vint8mf8_t *, vint8mf8_t *, vint8mf8_t *, vint8mf8_t *, vint8mf8_t *, vint8mf8_t *, vint8mf8_t *, vbool64_t, vint8mf8_t, vint8mf8_t, vint8mf8_t, vint8mf8_t, vint8mf8_t, vint8mf8_t, vint8mf8_t, vint8mf8_t, const int8_t *, vuint64m1_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vloxseg8ei64_v)))
void vloxseg8ei64(vuint8m1_t *, vuint8m1_t *, vuint8m1_t *, vuint8m1_t *, vuint8m1_t *, vuint8m1_t *, vuint8m1_t *, vuint8m1_t *, const uint8_t *, vuint64m8_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vloxseg8ei64_v_m)))
void vloxseg8ei64(vuint8m1_t *, vuint8m1_t *, vuint8m1_t *, vuint8m1_t *, vuint8m1_t *, vuint8m1_t *, vuint8m1_t *, vuint8m1_t *, vbool8_t, vuint8m1_t, vuint8m1_t, vuint8m1_t, vuint8m1_t, vuint8m1_t, vuint8m1_t, vuint8m1_t, vuint8m1_t, const uint8_t *, vuint64m8_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vloxseg8ei64_v)))
void vloxseg8ei64(vuint8mf2_t *, vuint8mf2_t *, vuint8mf2_t *, vuint8mf2_t *, vuint8mf2_t *, vuint8mf2_t *, vuint8mf2_t *, vuint8mf2_t *, const uint8_t *, vuint64m4_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vloxseg8ei64_v_m)))
void vloxseg8ei64(vuint8mf2_t *, vuint8mf2_t *, vuint8mf2_t *, vuint8mf2_t *, vuint8mf2_t *, vuint8mf2_t *, vuint8mf2_t *, vuint8mf2_t *, vbool16_t, vuint8mf2_t, vuint8mf2_t, vuint8mf2_t, vuint8mf2_t, vuint8mf2_t, vuint8mf2_t, vuint8mf2_t, vuint8mf2_t, const uint8_t *, vuint64m4_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vloxseg8ei64_v)))
void vloxseg8ei64(vuint8mf4_t *, vuint8mf4_t *, vuint8mf4_t *, vuint8mf4_t *, vuint8mf4_t *, vuint8mf4_t *, vuint8mf4_t *, vuint8mf4_t *, const uint8_t *, vuint64m2_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vloxseg8ei64_v_m)))
void vloxseg8ei64(vuint8mf4_t *, vuint8mf4_t *, vuint8mf4_t *, vuint8mf4_t *, vuint8mf4_t *, vuint8mf4_t *, vuint8mf4_t *, vuint8mf4_t *, vbool32_t, vuint8mf4_t, vuint8mf4_t, vuint8mf4_t, vuint8mf4_t, vuint8mf4_t, vuint8mf4_t, vuint8mf4_t, vuint8mf4_t, const uint8_t *, vuint64m2_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vloxseg8ei64_v)))
void vloxseg8ei64(vuint8mf8_t *, vuint8mf8_t *, vuint8mf8_t *, vuint8mf8_t *, vuint8mf8_t *, vuint8mf8_t *, vuint8mf8_t *, vuint8mf8_t *, const uint8_t *, vuint64m1_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vloxseg8ei64_v_m)))
void vloxseg8ei64(vuint8mf8_t *, vuint8mf8_t *, vuint8mf8_t *, vuint8mf8_t *, vuint8mf8_t *, vuint8mf8_t *, vuint8mf8_t *, vuint8mf8_t *, vbool64_t, vuint8mf8_t, vuint8mf8_t, vuint8mf8_t, vuint8mf8_t, vuint8mf8_t, vuint8mf8_t, vuint8mf8_t, vuint8mf8_t, const uint8_t *, vuint64m1_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vse64_v)))
void vse64(int64_t *, vint64m1_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vse64_v_m)))
void vse64(vbool64_t, int64_t *, vint64m1_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vse64_v)))
void vse64(int64_t *, vint64m2_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vse64_v_m)))
void vse64(vbool32_t, int64_t *, vint64m2_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vse64_v)))
void vse64(int64_t *, vint64m4_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vse64_v_m)))
void vse64(vbool16_t, int64_t *, vint64m4_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vse64_v)))
void vse64(int64_t *, vint64m8_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vse64_v_m)))
void vse64(vbool8_t, int64_t *, vint64m8_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vloxseg2ei64_v)))
void vloxseg2ei64(vint16m1_t *, vint16m1_t *, const int16_t *, vuint64m4_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vloxseg2ei64_v_m)))
void vloxseg2ei64(vint16m1_t *, vint16m1_t *, vbool16_t, vint16m1_t, vint16m1_t, const int16_t *, vuint64m4_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vloxseg2ei64_v)))
void vloxseg2ei64(vint16m2_t *, vint16m2_t *, const int16_t *, vuint64m8_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vloxseg2ei64_v_m)))
void vloxseg2ei64(vint16m2_t *, vint16m2_t *, vbool8_t, vint16m2_t, vint16m2_t, const int16_t *, vuint64m8_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vloxseg2ei64_v)))
void vloxseg2ei64(vint16mf2_t *, vint16mf2_t *, const int16_t *, vuint64m2_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vloxseg2ei64_v_m)))
void vloxseg2ei64(vint16mf2_t *, vint16mf2_t *, vbool32_t, vint16mf2_t, vint16mf2_t, const int16_t *, vuint64m2_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vloxseg2ei64_v)))
void vloxseg2ei64(vint16mf4_t *, vint16mf4_t *, const int16_t *, vuint64m1_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vloxseg2ei64_v_m)))
void vloxseg2ei64(vint16mf4_t *, vint16mf4_t *, vbool64_t, vint16mf4_t, vint16mf4_t, const int16_t *, vuint64m1_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vloxseg2ei64_v)))
void vloxseg2ei64(vuint16m1_t *, vuint16m1_t *, const uint16_t *, vuint64m4_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vloxseg2ei64_v_m)))
void vloxseg2ei64(vuint16m1_t *, vuint16m1_t *, vbool16_t, vuint16m1_t, vuint16m1_t, const uint16_t *, vuint64m4_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vloxseg2ei64_v)))
void vloxseg2ei64(vuint16m2_t *, vuint16m2_t *, const uint16_t *, vuint64m8_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vloxseg2ei64_v_m)))
void vloxseg2ei64(vuint16m2_t *, vuint16m2_t *, vbool8_t, vuint16m2_t, vuint16m2_t, const uint16_t *, vuint64m8_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vloxseg2ei64_v)))
void vloxseg2ei64(vuint16mf2_t *, vuint16mf2_t *, const uint16_t *, vuint64m2_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vloxseg2ei64_v_m)))
void vloxseg2ei64(vuint16mf2_t *, vuint16mf2_t *, vbool32_t, vuint16mf2_t, vuint16mf2_t, const uint16_t *, vuint64m2_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vloxseg2ei64_v)))
void vloxseg2ei64(vuint16mf4_t *, vuint16mf4_t *, const uint16_t *, vuint64m1_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vloxseg2ei64_v_m)))
void vloxseg2ei64(vuint16mf4_t *, vuint16mf4_t *, vbool64_t, vuint16mf4_t, vuint16mf4_t, const uint16_t *, vuint64m1_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vse64_v)))
void vse64(uint64_t *, vuint64m1_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vse64_v_m)))
void vse64(vbool64_t, uint64_t *, vuint64m1_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vse64_v)))
void vse64(uint64_t *, vuint64m2_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vse64_v_m)))
void vse64(vbool32_t, uint64_t *, vuint64m2_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vse64_v)))
void vse64(uint64_t *, vuint64m4_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vse64_v_m)))
void vse64(vbool16_t, uint64_t *, vuint64m4_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vse64_v)))
void vse64(uint64_t *, vuint64m8_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vse64_v_m)))
void vse64(vbool8_t, uint64_t *, vuint64m8_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vloxseg3ei64_v)))
void vloxseg3ei64(vint16m1_t *, vint16m1_t *, vint16m1_t *, const int16_t *, vuint64m4_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vloxseg3ei64_v_m)))
void vloxseg3ei64(vint16m1_t *, vint16m1_t *, vint16m1_t *, vbool16_t, vint16m1_t, vint16m1_t, vint16m1_t, const int16_t *, vuint64m4_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vloxseg3ei64_v)))
void vloxseg3ei64(vint16m2_t *, vint16m2_t *, vint16m2_t *, const int16_t *, vuint64m8_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vloxseg3ei64_v_m)))
void vloxseg3ei64(vint16m2_t *, vint16m2_t *, vint16m2_t *, vbool8_t, vint16m2_t, vint16m2_t, vint16m2_t, const int16_t *, vuint64m8_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vloxseg3ei64_v)))
void vloxseg3ei64(vint16mf2_t *, vint16mf2_t *, vint16mf2_t *, const int16_t *, vuint64m2_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vloxseg3ei64_v_m)))
void vloxseg3ei64(vint16mf2_t *, vint16mf2_t *, vint16mf2_t *, vbool32_t, vint16mf2_t, vint16mf2_t, vint16mf2_t, const int16_t *, vuint64m2_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vloxseg3ei64_v)))
void vloxseg3ei64(vint16mf4_t *, vint16mf4_t *, vint16mf4_t *, const int16_t *, vuint64m1_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vloxseg3ei64_v_m)))
void vloxseg3ei64(vint16mf4_t *, vint16mf4_t *, vint16mf4_t *, vbool64_t, vint16mf4_t, vint16mf4_t, vint16mf4_t, const int16_t *, vuint64m1_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vloxseg3ei64_v)))
void vloxseg3ei64(vuint16m1_t *, vuint16m1_t *, vuint16m1_t *, const uint16_t *, vuint64m4_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vloxseg3ei64_v_m)))
void vloxseg3ei64(vuint16m1_t *, vuint16m1_t *, vuint16m1_t *, vbool16_t, vuint16m1_t, vuint16m1_t, vuint16m1_t, const uint16_t *, vuint64m4_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vloxseg3ei64_v)))
void vloxseg3ei64(vuint16m2_t *, vuint16m2_t *, vuint16m2_t *, const uint16_t *, vuint64m8_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vloxseg3ei64_v_m)))
void vloxseg3ei64(vuint16m2_t *, vuint16m2_t *, vuint16m2_t *, vbool8_t, vuint16m2_t, vuint16m2_t, vuint16m2_t, const uint16_t *, vuint64m8_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vloxseg3ei64_v)))
void vloxseg3ei64(vuint16mf2_t *, vuint16mf2_t *, vuint16mf2_t *, const uint16_t *, vuint64m2_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vloxseg3ei64_v_m)))
void vloxseg3ei64(vuint16mf2_t *, vuint16mf2_t *, vuint16mf2_t *, vbool32_t, vuint16mf2_t, vuint16mf2_t, vuint16mf2_t, const uint16_t *, vuint64m2_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vloxseg3ei64_v)))
void vloxseg3ei64(vuint16mf4_t *, vuint16mf4_t *, vuint16mf4_t *, const uint16_t *, vuint64m1_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vloxseg3ei64_v_m)))
void vloxseg3ei64(vuint16mf4_t *, vuint16mf4_t *, vuint16mf4_t *, vbool64_t, vuint16mf4_t, vuint16mf4_t, vuint16mf4_t, const uint16_t *, vuint64m1_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vloxseg4ei64_v)))
void vloxseg4ei64(vint16m1_t *, vint16m1_t *, vint16m1_t *, vint16m1_t *, const int16_t *, vuint64m4_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vloxseg4ei64_v_m)))
void vloxseg4ei64(vint16m1_t *, vint16m1_t *, vint16m1_t *, vint16m1_t *, vbool16_t, vint16m1_t, vint16m1_t, vint16m1_t, vint16m1_t, const int16_t *, vuint64m4_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vloxseg4ei64_v)))
void vloxseg4ei64(vint16m2_t *, vint16m2_t *, vint16m2_t *, vint16m2_t *, const int16_t *, vuint64m8_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vloxseg4ei64_v_m)))
void vloxseg4ei64(vint16m2_t *, vint16m2_t *, vint16m2_t *, vint16m2_t *, vbool8_t, vint16m2_t, vint16m2_t, vint16m2_t, vint16m2_t, const int16_t *, vuint64m8_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vloxseg4ei64_v)))
void vloxseg4ei64(vint16mf2_t *, vint16mf2_t *, vint16mf2_t *, vint16mf2_t *, const int16_t *, vuint64m2_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vloxseg4ei64_v_m)))
void vloxseg4ei64(vint16mf2_t *, vint16mf2_t *, vint16mf2_t *, vint16mf2_t *, vbool32_t, vint16mf2_t, vint16mf2_t, vint16mf2_t, vint16mf2_t, const int16_t *, vuint64m2_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vloxseg4ei64_v)))
void vloxseg4ei64(vint16mf4_t *, vint16mf4_t *, vint16mf4_t *, vint16mf4_t *, const int16_t *, vuint64m1_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vloxseg4ei64_v_m)))
void vloxseg4ei64(vint16mf4_t *, vint16mf4_t *, vint16mf4_t *, vint16mf4_t *, vbool64_t, vint16mf4_t, vint16mf4_t, vint16mf4_t, vint16mf4_t, const int16_t *, vuint64m1_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vloxseg4ei64_v)))
void vloxseg4ei64(vuint16m1_t *, vuint16m1_t *, vuint16m1_t *, vuint16m1_t *, const uint16_t *, vuint64m4_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vloxseg4ei64_v_m)))
void vloxseg4ei64(vuint16m1_t *, vuint16m1_t *, vuint16m1_t *, vuint16m1_t *, vbool16_t, vuint16m1_t, vuint16m1_t, vuint16m1_t, vuint16m1_t, const uint16_t *, vuint64m4_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vloxseg4ei64_v)))
void vloxseg4ei64(vuint16m2_t *, vuint16m2_t *, vuint16m2_t *, vuint16m2_t *, const uint16_t *, vuint64m8_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vloxseg4ei64_v_m)))
void vloxseg4ei64(vuint16m2_t *, vuint16m2_t *, vuint16m2_t *, vuint16m2_t *, vbool8_t, vuint16m2_t, vuint16m2_t, vuint16m2_t, vuint16m2_t, const uint16_t *, vuint64m8_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vloxseg4ei64_v)))
void vloxseg4ei64(vuint16mf2_t *, vuint16mf2_t *, vuint16mf2_t *, vuint16mf2_t *, const uint16_t *, vuint64m2_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vloxseg4ei64_v_m)))
void vloxseg4ei64(vuint16mf2_t *, vuint16mf2_t *, vuint16mf2_t *, vuint16mf2_t *, vbool32_t, vuint16mf2_t, vuint16mf2_t, vuint16mf2_t, vuint16mf2_t, const uint16_t *, vuint64m2_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vloxseg4ei64_v)))
void vloxseg4ei64(vuint16mf4_t *, vuint16mf4_t *, vuint16mf4_t *, vuint16mf4_t *, const uint16_t *, vuint64m1_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vloxseg4ei64_v_m)))
void vloxseg4ei64(vuint16mf4_t *, vuint16mf4_t *, vuint16mf4_t *, vuint16mf4_t *, vbool64_t, vuint16mf4_t, vuint16mf4_t, vuint16mf4_t, vuint16mf4_t, const uint16_t *, vuint64m1_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vloxseg5ei64_v)))
void vloxseg5ei64(vint16m1_t *, vint16m1_t *, vint16m1_t *, vint16m1_t *, vint16m1_t *, const int16_t *, vuint64m4_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vloxseg5ei64_v_m)))
void vloxseg5ei64(vint16m1_t *, vint16m1_t *, vint16m1_t *, vint16m1_t *, vint16m1_t *, vbool16_t, vint16m1_t, vint16m1_t, vint16m1_t, vint16m1_t, vint16m1_t, const int16_t *, vuint64m4_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vloxseg5ei64_v)))
void vloxseg5ei64(vint16mf2_t *, vint16mf2_t *, vint16mf2_t *, vint16mf2_t *, vint16mf2_t *, const int16_t *, vuint64m2_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vloxseg5ei64_v_m)))
void vloxseg5ei64(vint16mf2_t *, vint16mf2_t *, vint16mf2_t *, vint16mf2_t *, vint16mf2_t *, vbool32_t, vint16mf2_t, vint16mf2_t, vint16mf2_t, vint16mf2_t, vint16mf2_t, const int16_t *, vuint64m2_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vloxseg5ei64_v)))
void vloxseg5ei64(vint16mf4_t *, vint16mf4_t *, vint16mf4_t *, vint16mf4_t *, vint16mf4_t *, const int16_t *, vuint64m1_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vloxseg5ei64_v_m)))
void vloxseg5ei64(vint16mf4_t *, vint16mf4_t *, vint16mf4_t *, vint16mf4_t *, vint16mf4_t *, vbool64_t, vint16mf4_t, vint16mf4_t, vint16mf4_t, vint16mf4_t, vint16mf4_t, const int16_t *, vuint64m1_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vloxseg5ei64_v)))
void vloxseg5ei64(vuint16m1_t *, vuint16m1_t *, vuint16m1_t *, vuint16m1_t *, vuint16m1_t *, const uint16_t *, vuint64m4_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vloxseg5ei64_v_m)))
void vloxseg5ei64(vuint16m1_t *, vuint16m1_t *, vuint16m1_t *, vuint16m1_t *, vuint16m1_t *, vbool16_t, vuint16m1_t, vuint16m1_t, vuint16m1_t, vuint16m1_t, vuint16m1_t, const uint16_t *, vuint64m4_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vloxseg5ei64_v)))
void vloxseg5ei64(vuint16mf2_t *, vuint16mf2_t *, vuint16mf2_t *, vuint16mf2_t *, vuint16mf2_t *, const uint16_t *, vuint64m2_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vloxseg5ei64_v_m)))
void vloxseg5ei64(vuint16mf2_t *, vuint16mf2_t *, vuint16mf2_t *, vuint16mf2_t *, vuint16mf2_t *, vbool32_t, vuint16mf2_t, vuint16mf2_t, vuint16mf2_t, vuint16mf2_t, vuint16mf2_t, const uint16_t *, vuint64m2_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vloxseg5ei64_v)))
void vloxseg5ei64(vuint16mf4_t *, vuint16mf4_t *, vuint16mf4_t *, vuint16mf4_t *, vuint16mf4_t *, const uint16_t *, vuint64m1_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vloxseg5ei64_v_m)))
void vloxseg5ei64(vuint16mf4_t *, vuint16mf4_t *, vuint16mf4_t *, vuint16mf4_t *, vuint16mf4_t *, vbool64_t, vuint16mf4_t, vuint16mf4_t, vuint16mf4_t, vuint16mf4_t, vuint16mf4_t, const uint16_t *, vuint64m1_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vloxseg6ei64_v)))
void vloxseg6ei64(vint16m1_t *, vint16m1_t *, vint16m1_t *, vint16m1_t *, vint16m1_t *, vint16m1_t *, const int16_t *, vuint64m4_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vloxseg6ei64_v_m)))
void vloxseg6ei64(vint16m1_t *, vint16m1_t *, vint16m1_t *, vint16m1_t *, vint16m1_t *, vint16m1_t *, vbool16_t, vint16m1_t, vint16m1_t, vint16m1_t, vint16m1_t, vint16m1_t, vint16m1_t, const int16_t *, vuint64m4_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vloxseg6ei64_v)))
void vloxseg6ei64(vint16mf2_t *, vint16mf2_t *, vint16mf2_t *, vint16mf2_t *, vint16mf2_t *, vint16mf2_t *, const int16_t *, vuint64m2_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vloxseg6ei64_v_m)))
void vloxseg6ei64(vint16mf2_t *, vint16mf2_t *, vint16mf2_t *, vint16mf2_t *, vint16mf2_t *, vint16mf2_t *, vbool32_t, vint16mf2_t, vint16mf2_t, vint16mf2_t, vint16mf2_t, vint16mf2_t, vint16mf2_t, const int16_t *, vuint64m2_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vloxseg6ei64_v)))
void vloxseg6ei64(vint16mf4_t *, vint16mf4_t *, vint16mf4_t *, vint16mf4_t *, vint16mf4_t *, vint16mf4_t *, const int16_t *, vuint64m1_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vloxseg6ei64_v_m)))
void vloxseg6ei64(vint16mf4_t *, vint16mf4_t *, vint16mf4_t *, vint16mf4_t *, vint16mf4_t *, vint16mf4_t *, vbool64_t, vint16mf4_t, vint16mf4_t, vint16mf4_t, vint16mf4_t, vint16mf4_t, vint16mf4_t, const int16_t *, vuint64m1_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vloxseg6ei64_v)))
void vloxseg6ei64(vuint16m1_t *, vuint16m1_t *, vuint16m1_t *, vuint16m1_t *, vuint16m1_t *, vuint16m1_t *, const uint16_t *, vuint64m4_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vloxseg6ei64_v_m)))
void vloxseg6ei64(vuint16m1_t *, vuint16m1_t *, vuint16m1_t *, vuint16m1_t *, vuint16m1_t *, vuint16m1_t *, vbool16_t, vuint16m1_t, vuint16m1_t, vuint16m1_t, vuint16m1_t, vuint16m1_t, vuint16m1_t, const uint16_t *, vuint64m4_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vloxseg6ei64_v)))
void vloxseg6ei64(vuint16mf2_t *, vuint16mf2_t *, vuint16mf2_t *, vuint16mf2_t *, vuint16mf2_t *, vuint16mf2_t *, const uint16_t *, vuint64m2_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vloxseg6ei64_v_m)))
void vloxseg6ei64(vuint16mf2_t *, vuint16mf2_t *, vuint16mf2_t *, vuint16mf2_t *, vuint16mf2_t *, vuint16mf2_t *, vbool32_t, vuint16mf2_t, vuint16mf2_t, vuint16mf2_t, vuint16mf2_t, vuint16mf2_t, vuint16mf2_t, const uint16_t *, vuint64m2_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vloxseg6ei64_v)))
void vloxseg6ei64(vuint16mf4_t *, vuint16mf4_t *, vuint16mf4_t *, vuint16mf4_t *, vuint16mf4_t *, vuint16mf4_t *, const uint16_t *, vuint64m1_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vloxseg6ei64_v_m)))
void vloxseg6ei64(vuint16mf4_t *, vuint16mf4_t *, vuint16mf4_t *, vuint16mf4_t *, vuint16mf4_t *, vuint16mf4_t *, vbool64_t, vuint16mf4_t, vuint16mf4_t, vuint16mf4_t, vuint16mf4_t, vuint16mf4_t, vuint16mf4_t, const uint16_t *, vuint64m1_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vloxseg7ei64_v)))
void vloxseg7ei64(vint16m1_t *, vint16m1_t *, vint16m1_t *, vint16m1_t *, vint16m1_t *, vint16m1_t *, vint16m1_t *, const int16_t *, vuint64m4_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vloxseg7ei64_v_m)))
void vloxseg7ei64(vint16m1_t *, vint16m1_t *, vint16m1_t *, vint16m1_t *, vint16m1_t *, vint16m1_t *, vint16m1_t *, vbool16_t, vint16m1_t, vint16m1_t, vint16m1_t, vint16m1_t, vint16m1_t, vint16m1_t, vint16m1_t, const int16_t *, vuint64m4_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vloxseg7ei64_v)))
void vloxseg7ei64(vint16mf2_t *, vint16mf2_t *, vint16mf2_t *, vint16mf2_t *, vint16mf2_t *, vint16mf2_t *, vint16mf2_t *, const int16_t *, vuint64m2_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vloxseg7ei64_v_m)))
void vloxseg7ei64(vint16mf2_t *, vint16mf2_t *, vint16mf2_t *, vint16mf2_t *, vint16mf2_t *, vint16mf2_t *, vint16mf2_t *, vbool32_t, vint16mf2_t, vint16mf2_t, vint16mf2_t, vint16mf2_t, vint16mf2_t, vint16mf2_t, vint16mf2_t, const int16_t *, vuint64m2_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vloxseg7ei64_v)))
void vloxseg7ei64(vint16mf4_t *, vint16mf4_t *, vint16mf4_t *, vint16mf4_t *, vint16mf4_t *, vint16mf4_t *, vint16mf4_t *, const int16_t *, vuint64m1_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vloxseg7ei64_v_m)))
void vloxseg7ei64(vint16mf4_t *, vint16mf4_t *, vint16mf4_t *, vint16mf4_t *, vint16mf4_t *, vint16mf4_t *, vint16mf4_t *, vbool64_t, vint16mf4_t, vint16mf4_t, vint16mf4_t, vint16mf4_t, vint16mf4_t, vint16mf4_t, vint16mf4_t, const int16_t *, vuint64m1_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vloxseg7ei64_v)))
void vloxseg7ei64(vuint16m1_t *, vuint16m1_t *, vuint16m1_t *, vuint16m1_t *, vuint16m1_t *, vuint16m1_t *, vuint16m1_t *, const uint16_t *, vuint64m4_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vloxseg7ei64_v_m)))
void vloxseg7ei64(vuint16m1_t *, vuint16m1_t *, vuint16m1_t *, vuint16m1_t *, vuint16m1_t *, vuint16m1_t *, vuint16m1_t *, vbool16_t, vuint16m1_t, vuint16m1_t, vuint16m1_t, vuint16m1_t, vuint16m1_t, vuint16m1_t, vuint16m1_t, const uint16_t *, vuint64m4_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vloxseg7ei64_v)))
void vloxseg7ei64(vuint16mf2_t *, vuint16mf2_t *, vuint16mf2_t *, vuint16mf2_t *, vuint16mf2_t *, vuint16mf2_t *, vuint16mf2_t *, const uint16_t *, vuint64m2_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vloxseg7ei64_v_m)))
void vloxseg7ei64(vuint16mf2_t *, vuint16mf2_t *, vuint16mf2_t *, vuint16mf2_t *, vuint16mf2_t *, vuint16mf2_t *, vuint16mf2_t *, vbool32_t, vuint16mf2_t, vuint16mf2_t, vuint16mf2_t, vuint16mf2_t, vuint16mf2_t, vuint16mf2_t, vuint16mf2_t, const uint16_t *, vuint64m2_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vloxseg7ei64_v)))
void vloxseg7ei64(vuint16mf4_t *, vuint16mf4_t *, vuint16mf4_t *, vuint16mf4_t *, vuint16mf4_t *, vuint16mf4_t *, vuint16mf4_t *, const uint16_t *, vuint64m1_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vloxseg7ei64_v_m)))
void vloxseg7ei64(vuint16mf4_t *, vuint16mf4_t *, vuint16mf4_t *, vuint16mf4_t *, vuint16mf4_t *, vuint16mf4_t *, vuint16mf4_t *, vbool64_t, vuint16mf4_t, vuint16mf4_t, vuint16mf4_t, vuint16mf4_t, vuint16mf4_t, vuint16mf4_t, vuint16mf4_t, const uint16_t *, vuint64m1_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vloxseg8ei64_v)))
void vloxseg8ei64(vint16m1_t *, vint16m1_t *, vint16m1_t *, vint16m1_t *, vint16m1_t *, vint16m1_t *, vint16m1_t *, vint16m1_t *, const int16_t *, vuint64m4_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vloxseg8ei64_v_m)))
void vloxseg8ei64(vint16m1_t *, vint16m1_t *, vint16m1_t *, vint16m1_t *, vint16m1_t *, vint16m1_t *, vint16m1_t *, vint16m1_t *, vbool16_t, vint16m1_t, vint16m1_t, vint16m1_t, vint16m1_t, vint16m1_t, vint16m1_t, vint16m1_t, vint16m1_t, const int16_t *, vuint64m4_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vloxseg8ei64_v)))
void vloxseg8ei64(vint16mf2_t *, vint16mf2_t *, vint16mf2_t *, vint16mf2_t *, vint16mf2_t *, vint16mf2_t *, vint16mf2_t *, vint16mf2_t *, const int16_t *, vuint64m2_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vloxseg8ei64_v_m)))
void vloxseg8ei64(vint16mf2_t *, vint16mf2_t *, vint16mf2_t *, vint16mf2_t *, vint16mf2_t *, vint16mf2_t *, vint16mf2_t *, vint16mf2_t *, vbool32_t, vint16mf2_t, vint16mf2_t, vint16mf2_t, vint16mf2_t, vint16mf2_t, vint16mf2_t, vint16mf2_t, vint16mf2_t, const int16_t *, vuint64m2_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vloxseg8ei64_v)))
void vloxseg8ei64(vint16mf4_t *, vint16mf4_t *, vint16mf4_t *, vint16mf4_t *, vint16mf4_t *, vint16mf4_t *, vint16mf4_t *, vint16mf4_t *, const int16_t *, vuint64m1_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vloxseg8ei64_v_m)))
void vloxseg8ei64(vint16mf4_t *, vint16mf4_t *, vint16mf4_t *, vint16mf4_t *, vint16mf4_t *, vint16mf4_t *, vint16mf4_t *, vint16mf4_t *, vbool64_t, vint16mf4_t, vint16mf4_t, vint16mf4_t, vint16mf4_t, vint16mf4_t, vint16mf4_t, vint16mf4_t, vint16mf4_t, const int16_t *, vuint64m1_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vloxseg8ei64_v)))
void vloxseg8ei64(vuint16m1_t *, vuint16m1_t *, vuint16m1_t *, vuint16m1_t *, vuint16m1_t *, vuint16m1_t *, vuint16m1_t *, vuint16m1_t *, const uint16_t *, vuint64m4_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vloxseg8ei64_v_m)))
void vloxseg8ei64(vuint16m1_t *, vuint16m1_t *, vuint16m1_t *, vuint16m1_t *, vuint16m1_t *, vuint16m1_t *, vuint16m1_t *, vuint16m1_t *, vbool16_t, vuint16m1_t, vuint16m1_t, vuint16m1_t, vuint16m1_t, vuint16m1_t, vuint16m1_t, vuint16m1_t, vuint16m1_t, const uint16_t *, vuint64m4_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vloxseg8ei64_v)))
void vloxseg8ei64(vuint16mf2_t *, vuint16mf2_t *, vuint16mf2_t *, vuint16mf2_t *, vuint16mf2_t *, vuint16mf2_t *, vuint16mf2_t *, vuint16mf2_t *, const uint16_t *, vuint64m2_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vloxseg8ei64_v_m)))
void vloxseg8ei64(vuint16mf2_t *, vuint16mf2_t *, vuint16mf2_t *, vuint16mf2_t *, vuint16mf2_t *, vuint16mf2_t *, vuint16mf2_t *, vuint16mf2_t *, vbool32_t, vuint16mf2_t, vuint16mf2_t, vuint16mf2_t, vuint16mf2_t, vuint16mf2_t, vuint16mf2_t, vuint16mf2_t, vuint16mf2_t, const uint16_t *, vuint64m2_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vloxseg8ei64_v)))
void vloxseg8ei64(vuint16mf4_t *, vuint16mf4_t *, vuint16mf4_t *, vuint16mf4_t *, vuint16mf4_t *, vuint16mf4_t *, vuint16mf4_t *, vuint16mf4_t *, const uint16_t *, vuint64m1_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vloxseg8ei64_v_m)))
void vloxseg8ei64(vuint16mf4_t *, vuint16mf4_t *, vuint16mf4_t *, vuint16mf4_t *, vuint16mf4_t *, vuint16mf4_t *, vuint16mf4_t *, vuint16mf4_t *, vbool64_t, vuint16mf4_t, vuint16mf4_t, vuint16mf4_t, vuint16mf4_t, vuint16mf4_t, vuint16mf4_t, vuint16mf4_t, vuint16mf4_t, const uint16_t *, vuint64m1_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vloxseg2ei64_v)))
void vloxseg2ei64(vint32m1_t *, vint32m1_t *, const int32_t *, vuint64m2_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vloxseg2ei64_v_m)))
void vloxseg2ei64(vint32m1_t *, vint32m1_t *, vbool32_t, vint32m1_t, vint32m1_t, const int32_t *, vuint64m2_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vloxseg2ei64_v)))
void vloxseg2ei64(vint32m2_t *, vint32m2_t *, const int32_t *, vuint64m4_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vloxseg2ei64_v_m)))
void vloxseg2ei64(vint32m2_t *, vint32m2_t *, vbool16_t, vint32m2_t, vint32m2_t, const int32_t *, vuint64m4_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vloxseg2ei64_v)))
void vloxseg2ei64(vint32m4_t *, vint32m4_t *, const int32_t *, vuint64m8_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vloxseg2ei64_v_m)))
void vloxseg2ei64(vint32m4_t *, vint32m4_t *, vbool8_t, vint32m4_t, vint32m4_t, const int32_t *, vuint64m8_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vloxseg2ei64_v)))
void vloxseg2ei64(vint32mf2_t *, vint32mf2_t *, const int32_t *, vuint64m1_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vloxseg2ei64_v_m)))
void vloxseg2ei64(vint32mf2_t *, vint32mf2_t *, vbool64_t, vint32mf2_t, vint32mf2_t, const int32_t *, vuint64m1_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vloxseg2ei64_v)))
void vloxseg2ei64(vuint32m1_t *, vuint32m1_t *, const uint32_t *, vuint64m2_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vloxseg2ei64_v_m)))
void vloxseg2ei64(vuint32m1_t *, vuint32m1_t *, vbool32_t, vuint32m1_t, vuint32m1_t, const uint32_t *, vuint64m2_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vloxseg2ei64_v)))
void vloxseg2ei64(vuint32m2_t *, vuint32m2_t *, const uint32_t *, vuint64m4_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vloxseg2ei64_v_m)))
void vloxseg2ei64(vuint32m2_t *, vuint32m2_t *, vbool16_t, vuint32m2_t, vuint32m2_t, const uint32_t *, vuint64m4_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vloxseg2ei64_v)))
void vloxseg2ei64(vuint32m4_t *, vuint32m4_t *, const uint32_t *, vuint64m8_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vloxseg2ei64_v_m)))
void vloxseg2ei64(vuint32m4_t *, vuint32m4_t *, vbool8_t, vuint32m4_t, vuint32m4_t, const uint32_t *, vuint64m8_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vloxseg2ei64_v)))
void vloxseg2ei64(vuint32mf2_t *, vuint32mf2_t *, const uint32_t *, vuint64m1_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vloxseg2ei64_v_m)))
void vloxseg2ei64(vuint32mf2_t *, vuint32mf2_t *, vbool64_t, vuint32mf2_t, vuint32mf2_t, const uint32_t *, vuint64m1_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vloxseg3ei64_v)))
void vloxseg3ei64(vint32m1_t *, vint32m1_t *, vint32m1_t *, const int32_t *, vuint64m2_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vloxseg3ei64_v_m)))
void vloxseg3ei64(vint32m1_t *, vint32m1_t *, vint32m1_t *, vbool32_t, vint32m1_t, vint32m1_t, vint32m1_t, const int32_t *, vuint64m2_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vloxseg3ei64_v)))
void vloxseg3ei64(vint32m2_t *, vint32m2_t *, vint32m2_t *, const int32_t *, vuint64m4_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vloxseg3ei64_v_m)))
void vloxseg3ei64(vint32m2_t *, vint32m2_t *, vint32m2_t *, vbool16_t, vint32m2_t, vint32m2_t, vint32m2_t, const int32_t *, vuint64m4_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vloxseg3ei64_v)))
void vloxseg3ei64(vint32mf2_t *, vint32mf2_t *, vint32mf2_t *, const int32_t *, vuint64m1_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vloxseg3ei64_v_m)))
void vloxseg3ei64(vint32mf2_t *, vint32mf2_t *, vint32mf2_t *, vbool64_t, vint32mf2_t, vint32mf2_t, vint32mf2_t, const int32_t *, vuint64m1_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vloxseg3ei64_v)))
void vloxseg3ei64(vuint32m1_t *, vuint32m1_t *, vuint32m1_t *, const uint32_t *, vuint64m2_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vloxseg3ei64_v_m)))
void vloxseg3ei64(vuint32m1_t *, vuint32m1_t *, vuint32m1_t *, vbool32_t, vuint32m1_t, vuint32m1_t, vuint32m1_t, const uint32_t *, vuint64m2_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vloxseg3ei64_v)))
void vloxseg3ei64(vuint32m2_t *, vuint32m2_t *, vuint32m2_t *, const uint32_t *, vuint64m4_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vloxseg3ei64_v_m)))
void vloxseg3ei64(vuint32m2_t *, vuint32m2_t *, vuint32m2_t *, vbool16_t, vuint32m2_t, vuint32m2_t, vuint32m2_t, const uint32_t *, vuint64m4_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vloxseg3ei64_v)))
void vloxseg3ei64(vuint32mf2_t *, vuint32mf2_t *, vuint32mf2_t *, const uint32_t *, vuint64m1_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vloxseg3ei64_v_m)))
void vloxseg3ei64(vuint32mf2_t *, vuint32mf2_t *, vuint32mf2_t *, vbool64_t, vuint32mf2_t, vuint32mf2_t, vuint32mf2_t, const uint32_t *, vuint64m1_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vloxseg4ei64_v)))
void vloxseg4ei64(vint32m1_t *, vint32m1_t *, vint32m1_t *, vint32m1_t *, const int32_t *, vuint64m2_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vloxseg4ei64_v_m)))
void vloxseg4ei64(vint32m1_t *, vint32m1_t *, vint32m1_t *, vint32m1_t *, vbool32_t, vint32m1_t, vint32m1_t, vint32m1_t, vint32m1_t, const int32_t *, vuint64m2_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vloxseg4ei64_v)))
void vloxseg4ei64(vint32m2_t *, vint32m2_t *, vint32m2_t *, vint32m2_t *, const int32_t *, vuint64m4_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vloxseg4ei64_v_m)))
void vloxseg4ei64(vint32m2_t *, vint32m2_t *, vint32m2_t *, vint32m2_t *, vbool16_t, vint32m2_t, vint32m2_t, vint32m2_t, vint32m2_t, const int32_t *, vuint64m4_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vloxseg4ei64_v)))
void vloxseg4ei64(vint32mf2_t *, vint32mf2_t *, vint32mf2_t *, vint32mf2_t *, const int32_t *, vuint64m1_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vloxseg4ei64_v_m)))
void vloxseg4ei64(vint32mf2_t *, vint32mf2_t *, vint32mf2_t *, vint32mf2_t *, vbool64_t, vint32mf2_t, vint32mf2_t, vint32mf2_t, vint32mf2_t, const int32_t *, vuint64m1_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vloxseg4ei64_v)))
void vloxseg4ei64(vuint32m1_t *, vuint32m1_t *, vuint32m1_t *, vuint32m1_t *, const uint32_t *, vuint64m2_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vloxseg4ei64_v_m)))
void vloxseg4ei64(vuint32m1_t *, vuint32m1_t *, vuint32m1_t *, vuint32m1_t *, vbool32_t, vuint32m1_t, vuint32m1_t, vuint32m1_t, vuint32m1_t, const uint32_t *, vuint64m2_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vloxseg4ei64_v)))
void vloxseg4ei64(vuint32m2_t *, vuint32m2_t *, vuint32m2_t *, vuint32m2_t *, const uint32_t *, vuint64m4_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vloxseg4ei64_v_m)))
void vloxseg4ei64(vuint32m2_t *, vuint32m2_t *, vuint32m2_t *, vuint32m2_t *, vbool16_t, vuint32m2_t, vuint32m2_t, vuint32m2_t, vuint32m2_t, const uint32_t *, vuint64m4_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vloxseg4ei64_v)))
void vloxseg4ei64(vuint32mf2_t *, vuint32mf2_t *, vuint32mf2_t *, vuint32mf2_t *, const uint32_t *, vuint64m1_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vloxseg4ei64_v_m)))
void vloxseg4ei64(vuint32mf2_t *, vuint32mf2_t *, vuint32mf2_t *, vuint32mf2_t *, vbool64_t, vuint32mf2_t, vuint32mf2_t, vuint32mf2_t, vuint32mf2_t, const uint32_t *, vuint64m1_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vloxseg5ei64_v)))
void vloxseg5ei64(vint32m1_t *, vint32m1_t *, vint32m1_t *, vint32m1_t *, vint32m1_t *, const int32_t *, vuint64m2_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vloxseg5ei64_v_m)))
void vloxseg5ei64(vint32m1_t *, vint32m1_t *, vint32m1_t *, vint32m1_t *, vint32m1_t *, vbool32_t, vint32m1_t, vint32m1_t, vint32m1_t, vint32m1_t, vint32m1_t, const int32_t *, vuint64m2_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vloxseg5ei64_v)))
void vloxseg5ei64(vint32mf2_t *, vint32mf2_t *, vint32mf2_t *, vint32mf2_t *, vint32mf2_t *, const int32_t *, vuint64m1_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vloxseg5ei64_v_m)))
void vloxseg5ei64(vint32mf2_t *, vint32mf2_t *, vint32mf2_t *, vint32mf2_t *, vint32mf2_t *, vbool64_t, vint32mf2_t, vint32mf2_t, vint32mf2_t, vint32mf2_t, vint32mf2_t, const int32_t *, vuint64m1_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vloxseg5ei64_v)))
void vloxseg5ei64(vuint32m1_t *, vuint32m1_t *, vuint32m1_t *, vuint32m1_t *, vuint32m1_t *, const uint32_t *, vuint64m2_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vloxseg5ei64_v_m)))
void vloxseg5ei64(vuint32m1_t *, vuint32m1_t *, vuint32m1_t *, vuint32m1_t *, vuint32m1_t *, vbool32_t, vuint32m1_t, vuint32m1_t, vuint32m1_t, vuint32m1_t, vuint32m1_t, const uint32_t *, vuint64m2_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vloxseg5ei64_v)))
void vloxseg5ei64(vuint32mf2_t *, vuint32mf2_t *, vuint32mf2_t *, vuint32mf2_t *, vuint32mf2_t *, const uint32_t *, vuint64m1_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vloxseg5ei64_v_m)))
void vloxseg5ei64(vuint32mf2_t *, vuint32mf2_t *, vuint32mf2_t *, vuint32mf2_t *, vuint32mf2_t *, vbool64_t, vuint32mf2_t, vuint32mf2_t, vuint32mf2_t, vuint32mf2_t, vuint32mf2_t, const uint32_t *, vuint64m1_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vloxseg6ei64_v)))
void vloxseg6ei64(vint32m1_t *, vint32m1_t *, vint32m1_t *, vint32m1_t *, vint32m1_t *, vint32m1_t *, const int32_t *, vuint64m2_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vloxseg6ei64_v_m)))
void vloxseg6ei64(vint32m1_t *, vint32m1_t *, vint32m1_t *, vint32m1_t *, vint32m1_t *, vint32m1_t *, vbool32_t, vint32m1_t, vint32m1_t, vint32m1_t, vint32m1_t, vint32m1_t, vint32m1_t, const int32_t *, vuint64m2_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vloxseg6ei64_v)))
void vloxseg6ei64(vint32mf2_t *, vint32mf2_t *, vint32mf2_t *, vint32mf2_t *, vint32mf2_t *, vint32mf2_t *, const int32_t *, vuint64m1_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vloxseg6ei64_v_m)))
void vloxseg6ei64(vint32mf2_t *, vint32mf2_t *, vint32mf2_t *, vint32mf2_t *, vint32mf2_t *, vint32mf2_t *, vbool64_t, vint32mf2_t, vint32mf2_t, vint32mf2_t, vint32mf2_t, vint32mf2_t, vint32mf2_t, const int32_t *, vuint64m1_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vloxseg6ei64_v)))
void vloxseg6ei64(vuint32m1_t *, vuint32m1_t *, vuint32m1_t *, vuint32m1_t *, vuint32m1_t *, vuint32m1_t *, const uint32_t *, vuint64m2_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vloxseg6ei64_v_m)))
void vloxseg6ei64(vuint32m1_t *, vuint32m1_t *, vuint32m1_t *, vuint32m1_t *, vuint32m1_t *, vuint32m1_t *, vbool32_t, vuint32m1_t, vuint32m1_t, vuint32m1_t, vuint32m1_t, vuint32m1_t, vuint32m1_t, const uint32_t *, vuint64m2_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vloxseg6ei64_v)))
void vloxseg6ei64(vuint32mf2_t *, vuint32mf2_t *, vuint32mf2_t *, vuint32mf2_t *, vuint32mf2_t *, vuint32mf2_t *, const uint32_t *, vuint64m1_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vloxseg6ei64_v_m)))
void vloxseg6ei64(vuint32mf2_t *, vuint32mf2_t *, vuint32mf2_t *, vuint32mf2_t *, vuint32mf2_t *, vuint32mf2_t *, vbool64_t, vuint32mf2_t, vuint32mf2_t, vuint32mf2_t, vuint32mf2_t, vuint32mf2_t, vuint32mf2_t, const uint32_t *, vuint64m1_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vloxseg7ei64_v)))
void vloxseg7ei64(vint32m1_t *, vint32m1_t *, vint32m1_t *, vint32m1_t *, vint32m1_t *, vint32m1_t *, vint32m1_t *, const int32_t *, vuint64m2_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vloxseg7ei64_v_m)))
void vloxseg7ei64(vint32m1_t *, vint32m1_t *, vint32m1_t *, vint32m1_t *, vint32m1_t *, vint32m1_t *, vint32m1_t *, vbool32_t, vint32m1_t, vint32m1_t, vint32m1_t, vint32m1_t, vint32m1_t, vint32m1_t, vint32m1_t, const int32_t *, vuint64m2_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vloxseg7ei64_v)))
void vloxseg7ei64(vint32mf2_t *, vint32mf2_t *, vint32mf2_t *, vint32mf2_t *, vint32mf2_t *, vint32mf2_t *, vint32mf2_t *, const int32_t *, vuint64m1_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vloxseg7ei64_v_m)))
void vloxseg7ei64(vint32mf2_t *, vint32mf2_t *, vint32mf2_t *, vint32mf2_t *, vint32mf2_t *, vint32mf2_t *, vint32mf2_t *, vbool64_t, vint32mf2_t, vint32mf2_t, vint32mf2_t, vint32mf2_t, vint32mf2_t, vint32mf2_t, vint32mf2_t, const int32_t *, vuint64m1_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vloxseg7ei64_v)))
void vloxseg7ei64(vuint32m1_t *, vuint32m1_t *, vuint32m1_t *, vuint32m1_t *, vuint32m1_t *, vuint32m1_t *, vuint32m1_t *, const uint32_t *, vuint64m2_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vloxseg7ei64_v_m)))
void vloxseg7ei64(vuint32m1_t *, vuint32m1_t *, vuint32m1_t *, vuint32m1_t *, vuint32m1_t *, vuint32m1_t *, vuint32m1_t *, vbool32_t, vuint32m1_t, vuint32m1_t, vuint32m1_t, vuint32m1_t, vuint32m1_t, vuint32m1_t, vuint32m1_t, const uint32_t *, vuint64m2_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vloxseg7ei64_v)))
void vloxseg7ei64(vuint32mf2_t *, vuint32mf2_t *, vuint32mf2_t *, vuint32mf2_t *, vuint32mf2_t *, vuint32mf2_t *, vuint32mf2_t *, const uint32_t *, vuint64m1_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vloxseg7ei64_v_m)))
void vloxseg7ei64(vuint32mf2_t *, vuint32mf2_t *, vuint32mf2_t *, vuint32mf2_t *, vuint32mf2_t *, vuint32mf2_t *, vuint32mf2_t *, vbool64_t, vuint32mf2_t, vuint32mf2_t, vuint32mf2_t, vuint32mf2_t, vuint32mf2_t, vuint32mf2_t, vuint32mf2_t, const uint32_t *, vuint64m1_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vloxseg8ei64_v)))
void vloxseg8ei64(vint32m1_t *, vint32m1_t *, vint32m1_t *, vint32m1_t *, vint32m1_t *, vint32m1_t *, vint32m1_t *, vint32m1_t *, const int32_t *, vuint64m2_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vloxseg8ei64_v_m)))
void vloxseg8ei64(vint32m1_t *, vint32m1_t *, vint32m1_t *, vint32m1_t *, vint32m1_t *, vint32m1_t *, vint32m1_t *, vint32m1_t *, vbool32_t, vint32m1_t, vint32m1_t, vint32m1_t, vint32m1_t, vint32m1_t, vint32m1_t, vint32m1_t, vint32m1_t, const int32_t *, vuint64m2_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vloxseg8ei64_v)))
void vloxseg8ei64(vint32mf2_t *, vint32mf2_t *, vint32mf2_t *, vint32mf2_t *, vint32mf2_t *, vint32mf2_t *, vint32mf2_t *, vint32mf2_t *, const int32_t *, vuint64m1_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vloxseg8ei64_v_m)))
void vloxseg8ei64(vint32mf2_t *, vint32mf2_t *, vint32mf2_t *, vint32mf2_t *, vint32mf2_t *, vint32mf2_t *, vint32mf2_t *, vint32mf2_t *, vbool64_t, vint32mf2_t, vint32mf2_t, vint32mf2_t, vint32mf2_t, vint32mf2_t, vint32mf2_t, vint32mf2_t, vint32mf2_t, const int32_t *, vuint64m1_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vloxseg8ei64_v)))
void vloxseg8ei64(vuint32m1_t *, vuint32m1_t *, vuint32m1_t *, vuint32m1_t *, vuint32m1_t *, vuint32m1_t *, vuint32m1_t *, vuint32m1_t *, const uint32_t *, vuint64m2_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vloxseg8ei64_v_m)))
void vloxseg8ei64(vuint32m1_t *, vuint32m1_t *, vuint32m1_t *, vuint32m1_t *, vuint32m1_t *, vuint32m1_t *, vuint32m1_t *, vuint32m1_t *, vbool32_t, vuint32m1_t, vuint32m1_t, vuint32m1_t, vuint32m1_t, vuint32m1_t, vuint32m1_t, vuint32m1_t, vuint32m1_t, const uint32_t *, vuint64m2_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vloxseg8ei64_v)))
void vloxseg8ei64(vuint32mf2_t *, vuint32mf2_t *, vuint32mf2_t *, vuint32mf2_t *, vuint32mf2_t *, vuint32mf2_t *, vuint32mf2_t *, vuint32mf2_t *, const uint32_t *, vuint64m1_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vloxseg8ei64_v_m)))
void vloxseg8ei64(vuint32mf2_t *, vuint32mf2_t *, vuint32mf2_t *, vuint32mf2_t *, vuint32mf2_t *, vuint32mf2_t *, vuint32mf2_t *, vuint32mf2_t *, vbool64_t, vuint32mf2_t, vuint32mf2_t, vuint32mf2_t, vuint32mf2_t, vuint32mf2_t, vuint32mf2_t, vuint32mf2_t, vuint32mf2_t, const uint32_t *, vuint64m1_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vloxseg2ei8_v)))
void vloxseg2ei8(vint64m1_t *, vint64m1_t *, const int64_t *, vuint8mf8_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vloxseg2ei8_v_m)))
void vloxseg2ei8(vint64m1_t *, vint64m1_t *, vbool64_t, vint64m1_t, vint64m1_t, const int64_t *, vuint8mf8_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vloxseg2ei8_v)))
void vloxseg2ei8(vint64m2_t *, vint64m2_t *, const int64_t *, vuint8mf4_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vloxseg2ei8_v_m)))
void vloxseg2ei8(vint64m2_t *, vint64m2_t *, vbool32_t, vint64m2_t, vint64m2_t, const int64_t *, vuint8mf4_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vloxseg2ei8_v)))
void vloxseg2ei8(vint64m4_t *, vint64m4_t *, const int64_t *, vuint8mf2_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vloxseg2ei8_v_m)))
void vloxseg2ei8(vint64m4_t *, vint64m4_t *, vbool16_t, vint64m4_t, vint64m4_t, const int64_t *, vuint8mf2_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vloxseg2ei8_v)))
void vloxseg2ei8(vuint64m1_t *, vuint64m1_t *, const uint64_t *, vuint8mf8_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vloxseg2ei8_v_m)))
void vloxseg2ei8(vuint64m1_t *, vuint64m1_t *, vbool64_t, vuint64m1_t, vuint64m1_t, const uint64_t *, vuint8mf8_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vloxseg2ei8_v)))
void vloxseg2ei8(vuint64m2_t *, vuint64m2_t *, const uint64_t *, vuint8mf4_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vloxseg2ei8_v_m)))
void vloxseg2ei8(vuint64m2_t *, vuint64m2_t *, vbool32_t, vuint64m2_t, vuint64m2_t, const uint64_t *, vuint8mf4_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vloxseg2ei8_v)))
void vloxseg2ei8(vuint64m4_t *, vuint64m4_t *, const uint64_t *, vuint8mf2_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vloxseg2ei8_v_m)))
void vloxseg2ei8(vuint64m4_t *, vuint64m4_t *, vbool16_t, vuint64m4_t, vuint64m4_t, const uint64_t *, vuint8mf2_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vlmul_ext_v)))
vint64m2_t vlmul_ext_i64m2(vint64m1_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vlmul_ext_v)))
vint64m4_t vlmul_ext_i64m4(vint64m1_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vlmul_ext_v)))
vint64m4_t vlmul_ext_i64m4(vint64m2_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vlmul_ext_v)))
vint64m8_t vlmul_ext_i64m8(vint64m1_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vlmul_ext_v)))
vint64m8_t vlmul_ext_i64m8(vint64m2_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vlmul_ext_v)))
vint64m8_t vlmul_ext_i64m8(vint64m4_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vlmul_ext_v)))
vuint64m2_t vlmul_ext_u64m2(vuint64m1_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vlmul_ext_v)))
vuint64m4_t vlmul_ext_u64m4(vuint64m1_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vlmul_ext_v)))
vuint64m4_t vlmul_ext_u64m4(vuint64m2_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vlmul_ext_v)))
vuint64m8_t vlmul_ext_u64m8(vuint64m1_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vlmul_ext_v)))
vuint64m8_t vlmul_ext_u64m8(vuint64m2_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vlmul_ext_v)))
vuint64m8_t vlmul_ext_u64m8(vuint64m4_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vlmul_trunc_v)))
vint64m1_t vlmul_trunc_i64m1(vint64m2_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vlmul_trunc_v)))
vint64m1_t vlmul_trunc_i64m1(vint64m4_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vlmul_trunc_v)))
vint64m1_t vlmul_trunc_i64m1(vint64m8_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vlmul_trunc_v)))
vint64m2_t vlmul_trunc_i64m2(vint64m4_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vlmul_trunc_v)))
vint64m2_t vlmul_trunc_i64m2(vint64m8_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vlmul_trunc_v)))
vint64m4_t vlmul_trunc_i64m4(vint64m8_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vlmul_trunc_v)))
vuint64m1_t vlmul_trunc_u64m1(vuint64m2_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vlmul_trunc_v)))
vuint64m1_t vlmul_trunc_u64m1(vuint64m4_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vlmul_trunc_v)))
vuint64m1_t vlmul_trunc_u64m1(vuint64m8_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vlmul_trunc_v)))
vuint64m2_t vlmul_trunc_u64m2(vuint64m4_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vlmul_trunc_v)))
vuint64m2_t vlmul_trunc_u64m2(vuint64m8_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vlmul_trunc_v)))
vuint64m4_t vlmul_trunc_u64m4(vuint64m8_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vreinterpret_v)))
vint16m1_t vreinterpret_i16m1(vint64m1_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vreinterpret_v)))
vint16m2_t vreinterpret_i16m2(vint64m2_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vreinterpret_v)))
vint16m4_t vreinterpret_i16m4(vint64m4_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vreinterpret_v)))
vint16m8_t vreinterpret_i16m8(vint64m8_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vreinterpret_v)))
vint32m1_t vreinterpret_i32m1(vint64m1_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vreinterpret_v)))
vint32m2_t vreinterpret_i32m2(vint64m2_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vreinterpret_v)))
vint32m4_t vreinterpret_i32m4(vint64m4_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vreinterpret_v)))
vint32m8_t vreinterpret_i32m8(vint64m8_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vreinterpret_v)))
vint64m1_t vreinterpret_i64m1(vint8m1_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vreinterpret_v)))
vint64m2_t vreinterpret_i64m2(vint8m2_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vreinterpret_v)))
vint64m4_t vreinterpret_i64m4(vint8m4_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vreinterpret_v)))
vint64m8_t vreinterpret_i64m8(vint8m8_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vreinterpret_v)))
vint64m1_t vreinterpret_i64m1(vint16m1_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vreinterpret_v)))
vint64m2_t vreinterpret_i64m2(vint16m2_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vreinterpret_v)))
vint64m4_t vreinterpret_i64m4(vint16m4_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vreinterpret_v)))
vint64m8_t vreinterpret_i64m8(vint16m8_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vreinterpret_v)))
vint64m1_t vreinterpret_i64m1(vint32m1_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vreinterpret_v)))
vint64m2_t vreinterpret_i64m2(vint32m2_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vreinterpret_v)))
vint64m4_t vreinterpret_i64m4(vint32m4_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vreinterpret_v)))
vint64m8_t vreinterpret_i64m8(vint32m8_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vreinterpret_v)))
vint8m1_t vreinterpret_i8m1(vint64m1_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vreinterpret_v)))
vint8m2_t vreinterpret_i8m2(vint64m2_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vreinterpret_v)))
vint8m4_t vreinterpret_i8m4(vint64m4_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vreinterpret_v)))
vint8m8_t vreinterpret_i8m8(vint64m8_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vreinterpret_v)))
vint64m1_t vreinterpret_i64m1(vuint64m1_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vreinterpret_v)))
vint64m2_t vreinterpret_i64m2(vuint64m2_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vreinterpret_v)))
vint64m4_t vreinterpret_i64m4(vuint64m4_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vreinterpret_v)))
vint64m8_t vreinterpret_i64m8(vuint64m8_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vreinterpret_v)))
vuint16m1_t vreinterpret_u16m1(vuint64m1_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vreinterpret_v)))
vuint16m2_t vreinterpret_u16m2(vuint64m2_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vreinterpret_v)))
vuint16m4_t vreinterpret_u16m4(vuint64m4_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vreinterpret_v)))
vuint16m8_t vreinterpret_u16m8(vuint64m8_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vreinterpret_v)))
vuint32m1_t vreinterpret_u32m1(vuint64m1_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vreinterpret_v)))
vuint32m2_t vreinterpret_u32m2(vuint64m2_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vreinterpret_v)))
vuint32m4_t vreinterpret_u32m4(vuint64m4_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vreinterpret_v)))
vuint32m8_t vreinterpret_u32m8(vuint64m8_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vreinterpret_v)))
vuint64m1_t vreinterpret_u64m1(vuint8m1_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vreinterpret_v)))
vuint64m2_t vreinterpret_u64m2(vuint8m2_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vreinterpret_v)))
vuint64m4_t vreinterpret_u64m4(vuint8m4_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vreinterpret_v)))
vuint64m8_t vreinterpret_u64m8(vuint8m8_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vreinterpret_v)))
vuint64m1_t vreinterpret_u64m1(vuint16m1_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vreinterpret_v)))
vuint64m2_t vreinterpret_u64m2(vuint16m2_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vreinterpret_v)))
vuint64m4_t vreinterpret_u64m4(vuint16m4_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vreinterpret_v)))
vuint64m8_t vreinterpret_u64m8(vuint16m8_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vreinterpret_v)))
vuint64m1_t vreinterpret_u64m1(vuint32m1_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vreinterpret_v)))
vuint64m2_t vreinterpret_u64m2(vuint32m2_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vreinterpret_v)))
vuint64m4_t vreinterpret_u64m4(vuint32m4_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vreinterpret_v)))
vuint64m8_t vreinterpret_u64m8(vuint32m8_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vreinterpret_v)))
vuint8m1_t vreinterpret_u8m1(vuint64m1_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vreinterpret_v)))
vuint8m2_t vreinterpret_u8m2(vuint64m2_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vreinterpret_v)))
vuint8m4_t vreinterpret_u8m4(vuint64m4_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vreinterpret_v)))
vuint8m8_t vreinterpret_u8m8(vuint64m8_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vreinterpret_v)))
vuint64m1_t vreinterpret_u64m1(vint64m1_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vreinterpret_v)))
vuint64m2_t vreinterpret_u64m2(vint64m2_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vreinterpret_v)))
vuint64m4_t vreinterpret_u64m4(vint64m4_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vreinterpret_v)))
vuint64m8_t vreinterpret_u64m8(vint64m8_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vsext_vf2)))
vint64m1_t vsext_vf2(vint32mf2_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vsext_vf2_m)))
vint64m1_t vsext_vf2(vbool64_t, vint64m1_t, vint32mf2_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vsext_vf2)))
vint64m2_t vsext_vf2(vint32m1_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vsext_vf2_m)))
vint64m2_t vsext_vf2(vbool32_t, vint64m2_t, vint32m1_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vsext_vf2)))
vint64m4_t vsext_vf2(vint32m2_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vsext_vf2_m)))
vint64m4_t vsext_vf2(vbool16_t, vint64m4_t, vint32m2_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vsext_vf2)))
vint64m8_t vsext_vf2(vint32m4_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vsext_vf2_m)))
vint64m8_t vsext_vf2(vbool8_t, vint64m8_t, vint32m4_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vsext_vf4)))
vint64m1_t vsext_vf4(vint16mf4_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vsext_vf4_m)))
vint64m1_t vsext_vf4(vbool64_t, vint64m1_t, vint16mf4_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vsext_vf4)))
vint64m2_t vsext_vf4(vint16mf2_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vsext_vf4_m)))
vint64m2_t vsext_vf4(vbool32_t, vint64m2_t, vint16mf2_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vsext_vf4)))
vint64m4_t vsext_vf4(vint16m1_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vsext_vf4_m)))
vint64m4_t vsext_vf4(vbool16_t, vint64m4_t, vint16m1_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vsext_vf4)))
vint64m8_t vsext_vf4(vint16m2_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vsext_vf4_m)))
vint64m8_t vsext_vf4(vbool8_t, vint64m8_t, vint16m2_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vsext_vf8)))
vint64m1_t vsext_vf8(vint8mf8_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vsext_vf8_m)))
vint64m1_t vsext_vf8(vbool64_t, vint64m1_t, vint8mf8_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vsext_vf8)))
vint64m2_t vsext_vf8(vint8mf4_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vsext_vf8_m)))
vint64m2_t vsext_vf8(vbool32_t, vint64m2_t, vint8mf4_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vsext_vf8)))
vint64m4_t vsext_vf8(vint8mf2_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vsext_vf8_m)))
vint64m4_t vsext_vf8(vbool16_t, vint64m4_t, vint8mf2_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vsext_vf8)))
vint64m8_t vsext_vf8(vint8m1_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vsext_vf8_m)))
vint64m8_t vsext_vf8(vbool8_t, vint64m8_t, vint8m1_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vzext_vf2)))
vuint64m1_t vzext_vf2(vuint32mf2_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vzext_vf2_m)))
vuint64m1_t vzext_vf2(vbool64_t, vuint64m1_t, vuint32mf2_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vzext_vf2)))
vuint64m2_t vzext_vf2(vuint32m1_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vzext_vf2_m)))
vuint64m2_t vzext_vf2(vbool32_t, vuint64m2_t, vuint32m1_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vzext_vf2)))
vuint64m4_t vzext_vf2(vuint32m2_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vzext_vf2_m)))
vuint64m4_t vzext_vf2(vbool16_t, vuint64m4_t, vuint32m2_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vzext_vf2)))
vuint64m8_t vzext_vf2(vuint32m4_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vzext_vf2_m)))
vuint64m8_t vzext_vf2(vbool8_t, vuint64m8_t, vuint32m4_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vzext_vf4)))
vuint64m1_t vzext_vf4(vuint16mf4_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vzext_vf4_m)))
vuint64m1_t vzext_vf4(vbool64_t, vuint64m1_t, vuint16mf4_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vzext_vf4)))
vuint64m2_t vzext_vf4(vuint16mf2_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vzext_vf4_m)))
vuint64m2_t vzext_vf4(vbool32_t, vuint64m2_t, vuint16mf2_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vzext_vf4)))
vuint64m4_t vzext_vf4(vuint16m1_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vzext_vf4_m)))
vuint64m4_t vzext_vf4(vbool16_t, vuint64m4_t, vuint16m1_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vzext_vf4)))
vuint64m8_t vzext_vf4(vuint16m2_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vzext_vf4_m)))
vuint64m8_t vzext_vf4(vbool8_t, vuint64m8_t, vuint16m2_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vzext_vf8)))
vuint64m1_t vzext_vf8(vuint8mf8_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vzext_vf8_m)))
vuint64m1_t vzext_vf8(vbool64_t, vuint64m1_t, vuint8mf8_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vzext_vf8)))
vuint64m2_t vzext_vf8(vuint8mf4_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vzext_vf8_m)))
vuint64m2_t vzext_vf8(vbool32_t, vuint64m2_t, vuint8mf4_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vzext_vf8)))
vuint64m4_t vzext_vf8(vuint8mf2_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vzext_vf8_m)))
vuint64m4_t vzext_vf8(vbool16_t, vuint64m4_t, vuint8mf2_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vzext_vf8)))
vuint64m8_t vzext_vf8(vuint8m1_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vzext_vf8_m)))
vuint64m8_t vzext_vf8(vbool8_t, vuint64m8_t, vuint8m1_t, size_t);
#endif

#if defined(__riscv_v) && (__riscv_v_elen >= 64)
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vmulh_vv)))
vint64m1_t vmulh(vint64m1_t, vint64m1_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vmulh_vv_m)))
vint64m1_t vmulh(vbool64_t, vint64m1_t, vint64m1_t, vint64m1_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vmulh_vv)))
vint64m2_t vmulh(vint64m2_t, vint64m2_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vmulh_vv_m)))
vint64m2_t vmulh(vbool32_t, vint64m2_t, vint64m2_t, vint64m2_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vmulh_vv)))
vint64m4_t vmulh(vint64m4_t, vint64m4_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vmulh_vv_m)))
vint64m4_t vmulh(vbool16_t, vint64m4_t, vint64m4_t, vint64m4_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vmulh_vv)))
vint64m8_t vmulh(vint64m8_t, vint64m8_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vmulh_vv_m)))
vint64m8_t vmulh(vbool8_t, vint64m8_t, vint64m8_t, vint64m8_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vmulh_vx)))
vint64m1_t vmulh(vint64m1_t, int64_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vmulh_vx_m)))
vint64m1_t vmulh(vbool64_t, vint64m1_t, vint64m1_t, int64_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vmulh_vx)))
vint64m2_t vmulh(vint64m2_t, int64_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vmulh_vx_m)))
vint64m2_t vmulh(vbool32_t, vint64m2_t, vint64m2_t, int64_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vmulh_vx)))
vint64m4_t vmulh(vint64m4_t, int64_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vmulh_vx_m)))
vint64m4_t vmulh(vbool16_t, vint64m4_t, vint64m4_t, int64_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vmulh_vx)))
vint64m8_t vmulh(vint64m8_t, int64_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vmulh_vx_m)))
vint64m8_t vmulh(vbool8_t, vint64m8_t, vint64m8_t, int64_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vmulhu_vv)))
vuint64m1_t vmulhu(vuint64m1_t, vuint64m1_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vmulhu_vv_m)))
vuint64m1_t vmulhu(vbool64_t, vuint64m1_t, vuint64m1_t, vuint64m1_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vmulhu_vv)))
vuint64m2_t vmulhu(vuint64m2_t, vuint64m2_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vmulhu_vv_m)))
vuint64m2_t vmulhu(vbool32_t, vuint64m2_t, vuint64m2_t, vuint64m2_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vmulhu_vv)))
vuint64m4_t vmulhu(vuint64m4_t, vuint64m4_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vmulhu_vv_m)))
vuint64m4_t vmulhu(vbool16_t, vuint64m4_t, vuint64m4_t, vuint64m4_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vmulhu_vv)))
vuint64m8_t vmulhu(vuint64m8_t, vuint64m8_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vmulhu_vv_m)))
vuint64m8_t vmulhu(vbool8_t, vuint64m8_t, vuint64m8_t, vuint64m8_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vmulhu_vx)))
vuint64m1_t vmulhu(vuint64m1_t, uint64_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vmulhu_vx_m)))
vuint64m1_t vmulhu(vbool64_t, vuint64m1_t, vuint64m1_t, uint64_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vmulhu_vx)))
vuint64m2_t vmulhu(vuint64m2_t, uint64_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vmulhu_vx_m)))
vuint64m2_t vmulhu(vbool32_t, vuint64m2_t, vuint64m2_t, uint64_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vmulhu_vx)))
vuint64m4_t vmulhu(vuint64m4_t, uint64_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vmulhu_vx_m)))
vuint64m4_t vmulhu(vbool16_t, vuint64m4_t, vuint64m4_t, uint64_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vmulhu_vx)))
vuint64m8_t vmulhu(vuint64m8_t, uint64_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vmulhu_vx_m)))
vuint64m8_t vmulhu(vbool8_t, vuint64m8_t, vuint64m8_t, uint64_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vmulhsu_vv)))
vint64m1_t vmulhsu(vint64m1_t, vuint64m1_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vmulhsu_vv_m)))
vint64m1_t vmulhsu(vbool64_t, vint64m1_t, vint64m1_t, vuint64m1_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vmulhsu_vv)))
vint64m2_t vmulhsu(vint64m2_t, vuint64m2_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vmulhsu_vv_m)))
vint64m2_t vmulhsu(vbool32_t, vint64m2_t, vint64m2_t, vuint64m2_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vmulhsu_vv)))
vint64m4_t vmulhsu(vint64m4_t, vuint64m4_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vmulhsu_vv_m)))
vint64m4_t vmulhsu(vbool16_t, vint64m4_t, vint64m4_t, vuint64m4_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vmulhsu_vv)))
vint64m8_t vmulhsu(vint64m8_t, vuint64m8_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vmulhsu_vv_m)))
vint64m8_t vmulhsu(vbool8_t, vint64m8_t, vint64m8_t, vuint64m8_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vmulhsu_vx)))
vint64m1_t vmulhsu(vint64m1_t, uint64_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vmulhsu_vx_m)))
vint64m1_t vmulhsu(vbool64_t, vint64m1_t, vint64m1_t, uint64_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vmulhsu_vx)))
vint64m2_t vmulhsu(vint64m2_t, uint64_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vmulhsu_vx_m)))
vint64m2_t vmulhsu(vbool32_t, vint64m2_t, vint64m2_t, uint64_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vmulhsu_vx)))
vint64m4_t vmulhsu(vint64m4_t, uint64_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vmulhsu_vx_m)))
vint64m4_t vmulhsu(vbool16_t, vint64m4_t, vint64m4_t, uint64_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vmulhsu_vx)))
vint64m8_t vmulhsu(vint64m8_t, uint64_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vmulhsu_vx_m)))
vint64m8_t vmulhsu(vbool8_t, vint64m8_t, vint64m8_t, uint64_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vsmul_vv)))
vint64m1_t vsmul(vint64m1_t, vint64m1_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vsmul_vv_m)))
vint64m1_t vsmul(vbool64_t, vint64m1_t, vint64m1_t, vint64m1_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vsmul_vv)))
vint64m2_t vsmul(vint64m2_t, vint64m2_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vsmul_vv_m)))
vint64m2_t vsmul(vbool32_t, vint64m2_t, vint64m2_t, vint64m2_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vsmul_vv)))
vint64m4_t vsmul(vint64m4_t, vint64m4_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vsmul_vv_m)))
vint64m4_t vsmul(vbool16_t, vint64m4_t, vint64m4_t, vint64m4_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vsmul_vv)))
vint64m8_t vsmul(vint64m8_t, vint64m8_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vsmul_vv_m)))
vint64m8_t vsmul(vbool8_t, vint64m8_t, vint64m8_t, vint64m8_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vsmul_vx)))
vint64m1_t vsmul(vint64m1_t, int64_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vsmul_vx_m)))
vint64m1_t vsmul(vbool64_t, vint64m1_t, vint64m1_t, int64_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vsmul_vx)))
vint64m2_t vsmul(vint64m2_t, int64_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vsmul_vx_m)))
vint64m2_t vsmul(vbool32_t, vint64m2_t, vint64m2_t, int64_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vsmul_vx)))
vint64m4_t vsmul(vint64m4_t, int64_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vsmul_vx_m)))
vint64m4_t vsmul(vbool16_t, vint64m4_t, vint64m4_t, int64_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vsmul_vx)))
vint64m8_t vsmul(vint64m8_t, int64_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vsmul_vx_m)))
vint64m8_t vsmul(vbool8_t, vint64m8_t, vint64m8_t, int64_t, size_t);
#endif

#if defined(__riscv_zfh) && (__riscv_v_elen >= 64)
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vloxseg2ei64_v)))
void vloxseg2ei64(vfloat16m1_t *, vfloat16m1_t *, const _Float16 *, vuint64m4_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vloxseg2ei64_v_m)))
void vloxseg2ei64(vfloat16m1_t *, vfloat16m1_t *, vbool16_t, vfloat16m1_t, vfloat16m1_t, const _Float16 *, vuint64m4_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vloxseg2ei64_v)))
void vloxseg2ei64(vfloat16m2_t *, vfloat16m2_t *, const _Float16 *, vuint64m8_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vloxseg2ei64_v_m)))
void vloxseg2ei64(vfloat16m2_t *, vfloat16m2_t *, vbool8_t, vfloat16m2_t, vfloat16m2_t, const _Float16 *, vuint64m8_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vloxseg2ei64_v)))
void vloxseg2ei64(vfloat16mf2_t *, vfloat16mf2_t *, const _Float16 *, vuint64m2_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vloxseg2ei64_v_m)))
void vloxseg2ei64(vfloat16mf2_t *, vfloat16mf2_t *, vbool32_t, vfloat16mf2_t, vfloat16mf2_t, const _Float16 *, vuint64m2_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vloxseg2ei64_v)))
void vloxseg2ei64(vfloat16mf4_t *, vfloat16mf4_t *, const _Float16 *, vuint64m1_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vloxseg2ei64_v_m)))
void vloxseg2ei64(vfloat16mf4_t *, vfloat16mf4_t *, vbool64_t, vfloat16mf4_t, vfloat16mf4_t, const _Float16 *, vuint64m1_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vloxseg3ei64_v)))
void vloxseg3ei64(vfloat16m1_t *, vfloat16m1_t *, vfloat16m1_t *, const _Float16 *, vuint64m4_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vloxseg3ei64_v_m)))
void vloxseg3ei64(vfloat16m1_t *, vfloat16m1_t *, vfloat16m1_t *, vbool16_t, vfloat16m1_t, vfloat16m1_t, vfloat16m1_t, const _Float16 *, vuint64m4_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vloxseg3ei64_v)))
void vloxseg3ei64(vfloat16m2_t *, vfloat16m2_t *, vfloat16m2_t *, const _Float16 *, vuint64m8_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vloxseg3ei64_v_m)))
void vloxseg3ei64(vfloat16m2_t *, vfloat16m2_t *, vfloat16m2_t *, vbool8_t, vfloat16m2_t, vfloat16m2_t, vfloat16m2_t, const _Float16 *, vuint64m8_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vloxseg3ei64_v)))
void vloxseg3ei64(vfloat16mf2_t *, vfloat16mf2_t *, vfloat16mf2_t *, const _Float16 *, vuint64m2_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vloxseg3ei64_v_m)))
void vloxseg3ei64(vfloat16mf2_t *, vfloat16mf2_t *, vfloat16mf2_t *, vbool32_t, vfloat16mf2_t, vfloat16mf2_t, vfloat16mf2_t, const _Float16 *, vuint64m2_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vloxseg3ei64_v)))
void vloxseg3ei64(vfloat16mf4_t *, vfloat16mf4_t *, vfloat16mf4_t *, const _Float16 *, vuint64m1_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vloxseg3ei64_v_m)))
void vloxseg3ei64(vfloat16mf4_t *, vfloat16mf4_t *, vfloat16mf4_t *, vbool64_t, vfloat16mf4_t, vfloat16mf4_t, vfloat16mf4_t, const _Float16 *, vuint64m1_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vloxseg4ei64_v)))
void vloxseg4ei64(vfloat16m1_t *, vfloat16m1_t *, vfloat16m1_t *, vfloat16m1_t *, const _Float16 *, vuint64m4_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vloxseg4ei64_v_m)))
void vloxseg4ei64(vfloat16m1_t *, vfloat16m1_t *, vfloat16m1_t *, vfloat16m1_t *, vbool16_t, vfloat16m1_t, vfloat16m1_t, vfloat16m1_t, vfloat16m1_t, const _Float16 *, vuint64m4_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vloxseg4ei64_v)))
void vloxseg4ei64(vfloat16m2_t *, vfloat16m2_t *, vfloat16m2_t *, vfloat16m2_t *, const _Float16 *, vuint64m8_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vloxseg4ei64_v_m)))
void vloxseg4ei64(vfloat16m2_t *, vfloat16m2_t *, vfloat16m2_t *, vfloat16m2_t *, vbool8_t, vfloat16m2_t, vfloat16m2_t, vfloat16m2_t, vfloat16m2_t, const _Float16 *, vuint64m8_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vloxseg4ei64_v)))
void vloxseg4ei64(vfloat16mf2_t *, vfloat16mf2_t *, vfloat16mf2_t *, vfloat16mf2_t *, const _Float16 *, vuint64m2_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vloxseg4ei64_v_m)))
void vloxseg4ei64(vfloat16mf2_t *, vfloat16mf2_t *, vfloat16mf2_t *, vfloat16mf2_t *, vbool32_t, vfloat16mf2_t, vfloat16mf2_t, vfloat16mf2_t, vfloat16mf2_t, const _Float16 *, vuint64m2_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vloxseg4ei64_v)))
void vloxseg4ei64(vfloat16mf4_t *, vfloat16mf4_t *, vfloat16mf4_t *, vfloat16mf4_t *, const _Float16 *, vuint64m1_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vloxseg4ei64_v_m)))
void vloxseg4ei64(vfloat16mf4_t *, vfloat16mf4_t *, vfloat16mf4_t *, vfloat16mf4_t *, vbool64_t, vfloat16mf4_t, vfloat16mf4_t, vfloat16mf4_t, vfloat16mf4_t, const _Float16 *, vuint64m1_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vloxseg5ei64_v)))
void vloxseg5ei64(vfloat16m1_t *, vfloat16m1_t *, vfloat16m1_t *, vfloat16m1_t *, vfloat16m1_t *, const _Float16 *, vuint64m4_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vloxseg5ei64_v_m)))
void vloxseg5ei64(vfloat16m1_t *, vfloat16m1_t *, vfloat16m1_t *, vfloat16m1_t *, vfloat16m1_t *, vbool16_t, vfloat16m1_t, vfloat16m1_t, vfloat16m1_t, vfloat16m1_t, vfloat16m1_t, const _Float16 *, vuint64m4_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vloxseg5ei64_v)))
void vloxseg5ei64(vfloat16mf2_t *, vfloat16mf2_t *, vfloat16mf2_t *, vfloat16mf2_t *, vfloat16mf2_t *, const _Float16 *, vuint64m2_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vloxseg5ei64_v_m)))
void vloxseg5ei64(vfloat16mf2_t *, vfloat16mf2_t *, vfloat16mf2_t *, vfloat16mf2_t *, vfloat16mf2_t *, vbool32_t, vfloat16mf2_t, vfloat16mf2_t, vfloat16mf2_t, vfloat16mf2_t, vfloat16mf2_t, const _Float16 *, vuint64m2_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vloxseg5ei64_v)))
void vloxseg5ei64(vfloat16mf4_t *, vfloat16mf4_t *, vfloat16mf4_t *, vfloat16mf4_t *, vfloat16mf4_t *, const _Float16 *, vuint64m1_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vloxseg5ei64_v_m)))
void vloxseg5ei64(vfloat16mf4_t *, vfloat16mf4_t *, vfloat16mf4_t *, vfloat16mf4_t *, vfloat16mf4_t *, vbool64_t, vfloat16mf4_t, vfloat16mf4_t, vfloat16mf4_t, vfloat16mf4_t, vfloat16mf4_t, const _Float16 *, vuint64m1_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vloxseg6ei64_v)))
void vloxseg6ei64(vfloat16m1_t *, vfloat16m1_t *, vfloat16m1_t *, vfloat16m1_t *, vfloat16m1_t *, vfloat16m1_t *, const _Float16 *, vuint64m4_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vloxseg6ei64_v_m)))
void vloxseg6ei64(vfloat16m1_t *, vfloat16m1_t *, vfloat16m1_t *, vfloat16m1_t *, vfloat16m1_t *, vfloat16m1_t *, vbool16_t, vfloat16m1_t, vfloat16m1_t, vfloat16m1_t, vfloat16m1_t, vfloat16m1_t, vfloat16m1_t, const _Float16 *, vuint64m4_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vloxseg6ei64_v)))
void vloxseg6ei64(vfloat16mf2_t *, vfloat16mf2_t *, vfloat16mf2_t *, vfloat16mf2_t *, vfloat16mf2_t *, vfloat16mf2_t *, const _Float16 *, vuint64m2_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vloxseg6ei64_v_m)))
void vloxseg6ei64(vfloat16mf2_t *, vfloat16mf2_t *, vfloat16mf2_t *, vfloat16mf2_t *, vfloat16mf2_t *, vfloat16mf2_t *, vbool32_t, vfloat16mf2_t, vfloat16mf2_t, vfloat16mf2_t, vfloat16mf2_t, vfloat16mf2_t, vfloat16mf2_t, const _Float16 *, vuint64m2_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vloxseg6ei64_v)))
void vloxseg6ei64(vfloat16mf4_t *, vfloat16mf4_t *, vfloat16mf4_t *, vfloat16mf4_t *, vfloat16mf4_t *, vfloat16mf4_t *, const _Float16 *, vuint64m1_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vloxseg6ei64_v_m)))
void vloxseg6ei64(vfloat16mf4_t *, vfloat16mf4_t *, vfloat16mf4_t *, vfloat16mf4_t *, vfloat16mf4_t *, vfloat16mf4_t *, vbool64_t, vfloat16mf4_t, vfloat16mf4_t, vfloat16mf4_t, vfloat16mf4_t, vfloat16mf4_t, vfloat16mf4_t, const _Float16 *, vuint64m1_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vloxseg7ei64_v)))
void vloxseg7ei64(vfloat16m1_t *, vfloat16m1_t *, vfloat16m1_t *, vfloat16m1_t *, vfloat16m1_t *, vfloat16m1_t *, vfloat16m1_t *, const _Float16 *, vuint64m4_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vloxseg7ei64_v_m)))
void vloxseg7ei64(vfloat16m1_t *, vfloat16m1_t *, vfloat16m1_t *, vfloat16m1_t *, vfloat16m1_t *, vfloat16m1_t *, vfloat16m1_t *, vbool16_t, vfloat16m1_t, vfloat16m1_t, vfloat16m1_t, vfloat16m1_t, vfloat16m1_t, vfloat16m1_t, vfloat16m1_t, const _Float16 *, vuint64m4_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vloxseg7ei64_v)))
void vloxseg7ei64(vfloat16mf2_t *, vfloat16mf2_t *, vfloat16mf2_t *, vfloat16mf2_t *, vfloat16mf2_t *, vfloat16mf2_t *, vfloat16mf2_t *, const _Float16 *, vuint64m2_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vloxseg7ei64_v_m)))
void vloxseg7ei64(vfloat16mf2_t *, vfloat16mf2_t *, vfloat16mf2_t *, vfloat16mf2_t *, vfloat16mf2_t *, vfloat16mf2_t *, vfloat16mf2_t *, vbool32_t, vfloat16mf2_t, vfloat16mf2_t, vfloat16mf2_t, vfloat16mf2_t, vfloat16mf2_t, vfloat16mf2_t, vfloat16mf2_t, const _Float16 *, vuint64m2_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vloxseg7ei64_v)))
void vloxseg7ei64(vfloat16mf4_t *, vfloat16mf4_t *, vfloat16mf4_t *, vfloat16mf4_t *, vfloat16mf4_t *, vfloat16mf4_t *, vfloat16mf4_t *, const _Float16 *, vuint64m1_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vloxseg7ei64_v_m)))
void vloxseg7ei64(vfloat16mf4_t *, vfloat16mf4_t *, vfloat16mf4_t *, vfloat16mf4_t *, vfloat16mf4_t *, vfloat16mf4_t *, vfloat16mf4_t *, vbool64_t, vfloat16mf4_t, vfloat16mf4_t, vfloat16mf4_t, vfloat16mf4_t, vfloat16mf4_t, vfloat16mf4_t, vfloat16mf4_t, const _Float16 *, vuint64m1_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vloxseg8ei64_v)))
void vloxseg8ei64(vfloat16m1_t *, vfloat16m1_t *, vfloat16m1_t *, vfloat16m1_t *, vfloat16m1_t *, vfloat16m1_t *, vfloat16m1_t *, vfloat16m1_t *, const _Float16 *, vuint64m4_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vloxseg8ei64_v_m)))
void vloxseg8ei64(vfloat16m1_t *, vfloat16m1_t *, vfloat16m1_t *, vfloat16m1_t *, vfloat16m1_t *, vfloat16m1_t *, vfloat16m1_t *, vfloat16m1_t *, vbool16_t, vfloat16m1_t, vfloat16m1_t, vfloat16m1_t, vfloat16m1_t, vfloat16m1_t, vfloat16m1_t, vfloat16m1_t, vfloat16m1_t, const _Float16 *, vuint64m4_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vloxseg8ei64_v)))
void vloxseg8ei64(vfloat16mf2_t *, vfloat16mf2_t *, vfloat16mf2_t *, vfloat16mf2_t *, vfloat16mf2_t *, vfloat16mf2_t *, vfloat16mf2_t *, vfloat16mf2_t *, const _Float16 *, vuint64m2_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vloxseg8ei64_v_m)))
void vloxseg8ei64(vfloat16mf2_t *, vfloat16mf2_t *, vfloat16mf2_t *, vfloat16mf2_t *, vfloat16mf2_t *, vfloat16mf2_t *, vfloat16mf2_t *, vfloat16mf2_t *, vbool32_t, vfloat16mf2_t, vfloat16mf2_t, vfloat16mf2_t, vfloat16mf2_t, vfloat16mf2_t, vfloat16mf2_t, vfloat16mf2_t, vfloat16mf2_t, const _Float16 *, vuint64m2_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vloxseg8ei64_v)))
void vloxseg8ei64(vfloat16mf4_t *, vfloat16mf4_t *, vfloat16mf4_t *, vfloat16mf4_t *, vfloat16mf4_t *, vfloat16mf4_t *, vfloat16mf4_t *, vfloat16mf4_t *, const _Float16 *, vuint64m1_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vloxseg8ei64_v_m)))
void vloxseg8ei64(vfloat16mf4_t *, vfloat16mf4_t *, vfloat16mf4_t *, vfloat16mf4_t *, vfloat16mf4_t *, vfloat16mf4_t *, vfloat16mf4_t *, vfloat16mf4_t *, vbool64_t, vfloat16mf4_t, vfloat16mf4_t, vfloat16mf4_t, vfloat16mf4_t, vfloat16mf4_t, vfloat16mf4_t, vfloat16mf4_t, vfloat16mf4_t, const _Float16 *, vuint64m1_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vsuxseg2ei64_v)))
void vsuxseg2ei64(_Float16 *, vuint64m4_t, vfloat16m1_t, vfloat16m1_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vsuxseg2ei64_v_m)))
void vsuxseg2ei64(vbool16_t, _Float16 *, vuint64m4_t, vfloat16m1_t, vfloat16m1_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vsuxseg2ei64_v)))
void vsuxseg2ei64(_Float16 *, vuint64m8_t, vfloat16m2_t, vfloat16m2_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vsuxseg2ei64_v_m)))
void vsuxseg2ei64(vbool8_t, _Float16 *, vuint64m8_t, vfloat16m2_t, vfloat16m2_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vsuxseg2ei64_v)))
void vsuxseg2ei64(_Float16 *, vuint64m2_t, vfloat16mf2_t, vfloat16mf2_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vsuxseg2ei64_v_m)))
void vsuxseg2ei64(vbool32_t, _Float16 *, vuint64m2_t, vfloat16mf2_t, vfloat16mf2_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vsuxseg2ei64_v)))
void vsuxseg2ei64(_Float16 *, vuint64m1_t, vfloat16mf4_t, vfloat16mf4_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vsuxseg2ei64_v_m)))
void vsuxseg2ei64(vbool64_t, _Float16 *, vuint64m1_t, vfloat16mf4_t, vfloat16mf4_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vsuxseg3ei64_v)))
void vsuxseg3ei64(_Float16 *, vuint64m4_t, vfloat16m1_t, vfloat16m1_t, vfloat16m1_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vsuxseg3ei64_v_m)))
void vsuxseg3ei64(vbool16_t, _Float16 *, vuint64m4_t, vfloat16m1_t, vfloat16m1_t, vfloat16m1_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vsuxseg3ei64_v)))
void vsuxseg3ei64(_Float16 *, vuint64m8_t, vfloat16m2_t, vfloat16m2_t, vfloat16m2_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vsuxseg3ei64_v_m)))
void vsuxseg3ei64(vbool8_t, _Float16 *, vuint64m8_t, vfloat16m2_t, vfloat16m2_t, vfloat16m2_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vsuxseg3ei64_v)))
void vsuxseg3ei64(_Float16 *, vuint64m2_t, vfloat16mf2_t, vfloat16mf2_t, vfloat16mf2_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vsuxseg3ei64_v_m)))
void vsuxseg3ei64(vbool32_t, _Float16 *, vuint64m2_t, vfloat16mf2_t, vfloat16mf2_t, vfloat16mf2_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vsuxseg3ei64_v)))
void vsuxseg3ei64(_Float16 *, vuint64m1_t, vfloat16mf4_t, vfloat16mf4_t, vfloat16mf4_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vsuxseg3ei64_v_m)))
void vsuxseg3ei64(vbool64_t, _Float16 *, vuint64m1_t, vfloat16mf4_t, vfloat16mf4_t, vfloat16mf4_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vsuxseg4ei64_v)))
void vsuxseg4ei64(_Float16 *, vuint64m4_t, vfloat16m1_t, vfloat16m1_t, vfloat16m1_t, vfloat16m1_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vsuxseg4ei64_v_m)))
void vsuxseg4ei64(vbool16_t, _Float16 *, vuint64m4_t, vfloat16m1_t, vfloat16m1_t, vfloat16m1_t, vfloat16m1_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vsuxseg4ei64_v)))
void vsuxseg4ei64(_Float16 *, vuint64m8_t, vfloat16m2_t, vfloat16m2_t, vfloat16m2_t, vfloat16m2_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vsuxseg4ei64_v_m)))
void vsuxseg4ei64(vbool8_t, _Float16 *, vuint64m8_t, vfloat16m2_t, vfloat16m2_t, vfloat16m2_t, vfloat16m2_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vsuxseg4ei64_v)))
void vsuxseg4ei64(_Float16 *, vuint64m2_t, vfloat16mf2_t, vfloat16mf2_t, vfloat16mf2_t, vfloat16mf2_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vsuxseg4ei64_v_m)))
void vsuxseg4ei64(vbool32_t, _Float16 *, vuint64m2_t, vfloat16mf2_t, vfloat16mf2_t, vfloat16mf2_t, vfloat16mf2_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vsuxseg4ei64_v)))
void vsuxseg4ei64(_Float16 *, vuint64m1_t, vfloat16mf4_t, vfloat16mf4_t, vfloat16mf4_t, vfloat16mf4_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vsuxseg4ei64_v_m)))
void vsuxseg4ei64(vbool64_t, _Float16 *, vuint64m1_t, vfloat16mf4_t, vfloat16mf4_t, vfloat16mf4_t, vfloat16mf4_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vsuxseg5ei64_v)))
void vsuxseg5ei64(_Float16 *, vuint64m4_t, vfloat16m1_t, vfloat16m1_t, vfloat16m1_t, vfloat16m1_t, vfloat16m1_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vsuxseg5ei64_v_m)))
void vsuxseg5ei64(vbool16_t, _Float16 *, vuint64m4_t, vfloat16m1_t, vfloat16m1_t, vfloat16m1_t, vfloat16m1_t, vfloat16m1_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vsuxseg5ei64_v)))
void vsuxseg5ei64(_Float16 *, vuint64m2_t, vfloat16mf2_t, vfloat16mf2_t, vfloat16mf2_t, vfloat16mf2_t, vfloat16mf2_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vsuxseg5ei64_v_m)))
void vsuxseg5ei64(vbool32_t, _Float16 *, vuint64m2_t, vfloat16mf2_t, vfloat16mf2_t, vfloat16mf2_t, vfloat16mf2_t, vfloat16mf2_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vsuxseg5ei64_v)))
void vsuxseg5ei64(_Float16 *, vuint64m1_t, vfloat16mf4_t, vfloat16mf4_t, vfloat16mf4_t, vfloat16mf4_t, vfloat16mf4_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vsuxseg5ei64_v_m)))
void vsuxseg5ei64(vbool64_t, _Float16 *, vuint64m1_t, vfloat16mf4_t, vfloat16mf4_t, vfloat16mf4_t, vfloat16mf4_t, vfloat16mf4_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vsuxseg6ei64_v)))
void vsuxseg6ei64(_Float16 *, vuint64m4_t, vfloat16m1_t, vfloat16m1_t, vfloat16m1_t, vfloat16m1_t, vfloat16m1_t, vfloat16m1_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vsuxseg6ei64_v_m)))
void vsuxseg6ei64(vbool16_t, _Float16 *, vuint64m4_t, vfloat16m1_t, vfloat16m1_t, vfloat16m1_t, vfloat16m1_t, vfloat16m1_t, vfloat16m1_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vsuxseg6ei64_v)))
void vsuxseg6ei64(_Float16 *, vuint64m2_t, vfloat16mf2_t, vfloat16mf2_t, vfloat16mf2_t, vfloat16mf2_t, vfloat16mf2_t, vfloat16mf2_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vsuxseg6ei64_v_m)))
void vsuxseg6ei64(vbool32_t, _Float16 *, vuint64m2_t, vfloat16mf2_t, vfloat16mf2_t, vfloat16mf2_t, vfloat16mf2_t, vfloat16mf2_t, vfloat16mf2_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vsuxseg6ei64_v)))
void vsuxseg6ei64(_Float16 *, vuint64m1_t, vfloat16mf4_t, vfloat16mf4_t, vfloat16mf4_t, vfloat16mf4_t, vfloat16mf4_t, vfloat16mf4_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vsuxseg6ei64_v_m)))
void vsuxseg6ei64(vbool64_t, _Float16 *, vuint64m1_t, vfloat16mf4_t, vfloat16mf4_t, vfloat16mf4_t, vfloat16mf4_t, vfloat16mf4_t, vfloat16mf4_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vsuxseg7ei64_v)))
void vsuxseg7ei64(_Float16 *, vuint64m4_t, vfloat16m1_t, vfloat16m1_t, vfloat16m1_t, vfloat16m1_t, vfloat16m1_t, vfloat16m1_t, vfloat16m1_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vsuxseg7ei64_v_m)))
void vsuxseg7ei64(vbool16_t, _Float16 *, vuint64m4_t, vfloat16m1_t, vfloat16m1_t, vfloat16m1_t, vfloat16m1_t, vfloat16m1_t, vfloat16m1_t, vfloat16m1_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vsuxseg7ei64_v)))
void vsuxseg7ei64(_Float16 *, vuint64m2_t, vfloat16mf2_t, vfloat16mf2_t, vfloat16mf2_t, vfloat16mf2_t, vfloat16mf2_t, vfloat16mf2_t, vfloat16mf2_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vsuxseg7ei64_v_m)))
void vsuxseg7ei64(vbool32_t, _Float16 *, vuint64m2_t, vfloat16mf2_t, vfloat16mf2_t, vfloat16mf2_t, vfloat16mf2_t, vfloat16mf2_t, vfloat16mf2_t, vfloat16mf2_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vsuxseg7ei64_v)))
void vsuxseg7ei64(_Float16 *, vuint64m1_t, vfloat16mf4_t, vfloat16mf4_t, vfloat16mf4_t, vfloat16mf4_t, vfloat16mf4_t, vfloat16mf4_t, vfloat16mf4_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vsuxseg7ei64_v_m)))
void vsuxseg7ei64(vbool64_t, _Float16 *, vuint64m1_t, vfloat16mf4_t, vfloat16mf4_t, vfloat16mf4_t, vfloat16mf4_t, vfloat16mf4_t, vfloat16mf4_t, vfloat16mf4_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vsuxseg8ei64_v)))
void vsuxseg8ei64(_Float16 *, vuint64m4_t, vfloat16m1_t, vfloat16m1_t, vfloat16m1_t, vfloat16m1_t, vfloat16m1_t, vfloat16m1_t, vfloat16m1_t, vfloat16m1_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vsuxseg8ei64_v_m)))
void vsuxseg8ei64(vbool16_t, _Float16 *, vuint64m4_t, vfloat16m1_t, vfloat16m1_t, vfloat16m1_t, vfloat16m1_t, vfloat16m1_t, vfloat16m1_t, vfloat16m1_t, vfloat16m1_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vsuxseg8ei64_v)))
void vsuxseg8ei64(_Float16 *, vuint64m2_t, vfloat16mf2_t, vfloat16mf2_t, vfloat16mf2_t, vfloat16mf2_t, vfloat16mf2_t, vfloat16mf2_t, vfloat16mf2_t, vfloat16mf2_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vsuxseg8ei64_v_m)))
void vsuxseg8ei64(vbool32_t, _Float16 *, vuint64m2_t, vfloat16mf2_t, vfloat16mf2_t, vfloat16mf2_t, vfloat16mf2_t, vfloat16mf2_t, vfloat16mf2_t, vfloat16mf2_t, vfloat16mf2_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vsuxseg8ei64_v)))
void vsuxseg8ei64(_Float16 *, vuint64m1_t, vfloat16mf4_t, vfloat16mf4_t, vfloat16mf4_t, vfloat16mf4_t, vfloat16mf4_t, vfloat16mf4_t, vfloat16mf4_t, vfloat16mf4_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vsuxseg8ei64_v_m)))
void vsuxseg8ei64(vbool64_t, _Float16 *, vuint64m1_t, vfloat16mf4_t, vfloat16mf4_t, vfloat16mf4_t, vfloat16mf4_t, vfloat16mf4_t, vfloat16mf4_t, vfloat16mf4_t, vfloat16mf4_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vsoxseg2ei64_v)))
void vsoxseg2ei64(_Float16 *, vuint64m4_t, vfloat16m1_t, vfloat16m1_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vsoxseg2ei64_v_m)))
void vsoxseg2ei64(vbool16_t, _Float16 *, vuint64m4_t, vfloat16m1_t, vfloat16m1_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vsoxseg2ei64_v)))
void vsoxseg2ei64(_Float16 *, vuint64m8_t, vfloat16m2_t, vfloat16m2_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vsoxseg2ei64_v_m)))
void vsoxseg2ei64(vbool8_t, _Float16 *, vuint64m8_t, vfloat16m2_t, vfloat16m2_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vsoxseg2ei64_v)))
void vsoxseg2ei64(_Float16 *, vuint64m2_t, vfloat16mf2_t, vfloat16mf2_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vsoxseg2ei64_v_m)))
void vsoxseg2ei64(vbool32_t, _Float16 *, vuint64m2_t, vfloat16mf2_t, vfloat16mf2_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vsoxseg2ei64_v)))
void vsoxseg2ei64(_Float16 *, vuint64m1_t, vfloat16mf4_t, vfloat16mf4_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vsoxseg2ei64_v_m)))
void vsoxseg2ei64(vbool64_t, _Float16 *, vuint64m1_t, vfloat16mf4_t, vfloat16mf4_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vsoxseg3ei64_v)))
void vsoxseg3ei64(_Float16 *, vuint64m4_t, vfloat16m1_t, vfloat16m1_t, vfloat16m1_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vsoxseg3ei64_v_m)))
void vsoxseg3ei64(vbool16_t, _Float16 *, vuint64m4_t, vfloat16m1_t, vfloat16m1_t, vfloat16m1_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vsoxseg3ei64_v)))
void vsoxseg3ei64(_Float16 *, vuint64m8_t, vfloat16m2_t, vfloat16m2_t, vfloat16m2_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vsoxseg3ei64_v_m)))
void vsoxseg3ei64(vbool8_t, _Float16 *, vuint64m8_t, vfloat16m2_t, vfloat16m2_t, vfloat16m2_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vsoxseg3ei64_v)))
void vsoxseg3ei64(_Float16 *, vuint64m2_t, vfloat16mf2_t, vfloat16mf2_t, vfloat16mf2_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vsoxseg3ei64_v_m)))
void vsoxseg3ei64(vbool32_t, _Float16 *, vuint64m2_t, vfloat16mf2_t, vfloat16mf2_t, vfloat16mf2_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vsoxseg3ei64_v)))
void vsoxseg3ei64(_Float16 *, vuint64m1_t, vfloat16mf4_t, vfloat16mf4_t, vfloat16mf4_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vsoxseg3ei64_v_m)))
void vsoxseg3ei64(vbool64_t, _Float16 *, vuint64m1_t, vfloat16mf4_t, vfloat16mf4_t, vfloat16mf4_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vsoxseg4ei64_v)))
void vsoxseg4ei64(_Float16 *, vuint64m4_t, vfloat16m1_t, vfloat16m1_t, vfloat16m1_t, vfloat16m1_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vsoxseg4ei64_v_m)))
void vsoxseg4ei64(vbool16_t, _Float16 *, vuint64m4_t, vfloat16m1_t, vfloat16m1_t, vfloat16m1_t, vfloat16m1_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vsoxseg4ei64_v)))
void vsoxseg4ei64(_Float16 *, vuint64m8_t, vfloat16m2_t, vfloat16m2_t, vfloat16m2_t, vfloat16m2_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vsoxseg4ei64_v_m)))
void vsoxseg4ei64(vbool8_t, _Float16 *, vuint64m8_t, vfloat16m2_t, vfloat16m2_t, vfloat16m2_t, vfloat16m2_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vsoxseg4ei64_v)))
void vsoxseg4ei64(_Float16 *, vuint64m2_t, vfloat16mf2_t, vfloat16mf2_t, vfloat16mf2_t, vfloat16mf2_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vsoxseg4ei64_v_m)))
void vsoxseg4ei64(vbool32_t, _Float16 *, vuint64m2_t, vfloat16mf2_t, vfloat16mf2_t, vfloat16mf2_t, vfloat16mf2_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vsoxseg4ei64_v)))
void vsoxseg4ei64(_Float16 *, vuint64m1_t, vfloat16mf4_t, vfloat16mf4_t, vfloat16mf4_t, vfloat16mf4_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vsoxseg4ei64_v_m)))
void vsoxseg4ei64(vbool64_t, _Float16 *, vuint64m1_t, vfloat16mf4_t, vfloat16mf4_t, vfloat16mf4_t, vfloat16mf4_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vsoxseg5ei64_v)))
void vsoxseg5ei64(_Float16 *, vuint64m4_t, vfloat16m1_t, vfloat16m1_t, vfloat16m1_t, vfloat16m1_t, vfloat16m1_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vsoxseg5ei64_v_m)))
void vsoxseg5ei64(vbool16_t, _Float16 *, vuint64m4_t, vfloat16m1_t, vfloat16m1_t, vfloat16m1_t, vfloat16m1_t, vfloat16m1_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vsoxseg5ei64_v)))
void vsoxseg5ei64(_Float16 *, vuint64m2_t, vfloat16mf2_t, vfloat16mf2_t, vfloat16mf2_t, vfloat16mf2_t, vfloat16mf2_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vsoxseg5ei64_v_m)))
void vsoxseg5ei64(vbool32_t, _Float16 *, vuint64m2_t, vfloat16mf2_t, vfloat16mf2_t, vfloat16mf2_t, vfloat16mf2_t, vfloat16mf2_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vsoxseg5ei64_v)))
void vsoxseg5ei64(_Float16 *, vuint64m1_t, vfloat16mf4_t, vfloat16mf4_t, vfloat16mf4_t, vfloat16mf4_t, vfloat16mf4_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vsoxseg5ei64_v_m)))
void vsoxseg5ei64(vbool64_t, _Float16 *, vuint64m1_t, vfloat16mf4_t, vfloat16mf4_t, vfloat16mf4_t, vfloat16mf4_t, vfloat16mf4_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vsoxseg6ei64_v)))
void vsoxseg6ei64(_Float16 *, vuint64m4_t, vfloat16m1_t, vfloat16m1_t, vfloat16m1_t, vfloat16m1_t, vfloat16m1_t, vfloat16m1_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vsoxseg6ei64_v_m)))
void vsoxseg6ei64(vbool16_t, _Float16 *, vuint64m4_t, vfloat16m1_t, vfloat16m1_t, vfloat16m1_t, vfloat16m1_t, vfloat16m1_t, vfloat16m1_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vsoxseg6ei64_v)))
void vsoxseg6ei64(_Float16 *, vuint64m2_t, vfloat16mf2_t, vfloat16mf2_t, vfloat16mf2_t, vfloat16mf2_t, vfloat16mf2_t, vfloat16mf2_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vsoxseg6ei64_v_m)))
void vsoxseg6ei64(vbool32_t, _Float16 *, vuint64m2_t, vfloat16mf2_t, vfloat16mf2_t, vfloat16mf2_t, vfloat16mf2_t, vfloat16mf2_t, vfloat16mf2_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vsoxseg6ei64_v)))
void vsoxseg6ei64(_Float16 *, vuint64m1_t, vfloat16mf4_t, vfloat16mf4_t, vfloat16mf4_t, vfloat16mf4_t, vfloat16mf4_t, vfloat16mf4_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vsoxseg6ei64_v_m)))
void vsoxseg6ei64(vbool64_t, _Float16 *, vuint64m1_t, vfloat16mf4_t, vfloat16mf4_t, vfloat16mf4_t, vfloat16mf4_t, vfloat16mf4_t, vfloat16mf4_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vsoxseg7ei64_v)))
void vsoxseg7ei64(_Float16 *, vuint64m4_t, vfloat16m1_t, vfloat16m1_t, vfloat16m1_t, vfloat16m1_t, vfloat16m1_t, vfloat16m1_t, vfloat16m1_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vsoxseg7ei64_v_m)))
void vsoxseg7ei64(vbool16_t, _Float16 *, vuint64m4_t, vfloat16m1_t, vfloat16m1_t, vfloat16m1_t, vfloat16m1_t, vfloat16m1_t, vfloat16m1_t, vfloat16m1_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vsoxseg7ei64_v)))
void vsoxseg7ei64(_Float16 *, vuint64m2_t, vfloat16mf2_t, vfloat16mf2_t, vfloat16mf2_t, vfloat16mf2_t, vfloat16mf2_t, vfloat16mf2_t, vfloat16mf2_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vsoxseg7ei64_v_m)))
void vsoxseg7ei64(vbool32_t, _Float16 *, vuint64m2_t, vfloat16mf2_t, vfloat16mf2_t, vfloat16mf2_t, vfloat16mf2_t, vfloat16mf2_t, vfloat16mf2_t, vfloat16mf2_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vsoxseg7ei64_v)))
void vsoxseg7ei64(_Float16 *, vuint64m1_t, vfloat16mf4_t, vfloat16mf4_t, vfloat16mf4_t, vfloat16mf4_t, vfloat16mf4_t, vfloat16mf4_t, vfloat16mf4_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vsoxseg7ei64_v_m)))
void vsoxseg7ei64(vbool64_t, _Float16 *, vuint64m1_t, vfloat16mf4_t, vfloat16mf4_t, vfloat16mf4_t, vfloat16mf4_t, vfloat16mf4_t, vfloat16mf4_t, vfloat16mf4_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vsoxseg8ei64_v)))
void vsoxseg8ei64(_Float16 *, vuint64m4_t, vfloat16m1_t, vfloat16m1_t, vfloat16m1_t, vfloat16m1_t, vfloat16m1_t, vfloat16m1_t, vfloat16m1_t, vfloat16m1_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vsoxseg8ei64_v_m)))
void vsoxseg8ei64(vbool16_t, _Float16 *, vuint64m4_t, vfloat16m1_t, vfloat16m1_t, vfloat16m1_t, vfloat16m1_t, vfloat16m1_t, vfloat16m1_t, vfloat16m1_t, vfloat16m1_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vsoxseg8ei64_v)))
void vsoxseg8ei64(_Float16 *, vuint64m2_t, vfloat16mf2_t, vfloat16mf2_t, vfloat16mf2_t, vfloat16mf2_t, vfloat16mf2_t, vfloat16mf2_t, vfloat16mf2_t, vfloat16mf2_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vsoxseg8ei64_v_m)))
void vsoxseg8ei64(vbool32_t, _Float16 *, vuint64m2_t, vfloat16mf2_t, vfloat16mf2_t, vfloat16mf2_t, vfloat16mf2_t, vfloat16mf2_t, vfloat16mf2_t, vfloat16mf2_t, vfloat16mf2_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vsoxseg8ei64_v)))
void vsoxseg8ei64(_Float16 *, vuint64m1_t, vfloat16mf4_t, vfloat16mf4_t, vfloat16mf4_t, vfloat16mf4_t, vfloat16mf4_t, vfloat16mf4_t, vfloat16mf4_t, vfloat16mf4_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vsoxseg8ei64_v_m)))
void vsoxseg8ei64(vbool64_t, _Float16 *, vuint64m1_t, vfloat16mf4_t, vfloat16mf4_t, vfloat16mf4_t, vfloat16mf4_t, vfloat16mf4_t, vfloat16mf4_t, vfloat16mf4_t, vfloat16mf4_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vluxseg2ei64_v)))
void vluxseg2ei64(vfloat16m1_t *, vfloat16m1_t *, const _Float16 *, vuint64m4_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vluxseg2ei64_v_m)))
void vluxseg2ei64(vfloat16m1_t *, vfloat16m1_t *, vbool16_t, vfloat16m1_t, vfloat16m1_t, const _Float16 *, vuint64m4_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vluxseg2ei64_v)))
void vluxseg2ei64(vfloat16m2_t *, vfloat16m2_t *, const _Float16 *, vuint64m8_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vluxseg2ei64_v_m)))
void vluxseg2ei64(vfloat16m2_t *, vfloat16m2_t *, vbool8_t, vfloat16m2_t, vfloat16m2_t, const _Float16 *, vuint64m8_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vluxseg2ei64_v)))
void vluxseg2ei64(vfloat16mf2_t *, vfloat16mf2_t *, const _Float16 *, vuint64m2_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vluxseg2ei64_v_m)))
void vluxseg2ei64(vfloat16mf2_t *, vfloat16mf2_t *, vbool32_t, vfloat16mf2_t, vfloat16mf2_t, const _Float16 *, vuint64m2_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vluxseg2ei64_v)))
void vluxseg2ei64(vfloat16mf4_t *, vfloat16mf4_t *, const _Float16 *, vuint64m1_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vluxseg2ei64_v_m)))
void vluxseg2ei64(vfloat16mf4_t *, vfloat16mf4_t *, vbool64_t, vfloat16mf4_t, vfloat16mf4_t, const _Float16 *, vuint64m1_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vluxseg3ei64_v)))
void vluxseg3ei64(vfloat16m1_t *, vfloat16m1_t *, vfloat16m1_t *, const _Float16 *, vuint64m4_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vluxseg3ei64_v_m)))
void vluxseg3ei64(vfloat16m1_t *, vfloat16m1_t *, vfloat16m1_t *, vbool16_t, vfloat16m1_t, vfloat16m1_t, vfloat16m1_t, const _Float16 *, vuint64m4_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vluxseg3ei64_v)))
void vluxseg3ei64(vfloat16m2_t *, vfloat16m2_t *, vfloat16m2_t *, const _Float16 *, vuint64m8_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vluxseg3ei64_v_m)))
void vluxseg3ei64(vfloat16m2_t *, vfloat16m2_t *, vfloat16m2_t *, vbool8_t, vfloat16m2_t, vfloat16m2_t, vfloat16m2_t, const _Float16 *, vuint64m8_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vluxseg3ei64_v)))
void vluxseg3ei64(vfloat16mf2_t *, vfloat16mf2_t *, vfloat16mf2_t *, const _Float16 *, vuint64m2_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vluxseg3ei64_v_m)))
void vluxseg3ei64(vfloat16mf2_t *, vfloat16mf2_t *, vfloat16mf2_t *, vbool32_t, vfloat16mf2_t, vfloat16mf2_t, vfloat16mf2_t, const _Float16 *, vuint64m2_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vluxseg3ei64_v)))
void vluxseg3ei64(vfloat16mf4_t *, vfloat16mf4_t *, vfloat16mf4_t *, const _Float16 *, vuint64m1_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vluxseg3ei64_v_m)))
void vluxseg3ei64(vfloat16mf4_t *, vfloat16mf4_t *, vfloat16mf4_t *, vbool64_t, vfloat16mf4_t, vfloat16mf4_t, vfloat16mf4_t, const _Float16 *, vuint64m1_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vluxseg4ei64_v)))
void vluxseg4ei64(vfloat16m1_t *, vfloat16m1_t *, vfloat16m1_t *, vfloat16m1_t *, const _Float16 *, vuint64m4_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vluxseg4ei64_v_m)))
void vluxseg4ei64(vfloat16m1_t *, vfloat16m1_t *, vfloat16m1_t *, vfloat16m1_t *, vbool16_t, vfloat16m1_t, vfloat16m1_t, vfloat16m1_t, vfloat16m1_t, const _Float16 *, vuint64m4_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vluxseg4ei64_v)))
void vluxseg4ei64(vfloat16m2_t *, vfloat16m2_t *, vfloat16m2_t *, vfloat16m2_t *, const _Float16 *, vuint64m8_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vluxseg4ei64_v_m)))
void vluxseg4ei64(vfloat16m2_t *, vfloat16m2_t *, vfloat16m2_t *, vfloat16m2_t *, vbool8_t, vfloat16m2_t, vfloat16m2_t, vfloat16m2_t, vfloat16m2_t, const _Float16 *, vuint64m8_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vluxseg4ei64_v)))
void vluxseg4ei64(vfloat16mf2_t *, vfloat16mf2_t *, vfloat16mf2_t *, vfloat16mf2_t *, const _Float16 *, vuint64m2_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vluxseg4ei64_v_m)))
void vluxseg4ei64(vfloat16mf2_t *, vfloat16mf2_t *, vfloat16mf2_t *, vfloat16mf2_t *, vbool32_t, vfloat16mf2_t, vfloat16mf2_t, vfloat16mf2_t, vfloat16mf2_t, const _Float16 *, vuint64m2_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vluxseg4ei64_v)))
void vluxseg4ei64(vfloat16mf4_t *, vfloat16mf4_t *, vfloat16mf4_t *, vfloat16mf4_t *, const _Float16 *, vuint64m1_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vluxseg4ei64_v_m)))
void vluxseg4ei64(vfloat16mf4_t *, vfloat16mf4_t *, vfloat16mf4_t *, vfloat16mf4_t *, vbool64_t, vfloat16mf4_t, vfloat16mf4_t, vfloat16mf4_t, vfloat16mf4_t, const _Float16 *, vuint64m1_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vluxseg5ei64_v)))
void vluxseg5ei64(vfloat16m1_t *, vfloat16m1_t *, vfloat16m1_t *, vfloat16m1_t *, vfloat16m1_t *, const _Float16 *, vuint64m4_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vluxseg5ei64_v_m)))
void vluxseg5ei64(vfloat16m1_t *, vfloat16m1_t *, vfloat16m1_t *, vfloat16m1_t *, vfloat16m1_t *, vbool16_t, vfloat16m1_t, vfloat16m1_t, vfloat16m1_t, vfloat16m1_t, vfloat16m1_t, const _Float16 *, vuint64m4_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vluxseg5ei64_v)))
void vluxseg5ei64(vfloat16mf2_t *, vfloat16mf2_t *, vfloat16mf2_t *, vfloat16mf2_t *, vfloat16mf2_t *, const _Float16 *, vuint64m2_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vluxseg5ei64_v_m)))
void vluxseg5ei64(vfloat16mf2_t *, vfloat16mf2_t *, vfloat16mf2_t *, vfloat16mf2_t *, vfloat16mf2_t *, vbool32_t, vfloat16mf2_t, vfloat16mf2_t, vfloat16mf2_t, vfloat16mf2_t, vfloat16mf2_t, const _Float16 *, vuint64m2_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vluxseg5ei64_v)))
void vluxseg5ei64(vfloat16mf4_t *, vfloat16mf4_t *, vfloat16mf4_t *, vfloat16mf4_t *, vfloat16mf4_t *, const _Float16 *, vuint64m1_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vluxseg5ei64_v_m)))
void vluxseg5ei64(vfloat16mf4_t *, vfloat16mf4_t *, vfloat16mf4_t *, vfloat16mf4_t *, vfloat16mf4_t *, vbool64_t, vfloat16mf4_t, vfloat16mf4_t, vfloat16mf4_t, vfloat16mf4_t, vfloat16mf4_t, const _Float16 *, vuint64m1_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vluxseg6ei64_v)))
void vluxseg6ei64(vfloat16m1_t *, vfloat16m1_t *, vfloat16m1_t *, vfloat16m1_t *, vfloat16m1_t *, vfloat16m1_t *, const _Float16 *, vuint64m4_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vluxseg6ei64_v_m)))
void vluxseg6ei64(vfloat16m1_t *, vfloat16m1_t *, vfloat16m1_t *, vfloat16m1_t *, vfloat16m1_t *, vfloat16m1_t *, vbool16_t, vfloat16m1_t, vfloat16m1_t, vfloat16m1_t, vfloat16m1_t, vfloat16m1_t, vfloat16m1_t, const _Float16 *, vuint64m4_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vluxseg6ei64_v)))
void vluxseg6ei64(vfloat16mf2_t *, vfloat16mf2_t *, vfloat16mf2_t *, vfloat16mf2_t *, vfloat16mf2_t *, vfloat16mf2_t *, const _Float16 *, vuint64m2_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vluxseg6ei64_v_m)))
void vluxseg6ei64(vfloat16mf2_t *, vfloat16mf2_t *, vfloat16mf2_t *, vfloat16mf2_t *, vfloat16mf2_t *, vfloat16mf2_t *, vbool32_t, vfloat16mf2_t, vfloat16mf2_t, vfloat16mf2_t, vfloat16mf2_t, vfloat16mf2_t, vfloat16mf2_t, const _Float16 *, vuint64m2_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vluxseg6ei64_v)))
void vluxseg6ei64(vfloat16mf4_t *, vfloat16mf4_t *, vfloat16mf4_t *, vfloat16mf4_t *, vfloat16mf4_t *, vfloat16mf4_t *, const _Float16 *, vuint64m1_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vluxseg6ei64_v_m)))
void vluxseg6ei64(vfloat16mf4_t *, vfloat16mf4_t *, vfloat16mf4_t *, vfloat16mf4_t *, vfloat16mf4_t *, vfloat16mf4_t *, vbool64_t, vfloat16mf4_t, vfloat16mf4_t, vfloat16mf4_t, vfloat16mf4_t, vfloat16mf4_t, vfloat16mf4_t, const _Float16 *, vuint64m1_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vluxseg7ei64_v)))
void vluxseg7ei64(vfloat16m1_t *, vfloat16m1_t *, vfloat16m1_t *, vfloat16m1_t *, vfloat16m1_t *, vfloat16m1_t *, vfloat16m1_t *, const _Float16 *, vuint64m4_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vluxseg7ei64_v_m)))
void vluxseg7ei64(vfloat16m1_t *, vfloat16m1_t *, vfloat16m1_t *, vfloat16m1_t *, vfloat16m1_t *, vfloat16m1_t *, vfloat16m1_t *, vbool16_t, vfloat16m1_t, vfloat16m1_t, vfloat16m1_t, vfloat16m1_t, vfloat16m1_t, vfloat16m1_t, vfloat16m1_t, const _Float16 *, vuint64m4_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vluxseg7ei64_v)))
void vluxseg7ei64(vfloat16mf2_t *, vfloat16mf2_t *, vfloat16mf2_t *, vfloat16mf2_t *, vfloat16mf2_t *, vfloat16mf2_t *, vfloat16mf2_t *, const _Float16 *, vuint64m2_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vluxseg7ei64_v_m)))
void vluxseg7ei64(vfloat16mf2_t *, vfloat16mf2_t *, vfloat16mf2_t *, vfloat16mf2_t *, vfloat16mf2_t *, vfloat16mf2_t *, vfloat16mf2_t *, vbool32_t, vfloat16mf2_t, vfloat16mf2_t, vfloat16mf2_t, vfloat16mf2_t, vfloat16mf2_t, vfloat16mf2_t, vfloat16mf2_t, const _Float16 *, vuint64m2_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vluxseg7ei64_v)))
void vluxseg7ei64(vfloat16mf4_t *, vfloat16mf4_t *, vfloat16mf4_t *, vfloat16mf4_t *, vfloat16mf4_t *, vfloat16mf4_t *, vfloat16mf4_t *, const _Float16 *, vuint64m1_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vluxseg7ei64_v_m)))
void vluxseg7ei64(vfloat16mf4_t *, vfloat16mf4_t *, vfloat16mf4_t *, vfloat16mf4_t *, vfloat16mf4_t *, vfloat16mf4_t *, vfloat16mf4_t *, vbool64_t, vfloat16mf4_t, vfloat16mf4_t, vfloat16mf4_t, vfloat16mf4_t, vfloat16mf4_t, vfloat16mf4_t, vfloat16mf4_t, const _Float16 *, vuint64m1_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vluxseg8ei64_v)))
void vluxseg8ei64(vfloat16m1_t *, vfloat16m1_t *, vfloat16m1_t *, vfloat16m1_t *, vfloat16m1_t *, vfloat16m1_t *, vfloat16m1_t *, vfloat16m1_t *, const _Float16 *, vuint64m4_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vluxseg8ei64_v_m)))
void vluxseg8ei64(vfloat16m1_t *, vfloat16m1_t *, vfloat16m1_t *, vfloat16m1_t *, vfloat16m1_t *, vfloat16m1_t *, vfloat16m1_t *, vfloat16m1_t *, vbool16_t, vfloat16m1_t, vfloat16m1_t, vfloat16m1_t, vfloat16m1_t, vfloat16m1_t, vfloat16m1_t, vfloat16m1_t, vfloat16m1_t, const _Float16 *, vuint64m4_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vluxseg8ei64_v)))
void vluxseg8ei64(vfloat16mf2_t *, vfloat16mf2_t *, vfloat16mf2_t *, vfloat16mf2_t *, vfloat16mf2_t *, vfloat16mf2_t *, vfloat16mf2_t *, vfloat16mf2_t *, const _Float16 *, vuint64m2_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vluxseg8ei64_v_m)))
void vluxseg8ei64(vfloat16mf2_t *, vfloat16mf2_t *, vfloat16mf2_t *, vfloat16mf2_t *, vfloat16mf2_t *, vfloat16mf2_t *, vfloat16mf2_t *, vfloat16mf2_t *, vbool32_t, vfloat16mf2_t, vfloat16mf2_t, vfloat16mf2_t, vfloat16mf2_t, vfloat16mf2_t, vfloat16mf2_t, vfloat16mf2_t, vfloat16mf2_t, const _Float16 *, vuint64m2_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vluxseg8ei64_v)))
void vluxseg8ei64(vfloat16mf4_t *, vfloat16mf4_t *, vfloat16mf4_t *, vfloat16mf4_t *, vfloat16mf4_t *, vfloat16mf4_t *, vfloat16mf4_t *, vfloat16mf4_t *, const _Float16 *, vuint64m1_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vluxseg8ei64_v_m)))
void vluxseg8ei64(vfloat16mf4_t *, vfloat16mf4_t *, vfloat16mf4_t *, vfloat16mf4_t *, vfloat16mf4_t *, vfloat16mf4_t *, vfloat16mf4_t *, vfloat16mf4_t *, vbool64_t, vfloat16mf4_t, vfloat16mf4_t, vfloat16mf4_t, vfloat16mf4_t, vfloat16mf4_t, vfloat16mf4_t, vfloat16mf4_t, vfloat16mf4_t, const _Float16 *, vuint64m1_t, size_t);
#endif

#if (__riscv_xlen == 64) && (__riscv_v_elen >= 64)
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vluxei64_v)))
vint8m1_t vluxei64(const int8_t *, vuint64m8_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vluxei64_v_m)))
vint8m1_t vluxei64(vbool8_t, vint8m1_t, const int8_t *, vuint64m8_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vluxei64_v)))
vint8mf2_t vluxei64(const int8_t *, vuint64m4_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vluxei64_v_m)))
vint8mf2_t vluxei64(vbool16_t, vint8mf2_t, const int8_t *, vuint64m4_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vluxei64_v)))
vint8mf4_t vluxei64(const int8_t *, vuint64m2_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vluxei64_v_m)))
vint8mf4_t vluxei64(vbool32_t, vint8mf4_t, const int8_t *, vuint64m2_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vluxei64_v)))
vint8mf8_t vluxei64(const int8_t *, vuint64m1_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vluxei64_v_m)))
vint8mf8_t vluxei64(vbool64_t, vint8mf8_t, const int8_t *, vuint64m1_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vluxei64_v)))
vuint8m1_t vluxei64(const uint8_t *, vuint64m8_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vluxei64_v_m)))
vuint8m1_t vluxei64(vbool8_t, vuint8m1_t, const uint8_t *, vuint64m8_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vluxei64_v)))
vuint8mf2_t vluxei64(const uint8_t *, vuint64m4_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vluxei64_v_m)))
vuint8mf2_t vluxei64(vbool16_t, vuint8mf2_t, const uint8_t *, vuint64m4_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vluxei64_v)))
vuint8mf4_t vluxei64(const uint8_t *, vuint64m2_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vluxei64_v_m)))
vuint8mf4_t vluxei64(vbool32_t, vuint8mf4_t, const uint8_t *, vuint64m2_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vluxei64_v)))
vuint8mf8_t vluxei64(const uint8_t *, vuint64m1_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vluxei64_v_m)))
vuint8mf8_t vluxei64(vbool64_t, vuint8mf8_t, const uint8_t *, vuint64m1_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vluxei64_v)))
vint16m1_t vluxei64(const int16_t *, vuint64m4_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vluxei64_v_m)))
vint16m1_t vluxei64(vbool16_t, vint16m1_t, const int16_t *, vuint64m4_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vluxei64_v)))
vint16m2_t vluxei64(const int16_t *, vuint64m8_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vluxei64_v_m)))
vint16m2_t vluxei64(vbool8_t, vint16m2_t, const int16_t *, vuint64m8_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vluxei64_v)))
vint16mf2_t vluxei64(const int16_t *, vuint64m2_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vluxei64_v_m)))
vint16mf2_t vluxei64(vbool32_t, vint16mf2_t, const int16_t *, vuint64m2_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vluxei64_v)))
vint16mf4_t vluxei64(const int16_t *, vuint64m1_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vluxei64_v_m)))
vint16mf4_t vluxei64(vbool64_t, vint16mf4_t, const int16_t *, vuint64m1_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vluxei64_v)))
vuint16m1_t vluxei64(const uint16_t *, vuint64m4_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vluxei64_v_m)))
vuint16m1_t vluxei64(vbool16_t, vuint16m1_t, const uint16_t *, vuint64m4_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vluxei64_v)))
vuint16m2_t vluxei64(const uint16_t *, vuint64m8_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vluxei64_v_m)))
vuint16m2_t vluxei64(vbool8_t, vuint16m2_t, const uint16_t *, vuint64m8_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vluxei64_v)))
vuint16mf2_t vluxei64(const uint16_t *, vuint64m2_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vluxei64_v_m)))
vuint16mf2_t vluxei64(vbool32_t, vuint16mf2_t, const uint16_t *, vuint64m2_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vluxei64_v)))
vuint16mf4_t vluxei64(const uint16_t *, vuint64m1_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vluxei64_v_m)))
vuint16mf4_t vluxei64(vbool64_t, vuint16mf4_t, const uint16_t *, vuint64m1_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vluxei64_v)))
vint32m1_t vluxei64(const int32_t *, vuint64m2_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vluxei64_v_m)))
vint32m1_t vluxei64(vbool32_t, vint32m1_t, const int32_t *, vuint64m2_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vluxei64_v)))
vint32m2_t vluxei64(const int32_t *, vuint64m4_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vluxei64_v_m)))
vint32m2_t vluxei64(vbool16_t, vint32m2_t, const int32_t *, vuint64m4_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vluxei64_v)))
vint32m4_t vluxei64(const int32_t *, vuint64m8_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vluxei64_v_m)))
vint32m4_t vluxei64(vbool8_t, vint32m4_t, const int32_t *, vuint64m8_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vluxei64_v)))
vint32mf2_t vluxei64(const int32_t *, vuint64m1_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vluxei64_v_m)))
vint32mf2_t vluxei64(vbool64_t, vint32mf2_t, const int32_t *, vuint64m1_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vluxei64_v)))
vuint32m1_t vluxei64(const uint32_t *, vuint64m2_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vluxei64_v_m)))
vuint32m1_t vluxei64(vbool32_t, vuint32m1_t, const uint32_t *, vuint64m2_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vluxei64_v)))
vuint32m2_t vluxei64(const uint32_t *, vuint64m4_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vluxei64_v_m)))
vuint32m2_t vluxei64(vbool16_t, vuint32m2_t, const uint32_t *, vuint64m4_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vluxei64_v)))
vuint32m4_t vluxei64(const uint32_t *, vuint64m8_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vluxei64_v_m)))
vuint32m4_t vluxei64(vbool8_t, vuint32m4_t, const uint32_t *, vuint64m8_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vluxei64_v)))
vuint32mf2_t vluxei64(const uint32_t *, vuint64m1_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vluxei64_v_m)))
vuint32mf2_t vluxei64(vbool64_t, vuint32mf2_t, const uint32_t *, vuint64m1_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vluxei64_v)))
vint64m1_t vluxei64(const int64_t *, vuint64m1_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vluxei64_v_m)))
vint64m1_t vluxei64(vbool64_t, vint64m1_t, const int64_t *, vuint64m1_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vluxei64_v)))
vint64m2_t vluxei64(const int64_t *, vuint64m2_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vluxei64_v_m)))
vint64m2_t vluxei64(vbool32_t, vint64m2_t, const int64_t *, vuint64m2_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vluxei64_v)))
vint64m4_t vluxei64(const int64_t *, vuint64m4_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vluxei64_v_m)))
vint64m4_t vluxei64(vbool16_t, vint64m4_t, const int64_t *, vuint64m4_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vluxei64_v)))
vint64m8_t vluxei64(const int64_t *, vuint64m8_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vluxei64_v_m)))
vint64m8_t vluxei64(vbool8_t, vint64m8_t, const int64_t *, vuint64m8_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vluxei64_v)))
vuint64m1_t vluxei64(const uint64_t *, vuint64m1_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vluxei64_v_m)))
vuint64m1_t vluxei64(vbool64_t, vuint64m1_t, const uint64_t *, vuint64m1_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vluxei64_v)))
vuint64m2_t vluxei64(const uint64_t *, vuint64m2_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vluxei64_v_m)))
vuint64m2_t vluxei64(vbool32_t, vuint64m2_t, const uint64_t *, vuint64m2_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vluxei64_v)))
vuint64m4_t vluxei64(const uint64_t *, vuint64m4_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vluxei64_v_m)))
vuint64m4_t vluxei64(vbool16_t, vuint64m4_t, const uint64_t *, vuint64m4_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vluxei64_v)))
vuint64m8_t vluxei64(const uint64_t *, vuint64m8_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vluxei64_v_m)))
vuint64m8_t vluxei64(vbool8_t, vuint64m8_t, const uint64_t *, vuint64m8_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vloxei64_v)))
vint8m1_t vloxei64(const int8_t *, vuint64m8_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vloxei64_v_m)))
vint8m1_t vloxei64(vbool8_t, vint8m1_t, const int8_t *, vuint64m8_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vloxei64_v)))
vint8mf2_t vloxei64(const int8_t *, vuint64m4_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vloxei64_v_m)))
vint8mf2_t vloxei64(vbool16_t, vint8mf2_t, const int8_t *, vuint64m4_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vloxei64_v)))
vint8mf4_t vloxei64(const int8_t *, vuint64m2_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vloxei64_v_m)))
vint8mf4_t vloxei64(vbool32_t, vint8mf4_t, const int8_t *, vuint64m2_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vloxei64_v)))
vint8mf8_t vloxei64(const int8_t *, vuint64m1_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vloxei64_v_m)))
vint8mf8_t vloxei64(vbool64_t, vint8mf8_t, const int8_t *, vuint64m1_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vloxei64_v)))
vuint8m1_t vloxei64(const uint8_t *, vuint64m8_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vloxei64_v_m)))
vuint8m1_t vloxei64(vbool8_t, vuint8m1_t, const uint8_t *, vuint64m8_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vloxei64_v)))
vuint8mf2_t vloxei64(const uint8_t *, vuint64m4_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vloxei64_v_m)))
vuint8mf2_t vloxei64(vbool16_t, vuint8mf2_t, const uint8_t *, vuint64m4_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vloxei64_v)))
vuint8mf4_t vloxei64(const uint8_t *, vuint64m2_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vloxei64_v_m)))
vuint8mf4_t vloxei64(vbool32_t, vuint8mf4_t, const uint8_t *, vuint64m2_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vloxei64_v)))
vuint8mf8_t vloxei64(const uint8_t *, vuint64m1_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vloxei64_v_m)))
vuint8mf8_t vloxei64(vbool64_t, vuint8mf8_t, const uint8_t *, vuint64m1_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vloxei64_v)))
vint16m1_t vloxei64(const int16_t *, vuint64m4_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vloxei64_v_m)))
vint16m1_t vloxei64(vbool16_t, vint16m1_t, const int16_t *, vuint64m4_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vloxei64_v)))
vint16m2_t vloxei64(const int16_t *, vuint64m8_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vloxei64_v_m)))
vint16m2_t vloxei64(vbool8_t, vint16m2_t, const int16_t *, vuint64m8_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vloxei64_v)))
vint16mf2_t vloxei64(const int16_t *, vuint64m2_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vloxei64_v_m)))
vint16mf2_t vloxei64(vbool32_t, vint16mf2_t, const int16_t *, vuint64m2_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vloxei64_v)))
vint16mf4_t vloxei64(const int16_t *, vuint64m1_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vloxei64_v_m)))
vint16mf4_t vloxei64(vbool64_t, vint16mf4_t, const int16_t *, vuint64m1_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vloxei64_v)))
vuint16m1_t vloxei64(const uint16_t *, vuint64m4_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vloxei64_v_m)))
vuint16m1_t vloxei64(vbool16_t, vuint16m1_t, const uint16_t *, vuint64m4_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vloxei64_v)))
vuint16m2_t vloxei64(const uint16_t *, vuint64m8_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vloxei64_v_m)))
vuint16m2_t vloxei64(vbool8_t, vuint16m2_t, const uint16_t *, vuint64m8_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vloxei64_v)))
vuint16mf2_t vloxei64(const uint16_t *, vuint64m2_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vloxei64_v_m)))
vuint16mf2_t vloxei64(vbool32_t, vuint16mf2_t, const uint16_t *, vuint64m2_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vloxei64_v)))
vuint16mf4_t vloxei64(const uint16_t *, vuint64m1_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vloxei64_v_m)))
vuint16mf4_t vloxei64(vbool64_t, vuint16mf4_t, const uint16_t *, vuint64m1_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vloxei64_v)))
vint32m1_t vloxei64(const int32_t *, vuint64m2_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vloxei64_v_m)))
vint32m1_t vloxei64(vbool32_t, vint32m1_t, const int32_t *, vuint64m2_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vloxei64_v)))
vint32m2_t vloxei64(const int32_t *, vuint64m4_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vloxei64_v_m)))
vint32m2_t vloxei64(vbool16_t, vint32m2_t, const int32_t *, vuint64m4_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vloxei64_v)))
vint32m4_t vloxei64(const int32_t *, vuint64m8_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vloxei64_v_m)))
vint32m4_t vloxei64(vbool8_t, vint32m4_t, const int32_t *, vuint64m8_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vloxei64_v)))
vint32mf2_t vloxei64(const int32_t *, vuint64m1_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vloxei64_v_m)))
vint32mf2_t vloxei64(vbool64_t, vint32mf2_t, const int32_t *, vuint64m1_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vloxei64_v)))
vuint32m1_t vloxei64(const uint32_t *, vuint64m2_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vloxei64_v_m)))
vuint32m1_t vloxei64(vbool32_t, vuint32m1_t, const uint32_t *, vuint64m2_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vloxei64_v)))
vuint32m2_t vloxei64(const uint32_t *, vuint64m4_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vloxei64_v_m)))
vuint32m2_t vloxei64(vbool16_t, vuint32m2_t, const uint32_t *, vuint64m4_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vloxei64_v)))
vuint32m4_t vloxei64(const uint32_t *, vuint64m8_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vloxei64_v_m)))
vuint32m4_t vloxei64(vbool8_t, vuint32m4_t, const uint32_t *, vuint64m8_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vloxei64_v)))
vuint32mf2_t vloxei64(const uint32_t *, vuint64m1_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vloxei64_v_m)))
vuint32mf2_t vloxei64(vbool64_t, vuint32mf2_t, const uint32_t *, vuint64m1_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vloxei64_v)))
vint64m1_t vloxei64(const int64_t *, vuint64m1_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vloxei64_v_m)))
vint64m1_t vloxei64(vbool64_t, vint64m1_t, const int64_t *, vuint64m1_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vloxei64_v)))
vint64m2_t vloxei64(const int64_t *, vuint64m2_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vloxei64_v_m)))
vint64m2_t vloxei64(vbool32_t, vint64m2_t, const int64_t *, vuint64m2_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vloxei64_v)))
vint64m4_t vloxei64(const int64_t *, vuint64m4_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vloxei64_v_m)))
vint64m4_t vloxei64(vbool16_t, vint64m4_t, const int64_t *, vuint64m4_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vloxei64_v)))
vint64m8_t vloxei64(const int64_t *, vuint64m8_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vloxei64_v_m)))
vint64m8_t vloxei64(vbool8_t, vint64m8_t, const int64_t *, vuint64m8_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vloxei64_v)))
vuint64m1_t vloxei64(const uint64_t *, vuint64m1_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vloxei64_v_m)))
vuint64m1_t vloxei64(vbool64_t, vuint64m1_t, const uint64_t *, vuint64m1_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vloxei64_v)))
vuint64m2_t vloxei64(const uint64_t *, vuint64m2_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vloxei64_v_m)))
vuint64m2_t vloxei64(vbool32_t, vuint64m2_t, const uint64_t *, vuint64m2_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vloxei64_v)))
vuint64m4_t vloxei64(const uint64_t *, vuint64m4_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vloxei64_v_m)))
vuint64m4_t vloxei64(vbool16_t, vuint64m4_t, const uint64_t *, vuint64m4_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vloxei64_v)))
vuint64m8_t vloxei64(const uint64_t *, vuint64m8_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vloxei64_v_m)))
vuint64m8_t vloxei64(vbool8_t, vuint64m8_t, const uint64_t *, vuint64m8_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vsuxei64_v)))
void vsuxei64(int16_t *, vuint64m4_t, vint16m1_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vsuxei64_v_m)))
void vsuxei64(vbool16_t, int16_t *, vuint64m4_t, vint16m1_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vsuxei64_v)))
void vsuxei64(int16_t *, vuint64m8_t, vint16m2_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vsuxei64_v_m)))
void vsuxei64(vbool8_t, int16_t *, vuint64m8_t, vint16m2_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vsuxei64_v)))
void vsuxei64(int16_t *, vuint64m2_t, vint16mf2_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vsuxei64_v_m)))
void vsuxei64(vbool32_t, int16_t *, vuint64m2_t, vint16mf2_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vsuxei64_v)))
void vsuxei64(int16_t *, vuint64m1_t, vint16mf4_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vsuxei64_v_m)))
void vsuxei64(vbool64_t, int16_t *, vuint64m1_t, vint16mf4_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vsuxei64_v)))
void vsuxei64(uint16_t *, vuint64m4_t, vuint16m1_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vsuxei64_v_m)))
void vsuxei64(vbool16_t, uint16_t *, vuint64m4_t, vuint16m1_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vsuxei64_v)))
void vsuxei64(uint16_t *, vuint64m8_t, vuint16m2_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vsuxei64_v_m)))
void vsuxei64(vbool8_t, uint16_t *, vuint64m8_t, vuint16m2_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vsuxei64_v)))
void vsuxei64(uint16_t *, vuint64m2_t, vuint16mf2_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vsuxei64_v_m)))
void vsuxei64(vbool32_t, uint16_t *, vuint64m2_t, vuint16mf2_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vsuxei64_v)))
void vsuxei64(uint16_t *, vuint64m1_t, vuint16mf4_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vsuxei64_v_m)))
void vsuxei64(vbool64_t, uint16_t *, vuint64m1_t, vuint16mf4_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vsuxei64_v)))
void vsuxei64(int32_t *, vuint64m2_t, vint32m1_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vsuxei64_v_m)))
void vsuxei64(vbool32_t, int32_t *, vuint64m2_t, vint32m1_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vsuxei64_v)))
void vsuxei64(int32_t *, vuint64m4_t, vint32m2_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vsuxei64_v_m)))
void vsuxei64(vbool16_t, int32_t *, vuint64m4_t, vint32m2_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vsuxei64_v)))
void vsuxei64(int32_t *, vuint64m8_t, vint32m4_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vsuxei64_v_m)))
void vsuxei64(vbool8_t, int32_t *, vuint64m8_t, vint32m4_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vsuxei64_v)))
void vsuxei64(int32_t *, vuint64m1_t, vint32mf2_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vsuxei64_v_m)))
void vsuxei64(vbool64_t, int32_t *, vuint64m1_t, vint32mf2_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vsuxei64_v)))
void vsuxei64(uint32_t *, vuint64m2_t, vuint32m1_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vsuxei64_v_m)))
void vsuxei64(vbool32_t, uint32_t *, vuint64m2_t, vuint32m1_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vsuxei64_v)))
void vsuxei64(uint32_t *, vuint64m4_t, vuint32m2_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vsuxei64_v_m)))
void vsuxei64(vbool16_t, uint32_t *, vuint64m4_t, vuint32m2_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vsuxei64_v)))
void vsuxei64(uint32_t *, vuint64m8_t, vuint32m4_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vsuxei64_v_m)))
void vsuxei64(vbool8_t, uint32_t *, vuint64m8_t, vuint32m4_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vsuxei64_v)))
void vsuxei64(uint32_t *, vuint64m1_t, vuint32mf2_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vsuxei64_v_m)))
void vsuxei64(vbool64_t, uint32_t *, vuint64m1_t, vuint32mf2_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vsuxei64_v)))
void vsuxei64(int64_t *, vuint64m1_t, vint64m1_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vsuxei64_v_m)))
void vsuxei64(vbool64_t, int64_t *, vuint64m1_t, vint64m1_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vsuxei64_v)))
void vsuxei64(int64_t *, vuint64m2_t, vint64m2_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vsuxei64_v_m)))
void vsuxei64(vbool32_t, int64_t *, vuint64m2_t, vint64m2_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vsuxei64_v)))
void vsuxei64(int64_t *, vuint64m4_t, vint64m4_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vsuxei64_v_m)))
void vsuxei64(vbool16_t, int64_t *, vuint64m4_t, vint64m4_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vsuxei64_v)))
void vsuxei64(int64_t *, vuint64m8_t, vint64m8_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vsuxei64_v_m)))
void vsuxei64(vbool8_t, int64_t *, vuint64m8_t, vint64m8_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vsuxei64_v)))
void vsuxei64(uint64_t *, vuint64m1_t, vuint64m1_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vsuxei64_v_m)))
void vsuxei64(vbool64_t, uint64_t *, vuint64m1_t, vuint64m1_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vsuxei64_v)))
void vsuxei64(uint64_t *, vuint64m2_t, vuint64m2_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vsuxei64_v_m)))
void vsuxei64(vbool32_t, uint64_t *, vuint64m2_t, vuint64m2_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vsuxei64_v)))
void vsuxei64(uint64_t *, vuint64m4_t, vuint64m4_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vsuxei64_v_m)))
void vsuxei64(vbool16_t, uint64_t *, vuint64m4_t, vuint64m4_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vsuxei64_v)))
void vsuxei64(uint64_t *, vuint64m8_t, vuint64m8_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vsuxei64_v_m)))
void vsuxei64(vbool8_t, uint64_t *, vuint64m8_t, vuint64m8_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vsoxei64_v)))
void vsoxei64(int8_t *, vuint64m8_t, vint8m1_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vsoxei64_v_m)))
void vsoxei64(vbool8_t, int8_t *, vuint64m8_t, vint8m1_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vsoxei64_v)))
void vsoxei64(int8_t *, vuint64m4_t, vint8mf2_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vsoxei64_v_m)))
void vsoxei64(vbool16_t, int8_t *, vuint64m4_t, vint8mf2_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vsoxei64_v)))
void vsoxei64(int8_t *, vuint64m2_t, vint8mf4_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vsoxei64_v_m)))
void vsoxei64(vbool32_t, int8_t *, vuint64m2_t, vint8mf4_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vsoxei64_v)))
void vsoxei64(int8_t *, vuint64m1_t, vint8mf8_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vsoxei64_v_m)))
void vsoxei64(vbool64_t, int8_t *, vuint64m1_t, vint8mf8_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vsoxei64_v)))
void vsoxei64(uint8_t *, vuint64m8_t, vuint8m1_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vsoxei64_v_m)))
void vsoxei64(vbool8_t, uint8_t *, vuint64m8_t, vuint8m1_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vsoxei64_v)))
void vsoxei64(uint8_t *, vuint64m4_t, vuint8mf2_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vsoxei64_v_m)))
void vsoxei64(vbool16_t, uint8_t *, vuint64m4_t, vuint8mf2_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vsoxei64_v)))
void vsoxei64(uint8_t *, vuint64m2_t, vuint8mf4_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vsoxei64_v_m)))
void vsoxei64(vbool32_t, uint8_t *, vuint64m2_t, vuint8mf4_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vsoxei64_v)))
void vsoxei64(uint8_t *, vuint64m1_t, vuint8mf8_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vsoxei64_v_m)))
void vsoxei64(vbool64_t, uint8_t *, vuint64m1_t, vuint8mf8_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vsoxei64_v)))
void vsoxei64(int16_t *, vuint64m4_t, vint16m1_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vsoxei64_v_m)))
void vsoxei64(vbool16_t, int16_t *, vuint64m4_t, vint16m1_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vsoxei64_v)))
void vsoxei64(int16_t *, vuint64m8_t, vint16m2_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vsoxei64_v_m)))
void vsoxei64(vbool8_t, int16_t *, vuint64m8_t, vint16m2_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vsoxei64_v)))
void vsoxei64(int16_t *, vuint64m2_t, vint16mf2_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vsoxei64_v_m)))
void vsoxei64(vbool32_t, int16_t *, vuint64m2_t, vint16mf2_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vsoxei64_v)))
void vsoxei64(int16_t *, vuint64m1_t, vint16mf4_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vsoxei64_v_m)))
void vsoxei64(vbool64_t, int16_t *, vuint64m1_t, vint16mf4_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vsoxei64_v)))
void vsoxei64(uint16_t *, vuint64m4_t, vuint16m1_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vsoxei64_v_m)))
void vsoxei64(vbool16_t, uint16_t *, vuint64m4_t, vuint16m1_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vsoxei64_v)))
void vsoxei64(uint16_t *, vuint64m8_t, vuint16m2_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vsoxei64_v_m)))
void vsoxei64(vbool8_t, uint16_t *, vuint64m8_t, vuint16m2_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vsoxei64_v)))
void vsoxei64(uint16_t *, vuint64m2_t, vuint16mf2_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vsoxei64_v_m)))
void vsoxei64(vbool32_t, uint16_t *, vuint64m2_t, vuint16mf2_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vsoxei64_v)))
void vsoxei64(uint16_t *, vuint64m1_t, vuint16mf4_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vsoxei64_v_m)))
void vsoxei64(vbool64_t, uint16_t *, vuint64m1_t, vuint16mf4_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vsuxei64_v)))
void vsuxei64(int8_t *, vuint64m8_t, vint8m1_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vsuxei64_v_m)))
void vsuxei64(vbool8_t, int8_t *, vuint64m8_t, vint8m1_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vsuxei64_v)))
void vsuxei64(int8_t *, vuint64m4_t, vint8mf2_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vsuxei64_v_m)))
void vsuxei64(vbool16_t, int8_t *, vuint64m4_t, vint8mf2_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vsuxei64_v)))
void vsuxei64(int8_t *, vuint64m2_t, vint8mf4_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vsuxei64_v_m)))
void vsuxei64(vbool32_t, int8_t *, vuint64m2_t, vint8mf4_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vsuxei64_v)))
void vsuxei64(int8_t *, vuint64m1_t, vint8mf8_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vsuxei64_v_m)))
void vsuxei64(vbool64_t, int8_t *, vuint64m1_t, vint8mf8_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vsoxei64_v)))
void vsoxei64(int32_t *, vuint64m2_t, vint32m1_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vsoxei64_v_m)))
void vsoxei64(vbool32_t, int32_t *, vuint64m2_t, vint32m1_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vsoxei64_v)))
void vsoxei64(int32_t *, vuint64m4_t, vint32m2_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vsoxei64_v_m)))
void vsoxei64(vbool16_t, int32_t *, vuint64m4_t, vint32m2_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vsoxei64_v)))
void vsoxei64(int32_t *, vuint64m8_t, vint32m4_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vsoxei64_v_m)))
void vsoxei64(vbool8_t, int32_t *, vuint64m8_t, vint32m4_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vsoxei64_v)))
void vsoxei64(int32_t *, vuint64m1_t, vint32mf2_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vsoxei64_v_m)))
void vsoxei64(vbool64_t, int32_t *, vuint64m1_t, vint32mf2_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vsoxei64_v)))
void vsoxei64(uint32_t *, vuint64m2_t, vuint32m1_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vsoxei64_v_m)))
void vsoxei64(vbool32_t, uint32_t *, vuint64m2_t, vuint32m1_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vsoxei64_v)))
void vsoxei64(uint32_t *, vuint64m4_t, vuint32m2_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vsoxei64_v_m)))
void vsoxei64(vbool16_t, uint32_t *, vuint64m4_t, vuint32m2_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vsoxei64_v)))
void vsoxei64(uint32_t *, vuint64m8_t, vuint32m4_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vsoxei64_v_m)))
void vsoxei64(vbool8_t, uint32_t *, vuint64m8_t, vuint32m4_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vsoxei64_v)))
void vsoxei64(uint32_t *, vuint64m1_t, vuint32mf2_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vsoxei64_v_m)))
void vsoxei64(vbool64_t, uint32_t *, vuint64m1_t, vuint32mf2_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vsuxei64_v)))
void vsuxei64(uint8_t *, vuint64m8_t, vuint8m1_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vsuxei64_v_m)))
void vsuxei64(vbool8_t, uint8_t *, vuint64m8_t, vuint8m1_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vsuxei64_v)))
void vsuxei64(uint8_t *, vuint64m4_t, vuint8mf2_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vsuxei64_v_m)))
void vsuxei64(vbool16_t, uint8_t *, vuint64m4_t, vuint8mf2_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vsuxei64_v)))
void vsuxei64(uint8_t *, vuint64m2_t, vuint8mf4_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vsuxei64_v_m)))
void vsuxei64(vbool32_t, uint8_t *, vuint64m2_t, vuint8mf4_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vsuxei64_v)))
void vsuxei64(uint8_t *, vuint64m1_t, vuint8mf8_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vsuxei64_v_m)))
void vsuxei64(vbool64_t, uint8_t *, vuint64m1_t, vuint8mf8_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vsoxei64_v)))
void vsoxei64(int64_t *, vuint64m1_t, vint64m1_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vsoxei64_v_m)))
void vsoxei64(vbool64_t, int64_t *, vuint64m1_t, vint64m1_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vsoxei64_v)))
void vsoxei64(int64_t *, vuint64m2_t, vint64m2_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vsoxei64_v_m)))
void vsoxei64(vbool32_t, int64_t *, vuint64m2_t, vint64m2_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vsoxei64_v)))
void vsoxei64(int64_t *, vuint64m4_t, vint64m4_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vsoxei64_v_m)))
void vsoxei64(vbool16_t, int64_t *, vuint64m4_t, vint64m4_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vsoxei64_v)))
void vsoxei64(int64_t *, vuint64m8_t, vint64m8_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vsoxei64_v_m)))
void vsoxei64(vbool8_t, int64_t *, vuint64m8_t, vint64m8_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vsoxei64_v)))
void vsoxei64(uint64_t *, vuint64m1_t, vuint64m1_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vsoxei64_v_m)))
void vsoxei64(vbool64_t, uint64_t *, vuint64m1_t, vuint64m1_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vsoxei64_v)))
void vsoxei64(uint64_t *, vuint64m2_t, vuint64m2_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vsoxei64_v_m)))
void vsoxei64(vbool32_t, uint64_t *, vuint64m2_t, vuint64m2_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vsoxei64_v)))
void vsoxei64(uint64_t *, vuint64m4_t, vuint64m4_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vsoxei64_v_m)))
void vsoxei64(vbool16_t, uint64_t *, vuint64m4_t, vuint64m4_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vsoxei64_v)))
void vsoxei64(uint64_t *, vuint64m8_t, vuint64m8_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vsoxei64_v_m)))
void vsoxei64(vbool8_t, uint64_t *, vuint64m8_t, vuint64m8_t, size_t);
#endif

#if defined(__riscv_zfh) && (__riscv_xlen == 64) && (__riscv_v_elen >= 64)
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vluxei64_v)))
vfloat16m1_t vluxei64(const _Float16 *, vuint64m4_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vluxei64_v_m)))
vfloat16m1_t vluxei64(vbool16_t, vfloat16m1_t, const _Float16 *, vuint64m4_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vluxei64_v)))
vfloat16m2_t vluxei64(const _Float16 *, vuint64m8_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vluxei64_v_m)))
vfloat16m2_t vluxei64(vbool8_t, vfloat16m2_t, const _Float16 *, vuint64m8_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vluxei64_v)))
vfloat16mf2_t vluxei64(const _Float16 *, vuint64m2_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vluxei64_v_m)))
vfloat16mf2_t vluxei64(vbool32_t, vfloat16mf2_t, const _Float16 *, vuint64m2_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vluxei64_v)))
vfloat16mf4_t vluxei64(const _Float16 *, vuint64m1_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vluxei64_v_m)))
vfloat16mf4_t vluxei64(vbool64_t, vfloat16mf4_t, const _Float16 *, vuint64m1_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vloxei64_v)))
vfloat16m1_t vloxei64(const _Float16 *, vuint64m4_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vloxei64_v_m)))
vfloat16m1_t vloxei64(vbool16_t, vfloat16m1_t, const _Float16 *, vuint64m4_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vloxei64_v)))
vfloat16m2_t vloxei64(const _Float16 *, vuint64m8_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vloxei64_v_m)))
vfloat16m2_t vloxei64(vbool8_t, vfloat16m2_t, const _Float16 *, vuint64m8_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vloxei64_v)))
vfloat16mf2_t vloxei64(const _Float16 *, vuint64m2_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vloxei64_v_m)))
vfloat16mf2_t vloxei64(vbool32_t, vfloat16mf2_t, const _Float16 *, vuint64m2_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vloxei64_v)))
vfloat16mf4_t vloxei64(const _Float16 *, vuint64m1_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vloxei64_v_m)))
vfloat16mf4_t vloxei64(vbool64_t, vfloat16mf4_t, const _Float16 *, vuint64m1_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vsuxei64_v)))
void vsuxei64(_Float16 *, vuint64m4_t, vfloat16m1_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vsuxei64_v_m)))
void vsuxei64(vbool16_t, _Float16 *, vuint64m4_t, vfloat16m1_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vsuxei64_v)))
void vsuxei64(_Float16 *, vuint64m8_t, vfloat16m2_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vsuxei64_v_m)))
void vsuxei64(vbool8_t, _Float16 *, vuint64m8_t, vfloat16m2_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vsuxei64_v)))
void vsuxei64(_Float16 *, vuint64m2_t, vfloat16mf2_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vsuxei64_v_m)))
void vsuxei64(vbool32_t, _Float16 *, vuint64m2_t, vfloat16mf2_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vsuxei64_v)))
void vsuxei64(_Float16 *, vuint64m1_t, vfloat16mf4_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vsuxei64_v_m)))
void vsuxei64(vbool64_t, _Float16 *, vuint64m1_t, vfloat16mf4_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vsoxei64_v)))
void vsoxei64(_Float16 *, vuint64m4_t, vfloat16m1_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vsoxei64_v_m)))
void vsoxei64(vbool16_t, _Float16 *, vuint64m4_t, vfloat16m1_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vsoxei64_v)))
void vsoxei64(_Float16 *, vuint64m8_t, vfloat16m2_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vsoxei64_v_m)))
void vsoxei64(vbool8_t, _Float16 *, vuint64m8_t, vfloat16m2_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vsoxei64_v)))
void vsoxei64(_Float16 *, vuint64m2_t, vfloat16mf2_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vsoxei64_v_m)))
void vsoxei64(vbool32_t, _Float16 *, vuint64m2_t, vfloat16mf2_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vsoxei64_v)))
void vsoxei64(_Float16 *, vuint64m1_t, vfloat16mf4_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vsoxei64_v_m)))
void vsoxei64(vbool64_t, _Float16 *, vuint64m1_t, vfloat16mf4_t, size_t);
#endif

#if (__riscv_v_elen_fp >= 32)
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vlse32_v_m)))
vfloat32m1_t vlse32(vbool32_t, vfloat32m1_t, const float *, ptrdiff_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vlse32_v_m)))
vfloat32m2_t vlse32(vbool16_t, vfloat32m2_t, const float *, ptrdiff_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vlse32_v_m)))
vfloat32m4_t vlse32(vbool8_t, vfloat32m4_t, const float *, ptrdiff_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vlse32_v_m)))
vfloat32m8_t vlse32(vbool4_t, vfloat32m8_t, const float *, ptrdiff_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vlse32_v_m)))
vfloat32mf2_t vlse32(vbool64_t, vfloat32mf2_t, const float *, ptrdiff_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vloxseg2ei8_v)))
void vloxseg2ei8(vfloat32m1_t *, vfloat32m1_t *, const float *, vuint8mf4_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vloxseg2ei8_v_m)))
void vloxseg2ei8(vfloat32m1_t *, vfloat32m1_t *, vbool32_t, vfloat32m1_t, vfloat32m1_t, const float *, vuint8mf4_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vloxseg2ei8_v)))
void vloxseg2ei8(vfloat32m2_t *, vfloat32m2_t *, const float *, vuint8mf2_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vloxseg2ei8_v_m)))
void vloxseg2ei8(vfloat32m2_t *, vfloat32m2_t *, vbool16_t, vfloat32m2_t, vfloat32m2_t, const float *, vuint8mf2_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vloxseg2ei8_v)))
void vloxseg2ei8(vfloat32m4_t *, vfloat32m4_t *, const float *, vuint8m1_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vloxseg2ei8_v_m)))
void vloxseg2ei8(vfloat32m4_t *, vfloat32m4_t *, vbool8_t, vfloat32m4_t, vfloat32m4_t, const float *, vuint8m1_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vloxseg2ei8_v)))
void vloxseg2ei8(vfloat32mf2_t *, vfloat32mf2_t *, const float *, vuint8mf8_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vloxseg2ei8_v_m)))
void vloxseg2ei8(vfloat32mf2_t *, vfloat32mf2_t *, vbool64_t, vfloat32mf2_t, vfloat32mf2_t, const float *, vuint8mf8_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vloxseg3ei8_v)))
void vloxseg3ei8(vfloat32m1_t *, vfloat32m1_t *, vfloat32m1_t *, const float *, vuint8mf4_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vloxseg3ei8_v_m)))
void vloxseg3ei8(vfloat32m1_t *, vfloat32m1_t *, vfloat32m1_t *, vbool32_t, vfloat32m1_t, vfloat32m1_t, vfloat32m1_t, const float *, vuint8mf4_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vloxseg3ei8_v)))
void vloxseg3ei8(vfloat32m2_t *, vfloat32m2_t *, vfloat32m2_t *, const float *, vuint8mf2_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vloxseg3ei8_v_m)))
void vloxseg3ei8(vfloat32m2_t *, vfloat32m2_t *, vfloat32m2_t *, vbool16_t, vfloat32m2_t, vfloat32m2_t, vfloat32m2_t, const float *, vuint8mf2_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vloxseg3ei8_v)))
void vloxseg3ei8(vfloat32mf2_t *, vfloat32mf2_t *, vfloat32mf2_t *, const float *, vuint8mf8_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vloxseg3ei8_v_m)))
void vloxseg3ei8(vfloat32mf2_t *, vfloat32mf2_t *, vfloat32mf2_t *, vbool64_t, vfloat32mf2_t, vfloat32mf2_t, vfloat32mf2_t, const float *, vuint8mf8_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vloxseg4ei8_v)))
void vloxseg4ei8(vfloat32m1_t *, vfloat32m1_t *, vfloat32m1_t *, vfloat32m1_t *, const float *, vuint8mf4_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vloxseg4ei8_v_m)))
void vloxseg4ei8(vfloat32m1_t *, vfloat32m1_t *, vfloat32m1_t *, vfloat32m1_t *, vbool32_t, vfloat32m1_t, vfloat32m1_t, vfloat32m1_t, vfloat32m1_t, const float *, vuint8mf4_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vloxseg4ei8_v)))
void vloxseg4ei8(vfloat32m2_t *, vfloat32m2_t *, vfloat32m2_t *, vfloat32m2_t *, const float *, vuint8mf2_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vloxseg4ei8_v_m)))
void vloxseg4ei8(vfloat32m2_t *, vfloat32m2_t *, vfloat32m2_t *, vfloat32m2_t *, vbool16_t, vfloat32m2_t, vfloat32m2_t, vfloat32m2_t, vfloat32m2_t, const float *, vuint8mf2_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vloxseg4ei8_v)))
void vloxseg4ei8(vfloat32mf2_t *, vfloat32mf2_t *, vfloat32mf2_t *, vfloat32mf2_t *, const float *, vuint8mf8_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vloxseg4ei8_v_m)))
void vloxseg4ei8(vfloat32mf2_t *, vfloat32mf2_t *, vfloat32mf2_t *, vfloat32mf2_t *, vbool64_t, vfloat32mf2_t, vfloat32mf2_t, vfloat32mf2_t, vfloat32mf2_t, const float *, vuint8mf8_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vloxseg5ei8_v)))
void vloxseg5ei8(vfloat32m1_t *, vfloat32m1_t *, vfloat32m1_t *, vfloat32m1_t *, vfloat32m1_t *, const float *, vuint8mf4_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vloxseg5ei8_v_m)))
void vloxseg5ei8(vfloat32m1_t *, vfloat32m1_t *, vfloat32m1_t *, vfloat32m1_t *, vfloat32m1_t *, vbool32_t, vfloat32m1_t, vfloat32m1_t, vfloat32m1_t, vfloat32m1_t, vfloat32m1_t, const float *, vuint8mf4_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vloxseg5ei8_v)))
void vloxseg5ei8(vfloat32mf2_t *, vfloat32mf2_t *, vfloat32mf2_t *, vfloat32mf2_t *, vfloat32mf2_t *, const float *, vuint8mf8_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vloxseg5ei8_v_m)))
void vloxseg5ei8(vfloat32mf2_t *, vfloat32mf2_t *, vfloat32mf2_t *, vfloat32mf2_t *, vfloat32mf2_t *, vbool64_t, vfloat32mf2_t, vfloat32mf2_t, vfloat32mf2_t, vfloat32mf2_t, vfloat32mf2_t, const float *, vuint8mf8_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vloxseg6ei8_v)))
void vloxseg6ei8(vfloat32m1_t *, vfloat32m1_t *, vfloat32m1_t *, vfloat32m1_t *, vfloat32m1_t *, vfloat32m1_t *, const float *, vuint8mf4_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vloxseg6ei8_v_m)))
void vloxseg6ei8(vfloat32m1_t *, vfloat32m1_t *, vfloat32m1_t *, vfloat32m1_t *, vfloat32m1_t *, vfloat32m1_t *, vbool32_t, vfloat32m1_t, vfloat32m1_t, vfloat32m1_t, vfloat32m1_t, vfloat32m1_t, vfloat32m1_t, const float *, vuint8mf4_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vloxseg6ei8_v)))
void vloxseg6ei8(vfloat32mf2_t *, vfloat32mf2_t *, vfloat32mf2_t *, vfloat32mf2_t *, vfloat32mf2_t *, vfloat32mf2_t *, const float *, vuint8mf8_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vloxseg6ei8_v_m)))
void vloxseg6ei8(vfloat32mf2_t *, vfloat32mf2_t *, vfloat32mf2_t *, vfloat32mf2_t *, vfloat32mf2_t *, vfloat32mf2_t *, vbool64_t, vfloat32mf2_t, vfloat32mf2_t, vfloat32mf2_t, vfloat32mf2_t, vfloat32mf2_t, vfloat32mf2_t, const float *, vuint8mf8_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vloxseg7ei8_v)))
void vloxseg7ei8(vfloat32m1_t *, vfloat32m1_t *, vfloat32m1_t *, vfloat32m1_t *, vfloat32m1_t *, vfloat32m1_t *, vfloat32m1_t *, const float *, vuint8mf4_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vloxseg7ei8_v_m)))
void vloxseg7ei8(vfloat32m1_t *, vfloat32m1_t *, vfloat32m1_t *, vfloat32m1_t *, vfloat32m1_t *, vfloat32m1_t *, vfloat32m1_t *, vbool32_t, vfloat32m1_t, vfloat32m1_t, vfloat32m1_t, vfloat32m1_t, vfloat32m1_t, vfloat32m1_t, vfloat32m1_t, const float *, vuint8mf4_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vloxseg7ei8_v)))
void vloxseg7ei8(vfloat32mf2_t *, vfloat32mf2_t *, vfloat32mf2_t *, vfloat32mf2_t *, vfloat32mf2_t *, vfloat32mf2_t *, vfloat32mf2_t *, const float *, vuint8mf8_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vloxseg7ei8_v_m)))
void vloxseg7ei8(vfloat32mf2_t *, vfloat32mf2_t *, vfloat32mf2_t *, vfloat32mf2_t *, vfloat32mf2_t *, vfloat32mf2_t *, vfloat32mf2_t *, vbool64_t, vfloat32mf2_t, vfloat32mf2_t, vfloat32mf2_t, vfloat32mf2_t, vfloat32mf2_t, vfloat32mf2_t, vfloat32mf2_t, const float *, vuint8mf8_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vloxseg8ei8_v)))
void vloxseg8ei8(vfloat32m1_t *, vfloat32m1_t *, vfloat32m1_t *, vfloat32m1_t *, vfloat32m1_t *, vfloat32m1_t *, vfloat32m1_t *, vfloat32m1_t *, const float *, vuint8mf4_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vloxseg8ei8_v_m)))
void vloxseg8ei8(vfloat32m1_t *, vfloat32m1_t *, vfloat32m1_t *, vfloat32m1_t *, vfloat32m1_t *, vfloat32m1_t *, vfloat32m1_t *, vfloat32m1_t *, vbool32_t, vfloat32m1_t, vfloat32m1_t, vfloat32m1_t, vfloat32m1_t, vfloat32m1_t, vfloat32m1_t, vfloat32m1_t, vfloat32m1_t, const float *, vuint8mf4_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vloxseg8ei8_v)))
void vloxseg8ei8(vfloat32mf2_t *, vfloat32mf2_t *, vfloat32mf2_t *, vfloat32mf2_t *, vfloat32mf2_t *, vfloat32mf2_t *, vfloat32mf2_t *, vfloat32mf2_t *, const float *, vuint8mf8_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vloxseg8ei8_v_m)))
void vloxseg8ei8(vfloat32mf2_t *, vfloat32mf2_t *, vfloat32mf2_t *, vfloat32mf2_t *, vfloat32mf2_t *, vfloat32mf2_t *, vfloat32mf2_t *, vfloat32mf2_t *, vbool64_t, vfloat32mf2_t, vfloat32mf2_t, vfloat32mf2_t, vfloat32mf2_t, vfloat32mf2_t, vfloat32mf2_t, vfloat32mf2_t, vfloat32mf2_t, const float *, vuint8mf8_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vloxseg2ei16_v)))
void vloxseg2ei16(vfloat32m1_t *, vfloat32m1_t *, const float *, vuint16mf2_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vloxseg2ei16_v_m)))
void vloxseg2ei16(vfloat32m1_t *, vfloat32m1_t *, vbool32_t, vfloat32m1_t, vfloat32m1_t, const float *, vuint16mf2_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vloxseg2ei16_v)))
void vloxseg2ei16(vfloat32m2_t *, vfloat32m2_t *, const float *, vuint16m1_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vloxseg2ei16_v_m)))
void vloxseg2ei16(vfloat32m2_t *, vfloat32m2_t *, vbool16_t, vfloat32m2_t, vfloat32m2_t, const float *, vuint16m1_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vloxseg2ei16_v)))
void vloxseg2ei16(vfloat32m4_t *, vfloat32m4_t *, const float *, vuint16m2_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vloxseg2ei16_v_m)))
void vloxseg2ei16(vfloat32m4_t *, vfloat32m4_t *, vbool8_t, vfloat32m4_t, vfloat32m4_t, const float *, vuint16m2_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vloxseg2ei16_v)))
void vloxseg2ei16(vfloat32mf2_t *, vfloat32mf2_t *, const float *, vuint16mf4_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vloxseg2ei16_v_m)))
void vloxseg2ei16(vfloat32mf2_t *, vfloat32mf2_t *, vbool64_t, vfloat32mf2_t, vfloat32mf2_t, const float *, vuint16mf4_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vsse32_v)))
void vsse32(float *, ptrdiff_t, vfloat32m1_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vsse32_v_m)))
void vsse32(vbool32_t, float *, ptrdiff_t, vfloat32m1_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vsse32_v)))
void vsse32(float *, ptrdiff_t, vfloat32m2_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vsse32_v_m)))
void vsse32(vbool16_t, float *, ptrdiff_t, vfloat32m2_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vsse32_v)))
void vsse32(float *, ptrdiff_t, vfloat32m4_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vsse32_v_m)))
void vsse32(vbool8_t, float *, ptrdiff_t, vfloat32m4_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vsse32_v)))
void vsse32(float *, ptrdiff_t, vfloat32m8_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vsse32_v_m)))
void vsse32(vbool4_t, float *, ptrdiff_t, vfloat32m8_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vsse32_v)))
void vsse32(float *, ptrdiff_t, vfloat32mf2_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vsse32_v_m)))
void vsse32(vbool64_t, float *, ptrdiff_t, vfloat32mf2_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vloxseg3ei16_v)))
void vloxseg3ei16(vfloat32m1_t *, vfloat32m1_t *, vfloat32m1_t *, const float *, vuint16mf2_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vloxseg3ei16_v_m)))
void vloxseg3ei16(vfloat32m1_t *, vfloat32m1_t *, vfloat32m1_t *, vbool32_t, vfloat32m1_t, vfloat32m1_t, vfloat32m1_t, const float *, vuint16mf2_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vloxseg3ei16_v)))
void vloxseg3ei16(vfloat32m2_t *, vfloat32m2_t *, vfloat32m2_t *, const float *, vuint16m1_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vloxseg3ei16_v_m)))
void vloxseg3ei16(vfloat32m2_t *, vfloat32m2_t *, vfloat32m2_t *, vbool16_t, vfloat32m2_t, vfloat32m2_t, vfloat32m2_t, const float *, vuint16m1_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vloxseg3ei16_v)))
void vloxseg3ei16(vfloat32mf2_t *, vfloat32mf2_t *, vfloat32mf2_t *, const float *, vuint16mf4_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vloxseg3ei16_v_m)))
void vloxseg3ei16(vfloat32mf2_t *, vfloat32mf2_t *, vfloat32mf2_t *, vbool64_t, vfloat32mf2_t, vfloat32mf2_t, vfloat32mf2_t, const float *, vuint16mf4_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vloxseg4ei16_v)))
void vloxseg4ei16(vfloat32m1_t *, vfloat32m1_t *, vfloat32m1_t *, vfloat32m1_t *, const float *, vuint16mf2_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vloxseg4ei16_v_m)))
void vloxseg4ei16(vfloat32m1_t *, vfloat32m1_t *, vfloat32m1_t *, vfloat32m1_t *, vbool32_t, vfloat32m1_t, vfloat32m1_t, vfloat32m1_t, vfloat32m1_t, const float *, vuint16mf2_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vloxseg4ei16_v)))
void vloxseg4ei16(vfloat32m2_t *, vfloat32m2_t *, vfloat32m2_t *, vfloat32m2_t *, const float *, vuint16m1_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vloxseg4ei16_v_m)))
void vloxseg4ei16(vfloat32m2_t *, vfloat32m2_t *, vfloat32m2_t *, vfloat32m2_t *, vbool16_t, vfloat32m2_t, vfloat32m2_t, vfloat32m2_t, vfloat32m2_t, const float *, vuint16m1_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vloxseg4ei16_v)))
void vloxseg4ei16(vfloat32mf2_t *, vfloat32mf2_t *, vfloat32mf2_t *, vfloat32mf2_t *, const float *, vuint16mf4_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vloxseg4ei16_v_m)))
void vloxseg4ei16(vfloat32mf2_t *, vfloat32mf2_t *, vfloat32mf2_t *, vfloat32mf2_t *, vbool64_t, vfloat32mf2_t, vfloat32mf2_t, vfloat32mf2_t, vfloat32mf2_t, const float *, vuint16mf4_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vloxseg5ei16_v)))
void vloxseg5ei16(vfloat32m1_t *, vfloat32m1_t *, vfloat32m1_t *, vfloat32m1_t *, vfloat32m1_t *, const float *, vuint16mf2_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vloxseg5ei16_v_m)))
void vloxseg5ei16(vfloat32m1_t *, vfloat32m1_t *, vfloat32m1_t *, vfloat32m1_t *, vfloat32m1_t *, vbool32_t, vfloat32m1_t, vfloat32m1_t, vfloat32m1_t, vfloat32m1_t, vfloat32m1_t, const float *, vuint16mf2_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vloxseg5ei16_v)))
void vloxseg5ei16(vfloat32mf2_t *, vfloat32mf2_t *, vfloat32mf2_t *, vfloat32mf2_t *, vfloat32mf2_t *, const float *, vuint16mf4_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vloxseg5ei16_v_m)))
void vloxseg5ei16(vfloat32mf2_t *, vfloat32mf2_t *, vfloat32mf2_t *, vfloat32mf2_t *, vfloat32mf2_t *, vbool64_t, vfloat32mf2_t, vfloat32mf2_t, vfloat32mf2_t, vfloat32mf2_t, vfloat32mf2_t, const float *, vuint16mf4_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vloxseg6ei16_v)))
void vloxseg6ei16(vfloat32m1_t *, vfloat32m1_t *, vfloat32m1_t *, vfloat32m1_t *, vfloat32m1_t *, vfloat32m1_t *, const float *, vuint16mf2_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vloxseg6ei16_v_m)))
void vloxseg6ei16(vfloat32m1_t *, vfloat32m1_t *, vfloat32m1_t *, vfloat32m1_t *, vfloat32m1_t *, vfloat32m1_t *, vbool32_t, vfloat32m1_t, vfloat32m1_t, vfloat32m1_t, vfloat32m1_t, vfloat32m1_t, vfloat32m1_t, const float *, vuint16mf2_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vloxseg6ei16_v)))
void vloxseg6ei16(vfloat32mf2_t *, vfloat32mf2_t *, vfloat32mf2_t *, vfloat32mf2_t *, vfloat32mf2_t *, vfloat32mf2_t *, const float *, vuint16mf4_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vloxseg6ei16_v_m)))
void vloxseg6ei16(vfloat32mf2_t *, vfloat32mf2_t *, vfloat32mf2_t *, vfloat32mf2_t *, vfloat32mf2_t *, vfloat32mf2_t *, vbool64_t, vfloat32mf2_t, vfloat32mf2_t, vfloat32mf2_t, vfloat32mf2_t, vfloat32mf2_t, vfloat32mf2_t, const float *, vuint16mf4_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vloxseg7ei16_v)))
void vloxseg7ei16(vfloat32m1_t *, vfloat32m1_t *, vfloat32m1_t *, vfloat32m1_t *, vfloat32m1_t *, vfloat32m1_t *, vfloat32m1_t *, const float *, vuint16mf2_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vloxseg7ei16_v_m)))
void vloxseg7ei16(vfloat32m1_t *, vfloat32m1_t *, vfloat32m1_t *, vfloat32m1_t *, vfloat32m1_t *, vfloat32m1_t *, vfloat32m1_t *, vbool32_t, vfloat32m1_t, vfloat32m1_t, vfloat32m1_t, vfloat32m1_t, vfloat32m1_t, vfloat32m1_t, vfloat32m1_t, const float *, vuint16mf2_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vloxseg7ei16_v)))
void vloxseg7ei16(vfloat32mf2_t *, vfloat32mf2_t *, vfloat32mf2_t *, vfloat32mf2_t *, vfloat32mf2_t *, vfloat32mf2_t *, vfloat32mf2_t *, const float *, vuint16mf4_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vloxseg7ei16_v_m)))
void vloxseg7ei16(vfloat32mf2_t *, vfloat32mf2_t *, vfloat32mf2_t *, vfloat32mf2_t *, vfloat32mf2_t *, vfloat32mf2_t *, vfloat32mf2_t *, vbool64_t, vfloat32mf2_t, vfloat32mf2_t, vfloat32mf2_t, vfloat32mf2_t, vfloat32mf2_t, vfloat32mf2_t, vfloat32mf2_t, const float *, vuint16mf4_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vloxseg8ei16_v)))
void vloxseg8ei16(vfloat32m1_t *, vfloat32m1_t *, vfloat32m1_t *, vfloat32m1_t *, vfloat32m1_t *, vfloat32m1_t *, vfloat32m1_t *, vfloat32m1_t *, const float *, vuint16mf2_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vloxseg8ei16_v_m)))
void vloxseg8ei16(vfloat32m1_t *, vfloat32m1_t *, vfloat32m1_t *, vfloat32m1_t *, vfloat32m1_t *, vfloat32m1_t *, vfloat32m1_t *, vfloat32m1_t *, vbool32_t, vfloat32m1_t, vfloat32m1_t, vfloat32m1_t, vfloat32m1_t, vfloat32m1_t, vfloat32m1_t, vfloat32m1_t, vfloat32m1_t, const float *, vuint16mf2_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vloxseg8ei16_v)))
void vloxseg8ei16(vfloat32mf2_t *, vfloat32mf2_t *, vfloat32mf2_t *, vfloat32mf2_t *, vfloat32mf2_t *, vfloat32mf2_t *, vfloat32mf2_t *, vfloat32mf2_t *, const float *, vuint16mf4_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vloxseg8ei16_v_m)))
void vloxseg8ei16(vfloat32mf2_t *, vfloat32mf2_t *, vfloat32mf2_t *, vfloat32mf2_t *, vfloat32mf2_t *, vfloat32mf2_t *, vfloat32mf2_t *, vfloat32mf2_t *, vbool64_t, vfloat32mf2_t, vfloat32mf2_t, vfloat32mf2_t, vfloat32mf2_t, vfloat32mf2_t, vfloat32mf2_t, vfloat32mf2_t, vfloat32mf2_t, const float *, vuint16mf4_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vloxseg2ei32_v)))
void vloxseg2ei32(vfloat32m1_t *, vfloat32m1_t *, const float *, vuint32m1_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vloxseg2ei32_v_m)))
void vloxseg2ei32(vfloat32m1_t *, vfloat32m1_t *, vbool32_t, vfloat32m1_t, vfloat32m1_t, const float *, vuint32m1_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vloxseg2ei32_v)))
void vloxseg2ei32(vfloat32m2_t *, vfloat32m2_t *, const float *, vuint32m2_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vloxseg2ei32_v_m)))
void vloxseg2ei32(vfloat32m2_t *, vfloat32m2_t *, vbool16_t, vfloat32m2_t, vfloat32m2_t, const float *, vuint32m2_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vloxseg2ei32_v)))
void vloxseg2ei32(vfloat32m4_t *, vfloat32m4_t *, const float *, vuint32m4_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vloxseg2ei32_v_m)))
void vloxseg2ei32(vfloat32m4_t *, vfloat32m4_t *, vbool8_t, vfloat32m4_t, vfloat32m4_t, const float *, vuint32m4_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vloxseg2ei32_v)))
void vloxseg2ei32(vfloat32mf2_t *, vfloat32mf2_t *, const float *, vuint32mf2_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vloxseg2ei32_v_m)))
void vloxseg2ei32(vfloat32mf2_t *, vfloat32mf2_t *, vbool64_t, vfloat32mf2_t, vfloat32mf2_t, const float *, vuint32mf2_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vloxseg3ei32_v)))
void vloxseg3ei32(vfloat32m1_t *, vfloat32m1_t *, vfloat32m1_t *, const float *, vuint32m1_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vloxseg3ei32_v_m)))
void vloxseg3ei32(vfloat32m1_t *, vfloat32m1_t *, vfloat32m1_t *, vbool32_t, vfloat32m1_t, vfloat32m1_t, vfloat32m1_t, const float *, vuint32m1_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vloxseg3ei32_v)))
void vloxseg3ei32(vfloat32m2_t *, vfloat32m2_t *, vfloat32m2_t *, const float *, vuint32m2_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vloxseg3ei32_v_m)))
void vloxseg3ei32(vfloat32m2_t *, vfloat32m2_t *, vfloat32m2_t *, vbool16_t, vfloat32m2_t, vfloat32m2_t, vfloat32m2_t, const float *, vuint32m2_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vloxseg3ei32_v)))
void vloxseg3ei32(vfloat32mf2_t *, vfloat32mf2_t *, vfloat32mf2_t *, const float *, vuint32mf2_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vloxseg3ei32_v_m)))
void vloxseg3ei32(vfloat32mf2_t *, vfloat32mf2_t *, vfloat32mf2_t *, vbool64_t, vfloat32mf2_t, vfloat32mf2_t, vfloat32mf2_t, const float *, vuint32mf2_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vloxseg4ei32_v)))
void vloxseg4ei32(vfloat32m1_t *, vfloat32m1_t *, vfloat32m1_t *, vfloat32m1_t *, const float *, vuint32m1_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vloxseg4ei32_v_m)))
void vloxseg4ei32(vfloat32m1_t *, vfloat32m1_t *, vfloat32m1_t *, vfloat32m1_t *, vbool32_t, vfloat32m1_t, vfloat32m1_t, vfloat32m1_t, vfloat32m1_t, const float *, vuint32m1_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vloxseg4ei32_v)))
void vloxseg4ei32(vfloat32m2_t *, vfloat32m2_t *, vfloat32m2_t *, vfloat32m2_t *, const float *, vuint32m2_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vloxseg4ei32_v_m)))
void vloxseg4ei32(vfloat32m2_t *, vfloat32m2_t *, vfloat32m2_t *, vfloat32m2_t *, vbool16_t, vfloat32m2_t, vfloat32m2_t, vfloat32m2_t, vfloat32m2_t, const float *, vuint32m2_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vloxseg4ei32_v)))
void vloxseg4ei32(vfloat32mf2_t *, vfloat32mf2_t *, vfloat32mf2_t *, vfloat32mf2_t *, const float *, vuint32mf2_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vloxseg4ei32_v_m)))
void vloxseg4ei32(vfloat32mf2_t *, vfloat32mf2_t *, vfloat32mf2_t *, vfloat32mf2_t *, vbool64_t, vfloat32mf2_t, vfloat32mf2_t, vfloat32mf2_t, vfloat32mf2_t, const float *, vuint32mf2_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vloxseg5ei32_v)))
void vloxseg5ei32(vfloat32m1_t *, vfloat32m1_t *, vfloat32m1_t *, vfloat32m1_t *, vfloat32m1_t *, const float *, vuint32m1_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vloxseg5ei32_v_m)))
void vloxseg5ei32(vfloat32m1_t *, vfloat32m1_t *, vfloat32m1_t *, vfloat32m1_t *, vfloat32m1_t *, vbool32_t, vfloat32m1_t, vfloat32m1_t, vfloat32m1_t, vfloat32m1_t, vfloat32m1_t, const float *, vuint32m1_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vloxseg5ei32_v)))
void vloxseg5ei32(vfloat32mf2_t *, vfloat32mf2_t *, vfloat32mf2_t *, vfloat32mf2_t *, vfloat32mf2_t *, const float *, vuint32mf2_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vloxseg5ei32_v_m)))
void vloxseg5ei32(vfloat32mf2_t *, vfloat32mf2_t *, vfloat32mf2_t *, vfloat32mf2_t *, vfloat32mf2_t *, vbool64_t, vfloat32mf2_t, vfloat32mf2_t, vfloat32mf2_t, vfloat32mf2_t, vfloat32mf2_t, const float *, vuint32mf2_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vloxseg6ei32_v)))
void vloxseg6ei32(vfloat32m1_t *, vfloat32m1_t *, vfloat32m1_t *, vfloat32m1_t *, vfloat32m1_t *, vfloat32m1_t *, const float *, vuint32m1_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vloxseg6ei32_v_m)))
void vloxseg6ei32(vfloat32m1_t *, vfloat32m1_t *, vfloat32m1_t *, vfloat32m1_t *, vfloat32m1_t *, vfloat32m1_t *, vbool32_t, vfloat32m1_t, vfloat32m1_t, vfloat32m1_t, vfloat32m1_t, vfloat32m1_t, vfloat32m1_t, const float *, vuint32m1_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vloxseg6ei32_v)))
void vloxseg6ei32(vfloat32mf2_t *, vfloat32mf2_t *, vfloat32mf2_t *, vfloat32mf2_t *, vfloat32mf2_t *, vfloat32mf2_t *, const float *, vuint32mf2_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vloxseg6ei32_v_m)))
void vloxseg6ei32(vfloat32mf2_t *, vfloat32mf2_t *, vfloat32mf2_t *, vfloat32mf2_t *, vfloat32mf2_t *, vfloat32mf2_t *, vbool64_t, vfloat32mf2_t, vfloat32mf2_t, vfloat32mf2_t, vfloat32mf2_t, vfloat32mf2_t, vfloat32mf2_t, const float *, vuint32mf2_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vloxseg7ei32_v)))
void vloxseg7ei32(vfloat32m1_t *, vfloat32m1_t *, vfloat32m1_t *, vfloat32m1_t *, vfloat32m1_t *, vfloat32m1_t *, vfloat32m1_t *, const float *, vuint32m1_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vloxseg7ei32_v_m)))
void vloxseg7ei32(vfloat32m1_t *, vfloat32m1_t *, vfloat32m1_t *, vfloat32m1_t *, vfloat32m1_t *, vfloat32m1_t *, vfloat32m1_t *, vbool32_t, vfloat32m1_t, vfloat32m1_t, vfloat32m1_t, vfloat32m1_t, vfloat32m1_t, vfloat32m1_t, vfloat32m1_t, const float *, vuint32m1_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vloxseg7ei32_v)))
void vloxseg7ei32(vfloat32mf2_t *, vfloat32mf2_t *, vfloat32mf2_t *, vfloat32mf2_t *, vfloat32mf2_t *, vfloat32mf2_t *, vfloat32mf2_t *, const float *, vuint32mf2_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vloxseg7ei32_v_m)))
void vloxseg7ei32(vfloat32mf2_t *, vfloat32mf2_t *, vfloat32mf2_t *, vfloat32mf2_t *, vfloat32mf2_t *, vfloat32mf2_t *, vfloat32mf2_t *, vbool64_t, vfloat32mf2_t, vfloat32mf2_t, vfloat32mf2_t, vfloat32mf2_t, vfloat32mf2_t, vfloat32mf2_t, vfloat32mf2_t, const float *, vuint32mf2_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vloxseg8ei32_v)))
void vloxseg8ei32(vfloat32m1_t *, vfloat32m1_t *, vfloat32m1_t *, vfloat32m1_t *, vfloat32m1_t *, vfloat32m1_t *, vfloat32m1_t *, vfloat32m1_t *, const float *, vuint32m1_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vloxseg8ei32_v_m)))
void vloxseg8ei32(vfloat32m1_t *, vfloat32m1_t *, vfloat32m1_t *, vfloat32m1_t *, vfloat32m1_t *, vfloat32m1_t *, vfloat32m1_t *, vfloat32m1_t *, vbool32_t, vfloat32m1_t, vfloat32m1_t, vfloat32m1_t, vfloat32m1_t, vfloat32m1_t, vfloat32m1_t, vfloat32m1_t, vfloat32m1_t, const float *, vuint32m1_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vloxseg8ei32_v)))
void vloxseg8ei32(vfloat32mf2_t *, vfloat32mf2_t *, vfloat32mf2_t *, vfloat32mf2_t *, vfloat32mf2_t *, vfloat32mf2_t *, vfloat32mf2_t *, vfloat32mf2_t *, const float *, vuint32mf2_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vloxseg8ei32_v_m)))
void vloxseg8ei32(vfloat32mf2_t *, vfloat32mf2_t *, vfloat32mf2_t *, vfloat32mf2_t *, vfloat32mf2_t *, vfloat32mf2_t *, vfloat32mf2_t *, vfloat32mf2_t *, vbool64_t, vfloat32mf2_t, vfloat32mf2_t, vfloat32mf2_t, vfloat32mf2_t, vfloat32mf2_t, vfloat32mf2_t, vfloat32mf2_t, vfloat32mf2_t, const float *, vuint32mf2_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vsseg2e32_v)))
void vsseg2e32(float *, vfloat32m1_t, vfloat32m1_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vsseg2e32_v_m)))
void vsseg2e32(vbool32_t, float *, vfloat32m1_t, vfloat32m1_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vsseg2e32_v)))
void vsseg2e32(float *, vfloat32m2_t, vfloat32m2_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vsseg2e32_v_m)))
void vsseg2e32(vbool16_t, float *, vfloat32m2_t, vfloat32m2_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vsseg2e32_v)))
void vsseg2e32(float *, vfloat32m4_t, vfloat32m4_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vsseg2e32_v_m)))
void vsseg2e32(vbool8_t, float *, vfloat32m4_t, vfloat32m4_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vsseg2e32_v)))
void vsseg2e32(float *, vfloat32mf2_t, vfloat32mf2_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vsseg2e32_v_m)))
void vsseg2e32(vbool64_t, float *, vfloat32mf2_t, vfloat32mf2_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vsseg3e32_v)))
void vsseg3e32(float *, vfloat32m1_t, vfloat32m1_t, vfloat32m1_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vsseg3e32_v_m)))
void vsseg3e32(vbool32_t, float *, vfloat32m1_t, vfloat32m1_t, vfloat32m1_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vsseg3e32_v)))
void vsseg3e32(float *, vfloat32m2_t, vfloat32m2_t, vfloat32m2_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vsseg3e32_v_m)))
void vsseg3e32(vbool16_t, float *, vfloat32m2_t, vfloat32m2_t, vfloat32m2_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vsseg3e32_v)))
void vsseg3e32(float *, vfloat32mf2_t, vfloat32mf2_t, vfloat32mf2_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vsseg3e32_v_m)))
void vsseg3e32(vbool64_t, float *, vfloat32mf2_t, vfloat32mf2_t, vfloat32mf2_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vsseg4e32_v)))
void vsseg4e32(float *, vfloat32m1_t, vfloat32m1_t, vfloat32m1_t, vfloat32m1_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vsseg4e32_v_m)))
void vsseg4e32(vbool32_t, float *, vfloat32m1_t, vfloat32m1_t, vfloat32m1_t, vfloat32m1_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vsseg4e32_v)))
void vsseg4e32(float *, vfloat32m2_t, vfloat32m2_t, vfloat32m2_t, vfloat32m2_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vsseg4e32_v_m)))
void vsseg4e32(vbool16_t, float *, vfloat32m2_t, vfloat32m2_t, vfloat32m2_t, vfloat32m2_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vsseg4e32_v)))
void vsseg4e32(float *, vfloat32mf2_t, vfloat32mf2_t, vfloat32mf2_t, vfloat32mf2_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vsseg4e32_v_m)))
void vsseg4e32(vbool64_t, float *, vfloat32mf2_t, vfloat32mf2_t, vfloat32mf2_t, vfloat32mf2_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vsseg5e32_v)))
void vsseg5e32(float *, vfloat32m1_t, vfloat32m1_t, vfloat32m1_t, vfloat32m1_t, vfloat32m1_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vsseg5e32_v_m)))
void vsseg5e32(vbool32_t, float *, vfloat32m1_t, vfloat32m1_t, vfloat32m1_t, vfloat32m1_t, vfloat32m1_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vsseg5e32_v)))
void vsseg5e32(float *, vfloat32mf2_t, vfloat32mf2_t, vfloat32mf2_t, vfloat32mf2_t, vfloat32mf2_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vsseg5e32_v_m)))
void vsseg5e32(vbool64_t, float *, vfloat32mf2_t, vfloat32mf2_t, vfloat32mf2_t, vfloat32mf2_t, vfloat32mf2_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vsseg6e32_v)))
void vsseg6e32(float *, vfloat32m1_t, vfloat32m1_t, vfloat32m1_t, vfloat32m1_t, vfloat32m1_t, vfloat32m1_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vsseg6e32_v_m)))
void vsseg6e32(vbool32_t, float *, vfloat32m1_t, vfloat32m1_t, vfloat32m1_t, vfloat32m1_t, vfloat32m1_t, vfloat32m1_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vsseg6e32_v)))
void vsseg6e32(float *, vfloat32mf2_t, vfloat32mf2_t, vfloat32mf2_t, vfloat32mf2_t, vfloat32mf2_t, vfloat32mf2_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vsseg6e32_v_m)))
void vsseg6e32(vbool64_t, float *, vfloat32mf2_t, vfloat32mf2_t, vfloat32mf2_t, vfloat32mf2_t, vfloat32mf2_t, vfloat32mf2_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vsseg7e32_v)))
void vsseg7e32(float *, vfloat32m1_t, vfloat32m1_t, vfloat32m1_t, vfloat32m1_t, vfloat32m1_t, vfloat32m1_t, vfloat32m1_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vsseg7e32_v_m)))
void vsseg7e32(vbool32_t, float *, vfloat32m1_t, vfloat32m1_t, vfloat32m1_t, vfloat32m1_t, vfloat32m1_t, vfloat32m1_t, vfloat32m1_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vsseg7e32_v)))
void vsseg7e32(float *, vfloat32mf2_t, vfloat32mf2_t, vfloat32mf2_t, vfloat32mf2_t, vfloat32mf2_t, vfloat32mf2_t, vfloat32mf2_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vsseg7e32_v_m)))
void vsseg7e32(vbool64_t, float *, vfloat32mf2_t, vfloat32mf2_t, vfloat32mf2_t, vfloat32mf2_t, vfloat32mf2_t, vfloat32mf2_t, vfloat32mf2_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vsseg8e32_v)))
void vsseg8e32(float *, vfloat32m1_t, vfloat32m1_t, vfloat32m1_t, vfloat32m1_t, vfloat32m1_t, vfloat32m1_t, vfloat32m1_t, vfloat32m1_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vsseg8e32_v_m)))
void vsseg8e32(vbool32_t, float *, vfloat32m1_t, vfloat32m1_t, vfloat32m1_t, vfloat32m1_t, vfloat32m1_t, vfloat32m1_t, vfloat32m1_t, vfloat32m1_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vsseg8e32_v)))
void vsseg8e32(float *, vfloat32mf2_t, vfloat32mf2_t, vfloat32mf2_t, vfloat32mf2_t, vfloat32mf2_t, vfloat32mf2_t, vfloat32mf2_t, vfloat32mf2_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vsseg8e32_v_m)))
void vsseg8e32(vbool64_t, float *, vfloat32mf2_t, vfloat32mf2_t, vfloat32mf2_t, vfloat32mf2_t, vfloat32mf2_t, vfloat32mf2_t, vfloat32mf2_t, vfloat32mf2_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vssseg2e32_v)))
void vssseg2e32(float *, ptrdiff_t, vfloat32m1_t, vfloat32m1_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vssseg2e32_v_m)))
void vssseg2e32(vbool32_t, float *, ptrdiff_t, vfloat32m1_t, vfloat32m1_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vssseg2e32_v)))
void vssseg2e32(float *, ptrdiff_t, vfloat32m2_t, vfloat32m2_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vssseg2e32_v_m)))
void vssseg2e32(vbool16_t, float *, ptrdiff_t, vfloat32m2_t, vfloat32m2_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vssseg2e32_v)))
void vssseg2e32(float *, ptrdiff_t, vfloat32m4_t, vfloat32m4_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vssseg2e32_v_m)))
void vssseg2e32(vbool8_t, float *, ptrdiff_t, vfloat32m4_t, vfloat32m4_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vssseg2e32_v)))
void vssseg2e32(float *, ptrdiff_t, vfloat32mf2_t, vfloat32mf2_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vssseg2e32_v_m)))
void vssseg2e32(vbool64_t, float *, ptrdiff_t, vfloat32mf2_t, vfloat32mf2_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vssseg3e32_v)))
void vssseg3e32(float *, ptrdiff_t, vfloat32m1_t, vfloat32m1_t, vfloat32m1_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vssseg3e32_v_m)))
void vssseg3e32(vbool32_t, float *, ptrdiff_t, vfloat32m1_t, vfloat32m1_t, vfloat32m1_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vssseg3e32_v)))
void vssseg3e32(float *, ptrdiff_t, vfloat32m2_t, vfloat32m2_t, vfloat32m2_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vssseg3e32_v_m)))
void vssseg3e32(vbool16_t, float *, ptrdiff_t, vfloat32m2_t, vfloat32m2_t, vfloat32m2_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vssseg3e32_v)))
void vssseg3e32(float *, ptrdiff_t, vfloat32mf2_t, vfloat32mf2_t, vfloat32mf2_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vssseg3e32_v_m)))
void vssseg3e32(vbool64_t, float *, ptrdiff_t, vfloat32mf2_t, vfloat32mf2_t, vfloat32mf2_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vssseg4e32_v)))
void vssseg4e32(float *, ptrdiff_t, vfloat32m1_t, vfloat32m1_t, vfloat32m1_t, vfloat32m1_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vssseg4e32_v_m)))
void vssseg4e32(vbool32_t, float *, ptrdiff_t, vfloat32m1_t, vfloat32m1_t, vfloat32m1_t, vfloat32m1_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vssseg4e32_v)))
void vssseg4e32(float *, ptrdiff_t, vfloat32m2_t, vfloat32m2_t, vfloat32m2_t, vfloat32m2_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vssseg4e32_v_m)))
void vssseg4e32(vbool16_t, float *, ptrdiff_t, vfloat32m2_t, vfloat32m2_t, vfloat32m2_t, vfloat32m2_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vssseg4e32_v)))
void vssseg4e32(float *, ptrdiff_t, vfloat32mf2_t, vfloat32mf2_t, vfloat32mf2_t, vfloat32mf2_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vssseg4e32_v_m)))
void vssseg4e32(vbool64_t, float *, ptrdiff_t, vfloat32mf2_t, vfloat32mf2_t, vfloat32mf2_t, vfloat32mf2_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vssseg5e32_v)))
void vssseg5e32(float *, ptrdiff_t, vfloat32m1_t, vfloat32m1_t, vfloat32m1_t, vfloat32m1_t, vfloat32m1_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vssseg5e32_v_m)))
void vssseg5e32(vbool32_t, float *, ptrdiff_t, vfloat32m1_t, vfloat32m1_t, vfloat32m1_t, vfloat32m1_t, vfloat32m1_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vssseg5e32_v)))
void vssseg5e32(float *, ptrdiff_t, vfloat32mf2_t, vfloat32mf2_t, vfloat32mf2_t, vfloat32mf2_t, vfloat32mf2_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vssseg5e32_v_m)))
void vssseg5e32(vbool64_t, float *, ptrdiff_t, vfloat32mf2_t, vfloat32mf2_t, vfloat32mf2_t, vfloat32mf2_t, vfloat32mf2_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vssseg6e32_v)))
void vssseg6e32(float *, ptrdiff_t, vfloat32m1_t, vfloat32m1_t, vfloat32m1_t, vfloat32m1_t, vfloat32m1_t, vfloat32m1_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vssseg6e32_v_m)))
void vssseg6e32(vbool32_t, float *, ptrdiff_t, vfloat32m1_t, vfloat32m1_t, vfloat32m1_t, vfloat32m1_t, vfloat32m1_t, vfloat32m1_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vssseg6e32_v)))
void vssseg6e32(float *, ptrdiff_t, vfloat32mf2_t, vfloat32mf2_t, vfloat32mf2_t, vfloat32mf2_t, vfloat32mf2_t, vfloat32mf2_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vssseg6e32_v_m)))
void vssseg6e32(vbool64_t, float *, ptrdiff_t, vfloat32mf2_t, vfloat32mf2_t, vfloat32mf2_t, vfloat32mf2_t, vfloat32mf2_t, vfloat32mf2_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vssseg7e32_v)))
void vssseg7e32(float *, ptrdiff_t, vfloat32m1_t, vfloat32m1_t, vfloat32m1_t, vfloat32m1_t, vfloat32m1_t, vfloat32m1_t, vfloat32m1_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vssseg7e32_v_m)))
void vssseg7e32(vbool32_t, float *, ptrdiff_t, vfloat32m1_t, vfloat32m1_t, vfloat32m1_t, vfloat32m1_t, vfloat32m1_t, vfloat32m1_t, vfloat32m1_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vssseg7e32_v)))
void vssseg7e32(float *, ptrdiff_t, vfloat32mf2_t, vfloat32mf2_t, vfloat32mf2_t, vfloat32mf2_t, vfloat32mf2_t, vfloat32mf2_t, vfloat32mf2_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vssseg7e32_v_m)))
void vssseg7e32(vbool64_t, float *, ptrdiff_t, vfloat32mf2_t, vfloat32mf2_t, vfloat32mf2_t, vfloat32mf2_t, vfloat32mf2_t, vfloat32mf2_t, vfloat32mf2_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vssseg8e32_v)))
void vssseg8e32(float *, ptrdiff_t, vfloat32m1_t, vfloat32m1_t, vfloat32m1_t, vfloat32m1_t, vfloat32m1_t, vfloat32m1_t, vfloat32m1_t, vfloat32m1_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vssseg8e32_v_m)))
void vssseg8e32(vbool32_t, float *, ptrdiff_t, vfloat32m1_t, vfloat32m1_t, vfloat32m1_t, vfloat32m1_t, vfloat32m1_t, vfloat32m1_t, vfloat32m1_t, vfloat32m1_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vssseg8e32_v)))
void vssseg8e32(float *, ptrdiff_t, vfloat32mf2_t, vfloat32mf2_t, vfloat32mf2_t, vfloat32mf2_t, vfloat32mf2_t, vfloat32mf2_t, vfloat32mf2_t, vfloat32mf2_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vssseg8e32_v_m)))
void vssseg8e32(vbool64_t, float *, ptrdiff_t, vfloat32mf2_t, vfloat32mf2_t, vfloat32mf2_t, vfloat32mf2_t, vfloat32mf2_t, vfloat32mf2_t, vfloat32mf2_t, vfloat32mf2_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vluxei8_v)))
vfloat32m1_t vluxei8(const float *, vuint8mf4_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vluxei8_v_m)))
vfloat32m1_t vluxei8(vbool32_t, vfloat32m1_t, const float *, vuint8mf4_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vluxei8_v)))
vfloat32m2_t vluxei8(const float *, vuint8mf2_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vluxei8_v_m)))
vfloat32m2_t vluxei8(vbool16_t, vfloat32m2_t, const float *, vuint8mf2_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vluxei8_v)))
vfloat32m4_t vluxei8(const float *, vuint8m1_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vluxei8_v_m)))
vfloat32m4_t vluxei8(vbool8_t, vfloat32m4_t, const float *, vuint8m1_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vluxei8_v)))
vfloat32m8_t vluxei8(const float *, vuint8m2_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vluxei8_v_m)))
vfloat32m8_t vluxei8(vbool4_t, vfloat32m8_t, const float *, vuint8m2_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vluxei8_v)))
vfloat32mf2_t vluxei8(const float *, vuint8mf8_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vluxei8_v_m)))
vfloat32mf2_t vluxei8(vbool64_t, vfloat32mf2_t, const float *, vuint8mf8_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vluxei16_v)))
vfloat32m1_t vluxei16(const float *, vuint16mf2_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vluxei16_v_m)))
vfloat32m1_t vluxei16(vbool32_t, vfloat32m1_t, const float *, vuint16mf2_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vluxei16_v)))
vfloat32m2_t vluxei16(const float *, vuint16m1_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vluxei16_v_m)))
vfloat32m2_t vluxei16(vbool16_t, vfloat32m2_t, const float *, vuint16m1_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vluxei16_v)))
vfloat32m4_t vluxei16(const float *, vuint16m2_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vluxei16_v_m)))
vfloat32m4_t vluxei16(vbool8_t, vfloat32m4_t, const float *, vuint16m2_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vluxei16_v)))
vfloat32m8_t vluxei16(const float *, vuint16m4_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vluxei16_v_m)))
vfloat32m8_t vluxei16(vbool4_t, vfloat32m8_t, const float *, vuint16m4_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vluxei16_v)))
vfloat32mf2_t vluxei16(const float *, vuint16mf4_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vluxei16_v_m)))
vfloat32mf2_t vluxei16(vbool64_t, vfloat32mf2_t, const float *, vuint16mf4_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vluxei32_v)))
vfloat32m1_t vluxei32(const float *, vuint32m1_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vluxei32_v_m)))
vfloat32m1_t vluxei32(vbool32_t, vfloat32m1_t, const float *, vuint32m1_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vluxei32_v)))
vfloat32m2_t vluxei32(const float *, vuint32m2_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vluxei32_v_m)))
vfloat32m2_t vluxei32(vbool16_t, vfloat32m2_t, const float *, vuint32m2_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vluxei32_v)))
vfloat32m4_t vluxei32(const float *, vuint32m4_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vluxei32_v_m)))
vfloat32m4_t vluxei32(vbool8_t, vfloat32m4_t, const float *, vuint32m4_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vluxei32_v)))
vfloat32m8_t vluxei32(const float *, vuint32m8_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vluxei32_v_m)))
vfloat32m8_t vluxei32(vbool4_t, vfloat32m8_t, const float *, vuint32m8_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vluxei32_v)))
vfloat32mf2_t vluxei32(const float *, vuint32mf2_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vluxei32_v_m)))
vfloat32mf2_t vluxei32(vbool64_t, vfloat32mf2_t, const float *, vuint32mf2_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vsuxseg2ei8_v)))
void vsuxseg2ei8(float *, vuint8mf4_t, vfloat32m1_t, vfloat32m1_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vsuxseg2ei8_v_m)))
void vsuxseg2ei8(vbool32_t, float *, vuint8mf4_t, vfloat32m1_t, vfloat32m1_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vsuxseg2ei8_v)))
void vsuxseg2ei8(float *, vuint8mf2_t, vfloat32m2_t, vfloat32m2_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vsuxseg2ei8_v_m)))
void vsuxseg2ei8(vbool16_t, float *, vuint8mf2_t, vfloat32m2_t, vfloat32m2_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vsuxseg2ei8_v)))
void vsuxseg2ei8(float *, vuint8m1_t, vfloat32m4_t, vfloat32m4_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vsuxseg2ei8_v_m)))
void vsuxseg2ei8(vbool8_t, float *, vuint8m1_t, vfloat32m4_t, vfloat32m4_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vsuxseg2ei8_v)))
void vsuxseg2ei8(float *, vuint8mf8_t, vfloat32mf2_t, vfloat32mf2_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vsuxseg2ei8_v_m)))
void vsuxseg2ei8(vbool64_t, float *, vuint8mf8_t, vfloat32mf2_t, vfloat32mf2_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vsuxseg3ei8_v)))
void vsuxseg3ei8(float *, vuint8mf4_t, vfloat32m1_t, vfloat32m1_t, vfloat32m1_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vsuxseg3ei8_v_m)))
void vsuxseg3ei8(vbool32_t, float *, vuint8mf4_t, vfloat32m1_t, vfloat32m1_t, vfloat32m1_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vsuxseg3ei8_v)))
void vsuxseg3ei8(float *, vuint8mf2_t, vfloat32m2_t, vfloat32m2_t, vfloat32m2_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vsuxseg3ei8_v_m)))
void vsuxseg3ei8(vbool16_t, float *, vuint8mf2_t, vfloat32m2_t, vfloat32m2_t, vfloat32m2_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vsuxseg3ei8_v)))
void vsuxseg3ei8(float *, vuint8mf8_t, vfloat32mf2_t, vfloat32mf2_t, vfloat32mf2_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vsuxseg3ei8_v_m)))
void vsuxseg3ei8(vbool64_t, float *, vuint8mf8_t, vfloat32mf2_t, vfloat32mf2_t, vfloat32mf2_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vsuxseg4ei8_v)))
void vsuxseg4ei8(float *, vuint8mf4_t, vfloat32m1_t, vfloat32m1_t, vfloat32m1_t, vfloat32m1_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vsuxseg4ei8_v_m)))
void vsuxseg4ei8(vbool32_t, float *, vuint8mf4_t, vfloat32m1_t, vfloat32m1_t, vfloat32m1_t, vfloat32m1_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vsuxseg4ei8_v)))
void vsuxseg4ei8(float *, vuint8mf2_t, vfloat32m2_t, vfloat32m2_t, vfloat32m2_t, vfloat32m2_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vsuxseg4ei8_v_m)))
void vsuxseg4ei8(vbool16_t, float *, vuint8mf2_t, vfloat32m2_t, vfloat32m2_t, vfloat32m2_t, vfloat32m2_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vsuxseg4ei8_v)))
void vsuxseg4ei8(float *, vuint8mf8_t, vfloat32mf2_t, vfloat32mf2_t, vfloat32mf2_t, vfloat32mf2_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vsuxseg4ei8_v_m)))
void vsuxseg4ei8(vbool64_t, float *, vuint8mf8_t, vfloat32mf2_t, vfloat32mf2_t, vfloat32mf2_t, vfloat32mf2_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vsuxseg5ei8_v)))
void vsuxseg5ei8(float *, vuint8mf4_t, vfloat32m1_t, vfloat32m1_t, vfloat32m1_t, vfloat32m1_t, vfloat32m1_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vsuxseg5ei8_v_m)))
void vsuxseg5ei8(vbool32_t, float *, vuint8mf4_t, vfloat32m1_t, vfloat32m1_t, vfloat32m1_t, vfloat32m1_t, vfloat32m1_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vsuxseg5ei8_v)))
void vsuxseg5ei8(float *, vuint8mf8_t, vfloat32mf2_t, vfloat32mf2_t, vfloat32mf2_t, vfloat32mf2_t, vfloat32mf2_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vsuxseg5ei8_v_m)))
void vsuxseg5ei8(vbool64_t, float *, vuint8mf8_t, vfloat32mf2_t, vfloat32mf2_t, vfloat32mf2_t, vfloat32mf2_t, vfloat32mf2_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vsuxseg6ei8_v)))
void vsuxseg6ei8(float *, vuint8mf4_t, vfloat32m1_t, vfloat32m1_t, vfloat32m1_t, vfloat32m1_t, vfloat32m1_t, vfloat32m1_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vsuxseg6ei8_v_m)))
void vsuxseg6ei8(vbool32_t, float *, vuint8mf4_t, vfloat32m1_t, vfloat32m1_t, vfloat32m1_t, vfloat32m1_t, vfloat32m1_t, vfloat32m1_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vsuxseg6ei8_v)))
void vsuxseg6ei8(float *, vuint8mf8_t, vfloat32mf2_t, vfloat32mf2_t, vfloat32mf2_t, vfloat32mf2_t, vfloat32mf2_t, vfloat32mf2_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vsuxseg6ei8_v_m)))
void vsuxseg6ei8(vbool64_t, float *, vuint8mf8_t, vfloat32mf2_t, vfloat32mf2_t, vfloat32mf2_t, vfloat32mf2_t, vfloat32mf2_t, vfloat32mf2_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vsuxseg7ei8_v)))
void vsuxseg7ei8(float *, vuint8mf4_t, vfloat32m1_t, vfloat32m1_t, vfloat32m1_t, vfloat32m1_t, vfloat32m1_t, vfloat32m1_t, vfloat32m1_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vsuxseg7ei8_v_m)))
void vsuxseg7ei8(vbool32_t, float *, vuint8mf4_t, vfloat32m1_t, vfloat32m1_t, vfloat32m1_t, vfloat32m1_t, vfloat32m1_t, vfloat32m1_t, vfloat32m1_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vsuxseg7ei8_v)))
void vsuxseg7ei8(float *, vuint8mf8_t, vfloat32mf2_t, vfloat32mf2_t, vfloat32mf2_t, vfloat32mf2_t, vfloat32mf2_t, vfloat32mf2_t, vfloat32mf2_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vsuxseg7ei8_v_m)))
void vsuxseg7ei8(vbool64_t, float *, vuint8mf8_t, vfloat32mf2_t, vfloat32mf2_t, vfloat32mf2_t, vfloat32mf2_t, vfloat32mf2_t, vfloat32mf2_t, vfloat32mf2_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vsuxseg8ei8_v)))
void vsuxseg8ei8(float *, vuint8mf4_t, vfloat32m1_t, vfloat32m1_t, vfloat32m1_t, vfloat32m1_t, vfloat32m1_t, vfloat32m1_t, vfloat32m1_t, vfloat32m1_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vsuxseg8ei8_v_m)))
void vsuxseg8ei8(vbool32_t, float *, vuint8mf4_t, vfloat32m1_t, vfloat32m1_t, vfloat32m1_t, vfloat32m1_t, vfloat32m1_t, vfloat32m1_t, vfloat32m1_t, vfloat32m1_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vsuxseg8ei8_v)))
void vsuxseg8ei8(float *, vuint8mf8_t, vfloat32mf2_t, vfloat32mf2_t, vfloat32mf2_t, vfloat32mf2_t, vfloat32mf2_t, vfloat32mf2_t, vfloat32mf2_t, vfloat32mf2_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vsuxseg8ei8_v_m)))
void vsuxseg8ei8(vbool64_t, float *, vuint8mf8_t, vfloat32mf2_t, vfloat32mf2_t, vfloat32mf2_t, vfloat32mf2_t, vfloat32mf2_t, vfloat32mf2_t, vfloat32mf2_t, vfloat32mf2_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vsuxseg2ei16_v)))
void vsuxseg2ei16(float *, vuint16mf2_t, vfloat32m1_t, vfloat32m1_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vsuxseg2ei16_v_m)))
void vsuxseg2ei16(vbool32_t, float *, vuint16mf2_t, vfloat32m1_t, vfloat32m1_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vsuxseg2ei16_v)))
void vsuxseg2ei16(float *, vuint16m1_t, vfloat32m2_t, vfloat32m2_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vsuxseg2ei16_v_m)))
void vsuxseg2ei16(vbool16_t, float *, vuint16m1_t, vfloat32m2_t, vfloat32m2_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vsuxseg2ei16_v)))
void vsuxseg2ei16(float *, vuint16m2_t, vfloat32m4_t, vfloat32m4_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vsuxseg2ei16_v_m)))
void vsuxseg2ei16(vbool8_t, float *, vuint16m2_t, vfloat32m4_t, vfloat32m4_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vsuxseg2ei16_v)))
void vsuxseg2ei16(float *, vuint16mf4_t, vfloat32mf2_t, vfloat32mf2_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vsuxseg2ei16_v_m)))
void vsuxseg2ei16(vbool64_t, float *, vuint16mf4_t, vfloat32mf2_t, vfloat32mf2_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vsuxseg3ei16_v)))
void vsuxseg3ei16(float *, vuint16mf2_t, vfloat32m1_t, vfloat32m1_t, vfloat32m1_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vsuxseg3ei16_v_m)))
void vsuxseg3ei16(vbool32_t, float *, vuint16mf2_t, vfloat32m1_t, vfloat32m1_t, vfloat32m1_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vsuxseg3ei16_v)))
void vsuxseg3ei16(float *, vuint16m1_t, vfloat32m2_t, vfloat32m2_t, vfloat32m2_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vsuxseg3ei16_v_m)))
void vsuxseg3ei16(vbool16_t, float *, vuint16m1_t, vfloat32m2_t, vfloat32m2_t, vfloat32m2_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vsuxseg3ei16_v)))
void vsuxseg3ei16(float *, vuint16mf4_t, vfloat32mf2_t, vfloat32mf2_t, vfloat32mf2_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vsuxseg3ei16_v_m)))
void vsuxseg3ei16(vbool64_t, float *, vuint16mf4_t, vfloat32mf2_t, vfloat32mf2_t, vfloat32mf2_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vsuxseg4ei16_v)))
void vsuxseg4ei16(float *, vuint16mf2_t, vfloat32m1_t, vfloat32m1_t, vfloat32m1_t, vfloat32m1_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vsuxseg4ei16_v_m)))
void vsuxseg4ei16(vbool32_t, float *, vuint16mf2_t, vfloat32m1_t, vfloat32m1_t, vfloat32m1_t, vfloat32m1_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vsuxseg4ei16_v)))
void vsuxseg4ei16(float *, vuint16m1_t, vfloat32m2_t, vfloat32m2_t, vfloat32m2_t, vfloat32m2_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vsuxseg4ei16_v_m)))
void vsuxseg4ei16(vbool16_t, float *, vuint16m1_t, vfloat32m2_t, vfloat32m2_t, vfloat32m2_t, vfloat32m2_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vsuxseg4ei16_v)))
void vsuxseg4ei16(float *, vuint16mf4_t, vfloat32mf2_t, vfloat32mf2_t, vfloat32mf2_t, vfloat32mf2_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vsuxseg4ei16_v_m)))
void vsuxseg4ei16(vbool64_t, float *, vuint16mf4_t, vfloat32mf2_t, vfloat32mf2_t, vfloat32mf2_t, vfloat32mf2_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vsuxseg5ei16_v)))
void vsuxseg5ei16(float *, vuint16mf2_t, vfloat32m1_t, vfloat32m1_t, vfloat32m1_t, vfloat32m1_t, vfloat32m1_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vsuxseg5ei16_v_m)))
void vsuxseg5ei16(vbool32_t, float *, vuint16mf2_t, vfloat32m1_t, vfloat32m1_t, vfloat32m1_t, vfloat32m1_t, vfloat32m1_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vsuxseg5ei16_v)))
void vsuxseg5ei16(float *, vuint16mf4_t, vfloat32mf2_t, vfloat32mf2_t, vfloat32mf2_t, vfloat32mf2_t, vfloat32mf2_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vsuxseg5ei16_v_m)))
void vsuxseg5ei16(vbool64_t, float *, vuint16mf4_t, vfloat32mf2_t, vfloat32mf2_t, vfloat32mf2_t, vfloat32mf2_t, vfloat32mf2_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vsuxseg6ei16_v)))
void vsuxseg6ei16(float *, vuint16mf2_t, vfloat32m1_t, vfloat32m1_t, vfloat32m1_t, vfloat32m1_t, vfloat32m1_t, vfloat32m1_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vsuxseg6ei16_v_m)))
void vsuxseg6ei16(vbool32_t, float *, vuint16mf2_t, vfloat32m1_t, vfloat32m1_t, vfloat32m1_t, vfloat32m1_t, vfloat32m1_t, vfloat32m1_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vsuxseg6ei16_v)))
void vsuxseg6ei16(float *, vuint16mf4_t, vfloat32mf2_t, vfloat32mf2_t, vfloat32mf2_t, vfloat32mf2_t, vfloat32mf2_t, vfloat32mf2_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vsuxseg6ei16_v_m)))
void vsuxseg6ei16(vbool64_t, float *, vuint16mf4_t, vfloat32mf2_t, vfloat32mf2_t, vfloat32mf2_t, vfloat32mf2_t, vfloat32mf2_t, vfloat32mf2_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vsuxseg7ei16_v)))
void vsuxseg7ei16(float *, vuint16mf2_t, vfloat32m1_t, vfloat32m1_t, vfloat32m1_t, vfloat32m1_t, vfloat32m1_t, vfloat32m1_t, vfloat32m1_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vsuxseg7ei16_v_m)))
void vsuxseg7ei16(vbool32_t, float *, vuint16mf2_t, vfloat32m1_t, vfloat32m1_t, vfloat32m1_t, vfloat32m1_t, vfloat32m1_t, vfloat32m1_t, vfloat32m1_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vsuxseg7ei16_v)))
void vsuxseg7ei16(float *, vuint16mf4_t, vfloat32mf2_t, vfloat32mf2_t, vfloat32mf2_t, vfloat32mf2_t, vfloat32mf2_t, vfloat32mf2_t, vfloat32mf2_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vsuxseg7ei16_v_m)))
void vsuxseg7ei16(vbool64_t, float *, vuint16mf4_t, vfloat32mf2_t, vfloat32mf2_t, vfloat32mf2_t, vfloat32mf2_t, vfloat32mf2_t, vfloat32mf2_t, vfloat32mf2_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vsuxseg8ei16_v)))
void vsuxseg8ei16(float *, vuint16mf2_t, vfloat32m1_t, vfloat32m1_t, vfloat32m1_t, vfloat32m1_t, vfloat32m1_t, vfloat32m1_t, vfloat32m1_t, vfloat32m1_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vsuxseg8ei16_v_m)))
void vsuxseg8ei16(vbool32_t, float *, vuint16mf2_t, vfloat32m1_t, vfloat32m1_t, vfloat32m1_t, vfloat32m1_t, vfloat32m1_t, vfloat32m1_t, vfloat32m1_t, vfloat32m1_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vsuxseg8ei16_v)))
void vsuxseg8ei16(float *, vuint16mf4_t, vfloat32mf2_t, vfloat32mf2_t, vfloat32mf2_t, vfloat32mf2_t, vfloat32mf2_t, vfloat32mf2_t, vfloat32mf2_t, vfloat32mf2_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vsuxseg8ei16_v_m)))
void vsuxseg8ei16(vbool64_t, float *, vuint16mf4_t, vfloat32mf2_t, vfloat32mf2_t, vfloat32mf2_t, vfloat32mf2_t, vfloat32mf2_t, vfloat32mf2_t, vfloat32mf2_t, vfloat32mf2_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vsuxseg2ei32_v)))
void vsuxseg2ei32(float *, vuint32m1_t, vfloat32m1_t, vfloat32m1_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vsuxseg2ei32_v_m)))
void vsuxseg2ei32(vbool32_t, float *, vuint32m1_t, vfloat32m1_t, vfloat32m1_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vsuxseg2ei32_v)))
void vsuxseg2ei32(float *, vuint32m2_t, vfloat32m2_t, vfloat32m2_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vsuxseg2ei32_v_m)))
void vsuxseg2ei32(vbool16_t, float *, vuint32m2_t, vfloat32m2_t, vfloat32m2_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vsuxseg2ei32_v)))
void vsuxseg2ei32(float *, vuint32m4_t, vfloat32m4_t, vfloat32m4_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vsuxseg2ei32_v_m)))
void vsuxseg2ei32(vbool8_t, float *, vuint32m4_t, vfloat32m4_t, vfloat32m4_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vsuxseg2ei32_v)))
void vsuxseg2ei32(float *, vuint32mf2_t, vfloat32mf2_t, vfloat32mf2_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vsuxseg2ei32_v_m)))
void vsuxseg2ei32(vbool64_t, float *, vuint32mf2_t, vfloat32mf2_t, vfloat32mf2_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vsuxseg3ei32_v)))
void vsuxseg3ei32(float *, vuint32m1_t, vfloat32m1_t, vfloat32m1_t, vfloat32m1_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vsuxseg3ei32_v_m)))
void vsuxseg3ei32(vbool32_t, float *, vuint32m1_t, vfloat32m1_t, vfloat32m1_t, vfloat32m1_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vsuxseg3ei32_v)))
void vsuxseg3ei32(float *, vuint32m2_t, vfloat32m2_t, vfloat32m2_t, vfloat32m2_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vsuxseg3ei32_v_m)))
void vsuxseg3ei32(vbool16_t, float *, vuint32m2_t, vfloat32m2_t, vfloat32m2_t, vfloat32m2_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vsuxseg3ei32_v)))
void vsuxseg3ei32(float *, vuint32mf2_t, vfloat32mf2_t, vfloat32mf2_t, vfloat32mf2_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vsuxseg3ei32_v_m)))
void vsuxseg3ei32(vbool64_t, float *, vuint32mf2_t, vfloat32mf2_t, vfloat32mf2_t, vfloat32mf2_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vsuxseg4ei32_v)))
void vsuxseg4ei32(float *, vuint32m1_t, vfloat32m1_t, vfloat32m1_t, vfloat32m1_t, vfloat32m1_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vsuxseg4ei32_v_m)))
void vsuxseg4ei32(vbool32_t, float *, vuint32m1_t, vfloat32m1_t, vfloat32m1_t, vfloat32m1_t, vfloat32m1_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vsuxseg4ei32_v)))
void vsuxseg4ei32(float *, vuint32m2_t, vfloat32m2_t, vfloat32m2_t, vfloat32m2_t, vfloat32m2_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vsuxseg4ei32_v_m)))
void vsuxseg4ei32(vbool16_t, float *, vuint32m2_t, vfloat32m2_t, vfloat32m2_t, vfloat32m2_t, vfloat32m2_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vsuxseg4ei32_v)))
void vsuxseg4ei32(float *, vuint32mf2_t, vfloat32mf2_t, vfloat32mf2_t, vfloat32mf2_t, vfloat32mf2_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vsuxseg4ei32_v_m)))
void vsuxseg4ei32(vbool64_t, float *, vuint32mf2_t, vfloat32mf2_t, vfloat32mf2_t, vfloat32mf2_t, vfloat32mf2_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vsuxseg5ei32_v)))
void vsuxseg5ei32(float *, vuint32m1_t, vfloat32m1_t, vfloat32m1_t, vfloat32m1_t, vfloat32m1_t, vfloat32m1_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vsuxseg5ei32_v_m)))
void vsuxseg5ei32(vbool32_t, float *, vuint32m1_t, vfloat32m1_t, vfloat32m1_t, vfloat32m1_t, vfloat32m1_t, vfloat32m1_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vsuxseg5ei32_v)))
void vsuxseg5ei32(float *, vuint32mf2_t, vfloat32mf2_t, vfloat32mf2_t, vfloat32mf2_t, vfloat32mf2_t, vfloat32mf2_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vsuxseg5ei32_v_m)))
void vsuxseg5ei32(vbool64_t, float *, vuint32mf2_t, vfloat32mf2_t, vfloat32mf2_t, vfloat32mf2_t, vfloat32mf2_t, vfloat32mf2_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vsuxseg6ei32_v)))
void vsuxseg6ei32(float *, vuint32m1_t, vfloat32m1_t, vfloat32m1_t, vfloat32m1_t, vfloat32m1_t, vfloat32m1_t, vfloat32m1_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vsuxseg6ei32_v_m)))
void vsuxseg6ei32(vbool32_t, float *, vuint32m1_t, vfloat32m1_t, vfloat32m1_t, vfloat32m1_t, vfloat32m1_t, vfloat32m1_t, vfloat32m1_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vsuxseg6ei32_v)))
void vsuxseg6ei32(float *, vuint32mf2_t, vfloat32mf2_t, vfloat32mf2_t, vfloat32mf2_t, vfloat32mf2_t, vfloat32mf2_t, vfloat32mf2_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vsuxseg6ei32_v_m)))
void vsuxseg6ei32(vbool64_t, float *, vuint32mf2_t, vfloat32mf2_t, vfloat32mf2_t, vfloat32mf2_t, vfloat32mf2_t, vfloat32mf2_t, vfloat32mf2_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vsuxseg7ei32_v)))
void vsuxseg7ei32(float *, vuint32m1_t, vfloat32m1_t, vfloat32m1_t, vfloat32m1_t, vfloat32m1_t, vfloat32m1_t, vfloat32m1_t, vfloat32m1_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vsuxseg7ei32_v_m)))
void vsuxseg7ei32(vbool32_t, float *, vuint32m1_t, vfloat32m1_t, vfloat32m1_t, vfloat32m1_t, vfloat32m1_t, vfloat32m1_t, vfloat32m1_t, vfloat32m1_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vsuxseg7ei32_v)))
void vsuxseg7ei32(float *, vuint32mf2_t, vfloat32mf2_t, vfloat32mf2_t, vfloat32mf2_t, vfloat32mf2_t, vfloat32mf2_t, vfloat32mf2_t, vfloat32mf2_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vsuxseg7ei32_v_m)))
void vsuxseg7ei32(vbool64_t, float *, vuint32mf2_t, vfloat32mf2_t, vfloat32mf2_t, vfloat32mf2_t, vfloat32mf2_t, vfloat32mf2_t, vfloat32mf2_t, vfloat32mf2_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vsuxseg8ei32_v)))
void vsuxseg8ei32(float *, vuint32m1_t, vfloat32m1_t, vfloat32m1_t, vfloat32m1_t, vfloat32m1_t, vfloat32m1_t, vfloat32m1_t, vfloat32m1_t, vfloat32m1_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vsuxseg8ei32_v_m)))
void vsuxseg8ei32(vbool32_t, float *, vuint32m1_t, vfloat32m1_t, vfloat32m1_t, vfloat32m1_t, vfloat32m1_t, vfloat32m1_t, vfloat32m1_t, vfloat32m1_t, vfloat32m1_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vsuxseg8ei32_v)))
void vsuxseg8ei32(float *, vuint32mf2_t, vfloat32mf2_t, vfloat32mf2_t, vfloat32mf2_t, vfloat32mf2_t, vfloat32mf2_t, vfloat32mf2_t, vfloat32mf2_t, vfloat32mf2_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vsuxseg8ei32_v_m)))
void vsuxseg8ei32(vbool64_t, float *, vuint32mf2_t, vfloat32mf2_t, vfloat32mf2_t, vfloat32mf2_t, vfloat32mf2_t, vfloat32mf2_t, vfloat32mf2_t, vfloat32mf2_t, vfloat32mf2_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vsoxseg2ei8_v)))
void vsoxseg2ei8(float *, vuint8mf4_t, vfloat32m1_t, vfloat32m1_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vsoxseg2ei8_v_m)))
void vsoxseg2ei8(vbool32_t, float *, vuint8mf4_t, vfloat32m1_t, vfloat32m1_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vsoxseg2ei8_v)))
void vsoxseg2ei8(float *, vuint8mf2_t, vfloat32m2_t, vfloat32m2_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vsoxseg2ei8_v_m)))
void vsoxseg2ei8(vbool16_t, float *, vuint8mf2_t, vfloat32m2_t, vfloat32m2_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vsoxseg2ei8_v)))
void vsoxseg2ei8(float *, vuint8m1_t, vfloat32m4_t, vfloat32m4_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vsoxseg2ei8_v_m)))
void vsoxseg2ei8(vbool8_t, float *, vuint8m1_t, vfloat32m4_t, vfloat32m4_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vsoxseg2ei8_v)))
void vsoxseg2ei8(float *, vuint8mf8_t, vfloat32mf2_t, vfloat32mf2_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vsoxseg2ei8_v_m)))
void vsoxseg2ei8(vbool64_t, float *, vuint8mf8_t, vfloat32mf2_t, vfloat32mf2_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vsoxseg3ei8_v)))
void vsoxseg3ei8(float *, vuint8mf4_t, vfloat32m1_t, vfloat32m1_t, vfloat32m1_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vsoxseg3ei8_v_m)))
void vsoxseg3ei8(vbool32_t, float *, vuint8mf4_t, vfloat32m1_t, vfloat32m1_t, vfloat32m1_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vsoxseg3ei8_v)))
void vsoxseg3ei8(float *, vuint8mf2_t, vfloat32m2_t, vfloat32m2_t, vfloat32m2_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vsoxseg3ei8_v_m)))
void vsoxseg3ei8(vbool16_t, float *, vuint8mf2_t, vfloat32m2_t, vfloat32m2_t, vfloat32m2_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vsoxseg3ei8_v)))
void vsoxseg3ei8(float *, vuint8mf8_t, vfloat32mf2_t, vfloat32mf2_t, vfloat32mf2_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vsoxseg3ei8_v_m)))
void vsoxseg3ei8(vbool64_t, float *, vuint8mf8_t, vfloat32mf2_t, vfloat32mf2_t, vfloat32mf2_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vsoxseg4ei8_v)))
void vsoxseg4ei8(float *, vuint8mf4_t, vfloat32m1_t, vfloat32m1_t, vfloat32m1_t, vfloat32m1_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vsoxseg4ei8_v_m)))
void vsoxseg4ei8(vbool32_t, float *, vuint8mf4_t, vfloat32m1_t, vfloat32m1_t, vfloat32m1_t, vfloat32m1_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vsoxseg4ei8_v)))
void vsoxseg4ei8(float *, vuint8mf2_t, vfloat32m2_t, vfloat32m2_t, vfloat32m2_t, vfloat32m2_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vsoxseg4ei8_v_m)))
void vsoxseg4ei8(vbool16_t, float *, vuint8mf2_t, vfloat32m2_t, vfloat32m2_t, vfloat32m2_t, vfloat32m2_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vsoxseg4ei8_v)))
void vsoxseg4ei8(float *, vuint8mf8_t, vfloat32mf2_t, vfloat32mf2_t, vfloat32mf2_t, vfloat32mf2_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vsoxseg4ei8_v_m)))
void vsoxseg4ei8(vbool64_t, float *, vuint8mf8_t, vfloat32mf2_t, vfloat32mf2_t, vfloat32mf2_t, vfloat32mf2_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vsoxseg5ei8_v)))
void vsoxseg5ei8(float *, vuint8mf4_t, vfloat32m1_t, vfloat32m1_t, vfloat32m1_t, vfloat32m1_t, vfloat32m1_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vsoxseg5ei8_v_m)))
void vsoxseg5ei8(vbool32_t, float *, vuint8mf4_t, vfloat32m1_t, vfloat32m1_t, vfloat32m1_t, vfloat32m1_t, vfloat32m1_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vsoxseg5ei8_v)))
void vsoxseg5ei8(float *, vuint8mf8_t, vfloat32mf2_t, vfloat32mf2_t, vfloat32mf2_t, vfloat32mf2_t, vfloat32mf2_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vsoxseg5ei8_v_m)))
void vsoxseg5ei8(vbool64_t, float *, vuint8mf8_t, vfloat32mf2_t, vfloat32mf2_t, vfloat32mf2_t, vfloat32mf2_t, vfloat32mf2_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vsoxseg6ei8_v)))
void vsoxseg6ei8(float *, vuint8mf4_t, vfloat32m1_t, vfloat32m1_t, vfloat32m1_t, vfloat32m1_t, vfloat32m1_t, vfloat32m1_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vsoxseg6ei8_v_m)))
void vsoxseg6ei8(vbool32_t, float *, vuint8mf4_t, vfloat32m1_t, vfloat32m1_t, vfloat32m1_t, vfloat32m1_t, vfloat32m1_t, vfloat32m1_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vsoxseg6ei8_v)))
void vsoxseg6ei8(float *, vuint8mf8_t, vfloat32mf2_t, vfloat32mf2_t, vfloat32mf2_t, vfloat32mf2_t, vfloat32mf2_t, vfloat32mf2_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vsoxseg6ei8_v_m)))
void vsoxseg6ei8(vbool64_t, float *, vuint8mf8_t, vfloat32mf2_t, vfloat32mf2_t, vfloat32mf2_t, vfloat32mf2_t, vfloat32mf2_t, vfloat32mf2_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vsoxseg7ei8_v)))
void vsoxseg7ei8(float *, vuint8mf4_t, vfloat32m1_t, vfloat32m1_t, vfloat32m1_t, vfloat32m1_t, vfloat32m1_t, vfloat32m1_t, vfloat32m1_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vsoxseg7ei8_v_m)))
void vsoxseg7ei8(vbool32_t, float *, vuint8mf4_t, vfloat32m1_t, vfloat32m1_t, vfloat32m1_t, vfloat32m1_t, vfloat32m1_t, vfloat32m1_t, vfloat32m1_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vsoxseg7ei8_v)))
void vsoxseg7ei8(float *, vuint8mf8_t, vfloat32mf2_t, vfloat32mf2_t, vfloat32mf2_t, vfloat32mf2_t, vfloat32mf2_t, vfloat32mf2_t, vfloat32mf2_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vsoxseg7ei8_v_m)))
void vsoxseg7ei8(vbool64_t, float *, vuint8mf8_t, vfloat32mf2_t, vfloat32mf2_t, vfloat32mf2_t, vfloat32mf2_t, vfloat32mf2_t, vfloat32mf2_t, vfloat32mf2_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vsoxseg8ei8_v)))
void vsoxseg8ei8(float *, vuint8mf4_t, vfloat32m1_t, vfloat32m1_t, vfloat32m1_t, vfloat32m1_t, vfloat32m1_t, vfloat32m1_t, vfloat32m1_t, vfloat32m1_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vsoxseg8ei8_v_m)))
void vsoxseg8ei8(vbool32_t, float *, vuint8mf4_t, vfloat32m1_t, vfloat32m1_t, vfloat32m1_t, vfloat32m1_t, vfloat32m1_t, vfloat32m1_t, vfloat32m1_t, vfloat32m1_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vsoxseg8ei8_v)))
void vsoxseg8ei8(float *, vuint8mf8_t, vfloat32mf2_t, vfloat32mf2_t, vfloat32mf2_t, vfloat32mf2_t, vfloat32mf2_t, vfloat32mf2_t, vfloat32mf2_t, vfloat32mf2_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vsoxseg8ei8_v_m)))
void vsoxseg8ei8(vbool64_t, float *, vuint8mf8_t, vfloat32mf2_t, vfloat32mf2_t, vfloat32mf2_t, vfloat32mf2_t, vfloat32mf2_t, vfloat32mf2_t, vfloat32mf2_t, vfloat32mf2_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vsoxseg2ei16_v)))
void vsoxseg2ei16(float *, vuint16mf2_t, vfloat32m1_t, vfloat32m1_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vsoxseg2ei16_v_m)))
void vsoxseg2ei16(vbool32_t, float *, vuint16mf2_t, vfloat32m1_t, vfloat32m1_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vsoxseg2ei16_v)))
void vsoxseg2ei16(float *, vuint16m1_t, vfloat32m2_t, vfloat32m2_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vsoxseg2ei16_v_m)))
void vsoxseg2ei16(vbool16_t, float *, vuint16m1_t, vfloat32m2_t, vfloat32m2_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vsoxseg2ei16_v)))
void vsoxseg2ei16(float *, vuint16m2_t, vfloat32m4_t, vfloat32m4_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vsoxseg2ei16_v_m)))
void vsoxseg2ei16(vbool8_t, float *, vuint16m2_t, vfloat32m4_t, vfloat32m4_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vsoxseg2ei16_v)))
void vsoxseg2ei16(float *, vuint16mf4_t, vfloat32mf2_t, vfloat32mf2_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vsoxseg2ei16_v_m)))
void vsoxseg2ei16(vbool64_t, float *, vuint16mf4_t, vfloat32mf2_t, vfloat32mf2_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vsoxseg3ei16_v)))
void vsoxseg3ei16(float *, vuint16mf2_t, vfloat32m1_t, vfloat32m1_t, vfloat32m1_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vsoxseg3ei16_v_m)))
void vsoxseg3ei16(vbool32_t, float *, vuint16mf2_t, vfloat32m1_t, vfloat32m1_t, vfloat32m1_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vsoxseg3ei16_v)))
void vsoxseg3ei16(float *, vuint16m1_t, vfloat32m2_t, vfloat32m2_t, vfloat32m2_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vsoxseg3ei16_v_m)))
void vsoxseg3ei16(vbool16_t, float *, vuint16m1_t, vfloat32m2_t, vfloat32m2_t, vfloat32m2_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vsoxseg3ei16_v)))
void vsoxseg3ei16(float *, vuint16mf4_t, vfloat32mf2_t, vfloat32mf2_t, vfloat32mf2_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vsoxseg3ei16_v_m)))
void vsoxseg3ei16(vbool64_t, float *, vuint16mf4_t, vfloat32mf2_t, vfloat32mf2_t, vfloat32mf2_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vsoxseg4ei16_v)))
void vsoxseg4ei16(float *, vuint16mf2_t, vfloat32m1_t, vfloat32m1_t, vfloat32m1_t, vfloat32m1_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vsoxseg4ei16_v_m)))
void vsoxseg4ei16(vbool32_t, float *, vuint16mf2_t, vfloat32m1_t, vfloat32m1_t, vfloat32m1_t, vfloat32m1_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vsoxseg4ei16_v)))
void vsoxseg4ei16(float *, vuint16m1_t, vfloat32m2_t, vfloat32m2_t, vfloat32m2_t, vfloat32m2_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vsoxseg4ei16_v_m)))
void vsoxseg4ei16(vbool16_t, float *, vuint16m1_t, vfloat32m2_t, vfloat32m2_t, vfloat32m2_t, vfloat32m2_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vsoxseg4ei16_v)))
void vsoxseg4ei16(float *, vuint16mf4_t, vfloat32mf2_t, vfloat32mf2_t, vfloat32mf2_t, vfloat32mf2_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vsoxseg4ei16_v_m)))
void vsoxseg4ei16(vbool64_t, float *, vuint16mf4_t, vfloat32mf2_t, vfloat32mf2_t, vfloat32mf2_t, vfloat32mf2_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vsoxseg5ei16_v)))
void vsoxseg5ei16(float *, vuint16mf2_t, vfloat32m1_t, vfloat32m1_t, vfloat32m1_t, vfloat32m1_t, vfloat32m1_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vsoxseg5ei16_v_m)))
void vsoxseg5ei16(vbool32_t, float *, vuint16mf2_t, vfloat32m1_t, vfloat32m1_t, vfloat32m1_t, vfloat32m1_t, vfloat32m1_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vsoxseg5ei16_v)))
void vsoxseg5ei16(float *, vuint16mf4_t, vfloat32mf2_t, vfloat32mf2_t, vfloat32mf2_t, vfloat32mf2_t, vfloat32mf2_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vsoxseg5ei16_v_m)))
void vsoxseg5ei16(vbool64_t, float *, vuint16mf4_t, vfloat32mf2_t, vfloat32mf2_t, vfloat32mf2_t, vfloat32mf2_t, vfloat32mf2_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vsoxseg6ei16_v)))
void vsoxseg6ei16(float *, vuint16mf2_t, vfloat32m1_t, vfloat32m1_t, vfloat32m1_t, vfloat32m1_t, vfloat32m1_t, vfloat32m1_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vsoxseg6ei16_v_m)))
void vsoxseg6ei16(vbool32_t, float *, vuint16mf2_t, vfloat32m1_t, vfloat32m1_t, vfloat32m1_t, vfloat32m1_t, vfloat32m1_t, vfloat32m1_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vsoxseg6ei16_v)))
void vsoxseg6ei16(float *, vuint16mf4_t, vfloat32mf2_t, vfloat32mf2_t, vfloat32mf2_t, vfloat32mf2_t, vfloat32mf2_t, vfloat32mf2_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vsoxseg6ei16_v_m)))
void vsoxseg6ei16(vbool64_t, float *, vuint16mf4_t, vfloat32mf2_t, vfloat32mf2_t, vfloat32mf2_t, vfloat32mf2_t, vfloat32mf2_t, vfloat32mf2_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vsoxseg7ei16_v)))
void vsoxseg7ei16(float *, vuint16mf2_t, vfloat32m1_t, vfloat32m1_t, vfloat32m1_t, vfloat32m1_t, vfloat32m1_t, vfloat32m1_t, vfloat32m1_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vsoxseg7ei16_v_m)))
void vsoxseg7ei16(vbool32_t, float *, vuint16mf2_t, vfloat32m1_t, vfloat32m1_t, vfloat32m1_t, vfloat32m1_t, vfloat32m1_t, vfloat32m1_t, vfloat32m1_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vsoxseg7ei16_v)))
void vsoxseg7ei16(float *, vuint16mf4_t, vfloat32mf2_t, vfloat32mf2_t, vfloat32mf2_t, vfloat32mf2_t, vfloat32mf2_t, vfloat32mf2_t, vfloat32mf2_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vsoxseg7ei16_v_m)))
void vsoxseg7ei16(vbool64_t, float *, vuint16mf4_t, vfloat32mf2_t, vfloat32mf2_t, vfloat32mf2_t, vfloat32mf2_t, vfloat32mf2_t, vfloat32mf2_t, vfloat32mf2_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vsoxseg8ei16_v)))
void vsoxseg8ei16(float *, vuint16mf2_t, vfloat32m1_t, vfloat32m1_t, vfloat32m1_t, vfloat32m1_t, vfloat32m1_t, vfloat32m1_t, vfloat32m1_t, vfloat32m1_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vsoxseg8ei16_v_m)))
void vsoxseg8ei16(vbool32_t, float *, vuint16mf2_t, vfloat32m1_t, vfloat32m1_t, vfloat32m1_t, vfloat32m1_t, vfloat32m1_t, vfloat32m1_t, vfloat32m1_t, vfloat32m1_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vsoxseg8ei16_v)))
void vsoxseg8ei16(float *, vuint16mf4_t, vfloat32mf2_t, vfloat32mf2_t, vfloat32mf2_t, vfloat32mf2_t, vfloat32mf2_t, vfloat32mf2_t, vfloat32mf2_t, vfloat32mf2_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vsoxseg8ei16_v_m)))
void vsoxseg8ei16(vbool64_t, float *, vuint16mf4_t, vfloat32mf2_t, vfloat32mf2_t, vfloat32mf2_t, vfloat32mf2_t, vfloat32mf2_t, vfloat32mf2_t, vfloat32mf2_t, vfloat32mf2_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vsoxseg2ei32_v)))
void vsoxseg2ei32(float *, vuint32m1_t, vfloat32m1_t, vfloat32m1_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vsoxseg2ei32_v_m)))
void vsoxseg2ei32(vbool32_t, float *, vuint32m1_t, vfloat32m1_t, vfloat32m1_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vsoxseg2ei32_v)))
void vsoxseg2ei32(float *, vuint32m2_t, vfloat32m2_t, vfloat32m2_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vsoxseg2ei32_v_m)))
void vsoxseg2ei32(vbool16_t, float *, vuint32m2_t, vfloat32m2_t, vfloat32m2_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vsoxseg2ei32_v)))
void vsoxseg2ei32(float *, vuint32m4_t, vfloat32m4_t, vfloat32m4_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vsoxseg2ei32_v_m)))
void vsoxseg2ei32(vbool8_t, float *, vuint32m4_t, vfloat32m4_t, vfloat32m4_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vsoxseg2ei32_v)))
void vsoxseg2ei32(float *, vuint32mf2_t, vfloat32mf2_t, vfloat32mf2_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vsoxseg2ei32_v_m)))
void vsoxseg2ei32(vbool64_t, float *, vuint32mf2_t, vfloat32mf2_t, vfloat32mf2_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vsoxseg3ei32_v)))
void vsoxseg3ei32(float *, vuint32m1_t, vfloat32m1_t, vfloat32m1_t, vfloat32m1_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vsoxseg3ei32_v_m)))
void vsoxseg3ei32(vbool32_t, float *, vuint32m1_t, vfloat32m1_t, vfloat32m1_t, vfloat32m1_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vsoxseg3ei32_v)))
void vsoxseg3ei32(float *, vuint32m2_t, vfloat32m2_t, vfloat32m2_t, vfloat32m2_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vsoxseg3ei32_v_m)))
void vsoxseg3ei32(vbool16_t, float *, vuint32m2_t, vfloat32m2_t, vfloat32m2_t, vfloat32m2_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vsoxseg3ei32_v)))
void vsoxseg3ei32(float *, vuint32mf2_t, vfloat32mf2_t, vfloat32mf2_t, vfloat32mf2_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vsoxseg3ei32_v_m)))
void vsoxseg3ei32(vbool64_t, float *, vuint32mf2_t, vfloat32mf2_t, vfloat32mf2_t, vfloat32mf2_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vsoxseg4ei32_v)))
void vsoxseg4ei32(float *, vuint32m1_t, vfloat32m1_t, vfloat32m1_t, vfloat32m1_t, vfloat32m1_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vsoxseg4ei32_v_m)))
void vsoxseg4ei32(vbool32_t, float *, vuint32m1_t, vfloat32m1_t, vfloat32m1_t, vfloat32m1_t, vfloat32m1_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vsoxseg4ei32_v)))
void vsoxseg4ei32(float *, vuint32m2_t, vfloat32m2_t, vfloat32m2_t, vfloat32m2_t, vfloat32m2_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vsoxseg4ei32_v_m)))
void vsoxseg4ei32(vbool16_t, float *, vuint32m2_t, vfloat32m2_t, vfloat32m2_t, vfloat32m2_t, vfloat32m2_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vsoxseg4ei32_v)))
void vsoxseg4ei32(float *, vuint32mf2_t, vfloat32mf2_t, vfloat32mf2_t, vfloat32mf2_t, vfloat32mf2_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vsoxseg4ei32_v_m)))
void vsoxseg4ei32(vbool64_t, float *, vuint32mf2_t, vfloat32mf2_t, vfloat32mf2_t, vfloat32mf2_t, vfloat32mf2_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vsoxseg5ei32_v)))
void vsoxseg5ei32(float *, vuint32m1_t, vfloat32m1_t, vfloat32m1_t, vfloat32m1_t, vfloat32m1_t, vfloat32m1_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vsoxseg5ei32_v_m)))
void vsoxseg5ei32(vbool32_t, float *, vuint32m1_t, vfloat32m1_t, vfloat32m1_t, vfloat32m1_t, vfloat32m1_t, vfloat32m1_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vsoxseg5ei32_v)))
void vsoxseg5ei32(float *, vuint32mf2_t, vfloat32mf2_t, vfloat32mf2_t, vfloat32mf2_t, vfloat32mf2_t, vfloat32mf2_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vsoxseg5ei32_v_m)))
void vsoxseg5ei32(vbool64_t, float *, vuint32mf2_t, vfloat32mf2_t, vfloat32mf2_t, vfloat32mf2_t, vfloat32mf2_t, vfloat32mf2_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vsoxseg6ei32_v)))
void vsoxseg6ei32(float *, vuint32m1_t, vfloat32m1_t, vfloat32m1_t, vfloat32m1_t, vfloat32m1_t, vfloat32m1_t, vfloat32m1_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vsoxseg6ei32_v_m)))
void vsoxseg6ei32(vbool32_t, float *, vuint32m1_t, vfloat32m1_t, vfloat32m1_t, vfloat32m1_t, vfloat32m1_t, vfloat32m1_t, vfloat32m1_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vsoxseg6ei32_v)))
void vsoxseg6ei32(float *, vuint32mf2_t, vfloat32mf2_t, vfloat32mf2_t, vfloat32mf2_t, vfloat32mf2_t, vfloat32mf2_t, vfloat32mf2_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vsoxseg6ei32_v_m)))
void vsoxseg6ei32(vbool64_t, float *, vuint32mf2_t, vfloat32mf2_t, vfloat32mf2_t, vfloat32mf2_t, vfloat32mf2_t, vfloat32mf2_t, vfloat32mf2_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vsoxseg7ei32_v)))
void vsoxseg7ei32(float *, vuint32m1_t, vfloat32m1_t, vfloat32m1_t, vfloat32m1_t, vfloat32m1_t, vfloat32m1_t, vfloat32m1_t, vfloat32m1_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vsoxseg7ei32_v_m)))
void vsoxseg7ei32(vbool32_t, float *, vuint32m1_t, vfloat32m1_t, vfloat32m1_t, vfloat32m1_t, vfloat32m1_t, vfloat32m1_t, vfloat32m1_t, vfloat32m1_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vsoxseg7ei32_v)))
void vsoxseg7ei32(float *, vuint32mf2_t, vfloat32mf2_t, vfloat32mf2_t, vfloat32mf2_t, vfloat32mf2_t, vfloat32mf2_t, vfloat32mf2_t, vfloat32mf2_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vsoxseg7ei32_v_m)))
void vsoxseg7ei32(vbool64_t, float *, vuint32mf2_t, vfloat32mf2_t, vfloat32mf2_t, vfloat32mf2_t, vfloat32mf2_t, vfloat32mf2_t, vfloat32mf2_t, vfloat32mf2_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vsoxseg8ei32_v)))
void vsoxseg8ei32(float *, vuint32m1_t, vfloat32m1_t, vfloat32m1_t, vfloat32m1_t, vfloat32m1_t, vfloat32m1_t, vfloat32m1_t, vfloat32m1_t, vfloat32m1_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vsoxseg8ei32_v_m)))
void vsoxseg8ei32(vbool32_t, float *, vuint32m1_t, vfloat32m1_t, vfloat32m1_t, vfloat32m1_t, vfloat32m1_t, vfloat32m1_t, vfloat32m1_t, vfloat32m1_t, vfloat32m1_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vsoxseg8ei32_v)))
void vsoxseg8ei32(float *, vuint32mf2_t, vfloat32mf2_t, vfloat32mf2_t, vfloat32mf2_t, vfloat32mf2_t, vfloat32mf2_t, vfloat32mf2_t, vfloat32mf2_t, vfloat32mf2_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vsoxseg8ei32_v_m)))
void vsoxseg8ei32(vbool64_t, float *, vuint32mf2_t, vfloat32mf2_t, vfloat32mf2_t, vfloat32mf2_t, vfloat32mf2_t, vfloat32mf2_t, vfloat32mf2_t, vfloat32mf2_t, vfloat32mf2_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vloxei8_v)))
vfloat32m1_t vloxei8(const float *, vuint8mf4_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vloxei8_v_m)))
vfloat32m1_t vloxei8(vbool32_t, vfloat32m1_t, const float *, vuint8mf4_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vloxei8_v)))
vfloat32m2_t vloxei8(const float *, vuint8mf2_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vloxei8_v_m)))
vfloat32m2_t vloxei8(vbool16_t, vfloat32m2_t, const float *, vuint8mf2_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vloxei8_v)))
vfloat32m4_t vloxei8(const float *, vuint8m1_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vloxei8_v_m)))
vfloat32m4_t vloxei8(vbool8_t, vfloat32m4_t, const float *, vuint8m1_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vloxei8_v)))
vfloat32m8_t vloxei8(const float *, vuint8m2_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vloxei8_v_m)))
vfloat32m8_t vloxei8(vbool4_t, vfloat32m8_t, const float *, vuint8m2_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vloxei8_v)))
vfloat32mf2_t vloxei8(const float *, vuint8mf8_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vloxei8_v_m)))
vfloat32mf2_t vloxei8(vbool64_t, vfloat32mf2_t, const float *, vuint8mf8_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vloxei16_v)))
vfloat32m1_t vloxei16(const float *, vuint16mf2_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vloxei16_v_m)))
vfloat32m1_t vloxei16(vbool32_t, vfloat32m1_t, const float *, vuint16mf2_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vloxei16_v)))
vfloat32m2_t vloxei16(const float *, vuint16m1_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vloxei16_v_m)))
vfloat32m2_t vloxei16(vbool16_t, vfloat32m2_t, const float *, vuint16m1_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vloxei16_v)))
vfloat32m4_t vloxei16(const float *, vuint16m2_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vloxei16_v_m)))
vfloat32m4_t vloxei16(vbool8_t, vfloat32m4_t, const float *, vuint16m2_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vloxei16_v)))
vfloat32m8_t vloxei16(const float *, vuint16m4_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vloxei16_v_m)))
vfloat32m8_t vloxei16(vbool4_t, vfloat32m8_t, const float *, vuint16m4_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vloxei16_v)))
vfloat32mf2_t vloxei16(const float *, vuint16mf4_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vloxei16_v_m)))
vfloat32mf2_t vloxei16(vbool64_t, vfloat32mf2_t, const float *, vuint16mf4_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vloxei32_v)))
vfloat32m1_t vloxei32(const float *, vuint32m1_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vloxei32_v_m)))
vfloat32m1_t vloxei32(vbool32_t, vfloat32m1_t, const float *, vuint32m1_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vloxei32_v)))
vfloat32m2_t vloxei32(const float *, vuint32m2_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vloxei32_v_m)))
vfloat32m2_t vloxei32(vbool16_t, vfloat32m2_t, const float *, vuint32m2_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vloxei32_v)))
vfloat32m4_t vloxei32(const float *, vuint32m4_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vloxei32_v_m)))
vfloat32m4_t vloxei32(vbool8_t, vfloat32m4_t, const float *, vuint32m4_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vloxei32_v)))
vfloat32m8_t vloxei32(const float *, vuint32m8_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vloxei32_v_m)))
vfloat32m8_t vloxei32(vbool4_t, vfloat32m8_t, const float *, vuint32m8_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vloxei32_v)))
vfloat32mf2_t vloxei32(const float *, vuint32mf2_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vloxei32_v_m)))
vfloat32mf2_t vloxei32(vbool64_t, vfloat32mf2_t, const float *, vuint32mf2_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vmv_v_v)))
vfloat32m1_t vmv_v(vfloat32m1_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vmv_v_v)))
vfloat32m2_t vmv_v(vfloat32m2_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vmv_v_v)))
vfloat32m4_t vmv_v(vfloat32m4_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vmv_v_v)))
vfloat32m8_t vmv_v(vfloat32m8_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vmv_v_v)))
vfloat32mf2_t vmv_v(vfloat32mf2_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vfadd_vv)))
vfloat32m1_t vfadd(vfloat32m1_t, vfloat32m1_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vfadd_vv_m)))
vfloat32m1_t vfadd(vbool32_t, vfloat32m1_t, vfloat32m1_t, vfloat32m1_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vfadd_vv)))
vfloat32m2_t vfadd(vfloat32m2_t, vfloat32m2_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vfadd_vv_m)))
vfloat32m2_t vfadd(vbool16_t, vfloat32m2_t, vfloat32m2_t, vfloat32m2_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vfadd_vv)))
vfloat32m4_t vfadd(vfloat32m4_t, vfloat32m4_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vfadd_vv_m)))
vfloat32m4_t vfadd(vbool8_t, vfloat32m4_t, vfloat32m4_t, vfloat32m4_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vfadd_vv)))
vfloat32m8_t vfadd(vfloat32m8_t, vfloat32m8_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vfadd_vv_m)))
vfloat32m8_t vfadd(vbool4_t, vfloat32m8_t, vfloat32m8_t, vfloat32m8_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vfadd_vv)))
vfloat32mf2_t vfadd(vfloat32mf2_t, vfloat32mf2_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vfadd_vv_m)))
vfloat32mf2_t vfadd(vbool64_t, vfloat32mf2_t, vfloat32mf2_t, vfloat32mf2_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vfadd_vf)))
vfloat32m1_t vfadd(vfloat32m1_t, float, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vfadd_vf_m)))
vfloat32m1_t vfadd(vbool32_t, vfloat32m1_t, vfloat32m1_t, float, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vfadd_vf)))
vfloat32m2_t vfadd(vfloat32m2_t, float, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vfadd_vf_m)))
vfloat32m2_t vfadd(vbool16_t, vfloat32m2_t, vfloat32m2_t, float, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vfadd_vf)))
vfloat32m4_t vfadd(vfloat32m4_t, float, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vfadd_vf_m)))
vfloat32m4_t vfadd(vbool8_t, vfloat32m4_t, vfloat32m4_t, float, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vfadd_vf)))
vfloat32m8_t vfadd(vfloat32m8_t, float, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vfadd_vf_m)))
vfloat32m8_t vfadd(vbool4_t, vfloat32m8_t, vfloat32m8_t, float, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vfadd_vf)))
vfloat32mf2_t vfadd(vfloat32mf2_t, float, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vfadd_vf_m)))
vfloat32mf2_t vfadd(vbool64_t, vfloat32mf2_t, vfloat32mf2_t, float, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vfsub_vv)))
vfloat32m1_t vfsub(vfloat32m1_t, vfloat32m1_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vfsub_vv_m)))
vfloat32m1_t vfsub(vbool32_t, vfloat32m1_t, vfloat32m1_t, vfloat32m1_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vfsub_vv)))
vfloat32m2_t vfsub(vfloat32m2_t, vfloat32m2_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vfsub_vv_m)))
vfloat32m2_t vfsub(vbool16_t, vfloat32m2_t, vfloat32m2_t, vfloat32m2_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vfsub_vv)))
vfloat32m4_t vfsub(vfloat32m4_t, vfloat32m4_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vfsub_vv_m)))
vfloat32m4_t vfsub(vbool8_t, vfloat32m4_t, vfloat32m4_t, vfloat32m4_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vfsub_vv)))
vfloat32m8_t vfsub(vfloat32m8_t, vfloat32m8_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vfsub_vv_m)))
vfloat32m8_t vfsub(vbool4_t, vfloat32m8_t, vfloat32m8_t, vfloat32m8_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vfsub_vv)))
vfloat32mf2_t vfsub(vfloat32mf2_t, vfloat32mf2_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vfsub_vv_m)))
vfloat32mf2_t vfsub(vbool64_t, vfloat32mf2_t, vfloat32mf2_t, vfloat32mf2_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vfsub_vf)))
vfloat32m1_t vfsub(vfloat32m1_t, float, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vfsub_vf_m)))
vfloat32m1_t vfsub(vbool32_t, vfloat32m1_t, vfloat32m1_t, float, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vfsub_vf)))
vfloat32m2_t vfsub(vfloat32m2_t, float, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vfsub_vf_m)))
vfloat32m2_t vfsub(vbool16_t, vfloat32m2_t, vfloat32m2_t, float, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vfsub_vf)))
vfloat32m4_t vfsub(vfloat32m4_t, float, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vfsub_vf_m)))
vfloat32m4_t vfsub(vbool8_t, vfloat32m4_t, vfloat32m4_t, float, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vfsub_vf)))
vfloat32m8_t vfsub(vfloat32m8_t, float, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vfsub_vf_m)))
vfloat32m8_t vfsub(vbool4_t, vfloat32m8_t, vfloat32m8_t, float, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vfsub_vf)))
vfloat32mf2_t vfsub(vfloat32mf2_t, float, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vfsub_vf_m)))
vfloat32mf2_t vfsub(vbool64_t, vfloat32mf2_t, vfloat32mf2_t, float, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vfrsub_vf)))
vfloat32m1_t vfrsub(vfloat32m1_t, float, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vfrsub_vf_m)))
vfloat32m1_t vfrsub(vbool32_t, vfloat32m1_t, vfloat32m1_t, float, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vfrsub_vf)))
vfloat32m2_t vfrsub(vfloat32m2_t, float, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vfrsub_vf_m)))
vfloat32m2_t vfrsub(vbool16_t, vfloat32m2_t, vfloat32m2_t, float, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vfrsub_vf)))
vfloat32m4_t vfrsub(vfloat32m4_t, float, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vfrsub_vf_m)))
vfloat32m4_t vfrsub(vbool8_t, vfloat32m4_t, vfloat32m4_t, float, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vfrsub_vf)))
vfloat32m8_t vfrsub(vfloat32m8_t, float, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vfrsub_vf_m)))
vfloat32m8_t vfrsub(vbool4_t, vfloat32m8_t, vfloat32m8_t, float, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vfrsub_vf)))
vfloat32mf2_t vfrsub(vfloat32mf2_t, float, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vfrsub_vf_m)))
vfloat32mf2_t vfrsub(vbool64_t, vfloat32mf2_t, vfloat32mf2_t, float, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vfmul_vv)))
vfloat32m1_t vfmul(vfloat32m1_t, vfloat32m1_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vfmul_vv_m)))
vfloat32m1_t vfmul(vbool32_t, vfloat32m1_t, vfloat32m1_t, vfloat32m1_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vfmul_vv)))
vfloat32m2_t vfmul(vfloat32m2_t, vfloat32m2_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vfmul_vv_m)))
vfloat32m2_t vfmul(vbool16_t, vfloat32m2_t, vfloat32m2_t, vfloat32m2_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vfmul_vv)))
vfloat32m4_t vfmul(vfloat32m4_t, vfloat32m4_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vfmul_vv_m)))
vfloat32m4_t vfmul(vbool8_t, vfloat32m4_t, vfloat32m4_t, vfloat32m4_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vfmul_vv)))
vfloat32m8_t vfmul(vfloat32m8_t, vfloat32m8_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vfmul_vv_m)))
vfloat32m8_t vfmul(vbool4_t, vfloat32m8_t, vfloat32m8_t, vfloat32m8_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vfmul_vv)))
vfloat32mf2_t vfmul(vfloat32mf2_t, vfloat32mf2_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vfmul_vv_m)))
vfloat32mf2_t vfmul(vbool64_t, vfloat32mf2_t, vfloat32mf2_t, vfloat32mf2_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vfmul_vf)))
vfloat32m1_t vfmul(vfloat32m1_t, float, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vfmul_vf_m)))
vfloat32m1_t vfmul(vbool32_t, vfloat32m1_t, vfloat32m1_t, float, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vfmul_vf)))
vfloat32m2_t vfmul(vfloat32m2_t, float, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vfmul_vf_m)))
vfloat32m2_t vfmul(vbool16_t, vfloat32m2_t, vfloat32m2_t, float, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vfmul_vf)))
vfloat32m4_t vfmul(vfloat32m4_t, float, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vfmul_vf_m)))
vfloat32m4_t vfmul(vbool8_t, vfloat32m4_t, vfloat32m4_t, float, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vfmul_vf)))
vfloat32m8_t vfmul(vfloat32m8_t, float, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vfmul_vf_m)))
vfloat32m8_t vfmul(vbool4_t, vfloat32m8_t, vfloat32m8_t, float, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vfmul_vf)))
vfloat32mf2_t vfmul(vfloat32mf2_t, float, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vfmul_vf_m)))
vfloat32mf2_t vfmul(vbool64_t, vfloat32mf2_t, vfloat32mf2_t, float, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vfdiv_vv)))
vfloat32m1_t vfdiv(vfloat32m1_t, vfloat32m1_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vfdiv_vv_m)))
vfloat32m1_t vfdiv(vbool32_t, vfloat32m1_t, vfloat32m1_t, vfloat32m1_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vfdiv_vv)))
vfloat32m2_t vfdiv(vfloat32m2_t, vfloat32m2_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vfdiv_vv_m)))
vfloat32m2_t vfdiv(vbool16_t, vfloat32m2_t, vfloat32m2_t, vfloat32m2_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vfdiv_vv)))
vfloat32m4_t vfdiv(vfloat32m4_t, vfloat32m4_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vfdiv_vv_m)))
vfloat32m4_t vfdiv(vbool8_t, vfloat32m4_t, vfloat32m4_t, vfloat32m4_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vfdiv_vv)))
vfloat32m8_t vfdiv(vfloat32m8_t, vfloat32m8_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vfdiv_vv_m)))
vfloat32m8_t vfdiv(vbool4_t, vfloat32m8_t, vfloat32m8_t, vfloat32m8_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vfdiv_vv)))
vfloat32mf2_t vfdiv(vfloat32mf2_t, vfloat32mf2_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vfdiv_vv_m)))
vfloat32mf2_t vfdiv(vbool64_t, vfloat32mf2_t, vfloat32mf2_t, vfloat32mf2_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vfdiv_vf)))
vfloat32m1_t vfdiv(vfloat32m1_t, float, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vfdiv_vf_m)))
vfloat32m1_t vfdiv(vbool32_t, vfloat32m1_t, vfloat32m1_t, float, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vfdiv_vf)))
vfloat32m2_t vfdiv(vfloat32m2_t, float, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vfdiv_vf_m)))
vfloat32m2_t vfdiv(vbool16_t, vfloat32m2_t, vfloat32m2_t, float, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vfdiv_vf)))
vfloat32m4_t vfdiv(vfloat32m4_t, float, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vfdiv_vf_m)))
vfloat32m4_t vfdiv(vbool8_t, vfloat32m4_t, vfloat32m4_t, float, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vfdiv_vf)))
vfloat32m8_t vfdiv(vfloat32m8_t, float, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vfdiv_vf_m)))
vfloat32m8_t vfdiv(vbool4_t, vfloat32m8_t, vfloat32m8_t, float, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vfdiv_vf)))
vfloat32mf2_t vfdiv(vfloat32mf2_t, float, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vfdiv_vf_m)))
vfloat32mf2_t vfdiv(vbool64_t, vfloat32mf2_t, vfloat32mf2_t, float, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vfrdiv_vf)))
vfloat32m1_t vfrdiv(vfloat32m1_t, float, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vfrdiv_vf_m)))
vfloat32m1_t vfrdiv(vbool32_t, vfloat32m1_t, vfloat32m1_t, float, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vfrdiv_vf)))
vfloat32m2_t vfrdiv(vfloat32m2_t, float, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vfrdiv_vf_m)))
vfloat32m2_t vfrdiv(vbool16_t, vfloat32m2_t, vfloat32m2_t, float, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vfrdiv_vf)))
vfloat32m4_t vfrdiv(vfloat32m4_t, float, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vfrdiv_vf_m)))
vfloat32m4_t vfrdiv(vbool8_t, vfloat32m4_t, vfloat32m4_t, float, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vfrdiv_vf)))
vfloat32m8_t vfrdiv(vfloat32m8_t, float, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vfrdiv_vf_m)))
vfloat32m8_t vfrdiv(vbool4_t, vfloat32m8_t, vfloat32m8_t, float, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vfrdiv_vf)))
vfloat32mf2_t vfrdiv(vfloat32mf2_t, float, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vfrdiv_vf_m)))
vfloat32mf2_t vfrdiv(vbool64_t, vfloat32mf2_t, vfloat32mf2_t, float, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vfmacc_vv)))
vfloat32m1_t vfmacc(vfloat32m1_t, vfloat32m1_t, vfloat32m1_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vfmacc_vv_m)))
vfloat32m1_t vfmacc(vbool32_t, vfloat32m1_t, vfloat32m1_t, vfloat32m1_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vfmacc_vv)))
vfloat32m2_t vfmacc(vfloat32m2_t, vfloat32m2_t, vfloat32m2_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vfmacc_vv_m)))
vfloat32m2_t vfmacc(vbool16_t, vfloat32m2_t, vfloat32m2_t, vfloat32m2_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vfmacc_vv)))
vfloat32m4_t vfmacc(vfloat32m4_t, vfloat32m4_t, vfloat32m4_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vfmacc_vv_m)))
vfloat32m4_t vfmacc(vbool8_t, vfloat32m4_t, vfloat32m4_t, vfloat32m4_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vfmacc_vv)))
vfloat32m8_t vfmacc(vfloat32m8_t, vfloat32m8_t, vfloat32m8_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vfmacc_vv_m)))
vfloat32m8_t vfmacc(vbool4_t, vfloat32m8_t, vfloat32m8_t, vfloat32m8_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vfmacc_vv)))
vfloat32mf2_t vfmacc(vfloat32mf2_t, vfloat32mf2_t, vfloat32mf2_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vfmacc_vv_m)))
vfloat32mf2_t vfmacc(vbool64_t, vfloat32mf2_t, vfloat32mf2_t, vfloat32mf2_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vfmacc_vf)))
vfloat32m1_t vfmacc(vfloat32m1_t, float, vfloat32m1_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vfmacc_vf_m)))
vfloat32m1_t vfmacc(vbool32_t, vfloat32m1_t, float, vfloat32m1_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vfmacc_vf)))
vfloat32m2_t vfmacc(vfloat32m2_t, float, vfloat32m2_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vfmacc_vf_m)))
vfloat32m2_t vfmacc(vbool16_t, vfloat32m2_t, float, vfloat32m2_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vfmacc_vf)))
vfloat32m4_t vfmacc(vfloat32m4_t, float, vfloat32m4_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vfmacc_vf_m)))
vfloat32m4_t vfmacc(vbool8_t, vfloat32m4_t, float, vfloat32m4_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vfmacc_vf)))
vfloat32m8_t vfmacc(vfloat32m8_t, float, vfloat32m8_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vfmacc_vf_m)))
vfloat32m8_t vfmacc(vbool4_t, vfloat32m8_t, float, vfloat32m8_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vfmacc_vf)))
vfloat32mf2_t vfmacc(vfloat32mf2_t, float, vfloat32mf2_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vfmacc_vf_m)))
vfloat32mf2_t vfmacc(vbool64_t, vfloat32mf2_t, float, vfloat32mf2_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vfnmacc_vv)))
vfloat32m1_t vfnmacc(vfloat32m1_t, vfloat32m1_t, vfloat32m1_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vfnmacc_vv_m)))
vfloat32m1_t vfnmacc(vbool32_t, vfloat32m1_t, vfloat32m1_t, vfloat32m1_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vfnmacc_vv)))
vfloat32m2_t vfnmacc(vfloat32m2_t, vfloat32m2_t, vfloat32m2_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vfnmacc_vv_m)))
vfloat32m2_t vfnmacc(vbool16_t, vfloat32m2_t, vfloat32m2_t, vfloat32m2_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vfnmacc_vv)))
vfloat32m4_t vfnmacc(vfloat32m4_t, vfloat32m4_t, vfloat32m4_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vfnmacc_vv_m)))
vfloat32m4_t vfnmacc(vbool8_t, vfloat32m4_t, vfloat32m4_t, vfloat32m4_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vfnmacc_vv)))
vfloat32m8_t vfnmacc(vfloat32m8_t, vfloat32m8_t, vfloat32m8_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vfnmacc_vv_m)))
vfloat32m8_t vfnmacc(vbool4_t, vfloat32m8_t, vfloat32m8_t, vfloat32m8_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vfnmacc_vv)))
vfloat32mf2_t vfnmacc(vfloat32mf2_t, vfloat32mf2_t, vfloat32mf2_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vfnmacc_vv_m)))
vfloat32mf2_t vfnmacc(vbool64_t, vfloat32mf2_t, vfloat32mf2_t, vfloat32mf2_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vfnmacc_vf)))
vfloat32m1_t vfnmacc(vfloat32m1_t, float, vfloat32m1_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vfnmacc_vf_m)))
vfloat32m1_t vfnmacc(vbool32_t, vfloat32m1_t, float, vfloat32m1_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vfnmacc_vf)))
vfloat32m2_t vfnmacc(vfloat32m2_t, float, vfloat32m2_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vfnmacc_vf_m)))
vfloat32m2_t vfnmacc(vbool16_t, vfloat32m2_t, float, vfloat32m2_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vfnmacc_vf)))
vfloat32m4_t vfnmacc(vfloat32m4_t, float, vfloat32m4_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vfnmacc_vf_m)))
vfloat32m4_t vfnmacc(vbool8_t, vfloat32m4_t, float, vfloat32m4_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vfnmacc_vf)))
vfloat32m8_t vfnmacc(vfloat32m8_t, float, vfloat32m8_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vfnmacc_vf_m)))
vfloat32m8_t vfnmacc(vbool4_t, vfloat32m8_t, float, vfloat32m8_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vfnmacc_vf)))
vfloat32mf2_t vfnmacc(vfloat32mf2_t, float, vfloat32mf2_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vfnmacc_vf_m)))
vfloat32mf2_t vfnmacc(vbool64_t, vfloat32mf2_t, float, vfloat32mf2_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vfmsac_vv)))
vfloat32m1_t vfmsac(vfloat32m1_t, vfloat32m1_t, vfloat32m1_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vfmsac_vv_m)))
vfloat32m1_t vfmsac(vbool32_t, vfloat32m1_t, vfloat32m1_t, vfloat32m1_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vfmsac_vv)))
vfloat32m2_t vfmsac(vfloat32m2_t, vfloat32m2_t, vfloat32m2_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vfmsac_vv_m)))
vfloat32m2_t vfmsac(vbool16_t, vfloat32m2_t, vfloat32m2_t, vfloat32m2_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vfmsac_vv)))
vfloat32m4_t vfmsac(vfloat32m4_t, vfloat32m4_t, vfloat32m4_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vfmsac_vv_m)))
vfloat32m4_t vfmsac(vbool8_t, vfloat32m4_t, vfloat32m4_t, vfloat32m4_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vfmsac_vv)))
vfloat32m8_t vfmsac(vfloat32m8_t, vfloat32m8_t, vfloat32m8_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vfmsac_vv_m)))
vfloat32m8_t vfmsac(vbool4_t, vfloat32m8_t, vfloat32m8_t, vfloat32m8_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vfmsac_vv)))
vfloat32mf2_t vfmsac(vfloat32mf2_t, vfloat32mf2_t, vfloat32mf2_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vfmsac_vv_m)))
vfloat32mf2_t vfmsac(vbool64_t, vfloat32mf2_t, vfloat32mf2_t, vfloat32mf2_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vfmsac_vf)))
vfloat32m1_t vfmsac(vfloat32m1_t, float, vfloat32m1_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vfmsac_vf_m)))
vfloat32m1_t vfmsac(vbool32_t, vfloat32m1_t, float, vfloat32m1_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vfmsac_vf)))
vfloat32m2_t vfmsac(vfloat32m2_t, float, vfloat32m2_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vfmsac_vf_m)))
vfloat32m2_t vfmsac(vbool16_t, vfloat32m2_t, float, vfloat32m2_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vfmsac_vf)))
vfloat32m4_t vfmsac(vfloat32m4_t, float, vfloat32m4_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vfmsac_vf_m)))
vfloat32m4_t vfmsac(vbool8_t, vfloat32m4_t, float, vfloat32m4_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vfmsac_vf)))
vfloat32m8_t vfmsac(vfloat32m8_t, float, vfloat32m8_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vfmsac_vf_m)))
vfloat32m8_t vfmsac(vbool4_t, vfloat32m8_t, float, vfloat32m8_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vfmsac_vf)))
vfloat32mf2_t vfmsac(vfloat32mf2_t, float, vfloat32mf2_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vfmsac_vf_m)))
vfloat32mf2_t vfmsac(vbool64_t, vfloat32mf2_t, float, vfloat32mf2_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vfnmsac_vv)))
vfloat32m1_t vfnmsac(vfloat32m1_t, vfloat32m1_t, vfloat32m1_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vfnmsac_vv_m)))
vfloat32m1_t vfnmsac(vbool32_t, vfloat32m1_t, vfloat32m1_t, vfloat32m1_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vfnmsac_vv)))
vfloat32m2_t vfnmsac(vfloat32m2_t, vfloat32m2_t, vfloat32m2_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vfnmsac_vv_m)))
vfloat32m2_t vfnmsac(vbool16_t, vfloat32m2_t, vfloat32m2_t, vfloat32m2_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vfnmsac_vv)))
vfloat32m4_t vfnmsac(vfloat32m4_t, vfloat32m4_t, vfloat32m4_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vfnmsac_vv_m)))
vfloat32m4_t vfnmsac(vbool8_t, vfloat32m4_t, vfloat32m4_t, vfloat32m4_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vfnmsac_vv)))
vfloat32m8_t vfnmsac(vfloat32m8_t, vfloat32m8_t, vfloat32m8_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vfnmsac_vv_m)))
vfloat32m8_t vfnmsac(vbool4_t, vfloat32m8_t, vfloat32m8_t, vfloat32m8_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vfnmsac_vv)))
vfloat32mf2_t vfnmsac(vfloat32mf2_t, vfloat32mf2_t, vfloat32mf2_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vfnmsac_vv_m)))
vfloat32mf2_t vfnmsac(vbool64_t, vfloat32mf2_t, vfloat32mf2_t, vfloat32mf2_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vfnmsac_vf)))
vfloat32m1_t vfnmsac(vfloat32m1_t, float, vfloat32m1_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vfnmsac_vf_m)))
vfloat32m1_t vfnmsac(vbool32_t, vfloat32m1_t, float, vfloat32m1_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vfnmsac_vf)))
vfloat32m2_t vfnmsac(vfloat32m2_t, float, vfloat32m2_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vfnmsac_vf_m)))
vfloat32m2_t vfnmsac(vbool16_t, vfloat32m2_t, float, vfloat32m2_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vfnmsac_vf)))
vfloat32m4_t vfnmsac(vfloat32m4_t, float, vfloat32m4_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vfnmsac_vf_m)))
vfloat32m4_t vfnmsac(vbool8_t, vfloat32m4_t, float, vfloat32m4_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vfnmsac_vf)))
vfloat32m8_t vfnmsac(vfloat32m8_t, float, vfloat32m8_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vfnmsac_vf_m)))
vfloat32m8_t vfnmsac(vbool4_t, vfloat32m8_t, float, vfloat32m8_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vfnmsac_vf)))
vfloat32mf2_t vfnmsac(vfloat32mf2_t, float, vfloat32mf2_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vfnmsac_vf_m)))
vfloat32mf2_t vfnmsac(vbool64_t, vfloat32mf2_t, float, vfloat32mf2_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vfmadd_vv)))
vfloat32m1_t vfmadd(vfloat32m1_t, vfloat32m1_t, vfloat32m1_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vfmadd_vv_m)))
vfloat32m1_t vfmadd(vbool32_t, vfloat32m1_t, vfloat32m1_t, vfloat32m1_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vfmadd_vv)))
vfloat32m2_t vfmadd(vfloat32m2_t, vfloat32m2_t, vfloat32m2_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vfmadd_vv_m)))
vfloat32m2_t vfmadd(vbool16_t, vfloat32m2_t, vfloat32m2_t, vfloat32m2_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vfmadd_vv)))
vfloat32m4_t vfmadd(vfloat32m4_t, vfloat32m4_t, vfloat32m4_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vfmadd_vv_m)))
vfloat32m4_t vfmadd(vbool8_t, vfloat32m4_t, vfloat32m4_t, vfloat32m4_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vfmadd_vv)))
vfloat32m8_t vfmadd(vfloat32m8_t, vfloat32m8_t, vfloat32m8_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vfmadd_vv_m)))
vfloat32m8_t vfmadd(vbool4_t, vfloat32m8_t, vfloat32m8_t, vfloat32m8_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vfmadd_vv)))
vfloat32mf2_t vfmadd(vfloat32mf2_t, vfloat32mf2_t, vfloat32mf2_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vfmadd_vv_m)))
vfloat32mf2_t vfmadd(vbool64_t, vfloat32mf2_t, vfloat32mf2_t, vfloat32mf2_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vfmadd_vf)))
vfloat32m1_t vfmadd(vfloat32m1_t, float, vfloat32m1_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vfmadd_vf_m)))
vfloat32m1_t vfmadd(vbool32_t, vfloat32m1_t, float, vfloat32m1_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vfmadd_vf)))
vfloat32m2_t vfmadd(vfloat32m2_t, float, vfloat32m2_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vfmadd_vf_m)))
vfloat32m2_t vfmadd(vbool16_t, vfloat32m2_t, float, vfloat32m2_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vfmadd_vf)))
vfloat32m4_t vfmadd(vfloat32m4_t, float, vfloat32m4_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vfmadd_vf_m)))
vfloat32m4_t vfmadd(vbool8_t, vfloat32m4_t, float, vfloat32m4_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vfmadd_vf)))
vfloat32m8_t vfmadd(vfloat32m8_t, float, vfloat32m8_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vfmadd_vf_m)))
vfloat32m8_t vfmadd(vbool4_t, vfloat32m8_t, float, vfloat32m8_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vfmadd_vf)))
vfloat32mf2_t vfmadd(vfloat32mf2_t, float, vfloat32mf2_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vfmadd_vf_m)))
vfloat32mf2_t vfmadd(vbool64_t, vfloat32mf2_t, float, vfloat32mf2_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vfnmadd_vv)))
vfloat32m1_t vfnmadd(vfloat32m1_t, vfloat32m1_t, vfloat32m1_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vfnmadd_vv_m)))
vfloat32m1_t vfnmadd(vbool32_t, vfloat32m1_t, vfloat32m1_t, vfloat32m1_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vfnmadd_vv)))
vfloat32m2_t vfnmadd(vfloat32m2_t, vfloat32m2_t, vfloat32m2_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vfnmadd_vv_m)))
vfloat32m2_t vfnmadd(vbool16_t, vfloat32m2_t, vfloat32m2_t, vfloat32m2_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vfnmadd_vv)))
vfloat32m4_t vfnmadd(vfloat32m4_t, vfloat32m4_t, vfloat32m4_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vfnmadd_vv_m)))
vfloat32m4_t vfnmadd(vbool8_t, vfloat32m4_t, vfloat32m4_t, vfloat32m4_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vfnmadd_vv)))
vfloat32m8_t vfnmadd(vfloat32m8_t, vfloat32m8_t, vfloat32m8_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vfnmadd_vv_m)))
vfloat32m8_t vfnmadd(vbool4_t, vfloat32m8_t, vfloat32m8_t, vfloat32m8_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vfnmadd_vv)))
vfloat32mf2_t vfnmadd(vfloat32mf2_t, vfloat32mf2_t, vfloat32mf2_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vfnmadd_vv_m)))
vfloat32mf2_t vfnmadd(vbool64_t, vfloat32mf2_t, vfloat32mf2_t, vfloat32mf2_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vfnmadd_vf)))
vfloat32m1_t vfnmadd(vfloat32m1_t, float, vfloat32m1_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vfnmadd_vf_m)))
vfloat32m1_t vfnmadd(vbool32_t, vfloat32m1_t, float, vfloat32m1_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vfnmadd_vf)))
vfloat32m2_t vfnmadd(vfloat32m2_t, float, vfloat32m2_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vfnmadd_vf_m)))
vfloat32m2_t vfnmadd(vbool16_t, vfloat32m2_t, float, vfloat32m2_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vfnmadd_vf)))
vfloat32m4_t vfnmadd(vfloat32m4_t, float, vfloat32m4_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vfnmadd_vf_m)))
vfloat32m4_t vfnmadd(vbool8_t, vfloat32m4_t, float, vfloat32m4_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vfnmadd_vf)))
vfloat32m8_t vfnmadd(vfloat32m8_t, float, vfloat32m8_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vfnmadd_vf_m)))
vfloat32m8_t vfnmadd(vbool4_t, vfloat32m8_t, float, vfloat32m8_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vfnmadd_vf)))
vfloat32mf2_t vfnmadd(vfloat32mf2_t, float, vfloat32mf2_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vfnmadd_vf_m)))
vfloat32mf2_t vfnmadd(vbool64_t, vfloat32mf2_t, float, vfloat32mf2_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vfmsub_vv)))
vfloat32m1_t vfmsub(vfloat32m1_t, vfloat32m1_t, vfloat32m1_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vfmsub_vv_m)))
vfloat32m1_t vfmsub(vbool32_t, vfloat32m1_t, vfloat32m1_t, vfloat32m1_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vfmsub_vv)))
vfloat32m2_t vfmsub(vfloat32m2_t, vfloat32m2_t, vfloat32m2_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vfmsub_vv_m)))
vfloat32m2_t vfmsub(vbool16_t, vfloat32m2_t, vfloat32m2_t, vfloat32m2_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vfmsub_vv)))
vfloat32m4_t vfmsub(vfloat32m4_t, vfloat32m4_t, vfloat32m4_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vfmsub_vv_m)))
vfloat32m4_t vfmsub(vbool8_t, vfloat32m4_t, vfloat32m4_t, vfloat32m4_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vfmsub_vv)))
vfloat32m8_t vfmsub(vfloat32m8_t, vfloat32m8_t, vfloat32m8_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vfmsub_vv_m)))
vfloat32m8_t vfmsub(vbool4_t, vfloat32m8_t, vfloat32m8_t, vfloat32m8_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vfmsub_vv)))
vfloat32mf2_t vfmsub(vfloat32mf2_t, vfloat32mf2_t, vfloat32mf2_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vfmsub_vv_m)))
vfloat32mf2_t vfmsub(vbool64_t, vfloat32mf2_t, vfloat32mf2_t, vfloat32mf2_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vfmsub_vf)))
vfloat32m1_t vfmsub(vfloat32m1_t, float, vfloat32m1_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vfmsub_vf_m)))
vfloat32m1_t vfmsub(vbool32_t, vfloat32m1_t, float, vfloat32m1_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vfmsub_vf)))
vfloat32m2_t vfmsub(vfloat32m2_t, float, vfloat32m2_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vfmsub_vf_m)))
vfloat32m2_t vfmsub(vbool16_t, vfloat32m2_t, float, vfloat32m2_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vfmsub_vf)))
vfloat32m4_t vfmsub(vfloat32m4_t, float, vfloat32m4_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vfmsub_vf_m)))
vfloat32m4_t vfmsub(vbool8_t, vfloat32m4_t, float, vfloat32m4_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vfmsub_vf)))
vfloat32m8_t vfmsub(vfloat32m8_t, float, vfloat32m8_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vfmsub_vf_m)))
vfloat32m8_t vfmsub(vbool4_t, vfloat32m8_t, float, vfloat32m8_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vfmsub_vf)))
vfloat32mf2_t vfmsub(vfloat32mf2_t, float, vfloat32mf2_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vfmsub_vf_m)))
vfloat32mf2_t vfmsub(vbool64_t, vfloat32mf2_t, float, vfloat32mf2_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vfnmsub_vv)))
vfloat32m1_t vfnmsub(vfloat32m1_t, vfloat32m1_t, vfloat32m1_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vfnmsub_vv_m)))
vfloat32m1_t vfnmsub(vbool32_t, vfloat32m1_t, vfloat32m1_t, vfloat32m1_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vfnmsub_vv)))
vfloat32m2_t vfnmsub(vfloat32m2_t, vfloat32m2_t, vfloat32m2_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vfnmsub_vv_m)))
vfloat32m2_t vfnmsub(vbool16_t, vfloat32m2_t, vfloat32m2_t, vfloat32m2_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vfnmsub_vv)))
vfloat32m4_t vfnmsub(vfloat32m4_t, vfloat32m4_t, vfloat32m4_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vfnmsub_vv_m)))
vfloat32m4_t vfnmsub(vbool8_t, vfloat32m4_t, vfloat32m4_t, vfloat32m4_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vfnmsub_vv)))
vfloat32m8_t vfnmsub(vfloat32m8_t, vfloat32m8_t, vfloat32m8_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vfnmsub_vv_m)))
vfloat32m8_t vfnmsub(vbool4_t, vfloat32m8_t, vfloat32m8_t, vfloat32m8_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vfnmsub_vv)))
vfloat32mf2_t vfnmsub(vfloat32mf2_t, vfloat32mf2_t, vfloat32mf2_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vfnmsub_vv_m)))
vfloat32mf2_t vfnmsub(vbool64_t, vfloat32mf2_t, vfloat32mf2_t, vfloat32mf2_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vfnmsub_vf)))
vfloat32m1_t vfnmsub(vfloat32m1_t, float, vfloat32m1_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vfnmsub_vf_m)))
vfloat32m1_t vfnmsub(vbool32_t, vfloat32m1_t, float, vfloat32m1_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vfnmsub_vf)))
vfloat32m2_t vfnmsub(vfloat32m2_t, float, vfloat32m2_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vfnmsub_vf_m)))
vfloat32m2_t vfnmsub(vbool16_t, vfloat32m2_t, float, vfloat32m2_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vfnmsub_vf)))
vfloat32m4_t vfnmsub(vfloat32m4_t, float, vfloat32m4_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vfnmsub_vf_m)))
vfloat32m4_t vfnmsub(vbool8_t, vfloat32m4_t, float, vfloat32m4_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vfnmsub_vf)))
vfloat32m8_t vfnmsub(vfloat32m8_t, float, vfloat32m8_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vfnmsub_vf_m)))
vfloat32m8_t vfnmsub(vbool4_t, vfloat32m8_t, float, vfloat32m8_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vfnmsub_vf)))
vfloat32mf2_t vfnmsub(vfloat32mf2_t, float, vfloat32mf2_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vfnmsub_vf_m)))
vfloat32mf2_t vfnmsub(vbool64_t, vfloat32mf2_t, float, vfloat32mf2_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vfmin_vv)))
vfloat32m1_t vfmin(vfloat32m1_t, vfloat32m1_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vfmin_vv_m)))
vfloat32m1_t vfmin(vbool32_t, vfloat32m1_t, vfloat32m1_t, vfloat32m1_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vfmin_vv)))
vfloat32m2_t vfmin(vfloat32m2_t, vfloat32m2_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vfmin_vv_m)))
vfloat32m2_t vfmin(vbool16_t, vfloat32m2_t, vfloat32m2_t, vfloat32m2_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vfmin_vv)))
vfloat32m4_t vfmin(vfloat32m4_t, vfloat32m4_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vfmin_vv_m)))
vfloat32m4_t vfmin(vbool8_t, vfloat32m4_t, vfloat32m4_t, vfloat32m4_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vfmin_vv)))
vfloat32m8_t vfmin(vfloat32m8_t, vfloat32m8_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vfmin_vv_m)))
vfloat32m8_t vfmin(vbool4_t, vfloat32m8_t, vfloat32m8_t, vfloat32m8_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vfmin_vv)))
vfloat32mf2_t vfmin(vfloat32mf2_t, vfloat32mf2_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vfmin_vv_m)))
vfloat32mf2_t vfmin(vbool64_t, vfloat32mf2_t, vfloat32mf2_t, vfloat32mf2_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vfmin_vf)))
vfloat32m1_t vfmin(vfloat32m1_t, float, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vfmin_vf_m)))
vfloat32m1_t vfmin(vbool32_t, vfloat32m1_t, vfloat32m1_t, float, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vfmin_vf)))
vfloat32m2_t vfmin(vfloat32m2_t, float, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vfmin_vf_m)))
vfloat32m2_t vfmin(vbool16_t, vfloat32m2_t, vfloat32m2_t, float, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vfmin_vf)))
vfloat32m4_t vfmin(vfloat32m4_t, float, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vfmin_vf_m)))
vfloat32m4_t vfmin(vbool8_t, vfloat32m4_t, vfloat32m4_t, float, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vfmin_vf)))
vfloat32m8_t vfmin(vfloat32m8_t, float, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vfmin_vf_m)))
vfloat32m8_t vfmin(vbool4_t, vfloat32m8_t, vfloat32m8_t, float, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vfmin_vf)))
vfloat32mf2_t vfmin(vfloat32mf2_t, float, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vfmin_vf_m)))
vfloat32mf2_t vfmin(vbool64_t, vfloat32mf2_t, vfloat32mf2_t, float, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vfmax_vv)))
vfloat32m1_t vfmax(vfloat32m1_t, vfloat32m1_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vfmax_vv_m)))
vfloat32m1_t vfmax(vbool32_t, vfloat32m1_t, vfloat32m1_t, vfloat32m1_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vfmax_vv)))
vfloat32m2_t vfmax(vfloat32m2_t, vfloat32m2_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vfmax_vv_m)))
vfloat32m2_t vfmax(vbool16_t, vfloat32m2_t, vfloat32m2_t, vfloat32m2_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vfmax_vv)))
vfloat32m4_t vfmax(vfloat32m4_t, vfloat32m4_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vfmax_vv_m)))
vfloat32m4_t vfmax(vbool8_t, vfloat32m4_t, vfloat32m4_t, vfloat32m4_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vfmax_vv)))
vfloat32m8_t vfmax(vfloat32m8_t, vfloat32m8_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vfmax_vv_m)))
vfloat32m8_t vfmax(vbool4_t, vfloat32m8_t, vfloat32m8_t, vfloat32m8_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vfmax_vv)))
vfloat32mf2_t vfmax(vfloat32mf2_t, vfloat32mf2_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vfmax_vv_m)))
vfloat32mf2_t vfmax(vbool64_t, vfloat32mf2_t, vfloat32mf2_t, vfloat32mf2_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vfmax_vf)))
vfloat32m1_t vfmax(vfloat32m1_t, float, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vfmax_vf_m)))
vfloat32m1_t vfmax(vbool32_t, vfloat32m1_t, vfloat32m1_t, float, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vfmax_vf)))
vfloat32m2_t vfmax(vfloat32m2_t, float, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vfmax_vf_m)))
vfloat32m2_t vfmax(vbool16_t, vfloat32m2_t, vfloat32m2_t, float, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vfmax_vf)))
vfloat32m4_t vfmax(vfloat32m4_t, float, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vfmax_vf_m)))
vfloat32m4_t vfmax(vbool8_t, vfloat32m4_t, vfloat32m4_t, float, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vfmax_vf)))
vfloat32m8_t vfmax(vfloat32m8_t, float, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vfmax_vf_m)))
vfloat32m8_t vfmax(vbool4_t, vfloat32m8_t, vfloat32m8_t, float, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vfmax_vf)))
vfloat32mf2_t vfmax(vfloat32mf2_t, float, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vfmax_vf_m)))
vfloat32mf2_t vfmax(vbool64_t, vfloat32mf2_t, vfloat32mf2_t, float, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vfsgnj_vv)))
vfloat32m1_t vfsgnj(vfloat32m1_t, vfloat32m1_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vfsgnj_vv_m)))
vfloat32m1_t vfsgnj(vbool32_t, vfloat32m1_t, vfloat32m1_t, vfloat32m1_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vfsgnj_vv)))
vfloat32m2_t vfsgnj(vfloat32m2_t, vfloat32m2_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vfsgnj_vv_m)))
vfloat32m2_t vfsgnj(vbool16_t, vfloat32m2_t, vfloat32m2_t, vfloat32m2_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vfsgnj_vv)))
vfloat32m4_t vfsgnj(vfloat32m4_t, vfloat32m4_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vfsgnj_vv_m)))
vfloat32m4_t vfsgnj(vbool8_t, vfloat32m4_t, vfloat32m4_t, vfloat32m4_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vfsgnj_vv)))
vfloat32m8_t vfsgnj(vfloat32m8_t, vfloat32m8_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vfsgnj_vv_m)))
vfloat32m8_t vfsgnj(vbool4_t, vfloat32m8_t, vfloat32m8_t, vfloat32m8_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vfsgnj_vv)))
vfloat32mf2_t vfsgnj(vfloat32mf2_t, vfloat32mf2_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vfsgnj_vv_m)))
vfloat32mf2_t vfsgnj(vbool64_t, vfloat32mf2_t, vfloat32mf2_t, vfloat32mf2_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vfsgnj_vf)))
vfloat32m1_t vfsgnj(vfloat32m1_t, float, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vfsgnj_vf_m)))
vfloat32m1_t vfsgnj(vbool32_t, vfloat32m1_t, vfloat32m1_t, float, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vfsgnj_vf)))
vfloat32m2_t vfsgnj(vfloat32m2_t, float, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vfsgnj_vf_m)))
vfloat32m2_t vfsgnj(vbool16_t, vfloat32m2_t, vfloat32m2_t, float, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vfsgnj_vf)))
vfloat32m4_t vfsgnj(vfloat32m4_t, float, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vfsgnj_vf_m)))
vfloat32m4_t vfsgnj(vbool8_t, vfloat32m4_t, vfloat32m4_t, float, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vfsgnj_vf)))
vfloat32m8_t vfsgnj(vfloat32m8_t, float, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vfsgnj_vf_m)))
vfloat32m8_t vfsgnj(vbool4_t, vfloat32m8_t, vfloat32m8_t, float, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vfsgnj_vf)))
vfloat32mf2_t vfsgnj(vfloat32mf2_t, float, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vfsgnj_vf_m)))
vfloat32mf2_t vfsgnj(vbool64_t, vfloat32mf2_t, vfloat32mf2_t, float, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vfsgnjn_vv)))
vfloat32m1_t vfsgnjn(vfloat32m1_t, vfloat32m1_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vfsgnjn_vv_m)))
vfloat32m1_t vfsgnjn(vbool32_t, vfloat32m1_t, vfloat32m1_t, vfloat32m1_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vfsgnjn_vv)))
vfloat32m2_t vfsgnjn(vfloat32m2_t, vfloat32m2_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vfsgnjn_vv_m)))
vfloat32m2_t vfsgnjn(vbool16_t, vfloat32m2_t, vfloat32m2_t, vfloat32m2_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vfsgnjn_vv)))
vfloat32m4_t vfsgnjn(vfloat32m4_t, vfloat32m4_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vfsgnjn_vv_m)))
vfloat32m4_t vfsgnjn(vbool8_t, vfloat32m4_t, vfloat32m4_t, vfloat32m4_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vfsgnjn_vv)))
vfloat32m8_t vfsgnjn(vfloat32m8_t, vfloat32m8_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vfsgnjn_vv_m)))
vfloat32m8_t vfsgnjn(vbool4_t, vfloat32m8_t, vfloat32m8_t, vfloat32m8_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vfsgnjn_vv)))
vfloat32mf2_t vfsgnjn(vfloat32mf2_t, vfloat32mf2_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vfsgnjn_vv_m)))
vfloat32mf2_t vfsgnjn(vbool64_t, vfloat32mf2_t, vfloat32mf2_t, vfloat32mf2_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vfsgnjn_vf)))
vfloat32m1_t vfsgnjn(vfloat32m1_t, float, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vfsgnjn_vf_m)))
vfloat32m1_t vfsgnjn(vbool32_t, vfloat32m1_t, vfloat32m1_t, float, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vfsgnjn_vf)))
vfloat32m2_t vfsgnjn(vfloat32m2_t, float, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vfsgnjn_vf_m)))
vfloat32m2_t vfsgnjn(vbool16_t, vfloat32m2_t, vfloat32m2_t, float, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vfsgnjn_vf)))
vfloat32m4_t vfsgnjn(vfloat32m4_t, float, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vfsgnjn_vf_m)))
vfloat32m4_t vfsgnjn(vbool8_t, vfloat32m4_t, vfloat32m4_t, float, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vfsgnjn_vf)))
vfloat32m8_t vfsgnjn(vfloat32m8_t, float, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vfsgnjn_vf_m)))
vfloat32m8_t vfsgnjn(vbool4_t, vfloat32m8_t, vfloat32m8_t, float, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vfsgnjn_vf)))
vfloat32mf2_t vfsgnjn(vfloat32mf2_t, float, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vfsgnjn_vf_m)))
vfloat32mf2_t vfsgnjn(vbool64_t, vfloat32mf2_t, vfloat32mf2_t, float, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vfsgnjx_vv)))
vfloat32m1_t vfsgnjx(vfloat32m1_t, vfloat32m1_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vfsgnjx_vv_m)))
vfloat32m1_t vfsgnjx(vbool32_t, vfloat32m1_t, vfloat32m1_t, vfloat32m1_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vfsgnjx_vv)))
vfloat32m2_t vfsgnjx(vfloat32m2_t, vfloat32m2_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vfsgnjx_vv_m)))
vfloat32m2_t vfsgnjx(vbool16_t, vfloat32m2_t, vfloat32m2_t, vfloat32m2_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vfsgnjx_vv)))
vfloat32m4_t vfsgnjx(vfloat32m4_t, vfloat32m4_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vfsgnjx_vv_m)))
vfloat32m4_t vfsgnjx(vbool8_t, vfloat32m4_t, vfloat32m4_t, vfloat32m4_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vfsgnjx_vv)))
vfloat32m8_t vfsgnjx(vfloat32m8_t, vfloat32m8_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vfsgnjx_vv_m)))
vfloat32m8_t vfsgnjx(vbool4_t, vfloat32m8_t, vfloat32m8_t, vfloat32m8_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vfsgnjx_vv)))
vfloat32mf2_t vfsgnjx(vfloat32mf2_t, vfloat32mf2_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vfsgnjx_vv_m)))
vfloat32mf2_t vfsgnjx(vbool64_t, vfloat32mf2_t, vfloat32mf2_t, vfloat32mf2_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vfsgnjx_vf)))
vfloat32m1_t vfsgnjx(vfloat32m1_t, float, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vfsgnjx_vf_m)))
vfloat32m1_t vfsgnjx(vbool32_t, vfloat32m1_t, vfloat32m1_t, float, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vfsgnjx_vf)))
vfloat32m2_t vfsgnjx(vfloat32m2_t, float, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vfsgnjx_vf_m)))
vfloat32m2_t vfsgnjx(vbool16_t, vfloat32m2_t, vfloat32m2_t, float, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vfsgnjx_vf)))
vfloat32m4_t vfsgnjx(vfloat32m4_t, float, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vfsgnjx_vf_m)))
vfloat32m4_t vfsgnjx(vbool8_t, vfloat32m4_t, vfloat32m4_t, float, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vfsgnjx_vf)))
vfloat32m8_t vfsgnjx(vfloat32m8_t, float, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vfsgnjx_vf_m)))
vfloat32m8_t vfsgnjx(vbool4_t, vfloat32m8_t, vfloat32m8_t, float, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vfsgnjx_vf)))
vfloat32mf2_t vfsgnjx(vfloat32mf2_t, float, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vfsgnjx_vf_m)))
vfloat32mf2_t vfsgnjx(vbool64_t, vfloat32mf2_t, vfloat32mf2_t, float, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vfabs_v)))
vfloat32m1_t vfabs(vfloat32m1_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vfabs_v_m)))
vfloat32m1_t vfabs(vbool32_t, vfloat32m1_t, vfloat32m1_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vfabs_v)))
vfloat32m2_t vfabs(vfloat32m2_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vfabs_v_m)))
vfloat32m2_t vfabs(vbool16_t, vfloat32m2_t, vfloat32m2_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vfabs_v)))
vfloat32m4_t vfabs(vfloat32m4_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vfabs_v_m)))
vfloat32m4_t vfabs(vbool8_t, vfloat32m4_t, vfloat32m4_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vfabs_v)))
vfloat32m8_t vfabs(vfloat32m8_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vfabs_v_m)))
vfloat32m8_t vfabs(vbool4_t, vfloat32m8_t, vfloat32m8_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vfabs_v)))
vfloat32mf2_t vfabs(vfloat32mf2_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vfabs_v_m)))
vfloat32mf2_t vfabs(vbool64_t, vfloat32mf2_t, vfloat32mf2_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vmfeq_vv)))
vbool32_t vmfeq(vfloat32m1_t, vfloat32m1_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vmfeq_vv_m)))
vbool32_t vmfeq(vbool32_t, vbool32_t, vfloat32m1_t, vfloat32m1_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vmfeq_vv)))
vbool16_t vmfeq(vfloat32m2_t, vfloat32m2_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vmfeq_vv_m)))
vbool16_t vmfeq(vbool16_t, vbool16_t, vfloat32m2_t, vfloat32m2_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vmfeq_vv)))
vbool8_t vmfeq(vfloat32m4_t, vfloat32m4_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vmfeq_vv_m)))
vbool8_t vmfeq(vbool8_t, vbool8_t, vfloat32m4_t, vfloat32m4_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vmfeq_vv)))
vbool4_t vmfeq(vfloat32m8_t, vfloat32m8_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vmfeq_vv_m)))
vbool4_t vmfeq(vbool4_t, vbool4_t, vfloat32m8_t, vfloat32m8_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vmfeq_vv)))
vbool64_t vmfeq(vfloat32mf2_t, vfloat32mf2_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vmfeq_vv_m)))
vbool64_t vmfeq(vbool64_t, vbool64_t, vfloat32mf2_t, vfloat32mf2_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vmfeq_vf)))
vbool32_t vmfeq(vfloat32m1_t, float, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vmfeq_vf_m)))
vbool32_t vmfeq(vbool32_t, vbool32_t, vfloat32m1_t, float, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vmfeq_vf)))
vbool16_t vmfeq(vfloat32m2_t, float, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vmfeq_vf_m)))
vbool16_t vmfeq(vbool16_t, vbool16_t, vfloat32m2_t, float, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vmfeq_vf)))
vbool8_t vmfeq(vfloat32m4_t, float, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vmfeq_vf_m)))
vbool8_t vmfeq(vbool8_t, vbool8_t, vfloat32m4_t, float, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vmfeq_vf)))
vbool4_t vmfeq(vfloat32m8_t, float, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vmfeq_vf_m)))
vbool4_t vmfeq(vbool4_t, vbool4_t, vfloat32m8_t, float, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vmfeq_vf)))
vbool64_t vmfeq(vfloat32mf2_t, float, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vmfeq_vf_m)))
vbool64_t vmfeq(vbool64_t, vbool64_t, vfloat32mf2_t, float, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vmfne_vv)))
vbool32_t vmfne(vfloat32m1_t, vfloat32m1_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vmfne_vv_m)))
vbool32_t vmfne(vbool32_t, vbool32_t, vfloat32m1_t, vfloat32m1_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vmfne_vv)))
vbool16_t vmfne(vfloat32m2_t, vfloat32m2_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vmfne_vv_m)))
vbool16_t vmfne(vbool16_t, vbool16_t, vfloat32m2_t, vfloat32m2_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vmfne_vv)))
vbool8_t vmfne(vfloat32m4_t, vfloat32m4_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vmfne_vv_m)))
vbool8_t vmfne(vbool8_t, vbool8_t, vfloat32m4_t, vfloat32m4_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vmfne_vv)))
vbool4_t vmfne(vfloat32m8_t, vfloat32m8_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vmfne_vv_m)))
vbool4_t vmfne(vbool4_t, vbool4_t, vfloat32m8_t, vfloat32m8_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vmfne_vv)))
vbool64_t vmfne(vfloat32mf2_t, vfloat32mf2_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vmfne_vv_m)))
vbool64_t vmfne(vbool64_t, vbool64_t, vfloat32mf2_t, vfloat32mf2_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vmfne_vf)))
vbool32_t vmfne(vfloat32m1_t, float, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vmfne_vf_m)))
vbool32_t vmfne(vbool32_t, vbool32_t, vfloat32m1_t, float, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vmfne_vf)))
vbool16_t vmfne(vfloat32m2_t, float, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vmfne_vf_m)))
vbool16_t vmfne(vbool16_t, vbool16_t, vfloat32m2_t, float, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vmfne_vf)))
vbool8_t vmfne(vfloat32m4_t, float, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vmfne_vf_m)))
vbool8_t vmfne(vbool8_t, vbool8_t, vfloat32m4_t, float, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vmfne_vf)))
vbool4_t vmfne(vfloat32m8_t, float, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vmfne_vf_m)))
vbool4_t vmfne(vbool4_t, vbool4_t, vfloat32m8_t, float, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vmfne_vf)))
vbool64_t vmfne(vfloat32mf2_t, float, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vmfne_vf_m)))
vbool64_t vmfne(vbool64_t, vbool64_t, vfloat32mf2_t, float, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vmflt_vv)))
vbool32_t vmflt(vfloat32m1_t, vfloat32m1_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vmflt_vv_m)))
vbool32_t vmflt(vbool32_t, vbool32_t, vfloat32m1_t, vfloat32m1_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vmflt_vv)))
vbool16_t vmflt(vfloat32m2_t, vfloat32m2_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vmflt_vv_m)))
vbool16_t vmflt(vbool16_t, vbool16_t, vfloat32m2_t, vfloat32m2_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vmflt_vv)))
vbool8_t vmflt(vfloat32m4_t, vfloat32m4_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vmflt_vv_m)))
vbool8_t vmflt(vbool8_t, vbool8_t, vfloat32m4_t, vfloat32m4_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vmflt_vv)))
vbool4_t vmflt(vfloat32m8_t, vfloat32m8_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vmflt_vv_m)))
vbool4_t vmflt(vbool4_t, vbool4_t, vfloat32m8_t, vfloat32m8_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vmflt_vv)))
vbool64_t vmflt(vfloat32mf2_t, vfloat32mf2_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vmflt_vv_m)))
vbool64_t vmflt(vbool64_t, vbool64_t, vfloat32mf2_t, vfloat32mf2_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vmflt_vf)))
vbool32_t vmflt(vfloat32m1_t, float, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vmflt_vf_m)))
vbool32_t vmflt(vbool32_t, vbool32_t, vfloat32m1_t, float, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vmflt_vf)))
vbool16_t vmflt(vfloat32m2_t, float, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vmflt_vf_m)))
vbool16_t vmflt(vbool16_t, vbool16_t, vfloat32m2_t, float, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vmflt_vf)))
vbool8_t vmflt(vfloat32m4_t, float, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vmflt_vf_m)))
vbool8_t vmflt(vbool8_t, vbool8_t, vfloat32m4_t, float, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vmflt_vf)))
vbool4_t vmflt(vfloat32m8_t, float, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vmflt_vf_m)))
vbool4_t vmflt(vbool4_t, vbool4_t, vfloat32m8_t, float, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vmflt_vf)))
vbool64_t vmflt(vfloat32mf2_t, float, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vmflt_vf_m)))
vbool64_t vmflt(vbool64_t, vbool64_t, vfloat32mf2_t, float, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vmfle_vv)))
vbool32_t vmfle(vfloat32m1_t, vfloat32m1_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vmfle_vv_m)))
vbool32_t vmfle(vbool32_t, vbool32_t, vfloat32m1_t, vfloat32m1_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vmfle_vv)))
vbool16_t vmfle(vfloat32m2_t, vfloat32m2_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vmfle_vv_m)))
vbool16_t vmfle(vbool16_t, vbool16_t, vfloat32m2_t, vfloat32m2_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vmfle_vv)))
vbool8_t vmfle(vfloat32m4_t, vfloat32m4_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vmfle_vv_m)))
vbool8_t vmfle(vbool8_t, vbool8_t, vfloat32m4_t, vfloat32m4_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vmfle_vv)))
vbool4_t vmfle(vfloat32m8_t, vfloat32m8_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vmfle_vv_m)))
vbool4_t vmfle(vbool4_t, vbool4_t, vfloat32m8_t, vfloat32m8_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vmfle_vv)))
vbool64_t vmfle(vfloat32mf2_t, vfloat32mf2_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vmfle_vv_m)))
vbool64_t vmfle(vbool64_t, vbool64_t, vfloat32mf2_t, vfloat32mf2_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vmfle_vf)))
vbool32_t vmfle(vfloat32m1_t, float, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vmfle_vf_m)))
vbool32_t vmfle(vbool32_t, vbool32_t, vfloat32m1_t, float, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vmfle_vf)))
vbool16_t vmfle(vfloat32m2_t, float, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vmfle_vf_m)))
vbool16_t vmfle(vbool16_t, vbool16_t, vfloat32m2_t, float, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vmfle_vf)))
vbool8_t vmfle(vfloat32m4_t, float, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vmfle_vf_m)))
vbool8_t vmfle(vbool8_t, vbool8_t, vfloat32m4_t, float, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vmfle_vf)))
vbool4_t vmfle(vfloat32m8_t, float, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vmfle_vf_m)))
vbool4_t vmfle(vbool4_t, vbool4_t, vfloat32m8_t, float, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vmfle_vf)))
vbool64_t vmfle(vfloat32mf2_t, float, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vmfle_vf_m)))
vbool64_t vmfle(vbool64_t, vbool64_t, vfloat32mf2_t, float, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vmfgt_vv)))
vbool32_t vmfgt(vfloat32m1_t, vfloat32m1_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vmfgt_vv_m)))
vbool32_t vmfgt(vbool32_t, vbool32_t, vfloat32m1_t, vfloat32m1_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vmfgt_vv)))
vbool16_t vmfgt(vfloat32m2_t, vfloat32m2_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vmfgt_vv_m)))
vbool16_t vmfgt(vbool16_t, vbool16_t, vfloat32m2_t, vfloat32m2_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vmfgt_vv)))
vbool8_t vmfgt(vfloat32m4_t, vfloat32m4_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vmfgt_vv_m)))
vbool8_t vmfgt(vbool8_t, vbool8_t, vfloat32m4_t, vfloat32m4_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vmfgt_vv)))
vbool4_t vmfgt(vfloat32m8_t, vfloat32m8_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vmfgt_vv_m)))
vbool4_t vmfgt(vbool4_t, vbool4_t, vfloat32m8_t, vfloat32m8_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vmfgt_vv)))
vbool64_t vmfgt(vfloat32mf2_t, vfloat32mf2_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vmfgt_vv_m)))
vbool64_t vmfgt(vbool64_t, vbool64_t, vfloat32mf2_t, vfloat32mf2_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vmfgt_vf)))
vbool32_t vmfgt(vfloat32m1_t, float, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vmfgt_vf_m)))
vbool32_t vmfgt(vbool32_t, vbool32_t, vfloat32m1_t, float, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vmfgt_vf)))
vbool16_t vmfgt(vfloat32m2_t, float, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vmfgt_vf_m)))
vbool16_t vmfgt(vbool16_t, vbool16_t, vfloat32m2_t, float, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vmfgt_vf)))
vbool8_t vmfgt(vfloat32m4_t, float, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vmfgt_vf_m)))
vbool8_t vmfgt(vbool8_t, vbool8_t, vfloat32m4_t, float, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vmfgt_vf)))
vbool4_t vmfgt(vfloat32m8_t, float, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vmfgt_vf_m)))
vbool4_t vmfgt(vbool4_t, vbool4_t, vfloat32m8_t, float, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vmfgt_vf)))
vbool64_t vmfgt(vfloat32mf2_t, float, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vmfgt_vf_m)))
vbool64_t vmfgt(vbool64_t, vbool64_t, vfloat32mf2_t, float, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vmfge_vv)))
vbool32_t vmfge(vfloat32m1_t, vfloat32m1_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vmfge_vv_m)))
vbool32_t vmfge(vbool32_t, vbool32_t, vfloat32m1_t, vfloat32m1_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vmfge_vv)))
vbool16_t vmfge(vfloat32m2_t, vfloat32m2_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vmfge_vv_m)))
vbool16_t vmfge(vbool16_t, vbool16_t, vfloat32m2_t, vfloat32m2_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vmfge_vv)))
vbool8_t vmfge(vfloat32m4_t, vfloat32m4_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vmfge_vv_m)))
vbool8_t vmfge(vbool8_t, vbool8_t, vfloat32m4_t, vfloat32m4_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vmfge_vv)))
vbool4_t vmfge(vfloat32m8_t, vfloat32m8_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vmfge_vv_m)))
vbool4_t vmfge(vbool4_t, vbool4_t, vfloat32m8_t, vfloat32m8_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vmfge_vv)))
vbool64_t vmfge(vfloat32mf2_t, vfloat32mf2_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vmfge_vv_m)))
vbool64_t vmfge(vbool64_t, vbool64_t, vfloat32mf2_t, vfloat32mf2_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vmfge_vf)))
vbool32_t vmfge(vfloat32m1_t, float, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vmfge_vf_m)))
vbool32_t vmfge(vbool32_t, vbool32_t, vfloat32m1_t, float, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vmfge_vf)))
vbool16_t vmfge(vfloat32m2_t, float, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vmfge_vf_m)))
vbool16_t vmfge(vbool16_t, vbool16_t, vfloat32m2_t, float, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vmfge_vf)))
vbool8_t vmfge(vfloat32m4_t, float, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vmfge_vf_m)))
vbool8_t vmfge(vbool8_t, vbool8_t, vfloat32m4_t, float, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vmfge_vf)))
vbool4_t vmfge(vfloat32m8_t, float, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vmfge_vf_m)))
vbool4_t vmfge(vbool4_t, vbool4_t, vfloat32m8_t, float, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vmfge_vf)))
vbool64_t vmfge(vfloat32mf2_t, float, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vmfge_vf_m)))
vbool64_t vmfge(vbool64_t, vbool64_t, vfloat32mf2_t, float, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vmerge_vvm)))
vfloat32m1_t vmerge(vbool32_t, vfloat32m1_t, vfloat32m1_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vmerge_vvm)))
vfloat32m2_t vmerge(vbool16_t, vfloat32m2_t, vfloat32m2_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vmerge_vvm)))
vfloat32m4_t vmerge(vbool8_t, vfloat32m4_t, vfloat32m4_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vmerge_vvm)))
vfloat32m8_t vmerge(vbool4_t, vfloat32m8_t, vfloat32m8_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vmerge_vvm)))
vfloat32mf2_t vmerge(vbool64_t, vfloat32mf2_t, vfloat32mf2_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vfmerge_vfm)))
vfloat32m1_t vfmerge(vbool32_t, vfloat32m1_t, float, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vfmerge_vfm)))
vfloat32m2_t vfmerge(vbool16_t, vfloat32m2_t, float, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vfmerge_vfm)))
vfloat32m4_t vfmerge(vbool8_t, vfloat32m4_t, float, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vfmerge_vfm)))
vfloat32m8_t vfmerge(vbool4_t, vfloat32m8_t, float, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vfmerge_vfm)))
vfloat32mf2_t vfmerge(vbool64_t, vfloat32mf2_t, float, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vfredmax_vs)))
vfloat32m1_t vfredmax(vfloat32m1_t, vfloat32m1_t, vfloat32m1_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vfredmax_vs_m)))
vfloat32m1_t vfredmax(vbool32_t, vfloat32m1_t, vfloat32m1_t, vfloat32m1_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vfredmax_vs)))
vfloat32m1_t vfredmax(vfloat32m1_t, vfloat32m2_t, vfloat32m1_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vfredmax_vs_m)))
vfloat32m1_t vfredmax(vbool16_t, vfloat32m1_t, vfloat32m2_t, vfloat32m1_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vfredmax_vs)))
vfloat32m1_t vfredmax(vfloat32m1_t, vfloat32m4_t, vfloat32m1_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vfredmax_vs_m)))
vfloat32m1_t vfredmax(vbool8_t, vfloat32m1_t, vfloat32m4_t, vfloat32m1_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vfredmax_vs)))
vfloat32m1_t vfredmax(vfloat32m1_t, vfloat32m8_t, vfloat32m1_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vfredmax_vs_m)))
vfloat32m1_t vfredmax(vbool4_t, vfloat32m1_t, vfloat32m8_t, vfloat32m1_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vfredmax_vs)))
vfloat32m1_t vfredmax(vfloat32m1_t, vfloat32mf2_t, vfloat32m1_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vfredmax_vs_m)))
vfloat32m1_t vfredmax(vbool64_t, vfloat32m1_t, vfloat32mf2_t, vfloat32m1_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vfredmin_vs)))
vfloat32m1_t vfredmin(vfloat32m1_t, vfloat32m1_t, vfloat32m1_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vfredmin_vs_m)))
vfloat32m1_t vfredmin(vbool32_t, vfloat32m1_t, vfloat32m1_t, vfloat32m1_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vfredmin_vs)))
vfloat32m1_t vfredmin(vfloat32m1_t, vfloat32m2_t, vfloat32m1_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vfredmin_vs_m)))
vfloat32m1_t vfredmin(vbool16_t, vfloat32m1_t, vfloat32m2_t, vfloat32m1_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vfredmin_vs)))
vfloat32m1_t vfredmin(vfloat32m1_t, vfloat32m4_t, vfloat32m1_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vfredmin_vs_m)))
vfloat32m1_t vfredmin(vbool8_t, vfloat32m1_t, vfloat32m4_t, vfloat32m1_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vfredmin_vs)))
vfloat32m1_t vfredmin(vfloat32m1_t, vfloat32m8_t, vfloat32m1_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vfredmin_vs_m)))
vfloat32m1_t vfredmin(vbool4_t, vfloat32m1_t, vfloat32m8_t, vfloat32m1_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vfredmin_vs)))
vfloat32m1_t vfredmin(vfloat32m1_t, vfloat32mf2_t, vfloat32m1_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vfredmin_vs_m)))
vfloat32m1_t vfredmin(vbool64_t, vfloat32m1_t, vfloat32mf2_t, vfloat32m1_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vfredusum_vs)))
vfloat32m1_t vfredusum(vfloat32m1_t, vfloat32m1_t, vfloat32m1_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vfredusum_vs_m)))
vfloat32m1_t vfredusum(vbool32_t, vfloat32m1_t, vfloat32m1_t, vfloat32m1_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vfredusum_vs)))
vfloat32m1_t vfredusum(vfloat32m1_t, vfloat32m2_t, vfloat32m1_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vfredusum_vs_m)))
vfloat32m1_t vfredusum(vbool16_t, vfloat32m1_t, vfloat32m2_t, vfloat32m1_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vfredusum_vs)))
vfloat32m1_t vfredusum(vfloat32m1_t, vfloat32m4_t, vfloat32m1_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vfredusum_vs_m)))
vfloat32m1_t vfredusum(vbool8_t, vfloat32m1_t, vfloat32m4_t, vfloat32m1_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vfredusum_vs)))
vfloat32m1_t vfredusum(vfloat32m1_t, vfloat32m8_t, vfloat32m1_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vfredusum_vs_m)))
vfloat32m1_t vfredusum(vbool4_t, vfloat32m1_t, vfloat32m8_t, vfloat32m1_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vfredusum_vs)))
vfloat32m1_t vfredusum(vfloat32m1_t, vfloat32mf2_t, vfloat32m1_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vfredusum_vs_m)))
vfloat32m1_t vfredusum(vbool64_t, vfloat32m1_t, vfloat32mf2_t, vfloat32m1_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vfredosum_vs)))
vfloat32m1_t vfredosum(vfloat32m1_t, vfloat32m1_t, vfloat32m1_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vfredosum_vs_m)))
vfloat32m1_t vfredosum(vbool32_t, vfloat32m1_t, vfloat32m1_t, vfloat32m1_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vfredosum_vs)))
vfloat32m1_t vfredosum(vfloat32m1_t, vfloat32m2_t, vfloat32m1_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vfredosum_vs_m)))
vfloat32m1_t vfredosum(vbool16_t, vfloat32m1_t, vfloat32m2_t, vfloat32m1_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vfredosum_vs)))
vfloat32m1_t vfredosum(vfloat32m1_t, vfloat32m4_t, vfloat32m1_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vfredosum_vs_m)))
vfloat32m1_t vfredosum(vbool8_t, vfloat32m1_t, vfloat32m4_t, vfloat32m1_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vfredosum_vs)))
vfloat32m1_t vfredosum(vfloat32m1_t, vfloat32m8_t, vfloat32m1_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vfredosum_vs_m)))
vfloat32m1_t vfredosum(vbool4_t, vfloat32m1_t, vfloat32m8_t, vfloat32m1_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vfredosum_vs)))
vfloat32m1_t vfredosum(vfloat32m1_t, vfloat32mf2_t, vfloat32m1_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vfredosum_vs_m)))
vfloat32m1_t vfredosum(vbool64_t, vfloat32m1_t, vfloat32mf2_t, vfloat32m1_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vfmv_f_s)))
float vfmv_f(vfloat32m1_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vfmv_f_s)))
float vfmv_f(vfloat32m2_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vfmv_f_s)))
float vfmv_f(vfloat32m4_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vfmv_f_s)))
float vfmv_f(vfloat32m8_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vfmv_f_s)))
float vfmv_f(vfloat32mf2_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vfmv_s_f)))
vfloat32m1_t vfmv_s(vfloat32m1_t, float, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vfmv_s_f)))
vfloat32m2_t vfmv_s(vfloat32m2_t, float, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vfmv_s_f)))
vfloat32m4_t vfmv_s(vfloat32m4_t, float, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vfmv_s_f)))
vfloat32m8_t vfmv_s(vfloat32m8_t, float, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vfmv_s_f)))
vfloat32mf2_t vfmv_s(vfloat32mf2_t, float, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vslideup_vx)))
vfloat32m1_t vslideup(vfloat32m1_t, vfloat32m1_t, size_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vslideup_vx_m)))
vfloat32m1_t vslideup(vbool32_t, vfloat32m1_t, vfloat32m1_t, size_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vslideup_vx)))
vfloat32m2_t vslideup(vfloat32m2_t, vfloat32m2_t, size_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vslideup_vx_m)))
vfloat32m2_t vslideup(vbool16_t, vfloat32m2_t, vfloat32m2_t, size_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vslideup_vx)))
vfloat32m4_t vslideup(vfloat32m4_t, vfloat32m4_t, size_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vslideup_vx_m)))
vfloat32m4_t vslideup(vbool8_t, vfloat32m4_t, vfloat32m4_t, size_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vslideup_vx)))
vfloat32m8_t vslideup(vfloat32m8_t, vfloat32m8_t, size_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vslideup_vx_m)))
vfloat32m8_t vslideup(vbool4_t, vfloat32m8_t, vfloat32m8_t, size_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vslideup_vx)))
vfloat32mf2_t vslideup(vfloat32mf2_t, vfloat32mf2_t, size_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vslideup_vx_m)))
vfloat32mf2_t vslideup(vbool64_t, vfloat32mf2_t, vfloat32mf2_t, size_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vslidedown_vx)))
vfloat32m1_t vslidedown(vfloat32m1_t, vfloat32m1_t, size_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vslidedown_vx_m)))
vfloat32m1_t vslidedown(vbool32_t, vfloat32m1_t, vfloat32m1_t, size_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vslidedown_vx)))
vfloat32m2_t vslidedown(vfloat32m2_t, vfloat32m2_t, size_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vslidedown_vx_m)))
vfloat32m2_t vslidedown(vbool16_t, vfloat32m2_t, vfloat32m2_t, size_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vslidedown_vx)))
vfloat32m4_t vslidedown(vfloat32m4_t, vfloat32m4_t, size_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vslidedown_vx_m)))
vfloat32m4_t vslidedown(vbool8_t, vfloat32m4_t, vfloat32m4_t, size_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vslidedown_vx)))
vfloat32m8_t vslidedown(vfloat32m8_t, vfloat32m8_t, size_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vslidedown_vx_m)))
vfloat32m8_t vslidedown(vbool4_t, vfloat32m8_t, vfloat32m8_t, size_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vslidedown_vx)))
vfloat32mf2_t vslidedown(vfloat32mf2_t, vfloat32mf2_t, size_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vslidedown_vx_m)))
vfloat32mf2_t vslidedown(vbool64_t, vfloat32mf2_t, vfloat32mf2_t, size_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vfslide1up_vf)))
vfloat32m1_t vfslide1up(vfloat32m1_t, float, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vfslide1up_vf_m)))
vfloat32m1_t vfslide1up(vbool32_t, vfloat32m1_t, vfloat32m1_t, float, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vfslide1up_vf)))
vfloat32m2_t vfslide1up(vfloat32m2_t, float, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vfslide1up_vf_m)))
vfloat32m2_t vfslide1up(vbool16_t, vfloat32m2_t, vfloat32m2_t, float, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vfslide1up_vf)))
vfloat32m4_t vfslide1up(vfloat32m4_t, float, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vfslide1up_vf_m)))
vfloat32m4_t vfslide1up(vbool8_t, vfloat32m4_t, vfloat32m4_t, float, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vfslide1up_vf)))
vfloat32m8_t vfslide1up(vfloat32m8_t, float, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vfslide1up_vf_m)))
vfloat32m8_t vfslide1up(vbool4_t, vfloat32m8_t, vfloat32m8_t, float, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vfslide1up_vf)))
vfloat32mf2_t vfslide1up(vfloat32mf2_t, float, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vfslide1up_vf_m)))
vfloat32mf2_t vfslide1up(vbool64_t, vfloat32mf2_t, vfloat32mf2_t, float, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vfslide1down_vf)))
vfloat32m1_t vfslide1down(vfloat32m1_t, float, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vfslide1down_vf_m)))
vfloat32m1_t vfslide1down(vbool32_t, vfloat32m1_t, vfloat32m1_t, float, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vfslide1down_vf)))
vfloat32m2_t vfslide1down(vfloat32m2_t, float, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vfslide1down_vf_m)))
vfloat32m2_t vfslide1down(vbool16_t, vfloat32m2_t, vfloat32m2_t, float, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vfslide1down_vf)))
vfloat32m4_t vfslide1down(vfloat32m4_t, float, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vfslide1down_vf_m)))
vfloat32m4_t vfslide1down(vbool8_t, vfloat32m4_t, vfloat32m4_t, float, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vfslide1down_vf)))
vfloat32m8_t vfslide1down(vfloat32m8_t, float, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vfslide1down_vf_m)))
vfloat32m8_t vfslide1down(vbool4_t, vfloat32m8_t, vfloat32m8_t, float, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vfslide1down_vf)))
vfloat32mf2_t vfslide1down(vfloat32mf2_t, float, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vfslide1down_vf_m)))
vfloat32mf2_t vfslide1down(vbool64_t, vfloat32mf2_t, vfloat32mf2_t, float, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vrgather_vv)))
vfloat32m1_t vrgather(vfloat32m1_t, vuint32m1_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vrgather_vv_m)))
vfloat32m1_t vrgather(vbool32_t, vfloat32m1_t, vfloat32m1_t, vuint32m1_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vrgather_vv)))
vfloat32m2_t vrgather(vfloat32m2_t, vuint32m2_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vrgather_vv_m)))
vfloat32m2_t vrgather(vbool16_t, vfloat32m2_t, vfloat32m2_t, vuint32m2_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vrgather_vv)))
vfloat32m4_t vrgather(vfloat32m4_t, vuint32m4_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vrgather_vv_m)))
vfloat32m4_t vrgather(vbool8_t, vfloat32m4_t, vfloat32m4_t, vuint32m4_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vrgather_vv)))
vfloat32m8_t vrgather(vfloat32m8_t, vuint32m8_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vrgather_vv_m)))
vfloat32m8_t vrgather(vbool4_t, vfloat32m8_t, vfloat32m8_t, vuint32m8_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vrgather_vv)))
vfloat32mf2_t vrgather(vfloat32mf2_t, vuint32mf2_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vrgather_vv_m)))
vfloat32mf2_t vrgather(vbool64_t, vfloat32mf2_t, vfloat32mf2_t, vuint32mf2_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vrgather_vx)))
vfloat32m1_t vrgather(vfloat32m1_t, size_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vrgather_vx_m)))
vfloat32m1_t vrgather(vbool32_t, vfloat32m1_t, vfloat32m1_t, size_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vrgather_vx)))
vfloat32m2_t vrgather(vfloat32m2_t, size_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vrgather_vx_m)))
vfloat32m2_t vrgather(vbool16_t, vfloat32m2_t, vfloat32m2_t, size_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vrgather_vx)))
vfloat32m4_t vrgather(vfloat32m4_t, size_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vrgather_vx_m)))
vfloat32m4_t vrgather(vbool8_t, vfloat32m4_t, vfloat32m4_t, size_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vrgather_vx)))
vfloat32m8_t vrgather(vfloat32m8_t, size_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vrgather_vx_m)))
vfloat32m8_t vrgather(vbool4_t, vfloat32m8_t, vfloat32m8_t, size_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vrgather_vx)))
vfloat32mf2_t vrgather(vfloat32mf2_t, size_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vrgather_vx_m)))
vfloat32mf2_t vrgather(vbool64_t, vfloat32mf2_t, vfloat32mf2_t, size_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vrgatherei16_vv)))
vfloat32m1_t vrgatherei16(vfloat32m1_t, vuint16mf2_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vrgatherei16_vv_m)))
vfloat32m1_t vrgatherei16(vbool32_t, vfloat32m1_t, vfloat32m1_t, vuint16mf2_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vrgatherei16_vv)))
vfloat32m2_t vrgatherei16(vfloat32m2_t, vuint16m1_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vrgatherei16_vv_m)))
vfloat32m2_t vrgatherei16(vbool16_t, vfloat32m2_t, vfloat32m2_t, vuint16m1_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vrgatherei16_vv)))
vfloat32m4_t vrgatherei16(vfloat32m4_t, vuint16m2_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vrgatherei16_vv_m)))
vfloat32m4_t vrgatherei16(vbool8_t, vfloat32m4_t, vfloat32m4_t, vuint16m2_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vrgatherei16_vv)))
vfloat32m8_t vrgatherei16(vfloat32m8_t, vuint16m4_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vrgatherei16_vv_m)))
vfloat32m8_t vrgatherei16(vbool4_t, vfloat32m8_t, vfloat32m8_t, vuint16m4_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vrgatherei16_vv)))
vfloat32mf2_t vrgatherei16(vfloat32mf2_t, vuint16mf4_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vrgatherei16_vv_m)))
vfloat32mf2_t vrgatherei16(vbool64_t, vfloat32mf2_t, vfloat32mf2_t, vuint16mf4_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vcompress_vm)))
vfloat32m1_t vcompress(vbool32_t, vfloat32m1_t, vfloat32m1_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vcompress_vm)))
vfloat32m2_t vcompress(vbool16_t, vfloat32m2_t, vfloat32m2_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vcompress_vm)))
vfloat32m4_t vcompress(vbool8_t, vfloat32m4_t, vfloat32m4_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vcompress_vm)))
vfloat32m8_t vcompress(vbool4_t, vfloat32m8_t, vfloat32m8_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vcompress_vm)))
vfloat32mf2_t vcompress(vbool64_t, vfloat32mf2_t, vfloat32mf2_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vget_v)))
vfloat32m1_t vget_f32m1(vfloat32m2_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vget_v)))
vfloat32m1_t vget_f32m1(vfloat32m4_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vget_v)))
vfloat32m1_t vget_f32m1(vfloat32m8_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vget_v)))
vfloat32m2_t vget_f32m2(vfloat32m4_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vget_v)))
vfloat32m2_t vget_f32m2(vfloat32m8_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vget_v)))
vfloat32m4_t vget_f32m4(vfloat32m8_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vset_v)))
vfloat32m2_t vset(vfloat32m2_t, size_t, vfloat32m1_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vset_v)))
vfloat32m4_t vset(vfloat32m4_t, size_t, vfloat32m1_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vset_v)))
vfloat32m4_t vset(vfloat32m4_t, size_t, vfloat32m2_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vset_v)))
vfloat32m8_t vset(vfloat32m8_t, size_t, vfloat32m1_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vset_v)))
vfloat32m8_t vset(vfloat32m8_t, size_t, vfloat32m2_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vset_v)))
vfloat32m8_t vset(vfloat32m8_t, size_t, vfloat32m4_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vsuxei8_v)))
void vsuxei8(float *, vuint8mf4_t, vfloat32m1_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vsuxei8_v_m)))
void vsuxei8(vbool32_t, float *, vuint8mf4_t, vfloat32m1_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vsuxei8_v)))
void vsuxei8(float *, vuint8mf2_t, vfloat32m2_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vsuxei8_v_m)))
void vsuxei8(vbool16_t, float *, vuint8mf2_t, vfloat32m2_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vsuxei8_v)))
void vsuxei8(float *, vuint8m1_t, vfloat32m4_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vsuxei8_v_m)))
void vsuxei8(vbool8_t, float *, vuint8m1_t, vfloat32m4_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vsuxei8_v)))
void vsuxei8(float *, vuint8m2_t, vfloat32m8_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vsuxei8_v_m)))
void vsuxei8(vbool4_t, float *, vuint8m2_t, vfloat32m8_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vsuxei8_v)))
void vsuxei8(float *, vuint8mf8_t, vfloat32mf2_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vsuxei8_v_m)))
void vsuxei8(vbool64_t, float *, vuint8mf8_t, vfloat32mf2_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vsuxei16_v)))
void vsuxei16(float *, vuint16mf2_t, vfloat32m1_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vsuxei16_v_m)))
void vsuxei16(vbool32_t, float *, vuint16mf2_t, vfloat32m1_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vsuxei16_v)))
void vsuxei16(float *, vuint16m1_t, vfloat32m2_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vsuxei16_v_m)))
void vsuxei16(vbool16_t, float *, vuint16m1_t, vfloat32m2_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vsuxei16_v)))
void vsuxei16(float *, vuint16m2_t, vfloat32m4_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vsuxei16_v_m)))
void vsuxei16(vbool8_t, float *, vuint16m2_t, vfloat32m4_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vsuxei16_v)))
void vsuxei16(float *, vuint16m4_t, vfloat32m8_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vsuxei16_v_m)))
void vsuxei16(vbool4_t, float *, vuint16m4_t, vfloat32m8_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vsuxei16_v)))
void vsuxei16(float *, vuint16mf4_t, vfloat32mf2_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vsuxei16_v_m)))
void vsuxei16(vbool64_t, float *, vuint16mf4_t, vfloat32mf2_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vsuxei32_v)))
void vsuxei32(float *, vuint32m1_t, vfloat32m1_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vsuxei32_v_m)))
void vsuxei32(vbool32_t, float *, vuint32m1_t, vfloat32m1_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vsuxei32_v)))
void vsuxei32(float *, vuint32m2_t, vfloat32m2_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vsuxei32_v_m)))
void vsuxei32(vbool16_t, float *, vuint32m2_t, vfloat32m2_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vsuxei32_v)))
void vsuxei32(float *, vuint32m4_t, vfloat32m4_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vsuxei32_v_m)))
void vsuxei32(vbool8_t, float *, vuint32m4_t, vfloat32m4_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vsuxei32_v)))
void vsuxei32(float *, vuint32m8_t, vfloat32m8_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vsuxei32_v_m)))
void vsuxei32(vbool4_t, float *, vuint32m8_t, vfloat32m8_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vsuxei32_v)))
void vsuxei32(float *, vuint32mf2_t, vfloat32mf2_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vsuxei32_v_m)))
void vsuxei32(vbool64_t, float *, vuint32mf2_t, vfloat32mf2_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vsoxei8_v)))
void vsoxei8(float *, vuint8mf4_t, vfloat32m1_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vsoxei8_v_m)))
void vsoxei8(vbool32_t, float *, vuint8mf4_t, vfloat32m1_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vsoxei8_v)))
void vsoxei8(float *, vuint8mf2_t, vfloat32m2_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vsoxei8_v_m)))
void vsoxei8(vbool16_t, float *, vuint8mf2_t, vfloat32m2_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vsoxei8_v)))
void vsoxei8(float *, vuint8m1_t, vfloat32m4_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vsoxei8_v_m)))
void vsoxei8(vbool8_t, float *, vuint8m1_t, vfloat32m4_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vsoxei8_v)))
void vsoxei8(float *, vuint8m2_t, vfloat32m8_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vsoxei8_v_m)))
void vsoxei8(vbool4_t, float *, vuint8m2_t, vfloat32m8_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vsoxei8_v)))
void vsoxei8(float *, vuint8mf8_t, vfloat32mf2_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vsoxei8_v_m)))
void vsoxei8(vbool64_t, float *, vuint8mf8_t, vfloat32mf2_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vsoxei16_v)))
void vsoxei16(float *, vuint16mf2_t, vfloat32m1_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vsoxei16_v_m)))
void vsoxei16(vbool32_t, float *, vuint16mf2_t, vfloat32m1_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vsoxei16_v)))
void vsoxei16(float *, vuint16m1_t, vfloat32m2_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vsoxei16_v_m)))
void vsoxei16(vbool16_t, float *, vuint16m1_t, vfloat32m2_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vsoxei16_v)))
void vsoxei16(float *, vuint16m2_t, vfloat32m4_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vsoxei16_v_m)))
void vsoxei16(vbool8_t, float *, vuint16m2_t, vfloat32m4_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vsoxei16_v)))
void vsoxei16(float *, vuint16m4_t, vfloat32m8_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vsoxei16_v_m)))
void vsoxei16(vbool4_t, float *, vuint16m4_t, vfloat32m8_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vsoxei16_v)))
void vsoxei16(float *, vuint16mf4_t, vfloat32mf2_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vsoxei16_v_m)))
void vsoxei16(vbool64_t, float *, vuint16mf4_t, vfloat32mf2_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vsoxei32_v)))
void vsoxei32(float *, vuint32m1_t, vfloat32m1_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vsoxei32_v_m)))
void vsoxei32(vbool32_t, float *, vuint32m1_t, vfloat32m1_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vsoxei32_v)))
void vsoxei32(float *, vuint32m2_t, vfloat32m2_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vsoxei32_v_m)))
void vsoxei32(vbool16_t, float *, vuint32m2_t, vfloat32m2_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vsoxei32_v)))
void vsoxei32(float *, vuint32m4_t, vfloat32m4_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vsoxei32_v_m)))
void vsoxei32(vbool8_t, float *, vuint32m4_t, vfloat32m4_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vsoxei32_v)))
void vsoxei32(float *, vuint32m8_t, vfloat32m8_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vsoxei32_v_m)))
void vsoxei32(vbool4_t, float *, vuint32m8_t, vfloat32m8_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vsoxei32_v)))
void vsoxei32(float *, vuint32mf2_t, vfloat32mf2_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vsoxei32_v_m)))
void vsoxei32(vbool64_t, float *, vuint32mf2_t, vfloat32mf2_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vle32ff_v_m)))
vfloat32m1_t vle32ff(vbool32_t, vfloat32m1_t, const float *, size_t *, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vle32ff_v_m)))
vfloat32m2_t vle32ff(vbool16_t, vfloat32m2_t, const float *, size_t *, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vle32ff_v_m)))
vfloat32m4_t vle32ff(vbool8_t, vfloat32m4_t, const float *, size_t *, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vle32ff_v_m)))
vfloat32m8_t vle32ff(vbool4_t, vfloat32m8_t, const float *, size_t *, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vle32ff_v_m)))
vfloat32mf2_t vle32ff(vbool64_t, vfloat32mf2_t, const float *, size_t *, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vlseg2e32_v_m)))
void vlseg2e32(vfloat32m1_t *, vfloat32m1_t *, vbool32_t, vfloat32m1_t, vfloat32m1_t, const float *, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vlseg2e32_v_m)))
void vlseg2e32(vfloat32m2_t *, vfloat32m2_t *, vbool16_t, vfloat32m2_t, vfloat32m2_t, const float *, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vlseg2e32_v_m)))
void vlseg2e32(vfloat32m4_t *, vfloat32m4_t *, vbool8_t, vfloat32m4_t, vfloat32m4_t, const float *, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vlseg2e32_v_m)))
void vlseg2e32(vfloat32mf2_t *, vfloat32mf2_t *, vbool64_t, vfloat32mf2_t, vfloat32mf2_t, const float *, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vlseg3e32_v_m)))
void vlseg3e32(vfloat32m1_t *, vfloat32m1_t *, vfloat32m1_t *, vbool32_t, vfloat32m1_t, vfloat32m1_t, vfloat32m1_t, const float *, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vlseg3e32_v_m)))
void vlseg3e32(vfloat32m2_t *, vfloat32m2_t *, vfloat32m2_t *, vbool16_t, vfloat32m2_t, vfloat32m2_t, vfloat32m2_t, const float *, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vlseg3e32_v_m)))
void vlseg3e32(vfloat32mf2_t *, vfloat32mf2_t *, vfloat32mf2_t *, vbool64_t, vfloat32mf2_t, vfloat32mf2_t, vfloat32mf2_t, const float *, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vlseg4e32_v_m)))
void vlseg4e32(vfloat32m1_t *, vfloat32m1_t *, vfloat32m1_t *, vfloat32m1_t *, vbool32_t, vfloat32m1_t, vfloat32m1_t, vfloat32m1_t, vfloat32m1_t, const float *, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vlseg4e32_v_m)))
void vlseg4e32(vfloat32m2_t *, vfloat32m2_t *, vfloat32m2_t *, vfloat32m2_t *, vbool16_t, vfloat32m2_t, vfloat32m2_t, vfloat32m2_t, vfloat32m2_t, const float *, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vlseg4e32_v_m)))
void vlseg4e32(vfloat32mf2_t *, vfloat32mf2_t *, vfloat32mf2_t *, vfloat32mf2_t *, vbool64_t, vfloat32mf2_t, vfloat32mf2_t, vfloat32mf2_t, vfloat32mf2_t, const float *, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vlseg5e32_v_m)))
void vlseg5e32(vfloat32m1_t *, vfloat32m1_t *, vfloat32m1_t *, vfloat32m1_t *, vfloat32m1_t *, vbool32_t, vfloat32m1_t, vfloat32m1_t, vfloat32m1_t, vfloat32m1_t, vfloat32m1_t, const float *, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vlseg5e32_v_m)))
void vlseg5e32(vfloat32mf2_t *, vfloat32mf2_t *, vfloat32mf2_t *, vfloat32mf2_t *, vfloat32mf2_t *, vbool64_t, vfloat32mf2_t, vfloat32mf2_t, vfloat32mf2_t, vfloat32mf2_t, vfloat32mf2_t, const float *, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vlseg6e32_v_m)))
void vlseg6e32(vfloat32m1_t *, vfloat32m1_t *, vfloat32m1_t *, vfloat32m1_t *, vfloat32m1_t *, vfloat32m1_t *, vbool32_t, vfloat32m1_t, vfloat32m1_t, vfloat32m1_t, vfloat32m1_t, vfloat32m1_t, vfloat32m1_t, const float *, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vlseg6e32_v_m)))
void vlseg6e32(vfloat32mf2_t *, vfloat32mf2_t *, vfloat32mf2_t *, vfloat32mf2_t *, vfloat32mf2_t *, vfloat32mf2_t *, vbool64_t, vfloat32mf2_t, vfloat32mf2_t, vfloat32mf2_t, vfloat32mf2_t, vfloat32mf2_t, vfloat32mf2_t, const float *, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vlseg7e32_v_m)))
void vlseg7e32(vfloat32m1_t *, vfloat32m1_t *, vfloat32m1_t *, vfloat32m1_t *, vfloat32m1_t *, vfloat32m1_t *, vfloat32m1_t *, vbool32_t, vfloat32m1_t, vfloat32m1_t, vfloat32m1_t, vfloat32m1_t, vfloat32m1_t, vfloat32m1_t, vfloat32m1_t, const float *, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vlseg7e32_v_m)))
void vlseg7e32(vfloat32mf2_t *, vfloat32mf2_t *, vfloat32mf2_t *, vfloat32mf2_t *, vfloat32mf2_t *, vfloat32mf2_t *, vfloat32mf2_t *, vbool64_t, vfloat32mf2_t, vfloat32mf2_t, vfloat32mf2_t, vfloat32mf2_t, vfloat32mf2_t, vfloat32mf2_t, vfloat32mf2_t, const float *, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vlseg8e32_v_m)))
void vlseg8e32(vfloat32m1_t *, vfloat32m1_t *, vfloat32m1_t *, vfloat32m1_t *, vfloat32m1_t *, vfloat32m1_t *, vfloat32m1_t *, vfloat32m1_t *, vbool32_t, vfloat32m1_t, vfloat32m1_t, vfloat32m1_t, vfloat32m1_t, vfloat32m1_t, vfloat32m1_t, vfloat32m1_t, vfloat32m1_t, const float *, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vlseg8e32_v_m)))
void vlseg8e32(vfloat32mf2_t *, vfloat32mf2_t *, vfloat32mf2_t *, vfloat32mf2_t *, vfloat32mf2_t *, vfloat32mf2_t *, vfloat32mf2_t *, vfloat32mf2_t *, vbool64_t, vfloat32mf2_t, vfloat32mf2_t, vfloat32mf2_t, vfloat32mf2_t, vfloat32mf2_t, vfloat32mf2_t, vfloat32mf2_t, vfloat32mf2_t, const float *, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vlseg2e32ff_v_m)))
void vlseg2e32ff(vfloat32m1_t *, vfloat32m1_t *, vbool32_t, vfloat32m1_t, vfloat32m1_t, const float *, size_t *, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vlseg2e32ff_v_m)))
void vlseg2e32ff(vfloat32m2_t *, vfloat32m2_t *, vbool16_t, vfloat32m2_t, vfloat32m2_t, const float *, size_t *, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vlseg2e32ff_v_m)))
void vlseg2e32ff(vfloat32m4_t *, vfloat32m4_t *, vbool8_t, vfloat32m4_t, vfloat32m4_t, const float *, size_t *, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vlseg2e32ff_v_m)))
void vlseg2e32ff(vfloat32mf2_t *, vfloat32mf2_t *, vbool64_t, vfloat32mf2_t, vfloat32mf2_t, const float *, size_t *, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vlseg3e32ff_v_m)))
void vlseg3e32ff(vfloat32m1_t *, vfloat32m1_t *, vfloat32m1_t *, vbool32_t, vfloat32m1_t, vfloat32m1_t, vfloat32m1_t, const float *, size_t *, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vlseg3e32ff_v_m)))
void vlseg3e32ff(vfloat32m2_t *, vfloat32m2_t *, vfloat32m2_t *, vbool16_t, vfloat32m2_t, vfloat32m2_t, vfloat32m2_t, const float *, size_t *, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vlseg3e32ff_v_m)))
void vlseg3e32ff(vfloat32mf2_t *, vfloat32mf2_t *, vfloat32mf2_t *, vbool64_t, vfloat32mf2_t, vfloat32mf2_t, vfloat32mf2_t, const float *, size_t *, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vlseg4e32ff_v_m)))
void vlseg4e32ff(vfloat32m1_t *, vfloat32m1_t *, vfloat32m1_t *, vfloat32m1_t *, vbool32_t, vfloat32m1_t, vfloat32m1_t, vfloat32m1_t, vfloat32m1_t, const float *, size_t *, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vlseg4e32ff_v_m)))
void vlseg4e32ff(vfloat32m2_t *, vfloat32m2_t *, vfloat32m2_t *, vfloat32m2_t *, vbool16_t, vfloat32m2_t, vfloat32m2_t, vfloat32m2_t, vfloat32m2_t, const float *, size_t *, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vlseg4e32ff_v_m)))
void vlseg4e32ff(vfloat32mf2_t *, vfloat32mf2_t *, vfloat32mf2_t *, vfloat32mf2_t *, vbool64_t, vfloat32mf2_t, vfloat32mf2_t, vfloat32mf2_t, vfloat32mf2_t, const float *, size_t *, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vlseg5e32ff_v_m)))
void vlseg5e32ff(vfloat32m1_t *, vfloat32m1_t *, vfloat32m1_t *, vfloat32m1_t *, vfloat32m1_t *, vbool32_t, vfloat32m1_t, vfloat32m1_t, vfloat32m1_t, vfloat32m1_t, vfloat32m1_t, const float *, size_t *, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vlseg5e32ff_v_m)))
void vlseg5e32ff(vfloat32mf2_t *, vfloat32mf2_t *, vfloat32mf2_t *, vfloat32mf2_t *, vfloat32mf2_t *, vbool64_t, vfloat32mf2_t, vfloat32mf2_t, vfloat32mf2_t, vfloat32mf2_t, vfloat32mf2_t, const float *, size_t *, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vlseg6e32ff_v_m)))
void vlseg6e32ff(vfloat32m1_t *, vfloat32m1_t *, vfloat32m1_t *, vfloat32m1_t *, vfloat32m1_t *, vfloat32m1_t *, vbool32_t, vfloat32m1_t, vfloat32m1_t, vfloat32m1_t, vfloat32m1_t, vfloat32m1_t, vfloat32m1_t, const float *, size_t *, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vlseg6e32ff_v_m)))
void vlseg6e32ff(vfloat32mf2_t *, vfloat32mf2_t *, vfloat32mf2_t *, vfloat32mf2_t *, vfloat32mf2_t *, vfloat32mf2_t *, vbool64_t, vfloat32mf2_t, vfloat32mf2_t, vfloat32mf2_t, vfloat32mf2_t, vfloat32mf2_t, vfloat32mf2_t, const float *, size_t *, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vlseg7e32ff_v_m)))
void vlseg7e32ff(vfloat32m1_t *, vfloat32m1_t *, vfloat32m1_t *, vfloat32m1_t *, vfloat32m1_t *, vfloat32m1_t *, vfloat32m1_t *, vbool32_t, vfloat32m1_t, vfloat32m1_t, vfloat32m1_t, vfloat32m1_t, vfloat32m1_t, vfloat32m1_t, vfloat32m1_t, const float *, size_t *, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vlseg7e32ff_v_m)))
void vlseg7e32ff(vfloat32mf2_t *, vfloat32mf2_t *, vfloat32mf2_t *, vfloat32mf2_t *, vfloat32mf2_t *, vfloat32mf2_t *, vfloat32mf2_t *, vbool64_t, vfloat32mf2_t, vfloat32mf2_t, vfloat32mf2_t, vfloat32mf2_t, vfloat32mf2_t, vfloat32mf2_t, vfloat32mf2_t, const float *, size_t *, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vlseg8e32ff_v_m)))
void vlseg8e32ff(vfloat32m1_t *, vfloat32m1_t *, vfloat32m1_t *, vfloat32m1_t *, vfloat32m1_t *, vfloat32m1_t *, vfloat32m1_t *, vfloat32m1_t *, vbool32_t, vfloat32m1_t, vfloat32m1_t, vfloat32m1_t, vfloat32m1_t, vfloat32m1_t, vfloat32m1_t, vfloat32m1_t, vfloat32m1_t, const float *, size_t *, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vlseg8e32ff_v_m)))
void vlseg8e32ff(vfloat32mf2_t *, vfloat32mf2_t *, vfloat32mf2_t *, vfloat32mf2_t *, vfloat32mf2_t *, vfloat32mf2_t *, vfloat32mf2_t *, vfloat32mf2_t *, vbool64_t, vfloat32mf2_t, vfloat32mf2_t, vfloat32mf2_t, vfloat32mf2_t, vfloat32mf2_t, vfloat32mf2_t, vfloat32mf2_t, vfloat32mf2_t, const float *, size_t *, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vlsseg2e32_v_m)))
void vlsseg2e32(vfloat32m1_t *, vfloat32m1_t *, vbool32_t, vfloat32m1_t, vfloat32m1_t, const float *, ptrdiff_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vlsseg2e32_v_m)))
void vlsseg2e32(vfloat32m2_t *, vfloat32m2_t *, vbool16_t, vfloat32m2_t, vfloat32m2_t, const float *, ptrdiff_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vlsseg2e32_v_m)))
void vlsseg2e32(vfloat32m4_t *, vfloat32m4_t *, vbool8_t, vfloat32m4_t, vfloat32m4_t, const float *, ptrdiff_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vlsseg2e32_v_m)))
void vlsseg2e32(vfloat32mf2_t *, vfloat32mf2_t *, vbool64_t, vfloat32mf2_t, vfloat32mf2_t, const float *, ptrdiff_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vlsseg3e32_v_m)))
void vlsseg3e32(vfloat32m1_t *, vfloat32m1_t *, vfloat32m1_t *, vbool32_t, vfloat32m1_t, vfloat32m1_t, vfloat32m1_t, const float *, ptrdiff_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vlsseg3e32_v_m)))
void vlsseg3e32(vfloat32m2_t *, vfloat32m2_t *, vfloat32m2_t *, vbool16_t, vfloat32m2_t, vfloat32m2_t, vfloat32m2_t, const float *, ptrdiff_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vlsseg3e32_v_m)))
void vlsseg3e32(vfloat32mf2_t *, vfloat32mf2_t *, vfloat32mf2_t *, vbool64_t, vfloat32mf2_t, vfloat32mf2_t, vfloat32mf2_t, const float *, ptrdiff_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vlsseg4e32_v_m)))
void vlsseg4e32(vfloat32m1_t *, vfloat32m1_t *, vfloat32m1_t *, vfloat32m1_t *, vbool32_t, vfloat32m1_t, vfloat32m1_t, vfloat32m1_t, vfloat32m1_t, const float *, ptrdiff_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vlsseg4e32_v_m)))
void vlsseg4e32(vfloat32m2_t *, vfloat32m2_t *, vfloat32m2_t *, vfloat32m2_t *, vbool16_t, vfloat32m2_t, vfloat32m2_t, vfloat32m2_t, vfloat32m2_t, const float *, ptrdiff_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vlsseg4e32_v_m)))
void vlsseg4e32(vfloat32mf2_t *, vfloat32mf2_t *, vfloat32mf2_t *, vfloat32mf2_t *, vbool64_t, vfloat32mf2_t, vfloat32mf2_t, vfloat32mf2_t, vfloat32mf2_t, const float *, ptrdiff_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vlsseg5e32_v_m)))
void vlsseg5e32(vfloat32m1_t *, vfloat32m1_t *, vfloat32m1_t *, vfloat32m1_t *, vfloat32m1_t *, vbool32_t, vfloat32m1_t, vfloat32m1_t, vfloat32m1_t, vfloat32m1_t, vfloat32m1_t, const float *, ptrdiff_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vlsseg5e32_v_m)))
void vlsseg5e32(vfloat32mf2_t *, vfloat32mf2_t *, vfloat32mf2_t *, vfloat32mf2_t *, vfloat32mf2_t *, vbool64_t, vfloat32mf2_t, vfloat32mf2_t, vfloat32mf2_t, vfloat32mf2_t, vfloat32mf2_t, const float *, ptrdiff_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vlsseg6e32_v_m)))
void vlsseg6e32(vfloat32m1_t *, vfloat32m1_t *, vfloat32m1_t *, vfloat32m1_t *, vfloat32m1_t *, vfloat32m1_t *, vbool32_t, vfloat32m1_t, vfloat32m1_t, vfloat32m1_t, vfloat32m1_t, vfloat32m1_t, vfloat32m1_t, const float *, ptrdiff_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vlsseg6e32_v_m)))
void vlsseg6e32(vfloat32mf2_t *, vfloat32mf2_t *, vfloat32mf2_t *, vfloat32mf2_t *, vfloat32mf2_t *, vfloat32mf2_t *, vbool64_t, vfloat32mf2_t, vfloat32mf2_t, vfloat32mf2_t, vfloat32mf2_t, vfloat32mf2_t, vfloat32mf2_t, const float *, ptrdiff_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vlsseg7e32_v_m)))
void vlsseg7e32(vfloat32m1_t *, vfloat32m1_t *, vfloat32m1_t *, vfloat32m1_t *, vfloat32m1_t *, vfloat32m1_t *, vfloat32m1_t *, vbool32_t, vfloat32m1_t, vfloat32m1_t, vfloat32m1_t, vfloat32m1_t, vfloat32m1_t, vfloat32m1_t, vfloat32m1_t, const float *, ptrdiff_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vlsseg7e32_v_m)))
void vlsseg7e32(vfloat32mf2_t *, vfloat32mf2_t *, vfloat32mf2_t *, vfloat32mf2_t *, vfloat32mf2_t *, vfloat32mf2_t *, vfloat32mf2_t *, vbool64_t, vfloat32mf2_t, vfloat32mf2_t, vfloat32mf2_t, vfloat32mf2_t, vfloat32mf2_t, vfloat32mf2_t, vfloat32mf2_t, const float *, ptrdiff_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vlsseg8e32_v_m)))
void vlsseg8e32(vfloat32m1_t *, vfloat32m1_t *, vfloat32m1_t *, vfloat32m1_t *, vfloat32m1_t *, vfloat32m1_t *, vfloat32m1_t *, vfloat32m1_t *, vbool32_t, vfloat32m1_t, vfloat32m1_t, vfloat32m1_t, vfloat32m1_t, vfloat32m1_t, vfloat32m1_t, vfloat32m1_t, vfloat32m1_t, const float *, ptrdiff_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vlsseg8e32_v_m)))
void vlsseg8e32(vfloat32mf2_t *, vfloat32mf2_t *, vfloat32mf2_t *, vfloat32mf2_t *, vfloat32mf2_t *, vfloat32mf2_t *, vfloat32mf2_t *, vfloat32mf2_t *, vbool64_t, vfloat32mf2_t, vfloat32mf2_t, vfloat32mf2_t, vfloat32mf2_t, vfloat32mf2_t, vfloat32mf2_t, vfloat32mf2_t, vfloat32mf2_t, const float *, ptrdiff_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vfneg_v)))
vfloat32m1_t vfneg(vfloat32m1_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vfneg_v_m)))
vfloat32m1_t vfneg(vbool32_t, vfloat32m1_t, vfloat32m1_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vfneg_v)))
vfloat32m2_t vfneg(vfloat32m2_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vfneg_v_m)))
vfloat32m2_t vfneg(vbool16_t, vfloat32m2_t, vfloat32m2_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vfneg_v)))
vfloat32m4_t vfneg(vfloat32m4_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vfneg_v_m)))
vfloat32m4_t vfneg(vbool8_t, vfloat32m4_t, vfloat32m4_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vfneg_v)))
vfloat32m8_t vfneg(vfloat32m8_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vfneg_v_m)))
vfloat32m8_t vfneg(vbool4_t, vfloat32m8_t, vfloat32m8_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vfneg_v)))
vfloat32mf2_t vfneg(vfloat32mf2_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vfneg_v_m)))
vfloat32mf2_t vfneg(vbool64_t, vfloat32mf2_t, vfloat32mf2_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vluxseg2ei8_v)))
void vluxseg2ei8(vfloat32m1_t *, vfloat32m1_t *, const float *, vuint8mf4_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vluxseg2ei8_v_m)))
void vluxseg2ei8(vfloat32m1_t *, vfloat32m1_t *, vbool32_t, vfloat32m1_t, vfloat32m1_t, const float *, vuint8mf4_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vluxseg2ei8_v)))
void vluxseg2ei8(vfloat32m2_t *, vfloat32m2_t *, const float *, vuint8mf2_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vluxseg2ei8_v_m)))
void vluxseg2ei8(vfloat32m2_t *, vfloat32m2_t *, vbool16_t, vfloat32m2_t, vfloat32m2_t, const float *, vuint8mf2_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vluxseg2ei8_v)))
void vluxseg2ei8(vfloat32m4_t *, vfloat32m4_t *, const float *, vuint8m1_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vluxseg2ei8_v_m)))
void vluxseg2ei8(vfloat32m4_t *, vfloat32m4_t *, vbool8_t, vfloat32m4_t, vfloat32m4_t, const float *, vuint8m1_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vluxseg2ei8_v)))
void vluxseg2ei8(vfloat32mf2_t *, vfloat32mf2_t *, const float *, vuint8mf8_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vluxseg2ei8_v_m)))
void vluxseg2ei8(vfloat32mf2_t *, vfloat32mf2_t *, vbool64_t, vfloat32mf2_t, vfloat32mf2_t, const float *, vuint8mf8_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vluxseg3ei8_v)))
void vluxseg3ei8(vfloat32m1_t *, vfloat32m1_t *, vfloat32m1_t *, const float *, vuint8mf4_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vluxseg3ei8_v_m)))
void vluxseg3ei8(vfloat32m1_t *, vfloat32m1_t *, vfloat32m1_t *, vbool32_t, vfloat32m1_t, vfloat32m1_t, vfloat32m1_t, const float *, vuint8mf4_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vluxseg3ei8_v)))
void vluxseg3ei8(vfloat32m2_t *, vfloat32m2_t *, vfloat32m2_t *, const float *, vuint8mf2_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vluxseg3ei8_v_m)))
void vluxseg3ei8(vfloat32m2_t *, vfloat32m2_t *, vfloat32m2_t *, vbool16_t, vfloat32m2_t, vfloat32m2_t, vfloat32m2_t, const float *, vuint8mf2_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vluxseg3ei8_v)))
void vluxseg3ei8(vfloat32mf2_t *, vfloat32mf2_t *, vfloat32mf2_t *, const float *, vuint8mf8_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vluxseg3ei8_v_m)))
void vluxseg3ei8(vfloat32mf2_t *, vfloat32mf2_t *, vfloat32mf2_t *, vbool64_t, vfloat32mf2_t, vfloat32mf2_t, vfloat32mf2_t, const float *, vuint8mf8_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vluxseg4ei8_v)))
void vluxseg4ei8(vfloat32m1_t *, vfloat32m1_t *, vfloat32m1_t *, vfloat32m1_t *, const float *, vuint8mf4_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vluxseg4ei8_v_m)))
void vluxseg4ei8(vfloat32m1_t *, vfloat32m1_t *, vfloat32m1_t *, vfloat32m1_t *, vbool32_t, vfloat32m1_t, vfloat32m1_t, vfloat32m1_t, vfloat32m1_t, const float *, vuint8mf4_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vluxseg4ei8_v)))
void vluxseg4ei8(vfloat32m2_t *, vfloat32m2_t *, vfloat32m2_t *, vfloat32m2_t *, const float *, vuint8mf2_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vluxseg4ei8_v_m)))
void vluxseg4ei8(vfloat32m2_t *, vfloat32m2_t *, vfloat32m2_t *, vfloat32m2_t *, vbool16_t, vfloat32m2_t, vfloat32m2_t, vfloat32m2_t, vfloat32m2_t, const float *, vuint8mf2_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vluxseg4ei8_v)))
void vluxseg4ei8(vfloat32mf2_t *, vfloat32mf2_t *, vfloat32mf2_t *, vfloat32mf2_t *, const float *, vuint8mf8_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vluxseg4ei8_v_m)))
void vluxseg4ei8(vfloat32mf2_t *, vfloat32mf2_t *, vfloat32mf2_t *, vfloat32mf2_t *, vbool64_t, vfloat32mf2_t, vfloat32mf2_t, vfloat32mf2_t, vfloat32mf2_t, const float *, vuint8mf8_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vluxseg5ei8_v)))
void vluxseg5ei8(vfloat32m1_t *, vfloat32m1_t *, vfloat32m1_t *, vfloat32m1_t *, vfloat32m1_t *, const float *, vuint8mf4_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vluxseg5ei8_v_m)))
void vluxseg5ei8(vfloat32m1_t *, vfloat32m1_t *, vfloat32m1_t *, vfloat32m1_t *, vfloat32m1_t *, vbool32_t, vfloat32m1_t, vfloat32m1_t, vfloat32m1_t, vfloat32m1_t, vfloat32m1_t, const float *, vuint8mf4_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vluxseg5ei8_v)))
void vluxseg5ei8(vfloat32mf2_t *, vfloat32mf2_t *, vfloat32mf2_t *, vfloat32mf2_t *, vfloat32mf2_t *, const float *, vuint8mf8_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vluxseg5ei8_v_m)))
void vluxseg5ei8(vfloat32mf2_t *, vfloat32mf2_t *, vfloat32mf2_t *, vfloat32mf2_t *, vfloat32mf2_t *, vbool64_t, vfloat32mf2_t, vfloat32mf2_t, vfloat32mf2_t, vfloat32mf2_t, vfloat32mf2_t, const float *, vuint8mf8_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vluxseg6ei8_v)))
void vluxseg6ei8(vfloat32m1_t *, vfloat32m1_t *, vfloat32m1_t *, vfloat32m1_t *, vfloat32m1_t *, vfloat32m1_t *, const float *, vuint8mf4_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vluxseg6ei8_v_m)))
void vluxseg6ei8(vfloat32m1_t *, vfloat32m1_t *, vfloat32m1_t *, vfloat32m1_t *, vfloat32m1_t *, vfloat32m1_t *, vbool32_t, vfloat32m1_t, vfloat32m1_t, vfloat32m1_t, vfloat32m1_t, vfloat32m1_t, vfloat32m1_t, const float *, vuint8mf4_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vluxseg6ei8_v)))
void vluxseg6ei8(vfloat32mf2_t *, vfloat32mf2_t *, vfloat32mf2_t *, vfloat32mf2_t *, vfloat32mf2_t *, vfloat32mf2_t *, const float *, vuint8mf8_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vluxseg6ei8_v_m)))
void vluxseg6ei8(vfloat32mf2_t *, vfloat32mf2_t *, vfloat32mf2_t *, vfloat32mf2_t *, vfloat32mf2_t *, vfloat32mf2_t *, vbool64_t, vfloat32mf2_t, vfloat32mf2_t, vfloat32mf2_t, vfloat32mf2_t, vfloat32mf2_t, vfloat32mf2_t, const float *, vuint8mf8_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vluxseg7ei8_v)))
void vluxseg7ei8(vfloat32m1_t *, vfloat32m1_t *, vfloat32m1_t *, vfloat32m1_t *, vfloat32m1_t *, vfloat32m1_t *, vfloat32m1_t *, const float *, vuint8mf4_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vluxseg7ei8_v_m)))
void vluxseg7ei8(vfloat32m1_t *, vfloat32m1_t *, vfloat32m1_t *, vfloat32m1_t *, vfloat32m1_t *, vfloat32m1_t *, vfloat32m1_t *, vbool32_t, vfloat32m1_t, vfloat32m1_t, vfloat32m1_t, vfloat32m1_t, vfloat32m1_t, vfloat32m1_t, vfloat32m1_t, const float *, vuint8mf4_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vluxseg7ei8_v)))
void vluxseg7ei8(vfloat32mf2_t *, vfloat32mf2_t *, vfloat32mf2_t *, vfloat32mf2_t *, vfloat32mf2_t *, vfloat32mf2_t *, vfloat32mf2_t *, const float *, vuint8mf8_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vluxseg7ei8_v_m)))
void vluxseg7ei8(vfloat32mf2_t *, vfloat32mf2_t *, vfloat32mf2_t *, vfloat32mf2_t *, vfloat32mf2_t *, vfloat32mf2_t *, vfloat32mf2_t *, vbool64_t, vfloat32mf2_t, vfloat32mf2_t, vfloat32mf2_t, vfloat32mf2_t, vfloat32mf2_t, vfloat32mf2_t, vfloat32mf2_t, const float *, vuint8mf8_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vluxseg8ei8_v)))
void vluxseg8ei8(vfloat32m1_t *, vfloat32m1_t *, vfloat32m1_t *, vfloat32m1_t *, vfloat32m1_t *, vfloat32m1_t *, vfloat32m1_t *, vfloat32m1_t *, const float *, vuint8mf4_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vluxseg8ei8_v_m)))
void vluxseg8ei8(vfloat32m1_t *, vfloat32m1_t *, vfloat32m1_t *, vfloat32m1_t *, vfloat32m1_t *, vfloat32m1_t *, vfloat32m1_t *, vfloat32m1_t *, vbool32_t, vfloat32m1_t, vfloat32m1_t, vfloat32m1_t, vfloat32m1_t, vfloat32m1_t, vfloat32m1_t, vfloat32m1_t, vfloat32m1_t, const float *, vuint8mf4_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vluxseg8ei8_v)))
void vluxseg8ei8(vfloat32mf2_t *, vfloat32mf2_t *, vfloat32mf2_t *, vfloat32mf2_t *, vfloat32mf2_t *, vfloat32mf2_t *, vfloat32mf2_t *, vfloat32mf2_t *, const float *, vuint8mf8_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vluxseg8ei8_v_m)))
void vluxseg8ei8(vfloat32mf2_t *, vfloat32mf2_t *, vfloat32mf2_t *, vfloat32mf2_t *, vfloat32mf2_t *, vfloat32mf2_t *, vfloat32mf2_t *, vfloat32mf2_t *, vbool64_t, vfloat32mf2_t, vfloat32mf2_t, vfloat32mf2_t, vfloat32mf2_t, vfloat32mf2_t, vfloat32mf2_t, vfloat32mf2_t, vfloat32mf2_t, const float *, vuint8mf8_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vluxseg2ei16_v)))
void vluxseg2ei16(vfloat32m1_t *, vfloat32m1_t *, const float *, vuint16mf2_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vluxseg2ei16_v_m)))
void vluxseg2ei16(vfloat32m1_t *, vfloat32m1_t *, vbool32_t, vfloat32m1_t, vfloat32m1_t, const float *, vuint16mf2_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vluxseg2ei16_v)))
void vluxseg2ei16(vfloat32m2_t *, vfloat32m2_t *, const float *, vuint16m1_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vluxseg2ei16_v_m)))
void vluxseg2ei16(vfloat32m2_t *, vfloat32m2_t *, vbool16_t, vfloat32m2_t, vfloat32m2_t, const float *, vuint16m1_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vluxseg2ei16_v)))
void vluxseg2ei16(vfloat32m4_t *, vfloat32m4_t *, const float *, vuint16m2_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vluxseg2ei16_v_m)))
void vluxseg2ei16(vfloat32m4_t *, vfloat32m4_t *, vbool8_t, vfloat32m4_t, vfloat32m4_t, const float *, vuint16m2_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vluxseg2ei16_v)))
void vluxseg2ei16(vfloat32mf2_t *, vfloat32mf2_t *, const float *, vuint16mf4_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vluxseg2ei16_v_m)))
void vluxseg2ei16(vfloat32mf2_t *, vfloat32mf2_t *, vbool64_t, vfloat32mf2_t, vfloat32mf2_t, const float *, vuint16mf4_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vluxseg3ei16_v)))
void vluxseg3ei16(vfloat32m1_t *, vfloat32m1_t *, vfloat32m1_t *, const float *, vuint16mf2_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vluxseg3ei16_v_m)))
void vluxseg3ei16(vfloat32m1_t *, vfloat32m1_t *, vfloat32m1_t *, vbool32_t, vfloat32m1_t, vfloat32m1_t, vfloat32m1_t, const float *, vuint16mf2_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vluxseg3ei16_v)))
void vluxseg3ei16(vfloat32m2_t *, vfloat32m2_t *, vfloat32m2_t *, const float *, vuint16m1_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vluxseg3ei16_v_m)))
void vluxseg3ei16(vfloat32m2_t *, vfloat32m2_t *, vfloat32m2_t *, vbool16_t, vfloat32m2_t, vfloat32m2_t, vfloat32m2_t, const float *, vuint16m1_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vluxseg3ei16_v)))
void vluxseg3ei16(vfloat32mf2_t *, vfloat32mf2_t *, vfloat32mf2_t *, const float *, vuint16mf4_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vluxseg3ei16_v_m)))
void vluxseg3ei16(vfloat32mf2_t *, vfloat32mf2_t *, vfloat32mf2_t *, vbool64_t, vfloat32mf2_t, vfloat32mf2_t, vfloat32mf2_t, const float *, vuint16mf4_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vluxseg4ei16_v)))
void vluxseg4ei16(vfloat32m1_t *, vfloat32m1_t *, vfloat32m1_t *, vfloat32m1_t *, const float *, vuint16mf2_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vluxseg4ei16_v_m)))
void vluxseg4ei16(vfloat32m1_t *, vfloat32m1_t *, vfloat32m1_t *, vfloat32m1_t *, vbool32_t, vfloat32m1_t, vfloat32m1_t, vfloat32m1_t, vfloat32m1_t, const float *, vuint16mf2_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vluxseg4ei16_v)))
void vluxseg4ei16(vfloat32m2_t *, vfloat32m2_t *, vfloat32m2_t *, vfloat32m2_t *, const float *, vuint16m1_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vluxseg4ei16_v_m)))
void vluxseg4ei16(vfloat32m2_t *, vfloat32m2_t *, vfloat32m2_t *, vfloat32m2_t *, vbool16_t, vfloat32m2_t, vfloat32m2_t, vfloat32m2_t, vfloat32m2_t, const float *, vuint16m1_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vluxseg4ei16_v)))
void vluxseg4ei16(vfloat32mf2_t *, vfloat32mf2_t *, vfloat32mf2_t *, vfloat32mf2_t *, const float *, vuint16mf4_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vluxseg4ei16_v_m)))
void vluxseg4ei16(vfloat32mf2_t *, vfloat32mf2_t *, vfloat32mf2_t *, vfloat32mf2_t *, vbool64_t, vfloat32mf2_t, vfloat32mf2_t, vfloat32mf2_t, vfloat32mf2_t, const float *, vuint16mf4_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vluxseg5ei16_v)))
void vluxseg5ei16(vfloat32m1_t *, vfloat32m1_t *, vfloat32m1_t *, vfloat32m1_t *, vfloat32m1_t *, const float *, vuint16mf2_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vluxseg5ei16_v_m)))
void vluxseg5ei16(vfloat32m1_t *, vfloat32m1_t *, vfloat32m1_t *, vfloat32m1_t *, vfloat32m1_t *, vbool32_t, vfloat32m1_t, vfloat32m1_t, vfloat32m1_t, vfloat32m1_t, vfloat32m1_t, const float *, vuint16mf2_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vluxseg5ei16_v)))
void vluxseg5ei16(vfloat32mf2_t *, vfloat32mf2_t *, vfloat32mf2_t *, vfloat32mf2_t *, vfloat32mf2_t *, const float *, vuint16mf4_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vluxseg5ei16_v_m)))
void vluxseg5ei16(vfloat32mf2_t *, vfloat32mf2_t *, vfloat32mf2_t *, vfloat32mf2_t *, vfloat32mf2_t *, vbool64_t, vfloat32mf2_t, vfloat32mf2_t, vfloat32mf2_t, vfloat32mf2_t, vfloat32mf2_t, const float *, vuint16mf4_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vluxseg6ei16_v)))
void vluxseg6ei16(vfloat32m1_t *, vfloat32m1_t *, vfloat32m1_t *, vfloat32m1_t *, vfloat32m1_t *, vfloat32m1_t *, const float *, vuint16mf2_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vluxseg6ei16_v_m)))
void vluxseg6ei16(vfloat32m1_t *, vfloat32m1_t *, vfloat32m1_t *, vfloat32m1_t *, vfloat32m1_t *, vfloat32m1_t *, vbool32_t, vfloat32m1_t, vfloat32m1_t, vfloat32m1_t, vfloat32m1_t, vfloat32m1_t, vfloat32m1_t, const float *, vuint16mf2_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vluxseg6ei16_v)))
void vluxseg6ei16(vfloat32mf2_t *, vfloat32mf2_t *, vfloat32mf2_t *, vfloat32mf2_t *, vfloat32mf2_t *, vfloat32mf2_t *, const float *, vuint16mf4_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vluxseg6ei16_v_m)))
void vluxseg6ei16(vfloat32mf2_t *, vfloat32mf2_t *, vfloat32mf2_t *, vfloat32mf2_t *, vfloat32mf2_t *, vfloat32mf2_t *, vbool64_t, vfloat32mf2_t, vfloat32mf2_t, vfloat32mf2_t, vfloat32mf2_t, vfloat32mf2_t, vfloat32mf2_t, const float *, vuint16mf4_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vluxseg7ei16_v)))
void vluxseg7ei16(vfloat32m1_t *, vfloat32m1_t *, vfloat32m1_t *, vfloat32m1_t *, vfloat32m1_t *, vfloat32m1_t *, vfloat32m1_t *, const float *, vuint16mf2_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vluxseg7ei16_v_m)))
void vluxseg7ei16(vfloat32m1_t *, vfloat32m1_t *, vfloat32m1_t *, vfloat32m1_t *, vfloat32m1_t *, vfloat32m1_t *, vfloat32m1_t *, vbool32_t, vfloat32m1_t, vfloat32m1_t, vfloat32m1_t, vfloat32m1_t, vfloat32m1_t, vfloat32m1_t, vfloat32m1_t, const float *, vuint16mf2_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vluxseg7ei16_v)))
void vluxseg7ei16(vfloat32mf2_t *, vfloat32mf2_t *, vfloat32mf2_t *, vfloat32mf2_t *, vfloat32mf2_t *, vfloat32mf2_t *, vfloat32mf2_t *, const float *, vuint16mf4_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vluxseg7ei16_v_m)))
void vluxseg7ei16(vfloat32mf2_t *, vfloat32mf2_t *, vfloat32mf2_t *, vfloat32mf2_t *, vfloat32mf2_t *, vfloat32mf2_t *, vfloat32mf2_t *, vbool64_t, vfloat32mf2_t, vfloat32mf2_t, vfloat32mf2_t, vfloat32mf2_t, vfloat32mf2_t, vfloat32mf2_t, vfloat32mf2_t, const float *, vuint16mf4_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vluxseg8ei16_v)))
void vluxseg8ei16(vfloat32m1_t *, vfloat32m1_t *, vfloat32m1_t *, vfloat32m1_t *, vfloat32m1_t *, vfloat32m1_t *, vfloat32m1_t *, vfloat32m1_t *, const float *, vuint16mf2_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vluxseg8ei16_v_m)))
void vluxseg8ei16(vfloat32m1_t *, vfloat32m1_t *, vfloat32m1_t *, vfloat32m1_t *, vfloat32m1_t *, vfloat32m1_t *, vfloat32m1_t *, vfloat32m1_t *, vbool32_t, vfloat32m1_t, vfloat32m1_t, vfloat32m1_t, vfloat32m1_t, vfloat32m1_t, vfloat32m1_t, vfloat32m1_t, vfloat32m1_t, const float *, vuint16mf2_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vluxseg8ei16_v)))
void vluxseg8ei16(vfloat32mf2_t *, vfloat32mf2_t *, vfloat32mf2_t *, vfloat32mf2_t *, vfloat32mf2_t *, vfloat32mf2_t *, vfloat32mf2_t *, vfloat32mf2_t *, const float *, vuint16mf4_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vluxseg8ei16_v_m)))
void vluxseg8ei16(vfloat32mf2_t *, vfloat32mf2_t *, vfloat32mf2_t *, vfloat32mf2_t *, vfloat32mf2_t *, vfloat32mf2_t *, vfloat32mf2_t *, vfloat32mf2_t *, vbool64_t, vfloat32mf2_t, vfloat32mf2_t, vfloat32mf2_t, vfloat32mf2_t, vfloat32mf2_t, vfloat32mf2_t, vfloat32mf2_t, vfloat32mf2_t, const float *, vuint16mf4_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vluxseg2ei32_v)))
void vluxseg2ei32(vfloat32m1_t *, vfloat32m1_t *, const float *, vuint32m1_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vluxseg2ei32_v_m)))
void vluxseg2ei32(vfloat32m1_t *, vfloat32m1_t *, vbool32_t, vfloat32m1_t, vfloat32m1_t, const float *, vuint32m1_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vluxseg2ei32_v)))
void vluxseg2ei32(vfloat32m2_t *, vfloat32m2_t *, const float *, vuint32m2_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vluxseg2ei32_v_m)))
void vluxseg2ei32(vfloat32m2_t *, vfloat32m2_t *, vbool16_t, vfloat32m2_t, vfloat32m2_t, const float *, vuint32m2_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vluxseg2ei32_v)))
void vluxseg2ei32(vfloat32m4_t *, vfloat32m4_t *, const float *, vuint32m4_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vluxseg2ei32_v_m)))
void vluxseg2ei32(vfloat32m4_t *, vfloat32m4_t *, vbool8_t, vfloat32m4_t, vfloat32m4_t, const float *, vuint32m4_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vluxseg2ei32_v)))
void vluxseg2ei32(vfloat32mf2_t *, vfloat32mf2_t *, const float *, vuint32mf2_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vluxseg2ei32_v_m)))
void vluxseg2ei32(vfloat32mf2_t *, vfloat32mf2_t *, vbool64_t, vfloat32mf2_t, vfloat32mf2_t, const float *, vuint32mf2_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vluxseg3ei32_v)))
void vluxseg3ei32(vfloat32m1_t *, vfloat32m1_t *, vfloat32m1_t *, const float *, vuint32m1_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vluxseg3ei32_v_m)))
void vluxseg3ei32(vfloat32m1_t *, vfloat32m1_t *, vfloat32m1_t *, vbool32_t, vfloat32m1_t, vfloat32m1_t, vfloat32m1_t, const float *, vuint32m1_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vluxseg3ei32_v)))
void vluxseg3ei32(vfloat32m2_t *, vfloat32m2_t *, vfloat32m2_t *, const float *, vuint32m2_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vluxseg3ei32_v_m)))
void vluxseg3ei32(vfloat32m2_t *, vfloat32m2_t *, vfloat32m2_t *, vbool16_t, vfloat32m2_t, vfloat32m2_t, vfloat32m2_t, const float *, vuint32m2_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vluxseg3ei32_v)))
void vluxseg3ei32(vfloat32mf2_t *, vfloat32mf2_t *, vfloat32mf2_t *, const float *, vuint32mf2_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vluxseg3ei32_v_m)))
void vluxseg3ei32(vfloat32mf2_t *, vfloat32mf2_t *, vfloat32mf2_t *, vbool64_t, vfloat32mf2_t, vfloat32mf2_t, vfloat32mf2_t, const float *, vuint32mf2_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vluxseg4ei32_v)))
void vluxseg4ei32(vfloat32m1_t *, vfloat32m1_t *, vfloat32m1_t *, vfloat32m1_t *, const float *, vuint32m1_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vluxseg4ei32_v_m)))
void vluxseg4ei32(vfloat32m1_t *, vfloat32m1_t *, vfloat32m1_t *, vfloat32m1_t *, vbool32_t, vfloat32m1_t, vfloat32m1_t, vfloat32m1_t, vfloat32m1_t, const float *, vuint32m1_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vluxseg4ei32_v)))
void vluxseg4ei32(vfloat32m2_t *, vfloat32m2_t *, vfloat32m2_t *, vfloat32m2_t *, const float *, vuint32m2_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vluxseg4ei32_v_m)))
void vluxseg4ei32(vfloat32m2_t *, vfloat32m2_t *, vfloat32m2_t *, vfloat32m2_t *, vbool16_t, vfloat32m2_t, vfloat32m2_t, vfloat32m2_t, vfloat32m2_t, const float *, vuint32m2_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vluxseg4ei32_v)))
void vluxseg4ei32(vfloat32mf2_t *, vfloat32mf2_t *, vfloat32mf2_t *, vfloat32mf2_t *, const float *, vuint32mf2_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vluxseg4ei32_v_m)))
void vluxseg4ei32(vfloat32mf2_t *, vfloat32mf2_t *, vfloat32mf2_t *, vfloat32mf2_t *, vbool64_t, vfloat32mf2_t, vfloat32mf2_t, vfloat32mf2_t, vfloat32mf2_t, const float *, vuint32mf2_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vluxseg5ei32_v)))
void vluxseg5ei32(vfloat32m1_t *, vfloat32m1_t *, vfloat32m1_t *, vfloat32m1_t *, vfloat32m1_t *, const float *, vuint32m1_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vluxseg5ei32_v_m)))
void vluxseg5ei32(vfloat32m1_t *, vfloat32m1_t *, vfloat32m1_t *, vfloat32m1_t *, vfloat32m1_t *, vbool32_t, vfloat32m1_t, vfloat32m1_t, vfloat32m1_t, vfloat32m1_t, vfloat32m1_t, const float *, vuint32m1_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vluxseg5ei32_v)))
void vluxseg5ei32(vfloat32mf2_t *, vfloat32mf2_t *, vfloat32mf2_t *, vfloat32mf2_t *, vfloat32mf2_t *, const float *, vuint32mf2_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vluxseg5ei32_v_m)))
void vluxseg5ei32(vfloat32mf2_t *, vfloat32mf2_t *, vfloat32mf2_t *, vfloat32mf2_t *, vfloat32mf2_t *, vbool64_t, vfloat32mf2_t, vfloat32mf2_t, vfloat32mf2_t, vfloat32mf2_t, vfloat32mf2_t, const float *, vuint32mf2_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vluxseg6ei32_v)))
void vluxseg6ei32(vfloat32m1_t *, vfloat32m1_t *, vfloat32m1_t *, vfloat32m1_t *, vfloat32m1_t *, vfloat32m1_t *, const float *, vuint32m1_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vluxseg6ei32_v_m)))
void vluxseg6ei32(vfloat32m1_t *, vfloat32m1_t *, vfloat32m1_t *, vfloat32m1_t *, vfloat32m1_t *, vfloat32m1_t *, vbool32_t, vfloat32m1_t, vfloat32m1_t, vfloat32m1_t, vfloat32m1_t, vfloat32m1_t, vfloat32m1_t, const float *, vuint32m1_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vluxseg6ei32_v)))
void vluxseg6ei32(vfloat32mf2_t *, vfloat32mf2_t *, vfloat32mf2_t *, vfloat32mf2_t *, vfloat32mf2_t *, vfloat32mf2_t *, const float *, vuint32mf2_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vluxseg6ei32_v_m)))
void vluxseg6ei32(vfloat32mf2_t *, vfloat32mf2_t *, vfloat32mf2_t *, vfloat32mf2_t *, vfloat32mf2_t *, vfloat32mf2_t *, vbool64_t, vfloat32mf2_t, vfloat32mf2_t, vfloat32mf2_t, vfloat32mf2_t, vfloat32mf2_t, vfloat32mf2_t, const float *, vuint32mf2_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vluxseg7ei32_v)))
void vluxseg7ei32(vfloat32m1_t *, vfloat32m1_t *, vfloat32m1_t *, vfloat32m1_t *, vfloat32m1_t *, vfloat32m1_t *, vfloat32m1_t *, const float *, vuint32m1_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vluxseg7ei32_v_m)))
void vluxseg7ei32(vfloat32m1_t *, vfloat32m1_t *, vfloat32m1_t *, vfloat32m1_t *, vfloat32m1_t *, vfloat32m1_t *, vfloat32m1_t *, vbool32_t, vfloat32m1_t, vfloat32m1_t, vfloat32m1_t, vfloat32m1_t, vfloat32m1_t, vfloat32m1_t, vfloat32m1_t, const float *, vuint32m1_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vluxseg7ei32_v)))
void vluxseg7ei32(vfloat32mf2_t *, vfloat32mf2_t *, vfloat32mf2_t *, vfloat32mf2_t *, vfloat32mf2_t *, vfloat32mf2_t *, vfloat32mf2_t *, const float *, vuint32mf2_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vluxseg7ei32_v_m)))
void vluxseg7ei32(vfloat32mf2_t *, vfloat32mf2_t *, vfloat32mf2_t *, vfloat32mf2_t *, vfloat32mf2_t *, vfloat32mf2_t *, vfloat32mf2_t *, vbool64_t, vfloat32mf2_t, vfloat32mf2_t, vfloat32mf2_t, vfloat32mf2_t, vfloat32mf2_t, vfloat32mf2_t, vfloat32mf2_t, const float *, vuint32mf2_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vluxseg8ei32_v)))
void vluxseg8ei32(vfloat32m1_t *, vfloat32m1_t *, vfloat32m1_t *, vfloat32m1_t *, vfloat32m1_t *, vfloat32m1_t *, vfloat32m1_t *, vfloat32m1_t *, const float *, vuint32m1_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vluxseg8ei32_v_m)))
void vluxseg8ei32(vfloat32m1_t *, vfloat32m1_t *, vfloat32m1_t *, vfloat32m1_t *, vfloat32m1_t *, vfloat32m1_t *, vfloat32m1_t *, vfloat32m1_t *, vbool32_t, vfloat32m1_t, vfloat32m1_t, vfloat32m1_t, vfloat32m1_t, vfloat32m1_t, vfloat32m1_t, vfloat32m1_t, vfloat32m1_t, const float *, vuint32m1_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vluxseg8ei32_v)))
void vluxseg8ei32(vfloat32mf2_t *, vfloat32mf2_t *, vfloat32mf2_t *, vfloat32mf2_t *, vfloat32mf2_t *, vfloat32mf2_t *, vfloat32mf2_t *, vfloat32mf2_t *, const float *, vuint32mf2_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vluxseg8ei32_v_m)))
void vluxseg8ei32(vfloat32mf2_t *, vfloat32mf2_t *, vfloat32mf2_t *, vfloat32mf2_t *, vfloat32mf2_t *, vfloat32mf2_t *, vfloat32mf2_t *, vfloat32mf2_t *, vbool64_t, vfloat32mf2_t, vfloat32mf2_t, vfloat32mf2_t, vfloat32mf2_t, vfloat32mf2_t, vfloat32mf2_t, vfloat32mf2_t, vfloat32mf2_t, const float *, vuint32mf2_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vle32_v_m)))
vfloat32m1_t vle32(vbool32_t, vfloat32m1_t, const float *, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vle32_v_m)))
vfloat32m2_t vle32(vbool16_t, vfloat32m2_t, const float *, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vle32_v_m)))
vfloat32m4_t vle32(vbool8_t, vfloat32m4_t, const float *, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vle32_v_m)))
vfloat32m8_t vle32(vbool4_t, vfloat32m8_t, const float *, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vle32_v_m)))
vfloat32mf2_t vle32(vbool64_t, vfloat32mf2_t, const float *, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vse32_v)))
void vse32(float *, vfloat32m1_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vse32_v_m)))
void vse32(vbool32_t, float *, vfloat32m1_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vse32_v)))
void vse32(float *, vfloat32m2_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vse32_v_m)))
void vse32(vbool16_t, float *, vfloat32m2_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vse32_v)))
void vse32(float *, vfloat32m4_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vse32_v_m)))
void vse32(vbool8_t, float *, vfloat32m4_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vse32_v)))
void vse32(float *, vfloat32m8_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vse32_v_m)))
void vse32(vbool4_t, float *, vfloat32m8_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vse32_v)))
void vse32(float *, vfloat32mf2_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vse32_v_m)))
void vse32(vbool64_t, float *, vfloat32mf2_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vfclass_v)))
vuint32m1_t vfclass(vfloat32m1_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vfclass_v_m)))
vuint32m1_t vfclass(vbool32_t, vuint32m1_t, vfloat32m1_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vfclass_v)))
vuint32m2_t vfclass(vfloat32m2_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vfclass_v_m)))
vuint32m2_t vfclass(vbool16_t, vuint32m2_t, vfloat32m2_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vfclass_v)))
vuint32m4_t vfclass(vfloat32m4_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vfclass_v_m)))
vuint32m4_t vfclass(vbool8_t, vuint32m4_t, vfloat32m4_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vfclass_v)))
vuint32m8_t vfclass(vfloat32m8_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vfclass_v_m)))
vuint32m8_t vfclass(vbool4_t, vuint32m8_t, vfloat32m8_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vfclass_v)))
vuint32mf2_t vfclass(vfloat32mf2_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vfclass_v_m)))
vuint32mf2_t vfclass(vbool64_t, vuint32mf2_t, vfloat32mf2_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vfcvt_f_x_v)))
vfloat32m1_t vfcvt_f(vint32m1_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vfcvt_f_x_v_m)))
vfloat32m1_t vfcvt_f(vbool32_t, vfloat32m1_t, vint32m1_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vfcvt_f_x_v)))
vfloat32m2_t vfcvt_f(vint32m2_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vfcvt_f_x_v_m)))
vfloat32m2_t vfcvt_f(vbool16_t, vfloat32m2_t, vint32m2_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vfcvt_f_x_v)))
vfloat32m4_t vfcvt_f(vint32m4_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vfcvt_f_x_v_m)))
vfloat32m4_t vfcvt_f(vbool8_t, vfloat32m4_t, vint32m4_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vfcvt_f_x_v)))
vfloat32m8_t vfcvt_f(vint32m8_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vfcvt_f_x_v_m)))
vfloat32m8_t vfcvt_f(vbool4_t, vfloat32m8_t, vint32m8_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vfcvt_f_x_v)))
vfloat32mf2_t vfcvt_f(vint32mf2_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vfcvt_f_x_v_m)))
vfloat32mf2_t vfcvt_f(vbool64_t, vfloat32mf2_t, vint32mf2_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vfcvt_f_xu_v)))
vfloat32m1_t vfcvt_f(vuint32m1_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vfcvt_f_xu_v_m)))
vfloat32m1_t vfcvt_f(vbool32_t, vfloat32m1_t, vuint32m1_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vfcvt_f_xu_v)))
vfloat32m2_t vfcvt_f(vuint32m2_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vfcvt_f_xu_v_m)))
vfloat32m2_t vfcvt_f(vbool16_t, vfloat32m2_t, vuint32m2_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vfcvt_f_xu_v)))
vfloat32m4_t vfcvt_f(vuint32m4_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vfcvt_f_xu_v_m)))
vfloat32m4_t vfcvt_f(vbool8_t, vfloat32m4_t, vuint32m4_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vfcvt_f_xu_v)))
vfloat32m8_t vfcvt_f(vuint32m8_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vfcvt_f_xu_v_m)))
vfloat32m8_t vfcvt_f(vbool4_t, vfloat32m8_t, vuint32m8_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vfcvt_f_xu_v)))
vfloat32mf2_t vfcvt_f(vuint32mf2_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vfcvt_f_xu_v_m)))
vfloat32mf2_t vfcvt_f(vbool64_t, vfloat32mf2_t, vuint32mf2_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vfcvt_rtz_x_f_v)))
vint32m1_t vfcvt_rtz_x(vfloat32m1_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vfcvt_rtz_x_f_v_m)))
vint32m1_t vfcvt_rtz_x(vbool32_t, vint32m1_t, vfloat32m1_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vfcvt_rtz_x_f_v)))
vint32m2_t vfcvt_rtz_x(vfloat32m2_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vfcvt_rtz_x_f_v_m)))
vint32m2_t vfcvt_rtz_x(vbool16_t, vint32m2_t, vfloat32m2_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vfcvt_rtz_x_f_v)))
vint32m4_t vfcvt_rtz_x(vfloat32m4_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vfcvt_rtz_x_f_v_m)))
vint32m4_t vfcvt_rtz_x(vbool8_t, vint32m4_t, vfloat32m4_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vfcvt_rtz_x_f_v)))
vint32m8_t vfcvt_rtz_x(vfloat32m8_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vfcvt_rtz_x_f_v_m)))
vint32m8_t vfcvt_rtz_x(vbool4_t, vint32m8_t, vfloat32m8_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vfcvt_rtz_x_f_v)))
vint32mf2_t vfcvt_rtz_x(vfloat32mf2_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vfcvt_rtz_x_f_v_m)))
vint32mf2_t vfcvt_rtz_x(vbool64_t, vint32mf2_t, vfloat32mf2_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vfcvt_rtz_xu_f_v)))
vuint32m1_t vfcvt_rtz_xu(vfloat32m1_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vfcvt_rtz_xu_f_v_m)))
vuint32m1_t vfcvt_rtz_xu(vbool32_t, vuint32m1_t, vfloat32m1_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vfcvt_rtz_xu_f_v)))
vuint32m2_t vfcvt_rtz_xu(vfloat32m2_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vfcvt_rtz_xu_f_v_m)))
vuint32m2_t vfcvt_rtz_xu(vbool16_t, vuint32m2_t, vfloat32m2_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vfcvt_rtz_xu_f_v)))
vuint32m4_t vfcvt_rtz_xu(vfloat32m4_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vfcvt_rtz_xu_f_v_m)))
vuint32m4_t vfcvt_rtz_xu(vbool8_t, vuint32m4_t, vfloat32m4_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vfcvt_rtz_xu_f_v)))
vuint32m8_t vfcvt_rtz_xu(vfloat32m8_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vfcvt_rtz_xu_f_v_m)))
vuint32m8_t vfcvt_rtz_xu(vbool4_t, vuint32m8_t, vfloat32m8_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vfcvt_rtz_xu_f_v)))
vuint32mf2_t vfcvt_rtz_xu(vfloat32mf2_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vfcvt_rtz_xu_f_v_m)))
vuint32mf2_t vfcvt_rtz_xu(vbool64_t, vuint32mf2_t, vfloat32mf2_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vfcvt_x_f_v)))
vint32m1_t vfcvt_x(vfloat32m1_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vfcvt_x_f_v_m)))
vint32m1_t vfcvt_x(vbool32_t, vint32m1_t, vfloat32m1_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vfcvt_x_f_v)))
vint32m2_t vfcvt_x(vfloat32m2_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vfcvt_x_f_v_m)))
vint32m2_t vfcvt_x(vbool16_t, vint32m2_t, vfloat32m2_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vfcvt_x_f_v)))
vint32m4_t vfcvt_x(vfloat32m4_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vfcvt_x_f_v_m)))
vint32m4_t vfcvt_x(vbool8_t, vint32m4_t, vfloat32m4_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vfcvt_x_f_v)))
vint32m8_t vfcvt_x(vfloat32m8_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vfcvt_x_f_v_m)))
vint32m8_t vfcvt_x(vbool4_t, vint32m8_t, vfloat32m8_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vfcvt_x_f_v)))
vint32mf2_t vfcvt_x(vfloat32mf2_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vfcvt_x_f_v_m)))
vint32mf2_t vfcvt_x(vbool64_t, vint32mf2_t, vfloat32mf2_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vfcvt_xu_f_v)))
vuint32m1_t vfcvt_xu(vfloat32m1_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vfcvt_xu_f_v_m)))
vuint32m1_t vfcvt_xu(vbool32_t, vuint32m1_t, vfloat32m1_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vfcvt_xu_f_v)))
vuint32m2_t vfcvt_xu(vfloat32m2_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vfcvt_xu_f_v_m)))
vuint32m2_t vfcvt_xu(vbool16_t, vuint32m2_t, vfloat32m2_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vfcvt_xu_f_v)))
vuint32m4_t vfcvt_xu(vfloat32m4_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vfcvt_xu_f_v_m)))
vuint32m4_t vfcvt_xu(vbool8_t, vuint32m4_t, vfloat32m4_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vfcvt_xu_f_v)))
vuint32m8_t vfcvt_xu(vfloat32m8_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vfcvt_xu_f_v_m)))
vuint32m8_t vfcvt_xu(vbool4_t, vuint32m8_t, vfloat32m8_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vfcvt_xu_f_v)))
vuint32mf2_t vfcvt_xu(vfloat32mf2_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vfcvt_xu_f_v_m)))
vuint32mf2_t vfcvt_xu(vbool64_t, vuint32mf2_t, vfloat32mf2_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vfncvt_rtz_x_f_w)))
vint16mf4_t vfncvt_rtz_x(vfloat32mf2_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vfncvt_rtz_x_f_w_m)))
vint16mf4_t vfncvt_rtz_x(vbool64_t, vint16mf4_t, vfloat32mf2_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vfncvt_rtz_x_f_w)))
vint16mf2_t vfncvt_rtz_x(vfloat32m1_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vfncvt_rtz_x_f_w_m)))
vint16mf2_t vfncvt_rtz_x(vbool32_t, vint16mf2_t, vfloat32m1_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vfncvt_rtz_x_f_w)))
vint16m1_t vfncvt_rtz_x(vfloat32m2_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vfncvt_rtz_x_f_w_m)))
vint16m1_t vfncvt_rtz_x(vbool16_t, vint16m1_t, vfloat32m2_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vfncvt_rtz_x_f_w)))
vint16m2_t vfncvt_rtz_x(vfloat32m4_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vfncvt_rtz_x_f_w_m)))
vint16m2_t vfncvt_rtz_x(vbool8_t, vint16m2_t, vfloat32m4_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vfncvt_rtz_x_f_w)))
vint16m4_t vfncvt_rtz_x(vfloat32m8_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vfncvt_rtz_x_f_w_m)))
vint16m4_t vfncvt_rtz_x(vbool4_t, vint16m4_t, vfloat32m8_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vfncvt_rtz_xu_f_w)))
vuint16mf4_t vfncvt_rtz_xu(vfloat32mf2_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vfncvt_rtz_xu_f_w_m)))
vuint16mf4_t vfncvt_rtz_xu(vbool64_t, vuint16mf4_t, vfloat32mf2_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vfncvt_rtz_xu_f_w)))
vuint16mf2_t vfncvt_rtz_xu(vfloat32m1_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vfncvt_rtz_xu_f_w_m)))
vuint16mf2_t vfncvt_rtz_xu(vbool32_t, vuint16mf2_t, vfloat32m1_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vfncvt_rtz_xu_f_w)))
vuint16m1_t vfncvt_rtz_xu(vfloat32m2_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vfncvt_rtz_xu_f_w_m)))
vuint16m1_t vfncvt_rtz_xu(vbool16_t, vuint16m1_t, vfloat32m2_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vfncvt_rtz_xu_f_w)))
vuint16m2_t vfncvt_rtz_xu(vfloat32m4_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vfncvt_rtz_xu_f_w_m)))
vuint16m2_t vfncvt_rtz_xu(vbool8_t, vuint16m2_t, vfloat32m4_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vfncvt_rtz_xu_f_w)))
vuint16m4_t vfncvt_rtz_xu(vfloat32m8_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vfncvt_rtz_xu_f_w_m)))
vuint16m4_t vfncvt_rtz_xu(vbool4_t, vuint16m4_t, vfloat32m8_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vfncvt_x_f_w)))
vint16mf4_t vfncvt_x(vfloat32mf2_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vfncvt_x_f_w_m)))
vint16mf4_t vfncvt_x(vbool64_t, vint16mf4_t, vfloat32mf2_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vfncvt_x_f_w)))
vint16mf2_t vfncvt_x(vfloat32m1_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vfncvt_x_f_w_m)))
vint16mf2_t vfncvt_x(vbool32_t, vint16mf2_t, vfloat32m1_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vfncvt_x_f_w)))
vint16m1_t vfncvt_x(vfloat32m2_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vfncvt_x_f_w_m)))
vint16m1_t vfncvt_x(vbool16_t, vint16m1_t, vfloat32m2_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vfncvt_x_f_w)))
vint16m2_t vfncvt_x(vfloat32m4_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vfncvt_x_f_w_m)))
vint16m2_t vfncvt_x(vbool8_t, vint16m2_t, vfloat32m4_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vfncvt_x_f_w)))
vint16m4_t vfncvt_x(vfloat32m8_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vfncvt_x_f_w_m)))
vint16m4_t vfncvt_x(vbool4_t, vint16m4_t, vfloat32m8_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vfncvt_xu_f_w)))
vuint16mf4_t vfncvt_xu(vfloat32mf2_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vfncvt_xu_f_w_m)))
vuint16mf4_t vfncvt_xu(vbool64_t, vuint16mf4_t, vfloat32mf2_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vfncvt_xu_f_w)))
vuint16mf2_t vfncvt_xu(vfloat32m1_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vfncvt_xu_f_w_m)))
vuint16mf2_t vfncvt_xu(vbool32_t, vuint16mf2_t, vfloat32m1_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vfncvt_xu_f_w)))
vuint16m1_t vfncvt_xu(vfloat32m2_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vfncvt_xu_f_w_m)))
vuint16m1_t vfncvt_xu(vbool16_t, vuint16m1_t, vfloat32m2_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vfncvt_xu_f_w)))
vuint16m2_t vfncvt_xu(vfloat32m4_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vfncvt_xu_f_w_m)))
vuint16m2_t vfncvt_xu(vbool8_t, vuint16m2_t, vfloat32m4_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vfncvt_xu_f_w)))
vuint16m4_t vfncvt_xu(vfloat32m8_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vfncvt_xu_f_w_m)))
vuint16m4_t vfncvt_xu(vbool4_t, vuint16m4_t, vfloat32m8_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vfrec7_v)))
vfloat32m1_t vfrec7(vfloat32m1_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vfrec7_v_m)))
vfloat32m1_t vfrec7(vbool32_t, vfloat32m1_t, vfloat32m1_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vfrec7_v)))
vfloat32m2_t vfrec7(vfloat32m2_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vfrec7_v_m)))
vfloat32m2_t vfrec7(vbool16_t, vfloat32m2_t, vfloat32m2_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vfrec7_v)))
vfloat32m4_t vfrec7(vfloat32m4_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vfrec7_v_m)))
vfloat32m4_t vfrec7(vbool8_t, vfloat32m4_t, vfloat32m4_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vfrec7_v)))
vfloat32m8_t vfrec7(vfloat32m8_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vfrec7_v_m)))
vfloat32m8_t vfrec7(vbool4_t, vfloat32m8_t, vfloat32m8_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vfrec7_v)))
vfloat32mf2_t vfrec7(vfloat32mf2_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vfrec7_v_m)))
vfloat32mf2_t vfrec7(vbool64_t, vfloat32mf2_t, vfloat32mf2_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vfrsqrt7_v)))
vfloat32m1_t vfrsqrt7(vfloat32m1_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vfrsqrt7_v_m)))
vfloat32m1_t vfrsqrt7(vbool32_t, vfloat32m1_t, vfloat32m1_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vfrsqrt7_v)))
vfloat32m2_t vfrsqrt7(vfloat32m2_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vfrsqrt7_v_m)))
vfloat32m2_t vfrsqrt7(vbool16_t, vfloat32m2_t, vfloat32m2_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vfrsqrt7_v)))
vfloat32m4_t vfrsqrt7(vfloat32m4_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vfrsqrt7_v_m)))
vfloat32m4_t vfrsqrt7(vbool8_t, vfloat32m4_t, vfloat32m4_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vfrsqrt7_v)))
vfloat32m8_t vfrsqrt7(vfloat32m8_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vfrsqrt7_v_m)))
vfloat32m8_t vfrsqrt7(vbool4_t, vfloat32m8_t, vfloat32m8_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vfrsqrt7_v)))
vfloat32mf2_t vfrsqrt7(vfloat32mf2_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vfrsqrt7_v_m)))
vfloat32mf2_t vfrsqrt7(vbool64_t, vfloat32mf2_t, vfloat32mf2_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vfsqrt_v)))
vfloat32m1_t vfsqrt(vfloat32m1_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vfsqrt_v_m)))
vfloat32m1_t vfsqrt(vbool32_t, vfloat32m1_t, vfloat32m1_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vfsqrt_v)))
vfloat32m2_t vfsqrt(vfloat32m2_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vfsqrt_v_m)))
vfloat32m2_t vfsqrt(vbool16_t, vfloat32m2_t, vfloat32m2_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vfsqrt_v)))
vfloat32m4_t vfsqrt(vfloat32m4_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vfsqrt_v_m)))
vfloat32m4_t vfsqrt(vbool8_t, vfloat32m4_t, vfloat32m4_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vfsqrt_v)))
vfloat32m8_t vfsqrt(vfloat32m8_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vfsqrt_v_m)))
vfloat32m8_t vfsqrt(vbool4_t, vfloat32m8_t, vfloat32m8_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vfsqrt_v)))
vfloat32mf2_t vfsqrt(vfloat32mf2_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vfsqrt_v_m)))
vfloat32mf2_t vfsqrt(vbool64_t, vfloat32mf2_t, vfloat32mf2_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vfwcvt_f_x_v)))
vfloat32mf2_t vfwcvt_f(vint16mf4_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vfwcvt_f_x_v_m)))
vfloat32mf2_t vfwcvt_f(vbool64_t, vfloat32mf2_t, vint16mf4_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vfwcvt_f_x_v)))
vfloat32m1_t vfwcvt_f(vint16mf2_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vfwcvt_f_x_v_m)))
vfloat32m1_t vfwcvt_f(vbool32_t, vfloat32m1_t, vint16mf2_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vfwcvt_f_x_v)))
vfloat32m2_t vfwcvt_f(vint16m1_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vfwcvt_f_x_v_m)))
vfloat32m2_t vfwcvt_f(vbool16_t, vfloat32m2_t, vint16m1_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vfwcvt_f_x_v)))
vfloat32m4_t vfwcvt_f(vint16m2_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vfwcvt_f_x_v_m)))
vfloat32m4_t vfwcvt_f(vbool8_t, vfloat32m4_t, vint16m2_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vfwcvt_f_x_v)))
vfloat32m8_t vfwcvt_f(vint16m4_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vfwcvt_f_x_v_m)))
vfloat32m8_t vfwcvt_f(vbool4_t, vfloat32m8_t, vint16m4_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vfwcvt_f_xu_v)))
vfloat32mf2_t vfwcvt_f(vuint16mf4_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vfwcvt_f_xu_v_m)))
vfloat32mf2_t vfwcvt_f(vbool64_t, vfloat32mf2_t, vuint16mf4_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vfwcvt_f_xu_v)))
vfloat32m1_t vfwcvt_f(vuint16mf2_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vfwcvt_f_xu_v_m)))
vfloat32m1_t vfwcvt_f(vbool32_t, vfloat32m1_t, vuint16mf2_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vfwcvt_f_xu_v)))
vfloat32m2_t vfwcvt_f(vuint16m1_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vfwcvt_f_xu_v_m)))
vfloat32m2_t vfwcvt_f(vbool16_t, vfloat32m2_t, vuint16m1_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vfwcvt_f_xu_v)))
vfloat32m4_t vfwcvt_f(vuint16m2_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vfwcvt_f_xu_v_m)))
vfloat32m4_t vfwcvt_f(vbool8_t, vfloat32m4_t, vuint16m2_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vfwcvt_f_xu_v)))
vfloat32m8_t vfwcvt_f(vuint16m4_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vfwcvt_f_xu_v_m)))
vfloat32m8_t vfwcvt_f(vbool4_t, vfloat32m8_t, vuint16m4_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vlmul_ext_v)))
vfloat32m1_t vlmul_ext_f32m1(vfloat32mf2_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vlmul_ext_v)))
vfloat32m2_t vlmul_ext_f32m2(vfloat32m1_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vlmul_ext_v)))
vfloat32m2_t vlmul_ext_f32m2(vfloat32mf2_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vlmul_ext_v)))
vfloat32m4_t vlmul_ext_f32m4(vfloat32m1_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vlmul_ext_v)))
vfloat32m4_t vlmul_ext_f32m4(vfloat32m2_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vlmul_ext_v)))
vfloat32m4_t vlmul_ext_f32m4(vfloat32mf2_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vlmul_ext_v)))
vfloat32m8_t vlmul_ext_f32m8(vfloat32m1_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vlmul_ext_v)))
vfloat32m8_t vlmul_ext_f32m8(vfloat32m2_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vlmul_ext_v)))
vfloat32m8_t vlmul_ext_f32m8(vfloat32m4_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vlmul_ext_v)))
vfloat32m8_t vlmul_ext_f32m8(vfloat32mf2_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vlmul_trunc_v)))
vfloat32mf2_t vlmul_trunc_f32mf2(vfloat32m1_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vlmul_trunc_v)))
vfloat32mf2_t vlmul_trunc_f32mf2(vfloat32m2_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vlmul_trunc_v)))
vfloat32mf2_t vlmul_trunc_f32mf2(vfloat32m4_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vlmul_trunc_v)))
vfloat32mf2_t vlmul_trunc_f32mf2(vfloat32m8_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vlmul_trunc_v)))
vfloat32m1_t vlmul_trunc_f32m1(vfloat32m2_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vlmul_trunc_v)))
vfloat32m1_t vlmul_trunc_f32m1(vfloat32m4_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vlmul_trunc_v)))
vfloat32m1_t vlmul_trunc_f32m1(vfloat32m8_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vlmul_trunc_v)))
vfloat32m2_t vlmul_trunc_f32m2(vfloat32m4_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vlmul_trunc_v)))
vfloat32m2_t vlmul_trunc_f32m2(vfloat32m8_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vlmul_trunc_v)))
vfloat32m4_t vlmul_trunc_f32m4(vfloat32m8_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vreinterpret_v)))
vfloat32m1_t vreinterpret_f32m1(vint32m1_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vreinterpret_v)))
vfloat32m2_t vreinterpret_f32m2(vint32m2_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vreinterpret_v)))
vfloat32m4_t vreinterpret_f32m4(vint32m4_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vreinterpret_v)))
vfloat32m8_t vreinterpret_f32m8(vint32m8_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vreinterpret_v)))
vfloat32mf2_t vreinterpret_f32mf2(vint32mf2_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vreinterpret_v)))
vfloat32m1_t vreinterpret_f32m1(vuint32m1_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vreinterpret_v)))
vfloat32m2_t vreinterpret_f32m2(vuint32m2_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vreinterpret_v)))
vfloat32m4_t vreinterpret_f32m4(vuint32m4_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vreinterpret_v)))
vfloat32m8_t vreinterpret_f32m8(vuint32m8_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vreinterpret_v)))
vfloat32mf2_t vreinterpret_f32mf2(vuint32mf2_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vreinterpret_v)))
vint32m1_t vreinterpret_i32m1(vfloat32m1_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vreinterpret_v)))
vint32m2_t vreinterpret_i32m2(vfloat32m2_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vreinterpret_v)))
vint32m4_t vreinterpret_i32m4(vfloat32m4_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vreinterpret_v)))
vint32m8_t vreinterpret_i32m8(vfloat32m8_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vreinterpret_v)))
vint32mf2_t vreinterpret_i32mf2(vfloat32mf2_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vreinterpret_v)))
vuint32m1_t vreinterpret_u32m1(vfloat32m1_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vreinterpret_v)))
vuint32m2_t vreinterpret_u32m2(vfloat32m2_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vreinterpret_v)))
vuint32m4_t vreinterpret_u32m4(vfloat32m4_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vreinterpret_v)))
vuint32m8_t vreinterpret_u32m8(vfloat32m8_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vreinterpret_v)))
vuint32mf2_t vreinterpret_u32mf2(vfloat32mf2_t);
#endif

#if defined(__riscv_zfh) && (__riscv_v_elen_fp >= 32)
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vfwadd_vv)))
vfloat32mf2_t vfwadd_vv(vfloat16mf4_t, vfloat16mf4_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vfwadd_vv_m)))
vfloat32mf2_t vfwadd_vv(vbool64_t, vfloat32mf2_t, vfloat16mf4_t, vfloat16mf4_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vfwadd_vv)))
vfloat32m1_t vfwadd_vv(vfloat16mf2_t, vfloat16mf2_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vfwadd_vv_m)))
vfloat32m1_t vfwadd_vv(vbool32_t, vfloat32m1_t, vfloat16mf2_t, vfloat16mf2_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vfwadd_vv)))
vfloat32m2_t vfwadd_vv(vfloat16m1_t, vfloat16m1_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vfwadd_vv_m)))
vfloat32m2_t vfwadd_vv(vbool16_t, vfloat32m2_t, vfloat16m1_t, vfloat16m1_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vfwadd_vv)))
vfloat32m4_t vfwadd_vv(vfloat16m2_t, vfloat16m2_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vfwadd_vv_m)))
vfloat32m4_t vfwadd_vv(vbool8_t, vfloat32m4_t, vfloat16m2_t, vfloat16m2_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vfwadd_vv)))
vfloat32m8_t vfwadd_vv(vfloat16m4_t, vfloat16m4_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vfwadd_vv_m)))
vfloat32m8_t vfwadd_vv(vbool4_t, vfloat32m8_t, vfloat16m4_t, vfloat16m4_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vfwadd_vf)))
vfloat32mf2_t vfwadd_vf(vfloat16mf4_t, _Float16, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vfwadd_vf_m)))
vfloat32mf2_t vfwadd_vf(vbool64_t, vfloat32mf2_t, vfloat16mf4_t, _Float16, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vfwadd_vf)))
vfloat32m1_t vfwadd_vf(vfloat16mf2_t, _Float16, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vfwadd_vf_m)))
vfloat32m1_t vfwadd_vf(vbool32_t, vfloat32m1_t, vfloat16mf2_t, _Float16, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vfwadd_vf)))
vfloat32m2_t vfwadd_vf(vfloat16m1_t, _Float16, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vfwadd_vf_m)))
vfloat32m2_t vfwadd_vf(vbool16_t, vfloat32m2_t, vfloat16m1_t, _Float16, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vfwadd_vf)))
vfloat32m4_t vfwadd_vf(vfloat16m2_t, _Float16, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vfwadd_vf_m)))
vfloat32m4_t vfwadd_vf(vbool8_t, vfloat32m4_t, vfloat16m2_t, _Float16, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vfwadd_vf)))
vfloat32m8_t vfwadd_vf(vfloat16m4_t, _Float16, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vfwadd_vf_m)))
vfloat32m8_t vfwadd_vf(vbool4_t, vfloat32m8_t, vfloat16m4_t, _Float16, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vfwsub_vv)))
vfloat32mf2_t vfwsub_vv(vfloat16mf4_t, vfloat16mf4_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vfwsub_vv_m)))
vfloat32mf2_t vfwsub_vv(vbool64_t, vfloat32mf2_t, vfloat16mf4_t, vfloat16mf4_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vfwsub_vv)))
vfloat32m1_t vfwsub_vv(vfloat16mf2_t, vfloat16mf2_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vfwsub_vv_m)))
vfloat32m1_t vfwsub_vv(vbool32_t, vfloat32m1_t, vfloat16mf2_t, vfloat16mf2_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vfwsub_vv)))
vfloat32m2_t vfwsub_vv(vfloat16m1_t, vfloat16m1_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vfwsub_vv_m)))
vfloat32m2_t vfwsub_vv(vbool16_t, vfloat32m2_t, vfloat16m1_t, vfloat16m1_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vfwsub_vv)))
vfloat32m4_t vfwsub_vv(vfloat16m2_t, vfloat16m2_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vfwsub_vv_m)))
vfloat32m4_t vfwsub_vv(vbool8_t, vfloat32m4_t, vfloat16m2_t, vfloat16m2_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vfwsub_vv)))
vfloat32m8_t vfwsub_vv(vfloat16m4_t, vfloat16m4_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vfwsub_vv_m)))
vfloat32m8_t vfwsub_vv(vbool4_t, vfloat32m8_t, vfloat16m4_t, vfloat16m4_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vfwsub_vf)))
vfloat32mf2_t vfwsub_vf(vfloat16mf4_t, _Float16, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vfwsub_vf_m)))
vfloat32mf2_t vfwsub_vf(vbool64_t, vfloat32mf2_t, vfloat16mf4_t, _Float16, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vfwsub_vf)))
vfloat32m1_t vfwsub_vf(vfloat16mf2_t, _Float16, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vfwsub_vf_m)))
vfloat32m1_t vfwsub_vf(vbool32_t, vfloat32m1_t, vfloat16mf2_t, _Float16, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vfwsub_vf)))
vfloat32m2_t vfwsub_vf(vfloat16m1_t, _Float16, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vfwsub_vf_m)))
vfloat32m2_t vfwsub_vf(vbool16_t, vfloat32m2_t, vfloat16m1_t, _Float16, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vfwsub_vf)))
vfloat32m4_t vfwsub_vf(vfloat16m2_t, _Float16, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vfwsub_vf_m)))
vfloat32m4_t vfwsub_vf(vbool8_t, vfloat32m4_t, vfloat16m2_t, _Float16, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vfwsub_vf)))
vfloat32m8_t vfwsub_vf(vfloat16m4_t, _Float16, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vfwsub_vf_m)))
vfloat32m8_t vfwsub_vf(vbool4_t, vfloat32m8_t, vfloat16m4_t, _Float16, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vfwadd_wv)))
vfloat32mf2_t vfwadd_wv(vfloat32mf2_t, vfloat16mf4_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vfwadd_wv_m)))
vfloat32mf2_t vfwadd_wv(vbool64_t, vfloat32mf2_t, vfloat32mf2_t, vfloat16mf4_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vfwadd_wv)))
vfloat32m1_t vfwadd_wv(vfloat32m1_t, vfloat16mf2_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vfwadd_wv_m)))
vfloat32m1_t vfwadd_wv(vbool32_t, vfloat32m1_t, vfloat32m1_t, vfloat16mf2_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vfwadd_wv)))
vfloat32m2_t vfwadd_wv(vfloat32m2_t, vfloat16m1_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vfwadd_wv_m)))
vfloat32m2_t vfwadd_wv(vbool16_t, vfloat32m2_t, vfloat32m2_t, vfloat16m1_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vfwadd_wv)))
vfloat32m4_t vfwadd_wv(vfloat32m4_t, vfloat16m2_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vfwadd_wv_m)))
vfloat32m4_t vfwadd_wv(vbool8_t, vfloat32m4_t, vfloat32m4_t, vfloat16m2_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vfwadd_wv)))
vfloat32m8_t vfwadd_wv(vfloat32m8_t, vfloat16m4_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vfwadd_wv_m)))
vfloat32m8_t vfwadd_wv(vbool4_t, vfloat32m8_t, vfloat32m8_t, vfloat16m4_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vfwadd_wf)))
vfloat32mf2_t vfwadd_wf(vfloat32mf2_t, _Float16, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vfwadd_wf_m)))
vfloat32mf2_t vfwadd_wf(vbool64_t, vfloat32mf2_t, vfloat32mf2_t, _Float16, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vfwadd_wf)))
vfloat32m1_t vfwadd_wf(vfloat32m1_t, _Float16, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vfwadd_wf_m)))
vfloat32m1_t vfwadd_wf(vbool32_t, vfloat32m1_t, vfloat32m1_t, _Float16, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vfwadd_wf)))
vfloat32m2_t vfwadd_wf(vfloat32m2_t, _Float16, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vfwadd_wf_m)))
vfloat32m2_t vfwadd_wf(vbool16_t, vfloat32m2_t, vfloat32m2_t, _Float16, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vfwadd_wf)))
vfloat32m4_t vfwadd_wf(vfloat32m4_t, _Float16, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vfwadd_wf_m)))
vfloat32m4_t vfwadd_wf(vbool8_t, vfloat32m4_t, vfloat32m4_t, _Float16, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vfwadd_wf)))
vfloat32m8_t vfwadd_wf(vfloat32m8_t, _Float16, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vfwadd_wf_m)))
vfloat32m8_t vfwadd_wf(vbool4_t, vfloat32m8_t, vfloat32m8_t, _Float16, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vfwsub_wv)))
vfloat32mf2_t vfwsub_wv(vfloat32mf2_t, vfloat16mf4_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vfwsub_wv_m)))
vfloat32mf2_t vfwsub_wv(vbool64_t, vfloat32mf2_t, vfloat32mf2_t, vfloat16mf4_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vfwsub_wv)))
vfloat32m1_t vfwsub_wv(vfloat32m1_t, vfloat16mf2_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vfwsub_wv_m)))
vfloat32m1_t vfwsub_wv(vbool32_t, vfloat32m1_t, vfloat32m1_t, vfloat16mf2_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vfwsub_wv)))
vfloat32m2_t vfwsub_wv(vfloat32m2_t, vfloat16m1_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vfwsub_wv_m)))
vfloat32m2_t vfwsub_wv(vbool16_t, vfloat32m2_t, vfloat32m2_t, vfloat16m1_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vfwsub_wv)))
vfloat32m4_t vfwsub_wv(vfloat32m4_t, vfloat16m2_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vfwsub_wv_m)))
vfloat32m4_t vfwsub_wv(vbool8_t, vfloat32m4_t, vfloat32m4_t, vfloat16m2_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vfwsub_wv)))
vfloat32m8_t vfwsub_wv(vfloat32m8_t, vfloat16m4_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vfwsub_wv_m)))
vfloat32m8_t vfwsub_wv(vbool4_t, vfloat32m8_t, vfloat32m8_t, vfloat16m4_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vfwsub_wf)))
vfloat32mf2_t vfwsub_wf(vfloat32mf2_t, _Float16, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vfwsub_wf_m)))
vfloat32mf2_t vfwsub_wf(vbool64_t, vfloat32mf2_t, vfloat32mf2_t, _Float16, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vfwsub_wf)))
vfloat32m1_t vfwsub_wf(vfloat32m1_t, _Float16, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vfwsub_wf_m)))
vfloat32m1_t vfwsub_wf(vbool32_t, vfloat32m1_t, vfloat32m1_t, _Float16, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vfwsub_wf)))
vfloat32m2_t vfwsub_wf(vfloat32m2_t, _Float16, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vfwsub_wf_m)))
vfloat32m2_t vfwsub_wf(vbool16_t, vfloat32m2_t, vfloat32m2_t, _Float16, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vfwsub_wf)))
vfloat32m4_t vfwsub_wf(vfloat32m4_t, _Float16, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vfwsub_wf_m)))
vfloat32m4_t vfwsub_wf(vbool8_t, vfloat32m4_t, vfloat32m4_t, _Float16, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vfwsub_wf)))
vfloat32m8_t vfwsub_wf(vfloat32m8_t, _Float16, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vfwsub_wf_m)))
vfloat32m8_t vfwsub_wf(vbool4_t, vfloat32m8_t, vfloat32m8_t, _Float16, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vfwmul_vv)))
vfloat32mf2_t vfwmul(vfloat16mf4_t, vfloat16mf4_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vfwmul_vv_m)))
vfloat32mf2_t vfwmul(vbool64_t, vfloat32mf2_t, vfloat16mf4_t, vfloat16mf4_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vfwmul_vv)))
vfloat32m1_t vfwmul(vfloat16mf2_t, vfloat16mf2_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vfwmul_vv_m)))
vfloat32m1_t vfwmul(vbool32_t, vfloat32m1_t, vfloat16mf2_t, vfloat16mf2_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vfwmul_vv)))
vfloat32m2_t vfwmul(vfloat16m1_t, vfloat16m1_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vfwmul_vv_m)))
vfloat32m2_t vfwmul(vbool16_t, vfloat32m2_t, vfloat16m1_t, vfloat16m1_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vfwmul_vv)))
vfloat32m4_t vfwmul(vfloat16m2_t, vfloat16m2_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vfwmul_vv_m)))
vfloat32m4_t vfwmul(vbool8_t, vfloat32m4_t, vfloat16m2_t, vfloat16m2_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vfwmul_vv)))
vfloat32m8_t vfwmul(vfloat16m4_t, vfloat16m4_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vfwmul_vv_m)))
vfloat32m8_t vfwmul(vbool4_t, vfloat32m8_t, vfloat16m4_t, vfloat16m4_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vfwmul_vf)))
vfloat32mf2_t vfwmul(vfloat16mf4_t, _Float16, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vfwmul_vf_m)))
vfloat32mf2_t vfwmul(vbool64_t, vfloat32mf2_t, vfloat16mf4_t, _Float16, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vfwmul_vf)))
vfloat32m1_t vfwmul(vfloat16mf2_t, _Float16, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vfwmul_vf_m)))
vfloat32m1_t vfwmul(vbool32_t, vfloat32m1_t, vfloat16mf2_t, _Float16, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vfwmul_vf)))
vfloat32m2_t vfwmul(vfloat16m1_t, _Float16, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vfwmul_vf_m)))
vfloat32m2_t vfwmul(vbool16_t, vfloat32m2_t, vfloat16m1_t, _Float16, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vfwmul_vf)))
vfloat32m4_t vfwmul(vfloat16m2_t, _Float16, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vfwmul_vf_m)))
vfloat32m4_t vfwmul(vbool8_t, vfloat32m4_t, vfloat16m2_t, _Float16, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vfwmul_vf)))
vfloat32m8_t vfwmul(vfloat16m4_t, _Float16, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vfwmul_vf_m)))
vfloat32m8_t vfwmul(vbool4_t, vfloat32m8_t, vfloat16m4_t, _Float16, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vfwmacc_vv)))
vfloat32mf2_t vfwmacc(vfloat32mf2_t, vfloat16mf4_t, vfloat16mf4_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vfwmacc_vv_m)))
vfloat32mf2_t vfwmacc(vbool64_t, vfloat32mf2_t, vfloat16mf4_t, vfloat16mf4_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vfwmacc_vv)))
vfloat32m1_t vfwmacc(vfloat32m1_t, vfloat16mf2_t, vfloat16mf2_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vfwmacc_vv_m)))
vfloat32m1_t vfwmacc(vbool32_t, vfloat32m1_t, vfloat16mf2_t, vfloat16mf2_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vfwmacc_vv)))
vfloat32m2_t vfwmacc(vfloat32m2_t, vfloat16m1_t, vfloat16m1_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vfwmacc_vv_m)))
vfloat32m2_t vfwmacc(vbool16_t, vfloat32m2_t, vfloat16m1_t, vfloat16m1_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vfwmacc_vv)))
vfloat32m4_t vfwmacc(vfloat32m4_t, vfloat16m2_t, vfloat16m2_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vfwmacc_vv_m)))
vfloat32m4_t vfwmacc(vbool8_t, vfloat32m4_t, vfloat16m2_t, vfloat16m2_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vfwmacc_vv)))
vfloat32m8_t vfwmacc(vfloat32m8_t, vfloat16m4_t, vfloat16m4_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vfwmacc_vv_m)))
vfloat32m8_t vfwmacc(vbool4_t, vfloat32m8_t, vfloat16m4_t, vfloat16m4_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vfwmacc_vf)))
vfloat32mf2_t vfwmacc(vfloat32mf2_t, _Float16, vfloat16mf4_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vfwmacc_vf_m)))
vfloat32mf2_t vfwmacc(vbool64_t, vfloat32mf2_t, _Float16, vfloat16mf4_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vfwmacc_vf)))
vfloat32m1_t vfwmacc(vfloat32m1_t, _Float16, vfloat16mf2_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vfwmacc_vf_m)))
vfloat32m1_t vfwmacc(vbool32_t, vfloat32m1_t, _Float16, vfloat16mf2_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vfwmacc_vf)))
vfloat32m2_t vfwmacc(vfloat32m2_t, _Float16, vfloat16m1_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vfwmacc_vf_m)))
vfloat32m2_t vfwmacc(vbool16_t, vfloat32m2_t, _Float16, vfloat16m1_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vfwmacc_vf)))
vfloat32m4_t vfwmacc(vfloat32m4_t, _Float16, vfloat16m2_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vfwmacc_vf_m)))
vfloat32m4_t vfwmacc(vbool8_t, vfloat32m4_t, _Float16, vfloat16m2_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vfwmacc_vf)))
vfloat32m8_t vfwmacc(vfloat32m8_t, _Float16, vfloat16m4_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vfwmacc_vf_m)))
vfloat32m8_t vfwmacc(vbool4_t, vfloat32m8_t, _Float16, vfloat16m4_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vfwnmacc_vv)))
vfloat32mf2_t vfwnmacc(vfloat32mf2_t, vfloat16mf4_t, vfloat16mf4_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vfwnmacc_vv_m)))
vfloat32mf2_t vfwnmacc(vbool64_t, vfloat32mf2_t, vfloat16mf4_t, vfloat16mf4_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vfwnmacc_vv)))
vfloat32m1_t vfwnmacc(vfloat32m1_t, vfloat16mf2_t, vfloat16mf2_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vfwnmacc_vv_m)))
vfloat32m1_t vfwnmacc(vbool32_t, vfloat32m1_t, vfloat16mf2_t, vfloat16mf2_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vfwnmacc_vv)))
vfloat32m2_t vfwnmacc(vfloat32m2_t, vfloat16m1_t, vfloat16m1_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vfwnmacc_vv_m)))
vfloat32m2_t vfwnmacc(vbool16_t, vfloat32m2_t, vfloat16m1_t, vfloat16m1_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vfwnmacc_vv)))
vfloat32m4_t vfwnmacc(vfloat32m4_t, vfloat16m2_t, vfloat16m2_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vfwnmacc_vv_m)))
vfloat32m4_t vfwnmacc(vbool8_t, vfloat32m4_t, vfloat16m2_t, vfloat16m2_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vfwnmacc_vv)))
vfloat32m8_t vfwnmacc(vfloat32m8_t, vfloat16m4_t, vfloat16m4_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vfwnmacc_vv_m)))
vfloat32m8_t vfwnmacc(vbool4_t, vfloat32m8_t, vfloat16m4_t, vfloat16m4_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vfwnmacc_vf)))
vfloat32mf2_t vfwnmacc(vfloat32mf2_t, _Float16, vfloat16mf4_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vfwnmacc_vf_m)))
vfloat32mf2_t vfwnmacc(vbool64_t, vfloat32mf2_t, _Float16, vfloat16mf4_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vfwnmacc_vf)))
vfloat32m1_t vfwnmacc(vfloat32m1_t, _Float16, vfloat16mf2_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vfwnmacc_vf_m)))
vfloat32m1_t vfwnmacc(vbool32_t, vfloat32m1_t, _Float16, vfloat16mf2_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vfwnmacc_vf)))
vfloat32m2_t vfwnmacc(vfloat32m2_t, _Float16, vfloat16m1_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vfwnmacc_vf_m)))
vfloat32m2_t vfwnmacc(vbool16_t, vfloat32m2_t, _Float16, vfloat16m1_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vfwnmacc_vf)))
vfloat32m4_t vfwnmacc(vfloat32m4_t, _Float16, vfloat16m2_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vfwnmacc_vf_m)))
vfloat32m4_t vfwnmacc(vbool8_t, vfloat32m4_t, _Float16, vfloat16m2_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vfwnmacc_vf)))
vfloat32m8_t vfwnmacc(vfloat32m8_t, _Float16, vfloat16m4_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vfwnmacc_vf_m)))
vfloat32m8_t vfwnmacc(vbool4_t, vfloat32m8_t, _Float16, vfloat16m4_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vfwmsac_vv)))
vfloat32mf2_t vfwmsac(vfloat32mf2_t, vfloat16mf4_t, vfloat16mf4_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vfwmsac_vv_m)))
vfloat32mf2_t vfwmsac(vbool64_t, vfloat32mf2_t, vfloat16mf4_t, vfloat16mf4_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vfwmsac_vv)))
vfloat32m1_t vfwmsac(vfloat32m1_t, vfloat16mf2_t, vfloat16mf2_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vfwmsac_vv_m)))
vfloat32m1_t vfwmsac(vbool32_t, vfloat32m1_t, vfloat16mf2_t, vfloat16mf2_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vfwmsac_vv)))
vfloat32m2_t vfwmsac(vfloat32m2_t, vfloat16m1_t, vfloat16m1_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vfwmsac_vv_m)))
vfloat32m2_t vfwmsac(vbool16_t, vfloat32m2_t, vfloat16m1_t, vfloat16m1_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vfwmsac_vv)))
vfloat32m4_t vfwmsac(vfloat32m4_t, vfloat16m2_t, vfloat16m2_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vfwmsac_vv_m)))
vfloat32m4_t vfwmsac(vbool8_t, vfloat32m4_t, vfloat16m2_t, vfloat16m2_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vfwmsac_vv)))
vfloat32m8_t vfwmsac(vfloat32m8_t, vfloat16m4_t, vfloat16m4_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vfwmsac_vv_m)))
vfloat32m8_t vfwmsac(vbool4_t, vfloat32m8_t, vfloat16m4_t, vfloat16m4_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vfwmsac_vf)))
vfloat32mf2_t vfwmsac(vfloat32mf2_t, _Float16, vfloat16mf4_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vfwmsac_vf_m)))
vfloat32mf2_t vfwmsac(vbool64_t, vfloat32mf2_t, _Float16, vfloat16mf4_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vfwmsac_vf)))
vfloat32m1_t vfwmsac(vfloat32m1_t, _Float16, vfloat16mf2_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vfwmsac_vf_m)))
vfloat32m1_t vfwmsac(vbool32_t, vfloat32m1_t, _Float16, vfloat16mf2_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vfwmsac_vf)))
vfloat32m2_t vfwmsac(vfloat32m2_t, _Float16, vfloat16m1_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vfwmsac_vf_m)))
vfloat32m2_t vfwmsac(vbool16_t, vfloat32m2_t, _Float16, vfloat16m1_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vfwmsac_vf)))
vfloat32m4_t vfwmsac(vfloat32m4_t, _Float16, vfloat16m2_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vfwmsac_vf_m)))
vfloat32m4_t vfwmsac(vbool8_t, vfloat32m4_t, _Float16, vfloat16m2_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vfwmsac_vf)))
vfloat32m8_t vfwmsac(vfloat32m8_t, _Float16, vfloat16m4_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vfwmsac_vf_m)))
vfloat32m8_t vfwmsac(vbool4_t, vfloat32m8_t, _Float16, vfloat16m4_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vfwnmsac_vv)))
vfloat32mf2_t vfwnmsac(vfloat32mf2_t, vfloat16mf4_t, vfloat16mf4_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vfwnmsac_vv_m)))
vfloat32mf2_t vfwnmsac(vbool64_t, vfloat32mf2_t, vfloat16mf4_t, vfloat16mf4_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vfwnmsac_vv)))
vfloat32m1_t vfwnmsac(vfloat32m1_t, vfloat16mf2_t, vfloat16mf2_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vfwnmsac_vv_m)))
vfloat32m1_t vfwnmsac(vbool32_t, vfloat32m1_t, vfloat16mf2_t, vfloat16mf2_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vfwnmsac_vv)))
vfloat32m2_t vfwnmsac(vfloat32m2_t, vfloat16m1_t, vfloat16m1_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vfwnmsac_vv_m)))
vfloat32m2_t vfwnmsac(vbool16_t, vfloat32m2_t, vfloat16m1_t, vfloat16m1_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vfwnmsac_vv)))
vfloat32m4_t vfwnmsac(vfloat32m4_t, vfloat16m2_t, vfloat16m2_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vfwnmsac_vv_m)))
vfloat32m4_t vfwnmsac(vbool8_t, vfloat32m4_t, vfloat16m2_t, vfloat16m2_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vfwnmsac_vv)))
vfloat32m8_t vfwnmsac(vfloat32m8_t, vfloat16m4_t, vfloat16m4_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vfwnmsac_vv_m)))
vfloat32m8_t vfwnmsac(vbool4_t, vfloat32m8_t, vfloat16m4_t, vfloat16m4_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vfwnmsac_vf)))
vfloat32mf2_t vfwnmsac(vfloat32mf2_t, _Float16, vfloat16mf4_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vfwnmsac_vf_m)))
vfloat32mf2_t vfwnmsac(vbool64_t, vfloat32mf2_t, _Float16, vfloat16mf4_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vfwnmsac_vf)))
vfloat32m1_t vfwnmsac(vfloat32m1_t, _Float16, vfloat16mf2_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vfwnmsac_vf_m)))
vfloat32m1_t vfwnmsac(vbool32_t, vfloat32m1_t, _Float16, vfloat16mf2_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vfwnmsac_vf)))
vfloat32m2_t vfwnmsac(vfloat32m2_t, _Float16, vfloat16m1_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vfwnmsac_vf_m)))
vfloat32m2_t vfwnmsac(vbool16_t, vfloat32m2_t, _Float16, vfloat16m1_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vfwnmsac_vf)))
vfloat32m4_t vfwnmsac(vfloat32m4_t, _Float16, vfloat16m2_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vfwnmsac_vf_m)))
vfloat32m4_t vfwnmsac(vbool8_t, vfloat32m4_t, _Float16, vfloat16m2_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vfwnmsac_vf)))
vfloat32m8_t vfwnmsac(vfloat32m8_t, _Float16, vfloat16m4_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vfwnmsac_vf_m)))
vfloat32m8_t vfwnmsac(vbool4_t, vfloat32m8_t, _Float16, vfloat16m4_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vfwredusum_vs)))
vfloat32m1_t vfwredusum(vfloat32m1_t, vfloat16m1_t, vfloat32m1_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vfwredusum_vs_m)))
vfloat32m1_t vfwredusum(vbool16_t, vfloat32m1_t, vfloat16m1_t, vfloat32m1_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vfwredusum_vs)))
vfloat32m1_t vfwredusum(vfloat32m1_t, vfloat16m2_t, vfloat32m1_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vfwredusum_vs_m)))
vfloat32m1_t vfwredusum(vbool8_t, vfloat32m1_t, vfloat16m2_t, vfloat32m1_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vfwredusum_vs)))
vfloat32m1_t vfwredusum(vfloat32m1_t, vfloat16m4_t, vfloat32m1_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vfwredusum_vs_m)))
vfloat32m1_t vfwredusum(vbool4_t, vfloat32m1_t, vfloat16m4_t, vfloat32m1_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vfwredusum_vs)))
vfloat32m1_t vfwredusum(vfloat32m1_t, vfloat16m8_t, vfloat32m1_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vfwredusum_vs_m)))
vfloat32m1_t vfwredusum(vbool2_t, vfloat32m1_t, vfloat16m8_t, vfloat32m1_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vfwredusum_vs)))
vfloat32m1_t vfwredusum(vfloat32m1_t, vfloat16mf2_t, vfloat32m1_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vfwredusum_vs_m)))
vfloat32m1_t vfwredusum(vbool32_t, vfloat32m1_t, vfloat16mf2_t, vfloat32m1_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vfwredusum_vs)))
vfloat32m1_t vfwredusum(vfloat32m1_t, vfloat16mf4_t, vfloat32m1_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vfwredusum_vs_m)))
vfloat32m1_t vfwredusum(vbool64_t, vfloat32m1_t, vfloat16mf4_t, vfloat32m1_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vfwredosum_vs)))
vfloat32m1_t vfwredosum(vfloat32m1_t, vfloat16m1_t, vfloat32m1_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vfwredosum_vs_m)))
vfloat32m1_t vfwredosum(vbool16_t, vfloat32m1_t, vfloat16m1_t, vfloat32m1_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vfwredosum_vs)))
vfloat32m1_t vfwredosum(vfloat32m1_t, vfloat16m2_t, vfloat32m1_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vfwredosum_vs_m)))
vfloat32m1_t vfwredosum(vbool8_t, vfloat32m1_t, vfloat16m2_t, vfloat32m1_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vfwredosum_vs)))
vfloat32m1_t vfwredosum(vfloat32m1_t, vfloat16m4_t, vfloat32m1_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vfwredosum_vs_m)))
vfloat32m1_t vfwredosum(vbool4_t, vfloat32m1_t, vfloat16m4_t, vfloat32m1_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vfwredosum_vs)))
vfloat32m1_t vfwredosum(vfloat32m1_t, vfloat16m8_t, vfloat32m1_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vfwredosum_vs_m)))
vfloat32m1_t vfwredosum(vbool2_t, vfloat32m1_t, vfloat16m8_t, vfloat32m1_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vfwredosum_vs)))
vfloat32m1_t vfwredosum(vfloat32m1_t, vfloat16mf2_t, vfloat32m1_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vfwredosum_vs_m)))
vfloat32m1_t vfwredosum(vbool32_t, vfloat32m1_t, vfloat16mf2_t, vfloat32m1_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vfwredosum_vs)))
vfloat32m1_t vfwredosum(vfloat32m1_t, vfloat16mf4_t, vfloat32m1_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vfwredosum_vs_m)))
vfloat32m1_t vfwredosum(vbool64_t, vfloat32m1_t, vfloat16mf4_t, vfloat32m1_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vfncvt_f_f_w)))
vfloat16mf4_t vfncvt_f(vfloat32mf2_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vfncvt_f_f_w_m)))
vfloat16mf4_t vfncvt_f(vbool64_t, vfloat16mf4_t, vfloat32mf2_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vfncvt_f_f_w)))
vfloat16mf2_t vfncvt_f(vfloat32m1_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vfncvt_f_f_w_m)))
vfloat16mf2_t vfncvt_f(vbool32_t, vfloat16mf2_t, vfloat32m1_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vfncvt_f_f_w)))
vfloat16m1_t vfncvt_f(vfloat32m2_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vfncvt_f_f_w_m)))
vfloat16m1_t vfncvt_f(vbool16_t, vfloat16m1_t, vfloat32m2_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vfncvt_f_f_w)))
vfloat16m2_t vfncvt_f(vfloat32m4_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vfncvt_f_f_w_m)))
vfloat16m2_t vfncvt_f(vbool8_t, vfloat16m2_t, vfloat32m4_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vfncvt_f_f_w)))
vfloat16m4_t vfncvt_f(vfloat32m8_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vfncvt_f_f_w_m)))
vfloat16m4_t vfncvt_f(vbool4_t, vfloat16m4_t, vfloat32m8_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vfncvt_rod_f_f_w)))
vfloat16mf4_t vfncvt_rod_f(vfloat32mf2_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vfncvt_rod_f_f_w_m)))
vfloat16mf4_t vfncvt_rod_f(vbool64_t, vfloat16mf4_t, vfloat32mf2_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vfncvt_rod_f_f_w)))
vfloat16mf2_t vfncvt_rod_f(vfloat32m1_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vfncvt_rod_f_f_w_m)))
vfloat16mf2_t vfncvt_rod_f(vbool32_t, vfloat16mf2_t, vfloat32m1_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vfncvt_rod_f_f_w)))
vfloat16m1_t vfncvt_rod_f(vfloat32m2_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vfncvt_rod_f_f_w_m)))
vfloat16m1_t vfncvt_rod_f(vbool16_t, vfloat16m1_t, vfloat32m2_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vfncvt_rod_f_f_w)))
vfloat16m2_t vfncvt_rod_f(vfloat32m4_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vfncvt_rod_f_f_w_m)))
vfloat16m2_t vfncvt_rod_f(vbool8_t, vfloat16m2_t, vfloat32m4_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vfncvt_rod_f_f_w)))
vfloat16m4_t vfncvt_rod_f(vfloat32m8_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vfncvt_rod_f_f_w_m)))
vfloat16m4_t vfncvt_rod_f(vbool4_t, vfloat16m4_t, vfloat32m8_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vfwcvt_f_f_v)))
vfloat32mf2_t vfwcvt_f(vfloat16mf4_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vfwcvt_f_f_v_m)))
vfloat32mf2_t vfwcvt_f(vbool64_t, vfloat32mf2_t, vfloat16mf4_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vfwcvt_f_f_v)))
vfloat32m1_t vfwcvt_f(vfloat16mf2_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vfwcvt_f_f_v_m)))
vfloat32m1_t vfwcvt_f(vbool32_t, vfloat32m1_t, vfloat16mf2_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vfwcvt_f_f_v)))
vfloat32m2_t vfwcvt_f(vfloat16m1_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vfwcvt_f_f_v_m)))
vfloat32m2_t vfwcvt_f(vbool16_t, vfloat32m2_t, vfloat16m1_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vfwcvt_f_f_v)))
vfloat32m4_t vfwcvt_f(vfloat16m2_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vfwcvt_f_f_v_m)))
vfloat32m4_t vfwcvt_f(vbool8_t, vfloat32m4_t, vfloat16m2_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vfwcvt_f_f_v)))
vfloat32m8_t vfwcvt_f(vfloat16m4_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vfwcvt_f_f_v_m)))
vfloat32m8_t vfwcvt_f(vbool4_t, vfloat32m8_t, vfloat16m4_t, size_t);
#endif

#if (__riscv_v_elen >= 64) && (__riscv_v_elen_fp >= 32)
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vloxseg2ei64_v)))
void vloxseg2ei64(vfloat32m1_t *, vfloat32m1_t *, const float *, vuint64m2_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vloxseg2ei64_v_m)))
void vloxseg2ei64(vfloat32m1_t *, vfloat32m1_t *, vbool32_t, vfloat32m1_t, vfloat32m1_t, const float *, vuint64m2_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vloxseg2ei64_v)))
void vloxseg2ei64(vfloat32m2_t *, vfloat32m2_t *, const float *, vuint64m4_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vloxseg2ei64_v_m)))
void vloxseg2ei64(vfloat32m2_t *, vfloat32m2_t *, vbool16_t, vfloat32m2_t, vfloat32m2_t, const float *, vuint64m4_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vloxseg2ei64_v)))
void vloxseg2ei64(vfloat32m4_t *, vfloat32m4_t *, const float *, vuint64m8_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vloxseg2ei64_v_m)))
void vloxseg2ei64(vfloat32m4_t *, vfloat32m4_t *, vbool8_t, vfloat32m4_t, vfloat32m4_t, const float *, vuint64m8_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vloxseg2ei64_v)))
void vloxseg2ei64(vfloat32mf2_t *, vfloat32mf2_t *, const float *, vuint64m1_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vloxseg2ei64_v_m)))
void vloxseg2ei64(vfloat32mf2_t *, vfloat32mf2_t *, vbool64_t, vfloat32mf2_t, vfloat32mf2_t, const float *, vuint64m1_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vloxseg3ei64_v)))
void vloxseg3ei64(vfloat32m1_t *, vfloat32m1_t *, vfloat32m1_t *, const float *, vuint64m2_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vloxseg3ei64_v_m)))
void vloxseg3ei64(vfloat32m1_t *, vfloat32m1_t *, vfloat32m1_t *, vbool32_t, vfloat32m1_t, vfloat32m1_t, vfloat32m1_t, const float *, vuint64m2_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vloxseg3ei64_v)))
void vloxseg3ei64(vfloat32m2_t *, vfloat32m2_t *, vfloat32m2_t *, const float *, vuint64m4_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vloxseg3ei64_v_m)))
void vloxseg3ei64(vfloat32m2_t *, vfloat32m2_t *, vfloat32m2_t *, vbool16_t, vfloat32m2_t, vfloat32m2_t, vfloat32m2_t, const float *, vuint64m4_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vloxseg3ei64_v)))
void vloxseg3ei64(vfloat32mf2_t *, vfloat32mf2_t *, vfloat32mf2_t *, const float *, vuint64m1_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vloxseg3ei64_v_m)))
void vloxseg3ei64(vfloat32mf2_t *, vfloat32mf2_t *, vfloat32mf2_t *, vbool64_t, vfloat32mf2_t, vfloat32mf2_t, vfloat32mf2_t, const float *, vuint64m1_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vloxseg4ei64_v)))
void vloxseg4ei64(vfloat32m1_t *, vfloat32m1_t *, vfloat32m1_t *, vfloat32m1_t *, const float *, vuint64m2_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vloxseg4ei64_v_m)))
void vloxseg4ei64(vfloat32m1_t *, vfloat32m1_t *, vfloat32m1_t *, vfloat32m1_t *, vbool32_t, vfloat32m1_t, vfloat32m1_t, vfloat32m1_t, vfloat32m1_t, const float *, vuint64m2_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vloxseg4ei64_v)))
void vloxseg4ei64(vfloat32m2_t *, vfloat32m2_t *, vfloat32m2_t *, vfloat32m2_t *, const float *, vuint64m4_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vloxseg4ei64_v_m)))
void vloxseg4ei64(vfloat32m2_t *, vfloat32m2_t *, vfloat32m2_t *, vfloat32m2_t *, vbool16_t, vfloat32m2_t, vfloat32m2_t, vfloat32m2_t, vfloat32m2_t, const float *, vuint64m4_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vloxseg4ei64_v)))
void vloxseg4ei64(vfloat32mf2_t *, vfloat32mf2_t *, vfloat32mf2_t *, vfloat32mf2_t *, const float *, vuint64m1_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vloxseg4ei64_v_m)))
void vloxseg4ei64(vfloat32mf2_t *, vfloat32mf2_t *, vfloat32mf2_t *, vfloat32mf2_t *, vbool64_t, vfloat32mf2_t, vfloat32mf2_t, vfloat32mf2_t, vfloat32mf2_t, const float *, vuint64m1_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vloxseg5ei64_v)))
void vloxseg5ei64(vfloat32m1_t *, vfloat32m1_t *, vfloat32m1_t *, vfloat32m1_t *, vfloat32m1_t *, const float *, vuint64m2_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vloxseg5ei64_v_m)))
void vloxseg5ei64(vfloat32m1_t *, vfloat32m1_t *, vfloat32m1_t *, vfloat32m1_t *, vfloat32m1_t *, vbool32_t, vfloat32m1_t, vfloat32m1_t, vfloat32m1_t, vfloat32m1_t, vfloat32m1_t, const float *, vuint64m2_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vloxseg5ei64_v)))
void vloxseg5ei64(vfloat32mf2_t *, vfloat32mf2_t *, vfloat32mf2_t *, vfloat32mf2_t *, vfloat32mf2_t *, const float *, vuint64m1_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vloxseg5ei64_v_m)))
void vloxseg5ei64(vfloat32mf2_t *, vfloat32mf2_t *, vfloat32mf2_t *, vfloat32mf2_t *, vfloat32mf2_t *, vbool64_t, vfloat32mf2_t, vfloat32mf2_t, vfloat32mf2_t, vfloat32mf2_t, vfloat32mf2_t, const float *, vuint64m1_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vloxseg6ei64_v)))
void vloxseg6ei64(vfloat32m1_t *, vfloat32m1_t *, vfloat32m1_t *, vfloat32m1_t *, vfloat32m1_t *, vfloat32m1_t *, const float *, vuint64m2_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vloxseg6ei64_v_m)))
void vloxseg6ei64(vfloat32m1_t *, vfloat32m1_t *, vfloat32m1_t *, vfloat32m1_t *, vfloat32m1_t *, vfloat32m1_t *, vbool32_t, vfloat32m1_t, vfloat32m1_t, vfloat32m1_t, vfloat32m1_t, vfloat32m1_t, vfloat32m1_t, const float *, vuint64m2_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vloxseg6ei64_v)))
void vloxseg6ei64(vfloat32mf2_t *, vfloat32mf2_t *, vfloat32mf2_t *, vfloat32mf2_t *, vfloat32mf2_t *, vfloat32mf2_t *, const float *, vuint64m1_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vloxseg6ei64_v_m)))
void vloxseg6ei64(vfloat32mf2_t *, vfloat32mf2_t *, vfloat32mf2_t *, vfloat32mf2_t *, vfloat32mf2_t *, vfloat32mf2_t *, vbool64_t, vfloat32mf2_t, vfloat32mf2_t, vfloat32mf2_t, vfloat32mf2_t, vfloat32mf2_t, vfloat32mf2_t, const float *, vuint64m1_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vloxseg7ei64_v)))
void vloxseg7ei64(vfloat32m1_t *, vfloat32m1_t *, vfloat32m1_t *, vfloat32m1_t *, vfloat32m1_t *, vfloat32m1_t *, vfloat32m1_t *, const float *, vuint64m2_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vloxseg7ei64_v_m)))
void vloxseg7ei64(vfloat32m1_t *, vfloat32m1_t *, vfloat32m1_t *, vfloat32m1_t *, vfloat32m1_t *, vfloat32m1_t *, vfloat32m1_t *, vbool32_t, vfloat32m1_t, vfloat32m1_t, vfloat32m1_t, vfloat32m1_t, vfloat32m1_t, vfloat32m1_t, vfloat32m1_t, const float *, vuint64m2_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vloxseg7ei64_v)))
void vloxseg7ei64(vfloat32mf2_t *, vfloat32mf2_t *, vfloat32mf2_t *, vfloat32mf2_t *, vfloat32mf2_t *, vfloat32mf2_t *, vfloat32mf2_t *, const float *, vuint64m1_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vloxseg7ei64_v_m)))
void vloxseg7ei64(vfloat32mf2_t *, vfloat32mf2_t *, vfloat32mf2_t *, vfloat32mf2_t *, vfloat32mf2_t *, vfloat32mf2_t *, vfloat32mf2_t *, vbool64_t, vfloat32mf2_t, vfloat32mf2_t, vfloat32mf2_t, vfloat32mf2_t, vfloat32mf2_t, vfloat32mf2_t, vfloat32mf2_t, const float *, vuint64m1_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vloxseg8ei64_v)))
void vloxseg8ei64(vfloat32m1_t *, vfloat32m1_t *, vfloat32m1_t *, vfloat32m1_t *, vfloat32m1_t *, vfloat32m1_t *, vfloat32m1_t *, vfloat32m1_t *, const float *, vuint64m2_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vloxseg8ei64_v_m)))
void vloxseg8ei64(vfloat32m1_t *, vfloat32m1_t *, vfloat32m1_t *, vfloat32m1_t *, vfloat32m1_t *, vfloat32m1_t *, vfloat32m1_t *, vfloat32m1_t *, vbool32_t, vfloat32m1_t, vfloat32m1_t, vfloat32m1_t, vfloat32m1_t, vfloat32m1_t, vfloat32m1_t, vfloat32m1_t, vfloat32m1_t, const float *, vuint64m2_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vloxseg8ei64_v)))
void vloxseg8ei64(vfloat32mf2_t *, vfloat32mf2_t *, vfloat32mf2_t *, vfloat32mf2_t *, vfloat32mf2_t *, vfloat32mf2_t *, vfloat32mf2_t *, vfloat32mf2_t *, const float *, vuint64m1_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vloxseg8ei64_v_m)))
void vloxseg8ei64(vfloat32mf2_t *, vfloat32mf2_t *, vfloat32mf2_t *, vfloat32mf2_t *, vfloat32mf2_t *, vfloat32mf2_t *, vfloat32mf2_t *, vfloat32mf2_t *, vbool64_t, vfloat32mf2_t, vfloat32mf2_t, vfloat32mf2_t, vfloat32mf2_t, vfloat32mf2_t, vfloat32mf2_t, vfloat32mf2_t, vfloat32mf2_t, const float *, vuint64m1_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vsuxseg2ei64_v)))
void vsuxseg2ei64(float *, vuint64m2_t, vfloat32m1_t, vfloat32m1_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vsuxseg2ei64_v_m)))
void vsuxseg2ei64(vbool32_t, float *, vuint64m2_t, vfloat32m1_t, vfloat32m1_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vsuxseg2ei64_v)))
void vsuxseg2ei64(float *, vuint64m4_t, vfloat32m2_t, vfloat32m2_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vsuxseg2ei64_v_m)))
void vsuxseg2ei64(vbool16_t, float *, vuint64m4_t, vfloat32m2_t, vfloat32m2_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vsuxseg2ei64_v)))
void vsuxseg2ei64(float *, vuint64m8_t, vfloat32m4_t, vfloat32m4_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vsuxseg2ei64_v_m)))
void vsuxseg2ei64(vbool8_t, float *, vuint64m8_t, vfloat32m4_t, vfloat32m4_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vsuxseg2ei64_v)))
void vsuxseg2ei64(float *, vuint64m1_t, vfloat32mf2_t, vfloat32mf2_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vsuxseg2ei64_v_m)))
void vsuxseg2ei64(vbool64_t, float *, vuint64m1_t, vfloat32mf2_t, vfloat32mf2_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vsuxseg3ei64_v)))
void vsuxseg3ei64(float *, vuint64m2_t, vfloat32m1_t, vfloat32m1_t, vfloat32m1_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vsuxseg3ei64_v_m)))
void vsuxseg3ei64(vbool32_t, float *, vuint64m2_t, vfloat32m1_t, vfloat32m1_t, vfloat32m1_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vsuxseg3ei64_v)))
void vsuxseg3ei64(float *, vuint64m4_t, vfloat32m2_t, vfloat32m2_t, vfloat32m2_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vsuxseg3ei64_v_m)))
void vsuxseg3ei64(vbool16_t, float *, vuint64m4_t, vfloat32m2_t, vfloat32m2_t, vfloat32m2_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vsuxseg3ei64_v)))
void vsuxseg3ei64(float *, vuint64m1_t, vfloat32mf2_t, vfloat32mf2_t, vfloat32mf2_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vsuxseg3ei64_v_m)))
void vsuxseg3ei64(vbool64_t, float *, vuint64m1_t, vfloat32mf2_t, vfloat32mf2_t, vfloat32mf2_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vsuxseg4ei64_v)))
void vsuxseg4ei64(float *, vuint64m2_t, vfloat32m1_t, vfloat32m1_t, vfloat32m1_t, vfloat32m1_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vsuxseg4ei64_v_m)))
void vsuxseg4ei64(vbool32_t, float *, vuint64m2_t, vfloat32m1_t, vfloat32m1_t, vfloat32m1_t, vfloat32m1_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vsuxseg4ei64_v)))
void vsuxseg4ei64(float *, vuint64m4_t, vfloat32m2_t, vfloat32m2_t, vfloat32m2_t, vfloat32m2_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vsuxseg4ei64_v_m)))
void vsuxseg4ei64(vbool16_t, float *, vuint64m4_t, vfloat32m2_t, vfloat32m2_t, vfloat32m2_t, vfloat32m2_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vsuxseg4ei64_v)))
void vsuxseg4ei64(float *, vuint64m1_t, vfloat32mf2_t, vfloat32mf2_t, vfloat32mf2_t, vfloat32mf2_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vsuxseg4ei64_v_m)))
void vsuxseg4ei64(vbool64_t, float *, vuint64m1_t, vfloat32mf2_t, vfloat32mf2_t, vfloat32mf2_t, vfloat32mf2_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vsuxseg5ei64_v)))
void vsuxseg5ei64(float *, vuint64m2_t, vfloat32m1_t, vfloat32m1_t, vfloat32m1_t, vfloat32m1_t, vfloat32m1_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vsuxseg5ei64_v_m)))
void vsuxseg5ei64(vbool32_t, float *, vuint64m2_t, vfloat32m1_t, vfloat32m1_t, vfloat32m1_t, vfloat32m1_t, vfloat32m1_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vsuxseg5ei64_v)))
void vsuxseg5ei64(float *, vuint64m1_t, vfloat32mf2_t, vfloat32mf2_t, vfloat32mf2_t, vfloat32mf2_t, vfloat32mf2_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vsuxseg5ei64_v_m)))
void vsuxseg5ei64(vbool64_t, float *, vuint64m1_t, vfloat32mf2_t, vfloat32mf2_t, vfloat32mf2_t, vfloat32mf2_t, vfloat32mf2_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vsuxseg6ei64_v)))
void vsuxseg6ei64(float *, vuint64m2_t, vfloat32m1_t, vfloat32m1_t, vfloat32m1_t, vfloat32m1_t, vfloat32m1_t, vfloat32m1_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vsuxseg6ei64_v_m)))
void vsuxseg6ei64(vbool32_t, float *, vuint64m2_t, vfloat32m1_t, vfloat32m1_t, vfloat32m1_t, vfloat32m1_t, vfloat32m1_t, vfloat32m1_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vsuxseg6ei64_v)))
void vsuxseg6ei64(float *, vuint64m1_t, vfloat32mf2_t, vfloat32mf2_t, vfloat32mf2_t, vfloat32mf2_t, vfloat32mf2_t, vfloat32mf2_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vsuxseg6ei64_v_m)))
void vsuxseg6ei64(vbool64_t, float *, vuint64m1_t, vfloat32mf2_t, vfloat32mf2_t, vfloat32mf2_t, vfloat32mf2_t, vfloat32mf2_t, vfloat32mf2_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vsuxseg7ei64_v)))
void vsuxseg7ei64(float *, vuint64m2_t, vfloat32m1_t, vfloat32m1_t, vfloat32m1_t, vfloat32m1_t, vfloat32m1_t, vfloat32m1_t, vfloat32m1_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vsuxseg7ei64_v_m)))
void vsuxseg7ei64(vbool32_t, float *, vuint64m2_t, vfloat32m1_t, vfloat32m1_t, vfloat32m1_t, vfloat32m1_t, vfloat32m1_t, vfloat32m1_t, vfloat32m1_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vsuxseg7ei64_v)))
void vsuxseg7ei64(float *, vuint64m1_t, vfloat32mf2_t, vfloat32mf2_t, vfloat32mf2_t, vfloat32mf2_t, vfloat32mf2_t, vfloat32mf2_t, vfloat32mf2_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vsuxseg7ei64_v_m)))
void vsuxseg7ei64(vbool64_t, float *, vuint64m1_t, vfloat32mf2_t, vfloat32mf2_t, vfloat32mf2_t, vfloat32mf2_t, vfloat32mf2_t, vfloat32mf2_t, vfloat32mf2_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vsuxseg8ei64_v)))
void vsuxseg8ei64(float *, vuint64m2_t, vfloat32m1_t, vfloat32m1_t, vfloat32m1_t, vfloat32m1_t, vfloat32m1_t, vfloat32m1_t, vfloat32m1_t, vfloat32m1_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vsuxseg8ei64_v_m)))
void vsuxseg8ei64(vbool32_t, float *, vuint64m2_t, vfloat32m1_t, vfloat32m1_t, vfloat32m1_t, vfloat32m1_t, vfloat32m1_t, vfloat32m1_t, vfloat32m1_t, vfloat32m1_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vsuxseg8ei64_v)))
void vsuxseg8ei64(float *, vuint64m1_t, vfloat32mf2_t, vfloat32mf2_t, vfloat32mf2_t, vfloat32mf2_t, vfloat32mf2_t, vfloat32mf2_t, vfloat32mf2_t, vfloat32mf2_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vsuxseg8ei64_v_m)))
void vsuxseg8ei64(vbool64_t, float *, vuint64m1_t, vfloat32mf2_t, vfloat32mf2_t, vfloat32mf2_t, vfloat32mf2_t, vfloat32mf2_t, vfloat32mf2_t, vfloat32mf2_t, vfloat32mf2_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vsoxseg2ei64_v)))
void vsoxseg2ei64(float *, vuint64m2_t, vfloat32m1_t, vfloat32m1_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vsoxseg2ei64_v_m)))
void vsoxseg2ei64(vbool32_t, float *, vuint64m2_t, vfloat32m1_t, vfloat32m1_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vsoxseg2ei64_v)))
void vsoxseg2ei64(float *, vuint64m4_t, vfloat32m2_t, vfloat32m2_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vsoxseg2ei64_v_m)))
void vsoxseg2ei64(vbool16_t, float *, vuint64m4_t, vfloat32m2_t, vfloat32m2_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vsoxseg2ei64_v)))
void vsoxseg2ei64(float *, vuint64m8_t, vfloat32m4_t, vfloat32m4_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vsoxseg2ei64_v_m)))
void vsoxseg2ei64(vbool8_t, float *, vuint64m8_t, vfloat32m4_t, vfloat32m4_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vsoxseg2ei64_v)))
void vsoxseg2ei64(float *, vuint64m1_t, vfloat32mf2_t, vfloat32mf2_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vsoxseg2ei64_v_m)))
void vsoxseg2ei64(vbool64_t, float *, vuint64m1_t, vfloat32mf2_t, vfloat32mf2_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vsoxseg3ei64_v)))
void vsoxseg3ei64(float *, vuint64m2_t, vfloat32m1_t, vfloat32m1_t, vfloat32m1_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vsoxseg3ei64_v_m)))
void vsoxseg3ei64(vbool32_t, float *, vuint64m2_t, vfloat32m1_t, vfloat32m1_t, vfloat32m1_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vsoxseg3ei64_v)))
void vsoxseg3ei64(float *, vuint64m4_t, vfloat32m2_t, vfloat32m2_t, vfloat32m2_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vsoxseg3ei64_v_m)))
void vsoxseg3ei64(vbool16_t, float *, vuint64m4_t, vfloat32m2_t, vfloat32m2_t, vfloat32m2_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vsoxseg3ei64_v)))
void vsoxseg3ei64(float *, vuint64m1_t, vfloat32mf2_t, vfloat32mf2_t, vfloat32mf2_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vsoxseg3ei64_v_m)))
void vsoxseg3ei64(vbool64_t, float *, vuint64m1_t, vfloat32mf2_t, vfloat32mf2_t, vfloat32mf2_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vsoxseg4ei64_v)))
void vsoxseg4ei64(float *, vuint64m2_t, vfloat32m1_t, vfloat32m1_t, vfloat32m1_t, vfloat32m1_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vsoxseg4ei64_v_m)))
void vsoxseg4ei64(vbool32_t, float *, vuint64m2_t, vfloat32m1_t, vfloat32m1_t, vfloat32m1_t, vfloat32m1_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vsoxseg4ei64_v)))
void vsoxseg4ei64(float *, vuint64m4_t, vfloat32m2_t, vfloat32m2_t, vfloat32m2_t, vfloat32m2_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vsoxseg4ei64_v_m)))
void vsoxseg4ei64(vbool16_t, float *, vuint64m4_t, vfloat32m2_t, vfloat32m2_t, vfloat32m2_t, vfloat32m2_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vsoxseg4ei64_v)))
void vsoxseg4ei64(float *, vuint64m1_t, vfloat32mf2_t, vfloat32mf2_t, vfloat32mf2_t, vfloat32mf2_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vsoxseg4ei64_v_m)))
void vsoxseg4ei64(vbool64_t, float *, vuint64m1_t, vfloat32mf2_t, vfloat32mf2_t, vfloat32mf2_t, vfloat32mf2_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vsoxseg5ei64_v)))
void vsoxseg5ei64(float *, vuint64m2_t, vfloat32m1_t, vfloat32m1_t, vfloat32m1_t, vfloat32m1_t, vfloat32m1_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vsoxseg5ei64_v_m)))
void vsoxseg5ei64(vbool32_t, float *, vuint64m2_t, vfloat32m1_t, vfloat32m1_t, vfloat32m1_t, vfloat32m1_t, vfloat32m1_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vsoxseg5ei64_v)))
void vsoxseg5ei64(float *, vuint64m1_t, vfloat32mf2_t, vfloat32mf2_t, vfloat32mf2_t, vfloat32mf2_t, vfloat32mf2_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vsoxseg5ei64_v_m)))
void vsoxseg5ei64(vbool64_t, float *, vuint64m1_t, vfloat32mf2_t, vfloat32mf2_t, vfloat32mf2_t, vfloat32mf2_t, vfloat32mf2_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vsoxseg6ei64_v)))
void vsoxseg6ei64(float *, vuint64m2_t, vfloat32m1_t, vfloat32m1_t, vfloat32m1_t, vfloat32m1_t, vfloat32m1_t, vfloat32m1_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vsoxseg6ei64_v_m)))
void vsoxseg6ei64(vbool32_t, float *, vuint64m2_t, vfloat32m1_t, vfloat32m1_t, vfloat32m1_t, vfloat32m1_t, vfloat32m1_t, vfloat32m1_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vsoxseg6ei64_v)))
void vsoxseg6ei64(float *, vuint64m1_t, vfloat32mf2_t, vfloat32mf2_t, vfloat32mf2_t, vfloat32mf2_t, vfloat32mf2_t, vfloat32mf2_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vsoxseg6ei64_v_m)))
void vsoxseg6ei64(vbool64_t, float *, vuint64m1_t, vfloat32mf2_t, vfloat32mf2_t, vfloat32mf2_t, vfloat32mf2_t, vfloat32mf2_t, vfloat32mf2_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vsoxseg7ei64_v)))
void vsoxseg7ei64(float *, vuint64m2_t, vfloat32m1_t, vfloat32m1_t, vfloat32m1_t, vfloat32m1_t, vfloat32m1_t, vfloat32m1_t, vfloat32m1_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vsoxseg7ei64_v_m)))
void vsoxseg7ei64(vbool32_t, float *, vuint64m2_t, vfloat32m1_t, vfloat32m1_t, vfloat32m1_t, vfloat32m1_t, vfloat32m1_t, vfloat32m1_t, vfloat32m1_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vsoxseg7ei64_v)))
void vsoxseg7ei64(float *, vuint64m1_t, vfloat32mf2_t, vfloat32mf2_t, vfloat32mf2_t, vfloat32mf2_t, vfloat32mf2_t, vfloat32mf2_t, vfloat32mf2_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vsoxseg7ei64_v_m)))
void vsoxseg7ei64(vbool64_t, float *, vuint64m1_t, vfloat32mf2_t, vfloat32mf2_t, vfloat32mf2_t, vfloat32mf2_t, vfloat32mf2_t, vfloat32mf2_t, vfloat32mf2_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vsoxseg8ei64_v)))
void vsoxseg8ei64(float *, vuint64m2_t, vfloat32m1_t, vfloat32m1_t, vfloat32m1_t, vfloat32m1_t, vfloat32m1_t, vfloat32m1_t, vfloat32m1_t, vfloat32m1_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vsoxseg8ei64_v_m)))
void vsoxseg8ei64(vbool32_t, float *, vuint64m2_t, vfloat32m1_t, vfloat32m1_t, vfloat32m1_t, vfloat32m1_t, vfloat32m1_t, vfloat32m1_t, vfloat32m1_t, vfloat32m1_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vsoxseg8ei64_v)))
void vsoxseg8ei64(float *, vuint64m1_t, vfloat32mf2_t, vfloat32mf2_t, vfloat32mf2_t, vfloat32mf2_t, vfloat32mf2_t, vfloat32mf2_t, vfloat32mf2_t, vfloat32mf2_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vsoxseg8ei64_v_m)))
void vsoxseg8ei64(vbool64_t, float *, vuint64m1_t, vfloat32mf2_t, vfloat32mf2_t, vfloat32mf2_t, vfloat32mf2_t, vfloat32mf2_t, vfloat32mf2_t, vfloat32mf2_t, vfloat32mf2_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vluxseg2ei64_v)))
void vluxseg2ei64(vfloat32m1_t *, vfloat32m1_t *, const float *, vuint64m2_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vluxseg2ei64_v_m)))
void vluxseg2ei64(vfloat32m1_t *, vfloat32m1_t *, vbool32_t, vfloat32m1_t, vfloat32m1_t, const float *, vuint64m2_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vluxseg2ei64_v)))
void vluxseg2ei64(vfloat32m2_t *, vfloat32m2_t *, const float *, vuint64m4_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vluxseg2ei64_v_m)))
void vluxseg2ei64(vfloat32m2_t *, vfloat32m2_t *, vbool16_t, vfloat32m2_t, vfloat32m2_t, const float *, vuint64m4_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vluxseg2ei64_v)))
void vluxseg2ei64(vfloat32m4_t *, vfloat32m4_t *, const float *, vuint64m8_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vluxseg2ei64_v_m)))
void vluxseg2ei64(vfloat32m4_t *, vfloat32m4_t *, vbool8_t, vfloat32m4_t, vfloat32m4_t, const float *, vuint64m8_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vluxseg2ei64_v)))
void vluxseg2ei64(vfloat32mf2_t *, vfloat32mf2_t *, const float *, vuint64m1_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vluxseg2ei64_v_m)))
void vluxseg2ei64(vfloat32mf2_t *, vfloat32mf2_t *, vbool64_t, vfloat32mf2_t, vfloat32mf2_t, const float *, vuint64m1_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vluxseg3ei64_v)))
void vluxseg3ei64(vfloat32m1_t *, vfloat32m1_t *, vfloat32m1_t *, const float *, vuint64m2_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vluxseg3ei64_v_m)))
void vluxseg3ei64(vfloat32m1_t *, vfloat32m1_t *, vfloat32m1_t *, vbool32_t, vfloat32m1_t, vfloat32m1_t, vfloat32m1_t, const float *, vuint64m2_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vluxseg3ei64_v)))
void vluxseg3ei64(vfloat32m2_t *, vfloat32m2_t *, vfloat32m2_t *, const float *, vuint64m4_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vluxseg3ei64_v_m)))
void vluxseg3ei64(vfloat32m2_t *, vfloat32m2_t *, vfloat32m2_t *, vbool16_t, vfloat32m2_t, vfloat32m2_t, vfloat32m2_t, const float *, vuint64m4_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vluxseg3ei64_v)))
void vluxseg3ei64(vfloat32mf2_t *, vfloat32mf2_t *, vfloat32mf2_t *, const float *, vuint64m1_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vluxseg3ei64_v_m)))
void vluxseg3ei64(vfloat32mf2_t *, vfloat32mf2_t *, vfloat32mf2_t *, vbool64_t, vfloat32mf2_t, vfloat32mf2_t, vfloat32mf2_t, const float *, vuint64m1_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vluxseg4ei64_v)))
void vluxseg4ei64(vfloat32m1_t *, vfloat32m1_t *, vfloat32m1_t *, vfloat32m1_t *, const float *, vuint64m2_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vluxseg4ei64_v_m)))
void vluxseg4ei64(vfloat32m1_t *, vfloat32m1_t *, vfloat32m1_t *, vfloat32m1_t *, vbool32_t, vfloat32m1_t, vfloat32m1_t, vfloat32m1_t, vfloat32m1_t, const float *, vuint64m2_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vluxseg4ei64_v)))
void vluxseg4ei64(vfloat32m2_t *, vfloat32m2_t *, vfloat32m2_t *, vfloat32m2_t *, const float *, vuint64m4_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vluxseg4ei64_v_m)))
void vluxseg4ei64(vfloat32m2_t *, vfloat32m2_t *, vfloat32m2_t *, vfloat32m2_t *, vbool16_t, vfloat32m2_t, vfloat32m2_t, vfloat32m2_t, vfloat32m2_t, const float *, vuint64m4_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vluxseg4ei64_v)))
void vluxseg4ei64(vfloat32mf2_t *, vfloat32mf2_t *, vfloat32mf2_t *, vfloat32mf2_t *, const float *, vuint64m1_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vluxseg4ei64_v_m)))
void vluxseg4ei64(vfloat32mf2_t *, vfloat32mf2_t *, vfloat32mf2_t *, vfloat32mf2_t *, vbool64_t, vfloat32mf2_t, vfloat32mf2_t, vfloat32mf2_t, vfloat32mf2_t, const float *, vuint64m1_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vluxseg5ei64_v)))
void vluxseg5ei64(vfloat32m1_t *, vfloat32m1_t *, vfloat32m1_t *, vfloat32m1_t *, vfloat32m1_t *, const float *, vuint64m2_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vluxseg5ei64_v_m)))
void vluxseg5ei64(vfloat32m1_t *, vfloat32m1_t *, vfloat32m1_t *, vfloat32m1_t *, vfloat32m1_t *, vbool32_t, vfloat32m1_t, vfloat32m1_t, vfloat32m1_t, vfloat32m1_t, vfloat32m1_t, const float *, vuint64m2_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vluxseg5ei64_v)))
void vluxseg5ei64(vfloat32mf2_t *, vfloat32mf2_t *, vfloat32mf2_t *, vfloat32mf2_t *, vfloat32mf2_t *, const float *, vuint64m1_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vluxseg5ei64_v_m)))
void vluxseg5ei64(vfloat32mf2_t *, vfloat32mf2_t *, vfloat32mf2_t *, vfloat32mf2_t *, vfloat32mf2_t *, vbool64_t, vfloat32mf2_t, vfloat32mf2_t, vfloat32mf2_t, vfloat32mf2_t, vfloat32mf2_t, const float *, vuint64m1_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vluxseg6ei64_v)))
void vluxseg6ei64(vfloat32m1_t *, vfloat32m1_t *, vfloat32m1_t *, vfloat32m1_t *, vfloat32m1_t *, vfloat32m1_t *, const float *, vuint64m2_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vluxseg6ei64_v_m)))
void vluxseg6ei64(vfloat32m1_t *, vfloat32m1_t *, vfloat32m1_t *, vfloat32m1_t *, vfloat32m1_t *, vfloat32m1_t *, vbool32_t, vfloat32m1_t, vfloat32m1_t, vfloat32m1_t, vfloat32m1_t, vfloat32m1_t, vfloat32m1_t, const float *, vuint64m2_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vluxseg6ei64_v)))
void vluxseg6ei64(vfloat32mf2_t *, vfloat32mf2_t *, vfloat32mf2_t *, vfloat32mf2_t *, vfloat32mf2_t *, vfloat32mf2_t *, const float *, vuint64m1_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vluxseg6ei64_v_m)))
void vluxseg6ei64(vfloat32mf2_t *, vfloat32mf2_t *, vfloat32mf2_t *, vfloat32mf2_t *, vfloat32mf2_t *, vfloat32mf2_t *, vbool64_t, vfloat32mf2_t, vfloat32mf2_t, vfloat32mf2_t, vfloat32mf2_t, vfloat32mf2_t, vfloat32mf2_t, const float *, vuint64m1_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vluxseg7ei64_v)))
void vluxseg7ei64(vfloat32m1_t *, vfloat32m1_t *, vfloat32m1_t *, vfloat32m1_t *, vfloat32m1_t *, vfloat32m1_t *, vfloat32m1_t *, const float *, vuint64m2_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vluxseg7ei64_v_m)))
void vluxseg7ei64(vfloat32m1_t *, vfloat32m1_t *, vfloat32m1_t *, vfloat32m1_t *, vfloat32m1_t *, vfloat32m1_t *, vfloat32m1_t *, vbool32_t, vfloat32m1_t, vfloat32m1_t, vfloat32m1_t, vfloat32m1_t, vfloat32m1_t, vfloat32m1_t, vfloat32m1_t, const float *, vuint64m2_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vluxseg7ei64_v)))
void vluxseg7ei64(vfloat32mf2_t *, vfloat32mf2_t *, vfloat32mf2_t *, vfloat32mf2_t *, vfloat32mf2_t *, vfloat32mf2_t *, vfloat32mf2_t *, const float *, vuint64m1_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vluxseg7ei64_v_m)))
void vluxseg7ei64(vfloat32mf2_t *, vfloat32mf2_t *, vfloat32mf2_t *, vfloat32mf2_t *, vfloat32mf2_t *, vfloat32mf2_t *, vfloat32mf2_t *, vbool64_t, vfloat32mf2_t, vfloat32mf2_t, vfloat32mf2_t, vfloat32mf2_t, vfloat32mf2_t, vfloat32mf2_t, vfloat32mf2_t, const float *, vuint64m1_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vluxseg8ei64_v)))
void vluxseg8ei64(vfloat32m1_t *, vfloat32m1_t *, vfloat32m1_t *, vfloat32m1_t *, vfloat32m1_t *, vfloat32m1_t *, vfloat32m1_t *, vfloat32m1_t *, const float *, vuint64m2_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vluxseg8ei64_v_m)))
void vluxseg8ei64(vfloat32m1_t *, vfloat32m1_t *, vfloat32m1_t *, vfloat32m1_t *, vfloat32m1_t *, vfloat32m1_t *, vfloat32m1_t *, vfloat32m1_t *, vbool32_t, vfloat32m1_t, vfloat32m1_t, vfloat32m1_t, vfloat32m1_t, vfloat32m1_t, vfloat32m1_t, vfloat32m1_t, vfloat32m1_t, const float *, vuint64m2_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vluxseg8ei64_v)))
void vluxseg8ei64(vfloat32mf2_t *, vfloat32mf2_t *, vfloat32mf2_t *, vfloat32mf2_t *, vfloat32mf2_t *, vfloat32mf2_t *, vfloat32mf2_t *, vfloat32mf2_t *, const float *, vuint64m1_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vluxseg8ei64_v_m)))
void vluxseg8ei64(vfloat32mf2_t *, vfloat32mf2_t *, vfloat32mf2_t *, vfloat32mf2_t *, vfloat32mf2_t *, vfloat32mf2_t *, vfloat32mf2_t *, vfloat32mf2_t *, vbool64_t, vfloat32mf2_t, vfloat32mf2_t, vfloat32mf2_t, vfloat32mf2_t, vfloat32mf2_t, vfloat32mf2_t, vfloat32mf2_t, vfloat32mf2_t, const float *, vuint64m1_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vfncvt_f_x_w)))
vfloat32mf2_t vfncvt_f(vint64m1_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vfncvt_f_x_w_m)))
vfloat32mf2_t vfncvt_f(vbool64_t, vfloat32mf2_t, vint64m1_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vfncvt_f_x_w)))
vfloat32m1_t vfncvt_f(vint64m2_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vfncvt_f_x_w_m)))
vfloat32m1_t vfncvt_f(vbool32_t, vfloat32m1_t, vint64m2_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vfncvt_f_x_w)))
vfloat32m2_t vfncvt_f(vint64m4_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vfncvt_f_x_w_m)))
vfloat32m2_t vfncvt_f(vbool16_t, vfloat32m2_t, vint64m4_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vfncvt_f_x_w)))
vfloat32m4_t vfncvt_f(vint64m8_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vfncvt_f_x_w_m)))
vfloat32m4_t vfncvt_f(vbool8_t, vfloat32m4_t, vint64m8_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vfncvt_f_xu_w)))
vfloat32mf2_t vfncvt_f(vuint64m1_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vfncvt_f_xu_w_m)))
vfloat32mf2_t vfncvt_f(vbool64_t, vfloat32mf2_t, vuint64m1_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vfncvt_f_xu_w)))
vfloat32m1_t vfncvt_f(vuint64m2_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vfncvt_f_xu_w_m)))
vfloat32m1_t vfncvt_f(vbool32_t, vfloat32m1_t, vuint64m2_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vfncvt_f_xu_w)))
vfloat32m2_t vfncvt_f(vuint64m4_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vfncvt_f_xu_w_m)))
vfloat32m2_t vfncvt_f(vbool16_t, vfloat32m2_t, vuint64m4_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vfncvt_f_xu_w)))
vfloat32m4_t vfncvt_f(vuint64m8_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vfncvt_f_xu_w_m)))
vfloat32m4_t vfncvt_f(vbool8_t, vfloat32m4_t, vuint64m8_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vfwcvt_rtz_x_f_v)))
vint64m1_t vfwcvt_rtz_x(vfloat32mf2_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vfwcvt_rtz_x_f_v_m)))
vint64m1_t vfwcvt_rtz_x(vbool64_t, vint64m1_t, vfloat32mf2_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vfwcvt_rtz_x_f_v)))
vint64m2_t vfwcvt_rtz_x(vfloat32m1_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vfwcvt_rtz_x_f_v_m)))
vint64m2_t vfwcvt_rtz_x(vbool32_t, vint64m2_t, vfloat32m1_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vfwcvt_rtz_x_f_v)))
vint64m4_t vfwcvt_rtz_x(vfloat32m2_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vfwcvt_rtz_x_f_v_m)))
vint64m4_t vfwcvt_rtz_x(vbool16_t, vint64m4_t, vfloat32m2_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vfwcvt_rtz_x_f_v)))
vint64m8_t vfwcvt_rtz_x(vfloat32m4_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vfwcvt_rtz_x_f_v_m)))
vint64m8_t vfwcvt_rtz_x(vbool8_t, vint64m8_t, vfloat32m4_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vfwcvt_rtz_xu_f_v)))
vuint64m1_t vfwcvt_rtz_xu(vfloat32mf2_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vfwcvt_rtz_xu_f_v_m)))
vuint64m1_t vfwcvt_rtz_xu(vbool64_t, vuint64m1_t, vfloat32mf2_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vfwcvt_rtz_xu_f_v)))
vuint64m2_t vfwcvt_rtz_xu(vfloat32m1_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vfwcvt_rtz_xu_f_v_m)))
vuint64m2_t vfwcvt_rtz_xu(vbool32_t, vuint64m2_t, vfloat32m1_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vfwcvt_rtz_xu_f_v)))
vuint64m4_t vfwcvt_rtz_xu(vfloat32m2_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vfwcvt_rtz_xu_f_v_m)))
vuint64m4_t vfwcvt_rtz_xu(vbool16_t, vuint64m4_t, vfloat32m2_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vfwcvt_rtz_xu_f_v)))
vuint64m8_t vfwcvt_rtz_xu(vfloat32m4_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vfwcvt_rtz_xu_f_v_m)))
vuint64m8_t vfwcvt_rtz_xu(vbool8_t, vuint64m8_t, vfloat32m4_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vfwcvt_x_f_v)))
vint64m1_t vfwcvt_x(vfloat32mf2_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vfwcvt_x_f_v_m)))
vint64m1_t vfwcvt_x(vbool64_t, vint64m1_t, vfloat32mf2_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vfwcvt_x_f_v)))
vint64m2_t vfwcvt_x(vfloat32m1_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vfwcvt_x_f_v_m)))
vint64m2_t vfwcvt_x(vbool32_t, vint64m2_t, vfloat32m1_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vfwcvt_x_f_v)))
vint64m4_t vfwcvt_x(vfloat32m2_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vfwcvt_x_f_v_m)))
vint64m4_t vfwcvt_x(vbool16_t, vint64m4_t, vfloat32m2_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vfwcvt_x_f_v)))
vint64m8_t vfwcvt_x(vfloat32m4_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vfwcvt_x_f_v_m)))
vint64m8_t vfwcvt_x(vbool8_t, vint64m8_t, vfloat32m4_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vfwcvt_xu_f_v)))
vuint64m1_t vfwcvt_xu(vfloat32mf2_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vfwcvt_xu_f_v_m)))
vuint64m1_t vfwcvt_xu(vbool64_t, vuint64m1_t, vfloat32mf2_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vfwcvt_xu_f_v)))
vuint64m2_t vfwcvt_xu(vfloat32m1_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vfwcvt_xu_f_v_m)))
vuint64m2_t vfwcvt_xu(vbool32_t, vuint64m2_t, vfloat32m1_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vfwcvt_xu_f_v)))
vuint64m4_t vfwcvt_xu(vfloat32m2_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vfwcvt_xu_f_v_m)))
vuint64m4_t vfwcvt_xu(vbool16_t, vuint64m4_t, vfloat32m2_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vfwcvt_xu_f_v)))
vuint64m8_t vfwcvt_xu(vfloat32m4_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vfwcvt_xu_f_v_m)))
vuint64m8_t vfwcvt_xu(vbool8_t, vuint64m8_t, vfloat32m4_t, size_t);
#endif

#if (__riscv_xlen == 64) && (__riscv_v_elen >= 64) && (__riscv_v_elen_fp >= 32)
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vluxei64_v)))
vfloat32m1_t vluxei64(const float *, vuint64m2_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vluxei64_v_m)))
vfloat32m1_t vluxei64(vbool32_t, vfloat32m1_t, const float *, vuint64m2_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vluxei64_v)))
vfloat32m2_t vluxei64(const float *, vuint64m4_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vluxei64_v_m)))
vfloat32m2_t vluxei64(vbool16_t, vfloat32m2_t, const float *, vuint64m4_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vluxei64_v)))
vfloat32m4_t vluxei64(const float *, vuint64m8_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vluxei64_v_m)))
vfloat32m4_t vluxei64(vbool8_t, vfloat32m4_t, const float *, vuint64m8_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vluxei64_v)))
vfloat32mf2_t vluxei64(const float *, vuint64m1_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vluxei64_v_m)))
vfloat32mf2_t vluxei64(vbool64_t, vfloat32mf2_t, const float *, vuint64m1_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vloxei64_v)))
vfloat32m1_t vloxei64(const float *, vuint64m2_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vloxei64_v_m)))
vfloat32m1_t vloxei64(vbool32_t, vfloat32m1_t, const float *, vuint64m2_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vloxei64_v)))
vfloat32m2_t vloxei64(const float *, vuint64m4_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vloxei64_v_m)))
vfloat32m2_t vloxei64(vbool16_t, vfloat32m2_t, const float *, vuint64m4_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vloxei64_v)))
vfloat32m4_t vloxei64(const float *, vuint64m8_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vloxei64_v_m)))
vfloat32m4_t vloxei64(vbool8_t, vfloat32m4_t, const float *, vuint64m8_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vloxei64_v)))
vfloat32mf2_t vloxei64(const float *, vuint64m1_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vloxei64_v_m)))
vfloat32mf2_t vloxei64(vbool64_t, vfloat32mf2_t, const float *, vuint64m1_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vsuxei64_v)))
void vsuxei64(float *, vuint64m2_t, vfloat32m1_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vsuxei64_v_m)))
void vsuxei64(vbool32_t, float *, vuint64m2_t, vfloat32m1_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vsuxei64_v)))
void vsuxei64(float *, vuint64m4_t, vfloat32m2_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vsuxei64_v_m)))
void vsuxei64(vbool16_t, float *, vuint64m4_t, vfloat32m2_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vsuxei64_v)))
void vsuxei64(float *, vuint64m8_t, vfloat32m4_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vsuxei64_v_m)))
void vsuxei64(vbool8_t, float *, vuint64m8_t, vfloat32m4_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vsuxei64_v)))
void vsuxei64(float *, vuint64m1_t, vfloat32mf2_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vsuxei64_v_m)))
void vsuxei64(vbool64_t, float *, vuint64m1_t, vfloat32mf2_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vsoxei64_v)))
void vsoxei64(float *, vuint64m2_t, vfloat32m1_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vsoxei64_v_m)))
void vsoxei64(vbool32_t, float *, vuint64m2_t, vfloat32m1_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vsoxei64_v)))
void vsoxei64(float *, vuint64m4_t, vfloat32m2_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vsoxei64_v_m)))
void vsoxei64(vbool16_t, float *, vuint64m4_t, vfloat32m2_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vsoxei64_v)))
void vsoxei64(float *, vuint64m8_t, vfloat32m4_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vsoxei64_v_m)))
void vsoxei64(vbool8_t, float *, vuint64m8_t, vfloat32m4_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vsoxei64_v)))
void vsoxei64(float *, vuint64m1_t, vfloat32mf2_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vsoxei64_v_m)))
void vsoxei64(vbool64_t, float *, vuint64m1_t, vfloat32mf2_t, size_t);
#endif

#if (__riscv_v_elen >= 64) && (__riscv_v_elen_fp >= 64)
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vlse64_v_m)))
vfloat64m1_t vlse64(vbool64_t, vfloat64m1_t, const double *, ptrdiff_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vlse64_v_m)))
vfloat64m2_t vlse64(vbool32_t, vfloat64m2_t, const double *, ptrdiff_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vlse64_v_m)))
vfloat64m4_t vlse64(vbool16_t, vfloat64m4_t, const double *, ptrdiff_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vlse64_v_m)))
vfloat64m8_t vlse64(vbool8_t, vfloat64m8_t, const double *, ptrdiff_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vloxseg2ei8_v)))
void vloxseg2ei8(vfloat64m1_t *, vfloat64m1_t *, const double *, vuint8mf8_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vloxseg2ei8_v_m)))
void vloxseg2ei8(vfloat64m1_t *, vfloat64m1_t *, vbool64_t, vfloat64m1_t, vfloat64m1_t, const double *, vuint8mf8_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vloxseg2ei8_v)))
void vloxseg2ei8(vfloat64m2_t *, vfloat64m2_t *, const double *, vuint8mf4_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vloxseg2ei8_v_m)))
void vloxseg2ei8(vfloat64m2_t *, vfloat64m2_t *, vbool32_t, vfloat64m2_t, vfloat64m2_t, const double *, vuint8mf4_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vloxseg2ei8_v)))
void vloxseg2ei8(vfloat64m4_t *, vfloat64m4_t *, const double *, vuint8mf2_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vloxseg2ei8_v_m)))
void vloxseg2ei8(vfloat64m4_t *, vfloat64m4_t *, vbool16_t, vfloat64m4_t, vfloat64m4_t, const double *, vuint8mf2_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vloxseg3ei8_v)))
void vloxseg3ei8(vfloat64m1_t *, vfloat64m1_t *, vfloat64m1_t *, const double *, vuint8mf8_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vloxseg3ei8_v_m)))
void vloxseg3ei8(vfloat64m1_t *, vfloat64m1_t *, vfloat64m1_t *, vbool64_t, vfloat64m1_t, vfloat64m1_t, vfloat64m1_t, const double *, vuint8mf8_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vloxseg3ei8_v)))
void vloxseg3ei8(vfloat64m2_t *, vfloat64m2_t *, vfloat64m2_t *, const double *, vuint8mf4_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vloxseg3ei8_v_m)))
void vloxseg3ei8(vfloat64m2_t *, vfloat64m2_t *, vfloat64m2_t *, vbool32_t, vfloat64m2_t, vfloat64m2_t, vfloat64m2_t, const double *, vuint8mf4_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vloxseg4ei8_v)))
void vloxseg4ei8(vfloat64m1_t *, vfloat64m1_t *, vfloat64m1_t *, vfloat64m1_t *, const double *, vuint8mf8_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vloxseg4ei8_v_m)))
void vloxseg4ei8(vfloat64m1_t *, vfloat64m1_t *, vfloat64m1_t *, vfloat64m1_t *, vbool64_t, vfloat64m1_t, vfloat64m1_t, vfloat64m1_t, vfloat64m1_t, const double *, vuint8mf8_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vloxseg4ei8_v)))
void vloxseg4ei8(vfloat64m2_t *, vfloat64m2_t *, vfloat64m2_t *, vfloat64m2_t *, const double *, vuint8mf4_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vloxseg4ei8_v_m)))
void vloxseg4ei8(vfloat64m2_t *, vfloat64m2_t *, vfloat64m2_t *, vfloat64m2_t *, vbool32_t, vfloat64m2_t, vfloat64m2_t, vfloat64m2_t, vfloat64m2_t, const double *, vuint8mf4_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vloxseg5ei8_v)))
void vloxseg5ei8(vfloat64m1_t *, vfloat64m1_t *, vfloat64m1_t *, vfloat64m1_t *, vfloat64m1_t *, const double *, vuint8mf8_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vloxseg5ei8_v_m)))
void vloxseg5ei8(vfloat64m1_t *, vfloat64m1_t *, vfloat64m1_t *, vfloat64m1_t *, vfloat64m1_t *, vbool64_t, vfloat64m1_t, vfloat64m1_t, vfloat64m1_t, vfloat64m1_t, vfloat64m1_t, const double *, vuint8mf8_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vloxseg6ei8_v)))
void vloxseg6ei8(vfloat64m1_t *, vfloat64m1_t *, vfloat64m1_t *, vfloat64m1_t *, vfloat64m1_t *, vfloat64m1_t *, const double *, vuint8mf8_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vloxseg6ei8_v_m)))
void vloxseg6ei8(vfloat64m1_t *, vfloat64m1_t *, vfloat64m1_t *, vfloat64m1_t *, vfloat64m1_t *, vfloat64m1_t *, vbool64_t, vfloat64m1_t, vfloat64m1_t, vfloat64m1_t, vfloat64m1_t, vfloat64m1_t, vfloat64m1_t, const double *, vuint8mf8_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vloxseg7ei8_v)))
void vloxseg7ei8(vfloat64m1_t *, vfloat64m1_t *, vfloat64m1_t *, vfloat64m1_t *, vfloat64m1_t *, vfloat64m1_t *, vfloat64m1_t *, const double *, vuint8mf8_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vloxseg7ei8_v_m)))
void vloxseg7ei8(vfloat64m1_t *, vfloat64m1_t *, vfloat64m1_t *, vfloat64m1_t *, vfloat64m1_t *, vfloat64m1_t *, vfloat64m1_t *, vbool64_t, vfloat64m1_t, vfloat64m1_t, vfloat64m1_t, vfloat64m1_t, vfloat64m1_t, vfloat64m1_t, vfloat64m1_t, const double *, vuint8mf8_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vloxseg8ei8_v)))
void vloxseg8ei8(vfloat64m1_t *, vfloat64m1_t *, vfloat64m1_t *, vfloat64m1_t *, vfloat64m1_t *, vfloat64m1_t *, vfloat64m1_t *, vfloat64m1_t *, const double *, vuint8mf8_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vloxseg8ei8_v_m)))
void vloxseg8ei8(vfloat64m1_t *, vfloat64m1_t *, vfloat64m1_t *, vfloat64m1_t *, vfloat64m1_t *, vfloat64m1_t *, vfloat64m1_t *, vfloat64m1_t *, vbool64_t, vfloat64m1_t, vfloat64m1_t, vfloat64m1_t, vfloat64m1_t, vfloat64m1_t, vfloat64m1_t, vfloat64m1_t, vfloat64m1_t, const double *, vuint8mf8_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vloxseg2ei16_v)))
void vloxseg2ei16(vfloat64m1_t *, vfloat64m1_t *, const double *, vuint16mf4_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vloxseg2ei16_v_m)))
void vloxseg2ei16(vfloat64m1_t *, vfloat64m1_t *, vbool64_t, vfloat64m1_t, vfloat64m1_t, const double *, vuint16mf4_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vloxseg2ei16_v)))
void vloxseg2ei16(vfloat64m2_t *, vfloat64m2_t *, const double *, vuint16mf2_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vloxseg2ei16_v_m)))
void vloxseg2ei16(vfloat64m2_t *, vfloat64m2_t *, vbool32_t, vfloat64m2_t, vfloat64m2_t, const double *, vuint16mf2_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vloxseg2ei16_v)))
void vloxseg2ei16(vfloat64m4_t *, vfloat64m4_t *, const double *, vuint16m1_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vloxseg2ei16_v_m)))
void vloxseg2ei16(vfloat64m4_t *, vfloat64m4_t *, vbool16_t, vfloat64m4_t, vfloat64m4_t, const double *, vuint16m1_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vloxseg3ei16_v)))
void vloxseg3ei16(vfloat64m1_t *, vfloat64m1_t *, vfloat64m1_t *, const double *, vuint16mf4_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vloxseg3ei16_v_m)))
void vloxseg3ei16(vfloat64m1_t *, vfloat64m1_t *, vfloat64m1_t *, vbool64_t, vfloat64m1_t, vfloat64m1_t, vfloat64m1_t, const double *, vuint16mf4_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vloxseg3ei16_v)))
void vloxseg3ei16(vfloat64m2_t *, vfloat64m2_t *, vfloat64m2_t *, const double *, vuint16mf2_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vloxseg3ei16_v_m)))
void vloxseg3ei16(vfloat64m2_t *, vfloat64m2_t *, vfloat64m2_t *, vbool32_t, vfloat64m2_t, vfloat64m2_t, vfloat64m2_t, const double *, vuint16mf2_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vloxseg4ei16_v)))
void vloxseg4ei16(vfloat64m1_t *, vfloat64m1_t *, vfloat64m1_t *, vfloat64m1_t *, const double *, vuint16mf4_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vloxseg4ei16_v_m)))
void vloxseg4ei16(vfloat64m1_t *, vfloat64m1_t *, vfloat64m1_t *, vfloat64m1_t *, vbool64_t, vfloat64m1_t, vfloat64m1_t, vfloat64m1_t, vfloat64m1_t, const double *, vuint16mf4_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vloxseg4ei16_v)))
void vloxseg4ei16(vfloat64m2_t *, vfloat64m2_t *, vfloat64m2_t *, vfloat64m2_t *, const double *, vuint16mf2_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vloxseg4ei16_v_m)))
void vloxseg4ei16(vfloat64m2_t *, vfloat64m2_t *, vfloat64m2_t *, vfloat64m2_t *, vbool32_t, vfloat64m2_t, vfloat64m2_t, vfloat64m2_t, vfloat64m2_t, const double *, vuint16mf2_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vsse64_v)))
void vsse64(double *, ptrdiff_t, vfloat64m1_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vsse64_v_m)))
void vsse64(vbool64_t, double *, ptrdiff_t, vfloat64m1_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vsse64_v)))
void vsse64(double *, ptrdiff_t, vfloat64m2_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vsse64_v_m)))
void vsse64(vbool32_t, double *, ptrdiff_t, vfloat64m2_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vsse64_v)))
void vsse64(double *, ptrdiff_t, vfloat64m4_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vsse64_v_m)))
void vsse64(vbool16_t, double *, ptrdiff_t, vfloat64m4_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vsse64_v)))
void vsse64(double *, ptrdiff_t, vfloat64m8_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vsse64_v_m)))
void vsse64(vbool8_t, double *, ptrdiff_t, vfloat64m8_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vloxseg5ei16_v)))
void vloxseg5ei16(vfloat64m1_t *, vfloat64m1_t *, vfloat64m1_t *, vfloat64m1_t *, vfloat64m1_t *, const double *, vuint16mf4_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vloxseg5ei16_v_m)))
void vloxseg5ei16(vfloat64m1_t *, vfloat64m1_t *, vfloat64m1_t *, vfloat64m1_t *, vfloat64m1_t *, vbool64_t, vfloat64m1_t, vfloat64m1_t, vfloat64m1_t, vfloat64m1_t, vfloat64m1_t, const double *, vuint16mf4_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vloxseg6ei16_v)))
void vloxseg6ei16(vfloat64m1_t *, vfloat64m1_t *, vfloat64m1_t *, vfloat64m1_t *, vfloat64m1_t *, vfloat64m1_t *, const double *, vuint16mf4_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vloxseg6ei16_v_m)))
void vloxseg6ei16(vfloat64m1_t *, vfloat64m1_t *, vfloat64m1_t *, vfloat64m1_t *, vfloat64m1_t *, vfloat64m1_t *, vbool64_t, vfloat64m1_t, vfloat64m1_t, vfloat64m1_t, vfloat64m1_t, vfloat64m1_t, vfloat64m1_t, const double *, vuint16mf4_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vloxseg7ei16_v)))
void vloxseg7ei16(vfloat64m1_t *, vfloat64m1_t *, vfloat64m1_t *, vfloat64m1_t *, vfloat64m1_t *, vfloat64m1_t *, vfloat64m1_t *, const double *, vuint16mf4_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vloxseg7ei16_v_m)))
void vloxseg7ei16(vfloat64m1_t *, vfloat64m1_t *, vfloat64m1_t *, vfloat64m1_t *, vfloat64m1_t *, vfloat64m1_t *, vfloat64m1_t *, vbool64_t, vfloat64m1_t, vfloat64m1_t, vfloat64m1_t, vfloat64m1_t, vfloat64m1_t, vfloat64m1_t, vfloat64m1_t, const double *, vuint16mf4_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vloxseg8ei16_v)))
void vloxseg8ei16(vfloat64m1_t *, vfloat64m1_t *, vfloat64m1_t *, vfloat64m1_t *, vfloat64m1_t *, vfloat64m1_t *, vfloat64m1_t *, vfloat64m1_t *, const double *, vuint16mf4_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vloxseg8ei16_v_m)))
void vloxseg8ei16(vfloat64m1_t *, vfloat64m1_t *, vfloat64m1_t *, vfloat64m1_t *, vfloat64m1_t *, vfloat64m1_t *, vfloat64m1_t *, vfloat64m1_t *, vbool64_t, vfloat64m1_t, vfloat64m1_t, vfloat64m1_t, vfloat64m1_t, vfloat64m1_t, vfloat64m1_t, vfloat64m1_t, vfloat64m1_t, const double *, vuint16mf4_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vloxseg2ei32_v)))
void vloxseg2ei32(vfloat64m1_t *, vfloat64m1_t *, const double *, vuint32mf2_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vloxseg2ei32_v_m)))
void vloxseg2ei32(vfloat64m1_t *, vfloat64m1_t *, vbool64_t, vfloat64m1_t, vfloat64m1_t, const double *, vuint32mf2_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vloxseg2ei32_v)))
void vloxseg2ei32(vfloat64m2_t *, vfloat64m2_t *, const double *, vuint32m1_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vloxseg2ei32_v_m)))
void vloxseg2ei32(vfloat64m2_t *, vfloat64m2_t *, vbool32_t, vfloat64m2_t, vfloat64m2_t, const double *, vuint32m1_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vloxseg2ei32_v)))
void vloxseg2ei32(vfloat64m4_t *, vfloat64m4_t *, const double *, vuint32m2_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vloxseg2ei32_v_m)))
void vloxseg2ei32(vfloat64m4_t *, vfloat64m4_t *, vbool16_t, vfloat64m4_t, vfloat64m4_t, const double *, vuint32m2_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vloxseg3ei32_v)))
void vloxseg3ei32(vfloat64m1_t *, vfloat64m1_t *, vfloat64m1_t *, const double *, vuint32mf2_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vloxseg3ei32_v_m)))
void vloxseg3ei32(vfloat64m1_t *, vfloat64m1_t *, vfloat64m1_t *, vbool64_t, vfloat64m1_t, vfloat64m1_t, vfloat64m1_t, const double *, vuint32mf2_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vloxseg3ei32_v)))
void vloxseg3ei32(vfloat64m2_t *, vfloat64m2_t *, vfloat64m2_t *, const double *, vuint32m1_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vloxseg3ei32_v_m)))
void vloxseg3ei32(vfloat64m2_t *, vfloat64m2_t *, vfloat64m2_t *, vbool32_t, vfloat64m2_t, vfloat64m2_t, vfloat64m2_t, const double *, vuint32m1_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vloxseg4ei32_v)))
void vloxseg4ei32(vfloat64m1_t *, vfloat64m1_t *, vfloat64m1_t *, vfloat64m1_t *, const double *, vuint32mf2_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vloxseg4ei32_v_m)))
void vloxseg4ei32(vfloat64m1_t *, vfloat64m1_t *, vfloat64m1_t *, vfloat64m1_t *, vbool64_t, vfloat64m1_t, vfloat64m1_t, vfloat64m1_t, vfloat64m1_t, const double *, vuint32mf2_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vloxseg4ei32_v)))
void vloxseg4ei32(vfloat64m2_t *, vfloat64m2_t *, vfloat64m2_t *, vfloat64m2_t *, const double *, vuint32m1_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vloxseg4ei32_v_m)))
void vloxseg4ei32(vfloat64m2_t *, vfloat64m2_t *, vfloat64m2_t *, vfloat64m2_t *, vbool32_t, vfloat64m2_t, vfloat64m2_t, vfloat64m2_t, vfloat64m2_t, const double *, vuint32m1_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vloxseg5ei32_v)))
void vloxseg5ei32(vfloat64m1_t *, vfloat64m1_t *, vfloat64m1_t *, vfloat64m1_t *, vfloat64m1_t *, const double *, vuint32mf2_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vloxseg5ei32_v_m)))
void vloxseg5ei32(vfloat64m1_t *, vfloat64m1_t *, vfloat64m1_t *, vfloat64m1_t *, vfloat64m1_t *, vbool64_t, vfloat64m1_t, vfloat64m1_t, vfloat64m1_t, vfloat64m1_t, vfloat64m1_t, const double *, vuint32mf2_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vloxseg6ei32_v)))
void vloxseg6ei32(vfloat64m1_t *, vfloat64m1_t *, vfloat64m1_t *, vfloat64m1_t *, vfloat64m1_t *, vfloat64m1_t *, const double *, vuint32mf2_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vloxseg6ei32_v_m)))
void vloxseg6ei32(vfloat64m1_t *, vfloat64m1_t *, vfloat64m1_t *, vfloat64m1_t *, vfloat64m1_t *, vfloat64m1_t *, vbool64_t, vfloat64m1_t, vfloat64m1_t, vfloat64m1_t, vfloat64m1_t, vfloat64m1_t, vfloat64m1_t, const double *, vuint32mf2_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vloxseg7ei32_v)))
void vloxseg7ei32(vfloat64m1_t *, vfloat64m1_t *, vfloat64m1_t *, vfloat64m1_t *, vfloat64m1_t *, vfloat64m1_t *, vfloat64m1_t *, const double *, vuint32mf2_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vloxseg7ei32_v_m)))
void vloxseg7ei32(vfloat64m1_t *, vfloat64m1_t *, vfloat64m1_t *, vfloat64m1_t *, vfloat64m1_t *, vfloat64m1_t *, vfloat64m1_t *, vbool64_t, vfloat64m1_t, vfloat64m1_t, vfloat64m1_t, vfloat64m1_t, vfloat64m1_t, vfloat64m1_t, vfloat64m1_t, const double *, vuint32mf2_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vloxseg8ei32_v)))
void vloxseg8ei32(vfloat64m1_t *, vfloat64m1_t *, vfloat64m1_t *, vfloat64m1_t *, vfloat64m1_t *, vfloat64m1_t *, vfloat64m1_t *, vfloat64m1_t *, const double *, vuint32mf2_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vloxseg8ei32_v_m)))
void vloxseg8ei32(vfloat64m1_t *, vfloat64m1_t *, vfloat64m1_t *, vfloat64m1_t *, vfloat64m1_t *, vfloat64m1_t *, vfloat64m1_t *, vfloat64m1_t *, vbool64_t, vfloat64m1_t, vfloat64m1_t, vfloat64m1_t, vfloat64m1_t, vfloat64m1_t, vfloat64m1_t, vfloat64m1_t, vfloat64m1_t, const double *, vuint32mf2_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vloxseg2ei64_v)))
void vloxseg2ei64(vfloat64m1_t *, vfloat64m1_t *, const double *, vuint64m1_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vloxseg2ei64_v_m)))
void vloxseg2ei64(vfloat64m1_t *, vfloat64m1_t *, vbool64_t, vfloat64m1_t, vfloat64m1_t, const double *, vuint64m1_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vloxseg2ei64_v)))
void vloxseg2ei64(vfloat64m2_t *, vfloat64m2_t *, const double *, vuint64m2_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vloxseg2ei64_v_m)))
void vloxseg2ei64(vfloat64m2_t *, vfloat64m2_t *, vbool32_t, vfloat64m2_t, vfloat64m2_t, const double *, vuint64m2_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vloxseg2ei64_v)))
void vloxseg2ei64(vfloat64m4_t *, vfloat64m4_t *, const double *, vuint64m4_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vloxseg2ei64_v_m)))
void vloxseg2ei64(vfloat64m4_t *, vfloat64m4_t *, vbool16_t, vfloat64m4_t, vfloat64m4_t, const double *, vuint64m4_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vloxseg3ei64_v)))
void vloxseg3ei64(vfloat64m1_t *, vfloat64m1_t *, vfloat64m1_t *, const double *, vuint64m1_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vloxseg3ei64_v_m)))
void vloxseg3ei64(vfloat64m1_t *, vfloat64m1_t *, vfloat64m1_t *, vbool64_t, vfloat64m1_t, vfloat64m1_t, vfloat64m1_t, const double *, vuint64m1_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vloxseg3ei64_v)))
void vloxseg3ei64(vfloat64m2_t *, vfloat64m2_t *, vfloat64m2_t *, const double *, vuint64m2_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vloxseg3ei64_v_m)))
void vloxseg3ei64(vfloat64m2_t *, vfloat64m2_t *, vfloat64m2_t *, vbool32_t, vfloat64m2_t, vfloat64m2_t, vfloat64m2_t, const double *, vuint64m2_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vloxseg4ei64_v)))
void vloxseg4ei64(vfloat64m1_t *, vfloat64m1_t *, vfloat64m1_t *, vfloat64m1_t *, const double *, vuint64m1_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vloxseg4ei64_v_m)))
void vloxseg4ei64(vfloat64m1_t *, vfloat64m1_t *, vfloat64m1_t *, vfloat64m1_t *, vbool64_t, vfloat64m1_t, vfloat64m1_t, vfloat64m1_t, vfloat64m1_t, const double *, vuint64m1_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vloxseg4ei64_v)))
void vloxseg4ei64(vfloat64m2_t *, vfloat64m2_t *, vfloat64m2_t *, vfloat64m2_t *, const double *, vuint64m2_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vloxseg4ei64_v_m)))
void vloxseg4ei64(vfloat64m2_t *, vfloat64m2_t *, vfloat64m2_t *, vfloat64m2_t *, vbool32_t, vfloat64m2_t, vfloat64m2_t, vfloat64m2_t, vfloat64m2_t, const double *, vuint64m2_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vloxseg5ei64_v)))
void vloxseg5ei64(vfloat64m1_t *, vfloat64m1_t *, vfloat64m1_t *, vfloat64m1_t *, vfloat64m1_t *, const double *, vuint64m1_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vloxseg5ei64_v_m)))
void vloxseg5ei64(vfloat64m1_t *, vfloat64m1_t *, vfloat64m1_t *, vfloat64m1_t *, vfloat64m1_t *, vbool64_t, vfloat64m1_t, vfloat64m1_t, vfloat64m1_t, vfloat64m1_t, vfloat64m1_t, const double *, vuint64m1_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vloxseg6ei64_v)))
void vloxseg6ei64(vfloat64m1_t *, vfloat64m1_t *, vfloat64m1_t *, vfloat64m1_t *, vfloat64m1_t *, vfloat64m1_t *, const double *, vuint64m1_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vloxseg6ei64_v_m)))
void vloxseg6ei64(vfloat64m1_t *, vfloat64m1_t *, vfloat64m1_t *, vfloat64m1_t *, vfloat64m1_t *, vfloat64m1_t *, vbool64_t, vfloat64m1_t, vfloat64m1_t, vfloat64m1_t, vfloat64m1_t, vfloat64m1_t, vfloat64m1_t, const double *, vuint64m1_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vloxseg7ei64_v)))
void vloxseg7ei64(vfloat64m1_t *, vfloat64m1_t *, vfloat64m1_t *, vfloat64m1_t *, vfloat64m1_t *, vfloat64m1_t *, vfloat64m1_t *, const double *, vuint64m1_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vloxseg7ei64_v_m)))
void vloxseg7ei64(vfloat64m1_t *, vfloat64m1_t *, vfloat64m1_t *, vfloat64m1_t *, vfloat64m1_t *, vfloat64m1_t *, vfloat64m1_t *, vbool64_t, vfloat64m1_t, vfloat64m1_t, vfloat64m1_t, vfloat64m1_t, vfloat64m1_t, vfloat64m1_t, vfloat64m1_t, const double *, vuint64m1_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vloxseg8ei64_v)))
void vloxseg8ei64(vfloat64m1_t *, vfloat64m1_t *, vfloat64m1_t *, vfloat64m1_t *, vfloat64m1_t *, vfloat64m1_t *, vfloat64m1_t *, vfloat64m1_t *, const double *, vuint64m1_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vloxseg8ei64_v_m)))
void vloxseg8ei64(vfloat64m1_t *, vfloat64m1_t *, vfloat64m1_t *, vfloat64m1_t *, vfloat64m1_t *, vfloat64m1_t *, vfloat64m1_t *, vfloat64m1_t *, vbool64_t, vfloat64m1_t, vfloat64m1_t, vfloat64m1_t, vfloat64m1_t, vfloat64m1_t, vfloat64m1_t, vfloat64m1_t, vfloat64m1_t, const double *, vuint64m1_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vsseg2e64_v)))
void vsseg2e64(double *, vfloat64m1_t, vfloat64m1_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vsseg2e64_v_m)))
void vsseg2e64(vbool64_t, double *, vfloat64m1_t, vfloat64m1_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vsseg2e64_v)))
void vsseg2e64(double *, vfloat64m2_t, vfloat64m2_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vsseg2e64_v_m)))
void vsseg2e64(vbool32_t, double *, vfloat64m2_t, vfloat64m2_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vsseg2e64_v)))
void vsseg2e64(double *, vfloat64m4_t, vfloat64m4_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vsseg2e64_v_m)))
void vsseg2e64(vbool16_t, double *, vfloat64m4_t, vfloat64m4_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vsseg3e64_v)))
void vsseg3e64(double *, vfloat64m1_t, vfloat64m1_t, vfloat64m1_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vsseg3e64_v_m)))
void vsseg3e64(vbool64_t, double *, vfloat64m1_t, vfloat64m1_t, vfloat64m1_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vsseg3e64_v)))
void vsseg3e64(double *, vfloat64m2_t, vfloat64m2_t, vfloat64m2_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vsseg3e64_v_m)))
void vsseg3e64(vbool32_t, double *, vfloat64m2_t, vfloat64m2_t, vfloat64m2_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vsseg4e64_v)))
void vsseg4e64(double *, vfloat64m1_t, vfloat64m1_t, vfloat64m1_t, vfloat64m1_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vsseg4e64_v_m)))
void vsseg4e64(vbool64_t, double *, vfloat64m1_t, vfloat64m1_t, vfloat64m1_t, vfloat64m1_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vsseg4e64_v)))
void vsseg4e64(double *, vfloat64m2_t, vfloat64m2_t, vfloat64m2_t, vfloat64m2_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vsseg4e64_v_m)))
void vsseg4e64(vbool32_t, double *, vfloat64m2_t, vfloat64m2_t, vfloat64m2_t, vfloat64m2_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vsseg5e64_v)))
void vsseg5e64(double *, vfloat64m1_t, vfloat64m1_t, vfloat64m1_t, vfloat64m1_t, vfloat64m1_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vsseg5e64_v_m)))
void vsseg5e64(vbool64_t, double *, vfloat64m1_t, vfloat64m1_t, vfloat64m1_t, vfloat64m1_t, vfloat64m1_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vsseg6e64_v)))
void vsseg6e64(double *, vfloat64m1_t, vfloat64m1_t, vfloat64m1_t, vfloat64m1_t, vfloat64m1_t, vfloat64m1_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vsseg6e64_v_m)))
void vsseg6e64(vbool64_t, double *, vfloat64m1_t, vfloat64m1_t, vfloat64m1_t, vfloat64m1_t, vfloat64m1_t, vfloat64m1_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vsseg7e64_v)))
void vsseg7e64(double *, vfloat64m1_t, vfloat64m1_t, vfloat64m1_t, vfloat64m1_t, vfloat64m1_t, vfloat64m1_t, vfloat64m1_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vsseg7e64_v_m)))
void vsseg7e64(vbool64_t, double *, vfloat64m1_t, vfloat64m1_t, vfloat64m1_t, vfloat64m1_t, vfloat64m1_t, vfloat64m1_t, vfloat64m1_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vsseg8e64_v)))
void vsseg8e64(double *, vfloat64m1_t, vfloat64m1_t, vfloat64m1_t, vfloat64m1_t, vfloat64m1_t, vfloat64m1_t, vfloat64m1_t, vfloat64m1_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vsseg8e64_v_m)))
void vsseg8e64(vbool64_t, double *, vfloat64m1_t, vfloat64m1_t, vfloat64m1_t, vfloat64m1_t, vfloat64m1_t, vfloat64m1_t, vfloat64m1_t, vfloat64m1_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vssseg2e64_v)))
void vssseg2e64(double *, ptrdiff_t, vfloat64m1_t, vfloat64m1_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vssseg2e64_v_m)))
void vssseg2e64(vbool64_t, double *, ptrdiff_t, vfloat64m1_t, vfloat64m1_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vssseg2e64_v)))
void vssseg2e64(double *, ptrdiff_t, vfloat64m2_t, vfloat64m2_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vssseg2e64_v_m)))
void vssseg2e64(vbool32_t, double *, ptrdiff_t, vfloat64m2_t, vfloat64m2_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vssseg2e64_v)))
void vssseg2e64(double *, ptrdiff_t, vfloat64m4_t, vfloat64m4_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vssseg2e64_v_m)))
void vssseg2e64(vbool16_t, double *, ptrdiff_t, vfloat64m4_t, vfloat64m4_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vssseg3e64_v)))
void vssseg3e64(double *, ptrdiff_t, vfloat64m1_t, vfloat64m1_t, vfloat64m1_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vssseg3e64_v_m)))
void vssseg3e64(vbool64_t, double *, ptrdiff_t, vfloat64m1_t, vfloat64m1_t, vfloat64m1_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vssseg3e64_v)))
void vssseg3e64(double *, ptrdiff_t, vfloat64m2_t, vfloat64m2_t, vfloat64m2_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vssseg3e64_v_m)))
void vssseg3e64(vbool32_t, double *, ptrdiff_t, vfloat64m2_t, vfloat64m2_t, vfloat64m2_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vssseg4e64_v)))
void vssseg4e64(double *, ptrdiff_t, vfloat64m1_t, vfloat64m1_t, vfloat64m1_t, vfloat64m1_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vssseg4e64_v_m)))
void vssseg4e64(vbool64_t, double *, ptrdiff_t, vfloat64m1_t, vfloat64m1_t, vfloat64m1_t, vfloat64m1_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vssseg4e64_v)))
void vssseg4e64(double *, ptrdiff_t, vfloat64m2_t, vfloat64m2_t, vfloat64m2_t, vfloat64m2_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vssseg4e64_v_m)))
void vssseg4e64(vbool32_t, double *, ptrdiff_t, vfloat64m2_t, vfloat64m2_t, vfloat64m2_t, vfloat64m2_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vssseg5e64_v)))
void vssseg5e64(double *, ptrdiff_t, vfloat64m1_t, vfloat64m1_t, vfloat64m1_t, vfloat64m1_t, vfloat64m1_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vssseg5e64_v_m)))
void vssseg5e64(vbool64_t, double *, ptrdiff_t, vfloat64m1_t, vfloat64m1_t, vfloat64m1_t, vfloat64m1_t, vfloat64m1_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vssseg6e64_v)))
void vssseg6e64(double *, ptrdiff_t, vfloat64m1_t, vfloat64m1_t, vfloat64m1_t, vfloat64m1_t, vfloat64m1_t, vfloat64m1_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vssseg6e64_v_m)))
void vssseg6e64(vbool64_t, double *, ptrdiff_t, vfloat64m1_t, vfloat64m1_t, vfloat64m1_t, vfloat64m1_t, vfloat64m1_t, vfloat64m1_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vssseg7e64_v)))
void vssseg7e64(double *, ptrdiff_t, vfloat64m1_t, vfloat64m1_t, vfloat64m1_t, vfloat64m1_t, vfloat64m1_t, vfloat64m1_t, vfloat64m1_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vssseg7e64_v_m)))
void vssseg7e64(vbool64_t, double *, ptrdiff_t, vfloat64m1_t, vfloat64m1_t, vfloat64m1_t, vfloat64m1_t, vfloat64m1_t, vfloat64m1_t, vfloat64m1_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vssseg8e64_v)))
void vssseg8e64(double *, ptrdiff_t, vfloat64m1_t, vfloat64m1_t, vfloat64m1_t, vfloat64m1_t, vfloat64m1_t, vfloat64m1_t, vfloat64m1_t, vfloat64m1_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vssseg8e64_v_m)))
void vssseg8e64(vbool64_t, double *, ptrdiff_t, vfloat64m1_t, vfloat64m1_t, vfloat64m1_t, vfloat64m1_t, vfloat64m1_t, vfloat64m1_t, vfloat64m1_t, vfloat64m1_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vluxei8_v)))
vfloat64m1_t vluxei8(const double *, vuint8mf8_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vluxei8_v_m)))
vfloat64m1_t vluxei8(vbool64_t, vfloat64m1_t, const double *, vuint8mf8_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vluxei8_v)))
vfloat64m2_t vluxei8(const double *, vuint8mf4_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vluxei8_v_m)))
vfloat64m2_t vluxei8(vbool32_t, vfloat64m2_t, const double *, vuint8mf4_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vluxei8_v)))
vfloat64m4_t vluxei8(const double *, vuint8mf2_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vluxei8_v_m)))
vfloat64m4_t vluxei8(vbool16_t, vfloat64m4_t, const double *, vuint8mf2_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vluxei8_v)))
vfloat64m8_t vluxei8(const double *, vuint8m1_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vluxei8_v_m)))
vfloat64m8_t vluxei8(vbool8_t, vfloat64m8_t, const double *, vuint8m1_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vluxei16_v)))
vfloat64m1_t vluxei16(const double *, vuint16mf4_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vluxei16_v_m)))
vfloat64m1_t vluxei16(vbool64_t, vfloat64m1_t, const double *, vuint16mf4_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vluxei16_v)))
vfloat64m2_t vluxei16(const double *, vuint16mf2_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vluxei16_v_m)))
vfloat64m2_t vluxei16(vbool32_t, vfloat64m2_t, const double *, vuint16mf2_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vluxei16_v)))
vfloat64m4_t vluxei16(const double *, vuint16m1_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vluxei16_v_m)))
vfloat64m4_t vluxei16(vbool16_t, vfloat64m4_t, const double *, vuint16m1_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vluxei16_v)))
vfloat64m8_t vluxei16(const double *, vuint16m2_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vluxei16_v_m)))
vfloat64m8_t vluxei16(vbool8_t, vfloat64m8_t, const double *, vuint16m2_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vluxei32_v)))
vfloat64m1_t vluxei32(const double *, vuint32mf2_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vluxei32_v_m)))
vfloat64m1_t vluxei32(vbool64_t, vfloat64m1_t, const double *, vuint32mf2_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vluxei32_v)))
vfloat64m2_t vluxei32(const double *, vuint32m1_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vluxei32_v_m)))
vfloat64m2_t vluxei32(vbool32_t, vfloat64m2_t, const double *, vuint32m1_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vluxei32_v)))
vfloat64m4_t vluxei32(const double *, vuint32m2_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vluxei32_v_m)))
vfloat64m4_t vluxei32(vbool16_t, vfloat64m4_t, const double *, vuint32m2_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vluxei32_v)))
vfloat64m8_t vluxei32(const double *, vuint32m4_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vluxei32_v_m)))
vfloat64m8_t vluxei32(vbool8_t, vfloat64m8_t, const double *, vuint32m4_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vsuxseg2ei8_v)))
void vsuxseg2ei8(double *, vuint8mf8_t, vfloat64m1_t, vfloat64m1_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vsuxseg2ei8_v_m)))
void vsuxseg2ei8(vbool64_t, double *, vuint8mf8_t, vfloat64m1_t, vfloat64m1_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vsuxseg2ei8_v)))
void vsuxseg2ei8(double *, vuint8mf4_t, vfloat64m2_t, vfloat64m2_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vsuxseg2ei8_v_m)))
void vsuxseg2ei8(vbool32_t, double *, vuint8mf4_t, vfloat64m2_t, vfloat64m2_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vsuxseg2ei8_v)))
void vsuxseg2ei8(double *, vuint8mf2_t, vfloat64m4_t, vfloat64m4_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vsuxseg2ei8_v_m)))
void vsuxseg2ei8(vbool16_t, double *, vuint8mf2_t, vfloat64m4_t, vfloat64m4_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vsuxseg3ei8_v)))
void vsuxseg3ei8(double *, vuint8mf8_t, vfloat64m1_t, vfloat64m1_t, vfloat64m1_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vsuxseg3ei8_v_m)))
void vsuxseg3ei8(vbool64_t, double *, vuint8mf8_t, vfloat64m1_t, vfloat64m1_t, vfloat64m1_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vsuxseg3ei8_v)))
void vsuxseg3ei8(double *, vuint8mf4_t, vfloat64m2_t, vfloat64m2_t, vfloat64m2_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vsuxseg3ei8_v_m)))
void vsuxseg3ei8(vbool32_t, double *, vuint8mf4_t, vfloat64m2_t, vfloat64m2_t, vfloat64m2_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vsuxseg4ei8_v)))
void vsuxseg4ei8(double *, vuint8mf8_t, vfloat64m1_t, vfloat64m1_t, vfloat64m1_t, vfloat64m1_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vsuxseg4ei8_v_m)))
void vsuxseg4ei8(vbool64_t, double *, vuint8mf8_t, vfloat64m1_t, vfloat64m1_t, vfloat64m1_t, vfloat64m1_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vsuxseg4ei8_v)))
void vsuxseg4ei8(double *, vuint8mf4_t, vfloat64m2_t, vfloat64m2_t, vfloat64m2_t, vfloat64m2_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vsuxseg4ei8_v_m)))
void vsuxseg4ei8(vbool32_t, double *, vuint8mf4_t, vfloat64m2_t, vfloat64m2_t, vfloat64m2_t, vfloat64m2_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vsuxseg5ei8_v)))
void vsuxseg5ei8(double *, vuint8mf8_t, vfloat64m1_t, vfloat64m1_t, vfloat64m1_t, vfloat64m1_t, vfloat64m1_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vsuxseg5ei8_v_m)))
void vsuxseg5ei8(vbool64_t, double *, vuint8mf8_t, vfloat64m1_t, vfloat64m1_t, vfloat64m1_t, vfloat64m1_t, vfloat64m1_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vsuxseg6ei8_v)))
void vsuxseg6ei8(double *, vuint8mf8_t, vfloat64m1_t, vfloat64m1_t, vfloat64m1_t, vfloat64m1_t, vfloat64m1_t, vfloat64m1_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vsuxseg6ei8_v_m)))
void vsuxseg6ei8(vbool64_t, double *, vuint8mf8_t, vfloat64m1_t, vfloat64m1_t, vfloat64m1_t, vfloat64m1_t, vfloat64m1_t, vfloat64m1_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vsuxseg7ei8_v)))
void vsuxseg7ei8(double *, vuint8mf8_t, vfloat64m1_t, vfloat64m1_t, vfloat64m1_t, vfloat64m1_t, vfloat64m1_t, vfloat64m1_t, vfloat64m1_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vsuxseg7ei8_v_m)))
void vsuxseg7ei8(vbool64_t, double *, vuint8mf8_t, vfloat64m1_t, vfloat64m1_t, vfloat64m1_t, vfloat64m1_t, vfloat64m1_t, vfloat64m1_t, vfloat64m1_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vsuxseg8ei8_v)))
void vsuxseg8ei8(double *, vuint8mf8_t, vfloat64m1_t, vfloat64m1_t, vfloat64m1_t, vfloat64m1_t, vfloat64m1_t, vfloat64m1_t, vfloat64m1_t, vfloat64m1_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vsuxseg8ei8_v_m)))
void vsuxseg8ei8(vbool64_t, double *, vuint8mf8_t, vfloat64m1_t, vfloat64m1_t, vfloat64m1_t, vfloat64m1_t, vfloat64m1_t, vfloat64m1_t, vfloat64m1_t, vfloat64m1_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vsuxseg2ei16_v)))
void vsuxseg2ei16(double *, vuint16mf4_t, vfloat64m1_t, vfloat64m1_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vsuxseg2ei16_v_m)))
void vsuxseg2ei16(vbool64_t, double *, vuint16mf4_t, vfloat64m1_t, vfloat64m1_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vsuxseg2ei16_v)))
void vsuxseg2ei16(double *, vuint16mf2_t, vfloat64m2_t, vfloat64m2_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vsuxseg2ei16_v_m)))
void vsuxseg2ei16(vbool32_t, double *, vuint16mf2_t, vfloat64m2_t, vfloat64m2_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vsuxseg2ei16_v)))
void vsuxseg2ei16(double *, vuint16m1_t, vfloat64m4_t, vfloat64m4_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vsuxseg2ei16_v_m)))
void vsuxseg2ei16(vbool16_t, double *, vuint16m1_t, vfloat64m4_t, vfloat64m4_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vsuxseg3ei16_v)))
void vsuxseg3ei16(double *, vuint16mf4_t, vfloat64m1_t, vfloat64m1_t, vfloat64m1_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vsuxseg3ei16_v_m)))
void vsuxseg3ei16(vbool64_t, double *, vuint16mf4_t, vfloat64m1_t, vfloat64m1_t, vfloat64m1_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vsuxseg3ei16_v)))
void vsuxseg3ei16(double *, vuint16mf2_t, vfloat64m2_t, vfloat64m2_t, vfloat64m2_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vsuxseg3ei16_v_m)))
void vsuxseg3ei16(vbool32_t, double *, vuint16mf2_t, vfloat64m2_t, vfloat64m2_t, vfloat64m2_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vsuxseg4ei16_v)))
void vsuxseg4ei16(double *, vuint16mf4_t, vfloat64m1_t, vfloat64m1_t, vfloat64m1_t, vfloat64m1_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vsuxseg4ei16_v_m)))
void vsuxseg4ei16(vbool64_t, double *, vuint16mf4_t, vfloat64m1_t, vfloat64m1_t, vfloat64m1_t, vfloat64m1_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vsuxseg4ei16_v)))
void vsuxseg4ei16(double *, vuint16mf2_t, vfloat64m2_t, vfloat64m2_t, vfloat64m2_t, vfloat64m2_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vsuxseg4ei16_v_m)))
void vsuxseg4ei16(vbool32_t, double *, vuint16mf2_t, vfloat64m2_t, vfloat64m2_t, vfloat64m2_t, vfloat64m2_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vsuxseg5ei16_v)))
void vsuxseg5ei16(double *, vuint16mf4_t, vfloat64m1_t, vfloat64m1_t, vfloat64m1_t, vfloat64m1_t, vfloat64m1_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vsuxseg5ei16_v_m)))
void vsuxseg5ei16(vbool64_t, double *, vuint16mf4_t, vfloat64m1_t, vfloat64m1_t, vfloat64m1_t, vfloat64m1_t, vfloat64m1_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vsuxseg6ei16_v)))
void vsuxseg6ei16(double *, vuint16mf4_t, vfloat64m1_t, vfloat64m1_t, vfloat64m1_t, vfloat64m1_t, vfloat64m1_t, vfloat64m1_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vsuxseg6ei16_v_m)))
void vsuxseg6ei16(vbool64_t, double *, vuint16mf4_t, vfloat64m1_t, vfloat64m1_t, vfloat64m1_t, vfloat64m1_t, vfloat64m1_t, vfloat64m1_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vsuxseg7ei16_v)))
void vsuxseg7ei16(double *, vuint16mf4_t, vfloat64m1_t, vfloat64m1_t, vfloat64m1_t, vfloat64m1_t, vfloat64m1_t, vfloat64m1_t, vfloat64m1_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vsuxseg7ei16_v_m)))
void vsuxseg7ei16(vbool64_t, double *, vuint16mf4_t, vfloat64m1_t, vfloat64m1_t, vfloat64m1_t, vfloat64m1_t, vfloat64m1_t, vfloat64m1_t, vfloat64m1_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vsuxseg8ei16_v)))
void vsuxseg8ei16(double *, vuint16mf4_t, vfloat64m1_t, vfloat64m1_t, vfloat64m1_t, vfloat64m1_t, vfloat64m1_t, vfloat64m1_t, vfloat64m1_t, vfloat64m1_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vsuxseg8ei16_v_m)))
void vsuxseg8ei16(vbool64_t, double *, vuint16mf4_t, vfloat64m1_t, vfloat64m1_t, vfloat64m1_t, vfloat64m1_t, vfloat64m1_t, vfloat64m1_t, vfloat64m1_t, vfloat64m1_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vsuxseg2ei32_v)))
void vsuxseg2ei32(double *, vuint32mf2_t, vfloat64m1_t, vfloat64m1_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vsuxseg2ei32_v_m)))
void vsuxseg2ei32(vbool64_t, double *, vuint32mf2_t, vfloat64m1_t, vfloat64m1_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vsuxseg2ei32_v)))
void vsuxseg2ei32(double *, vuint32m1_t, vfloat64m2_t, vfloat64m2_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vsuxseg2ei32_v_m)))
void vsuxseg2ei32(vbool32_t, double *, vuint32m1_t, vfloat64m2_t, vfloat64m2_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vsuxseg2ei32_v)))
void vsuxseg2ei32(double *, vuint32m2_t, vfloat64m4_t, vfloat64m4_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vsuxseg2ei32_v_m)))
void vsuxseg2ei32(vbool16_t, double *, vuint32m2_t, vfloat64m4_t, vfloat64m4_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vsuxseg3ei32_v)))
void vsuxseg3ei32(double *, vuint32mf2_t, vfloat64m1_t, vfloat64m1_t, vfloat64m1_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vsuxseg3ei32_v_m)))
void vsuxseg3ei32(vbool64_t, double *, vuint32mf2_t, vfloat64m1_t, vfloat64m1_t, vfloat64m1_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vsuxseg3ei32_v)))
void vsuxseg3ei32(double *, vuint32m1_t, vfloat64m2_t, vfloat64m2_t, vfloat64m2_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vsuxseg3ei32_v_m)))
void vsuxseg3ei32(vbool32_t, double *, vuint32m1_t, vfloat64m2_t, vfloat64m2_t, vfloat64m2_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vsuxseg4ei32_v)))
void vsuxseg4ei32(double *, vuint32mf2_t, vfloat64m1_t, vfloat64m1_t, vfloat64m1_t, vfloat64m1_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vsuxseg4ei32_v_m)))
void vsuxseg4ei32(vbool64_t, double *, vuint32mf2_t, vfloat64m1_t, vfloat64m1_t, vfloat64m1_t, vfloat64m1_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vsuxseg4ei32_v)))
void vsuxseg4ei32(double *, vuint32m1_t, vfloat64m2_t, vfloat64m2_t, vfloat64m2_t, vfloat64m2_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vsuxseg4ei32_v_m)))
void vsuxseg4ei32(vbool32_t, double *, vuint32m1_t, vfloat64m2_t, vfloat64m2_t, vfloat64m2_t, vfloat64m2_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vsuxseg5ei32_v)))
void vsuxseg5ei32(double *, vuint32mf2_t, vfloat64m1_t, vfloat64m1_t, vfloat64m1_t, vfloat64m1_t, vfloat64m1_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vsuxseg5ei32_v_m)))
void vsuxseg5ei32(vbool64_t, double *, vuint32mf2_t, vfloat64m1_t, vfloat64m1_t, vfloat64m1_t, vfloat64m1_t, vfloat64m1_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vsuxseg6ei32_v)))
void vsuxseg6ei32(double *, vuint32mf2_t, vfloat64m1_t, vfloat64m1_t, vfloat64m1_t, vfloat64m1_t, vfloat64m1_t, vfloat64m1_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vsuxseg6ei32_v_m)))
void vsuxseg6ei32(vbool64_t, double *, vuint32mf2_t, vfloat64m1_t, vfloat64m1_t, vfloat64m1_t, vfloat64m1_t, vfloat64m1_t, vfloat64m1_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vsuxseg7ei32_v)))
void vsuxseg7ei32(double *, vuint32mf2_t, vfloat64m1_t, vfloat64m1_t, vfloat64m1_t, vfloat64m1_t, vfloat64m1_t, vfloat64m1_t, vfloat64m1_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vsuxseg7ei32_v_m)))
void vsuxseg7ei32(vbool64_t, double *, vuint32mf2_t, vfloat64m1_t, vfloat64m1_t, vfloat64m1_t, vfloat64m1_t, vfloat64m1_t, vfloat64m1_t, vfloat64m1_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vsuxseg8ei32_v)))
void vsuxseg8ei32(double *, vuint32mf2_t, vfloat64m1_t, vfloat64m1_t, vfloat64m1_t, vfloat64m1_t, vfloat64m1_t, vfloat64m1_t, vfloat64m1_t, vfloat64m1_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vsuxseg8ei32_v_m)))
void vsuxseg8ei32(vbool64_t, double *, vuint32mf2_t, vfloat64m1_t, vfloat64m1_t, vfloat64m1_t, vfloat64m1_t, vfloat64m1_t, vfloat64m1_t, vfloat64m1_t, vfloat64m1_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vsuxseg2ei64_v)))
void vsuxseg2ei64(double *, vuint64m1_t, vfloat64m1_t, vfloat64m1_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vsuxseg2ei64_v_m)))
void vsuxseg2ei64(vbool64_t, double *, vuint64m1_t, vfloat64m1_t, vfloat64m1_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vsuxseg2ei64_v)))
void vsuxseg2ei64(double *, vuint64m2_t, vfloat64m2_t, vfloat64m2_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vsuxseg2ei64_v_m)))
void vsuxseg2ei64(vbool32_t, double *, vuint64m2_t, vfloat64m2_t, vfloat64m2_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vsuxseg2ei64_v)))
void vsuxseg2ei64(double *, vuint64m4_t, vfloat64m4_t, vfloat64m4_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vsuxseg2ei64_v_m)))
void vsuxseg2ei64(vbool16_t, double *, vuint64m4_t, vfloat64m4_t, vfloat64m4_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vsuxseg3ei64_v)))
void vsuxseg3ei64(double *, vuint64m1_t, vfloat64m1_t, vfloat64m1_t, vfloat64m1_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vsuxseg3ei64_v_m)))
void vsuxseg3ei64(vbool64_t, double *, vuint64m1_t, vfloat64m1_t, vfloat64m1_t, vfloat64m1_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vsuxseg3ei64_v)))
void vsuxseg3ei64(double *, vuint64m2_t, vfloat64m2_t, vfloat64m2_t, vfloat64m2_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vsuxseg3ei64_v_m)))
void vsuxseg3ei64(vbool32_t, double *, vuint64m2_t, vfloat64m2_t, vfloat64m2_t, vfloat64m2_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vsuxseg4ei64_v)))
void vsuxseg4ei64(double *, vuint64m1_t, vfloat64m1_t, vfloat64m1_t, vfloat64m1_t, vfloat64m1_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vsuxseg4ei64_v_m)))
void vsuxseg4ei64(vbool64_t, double *, vuint64m1_t, vfloat64m1_t, vfloat64m1_t, vfloat64m1_t, vfloat64m1_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vsuxseg4ei64_v)))
void vsuxseg4ei64(double *, vuint64m2_t, vfloat64m2_t, vfloat64m2_t, vfloat64m2_t, vfloat64m2_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vsuxseg4ei64_v_m)))
void vsuxseg4ei64(vbool32_t, double *, vuint64m2_t, vfloat64m2_t, vfloat64m2_t, vfloat64m2_t, vfloat64m2_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vsuxseg5ei64_v)))
void vsuxseg5ei64(double *, vuint64m1_t, vfloat64m1_t, vfloat64m1_t, vfloat64m1_t, vfloat64m1_t, vfloat64m1_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vsuxseg5ei64_v_m)))
void vsuxseg5ei64(vbool64_t, double *, vuint64m1_t, vfloat64m1_t, vfloat64m1_t, vfloat64m1_t, vfloat64m1_t, vfloat64m1_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vsuxseg6ei64_v)))
void vsuxseg6ei64(double *, vuint64m1_t, vfloat64m1_t, vfloat64m1_t, vfloat64m1_t, vfloat64m1_t, vfloat64m1_t, vfloat64m1_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vsuxseg6ei64_v_m)))
void vsuxseg6ei64(vbool64_t, double *, vuint64m1_t, vfloat64m1_t, vfloat64m1_t, vfloat64m1_t, vfloat64m1_t, vfloat64m1_t, vfloat64m1_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vsuxseg7ei64_v)))
void vsuxseg7ei64(double *, vuint64m1_t, vfloat64m1_t, vfloat64m1_t, vfloat64m1_t, vfloat64m1_t, vfloat64m1_t, vfloat64m1_t, vfloat64m1_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vsuxseg7ei64_v_m)))
void vsuxseg7ei64(vbool64_t, double *, vuint64m1_t, vfloat64m1_t, vfloat64m1_t, vfloat64m1_t, vfloat64m1_t, vfloat64m1_t, vfloat64m1_t, vfloat64m1_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vsuxseg8ei64_v)))
void vsuxseg8ei64(double *, vuint64m1_t, vfloat64m1_t, vfloat64m1_t, vfloat64m1_t, vfloat64m1_t, vfloat64m1_t, vfloat64m1_t, vfloat64m1_t, vfloat64m1_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vsuxseg8ei64_v_m)))
void vsuxseg8ei64(vbool64_t, double *, vuint64m1_t, vfloat64m1_t, vfloat64m1_t, vfloat64m1_t, vfloat64m1_t, vfloat64m1_t, vfloat64m1_t, vfloat64m1_t, vfloat64m1_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vsoxseg2ei8_v)))
void vsoxseg2ei8(double *, vuint8mf8_t, vfloat64m1_t, vfloat64m1_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vsoxseg2ei8_v_m)))
void vsoxseg2ei8(vbool64_t, double *, vuint8mf8_t, vfloat64m1_t, vfloat64m1_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vsoxseg2ei8_v)))
void vsoxseg2ei8(double *, vuint8mf4_t, vfloat64m2_t, vfloat64m2_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vsoxseg2ei8_v_m)))
void vsoxseg2ei8(vbool32_t, double *, vuint8mf4_t, vfloat64m2_t, vfloat64m2_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vsoxseg2ei8_v)))
void vsoxseg2ei8(double *, vuint8mf2_t, vfloat64m4_t, vfloat64m4_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vsoxseg2ei8_v_m)))
void vsoxseg2ei8(vbool16_t, double *, vuint8mf2_t, vfloat64m4_t, vfloat64m4_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vsoxseg3ei8_v)))
void vsoxseg3ei8(double *, vuint8mf8_t, vfloat64m1_t, vfloat64m1_t, vfloat64m1_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vsoxseg3ei8_v_m)))
void vsoxseg3ei8(vbool64_t, double *, vuint8mf8_t, vfloat64m1_t, vfloat64m1_t, vfloat64m1_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vsoxseg3ei8_v)))
void vsoxseg3ei8(double *, vuint8mf4_t, vfloat64m2_t, vfloat64m2_t, vfloat64m2_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vsoxseg3ei8_v_m)))
void vsoxseg3ei8(vbool32_t, double *, vuint8mf4_t, vfloat64m2_t, vfloat64m2_t, vfloat64m2_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vsoxseg4ei8_v)))
void vsoxseg4ei8(double *, vuint8mf8_t, vfloat64m1_t, vfloat64m1_t, vfloat64m1_t, vfloat64m1_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vsoxseg4ei8_v_m)))
void vsoxseg4ei8(vbool64_t, double *, vuint8mf8_t, vfloat64m1_t, vfloat64m1_t, vfloat64m1_t, vfloat64m1_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vsoxseg4ei8_v)))
void vsoxseg4ei8(double *, vuint8mf4_t, vfloat64m2_t, vfloat64m2_t, vfloat64m2_t, vfloat64m2_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vsoxseg4ei8_v_m)))
void vsoxseg4ei8(vbool32_t, double *, vuint8mf4_t, vfloat64m2_t, vfloat64m2_t, vfloat64m2_t, vfloat64m2_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vsoxseg5ei8_v)))
void vsoxseg5ei8(double *, vuint8mf8_t, vfloat64m1_t, vfloat64m1_t, vfloat64m1_t, vfloat64m1_t, vfloat64m1_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vsoxseg5ei8_v_m)))
void vsoxseg5ei8(vbool64_t, double *, vuint8mf8_t, vfloat64m1_t, vfloat64m1_t, vfloat64m1_t, vfloat64m1_t, vfloat64m1_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vsoxseg6ei8_v)))
void vsoxseg6ei8(double *, vuint8mf8_t, vfloat64m1_t, vfloat64m1_t, vfloat64m1_t, vfloat64m1_t, vfloat64m1_t, vfloat64m1_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vsoxseg6ei8_v_m)))
void vsoxseg6ei8(vbool64_t, double *, vuint8mf8_t, vfloat64m1_t, vfloat64m1_t, vfloat64m1_t, vfloat64m1_t, vfloat64m1_t, vfloat64m1_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vsoxseg7ei8_v)))
void vsoxseg7ei8(double *, vuint8mf8_t, vfloat64m1_t, vfloat64m1_t, vfloat64m1_t, vfloat64m1_t, vfloat64m1_t, vfloat64m1_t, vfloat64m1_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vsoxseg7ei8_v_m)))
void vsoxseg7ei8(vbool64_t, double *, vuint8mf8_t, vfloat64m1_t, vfloat64m1_t, vfloat64m1_t, vfloat64m1_t, vfloat64m1_t, vfloat64m1_t, vfloat64m1_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vsoxseg8ei8_v)))
void vsoxseg8ei8(double *, vuint8mf8_t, vfloat64m1_t, vfloat64m1_t, vfloat64m1_t, vfloat64m1_t, vfloat64m1_t, vfloat64m1_t, vfloat64m1_t, vfloat64m1_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vsoxseg8ei8_v_m)))
void vsoxseg8ei8(vbool64_t, double *, vuint8mf8_t, vfloat64m1_t, vfloat64m1_t, vfloat64m1_t, vfloat64m1_t, vfloat64m1_t, vfloat64m1_t, vfloat64m1_t, vfloat64m1_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vsoxseg2ei16_v)))
void vsoxseg2ei16(double *, vuint16mf4_t, vfloat64m1_t, vfloat64m1_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vsoxseg2ei16_v_m)))
void vsoxseg2ei16(vbool64_t, double *, vuint16mf4_t, vfloat64m1_t, vfloat64m1_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vsoxseg2ei16_v)))
void vsoxseg2ei16(double *, vuint16mf2_t, vfloat64m2_t, vfloat64m2_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vsoxseg2ei16_v_m)))
void vsoxseg2ei16(vbool32_t, double *, vuint16mf2_t, vfloat64m2_t, vfloat64m2_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vsoxseg2ei16_v)))
void vsoxseg2ei16(double *, vuint16m1_t, vfloat64m4_t, vfloat64m4_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vsoxseg2ei16_v_m)))
void vsoxseg2ei16(vbool16_t, double *, vuint16m1_t, vfloat64m4_t, vfloat64m4_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vsoxseg3ei16_v)))
void vsoxseg3ei16(double *, vuint16mf4_t, vfloat64m1_t, vfloat64m1_t, vfloat64m1_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vsoxseg3ei16_v_m)))
void vsoxseg3ei16(vbool64_t, double *, vuint16mf4_t, vfloat64m1_t, vfloat64m1_t, vfloat64m1_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vsoxseg3ei16_v)))
void vsoxseg3ei16(double *, vuint16mf2_t, vfloat64m2_t, vfloat64m2_t, vfloat64m2_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vsoxseg3ei16_v_m)))
void vsoxseg3ei16(vbool32_t, double *, vuint16mf2_t, vfloat64m2_t, vfloat64m2_t, vfloat64m2_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vsoxseg4ei16_v)))
void vsoxseg4ei16(double *, vuint16mf4_t, vfloat64m1_t, vfloat64m1_t, vfloat64m1_t, vfloat64m1_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vsoxseg4ei16_v_m)))
void vsoxseg4ei16(vbool64_t, double *, vuint16mf4_t, vfloat64m1_t, vfloat64m1_t, vfloat64m1_t, vfloat64m1_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vsoxseg4ei16_v)))
void vsoxseg4ei16(double *, vuint16mf2_t, vfloat64m2_t, vfloat64m2_t, vfloat64m2_t, vfloat64m2_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vsoxseg4ei16_v_m)))
void vsoxseg4ei16(vbool32_t, double *, vuint16mf2_t, vfloat64m2_t, vfloat64m2_t, vfloat64m2_t, vfloat64m2_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vsoxseg5ei16_v)))
void vsoxseg5ei16(double *, vuint16mf4_t, vfloat64m1_t, vfloat64m1_t, vfloat64m1_t, vfloat64m1_t, vfloat64m1_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vsoxseg5ei16_v_m)))
void vsoxseg5ei16(vbool64_t, double *, vuint16mf4_t, vfloat64m1_t, vfloat64m1_t, vfloat64m1_t, vfloat64m1_t, vfloat64m1_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vsoxseg6ei16_v)))
void vsoxseg6ei16(double *, vuint16mf4_t, vfloat64m1_t, vfloat64m1_t, vfloat64m1_t, vfloat64m1_t, vfloat64m1_t, vfloat64m1_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vsoxseg6ei16_v_m)))
void vsoxseg6ei16(vbool64_t, double *, vuint16mf4_t, vfloat64m1_t, vfloat64m1_t, vfloat64m1_t, vfloat64m1_t, vfloat64m1_t, vfloat64m1_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vsoxseg7ei16_v)))
void vsoxseg7ei16(double *, vuint16mf4_t, vfloat64m1_t, vfloat64m1_t, vfloat64m1_t, vfloat64m1_t, vfloat64m1_t, vfloat64m1_t, vfloat64m1_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vsoxseg7ei16_v_m)))
void vsoxseg7ei16(vbool64_t, double *, vuint16mf4_t, vfloat64m1_t, vfloat64m1_t, vfloat64m1_t, vfloat64m1_t, vfloat64m1_t, vfloat64m1_t, vfloat64m1_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vsoxseg8ei16_v)))
void vsoxseg8ei16(double *, vuint16mf4_t, vfloat64m1_t, vfloat64m1_t, vfloat64m1_t, vfloat64m1_t, vfloat64m1_t, vfloat64m1_t, vfloat64m1_t, vfloat64m1_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vsoxseg8ei16_v_m)))
void vsoxseg8ei16(vbool64_t, double *, vuint16mf4_t, vfloat64m1_t, vfloat64m1_t, vfloat64m1_t, vfloat64m1_t, vfloat64m1_t, vfloat64m1_t, vfloat64m1_t, vfloat64m1_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vsoxseg2ei32_v)))
void vsoxseg2ei32(double *, vuint32mf2_t, vfloat64m1_t, vfloat64m1_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vsoxseg2ei32_v_m)))
void vsoxseg2ei32(vbool64_t, double *, vuint32mf2_t, vfloat64m1_t, vfloat64m1_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vsoxseg2ei32_v)))
void vsoxseg2ei32(double *, vuint32m1_t, vfloat64m2_t, vfloat64m2_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vsoxseg2ei32_v_m)))
void vsoxseg2ei32(vbool32_t, double *, vuint32m1_t, vfloat64m2_t, vfloat64m2_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vsoxseg2ei32_v)))
void vsoxseg2ei32(double *, vuint32m2_t, vfloat64m4_t, vfloat64m4_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vsoxseg2ei32_v_m)))
void vsoxseg2ei32(vbool16_t, double *, vuint32m2_t, vfloat64m4_t, vfloat64m4_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vsoxseg3ei32_v)))
void vsoxseg3ei32(double *, vuint32mf2_t, vfloat64m1_t, vfloat64m1_t, vfloat64m1_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vsoxseg3ei32_v_m)))
void vsoxseg3ei32(vbool64_t, double *, vuint32mf2_t, vfloat64m1_t, vfloat64m1_t, vfloat64m1_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vsoxseg3ei32_v)))
void vsoxseg3ei32(double *, vuint32m1_t, vfloat64m2_t, vfloat64m2_t, vfloat64m2_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vsoxseg3ei32_v_m)))
void vsoxseg3ei32(vbool32_t, double *, vuint32m1_t, vfloat64m2_t, vfloat64m2_t, vfloat64m2_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vsoxseg4ei32_v)))
void vsoxseg4ei32(double *, vuint32mf2_t, vfloat64m1_t, vfloat64m1_t, vfloat64m1_t, vfloat64m1_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vsoxseg4ei32_v_m)))
void vsoxseg4ei32(vbool64_t, double *, vuint32mf2_t, vfloat64m1_t, vfloat64m1_t, vfloat64m1_t, vfloat64m1_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vsoxseg4ei32_v)))
void vsoxseg4ei32(double *, vuint32m1_t, vfloat64m2_t, vfloat64m2_t, vfloat64m2_t, vfloat64m2_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vsoxseg4ei32_v_m)))
void vsoxseg4ei32(vbool32_t, double *, vuint32m1_t, vfloat64m2_t, vfloat64m2_t, vfloat64m2_t, vfloat64m2_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vsoxseg5ei32_v)))
void vsoxseg5ei32(double *, vuint32mf2_t, vfloat64m1_t, vfloat64m1_t, vfloat64m1_t, vfloat64m1_t, vfloat64m1_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vsoxseg5ei32_v_m)))
void vsoxseg5ei32(vbool64_t, double *, vuint32mf2_t, vfloat64m1_t, vfloat64m1_t, vfloat64m1_t, vfloat64m1_t, vfloat64m1_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vsoxseg6ei32_v)))
void vsoxseg6ei32(double *, vuint32mf2_t, vfloat64m1_t, vfloat64m1_t, vfloat64m1_t, vfloat64m1_t, vfloat64m1_t, vfloat64m1_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vsoxseg6ei32_v_m)))
void vsoxseg6ei32(vbool64_t, double *, vuint32mf2_t, vfloat64m1_t, vfloat64m1_t, vfloat64m1_t, vfloat64m1_t, vfloat64m1_t, vfloat64m1_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vsoxseg7ei32_v)))
void vsoxseg7ei32(double *, vuint32mf2_t, vfloat64m1_t, vfloat64m1_t, vfloat64m1_t, vfloat64m1_t, vfloat64m1_t, vfloat64m1_t, vfloat64m1_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vsoxseg7ei32_v_m)))
void vsoxseg7ei32(vbool64_t, double *, vuint32mf2_t, vfloat64m1_t, vfloat64m1_t, vfloat64m1_t, vfloat64m1_t, vfloat64m1_t, vfloat64m1_t, vfloat64m1_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vsoxseg8ei32_v)))
void vsoxseg8ei32(double *, vuint32mf2_t, vfloat64m1_t, vfloat64m1_t, vfloat64m1_t, vfloat64m1_t, vfloat64m1_t, vfloat64m1_t, vfloat64m1_t, vfloat64m1_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vsoxseg8ei32_v_m)))
void vsoxseg8ei32(vbool64_t, double *, vuint32mf2_t, vfloat64m1_t, vfloat64m1_t, vfloat64m1_t, vfloat64m1_t, vfloat64m1_t, vfloat64m1_t, vfloat64m1_t, vfloat64m1_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vsoxseg2ei64_v)))
void vsoxseg2ei64(double *, vuint64m1_t, vfloat64m1_t, vfloat64m1_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vsoxseg2ei64_v_m)))
void vsoxseg2ei64(vbool64_t, double *, vuint64m1_t, vfloat64m1_t, vfloat64m1_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vsoxseg2ei64_v)))
void vsoxseg2ei64(double *, vuint64m2_t, vfloat64m2_t, vfloat64m2_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vsoxseg2ei64_v_m)))
void vsoxseg2ei64(vbool32_t, double *, vuint64m2_t, vfloat64m2_t, vfloat64m2_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vsoxseg2ei64_v)))
void vsoxseg2ei64(double *, vuint64m4_t, vfloat64m4_t, vfloat64m4_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vsoxseg2ei64_v_m)))
void vsoxseg2ei64(vbool16_t, double *, vuint64m4_t, vfloat64m4_t, vfloat64m4_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vsoxseg3ei64_v)))
void vsoxseg3ei64(double *, vuint64m1_t, vfloat64m1_t, vfloat64m1_t, vfloat64m1_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vsoxseg3ei64_v_m)))
void vsoxseg3ei64(vbool64_t, double *, vuint64m1_t, vfloat64m1_t, vfloat64m1_t, vfloat64m1_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vsoxseg3ei64_v)))
void vsoxseg3ei64(double *, vuint64m2_t, vfloat64m2_t, vfloat64m2_t, vfloat64m2_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vsoxseg3ei64_v_m)))
void vsoxseg3ei64(vbool32_t, double *, vuint64m2_t, vfloat64m2_t, vfloat64m2_t, vfloat64m2_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vsoxseg4ei64_v)))
void vsoxseg4ei64(double *, vuint64m1_t, vfloat64m1_t, vfloat64m1_t, vfloat64m1_t, vfloat64m1_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vsoxseg4ei64_v_m)))
void vsoxseg4ei64(vbool64_t, double *, vuint64m1_t, vfloat64m1_t, vfloat64m1_t, vfloat64m1_t, vfloat64m1_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vsoxseg4ei64_v)))
void vsoxseg4ei64(double *, vuint64m2_t, vfloat64m2_t, vfloat64m2_t, vfloat64m2_t, vfloat64m2_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vsoxseg4ei64_v_m)))
void vsoxseg4ei64(vbool32_t, double *, vuint64m2_t, vfloat64m2_t, vfloat64m2_t, vfloat64m2_t, vfloat64m2_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vsoxseg5ei64_v)))
void vsoxseg5ei64(double *, vuint64m1_t, vfloat64m1_t, vfloat64m1_t, vfloat64m1_t, vfloat64m1_t, vfloat64m1_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vsoxseg5ei64_v_m)))
void vsoxseg5ei64(vbool64_t, double *, vuint64m1_t, vfloat64m1_t, vfloat64m1_t, vfloat64m1_t, vfloat64m1_t, vfloat64m1_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vsoxseg6ei64_v)))
void vsoxseg6ei64(double *, vuint64m1_t, vfloat64m1_t, vfloat64m1_t, vfloat64m1_t, vfloat64m1_t, vfloat64m1_t, vfloat64m1_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vsoxseg6ei64_v_m)))
void vsoxseg6ei64(vbool64_t, double *, vuint64m1_t, vfloat64m1_t, vfloat64m1_t, vfloat64m1_t, vfloat64m1_t, vfloat64m1_t, vfloat64m1_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vsoxseg7ei64_v)))
void vsoxseg7ei64(double *, vuint64m1_t, vfloat64m1_t, vfloat64m1_t, vfloat64m1_t, vfloat64m1_t, vfloat64m1_t, vfloat64m1_t, vfloat64m1_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vsoxseg7ei64_v_m)))
void vsoxseg7ei64(vbool64_t, double *, vuint64m1_t, vfloat64m1_t, vfloat64m1_t, vfloat64m1_t, vfloat64m1_t, vfloat64m1_t, vfloat64m1_t, vfloat64m1_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vsoxseg8ei64_v)))
void vsoxseg8ei64(double *, vuint64m1_t, vfloat64m1_t, vfloat64m1_t, vfloat64m1_t, vfloat64m1_t, vfloat64m1_t, vfloat64m1_t, vfloat64m1_t, vfloat64m1_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vsoxseg8ei64_v_m)))
void vsoxseg8ei64(vbool64_t, double *, vuint64m1_t, vfloat64m1_t, vfloat64m1_t, vfloat64m1_t, vfloat64m1_t, vfloat64m1_t, vfloat64m1_t, vfloat64m1_t, vfloat64m1_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vloxei8_v)))
vfloat64m1_t vloxei8(const double *, vuint8mf8_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vloxei8_v_m)))
vfloat64m1_t vloxei8(vbool64_t, vfloat64m1_t, const double *, vuint8mf8_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vloxei8_v)))
vfloat64m2_t vloxei8(const double *, vuint8mf4_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vloxei8_v_m)))
vfloat64m2_t vloxei8(vbool32_t, vfloat64m2_t, const double *, vuint8mf4_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vloxei8_v)))
vfloat64m4_t vloxei8(const double *, vuint8mf2_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vloxei8_v_m)))
vfloat64m4_t vloxei8(vbool16_t, vfloat64m4_t, const double *, vuint8mf2_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vloxei8_v)))
vfloat64m8_t vloxei8(const double *, vuint8m1_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vloxei8_v_m)))
vfloat64m8_t vloxei8(vbool8_t, vfloat64m8_t, const double *, vuint8m1_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vloxei16_v)))
vfloat64m1_t vloxei16(const double *, vuint16mf4_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vloxei16_v_m)))
vfloat64m1_t vloxei16(vbool64_t, vfloat64m1_t, const double *, vuint16mf4_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vloxei16_v)))
vfloat64m2_t vloxei16(const double *, vuint16mf2_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vloxei16_v_m)))
vfloat64m2_t vloxei16(vbool32_t, vfloat64m2_t, const double *, vuint16mf2_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vloxei16_v)))
vfloat64m4_t vloxei16(const double *, vuint16m1_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vloxei16_v_m)))
vfloat64m4_t vloxei16(vbool16_t, vfloat64m4_t, const double *, vuint16m1_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vloxei16_v)))
vfloat64m8_t vloxei16(const double *, vuint16m2_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vloxei16_v_m)))
vfloat64m8_t vloxei16(vbool8_t, vfloat64m8_t, const double *, vuint16m2_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vloxei32_v)))
vfloat64m1_t vloxei32(const double *, vuint32mf2_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vloxei32_v_m)))
vfloat64m1_t vloxei32(vbool64_t, vfloat64m1_t, const double *, vuint32mf2_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vloxei32_v)))
vfloat64m2_t vloxei32(const double *, vuint32m1_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vloxei32_v_m)))
vfloat64m2_t vloxei32(vbool32_t, vfloat64m2_t, const double *, vuint32m1_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vloxei32_v)))
vfloat64m4_t vloxei32(const double *, vuint32m2_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vloxei32_v_m)))
vfloat64m4_t vloxei32(vbool16_t, vfloat64m4_t, const double *, vuint32m2_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vloxei32_v)))
vfloat64m8_t vloxei32(const double *, vuint32m4_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vloxei32_v_m)))
vfloat64m8_t vloxei32(vbool8_t, vfloat64m8_t, const double *, vuint32m4_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vmv_v_v)))
vfloat64m1_t vmv_v(vfloat64m1_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vmv_v_v)))
vfloat64m2_t vmv_v(vfloat64m2_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vmv_v_v)))
vfloat64m4_t vmv_v(vfloat64m4_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vmv_v_v)))
vfloat64m8_t vmv_v(vfloat64m8_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vfadd_vv)))
vfloat64m1_t vfadd(vfloat64m1_t, vfloat64m1_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vfadd_vv_m)))
vfloat64m1_t vfadd(vbool64_t, vfloat64m1_t, vfloat64m1_t, vfloat64m1_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vfadd_vv)))
vfloat64m2_t vfadd(vfloat64m2_t, vfloat64m2_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vfadd_vv_m)))
vfloat64m2_t vfadd(vbool32_t, vfloat64m2_t, vfloat64m2_t, vfloat64m2_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vfadd_vv)))
vfloat64m4_t vfadd(vfloat64m4_t, vfloat64m4_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vfadd_vv_m)))
vfloat64m4_t vfadd(vbool16_t, vfloat64m4_t, vfloat64m4_t, vfloat64m4_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vfadd_vv)))
vfloat64m8_t vfadd(vfloat64m8_t, vfloat64m8_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vfadd_vv_m)))
vfloat64m8_t vfadd(vbool8_t, vfloat64m8_t, vfloat64m8_t, vfloat64m8_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vfadd_vf)))
vfloat64m1_t vfadd(vfloat64m1_t, double, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vfadd_vf_m)))
vfloat64m1_t vfadd(vbool64_t, vfloat64m1_t, vfloat64m1_t, double, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vfadd_vf)))
vfloat64m2_t vfadd(vfloat64m2_t, double, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vfadd_vf_m)))
vfloat64m2_t vfadd(vbool32_t, vfloat64m2_t, vfloat64m2_t, double, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vfadd_vf)))
vfloat64m4_t vfadd(vfloat64m4_t, double, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vfadd_vf_m)))
vfloat64m4_t vfadd(vbool16_t, vfloat64m4_t, vfloat64m4_t, double, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vfadd_vf)))
vfloat64m8_t vfadd(vfloat64m8_t, double, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vfadd_vf_m)))
vfloat64m8_t vfadd(vbool8_t, vfloat64m8_t, vfloat64m8_t, double, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vfsub_vv)))
vfloat64m1_t vfsub(vfloat64m1_t, vfloat64m1_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vfsub_vv_m)))
vfloat64m1_t vfsub(vbool64_t, vfloat64m1_t, vfloat64m1_t, vfloat64m1_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vfsub_vv)))
vfloat64m2_t vfsub(vfloat64m2_t, vfloat64m2_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vfsub_vv_m)))
vfloat64m2_t vfsub(vbool32_t, vfloat64m2_t, vfloat64m2_t, vfloat64m2_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vfsub_vv)))
vfloat64m4_t vfsub(vfloat64m4_t, vfloat64m4_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vfsub_vv_m)))
vfloat64m4_t vfsub(vbool16_t, vfloat64m4_t, vfloat64m4_t, vfloat64m4_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vfsub_vv)))
vfloat64m8_t vfsub(vfloat64m8_t, vfloat64m8_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vfsub_vv_m)))
vfloat64m8_t vfsub(vbool8_t, vfloat64m8_t, vfloat64m8_t, vfloat64m8_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vfsub_vf)))
vfloat64m1_t vfsub(vfloat64m1_t, double, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vfsub_vf_m)))
vfloat64m1_t vfsub(vbool64_t, vfloat64m1_t, vfloat64m1_t, double, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vfsub_vf)))
vfloat64m2_t vfsub(vfloat64m2_t, double, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vfsub_vf_m)))
vfloat64m2_t vfsub(vbool32_t, vfloat64m2_t, vfloat64m2_t, double, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vfsub_vf)))
vfloat64m4_t vfsub(vfloat64m4_t, double, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vfsub_vf_m)))
vfloat64m4_t vfsub(vbool16_t, vfloat64m4_t, vfloat64m4_t, double, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vfsub_vf)))
vfloat64m8_t vfsub(vfloat64m8_t, double, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vfsub_vf_m)))
vfloat64m8_t vfsub(vbool8_t, vfloat64m8_t, vfloat64m8_t, double, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vfrsub_vf)))
vfloat64m1_t vfrsub(vfloat64m1_t, double, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vfrsub_vf_m)))
vfloat64m1_t vfrsub(vbool64_t, vfloat64m1_t, vfloat64m1_t, double, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vfrsub_vf)))
vfloat64m2_t vfrsub(vfloat64m2_t, double, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vfrsub_vf_m)))
vfloat64m2_t vfrsub(vbool32_t, vfloat64m2_t, vfloat64m2_t, double, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vfrsub_vf)))
vfloat64m4_t vfrsub(vfloat64m4_t, double, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vfrsub_vf_m)))
vfloat64m4_t vfrsub(vbool16_t, vfloat64m4_t, vfloat64m4_t, double, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vfrsub_vf)))
vfloat64m8_t vfrsub(vfloat64m8_t, double, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vfrsub_vf_m)))
vfloat64m8_t vfrsub(vbool8_t, vfloat64m8_t, vfloat64m8_t, double, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vfwadd_wf)))
vfloat64m1_t vfwadd_wf(vfloat64m1_t, float, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vfwadd_wf_m)))
vfloat64m1_t vfwadd_wf(vbool64_t, vfloat64m1_t, vfloat64m1_t, float, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vfwadd_wf)))
vfloat64m2_t vfwadd_wf(vfloat64m2_t, float, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vfwadd_wf_m)))
vfloat64m2_t vfwadd_wf(vbool32_t, vfloat64m2_t, vfloat64m2_t, float, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vfwadd_wf)))
vfloat64m4_t vfwadd_wf(vfloat64m4_t, float, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vfwadd_wf_m)))
vfloat64m4_t vfwadd_wf(vbool16_t, vfloat64m4_t, vfloat64m4_t, float, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vfwadd_wf)))
vfloat64m8_t vfwadd_wf(vfloat64m8_t, float, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vfwadd_wf_m)))
vfloat64m8_t vfwadd_wf(vbool8_t, vfloat64m8_t, vfloat64m8_t, float, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vfwsub_wf)))
vfloat64m1_t vfwsub_wf(vfloat64m1_t, float, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vfwsub_wf_m)))
vfloat64m1_t vfwsub_wf(vbool64_t, vfloat64m1_t, vfloat64m1_t, float, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vfwsub_wf)))
vfloat64m2_t vfwsub_wf(vfloat64m2_t, float, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vfwsub_wf_m)))
vfloat64m2_t vfwsub_wf(vbool32_t, vfloat64m2_t, vfloat64m2_t, float, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vfwsub_wf)))
vfloat64m4_t vfwsub_wf(vfloat64m4_t, float, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vfwsub_wf_m)))
vfloat64m4_t vfwsub_wf(vbool16_t, vfloat64m4_t, vfloat64m4_t, float, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vfwsub_wf)))
vfloat64m8_t vfwsub_wf(vfloat64m8_t, float, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vfwsub_wf_m)))
vfloat64m8_t vfwsub_wf(vbool8_t, vfloat64m8_t, vfloat64m8_t, float, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vfmul_vv)))
vfloat64m1_t vfmul(vfloat64m1_t, vfloat64m1_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vfmul_vv_m)))
vfloat64m1_t vfmul(vbool64_t, vfloat64m1_t, vfloat64m1_t, vfloat64m1_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vfmul_vv)))
vfloat64m2_t vfmul(vfloat64m2_t, vfloat64m2_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vfmul_vv_m)))
vfloat64m2_t vfmul(vbool32_t, vfloat64m2_t, vfloat64m2_t, vfloat64m2_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vfmul_vv)))
vfloat64m4_t vfmul(vfloat64m4_t, vfloat64m4_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vfmul_vv_m)))
vfloat64m4_t vfmul(vbool16_t, vfloat64m4_t, vfloat64m4_t, vfloat64m4_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vfmul_vv)))
vfloat64m8_t vfmul(vfloat64m8_t, vfloat64m8_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vfmul_vv_m)))
vfloat64m8_t vfmul(vbool8_t, vfloat64m8_t, vfloat64m8_t, vfloat64m8_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vfmul_vf)))
vfloat64m1_t vfmul(vfloat64m1_t, double, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vfmul_vf_m)))
vfloat64m1_t vfmul(vbool64_t, vfloat64m1_t, vfloat64m1_t, double, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vfmul_vf)))
vfloat64m2_t vfmul(vfloat64m2_t, double, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vfmul_vf_m)))
vfloat64m2_t vfmul(vbool32_t, vfloat64m2_t, vfloat64m2_t, double, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vfmul_vf)))
vfloat64m4_t vfmul(vfloat64m4_t, double, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vfmul_vf_m)))
vfloat64m4_t vfmul(vbool16_t, vfloat64m4_t, vfloat64m4_t, double, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vfmul_vf)))
vfloat64m8_t vfmul(vfloat64m8_t, double, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vfmul_vf_m)))
vfloat64m8_t vfmul(vbool8_t, vfloat64m8_t, vfloat64m8_t, double, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vfdiv_vv)))
vfloat64m1_t vfdiv(vfloat64m1_t, vfloat64m1_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vfdiv_vv_m)))
vfloat64m1_t vfdiv(vbool64_t, vfloat64m1_t, vfloat64m1_t, vfloat64m1_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vfdiv_vv)))
vfloat64m2_t vfdiv(vfloat64m2_t, vfloat64m2_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vfdiv_vv_m)))
vfloat64m2_t vfdiv(vbool32_t, vfloat64m2_t, vfloat64m2_t, vfloat64m2_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vfdiv_vv)))
vfloat64m4_t vfdiv(vfloat64m4_t, vfloat64m4_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vfdiv_vv_m)))
vfloat64m4_t vfdiv(vbool16_t, vfloat64m4_t, vfloat64m4_t, vfloat64m4_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vfdiv_vv)))
vfloat64m8_t vfdiv(vfloat64m8_t, vfloat64m8_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vfdiv_vv_m)))
vfloat64m8_t vfdiv(vbool8_t, vfloat64m8_t, vfloat64m8_t, vfloat64m8_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vfdiv_vf)))
vfloat64m1_t vfdiv(vfloat64m1_t, double, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vfdiv_vf_m)))
vfloat64m1_t vfdiv(vbool64_t, vfloat64m1_t, vfloat64m1_t, double, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vfdiv_vf)))
vfloat64m2_t vfdiv(vfloat64m2_t, double, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vfdiv_vf_m)))
vfloat64m2_t vfdiv(vbool32_t, vfloat64m2_t, vfloat64m2_t, double, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vfdiv_vf)))
vfloat64m4_t vfdiv(vfloat64m4_t, double, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vfdiv_vf_m)))
vfloat64m4_t vfdiv(vbool16_t, vfloat64m4_t, vfloat64m4_t, double, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vfdiv_vf)))
vfloat64m8_t vfdiv(vfloat64m8_t, double, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vfdiv_vf_m)))
vfloat64m8_t vfdiv(vbool8_t, vfloat64m8_t, vfloat64m8_t, double, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vfrdiv_vf)))
vfloat64m1_t vfrdiv(vfloat64m1_t, double, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vfrdiv_vf_m)))
vfloat64m1_t vfrdiv(vbool64_t, vfloat64m1_t, vfloat64m1_t, double, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vfrdiv_vf)))
vfloat64m2_t vfrdiv(vfloat64m2_t, double, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vfrdiv_vf_m)))
vfloat64m2_t vfrdiv(vbool32_t, vfloat64m2_t, vfloat64m2_t, double, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vfrdiv_vf)))
vfloat64m4_t vfrdiv(vfloat64m4_t, double, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vfrdiv_vf_m)))
vfloat64m4_t vfrdiv(vbool16_t, vfloat64m4_t, vfloat64m4_t, double, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vfrdiv_vf)))
vfloat64m8_t vfrdiv(vfloat64m8_t, double, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vfrdiv_vf_m)))
vfloat64m8_t vfrdiv(vbool8_t, vfloat64m8_t, vfloat64m8_t, double, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vfmacc_vv)))
vfloat64m1_t vfmacc(vfloat64m1_t, vfloat64m1_t, vfloat64m1_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vfmacc_vv_m)))
vfloat64m1_t vfmacc(vbool64_t, vfloat64m1_t, vfloat64m1_t, vfloat64m1_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vfmacc_vv)))
vfloat64m2_t vfmacc(vfloat64m2_t, vfloat64m2_t, vfloat64m2_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vfmacc_vv_m)))
vfloat64m2_t vfmacc(vbool32_t, vfloat64m2_t, vfloat64m2_t, vfloat64m2_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vfmacc_vv)))
vfloat64m4_t vfmacc(vfloat64m4_t, vfloat64m4_t, vfloat64m4_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vfmacc_vv_m)))
vfloat64m4_t vfmacc(vbool16_t, vfloat64m4_t, vfloat64m4_t, vfloat64m4_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vfmacc_vv)))
vfloat64m8_t vfmacc(vfloat64m8_t, vfloat64m8_t, vfloat64m8_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vfmacc_vv_m)))
vfloat64m8_t vfmacc(vbool8_t, vfloat64m8_t, vfloat64m8_t, vfloat64m8_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vfmacc_vf)))
vfloat64m1_t vfmacc(vfloat64m1_t, double, vfloat64m1_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vfmacc_vf_m)))
vfloat64m1_t vfmacc(vbool64_t, vfloat64m1_t, double, vfloat64m1_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vfmacc_vf)))
vfloat64m2_t vfmacc(vfloat64m2_t, double, vfloat64m2_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vfmacc_vf_m)))
vfloat64m2_t vfmacc(vbool32_t, vfloat64m2_t, double, vfloat64m2_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vfmacc_vf)))
vfloat64m4_t vfmacc(vfloat64m4_t, double, vfloat64m4_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vfmacc_vf_m)))
vfloat64m4_t vfmacc(vbool16_t, vfloat64m4_t, double, vfloat64m4_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vfmacc_vf)))
vfloat64m8_t vfmacc(vfloat64m8_t, double, vfloat64m8_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vfmacc_vf_m)))
vfloat64m8_t vfmacc(vbool8_t, vfloat64m8_t, double, vfloat64m8_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vfnmacc_vv)))
vfloat64m1_t vfnmacc(vfloat64m1_t, vfloat64m1_t, vfloat64m1_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vfnmacc_vv_m)))
vfloat64m1_t vfnmacc(vbool64_t, vfloat64m1_t, vfloat64m1_t, vfloat64m1_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vfnmacc_vv)))
vfloat64m2_t vfnmacc(vfloat64m2_t, vfloat64m2_t, vfloat64m2_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vfnmacc_vv_m)))
vfloat64m2_t vfnmacc(vbool32_t, vfloat64m2_t, vfloat64m2_t, vfloat64m2_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vfnmacc_vv)))
vfloat64m4_t vfnmacc(vfloat64m4_t, vfloat64m4_t, vfloat64m4_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vfnmacc_vv_m)))
vfloat64m4_t vfnmacc(vbool16_t, vfloat64m4_t, vfloat64m4_t, vfloat64m4_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vfnmacc_vv)))
vfloat64m8_t vfnmacc(vfloat64m8_t, vfloat64m8_t, vfloat64m8_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vfnmacc_vv_m)))
vfloat64m8_t vfnmacc(vbool8_t, vfloat64m8_t, vfloat64m8_t, vfloat64m8_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vfnmacc_vf)))
vfloat64m1_t vfnmacc(vfloat64m1_t, double, vfloat64m1_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vfnmacc_vf_m)))
vfloat64m1_t vfnmacc(vbool64_t, vfloat64m1_t, double, vfloat64m1_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vfnmacc_vf)))
vfloat64m2_t vfnmacc(vfloat64m2_t, double, vfloat64m2_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vfnmacc_vf_m)))
vfloat64m2_t vfnmacc(vbool32_t, vfloat64m2_t, double, vfloat64m2_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vfnmacc_vf)))
vfloat64m4_t vfnmacc(vfloat64m4_t, double, vfloat64m4_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vfnmacc_vf_m)))
vfloat64m4_t vfnmacc(vbool16_t, vfloat64m4_t, double, vfloat64m4_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vfnmacc_vf)))
vfloat64m8_t vfnmacc(vfloat64m8_t, double, vfloat64m8_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vfnmacc_vf_m)))
vfloat64m8_t vfnmacc(vbool8_t, vfloat64m8_t, double, vfloat64m8_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vfmsac_vv)))
vfloat64m1_t vfmsac(vfloat64m1_t, vfloat64m1_t, vfloat64m1_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vfmsac_vv_m)))
vfloat64m1_t vfmsac(vbool64_t, vfloat64m1_t, vfloat64m1_t, vfloat64m1_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vfmsac_vv)))
vfloat64m2_t vfmsac(vfloat64m2_t, vfloat64m2_t, vfloat64m2_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vfmsac_vv_m)))
vfloat64m2_t vfmsac(vbool32_t, vfloat64m2_t, vfloat64m2_t, vfloat64m2_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vfmsac_vv)))
vfloat64m4_t vfmsac(vfloat64m4_t, vfloat64m4_t, vfloat64m4_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vfmsac_vv_m)))
vfloat64m4_t vfmsac(vbool16_t, vfloat64m4_t, vfloat64m4_t, vfloat64m4_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vfmsac_vv)))
vfloat64m8_t vfmsac(vfloat64m8_t, vfloat64m8_t, vfloat64m8_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vfmsac_vv_m)))
vfloat64m8_t vfmsac(vbool8_t, vfloat64m8_t, vfloat64m8_t, vfloat64m8_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vfmsac_vf)))
vfloat64m1_t vfmsac(vfloat64m1_t, double, vfloat64m1_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vfmsac_vf_m)))
vfloat64m1_t vfmsac(vbool64_t, vfloat64m1_t, double, vfloat64m1_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vfmsac_vf)))
vfloat64m2_t vfmsac(vfloat64m2_t, double, vfloat64m2_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vfmsac_vf_m)))
vfloat64m2_t vfmsac(vbool32_t, vfloat64m2_t, double, vfloat64m2_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vfmsac_vf)))
vfloat64m4_t vfmsac(vfloat64m4_t, double, vfloat64m4_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vfmsac_vf_m)))
vfloat64m4_t vfmsac(vbool16_t, vfloat64m4_t, double, vfloat64m4_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vfmsac_vf)))
vfloat64m8_t vfmsac(vfloat64m8_t, double, vfloat64m8_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vfmsac_vf_m)))
vfloat64m8_t vfmsac(vbool8_t, vfloat64m8_t, double, vfloat64m8_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vfnmsac_vv)))
vfloat64m1_t vfnmsac(vfloat64m1_t, vfloat64m1_t, vfloat64m1_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vfnmsac_vv_m)))
vfloat64m1_t vfnmsac(vbool64_t, vfloat64m1_t, vfloat64m1_t, vfloat64m1_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vfnmsac_vv)))
vfloat64m2_t vfnmsac(vfloat64m2_t, vfloat64m2_t, vfloat64m2_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vfnmsac_vv_m)))
vfloat64m2_t vfnmsac(vbool32_t, vfloat64m2_t, vfloat64m2_t, vfloat64m2_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vfnmsac_vv)))
vfloat64m4_t vfnmsac(vfloat64m4_t, vfloat64m4_t, vfloat64m4_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vfnmsac_vv_m)))
vfloat64m4_t vfnmsac(vbool16_t, vfloat64m4_t, vfloat64m4_t, vfloat64m4_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vfnmsac_vv)))
vfloat64m8_t vfnmsac(vfloat64m8_t, vfloat64m8_t, vfloat64m8_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vfnmsac_vv_m)))
vfloat64m8_t vfnmsac(vbool8_t, vfloat64m8_t, vfloat64m8_t, vfloat64m8_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vfnmsac_vf)))
vfloat64m1_t vfnmsac(vfloat64m1_t, double, vfloat64m1_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vfnmsac_vf_m)))
vfloat64m1_t vfnmsac(vbool64_t, vfloat64m1_t, double, vfloat64m1_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vfnmsac_vf)))
vfloat64m2_t vfnmsac(vfloat64m2_t, double, vfloat64m2_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vfnmsac_vf_m)))
vfloat64m2_t vfnmsac(vbool32_t, vfloat64m2_t, double, vfloat64m2_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vfnmsac_vf)))
vfloat64m4_t vfnmsac(vfloat64m4_t, double, vfloat64m4_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vfnmsac_vf_m)))
vfloat64m4_t vfnmsac(vbool16_t, vfloat64m4_t, double, vfloat64m4_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vfnmsac_vf)))
vfloat64m8_t vfnmsac(vfloat64m8_t, double, vfloat64m8_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vfnmsac_vf_m)))
vfloat64m8_t vfnmsac(vbool8_t, vfloat64m8_t, double, vfloat64m8_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vfmadd_vv)))
vfloat64m1_t vfmadd(vfloat64m1_t, vfloat64m1_t, vfloat64m1_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vfmadd_vv_m)))
vfloat64m1_t vfmadd(vbool64_t, vfloat64m1_t, vfloat64m1_t, vfloat64m1_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vfmadd_vv)))
vfloat64m2_t vfmadd(vfloat64m2_t, vfloat64m2_t, vfloat64m2_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vfmadd_vv_m)))
vfloat64m2_t vfmadd(vbool32_t, vfloat64m2_t, vfloat64m2_t, vfloat64m2_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vfmadd_vv)))
vfloat64m4_t vfmadd(vfloat64m4_t, vfloat64m4_t, vfloat64m4_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vfmadd_vv_m)))
vfloat64m4_t vfmadd(vbool16_t, vfloat64m4_t, vfloat64m4_t, vfloat64m4_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vfmadd_vv)))
vfloat64m8_t vfmadd(vfloat64m8_t, vfloat64m8_t, vfloat64m8_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vfmadd_vv_m)))
vfloat64m8_t vfmadd(vbool8_t, vfloat64m8_t, vfloat64m8_t, vfloat64m8_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vfmadd_vf)))
vfloat64m1_t vfmadd(vfloat64m1_t, double, vfloat64m1_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vfmadd_vf_m)))
vfloat64m1_t vfmadd(vbool64_t, vfloat64m1_t, double, vfloat64m1_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vfmadd_vf)))
vfloat64m2_t vfmadd(vfloat64m2_t, double, vfloat64m2_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vfmadd_vf_m)))
vfloat64m2_t vfmadd(vbool32_t, vfloat64m2_t, double, vfloat64m2_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vfmadd_vf)))
vfloat64m4_t vfmadd(vfloat64m4_t, double, vfloat64m4_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vfmadd_vf_m)))
vfloat64m4_t vfmadd(vbool16_t, vfloat64m4_t, double, vfloat64m4_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vfmadd_vf)))
vfloat64m8_t vfmadd(vfloat64m8_t, double, vfloat64m8_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vfmadd_vf_m)))
vfloat64m8_t vfmadd(vbool8_t, vfloat64m8_t, double, vfloat64m8_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vfnmadd_vv)))
vfloat64m1_t vfnmadd(vfloat64m1_t, vfloat64m1_t, vfloat64m1_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vfnmadd_vv_m)))
vfloat64m1_t vfnmadd(vbool64_t, vfloat64m1_t, vfloat64m1_t, vfloat64m1_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vfnmadd_vv)))
vfloat64m2_t vfnmadd(vfloat64m2_t, vfloat64m2_t, vfloat64m2_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vfnmadd_vv_m)))
vfloat64m2_t vfnmadd(vbool32_t, vfloat64m2_t, vfloat64m2_t, vfloat64m2_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vfnmadd_vv)))
vfloat64m4_t vfnmadd(vfloat64m4_t, vfloat64m4_t, vfloat64m4_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vfnmadd_vv_m)))
vfloat64m4_t vfnmadd(vbool16_t, vfloat64m4_t, vfloat64m4_t, vfloat64m4_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vfnmadd_vv)))
vfloat64m8_t vfnmadd(vfloat64m8_t, vfloat64m8_t, vfloat64m8_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vfnmadd_vv_m)))
vfloat64m8_t vfnmadd(vbool8_t, vfloat64m8_t, vfloat64m8_t, vfloat64m8_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vfnmadd_vf)))
vfloat64m1_t vfnmadd(vfloat64m1_t, double, vfloat64m1_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vfnmadd_vf_m)))
vfloat64m1_t vfnmadd(vbool64_t, vfloat64m1_t, double, vfloat64m1_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vfnmadd_vf)))
vfloat64m2_t vfnmadd(vfloat64m2_t, double, vfloat64m2_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vfnmadd_vf_m)))
vfloat64m2_t vfnmadd(vbool32_t, vfloat64m2_t, double, vfloat64m2_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vfnmadd_vf)))
vfloat64m4_t vfnmadd(vfloat64m4_t, double, vfloat64m4_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vfnmadd_vf_m)))
vfloat64m4_t vfnmadd(vbool16_t, vfloat64m4_t, double, vfloat64m4_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vfnmadd_vf)))
vfloat64m8_t vfnmadd(vfloat64m8_t, double, vfloat64m8_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vfnmadd_vf_m)))
vfloat64m8_t vfnmadd(vbool8_t, vfloat64m8_t, double, vfloat64m8_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vfmsub_vv)))
vfloat64m1_t vfmsub(vfloat64m1_t, vfloat64m1_t, vfloat64m1_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vfmsub_vv_m)))
vfloat64m1_t vfmsub(vbool64_t, vfloat64m1_t, vfloat64m1_t, vfloat64m1_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vfmsub_vv)))
vfloat64m2_t vfmsub(vfloat64m2_t, vfloat64m2_t, vfloat64m2_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vfmsub_vv_m)))
vfloat64m2_t vfmsub(vbool32_t, vfloat64m2_t, vfloat64m2_t, vfloat64m2_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vfmsub_vv)))
vfloat64m4_t vfmsub(vfloat64m4_t, vfloat64m4_t, vfloat64m4_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vfmsub_vv_m)))
vfloat64m4_t vfmsub(vbool16_t, vfloat64m4_t, vfloat64m4_t, vfloat64m4_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vfmsub_vv)))
vfloat64m8_t vfmsub(vfloat64m8_t, vfloat64m8_t, vfloat64m8_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vfmsub_vv_m)))
vfloat64m8_t vfmsub(vbool8_t, vfloat64m8_t, vfloat64m8_t, vfloat64m8_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vfmsub_vf)))
vfloat64m1_t vfmsub(vfloat64m1_t, double, vfloat64m1_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vfmsub_vf_m)))
vfloat64m1_t vfmsub(vbool64_t, vfloat64m1_t, double, vfloat64m1_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vfmsub_vf)))
vfloat64m2_t vfmsub(vfloat64m2_t, double, vfloat64m2_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vfmsub_vf_m)))
vfloat64m2_t vfmsub(vbool32_t, vfloat64m2_t, double, vfloat64m2_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vfmsub_vf)))
vfloat64m4_t vfmsub(vfloat64m4_t, double, vfloat64m4_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vfmsub_vf_m)))
vfloat64m4_t vfmsub(vbool16_t, vfloat64m4_t, double, vfloat64m4_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vfmsub_vf)))
vfloat64m8_t vfmsub(vfloat64m8_t, double, vfloat64m8_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vfmsub_vf_m)))
vfloat64m8_t vfmsub(vbool8_t, vfloat64m8_t, double, vfloat64m8_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vfnmsub_vv)))
vfloat64m1_t vfnmsub(vfloat64m1_t, vfloat64m1_t, vfloat64m1_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vfnmsub_vv_m)))
vfloat64m1_t vfnmsub(vbool64_t, vfloat64m1_t, vfloat64m1_t, vfloat64m1_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vfnmsub_vv)))
vfloat64m2_t vfnmsub(vfloat64m2_t, vfloat64m2_t, vfloat64m2_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vfnmsub_vv_m)))
vfloat64m2_t vfnmsub(vbool32_t, vfloat64m2_t, vfloat64m2_t, vfloat64m2_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vfnmsub_vv)))
vfloat64m4_t vfnmsub(vfloat64m4_t, vfloat64m4_t, vfloat64m4_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vfnmsub_vv_m)))
vfloat64m4_t vfnmsub(vbool16_t, vfloat64m4_t, vfloat64m4_t, vfloat64m4_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vfnmsub_vv)))
vfloat64m8_t vfnmsub(vfloat64m8_t, vfloat64m8_t, vfloat64m8_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vfnmsub_vv_m)))
vfloat64m8_t vfnmsub(vbool8_t, vfloat64m8_t, vfloat64m8_t, vfloat64m8_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vfnmsub_vf)))
vfloat64m1_t vfnmsub(vfloat64m1_t, double, vfloat64m1_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vfnmsub_vf_m)))
vfloat64m1_t vfnmsub(vbool64_t, vfloat64m1_t, double, vfloat64m1_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vfnmsub_vf)))
vfloat64m2_t vfnmsub(vfloat64m2_t, double, vfloat64m2_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vfnmsub_vf_m)))
vfloat64m2_t vfnmsub(vbool32_t, vfloat64m2_t, double, vfloat64m2_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vfnmsub_vf)))
vfloat64m4_t vfnmsub(vfloat64m4_t, double, vfloat64m4_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vfnmsub_vf_m)))
vfloat64m4_t vfnmsub(vbool16_t, vfloat64m4_t, double, vfloat64m4_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vfnmsub_vf)))
vfloat64m8_t vfnmsub(vfloat64m8_t, double, vfloat64m8_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vfnmsub_vf_m)))
vfloat64m8_t vfnmsub(vbool8_t, vfloat64m8_t, double, vfloat64m8_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vfmin_vv)))
vfloat64m1_t vfmin(vfloat64m1_t, vfloat64m1_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vfmin_vv_m)))
vfloat64m1_t vfmin(vbool64_t, vfloat64m1_t, vfloat64m1_t, vfloat64m1_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vfmin_vv)))
vfloat64m2_t vfmin(vfloat64m2_t, vfloat64m2_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vfmin_vv_m)))
vfloat64m2_t vfmin(vbool32_t, vfloat64m2_t, vfloat64m2_t, vfloat64m2_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vfmin_vv)))
vfloat64m4_t vfmin(vfloat64m4_t, vfloat64m4_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vfmin_vv_m)))
vfloat64m4_t vfmin(vbool16_t, vfloat64m4_t, vfloat64m4_t, vfloat64m4_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vfmin_vv)))
vfloat64m8_t vfmin(vfloat64m8_t, vfloat64m8_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vfmin_vv_m)))
vfloat64m8_t vfmin(vbool8_t, vfloat64m8_t, vfloat64m8_t, vfloat64m8_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vfmin_vf)))
vfloat64m1_t vfmin(vfloat64m1_t, double, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vfmin_vf_m)))
vfloat64m1_t vfmin(vbool64_t, vfloat64m1_t, vfloat64m1_t, double, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vfmin_vf)))
vfloat64m2_t vfmin(vfloat64m2_t, double, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vfmin_vf_m)))
vfloat64m2_t vfmin(vbool32_t, vfloat64m2_t, vfloat64m2_t, double, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vfmin_vf)))
vfloat64m4_t vfmin(vfloat64m4_t, double, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vfmin_vf_m)))
vfloat64m4_t vfmin(vbool16_t, vfloat64m4_t, vfloat64m4_t, double, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vfmin_vf)))
vfloat64m8_t vfmin(vfloat64m8_t, double, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vfmin_vf_m)))
vfloat64m8_t vfmin(vbool8_t, vfloat64m8_t, vfloat64m8_t, double, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vfmax_vv)))
vfloat64m1_t vfmax(vfloat64m1_t, vfloat64m1_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vfmax_vv_m)))
vfloat64m1_t vfmax(vbool64_t, vfloat64m1_t, vfloat64m1_t, vfloat64m1_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vfmax_vv)))
vfloat64m2_t vfmax(vfloat64m2_t, vfloat64m2_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vfmax_vv_m)))
vfloat64m2_t vfmax(vbool32_t, vfloat64m2_t, vfloat64m2_t, vfloat64m2_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vfmax_vv)))
vfloat64m4_t vfmax(vfloat64m4_t, vfloat64m4_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vfmax_vv_m)))
vfloat64m4_t vfmax(vbool16_t, vfloat64m4_t, vfloat64m4_t, vfloat64m4_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vfmax_vv)))
vfloat64m8_t vfmax(vfloat64m8_t, vfloat64m8_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vfmax_vv_m)))
vfloat64m8_t vfmax(vbool8_t, vfloat64m8_t, vfloat64m8_t, vfloat64m8_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vfmax_vf)))
vfloat64m1_t vfmax(vfloat64m1_t, double, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vfmax_vf_m)))
vfloat64m1_t vfmax(vbool64_t, vfloat64m1_t, vfloat64m1_t, double, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vfmax_vf)))
vfloat64m2_t vfmax(vfloat64m2_t, double, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vfmax_vf_m)))
vfloat64m2_t vfmax(vbool32_t, vfloat64m2_t, vfloat64m2_t, double, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vfmax_vf)))
vfloat64m4_t vfmax(vfloat64m4_t, double, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vfmax_vf_m)))
vfloat64m4_t vfmax(vbool16_t, vfloat64m4_t, vfloat64m4_t, double, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vfmax_vf)))
vfloat64m8_t vfmax(vfloat64m8_t, double, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vfmax_vf_m)))
vfloat64m8_t vfmax(vbool8_t, vfloat64m8_t, vfloat64m8_t, double, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vfsgnj_vv)))
vfloat64m1_t vfsgnj(vfloat64m1_t, vfloat64m1_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vfsgnj_vv_m)))
vfloat64m1_t vfsgnj(vbool64_t, vfloat64m1_t, vfloat64m1_t, vfloat64m1_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vfsgnj_vv)))
vfloat64m2_t vfsgnj(vfloat64m2_t, vfloat64m2_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vfsgnj_vv_m)))
vfloat64m2_t vfsgnj(vbool32_t, vfloat64m2_t, vfloat64m2_t, vfloat64m2_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vfsgnj_vv)))
vfloat64m4_t vfsgnj(vfloat64m4_t, vfloat64m4_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vfsgnj_vv_m)))
vfloat64m4_t vfsgnj(vbool16_t, vfloat64m4_t, vfloat64m4_t, vfloat64m4_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vfsgnj_vv)))
vfloat64m8_t vfsgnj(vfloat64m8_t, vfloat64m8_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vfsgnj_vv_m)))
vfloat64m8_t vfsgnj(vbool8_t, vfloat64m8_t, vfloat64m8_t, vfloat64m8_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vfsgnj_vf)))
vfloat64m1_t vfsgnj(vfloat64m1_t, double, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vfsgnj_vf_m)))
vfloat64m1_t vfsgnj(vbool64_t, vfloat64m1_t, vfloat64m1_t, double, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vfsgnj_vf)))
vfloat64m2_t vfsgnj(vfloat64m2_t, double, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vfsgnj_vf_m)))
vfloat64m2_t vfsgnj(vbool32_t, vfloat64m2_t, vfloat64m2_t, double, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vfsgnj_vf)))
vfloat64m4_t vfsgnj(vfloat64m4_t, double, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vfsgnj_vf_m)))
vfloat64m4_t vfsgnj(vbool16_t, vfloat64m4_t, vfloat64m4_t, double, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vfsgnj_vf)))
vfloat64m8_t vfsgnj(vfloat64m8_t, double, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vfsgnj_vf_m)))
vfloat64m8_t vfsgnj(vbool8_t, vfloat64m8_t, vfloat64m8_t, double, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vfsgnjn_vv)))
vfloat64m1_t vfsgnjn(vfloat64m1_t, vfloat64m1_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vfsgnjn_vv_m)))
vfloat64m1_t vfsgnjn(vbool64_t, vfloat64m1_t, vfloat64m1_t, vfloat64m1_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vfsgnjn_vv)))
vfloat64m2_t vfsgnjn(vfloat64m2_t, vfloat64m2_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vfsgnjn_vv_m)))
vfloat64m2_t vfsgnjn(vbool32_t, vfloat64m2_t, vfloat64m2_t, vfloat64m2_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vfsgnjn_vv)))
vfloat64m4_t vfsgnjn(vfloat64m4_t, vfloat64m4_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vfsgnjn_vv_m)))
vfloat64m4_t vfsgnjn(vbool16_t, vfloat64m4_t, vfloat64m4_t, vfloat64m4_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vfsgnjn_vv)))
vfloat64m8_t vfsgnjn(vfloat64m8_t, vfloat64m8_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vfsgnjn_vv_m)))
vfloat64m8_t vfsgnjn(vbool8_t, vfloat64m8_t, vfloat64m8_t, vfloat64m8_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vfsgnjn_vf)))
vfloat64m1_t vfsgnjn(vfloat64m1_t, double, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vfsgnjn_vf_m)))
vfloat64m1_t vfsgnjn(vbool64_t, vfloat64m1_t, vfloat64m1_t, double, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vfsgnjn_vf)))
vfloat64m2_t vfsgnjn(vfloat64m2_t, double, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vfsgnjn_vf_m)))
vfloat64m2_t vfsgnjn(vbool32_t, vfloat64m2_t, vfloat64m2_t, double, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vfsgnjn_vf)))
vfloat64m4_t vfsgnjn(vfloat64m4_t, double, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vfsgnjn_vf_m)))
vfloat64m4_t vfsgnjn(vbool16_t, vfloat64m4_t, vfloat64m4_t, double, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vfsgnjn_vf)))
vfloat64m8_t vfsgnjn(vfloat64m8_t, double, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vfsgnjn_vf_m)))
vfloat64m8_t vfsgnjn(vbool8_t, vfloat64m8_t, vfloat64m8_t, double, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vfsgnjx_vv)))
vfloat64m1_t vfsgnjx(vfloat64m1_t, vfloat64m1_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vfsgnjx_vv_m)))
vfloat64m1_t vfsgnjx(vbool64_t, vfloat64m1_t, vfloat64m1_t, vfloat64m1_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vfsgnjx_vv)))
vfloat64m2_t vfsgnjx(vfloat64m2_t, vfloat64m2_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vfsgnjx_vv_m)))
vfloat64m2_t vfsgnjx(vbool32_t, vfloat64m2_t, vfloat64m2_t, vfloat64m2_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vfsgnjx_vv)))
vfloat64m4_t vfsgnjx(vfloat64m4_t, vfloat64m4_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vfsgnjx_vv_m)))
vfloat64m4_t vfsgnjx(vbool16_t, vfloat64m4_t, vfloat64m4_t, vfloat64m4_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vfsgnjx_vv)))
vfloat64m8_t vfsgnjx(vfloat64m8_t, vfloat64m8_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vfsgnjx_vv_m)))
vfloat64m8_t vfsgnjx(vbool8_t, vfloat64m8_t, vfloat64m8_t, vfloat64m8_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vfsgnjx_vf)))
vfloat64m1_t vfsgnjx(vfloat64m1_t, double, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vfsgnjx_vf_m)))
vfloat64m1_t vfsgnjx(vbool64_t, vfloat64m1_t, vfloat64m1_t, double, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vfsgnjx_vf)))
vfloat64m2_t vfsgnjx(vfloat64m2_t, double, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vfsgnjx_vf_m)))
vfloat64m2_t vfsgnjx(vbool32_t, vfloat64m2_t, vfloat64m2_t, double, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vfsgnjx_vf)))
vfloat64m4_t vfsgnjx(vfloat64m4_t, double, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vfsgnjx_vf_m)))
vfloat64m4_t vfsgnjx(vbool16_t, vfloat64m4_t, vfloat64m4_t, double, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vfsgnjx_vf)))
vfloat64m8_t vfsgnjx(vfloat64m8_t, double, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vfsgnjx_vf_m)))
vfloat64m8_t vfsgnjx(vbool8_t, vfloat64m8_t, vfloat64m8_t, double, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vfabs_v)))
vfloat64m1_t vfabs(vfloat64m1_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vfabs_v_m)))
vfloat64m1_t vfabs(vbool64_t, vfloat64m1_t, vfloat64m1_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vfabs_v)))
vfloat64m2_t vfabs(vfloat64m2_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vfabs_v_m)))
vfloat64m2_t vfabs(vbool32_t, vfloat64m2_t, vfloat64m2_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vfabs_v)))
vfloat64m4_t vfabs(vfloat64m4_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vfabs_v_m)))
vfloat64m4_t vfabs(vbool16_t, vfloat64m4_t, vfloat64m4_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vfabs_v)))
vfloat64m8_t vfabs(vfloat64m8_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vfabs_v_m)))
vfloat64m8_t vfabs(vbool8_t, vfloat64m8_t, vfloat64m8_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vmfeq_vv)))
vbool64_t vmfeq(vfloat64m1_t, vfloat64m1_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vmfeq_vv_m)))
vbool64_t vmfeq(vbool64_t, vbool64_t, vfloat64m1_t, vfloat64m1_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vmfeq_vv)))
vbool32_t vmfeq(vfloat64m2_t, vfloat64m2_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vmfeq_vv_m)))
vbool32_t vmfeq(vbool32_t, vbool32_t, vfloat64m2_t, vfloat64m2_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vmfeq_vv)))
vbool16_t vmfeq(vfloat64m4_t, vfloat64m4_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vmfeq_vv_m)))
vbool16_t vmfeq(vbool16_t, vbool16_t, vfloat64m4_t, vfloat64m4_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vmfeq_vv)))
vbool8_t vmfeq(vfloat64m8_t, vfloat64m8_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vmfeq_vv_m)))
vbool8_t vmfeq(vbool8_t, vbool8_t, vfloat64m8_t, vfloat64m8_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vmfeq_vf)))
vbool64_t vmfeq(vfloat64m1_t, double, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vmfeq_vf_m)))
vbool64_t vmfeq(vbool64_t, vbool64_t, vfloat64m1_t, double, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vmfeq_vf)))
vbool32_t vmfeq(vfloat64m2_t, double, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vmfeq_vf_m)))
vbool32_t vmfeq(vbool32_t, vbool32_t, vfloat64m2_t, double, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vmfeq_vf)))
vbool16_t vmfeq(vfloat64m4_t, double, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vmfeq_vf_m)))
vbool16_t vmfeq(vbool16_t, vbool16_t, vfloat64m4_t, double, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vmfeq_vf)))
vbool8_t vmfeq(vfloat64m8_t, double, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vmfeq_vf_m)))
vbool8_t vmfeq(vbool8_t, vbool8_t, vfloat64m8_t, double, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vmfne_vv)))
vbool64_t vmfne(vfloat64m1_t, vfloat64m1_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vmfne_vv_m)))
vbool64_t vmfne(vbool64_t, vbool64_t, vfloat64m1_t, vfloat64m1_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vmfne_vv)))
vbool32_t vmfne(vfloat64m2_t, vfloat64m2_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vmfne_vv_m)))
vbool32_t vmfne(vbool32_t, vbool32_t, vfloat64m2_t, vfloat64m2_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vmfne_vv)))
vbool16_t vmfne(vfloat64m4_t, vfloat64m4_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vmfne_vv_m)))
vbool16_t vmfne(vbool16_t, vbool16_t, vfloat64m4_t, vfloat64m4_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vmfne_vv)))
vbool8_t vmfne(vfloat64m8_t, vfloat64m8_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vmfne_vv_m)))
vbool8_t vmfne(vbool8_t, vbool8_t, vfloat64m8_t, vfloat64m8_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vmfne_vf)))
vbool64_t vmfne(vfloat64m1_t, double, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vmfne_vf_m)))
vbool64_t vmfne(vbool64_t, vbool64_t, vfloat64m1_t, double, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vmfne_vf)))
vbool32_t vmfne(vfloat64m2_t, double, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vmfne_vf_m)))
vbool32_t vmfne(vbool32_t, vbool32_t, vfloat64m2_t, double, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vmfne_vf)))
vbool16_t vmfne(vfloat64m4_t, double, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vmfne_vf_m)))
vbool16_t vmfne(vbool16_t, vbool16_t, vfloat64m4_t, double, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vmfne_vf)))
vbool8_t vmfne(vfloat64m8_t, double, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vmfne_vf_m)))
vbool8_t vmfne(vbool8_t, vbool8_t, vfloat64m8_t, double, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vmflt_vv)))
vbool64_t vmflt(vfloat64m1_t, vfloat64m1_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vmflt_vv_m)))
vbool64_t vmflt(vbool64_t, vbool64_t, vfloat64m1_t, vfloat64m1_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vmflt_vv)))
vbool32_t vmflt(vfloat64m2_t, vfloat64m2_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vmflt_vv_m)))
vbool32_t vmflt(vbool32_t, vbool32_t, vfloat64m2_t, vfloat64m2_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vmflt_vv)))
vbool16_t vmflt(vfloat64m4_t, vfloat64m4_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vmflt_vv_m)))
vbool16_t vmflt(vbool16_t, vbool16_t, vfloat64m4_t, vfloat64m4_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vmflt_vv)))
vbool8_t vmflt(vfloat64m8_t, vfloat64m8_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vmflt_vv_m)))
vbool8_t vmflt(vbool8_t, vbool8_t, vfloat64m8_t, vfloat64m8_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vmflt_vf)))
vbool64_t vmflt(vfloat64m1_t, double, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vmflt_vf_m)))
vbool64_t vmflt(vbool64_t, vbool64_t, vfloat64m1_t, double, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vmflt_vf)))
vbool32_t vmflt(vfloat64m2_t, double, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vmflt_vf_m)))
vbool32_t vmflt(vbool32_t, vbool32_t, vfloat64m2_t, double, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vmflt_vf)))
vbool16_t vmflt(vfloat64m4_t, double, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vmflt_vf_m)))
vbool16_t vmflt(vbool16_t, vbool16_t, vfloat64m4_t, double, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vmflt_vf)))
vbool8_t vmflt(vfloat64m8_t, double, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vmflt_vf_m)))
vbool8_t vmflt(vbool8_t, vbool8_t, vfloat64m8_t, double, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vmfle_vv)))
vbool64_t vmfle(vfloat64m1_t, vfloat64m1_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vmfle_vv_m)))
vbool64_t vmfle(vbool64_t, vbool64_t, vfloat64m1_t, vfloat64m1_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vmfle_vv)))
vbool32_t vmfle(vfloat64m2_t, vfloat64m2_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vmfle_vv_m)))
vbool32_t vmfle(vbool32_t, vbool32_t, vfloat64m2_t, vfloat64m2_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vmfle_vv)))
vbool16_t vmfle(vfloat64m4_t, vfloat64m4_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vmfle_vv_m)))
vbool16_t vmfle(vbool16_t, vbool16_t, vfloat64m4_t, vfloat64m4_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vmfle_vv)))
vbool8_t vmfle(vfloat64m8_t, vfloat64m8_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vmfle_vv_m)))
vbool8_t vmfle(vbool8_t, vbool8_t, vfloat64m8_t, vfloat64m8_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vmfle_vf)))
vbool64_t vmfle(vfloat64m1_t, double, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vmfle_vf_m)))
vbool64_t vmfle(vbool64_t, vbool64_t, vfloat64m1_t, double, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vmfle_vf)))
vbool32_t vmfle(vfloat64m2_t, double, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vmfle_vf_m)))
vbool32_t vmfle(vbool32_t, vbool32_t, vfloat64m2_t, double, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vmfle_vf)))
vbool16_t vmfle(vfloat64m4_t, double, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vmfle_vf_m)))
vbool16_t vmfle(vbool16_t, vbool16_t, vfloat64m4_t, double, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vmfle_vf)))
vbool8_t vmfle(vfloat64m8_t, double, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vmfle_vf_m)))
vbool8_t vmfle(vbool8_t, vbool8_t, vfloat64m8_t, double, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vmfgt_vv)))
vbool64_t vmfgt(vfloat64m1_t, vfloat64m1_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vmfgt_vv_m)))
vbool64_t vmfgt(vbool64_t, vbool64_t, vfloat64m1_t, vfloat64m1_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vmfgt_vv)))
vbool32_t vmfgt(vfloat64m2_t, vfloat64m2_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vmfgt_vv_m)))
vbool32_t vmfgt(vbool32_t, vbool32_t, vfloat64m2_t, vfloat64m2_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vmfgt_vv)))
vbool16_t vmfgt(vfloat64m4_t, vfloat64m4_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vmfgt_vv_m)))
vbool16_t vmfgt(vbool16_t, vbool16_t, vfloat64m4_t, vfloat64m4_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vmfgt_vv)))
vbool8_t vmfgt(vfloat64m8_t, vfloat64m8_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vmfgt_vv_m)))
vbool8_t vmfgt(vbool8_t, vbool8_t, vfloat64m8_t, vfloat64m8_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vmfgt_vf)))
vbool64_t vmfgt(vfloat64m1_t, double, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vmfgt_vf_m)))
vbool64_t vmfgt(vbool64_t, vbool64_t, vfloat64m1_t, double, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vmfgt_vf)))
vbool32_t vmfgt(vfloat64m2_t, double, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vmfgt_vf_m)))
vbool32_t vmfgt(vbool32_t, vbool32_t, vfloat64m2_t, double, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vmfgt_vf)))
vbool16_t vmfgt(vfloat64m4_t, double, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vmfgt_vf_m)))
vbool16_t vmfgt(vbool16_t, vbool16_t, vfloat64m4_t, double, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vmfgt_vf)))
vbool8_t vmfgt(vfloat64m8_t, double, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vmfgt_vf_m)))
vbool8_t vmfgt(vbool8_t, vbool8_t, vfloat64m8_t, double, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vmfge_vv)))
vbool64_t vmfge(vfloat64m1_t, vfloat64m1_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vmfge_vv_m)))
vbool64_t vmfge(vbool64_t, vbool64_t, vfloat64m1_t, vfloat64m1_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vmfge_vv)))
vbool32_t vmfge(vfloat64m2_t, vfloat64m2_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vmfge_vv_m)))
vbool32_t vmfge(vbool32_t, vbool32_t, vfloat64m2_t, vfloat64m2_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vmfge_vv)))
vbool16_t vmfge(vfloat64m4_t, vfloat64m4_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vmfge_vv_m)))
vbool16_t vmfge(vbool16_t, vbool16_t, vfloat64m4_t, vfloat64m4_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vmfge_vv)))
vbool8_t vmfge(vfloat64m8_t, vfloat64m8_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vmfge_vv_m)))
vbool8_t vmfge(vbool8_t, vbool8_t, vfloat64m8_t, vfloat64m8_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vmfge_vf)))
vbool64_t vmfge(vfloat64m1_t, double, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vmfge_vf_m)))
vbool64_t vmfge(vbool64_t, vbool64_t, vfloat64m1_t, double, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vmfge_vf)))
vbool32_t vmfge(vfloat64m2_t, double, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vmfge_vf_m)))
vbool32_t vmfge(vbool32_t, vbool32_t, vfloat64m2_t, double, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vmfge_vf)))
vbool16_t vmfge(vfloat64m4_t, double, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vmfge_vf_m)))
vbool16_t vmfge(vbool16_t, vbool16_t, vfloat64m4_t, double, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vmfge_vf)))
vbool8_t vmfge(vfloat64m8_t, double, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vmfge_vf_m)))
vbool8_t vmfge(vbool8_t, vbool8_t, vfloat64m8_t, double, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vmerge_vvm)))
vfloat64m1_t vmerge(vbool64_t, vfloat64m1_t, vfloat64m1_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vmerge_vvm)))
vfloat64m2_t vmerge(vbool32_t, vfloat64m2_t, vfloat64m2_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vmerge_vvm)))
vfloat64m4_t vmerge(vbool16_t, vfloat64m4_t, vfloat64m4_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vmerge_vvm)))
vfloat64m8_t vmerge(vbool8_t, vfloat64m8_t, vfloat64m8_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vfmerge_vfm)))
vfloat64m1_t vfmerge(vbool64_t, vfloat64m1_t, double, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vfmerge_vfm)))
vfloat64m2_t vfmerge(vbool32_t, vfloat64m2_t, double, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vfmerge_vfm)))
vfloat64m4_t vfmerge(vbool16_t, vfloat64m4_t, double, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vfmerge_vfm)))
vfloat64m8_t vfmerge(vbool8_t, vfloat64m8_t, double, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vfredmax_vs)))
vfloat64m1_t vfredmax(vfloat64m1_t, vfloat64m1_t, vfloat64m1_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vfredmax_vs_m)))
vfloat64m1_t vfredmax(vbool64_t, vfloat64m1_t, vfloat64m1_t, vfloat64m1_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vfredmax_vs)))
vfloat64m1_t vfredmax(vfloat64m1_t, vfloat64m2_t, vfloat64m1_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vfredmax_vs_m)))
vfloat64m1_t vfredmax(vbool32_t, vfloat64m1_t, vfloat64m2_t, vfloat64m1_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vfredmax_vs)))
vfloat64m1_t vfredmax(vfloat64m1_t, vfloat64m4_t, vfloat64m1_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vfredmax_vs_m)))
vfloat64m1_t vfredmax(vbool16_t, vfloat64m1_t, vfloat64m4_t, vfloat64m1_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vfredmax_vs)))
vfloat64m1_t vfredmax(vfloat64m1_t, vfloat64m8_t, vfloat64m1_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vfredmax_vs_m)))
vfloat64m1_t vfredmax(vbool8_t, vfloat64m1_t, vfloat64m8_t, vfloat64m1_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vfredmin_vs)))
vfloat64m1_t vfredmin(vfloat64m1_t, vfloat64m1_t, vfloat64m1_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vfredmin_vs_m)))
vfloat64m1_t vfredmin(vbool64_t, vfloat64m1_t, vfloat64m1_t, vfloat64m1_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vfredmin_vs)))
vfloat64m1_t vfredmin(vfloat64m1_t, vfloat64m2_t, vfloat64m1_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vfredmin_vs_m)))
vfloat64m1_t vfredmin(vbool32_t, vfloat64m1_t, vfloat64m2_t, vfloat64m1_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vfredmin_vs)))
vfloat64m1_t vfredmin(vfloat64m1_t, vfloat64m4_t, vfloat64m1_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vfredmin_vs_m)))
vfloat64m1_t vfredmin(vbool16_t, vfloat64m1_t, vfloat64m4_t, vfloat64m1_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vfredmin_vs)))
vfloat64m1_t vfredmin(vfloat64m1_t, vfloat64m8_t, vfloat64m1_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vfredmin_vs_m)))
vfloat64m1_t vfredmin(vbool8_t, vfloat64m1_t, vfloat64m8_t, vfloat64m1_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vfredusum_vs)))
vfloat64m1_t vfredusum(vfloat64m1_t, vfloat64m1_t, vfloat64m1_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vfredusum_vs_m)))
vfloat64m1_t vfredusum(vbool64_t, vfloat64m1_t, vfloat64m1_t, vfloat64m1_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vfredusum_vs)))
vfloat64m1_t vfredusum(vfloat64m1_t, vfloat64m2_t, vfloat64m1_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vfredusum_vs_m)))
vfloat64m1_t vfredusum(vbool32_t, vfloat64m1_t, vfloat64m2_t, vfloat64m1_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vfredusum_vs)))
vfloat64m1_t vfredusum(vfloat64m1_t, vfloat64m4_t, vfloat64m1_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vfredusum_vs_m)))
vfloat64m1_t vfredusum(vbool16_t, vfloat64m1_t, vfloat64m4_t, vfloat64m1_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vfredusum_vs)))
vfloat64m1_t vfredusum(vfloat64m1_t, vfloat64m8_t, vfloat64m1_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vfredusum_vs_m)))
vfloat64m1_t vfredusum(vbool8_t, vfloat64m1_t, vfloat64m8_t, vfloat64m1_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vfredosum_vs)))
vfloat64m1_t vfredosum(vfloat64m1_t, vfloat64m1_t, vfloat64m1_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vfredosum_vs_m)))
vfloat64m1_t vfredosum(vbool64_t, vfloat64m1_t, vfloat64m1_t, vfloat64m1_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vfredosum_vs)))
vfloat64m1_t vfredosum(vfloat64m1_t, vfloat64m2_t, vfloat64m1_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vfredosum_vs_m)))
vfloat64m1_t vfredosum(vbool32_t, vfloat64m1_t, vfloat64m2_t, vfloat64m1_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vfredosum_vs)))
vfloat64m1_t vfredosum(vfloat64m1_t, vfloat64m4_t, vfloat64m1_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vfredosum_vs_m)))
vfloat64m1_t vfredosum(vbool16_t, vfloat64m1_t, vfloat64m4_t, vfloat64m1_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vfredosum_vs)))
vfloat64m1_t vfredosum(vfloat64m1_t, vfloat64m8_t, vfloat64m1_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vfredosum_vs_m)))
vfloat64m1_t vfredosum(vbool8_t, vfloat64m1_t, vfloat64m8_t, vfloat64m1_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vfmv_f_s)))
double vfmv_f(vfloat64m1_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vfmv_f_s)))
double vfmv_f(vfloat64m2_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vfmv_f_s)))
double vfmv_f(vfloat64m4_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vfmv_f_s)))
double vfmv_f(vfloat64m8_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vfmv_s_f)))
vfloat64m1_t vfmv_s(vfloat64m1_t, double, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vfmv_s_f)))
vfloat64m2_t vfmv_s(vfloat64m2_t, double, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vfmv_s_f)))
vfloat64m4_t vfmv_s(vfloat64m4_t, double, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vfmv_s_f)))
vfloat64m8_t vfmv_s(vfloat64m8_t, double, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vslideup_vx)))
vfloat64m1_t vslideup(vfloat64m1_t, vfloat64m1_t, size_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vslideup_vx_m)))
vfloat64m1_t vslideup(vbool64_t, vfloat64m1_t, vfloat64m1_t, size_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vslideup_vx)))
vfloat64m2_t vslideup(vfloat64m2_t, vfloat64m2_t, size_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vslideup_vx_m)))
vfloat64m2_t vslideup(vbool32_t, vfloat64m2_t, vfloat64m2_t, size_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vslideup_vx)))
vfloat64m4_t vslideup(vfloat64m4_t, vfloat64m4_t, size_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vslideup_vx_m)))
vfloat64m4_t vslideup(vbool16_t, vfloat64m4_t, vfloat64m4_t, size_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vslideup_vx)))
vfloat64m8_t vslideup(vfloat64m8_t, vfloat64m8_t, size_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vslideup_vx_m)))
vfloat64m8_t vslideup(vbool8_t, vfloat64m8_t, vfloat64m8_t, size_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vslidedown_vx)))
vfloat64m1_t vslidedown(vfloat64m1_t, vfloat64m1_t, size_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vslidedown_vx_m)))
vfloat64m1_t vslidedown(vbool64_t, vfloat64m1_t, vfloat64m1_t, size_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vslidedown_vx)))
vfloat64m2_t vslidedown(vfloat64m2_t, vfloat64m2_t, size_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vslidedown_vx_m)))
vfloat64m2_t vslidedown(vbool32_t, vfloat64m2_t, vfloat64m2_t, size_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vslidedown_vx)))
vfloat64m4_t vslidedown(vfloat64m4_t, vfloat64m4_t, size_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vslidedown_vx_m)))
vfloat64m4_t vslidedown(vbool16_t, vfloat64m4_t, vfloat64m4_t, size_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vslidedown_vx)))
vfloat64m8_t vslidedown(vfloat64m8_t, vfloat64m8_t, size_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vslidedown_vx_m)))
vfloat64m8_t vslidedown(vbool8_t, vfloat64m8_t, vfloat64m8_t, size_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vfslide1up_vf)))
vfloat64m1_t vfslide1up(vfloat64m1_t, double, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vfslide1up_vf_m)))
vfloat64m1_t vfslide1up(vbool64_t, vfloat64m1_t, vfloat64m1_t, double, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vfslide1up_vf)))
vfloat64m2_t vfslide1up(vfloat64m2_t, double, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vfslide1up_vf_m)))
vfloat64m2_t vfslide1up(vbool32_t, vfloat64m2_t, vfloat64m2_t, double, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vfslide1up_vf)))
vfloat64m4_t vfslide1up(vfloat64m4_t, double, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vfslide1up_vf_m)))
vfloat64m4_t vfslide1up(vbool16_t, vfloat64m4_t, vfloat64m4_t, double, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vfslide1up_vf)))
vfloat64m8_t vfslide1up(vfloat64m8_t, double, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vfslide1up_vf_m)))
vfloat64m8_t vfslide1up(vbool8_t, vfloat64m8_t, vfloat64m8_t, double, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vfslide1down_vf)))
vfloat64m1_t vfslide1down(vfloat64m1_t, double, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vfslide1down_vf_m)))
vfloat64m1_t vfslide1down(vbool64_t, vfloat64m1_t, vfloat64m1_t, double, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vfslide1down_vf)))
vfloat64m2_t vfslide1down(vfloat64m2_t, double, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vfslide1down_vf_m)))
vfloat64m2_t vfslide1down(vbool32_t, vfloat64m2_t, vfloat64m2_t, double, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vfslide1down_vf)))
vfloat64m4_t vfslide1down(vfloat64m4_t, double, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vfslide1down_vf_m)))
vfloat64m4_t vfslide1down(vbool16_t, vfloat64m4_t, vfloat64m4_t, double, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vfslide1down_vf)))
vfloat64m8_t vfslide1down(vfloat64m8_t, double, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vfslide1down_vf_m)))
vfloat64m8_t vfslide1down(vbool8_t, vfloat64m8_t, vfloat64m8_t, double, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vrgather_vv)))
vfloat64m1_t vrgather(vfloat64m1_t, vuint64m1_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vrgather_vv_m)))
vfloat64m1_t vrgather(vbool64_t, vfloat64m1_t, vfloat64m1_t, vuint64m1_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vrgather_vv)))
vfloat64m2_t vrgather(vfloat64m2_t, vuint64m2_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vrgather_vv_m)))
vfloat64m2_t vrgather(vbool32_t, vfloat64m2_t, vfloat64m2_t, vuint64m2_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vrgather_vv)))
vfloat64m4_t vrgather(vfloat64m4_t, vuint64m4_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vrgather_vv_m)))
vfloat64m4_t vrgather(vbool16_t, vfloat64m4_t, vfloat64m4_t, vuint64m4_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vrgather_vv)))
vfloat64m8_t vrgather(vfloat64m8_t, vuint64m8_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vrgather_vv_m)))
vfloat64m8_t vrgather(vbool8_t, vfloat64m8_t, vfloat64m8_t, vuint64m8_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vrgather_vx)))
vfloat64m1_t vrgather(vfloat64m1_t, size_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vrgather_vx_m)))
vfloat64m1_t vrgather(vbool64_t, vfloat64m1_t, vfloat64m1_t, size_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vrgather_vx)))
vfloat64m2_t vrgather(vfloat64m2_t, size_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vrgather_vx_m)))
vfloat64m2_t vrgather(vbool32_t, vfloat64m2_t, vfloat64m2_t, size_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vrgather_vx)))
vfloat64m4_t vrgather(vfloat64m4_t, size_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vrgather_vx_m)))
vfloat64m4_t vrgather(vbool16_t, vfloat64m4_t, vfloat64m4_t, size_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vrgather_vx)))
vfloat64m8_t vrgather(vfloat64m8_t, size_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vrgather_vx_m)))
vfloat64m8_t vrgather(vbool8_t, vfloat64m8_t, vfloat64m8_t, size_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vrgatherei16_vv)))
vfloat64m1_t vrgatherei16(vfloat64m1_t, vuint16mf4_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vrgatherei16_vv_m)))
vfloat64m1_t vrgatherei16(vbool64_t, vfloat64m1_t, vfloat64m1_t, vuint16mf4_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vrgatherei16_vv)))
vfloat64m2_t vrgatherei16(vfloat64m2_t, vuint16mf2_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vrgatherei16_vv_m)))
vfloat64m2_t vrgatherei16(vbool32_t, vfloat64m2_t, vfloat64m2_t, vuint16mf2_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vrgatherei16_vv)))
vfloat64m4_t vrgatherei16(vfloat64m4_t, vuint16m1_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vrgatherei16_vv_m)))
vfloat64m4_t vrgatherei16(vbool16_t, vfloat64m4_t, vfloat64m4_t, vuint16m1_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vrgatherei16_vv)))
vfloat64m8_t vrgatherei16(vfloat64m8_t, vuint16m2_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vrgatherei16_vv_m)))
vfloat64m8_t vrgatherei16(vbool8_t, vfloat64m8_t, vfloat64m8_t, vuint16m2_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vcompress_vm)))
vfloat64m1_t vcompress(vbool64_t, vfloat64m1_t, vfloat64m1_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vcompress_vm)))
vfloat64m2_t vcompress(vbool32_t, vfloat64m2_t, vfloat64m2_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vcompress_vm)))
vfloat64m4_t vcompress(vbool16_t, vfloat64m4_t, vfloat64m4_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vcompress_vm)))
vfloat64m8_t vcompress(vbool8_t, vfloat64m8_t, vfloat64m8_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vget_v)))
vfloat64m1_t vget_f64m1(vfloat64m2_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vget_v)))
vfloat64m1_t vget_f64m1(vfloat64m4_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vget_v)))
vfloat64m1_t vget_f64m1(vfloat64m8_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vget_v)))
vfloat64m2_t vget_f64m2(vfloat64m4_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vget_v)))
vfloat64m2_t vget_f64m2(vfloat64m8_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vget_v)))
vfloat64m4_t vget_f64m4(vfloat64m8_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vset_v)))
vfloat64m2_t vset(vfloat64m2_t, size_t, vfloat64m1_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vset_v)))
vfloat64m4_t vset(vfloat64m4_t, size_t, vfloat64m1_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vset_v)))
vfloat64m4_t vset(vfloat64m4_t, size_t, vfloat64m2_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vset_v)))
vfloat64m8_t vset(vfloat64m8_t, size_t, vfloat64m1_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vset_v)))
vfloat64m8_t vset(vfloat64m8_t, size_t, vfloat64m2_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vset_v)))
vfloat64m8_t vset(vfloat64m8_t, size_t, vfloat64m4_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vsuxei8_v)))
void vsuxei8(double *, vuint8mf8_t, vfloat64m1_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vsuxei8_v_m)))
void vsuxei8(vbool64_t, double *, vuint8mf8_t, vfloat64m1_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vsuxei8_v)))
void vsuxei8(double *, vuint8mf4_t, vfloat64m2_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vsuxei8_v_m)))
void vsuxei8(vbool32_t, double *, vuint8mf4_t, vfloat64m2_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vsuxei8_v)))
void vsuxei8(double *, vuint8mf2_t, vfloat64m4_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vsuxei8_v_m)))
void vsuxei8(vbool16_t, double *, vuint8mf2_t, vfloat64m4_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vsuxei8_v)))
void vsuxei8(double *, vuint8m1_t, vfloat64m8_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vsuxei8_v_m)))
void vsuxei8(vbool8_t, double *, vuint8m1_t, vfloat64m8_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vsuxei16_v)))
void vsuxei16(double *, vuint16mf4_t, vfloat64m1_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vsuxei16_v_m)))
void vsuxei16(vbool64_t, double *, vuint16mf4_t, vfloat64m1_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vsuxei16_v)))
void vsuxei16(double *, vuint16mf2_t, vfloat64m2_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vsuxei16_v_m)))
void vsuxei16(vbool32_t, double *, vuint16mf2_t, vfloat64m2_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vsuxei16_v)))
void vsuxei16(double *, vuint16m1_t, vfloat64m4_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vsuxei16_v_m)))
void vsuxei16(vbool16_t, double *, vuint16m1_t, vfloat64m4_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vsuxei16_v)))
void vsuxei16(double *, vuint16m2_t, vfloat64m8_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vsuxei16_v_m)))
void vsuxei16(vbool8_t, double *, vuint16m2_t, vfloat64m8_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vsuxei32_v)))
void vsuxei32(double *, vuint32mf2_t, vfloat64m1_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vsuxei32_v_m)))
void vsuxei32(vbool64_t, double *, vuint32mf2_t, vfloat64m1_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vsuxei32_v)))
void vsuxei32(double *, vuint32m1_t, vfloat64m2_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vsuxei32_v_m)))
void vsuxei32(vbool32_t, double *, vuint32m1_t, vfloat64m2_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vsuxei32_v)))
void vsuxei32(double *, vuint32m2_t, vfloat64m4_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vsuxei32_v_m)))
void vsuxei32(vbool16_t, double *, vuint32m2_t, vfloat64m4_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vsuxei32_v)))
void vsuxei32(double *, vuint32m4_t, vfloat64m8_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vsuxei32_v_m)))
void vsuxei32(vbool8_t, double *, vuint32m4_t, vfloat64m8_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vsoxei8_v)))
void vsoxei8(double *, vuint8mf8_t, vfloat64m1_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vsoxei8_v_m)))
void vsoxei8(vbool64_t, double *, vuint8mf8_t, vfloat64m1_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vsoxei8_v)))
void vsoxei8(double *, vuint8mf4_t, vfloat64m2_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vsoxei8_v_m)))
void vsoxei8(vbool32_t, double *, vuint8mf4_t, vfloat64m2_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vsoxei8_v)))
void vsoxei8(double *, vuint8mf2_t, vfloat64m4_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vsoxei8_v_m)))
void vsoxei8(vbool16_t, double *, vuint8mf2_t, vfloat64m4_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vsoxei8_v)))
void vsoxei8(double *, vuint8m1_t, vfloat64m8_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vsoxei8_v_m)))
void vsoxei8(vbool8_t, double *, vuint8m1_t, vfloat64m8_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vsoxei16_v)))
void vsoxei16(double *, vuint16mf4_t, vfloat64m1_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vsoxei16_v_m)))
void vsoxei16(vbool64_t, double *, vuint16mf4_t, vfloat64m1_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vsoxei16_v)))
void vsoxei16(double *, vuint16mf2_t, vfloat64m2_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vsoxei16_v_m)))
void vsoxei16(vbool32_t, double *, vuint16mf2_t, vfloat64m2_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vsoxei16_v)))
void vsoxei16(double *, vuint16m1_t, vfloat64m4_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vsoxei16_v_m)))
void vsoxei16(vbool16_t, double *, vuint16m1_t, vfloat64m4_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vsoxei16_v)))
void vsoxei16(double *, vuint16m2_t, vfloat64m8_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vsoxei16_v_m)))
void vsoxei16(vbool8_t, double *, vuint16m2_t, vfloat64m8_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vsoxei32_v)))
void vsoxei32(double *, vuint32mf2_t, vfloat64m1_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vsoxei32_v_m)))
void vsoxei32(vbool64_t, double *, vuint32mf2_t, vfloat64m1_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vsoxei32_v)))
void vsoxei32(double *, vuint32m1_t, vfloat64m2_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vsoxei32_v_m)))
void vsoxei32(vbool32_t, double *, vuint32m1_t, vfloat64m2_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vsoxei32_v)))
void vsoxei32(double *, vuint32m2_t, vfloat64m4_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vsoxei32_v_m)))
void vsoxei32(vbool16_t, double *, vuint32m2_t, vfloat64m4_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vsoxei32_v)))
void vsoxei32(double *, vuint32m4_t, vfloat64m8_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vsoxei32_v_m)))
void vsoxei32(vbool8_t, double *, vuint32m4_t, vfloat64m8_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vle64ff_v_m)))
vfloat64m1_t vle64ff(vbool64_t, vfloat64m1_t, const double *, size_t *, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vle64ff_v_m)))
vfloat64m2_t vle64ff(vbool32_t, vfloat64m2_t, const double *, size_t *, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vle64ff_v_m)))
vfloat64m4_t vle64ff(vbool16_t, vfloat64m4_t, const double *, size_t *, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vle64ff_v_m)))
vfloat64m8_t vle64ff(vbool8_t, vfloat64m8_t, const double *, size_t *, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vlseg2e64_v_m)))
void vlseg2e64(vfloat64m1_t *, vfloat64m1_t *, vbool64_t, vfloat64m1_t, vfloat64m1_t, const double *, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vlseg2e64_v_m)))
void vlseg2e64(vfloat64m2_t *, vfloat64m2_t *, vbool32_t, vfloat64m2_t, vfloat64m2_t, const double *, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vlseg2e64_v_m)))
void vlseg2e64(vfloat64m4_t *, vfloat64m4_t *, vbool16_t, vfloat64m4_t, vfloat64m4_t, const double *, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vlseg3e64_v_m)))
void vlseg3e64(vfloat64m1_t *, vfloat64m1_t *, vfloat64m1_t *, vbool64_t, vfloat64m1_t, vfloat64m1_t, vfloat64m1_t, const double *, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vlseg3e64_v_m)))
void vlseg3e64(vfloat64m2_t *, vfloat64m2_t *, vfloat64m2_t *, vbool32_t, vfloat64m2_t, vfloat64m2_t, vfloat64m2_t, const double *, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vlseg4e64_v_m)))
void vlseg4e64(vfloat64m1_t *, vfloat64m1_t *, vfloat64m1_t *, vfloat64m1_t *, vbool64_t, vfloat64m1_t, vfloat64m1_t, vfloat64m1_t, vfloat64m1_t, const double *, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vlseg4e64_v_m)))
void vlseg4e64(vfloat64m2_t *, vfloat64m2_t *, vfloat64m2_t *, vfloat64m2_t *, vbool32_t, vfloat64m2_t, vfloat64m2_t, vfloat64m2_t, vfloat64m2_t, const double *, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vlseg5e64_v_m)))
void vlseg5e64(vfloat64m1_t *, vfloat64m1_t *, vfloat64m1_t *, vfloat64m1_t *, vfloat64m1_t *, vbool64_t, vfloat64m1_t, vfloat64m1_t, vfloat64m1_t, vfloat64m1_t, vfloat64m1_t, const double *, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vlseg6e64_v_m)))
void vlseg6e64(vfloat64m1_t *, vfloat64m1_t *, vfloat64m1_t *, vfloat64m1_t *, vfloat64m1_t *, vfloat64m1_t *, vbool64_t, vfloat64m1_t, vfloat64m1_t, vfloat64m1_t, vfloat64m1_t, vfloat64m1_t, vfloat64m1_t, const double *, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vlseg7e64_v_m)))
void vlseg7e64(vfloat64m1_t *, vfloat64m1_t *, vfloat64m1_t *, vfloat64m1_t *, vfloat64m1_t *, vfloat64m1_t *, vfloat64m1_t *, vbool64_t, vfloat64m1_t, vfloat64m1_t, vfloat64m1_t, vfloat64m1_t, vfloat64m1_t, vfloat64m1_t, vfloat64m1_t, const double *, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vlseg8e64_v_m)))
void vlseg8e64(vfloat64m1_t *, vfloat64m1_t *, vfloat64m1_t *, vfloat64m1_t *, vfloat64m1_t *, vfloat64m1_t *, vfloat64m1_t *, vfloat64m1_t *, vbool64_t, vfloat64m1_t, vfloat64m1_t, vfloat64m1_t, vfloat64m1_t, vfloat64m1_t, vfloat64m1_t, vfloat64m1_t, vfloat64m1_t, const double *, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vlseg2e64ff_v_m)))
void vlseg2e64ff(vfloat64m1_t *, vfloat64m1_t *, vbool64_t, vfloat64m1_t, vfloat64m1_t, const double *, size_t *, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vlseg2e64ff_v_m)))
void vlseg2e64ff(vfloat64m2_t *, vfloat64m2_t *, vbool32_t, vfloat64m2_t, vfloat64m2_t, const double *, size_t *, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vlseg2e64ff_v_m)))
void vlseg2e64ff(vfloat64m4_t *, vfloat64m4_t *, vbool16_t, vfloat64m4_t, vfloat64m4_t, const double *, size_t *, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vlseg3e64ff_v_m)))
void vlseg3e64ff(vfloat64m1_t *, vfloat64m1_t *, vfloat64m1_t *, vbool64_t, vfloat64m1_t, vfloat64m1_t, vfloat64m1_t, const double *, size_t *, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vlseg3e64ff_v_m)))
void vlseg3e64ff(vfloat64m2_t *, vfloat64m2_t *, vfloat64m2_t *, vbool32_t, vfloat64m2_t, vfloat64m2_t, vfloat64m2_t, const double *, size_t *, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vlseg4e64ff_v_m)))
void vlseg4e64ff(vfloat64m1_t *, vfloat64m1_t *, vfloat64m1_t *, vfloat64m1_t *, vbool64_t, vfloat64m1_t, vfloat64m1_t, vfloat64m1_t, vfloat64m1_t, const double *, size_t *, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vlseg4e64ff_v_m)))
void vlseg4e64ff(vfloat64m2_t *, vfloat64m2_t *, vfloat64m2_t *, vfloat64m2_t *, vbool32_t, vfloat64m2_t, vfloat64m2_t, vfloat64m2_t, vfloat64m2_t, const double *, size_t *, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vlseg5e64ff_v_m)))
void vlseg5e64ff(vfloat64m1_t *, vfloat64m1_t *, vfloat64m1_t *, vfloat64m1_t *, vfloat64m1_t *, vbool64_t, vfloat64m1_t, vfloat64m1_t, vfloat64m1_t, vfloat64m1_t, vfloat64m1_t, const double *, size_t *, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vlseg6e64ff_v_m)))
void vlseg6e64ff(vfloat64m1_t *, vfloat64m1_t *, vfloat64m1_t *, vfloat64m1_t *, vfloat64m1_t *, vfloat64m1_t *, vbool64_t, vfloat64m1_t, vfloat64m1_t, vfloat64m1_t, vfloat64m1_t, vfloat64m1_t, vfloat64m1_t, const double *, size_t *, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vlseg7e64ff_v_m)))
void vlseg7e64ff(vfloat64m1_t *, vfloat64m1_t *, vfloat64m1_t *, vfloat64m1_t *, vfloat64m1_t *, vfloat64m1_t *, vfloat64m1_t *, vbool64_t, vfloat64m1_t, vfloat64m1_t, vfloat64m1_t, vfloat64m1_t, vfloat64m1_t, vfloat64m1_t, vfloat64m1_t, const double *, size_t *, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vlseg8e64ff_v_m)))
void vlseg8e64ff(vfloat64m1_t *, vfloat64m1_t *, vfloat64m1_t *, vfloat64m1_t *, vfloat64m1_t *, vfloat64m1_t *, vfloat64m1_t *, vfloat64m1_t *, vbool64_t, vfloat64m1_t, vfloat64m1_t, vfloat64m1_t, vfloat64m1_t, vfloat64m1_t, vfloat64m1_t, vfloat64m1_t, vfloat64m1_t, const double *, size_t *, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vlsseg2e64_v_m)))
void vlsseg2e64(vfloat64m1_t *, vfloat64m1_t *, vbool64_t, vfloat64m1_t, vfloat64m1_t, const double *, ptrdiff_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vlsseg2e64_v_m)))
void vlsseg2e64(vfloat64m2_t *, vfloat64m2_t *, vbool32_t, vfloat64m2_t, vfloat64m2_t, const double *, ptrdiff_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vlsseg2e64_v_m)))
void vlsseg2e64(vfloat64m4_t *, vfloat64m4_t *, vbool16_t, vfloat64m4_t, vfloat64m4_t, const double *, ptrdiff_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vlsseg3e64_v_m)))
void vlsseg3e64(vfloat64m1_t *, vfloat64m1_t *, vfloat64m1_t *, vbool64_t, vfloat64m1_t, vfloat64m1_t, vfloat64m1_t, const double *, ptrdiff_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vlsseg3e64_v_m)))
void vlsseg3e64(vfloat64m2_t *, vfloat64m2_t *, vfloat64m2_t *, vbool32_t, vfloat64m2_t, vfloat64m2_t, vfloat64m2_t, const double *, ptrdiff_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vlsseg4e64_v_m)))
void vlsseg4e64(vfloat64m1_t *, vfloat64m1_t *, vfloat64m1_t *, vfloat64m1_t *, vbool64_t, vfloat64m1_t, vfloat64m1_t, vfloat64m1_t, vfloat64m1_t, const double *, ptrdiff_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vlsseg4e64_v_m)))
void vlsseg4e64(vfloat64m2_t *, vfloat64m2_t *, vfloat64m2_t *, vfloat64m2_t *, vbool32_t, vfloat64m2_t, vfloat64m2_t, vfloat64m2_t, vfloat64m2_t, const double *, ptrdiff_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vlsseg5e64_v_m)))
void vlsseg5e64(vfloat64m1_t *, vfloat64m1_t *, vfloat64m1_t *, vfloat64m1_t *, vfloat64m1_t *, vbool64_t, vfloat64m1_t, vfloat64m1_t, vfloat64m1_t, vfloat64m1_t, vfloat64m1_t, const double *, ptrdiff_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vlsseg6e64_v_m)))
void vlsseg6e64(vfloat64m1_t *, vfloat64m1_t *, vfloat64m1_t *, vfloat64m1_t *, vfloat64m1_t *, vfloat64m1_t *, vbool64_t, vfloat64m1_t, vfloat64m1_t, vfloat64m1_t, vfloat64m1_t, vfloat64m1_t, vfloat64m1_t, const double *, ptrdiff_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vlsseg7e64_v_m)))
void vlsseg7e64(vfloat64m1_t *, vfloat64m1_t *, vfloat64m1_t *, vfloat64m1_t *, vfloat64m1_t *, vfloat64m1_t *, vfloat64m1_t *, vbool64_t, vfloat64m1_t, vfloat64m1_t, vfloat64m1_t, vfloat64m1_t, vfloat64m1_t, vfloat64m1_t, vfloat64m1_t, const double *, ptrdiff_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vlsseg8e64_v_m)))
void vlsseg8e64(vfloat64m1_t *, vfloat64m1_t *, vfloat64m1_t *, vfloat64m1_t *, vfloat64m1_t *, vfloat64m1_t *, vfloat64m1_t *, vfloat64m1_t *, vbool64_t, vfloat64m1_t, vfloat64m1_t, vfloat64m1_t, vfloat64m1_t, vfloat64m1_t, vfloat64m1_t, vfloat64m1_t, vfloat64m1_t, const double *, ptrdiff_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vfneg_v)))
vfloat64m1_t vfneg(vfloat64m1_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vfneg_v_m)))
vfloat64m1_t vfneg(vbool64_t, vfloat64m1_t, vfloat64m1_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vfneg_v)))
vfloat64m2_t vfneg(vfloat64m2_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vfneg_v_m)))
vfloat64m2_t vfneg(vbool32_t, vfloat64m2_t, vfloat64m2_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vfneg_v)))
vfloat64m4_t vfneg(vfloat64m4_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vfneg_v_m)))
vfloat64m4_t vfneg(vbool16_t, vfloat64m4_t, vfloat64m4_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vfneg_v)))
vfloat64m8_t vfneg(vfloat64m8_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vfneg_v_m)))
vfloat64m8_t vfneg(vbool8_t, vfloat64m8_t, vfloat64m8_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vluxseg2ei8_v)))
void vluxseg2ei8(vfloat64m1_t *, vfloat64m1_t *, const double *, vuint8mf8_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vluxseg2ei8_v_m)))
void vluxseg2ei8(vfloat64m1_t *, vfloat64m1_t *, vbool64_t, vfloat64m1_t, vfloat64m1_t, const double *, vuint8mf8_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vluxseg2ei8_v)))
void vluxseg2ei8(vfloat64m2_t *, vfloat64m2_t *, const double *, vuint8mf4_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vluxseg2ei8_v_m)))
void vluxseg2ei8(vfloat64m2_t *, vfloat64m2_t *, vbool32_t, vfloat64m2_t, vfloat64m2_t, const double *, vuint8mf4_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vluxseg2ei8_v)))
void vluxseg2ei8(vfloat64m4_t *, vfloat64m4_t *, const double *, vuint8mf2_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vluxseg2ei8_v_m)))
void vluxseg2ei8(vfloat64m4_t *, vfloat64m4_t *, vbool16_t, vfloat64m4_t, vfloat64m4_t, const double *, vuint8mf2_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vluxseg3ei8_v)))
void vluxseg3ei8(vfloat64m1_t *, vfloat64m1_t *, vfloat64m1_t *, const double *, vuint8mf8_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vluxseg3ei8_v_m)))
void vluxseg3ei8(vfloat64m1_t *, vfloat64m1_t *, vfloat64m1_t *, vbool64_t, vfloat64m1_t, vfloat64m1_t, vfloat64m1_t, const double *, vuint8mf8_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vluxseg3ei8_v)))
void vluxseg3ei8(vfloat64m2_t *, vfloat64m2_t *, vfloat64m2_t *, const double *, vuint8mf4_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vluxseg3ei8_v_m)))
void vluxseg3ei8(vfloat64m2_t *, vfloat64m2_t *, vfloat64m2_t *, vbool32_t, vfloat64m2_t, vfloat64m2_t, vfloat64m2_t, const double *, vuint8mf4_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vluxseg4ei8_v)))
void vluxseg4ei8(vfloat64m1_t *, vfloat64m1_t *, vfloat64m1_t *, vfloat64m1_t *, const double *, vuint8mf8_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vluxseg4ei8_v_m)))
void vluxseg4ei8(vfloat64m1_t *, vfloat64m1_t *, vfloat64m1_t *, vfloat64m1_t *, vbool64_t, vfloat64m1_t, vfloat64m1_t, vfloat64m1_t, vfloat64m1_t, const double *, vuint8mf8_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vluxseg4ei8_v)))
void vluxseg4ei8(vfloat64m2_t *, vfloat64m2_t *, vfloat64m2_t *, vfloat64m2_t *, const double *, vuint8mf4_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vluxseg4ei8_v_m)))
void vluxseg4ei8(vfloat64m2_t *, vfloat64m2_t *, vfloat64m2_t *, vfloat64m2_t *, vbool32_t, vfloat64m2_t, vfloat64m2_t, vfloat64m2_t, vfloat64m2_t, const double *, vuint8mf4_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vluxseg5ei8_v)))
void vluxseg5ei8(vfloat64m1_t *, vfloat64m1_t *, vfloat64m1_t *, vfloat64m1_t *, vfloat64m1_t *, const double *, vuint8mf8_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vluxseg5ei8_v_m)))
void vluxseg5ei8(vfloat64m1_t *, vfloat64m1_t *, vfloat64m1_t *, vfloat64m1_t *, vfloat64m1_t *, vbool64_t, vfloat64m1_t, vfloat64m1_t, vfloat64m1_t, vfloat64m1_t, vfloat64m1_t, const double *, vuint8mf8_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vluxseg6ei8_v)))
void vluxseg6ei8(vfloat64m1_t *, vfloat64m1_t *, vfloat64m1_t *, vfloat64m1_t *, vfloat64m1_t *, vfloat64m1_t *, const double *, vuint8mf8_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vluxseg6ei8_v_m)))
void vluxseg6ei8(vfloat64m1_t *, vfloat64m1_t *, vfloat64m1_t *, vfloat64m1_t *, vfloat64m1_t *, vfloat64m1_t *, vbool64_t, vfloat64m1_t, vfloat64m1_t, vfloat64m1_t, vfloat64m1_t, vfloat64m1_t, vfloat64m1_t, const double *, vuint8mf8_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vluxseg7ei8_v)))
void vluxseg7ei8(vfloat64m1_t *, vfloat64m1_t *, vfloat64m1_t *, vfloat64m1_t *, vfloat64m1_t *, vfloat64m1_t *, vfloat64m1_t *, const double *, vuint8mf8_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vluxseg7ei8_v_m)))
void vluxseg7ei8(vfloat64m1_t *, vfloat64m1_t *, vfloat64m1_t *, vfloat64m1_t *, vfloat64m1_t *, vfloat64m1_t *, vfloat64m1_t *, vbool64_t, vfloat64m1_t, vfloat64m1_t, vfloat64m1_t, vfloat64m1_t, vfloat64m1_t, vfloat64m1_t, vfloat64m1_t, const double *, vuint8mf8_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vluxseg8ei8_v)))
void vluxseg8ei8(vfloat64m1_t *, vfloat64m1_t *, vfloat64m1_t *, vfloat64m1_t *, vfloat64m1_t *, vfloat64m1_t *, vfloat64m1_t *, vfloat64m1_t *, const double *, vuint8mf8_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vluxseg8ei8_v_m)))
void vluxseg8ei8(vfloat64m1_t *, vfloat64m1_t *, vfloat64m1_t *, vfloat64m1_t *, vfloat64m1_t *, vfloat64m1_t *, vfloat64m1_t *, vfloat64m1_t *, vbool64_t, vfloat64m1_t, vfloat64m1_t, vfloat64m1_t, vfloat64m1_t, vfloat64m1_t, vfloat64m1_t, vfloat64m1_t, vfloat64m1_t, const double *, vuint8mf8_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vluxseg2ei16_v)))
void vluxseg2ei16(vfloat64m1_t *, vfloat64m1_t *, const double *, vuint16mf4_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vluxseg2ei16_v_m)))
void vluxseg2ei16(vfloat64m1_t *, vfloat64m1_t *, vbool64_t, vfloat64m1_t, vfloat64m1_t, const double *, vuint16mf4_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vluxseg2ei16_v)))
void vluxseg2ei16(vfloat64m2_t *, vfloat64m2_t *, const double *, vuint16mf2_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vluxseg2ei16_v_m)))
void vluxseg2ei16(vfloat64m2_t *, vfloat64m2_t *, vbool32_t, vfloat64m2_t, vfloat64m2_t, const double *, vuint16mf2_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vluxseg2ei16_v)))
void vluxseg2ei16(vfloat64m4_t *, vfloat64m4_t *, const double *, vuint16m1_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vluxseg2ei16_v_m)))
void vluxseg2ei16(vfloat64m4_t *, vfloat64m4_t *, vbool16_t, vfloat64m4_t, vfloat64m4_t, const double *, vuint16m1_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vluxseg3ei16_v)))
void vluxseg3ei16(vfloat64m1_t *, vfloat64m1_t *, vfloat64m1_t *, const double *, vuint16mf4_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vluxseg3ei16_v_m)))
void vluxseg3ei16(vfloat64m1_t *, vfloat64m1_t *, vfloat64m1_t *, vbool64_t, vfloat64m1_t, vfloat64m1_t, vfloat64m1_t, const double *, vuint16mf4_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vluxseg3ei16_v)))
void vluxseg3ei16(vfloat64m2_t *, vfloat64m2_t *, vfloat64m2_t *, const double *, vuint16mf2_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vluxseg3ei16_v_m)))
void vluxseg3ei16(vfloat64m2_t *, vfloat64m2_t *, vfloat64m2_t *, vbool32_t, vfloat64m2_t, vfloat64m2_t, vfloat64m2_t, const double *, vuint16mf2_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vluxseg4ei16_v)))
void vluxseg4ei16(vfloat64m1_t *, vfloat64m1_t *, vfloat64m1_t *, vfloat64m1_t *, const double *, vuint16mf4_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vluxseg4ei16_v_m)))
void vluxseg4ei16(vfloat64m1_t *, vfloat64m1_t *, vfloat64m1_t *, vfloat64m1_t *, vbool64_t, vfloat64m1_t, vfloat64m1_t, vfloat64m1_t, vfloat64m1_t, const double *, vuint16mf4_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vluxseg4ei16_v)))
void vluxseg4ei16(vfloat64m2_t *, vfloat64m2_t *, vfloat64m2_t *, vfloat64m2_t *, const double *, vuint16mf2_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vluxseg4ei16_v_m)))
void vluxseg4ei16(vfloat64m2_t *, vfloat64m2_t *, vfloat64m2_t *, vfloat64m2_t *, vbool32_t, vfloat64m2_t, vfloat64m2_t, vfloat64m2_t, vfloat64m2_t, const double *, vuint16mf2_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vluxseg5ei16_v)))
void vluxseg5ei16(vfloat64m1_t *, vfloat64m1_t *, vfloat64m1_t *, vfloat64m1_t *, vfloat64m1_t *, const double *, vuint16mf4_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vluxseg5ei16_v_m)))
void vluxseg5ei16(vfloat64m1_t *, vfloat64m1_t *, vfloat64m1_t *, vfloat64m1_t *, vfloat64m1_t *, vbool64_t, vfloat64m1_t, vfloat64m1_t, vfloat64m1_t, vfloat64m1_t, vfloat64m1_t, const double *, vuint16mf4_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vluxseg6ei16_v)))
void vluxseg6ei16(vfloat64m1_t *, vfloat64m1_t *, vfloat64m1_t *, vfloat64m1_t *, vfloat64m1_t *, vfloat64m1_t *, const double *, vuint16mf4_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vluxseg6ei16_v_m)))
void vluxseg6ei16(vfloat64m1_t *, vfloat64m1_t *, vfloat64m1_t *, vfloat64m1_t *, vfloat64m1_t *, vfloat64m1_t *, vbool64_t, vfloat64m1_t, vfloat64m1_t, vfloat64m1_t, vfloat64m1_t, vfloat64m1_t, vfloat64m1_t, const double *, vuint16mf4_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vluxseg7ei16_v)))
void vluxseg7ei16(vfloat64m1_t *, vfloat64m1_t *, vfloat64m1_t *, vfloat64m1_t *, vfloat64m1_t *, vfloat64m1_t *, vfloat64m1_t *, const double *, vuint16mf4_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vluxseg7ei16_v_m)))
void vluxseg7ei16(vfloat64m1_t *, vfloat64m1_t *, vfloat64m1_t *, vfloat64m1_t *, vfloat64m1_t *, vfloat64m1_t *, vfloat64m1_t *, vbool64_t, vfloat64m1_t, vfloat64m1_t, vfloat64m1_t, vfloat64m1_t, vfloat64m1_t, vfloat64m1_t, vfloat64m1_t, const double *, vuint16mf4_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vluxseg8ei16_v)))
void vluxseg8ei16(vfloat64m1_t *, vfloat64m1_t *, vfloat64m1_t *, vfloat64m1_t *, vfloat64m1_t *, vfloat64m1_t *, vfloat64m1_t *, vfloat64m1_t *, const double *, vuint16mf4_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vluxseg8ei16_v_m)))
void vluxseg8ei16(vfloat64m1_t *, vfloat64m1_t *, vfloat64m1_t *, vfloat64m1_t *, vfloat64m1_t *, vfloat64m1_t *, vfloat64m1_t *, vfloat64m1_t *, vbool64_t, vfloat64m1_t, vfloat64m1_t, vfloat64m1_t, vfloat64m1_t, vfloat64m1_t, vfloat64m1_t, vfloat64m1_t, vfloat64m1_t, const double *, vuint16mf4_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vluxseg2ei32_v)))
void vluxseg2ei32(vfloat64m1_t *, vfloat64m1_t *, const double *, vuint32mf2_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vluxseg2ei32_v_m)))
void vluxseg2ei32(vfloat64m1_t *, vfloat64m1_t *, vbool64_t, vfloat64m1_t, vfloat64m1_t, const double *, vuint32mf2_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vluxseg2ei32_v)))
void vluxseg2ei32(vfloat64m2_t *, vfloat64m2_t *, const double *, vuint32m1_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vluxseg2ei32_v_m)))
void vluxseg2ei32(vfloat64m2_t *, vfloat64m2_t *, vbool32_t, vfloat64m2_t, vfloat64m2_t, const double *, vuint32m1_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vluxseg2ei32_v)))
void vluxseg2ei32(vfloat64m4_t *, vfloat64m4_t *, const double *, vuint32m2_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vluxseg2ei32_v_m)))
void vluxseg2ei32(vfloat64m4_t *, vfloat64m4_t *, vbool16_t, vfloat64m4_t, vfloat64m4_t, const double *, vuint32m2_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vluxseg3ei32_v)))
void vluxseg3ei32(vfloat64m1_t *, vfloat64m1_t *, vfloat64m1_t *, const double *, vuint32mf2_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vluxseg3ei32_v_m)))
void vluxseg3ei32(vfloat64m1_t *, vfloat64m1_t *, vfloat64m1_t *, vbool64_t, vfloat64m1_t, vfloat64m1_t, vfloat64m1_t, const double *, vuint32mf2_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vluxseg3ei32_v)))
void vluxseg3ei32(vfloat64m2_t *, vfloat64m2_t *, vfloat64m2_t *, const double *, vuint32m1_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vluxseg3ei32_v_m)))
void vluxseg3ei32(vfloat64m2_t *, vfloat64m2_t *, vfloat64m2_t *, vbool32_t, vfloat64m2_t, vfloat64m2_t, vfloat64m2_t, const double *, vuint32m1_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vluxseg4ei32_v)))
void vluxseg4ei32(vfloat64m1_t *, vfloat64m1_t *, vfloat64m1_t *, vfloat64m1_t *, const double *, vuint32mf2_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vluxseg4ei32_v_m)))
void vluxseg4ei32(vfloat64m1_t *, vfloat64m1_t *, vfloat64m1_t *, vfloat64m1_t *, vbool64_t, vfloat64m1_t, vfloat64m1_t, vfloat64m1_t, vfloat64m1_t, const double *, vuint32mf2_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vluxseg4ei32_v)))
void vluxseg4ei32(vfloat64m2_t *, vfloat64m2_t *, vfloat64m2_t *, vfloat64m2_t *, const double *, vuint32m1_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vluxseg4ei32_v_m)))
void vluxseg4ei32(vfloat64m2_t *, vfloat64m2_t *, vfloat64m2_t *, vfloat64m2_t *, vbool32_t, vfloat64m2_t, vfloat64m2_t, vfloat64m2_t, vfloat64m2_t, const double *, vuint32m1_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vluxseg5ei32_v)))
void vluxseg5ei32(vfloat64m1_t *, vfloat64m1_t *, vfloat64m1_t *, vfloat64m1_t *, vfloat64m1_t *, const double *, vuint32mf2_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vluxseg5ei32_v_m)))
void vluxseg5ei32(vfloat64m1_t *, vfloat64m1_t *, vfloat64m1_t *, vfloat64m1_t *, vfloat64m1_t *, vbool64_t, vfloat64m1_t, vfloat64m1_t, vfloat64m1_t, vfloat64m1_t, vfloat64m1_t, const double *, vuint32mf2_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vluxseg6ei32_v)))
void vluxseg6ei32(vfloat64m1_t *, vfloat64m1_t *, vfloat64m1_t *, vfloat64m1_t *, vfloat64m1_t *, vfloat64m1_t *, const double *, vuint32mf2_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vluxseg6ei32_v_m)))
void vluxseg6ei32(vfloat64m1_t *, vfloat64m1_t *, vfloat64m1_t *, vfloat64m1_t *, vfloat64m1_t *, vfloat64m1_t *, vbool64_t, vfloat64m1_t, vfloat64m1_t, vfloat64m1_t, vfloat64m1_t, vfloat64m1_t, vfloat64m1_t, const double *, vuint32mf2_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vluxseg7ei32_v)))
void vluxseg7ei32(vfloat64m1_t *, vfloat64m1_t *, vfloat64m1_t *, vfloat64m1_t *, vfloat64m1_t *, vfloat64m1_t *, vfloat64m1_t *, const double *, vuint32mf2_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vluxseg7ei32_v_m)))
void vluxseg7ei32(vfloat64m1_t *, vfloat64m1_t *, vfloat64m1_t *, vfloat64m1_t *, vfloat64m1_t *, vfloat64m1_t *, vfloat64m1_t *, vbool64_t, vfloat64m1_t, vfloat64m1_t, vfloat64m1_t, vfloat64m1_t, vfloat64m1_t, vfloat64m1_t, vfloat64m1_t, const double *, vuint32mf2_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vluxseg8ei32_v)))
void vluxseg8ei32(vfloat64m1_t *, vfloat64m1_t *, vfloat64m1_t *, vfloat64m1_t *, vfloat64m1_t *, vfloat64m1_t *, vfloat64m1_t *, vfloat64m1_t *, const double *, vuint32mf2_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vluxseg8ei32_v_m)))
void vluxseg8ei32(vfloat64m1_t *, vfloat64m1_t *, vfloat64m1_t *, vfloat64m1_t *, vfloat64m1_t *, vfloat64m1_t *, vfloat64m1_t *, vfloat64m1_t *, vbool64_t, vfloat64m1_t, vfloat64m1_t, vfloat64m1_t, vfloat64m1_t, vfloat64m1_t, vfloat64m1_t, vfloat64m1_t, vfloat64m1_t, const double *, vuint32mf2_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vluxseg2ei64_v)))
void vluxseg2ei64(vfloat64m1_t *, vfloat64m1_t *, const double *, vuint64m1_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vluxseg2ei64_v_m)))
void vluxseg2ei64(vfloat64m1_t *, vfloat64m1_t *, vbool64_t, vfloat64m1_t, vfloat64m1_t, const double *, vuint64m1_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vluxseg2ei64_v)))
void vluxseg2ei64(vfloat64m2_t *, vfloat64m2_t *, const double *, vuint64m2_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vluxseg2ei64_v_m)))
void vluxseg2ei64(vfloat64m2_t *, vfloat64m2_t *, vbool32_t, vfloat64m2_t, vfloat64m2_t, const double *, vuint64m2_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vluxseg2ei64_v)))
void vluxseg2ei64(vfloat64m4_t *, vfloat64m4_t *, const double *, vuint64m4_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vluxseg2ei64_v_m)))
void vluxseg2ei64(vfloat64m4_t *, vfloat64m4_t *, vbool16_t, vfloat64m4_t, vfloat64m4_t, const double *, vuint64m4_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vluxseg3ei64_v)))
void vluxseg3ei64(vfloat64m1_t *, vfloat64m1_t *, vfloat64m1_t *, const double *, vuint64m1_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vluxseg3ei64_v_m)))
void vluxseg3ei64(vfloat64m1_t *, vfloat64m1_t *, vfloat64m1_t *, vbool64_t, vfloat64m1_t, vfloat64m1_t, vfloat64m1_t, const double *, vuint64m1_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vluxseg3ei64_v)))
void vluxseg3ei64(vfloat64m2_t *, vfloat64m2_t *, vfloat64m2_t *, const double *, vuint64m2_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vluxseg3ei64_v_m)))
void vluxseg3ei64(vfloat64m2_t *, vfloat64m2_t *, vfloat64m2_t *, vbool32_t, vfloat64m2_t, vfloat64m2_t, vfloat64m2_t, const double *, vuint64m2_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vluxseg4ei64_v)))
void vluxseg4ei64(vfloat64m1_t *, vfloat64m1_t *, vfloat64m1_t *, vfloat64m1_t *, const double *, vuint64m1_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vluxseg4ei64_v_m)))
void vluxseg4ei64(vfloat64m1_t *, vfloat64m1_t *, vfloat64m1_t *, vfloat64m1_t *, vbool64_t, vfloat64m1_t, vfloat64m1_t, vfloat64m1_t, vfloat64m1_t, const double *, vuint64m1_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vluxseg4ei64_v)))
void vluxseg4ei64(vfloat64m2_t *, vfloat64m2_t *, vfloat64m2_t *, vfloat64m2_t *, const double *, vuint64m2_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vluxseg4ei64_v_m)))
void vluxseg4ei64(vfloat64m2_t *, vfloat64m2_t *, vfloat64m2_t *, vfloat64m2_t *, vbool32_t, vfloat64m2_t, vfloat64m2_t, vfloat64m2_t, vfloat64m2_t, const double *, vuint64m2_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vluxseg5ei64_v)))
void vluxseg5ei64(vfloat64m1_t *, vfloat64m1_t *, vfloat64m1_t *, vfloat64m1_t *, vfloat64m1_t *, const double *, vuint64m1_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vluxseg5ei64_v_m)))
void vluxseg5ei64(vfloat64m1_t *, vfloat64m1_t *, vfloat64m1_t *, vfloat64m1_t *, vfloat64m1_t *, vbool64_t, vfloat64m1_t, vfloat64m1_t, vfloat64m1_t, vfloat64m1_t, vfloat64m1_t, const double *, vuint64m1_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vluxseg6ei64_v)))
void vluxseg6ei64(vfloat64m1_t *, vfloat64m1_t *, vfloat64m1_t *, vfloat64m1_t *, vfloat64m1_t *, vfloat64m1_t *, const double *, vuint64m1_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vluxseg6ei64_v_m)))
void vluxseg6ei64(vfloat64m1_t *, vfloat64m1_t *, vfloat64m1_t *, vfloat64m1_t *, vfloat64m1_t *, vfloat64m1_t *, vbool64_t, vfloat64m1_t, vfloat64m1_t, vfloat64m1_t, vfloat64m1_t, vfloat64m1_t, vfloat64m1_t, const double *, vuint64m1_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vluxseg7ei64_v)))
void vluxseg7ei64(vfloat64m1_t *, vfloat64m1_t *, vfloat64m1_t *, vfloat64m1_t *, vfloat64m1_t *, vfloat64m1_t *, vfloat64m1_t *, const double *, vuint64m1_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vluxseg7ei64_v_m)))
void vluxseg7ei64(vfloat64m1_t *, vfloat64m1_t *, vfloat64m1_t *, vfloat64m1_t *, vfloat64m1_t *, vfloat64m1_t *, vfloat64m1_t *, vbool64_t, vfloat64m1_t, vfloat64m1_t, vfloat64m1_t, vfloat64m1_t, vfloat64m1_t, vfloat64m1_t, vfloat64m1_t, const double *, vuint64m1_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vluxseg8ei64_v)))
void vluxseg8ei64(vfloat64m1_t *, vfloat64m1_t *, vfloat64m1_t *, vfloat64m1_t *, vfloat64m1_t *, vfloat64m1_t *, vfloat64m1_t *, vfloat64m1_t *, const double *, vuint64m1_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vluxseg8ei64_v_m)))
void vluxseg8ei64(vfloat64m1_t *, vfloat64m1_t *, vfloat64m1_t *, vfloat64m1_t *, vfloat64m1_t *, vfloat64m1_t *, vfloat64m1_t *, vfloat64m1_t *, vbool64_t, vfloat64m1_t, vfloat64m1_t, vfloat64m1_t, vfloat64m1_t, vfloat64m1_t, vfloat64m1_t, vfloat64m1_t, vfloat64m1_t, const double *, vuint64m1_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vle64_v_m)))
vfloat64m1_t vle64(vbool64_t, vfloat64m1_t, const double *, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vle64_v_m)))
vfloat64m2_t vle64(vbool32_t, vfloat64m2_t, const double *, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vle64_v_m)))
vfloat64m4_t vle64(vbool16_t, vfloat64m4_t, const double *, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vle64_v_m)))
vfloat64m8_t vle64(vbool8_t, vfloat64m8_t, const double *, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vse64_v)))
void vse64(double *, vfloat64m1_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vse64_v_m)))
void vse64(vbool64_t, double *, vfloat64m1_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vse64_v)))
void vse64(double *, vfloat64m2_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vse64_v_m)))
void vse64(vbool32_t, double *, vfloat64m2_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vse64_v)))
void vse64(double *, vfloat64m4_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vse64_v_m)))
void vse64(vbool16_t, double *, vfloat64m4_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vse64_v)))
void vse64(double *, vfloat64m8_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vse64_v_m)))
void vse64(vbool8_t, double *, vfloat64m8_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vfclass_v)))
vuint64m1_t vfclass(vfloat64m1_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vfclass_v_m)))
vuint64m1_t vfclass(vbool64_t, vuint64m1_t, vfloat64m1_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vfclass_v)))
vuint64m2_t vfclass(vfloat64m2_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vfclass_v_m)))
vuint64m2_t vfclass(vbool32_t, vuint64m2_t, vfloat64m2_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vfclass_v)))
vuint64m4_t vfclass(vfloat64m4_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vfclass_v_m)))
vuint64m4_t vfclass(vbool16_t, vuint64m4_t, vfloat64m4_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vfclass_v)))
vuint64m8_t vfclass(vfloat64m8_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vfclass_v_m)))
vuint64m8_t vfclass(vbool8_t, vuint64m8_t, vfloat64m8_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vfcvt_f_x_v)))
vfloat64m1_t vfcvt_f(vint64m1_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vfcvt_f_x_v_m)))
vfloat64m1_t vfcvt_f(vbool64_t, vfloat64m1_t, vint64m1_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vfcvt_f_x_v)))
vfloat64m2_t vfcvt_f(vint64m2_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vfcvt_f_x_v_m)))
vfloat64m2_t vfcvt_f(vbool32_t, vfloat64m2_t, vint64m2_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vfcvt_f_x_v)))
vfloat64m4_t vfcvt_f(vint64m4_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vfcvt_f_x_v_m)))
vfloat64m4_t vfcvt_f(vbool16_t, vfloat64m4_t, vint64m4_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vfcvt_f_x_v)))
vfloat64m8_t vfcvt_f(vint64m8_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vfcvt_f_x_v_m)))
vfloat64m8_t vfcvt_f(vbool8_t, vfloat64m8_t, vint64m8_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vfcvt_f_xu_v)))
vfloat64m1_t vfcvt_f(vuint64m1_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vfcvt_f_xu_v_m)))
vfloat64m1_t vfcvt_f(vbool64_t, vfloat64m1_t, vuint64m1_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vfcvt_f_xu_v)))
vfloat64m2_t vfcvt_f(vuint64m2_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vfcvt_f_xu_v_m)))
vfloat64m2_t vfcvt_f(vbool32_t, vfloat64m2_t, vuint64m2_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vfcvt_f_xu_v)))
vfloat64m4_t vfcvt_f(vuint64m4_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vfcvt_f_xu_v_m)))
vfloat64m4_t vfcvt_f(vbool16_t, vfloat64m4_t, vuint64m4_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vfcvt_f_xu_v)))
vfloat64m8_t vfcvt_f(vuint64m8_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vfcvt_f_xu_v_m)))
vfloat64m8_t vfcvt_f(vbool8_t, vfloat64m8_t, vuint64m8_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vfcvt_rtz_x_f_v)))
vint64m1_t vfcvt_rtz_x(vfloat64m1_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vfcvt_rtz_x_f_v_m)))
vint64m1_t vfcvt_rtz_x(vbool64_t, vint64m1_t, vfloat64m1_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vfcvt_rtz_x_f_v)))
vint64m2_t vfcvt_rtz_x(vfloat64m2_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vfcvt_rtz_x_f_v_m)))
vint64m2_t vfcvt_rtz_x(vbool32_t, vint64m2_t, vfloat64m2_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vfcvt_rtz_x_f_v)))
vint64m4_t vfcvt_rtz_x(vfloat64m4_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vfcvt_rtz_x_f_v_m)))
vint64m4_t vfcvt_rtz_x(vbool16_t, vint64m4_t, vfloat64m4_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vfcvt_rtz_x_f_v)))
vint64m8_t vfcvt_rtz_x(vfloat64m8_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vfcvt_rtz_x_f_v_m)))
vint64m8_t vfcvt_rtz_x(vbool8_t, vint64m8_t, vfloat64m8_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vfcvt_rtz_xu_f_v)))
vuint64m1_t vfcvt_rtz_xu(vfloat64m1_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vfcvt_rtz_xu_f_v_m)))
vuint64m1_t vfcvt_rtz_xu(vbool64_t, vuint64m1_t, vfloat64m1_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vfcvt_rtz_xu_f_v)))
vuint64m2_t vfcvt_rtz_xu(vfloat64m2_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vfcvt_rtz_xu_f_v_m)))
vuint64m2_t vfcvt_rtz_xu(vbool32_t, vuint64m2_t, vfloat64m2_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vfcvt_rtz_xu_f_v)))
vuint64m4_t vfcvt_rtz_xu(vfloat64m4_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vfcvt_rtz_xu_f_v_m)))
vuint64m4_t vfcvt_rtz_xu(vbool16_t, vuint64m4_t, vfloat64m4_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vfcvt_rtz_xu_f_v)))
vuint64m8_t vfcvt_rtz_xu(vfloat64m8_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vfcvt_rtz_xu_f_v_m)))
vuint64m8_t vfcvt_rtz_xu(vbool8_t, vuint64m8_t, vfloat64m8_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vfcvt_x_f_v)))
vint64m1_t vfcvt_x(vfloat64m1_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vfcvt_x_f_v_m)))
vint64m1_t vfcvt_x(vbool64_t, vint64m1_t, vfloat64m1_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vfcvt_x_f_v)))
vint64m2_t vfcvt_x(vfloat64m2_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vfcvt_x_f_v_m)))
vint64m2_t vfcvt_x(vbool32_t, vint64m2_t, vfloat64m2_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vfcvt_x_f_v)))
vint64m4_t vfcvt_x(vfloat64m4_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vfcvt_x_f_v_m)))
vint64m4_t vfcvt_x(vbool16_t, vint64m4_t, vfloat64m4_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vfcvt_x_f_v)))
vint64m8_t vfcvt_x(vfloat64m8_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vfcvt_x_f_v_m)))
vint64m8_t vfcvt_x(vbool8_t, vint64m8_t, vfloat64m8_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vfcvt_xu_f_v)))
vuint64m1_t vfcvt_xu(vfloat64m1_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vfcvt_xu_f_v_m)))
vuint64m1_t vfcvt_xu(vbool64_t, vuint64m1_t, vfloat64m1_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vfcvt_xu_f_v)))
vuint64m2_t vfcvt_xu(vfloat64m2_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vfcvt_xu_f_v_m)))
vuint64m2_t vfcvt_xu(vbool32_t, vuint64m2_t, vfloat64m2_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vfcvt_xu_f_v)))
vuint64m4_t vfcvt_xu(vfloat64m4_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vfcvt_xu_f_v_m)))
vuint64m4_t vfcvt_xu(vbool16_t, vuint64m4_t, vfloat64m4_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vfcvt_xu_f_v)))
vuint64m8_t vfcvt_xu(vfloat64m8_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vfcvt_xu_f_v_m)))
vuint64m8_t vfcvt_xu(vbool8_t, vuint64m8_t, vfloat64m8_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vfncvt_rtz_x_f_w)))
vint32mf2_t vfncvt_rtz_x(vfloat64m1_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vfncvt_rtz_x_f_w_m)))
vint32mf2_t vfncvt_rtz_x(vbool64_t, vint32mf2_t, vfloat64m1_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vfncvt_rtz_x_f_w)))
vint32m1_t vfncvt_rtz_x(vfloat64m2_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vfncvt_rtz_x_f_w_m)))
vint32m1_t vfncvt_rtz_x(vbool32_t, vint32m1_t, vfloat64m2_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vfncvt_rtz_x_f_w)))
vint32m2_t vfncvt_rtz_x(vfloat64m4_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vfncvt_rtz_x_f_w_m)))
vint32m2_t vfncvt_rtz_x(vbool16_t, vint32m2_t, vfloat64m4_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vfncvt_rtz_x_f_w)))
vint32m4_t vfncvt_rtz_x(vfloat64m8_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vfncvt_rtz_x_f_w_m)))
vint32m4_t vfncvt_rtz_x(vbool8_t, vint32m4_t, vfloat64m8_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vfncvt_rtz_xu_f_w)))
vuint32mf2_t vfncvt_rtz_xu(vfloat64m1_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vfncvt_rtz_xu_f_w_m)))
vuint32mf2_t vfncvt_rtz_xu(vbool64_t, vuint32mf2_t, vfloat64m1_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vfncvt_rtz_xu_f_w)))
vuint32m1_t vfncvt_rtz_xu(vfloat64m2_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vfncvt_rtz_xu_f_w_m)))
vuint32m1_t vfncvt_rtz_xu(vbool32_t, vuint32m1_t, vfloat64m2_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vfncvt_rtz_xu_f_w)))
vuint32m2_t vfncvt_rtz_xu(vfloat64m4_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vfncvt_rtz_xu_f_w_m)))
vuint32m2_t vfncvt_rtz_xu(vbool16_t, vuint32m2_t, vfloat64m4_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vfncvt_rtz_xu_f_w)))
vuint32m4_t vfncvt_rtz_xu(vfloat64m8_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vfncvt_rtz_xu_f_w_m)))
vuint32m4_t vfncvt_rtz_xu(vbool8_t, vuint32m4_t, vfloat64m8_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vfncvt_x_f_w)))
vint32mf2_t vfncvt_x(vfloat64m1_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vfncvt_x_f_w_m)))
vint32mf2_t vfncvt_x(vbool64_t, vint32mf2_t, vfloat64m1_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vfncvt_x_f_w)))
vint32m1_t vfncvt_x(vfloat64m2_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vfncvt_x_f_w_m)))
vint32m1_t vfncvt_x(vbool32_t, vint32m1_t, vfloat64m2_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vfncvt_x_f_w)))
vint32m2_t vfncvt_x(vfloat64m4_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vfncvt_x_f_w_m)))
vint32m2_t vfncvt_x(vbool16_t, vint32m2_t, vfloat64m4_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vfncvt_x_f_w)))
vint32m4_t vfncvt_x(vfloat64m8_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vfncvt_x_f_w_m)))
vint32m4_t vfncvt_x(vbool8_t, vint32m4_t, vfloat64m8_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vfncvt_xu_f_w)))
vuint32mf2_t vfncvt_xu(vfloat64m1_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vfncvt_xu_f_w_m)))
vuint32mf2_t vfncvt_xu(vbool64_t, vuint32mf2_t, vfloat64m1_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vfncvt_xu_f_w)))
vuint32m1_t vfncvt_xu(vfloat64m2_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vfncvt_xu_f_w_m)))
vuint32m1_t vfncvt_xu(vbool32_t, vuint32m1_t, vfloat64m2_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vfncvt_xu_f_w)))
vuint32m2_t vfncvt_xu(vfloat64m4_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vfncvt_xu_f_w_m)))
vuint32m2_t vfncvt_xu(vbool16_t, vuint32m2_t, vfloat64m4_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vfncvt_xu_f_w)))
vuint32m4_t vfncvt_xu(vfloat64m8_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vfncvt_xu_f_w_m)))
vuint32m4_t vfncvt_xu(vbool8_t, vuint32m4_t, vfloat64m8_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vfrec7_v)))
vfloat64m1_t vfrec7(vfloat64m1_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vfrec7_v_m)))
vfloat64m1_t vfrec7(vbool64_t, vfloat64m1_t, vfloat64m1_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vfrec7_v)))
vfloat64m2_t vfrec7(vfloat64m2_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vfrec7_v_m)))
vfloat64m2_t vfrec7(vbool32_t, vfloat64m2_t, vfloat64m2_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vfrec7_v)))
vfloat64m4_t vfrec7(vfloat64m4_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vfrec7_v_m)))
vfloat64m4_t vfrec7(vbool16_t, vfloat64m4_t, vfloat64m4_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vfrec7_v)))
vfloat64m8_t vfrec7(vfloat64m8_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vfrec7_v_m)))
vfloat64m8_t vfrec7(vbool8_t, vfloat64m8_t, vfloat64m8_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vfrsqrt7_v)))
vfloat64m1_t vfrsqrt7(vfloat64m1_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vfrsqrt7_v_m)))
vfloat64m1_t vfrsqrt7(vbool64_t, vfloat64m1_t, vfloat64m1_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vfrsqrt7_v)))
vfloat64m2_t vfrsqrt7(vfloat64m2_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vfrsqrt7_v_m)))
vfloat64m2_t vfrsqrt7(vbool32_t, vfloat64m2_t, vfloat64m2_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vfrsqrt7_v)))
vfloat64m4_t vfrsqrt7(vfloat64m4_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vfrsqrt7_v_m)))
vfloat64m4_t vfrsqrt7(vbool16_t, vfloat64m4_t, vfloat64m4_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vfrsqrt7_v)))
vfloat64m8_t vfrsqrt7(vfloat64m8_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vfrsqrt7_v_m)))
vfloat64m8_t vfrsqrt7(vbool8_t, vfloat64m8_t, vfloat64m8_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vfsqrt_v)))
vfloat64m1_t vfsqrt(vfloat64m1_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vfsqrt_v_m)))
vfloat64m1_t vfsqrt(vbool64_t, vfloat64m1_t, vfloat64m1_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vfsqrt_v)))
vfloat64m2_t vfsqrt(vfloat64m2_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vfsqrt_v_m)))
vfloat64m2_t vfsqrt(vbool32_t, vfloat64m2_t, vfloat64m2_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vfsqrt_v)))
vfloat64m4_t vfsqrt(vfloat64m4_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vfsqrt_v_m)))
vfloat64m4_t vfsqrt(vbool16_t, vfloat64m4_t, vfloat64m4_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vfsqrt_v)))
vfloat64m8_t vfsqrt(vfloat64m8_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vfsqrt_v_m)))
vfloat64m8_t vfsqrt(vbool8_t, vfloat64m8_t, vfloat64m8_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vfwcvt_f_x_v)))
vfloat64m1_t vfwcvt_f(vint32mf2_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vfwcvt_f_x_v_m)))
vfloat64m1_t vfwcvt_f(vbool64_t, vfloat64m1_t, vint32mf2_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vfwcvt_f_x_v)))
vfloat64m2_t vfwcvt_f(vint32m1_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vfwcvt_f_x_v_m)))
vfloat64m2_t vfwcvt_f(vbool32_t, vfloat64m2_t, vint32m1_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vfwcvt_f_x_v)))
vfloat64m4_t vfwcvt_f(vint32m2_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vfwcvt_f_x_v_m)))
vfloat64m4_t vfwcvt_f(vbool16_t, vfloat64m4_t, vint32m2_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vfwcvt_f_x_v)))
vfloat64m8_t vfwcvt_f(vint32m4_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vfwcvt_f_x_v_m)))
vfloat64m8_t vfwcvt_f(vbool8_t, vfloat64m8_t, vint32m4_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vfwcvt_f_xu_v)))
vfloat64m1_t vfwcvt_f(vuint32mf2_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vfwcvt_f_xu_v_m)))
vfloat64m1_t vfwcvt_f(vbool64_t, vfloat64m1_t, vuint32mf2_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vfwcvt_f_xu_v)))
vfloat64m2_t vfwcvt_f(vuint32m1_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vfwcvt_f_xu_v_m)))
vfloat64m2_t vfwcvt_f(vbool32_t, vfloat64m2_t, vuint32m1_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vfwcvt_f_xu_v)))
vfloat64m4_t vfwcvt_f(vuint32m2_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vfwcvt_f_xu_v_m)))
vfloat64m4_t vfwcvt_f(vbool16_t, vfloat64m4_t, vuint32m2_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vfwcvt_f_xu_v)))
vfloat64m8_t vfwcvt_f(vuint32m4_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vfwcvt_f_xu_v_m)))
vfloat64m8_t vfwcvt_f(vbool8_t, vfloat64m8_t, vuint32m4_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vlmul_ext_v)))
vfloat64m2_t vlmul_ext_f64m2(vfloat64m1_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vlmul_ext_v)))
vfloat64m4_t vlmul_ext_f64m4(vfloat64m1_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vlmul_ext_v)))
vfloat64m4_t vlmul_ext_f64m4(vfloat64m2_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vlmul_ext_v)))
vfloat64m8_t vlmul_ext_f64m8(vfloat64m1_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vlmul_ext_v)))
vfloat64m8_t vlmul_ext_f64m8(vfloat64m2_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vlmul_ext_v)))
vfloat64m8_t vlmul_ext_f64m8(vfloat64m4_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vlmul_trunc_v)))
vfloat64m1_t vlmul_trunc_f64m1(vfloat64m2_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vlmul_trunc_v)))
vfloat64m1_t vlmul_trunc_f64m1(vfloat64m4_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vlmul_trunc_v)))
vfloat64m1_t vlmul_trunc_f64m1(vfloat64m8_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vlmul_trunc_v)))
vfloat64m2_t vlmul_trunc_f64m2(vfloat64m4_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vlmul_trunc_v)))
vfloat64m2_t vlmul_trunc_f64m2(vfloat64m8_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vlmul_trunc_v)))
vfloat64m4_t vlmul_trunc_f64m4(vfloat64m8_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vreinterpret_v)))
vfloat64m1_t vreinterpret_f64m1(vint64m1_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vreinterpret_v)))
vfloat64m2_t vreinterpret_f64m2(vint64m2_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vreinterpret_v)))
vfloat64m4_t vreinterpret_f64m4(vint64m4_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vreinterpret_v)))
vfloat64m8_t vreinterpret_f64m8(vint64m8_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vreinterpret_v)))
vfloat64m1_t vreinterpret_f64m1(vuint64m1_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vreinterpret_v)))
vfloat64m2_t vreinterpret_f64m2(vuint64m2_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vreinterpret_v)))
vfloat64m4_t vreinterpret_f64m4(vuint64m4_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vreinterpret_v)))
vfloat64m8_t vreinterpret_f64m8(vuint64m8_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vreinterpret_v)))
vint64m1_t vreinterpret_i64m1(vfloat64m1_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vreinterpret_v)))
vint64m2_t vreinterpret_i64m2(vfloat64m2_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vreinterpret_v)))
vint64m4_t vreinterpret_i64m4(vfloat64m4_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vreinterpret_v)))
vint64m8_t vreinterpret_i64m8(vfloat64m8_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vreinterpret_v)))
vuint64m1_t vreinterpret_u64m1(vfloat64m1_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vreinterpret_v)))
vuint64m2_t vreinterpret_u64m2(vfloat64m2_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vreinterpret_v)))
vuint64m4_t vreinterpret_u64m4(vfloat64m4_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vreinterpret_v)))
vuint64m8_t vreinterpret_u64m8(vfloat64m8_t);
#endif

#if (__riscv_xlen == 64) && (__riscv_v_elen >= 64) && (__riscv_v_elen_fp >= 64)
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vluxei64_v)))
vfloat64m1_t vluxei64(const double *, vuint64m1_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vluxei64_v_m)))
vfloat64m1_t vluxei64(vbool64_t, vfloat64m1_t, const double *, vuint64m1_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vluxei64_v)))
vfloat64m2_t vluxei64(const double *, vuint64m2_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vluxei64_v_m)))
vfloat64m2_t vluxei64(vbool32_t, vfloat64m2_t, const double *, vuint64m2_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vluxei64_v)))
vfloat64m4_t vluxei64(const double *, vuint64m4_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vluxei64_v_m)))
vfloat64m4_t vluxei64(vbool16_t, vfloat64m4_t, const double *, vuint64m4_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vluxei64_v)))
vfloat64m8_t vluxei64(const double *, vuint64m8_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vluxei64_v_m)))
vfloat64m8_t vluxei64(vbool8_t, vfloat64m8_t, const double *, vuint64m8_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vloxei64_v)))
vfloat64m1_t vloxei64(const double *, vuint64m1_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vloxei64_v_m)))
vfloat64m1_t vloxei64(vbool64_t, vfloat64m1_t, const double *, vuint64m1_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vloxei64_v)))
vfloat64m2_t vloxei64(const double *, vuint64m2_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vloxei64_v_m)))
vfloat64m2_t vloxei64(vbool32_t, vfloat64m2_t, const double *, vuint64m2_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vloxei64_v)))
vfloat64m4_t vloxei64(const double *, vuint64m4_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vloxei64_v_m)))
vfloat64m4_t vloxei64(vbool16_t, vfloat64m4_t, const double *, vuint64m4_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vloxei64_v)))
vfloat64m8_t vloxei64(const double *, vuint64m8_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vloxei64_v_m)))
vfloat64m8_t vloxei64(vbool8_t, vfloat64m8_t, const double *, vuint64m8_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vsuxei64_v)))
void vsuxei64(double *, vuint64m1_t, vfloat64m1_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vsuxei64_v_m)))
void vsuxei64(vbool64_t, double *, vuint64m1_t, vfloat64m1_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vsuxei64_v)))
void vsuxei64(double *, vuint64m2_t, vfloat64m2_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vsuxei64_v_m)))
void vsuxei64(vbool32_t, double *, vuint64m2_t, vfloat64m2_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vsuxei64_v)))
void vsuxei64(double *, vuint64m4_t, vfloat64m4_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vsuxei64_v_m)))
void vsuxei64(vbool16_t, double *, vuint64m4_t, vfloat64m4_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vsuxei64_v)))
void vsuxei64(double *, vuint64m8_t, vfloat64m8_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vsuxei64_v_m)))
void vsuxei64(vbool8_t, double *, vuint64m8_t, vfloat64m8_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vsoxei64_v)))
void vsoxei64(double *, vuint64m1_t, vfloat64m1_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vsoxei64_v_m)))
void vsoxei64(vbool64_t, double *, vuint64m1_t, vfloat64m1_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vsoxei64_v)))
void vsoxei64(double *, vuint64m2_t, vfloat64m2_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vsoxei64_v_m)))
void vsoxei64(vbool32_t, double *, vuint64m2_t, vfloat64m2_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vsoxei64_v)))
void vsoxei64(double *, vuint64m4_t, vfloat64m4_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vsoxei64_v_m)))
void vsoxei64(vbool16_t, double *, vuint64m4_t, vfloat64m4_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vsoxei64_v)))
void vsoxei64(double *, vuint64m8_t, vfloat64m8_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vsoxei64_v_m)))
void vsoxei64(vbool8_t, double *, vuint64m8_t, vfloat64m8_t, size_t);
#endif

#if (__riscv_v_elen >= 64) && (__riscv_v_elen_fp >= 32) && (__riscv_v_elen_fp >= 64)
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vfwadd_vv)))
vfloat64m1_t vfwadd_vv(vfloat32mf2_t, vfloat32mf2_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vfwadd_vv_m)))
vfloat64m1_t vfwadd_vv(vbool64_t, vfloat64m1_t, vfloat32mf2_t, vfloat32mf2_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vfwadd_vv)))
vfloat64m2_t vfwadd_vv(vfloat32m1_t, vfloat32m1_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vfwadd_vv_m)))
vfloat64m2_t vfwadd_vv(vbool32_t, vfloat64m2_t, vfloat32m1_t, vfloat32m1_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vfwadd_vv)))
vfloat64m4_t vfwadd_vv(vfloat32m2_t, vfloat32m2_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vfwadd_vv_m)))
vfloat64m4_t vfwadd_vv(vbool16_t, vfloat64m4_t, vfloat32m2_t, vfloat32m2_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vfwadd_vv)))
vfloat64m8_t vfwadd_vv(vfloat32m4_t, vfloat32m4_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vfwadd_vv_m)))
vfloat64m8_t vfwadd_vv(vbool8_t, vfloat64m8_t, vfloat32m4_t, vfloat32m4_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vfwadd_vf)))
vfloat64m1_t vfwadd_vf(vfloat32mf2_t, float, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vfwadd_vf_m)))
vfloat64m1_t vfwadd_vf(vbool64_t, vfloat64m1_t, vfloat32mf2_t, float, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vfwadd_vf)))
vfloat64m2_t vfwadd_vf(vfloat32m1_t, float, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vfwadd_vf_m)))
vfloat64m2_t vfwadd_vf(vbool32_t, vfloat64m2_t, vfloat32m1_t, float, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vfwadd_vf)))
vfloat64m4_t vfwadd_vf(vfloat32m2_t, float, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vfwadd_vf_m)))
vfloat64m4_t vfwadd_vf(vbool16_t, vfloat64m4_t, vfloat32m2_t, float, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vfwadd_vf)))
vfloat64m8_t vfwadd_vf(vfloat32m4_t, float, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vfwadd_vf_m)))
vfloat64m8_t vfwadd_vf(vbool8_t, vfloat64m8_t, vfloat32m4_t, float, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vfwsub_vv)))
vfloat64m1_t vfwsub_vv(vfloat32mf2_t, vfloat32mf2_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vfwsub_vv_m)))
vfloat64m1_t vfwsub_vv(vbool64_t, vfloat64m1_t, vfloat32mf2_t, vfloat32mf2_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vfwsub_vv)))
vfloat64m2_t vfwsub_vv(vfloat32m1_t, vfloat32m1_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vfwsub_vv_m)))
vfloat64m2_t vfwsub_vv(vbool32_t, vfloat64m2_t, vfloat32m1_t, vfloat32m1_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vfwsub_vv)))
vfloat64m4_t vfwsub_vv(vfloat32m2_t, vfloat32m2_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vfwsub_vv_m)))
vfloat64m4_t vfwsub_vv(vbool16_t, vfloat64m4_t, vfloat32m2_t, vfloat32m2_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vfwsub_vv)))
vfloat64m8_t vfwsub_vv(vfloat32m4_t, vfloat32m4_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vfwsub_vv_m)))
vfloat64m8_t vfwsub_vv(vbool8_t, vfloat64m8_t, vfloat32m4_t, vfloat32m4_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vfwsub_vf)))
vfloat64m1_t vfwsub_vf(vfloat32mf2_t, float, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vfwsub_vf_m)))
vfloat64m1_t vfwsub_vf(vbool64_t, vfloat64m1_t, vfloat32mf2_t, float, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vfwsub_vf)))
vfloat64m2_t vfwsub_vf(vfloat32m1_t, float, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vfwsub_vf_m)))
vfloat64m2_t vfwsub_vf(vbool32_t, vfloat64m2_t, vfloat32m1_t, float, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vfwsub_vf)))
vfloat64m4_t vfwsub_vf(vfloat32m2_t, float, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vfwsub_vf_m)))
vfloat64m4_t vfwsub_vf(vbool16_t, vfloat64m4_t, vfloat32m2_t, float, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vfwsub_vf)))
vfloat64m8_t vfwsub_vf(vfloat32m4_t, float, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vfwsub_vf_m)))
vfloat64m8_t vfwsub_vf(vbool8_t, vfloat64m8_t, vfloat32m4_t, float, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vfwadd_wv)))
vfloat64m1_t vfwadd_wv(vfloat64m1_t, vfloat32mf2_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vfwadd_wv_m)))
vfloat64m1_t vfwadd_wv(vbool64_t, vfloat64m1_t, vfloat64m1_t, vfloat32mf2_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vfwadd_wv)))
vfloat64m2_t vfwadd_wv(vfloat64m2_t, vfloat32m1_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vfwadd_wv_m)))
vfloat64m2_t vfwadd_wv(vbool32_t, vfloat64m2_t, vfloat64m2_t, vfloat32m1_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vfwadd_wv)))
vfloat64m4_t vfwadd_wv(vfloat64m4_t, vfloat32m2_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vfwadd_wv_m)))
vfloat64m4_t vfwadd_wv(vbool16_t, vfloat64m4_t, vfloat64m4_t, vfloat32m2_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vfwadd_wv)))
vfloat64m8_t vfwadd_wv(vfloat64m8_t, vfloat32m4_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vfwadd_wv_m)))
vfloat64m8_t vfwadd_wv(vbool8_t, vfloat64m8_t, vfloat64m8_t, vfloat32m4_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vfwsub_wv)))
vfloat64m1_t vfwsub_wv(vfloat64m1_t, vfloat32mf2_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vfwsub_wv_m)))
vfloat64m1_t vfwsub_wv(vbool64_t, vfloat64m1_t, vfloat64m1_t, vfloat32mf2_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vfwsub_wv)))
vfloat64m2_t vfwsub_wv(vfloat64m2_t, vfloat32m1_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vfwsub_wv_m)))
vfloat64m2_t vfwsub_wv(vbool32_t, vfloat64m2_t, vfloat64m2_t, vfloat32m1_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vfwsub_wv)))
vfloat64m4_t vfwsub_wv(vfloat64m4_t, vfloat32m2_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vfwsub_wv_m)))
vfloat64m4_t vfwsub_wv(vbool16_t, vfloat64m4_t, vfloat64m4_t, vfloat32m2_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vfwsub_wv)))
vfloat64m8_t vfwsub_wv(vfloat64m8_t, vfloat32m4_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vfwsub_wv_m)))
vfloat64m8_t vfwsub_wv(vbool8_t, vfloat64m8_t, vfloat64m8_t, vfloat32m4_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vfwmul_vv)))
vfloat64m1_t vfwmul(vfloat32mf2_t, vfloat32mf2_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vfwmul_vv_m)))
vfloat64m1_t vfwmul(vbool64_t, vfloat64m1_t, vfloat32mf2_t, vfloat32mf2_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vfwmul_vv)))
vfloat64m2_t vfwmul(vfloat32m1_t, vfloat32m1_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vfwmul_vv_m)))
vfloat64m2_t vfwmul(vbool32_t, vfloat64m2_t, vfloat32m1_t, vfloat32m1_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vfwmul_vv)))
vfloat64m4_t vfwmul(vfloat32m2_t, vfloat32m2_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vfwmul_vv_m)))
vfloat64m4_t vfwmul(vbool16_t, vfloat64m4_t, vfloat32m2_t, vfloat32m2_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vfwmul_vv)))
vfloat64m8_t vfwmul(vfloat32m4_t, vfloat32m4_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vfwmul_vv_m)))
vfloat64m8_t vfwmul(vbool8_t, vfloat64m8_t, vfloat32m4_t, vfloat32m4_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vfwmul_vf)))
vfloat64m1_t vfwmul(vfloat32mf2_t, float, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vfwmul_vf_m)))
vfloat64m1_t vfwmul(vbool64_t, vfloat64m1_t, vfloat32mf2_t, float, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vfwmul_vf)))
vfloat64m2_t vfwmul(vfloat32m1_t, float, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vfwmul_vf_m)))
vfloat64m2_t vfwmul(vbool32_t, vfloat64m2_t, vfloat32m1_t, float, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vfwmul_vf)))
vfloat64m4_t vfwmul(vfloat32m2_t, float, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vfwmul_vf_m)))
vfloat64m4_t vfwmul(vbool16_t, vfloat64m4_t, vfloat32m2_t, float, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vfwmul_vf)))
vfloat64m8_t vfwmul(vfloat32m4_t, float, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vfwmul_vf_m)))
vfloat64m8_t vfwmul(vbool8_t, vfloat64m8_t, vfloat32m4_t, float, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vfwmacc_vv)))
vfloat64m1_t vfwmacc(vfloat64m1_t, vfloat32mf2_t, vfloat32mf2_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vfwmacc_vv_m)))
vfloat64m1_t vfwmacc(vbool64_t, vfloat64m1_t, vfloat32mf2_t, vfloat32mf2_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vfwmacc_vv)))
vfloat64m2_t vfwmacc(vfloat64m2_t, vfloat32m1_t, vfloat32m1_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vfwmacc_vv_m)))
vfloat64m2_t vfwmacc(vbool32_t, vfloat64m2_t, vfloat32m1_t, vfloat32m1_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vfwmacc_vv)))
vfloat64m4_t vfwmacc(vfloat64m4_t, vfloat32m2_t, vfloat32m2_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vfwmacc_vv_m)))
vfloat64m4_t vfwmacc(vbool16_t, vfloat64m4_t, vfloat32m2_t, vfloat32m2_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vfwmacc_vv)))
vfloat64m8_t vfwmacc(vfloat64m8_t, vfloat32m4_t, vfloat32m4_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vfwmacc_vv_m)))
vfloat64m8_t vfwmacc(vbool8_t, vfloat64m8_t, vfloat32m4_t, vfloat32m4_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vfwmacc_vf)))
vfloat64m1_t vfwmacc(vfloat64m1_t, float, vfloat32mf2_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vfwmacc_vf_m)))
vfloat64m1_t vfwmacc(vbool64_t, vfloat64m1_t, float, vfloat32mf2_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vfwmacc_vf)))
vfloat64m2_t vfwmacc(vfloat64m2_t, float, vfloat32m1_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vfwmacc_vf_m)))
vfloat64m2_t vfwmacc(vbool32_t, vfloat64m2_t, float, vfloat32m1_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vfwmacc_vf)))
vfloat64m4_t vfwmacc(vfloat64m4_t, float, vfloat32m2_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vfwmacc_vf_m)))
vfloat64m4_t vfwmacc(vbool16_t, vfloat64m4_t, float, vfloat32m2_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vfwmacc_vf)))
vfloat64m8_t vfwmacc(vfloat64m8_t, float, vfloat32m4_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vfwmacc_vf_m)))
vfloat64m8_t vfwmacc(vbool8_t, vfloat64m8_t, float, vfloat32m4_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vfwnmacc_vv)))
vfloat64m1_t vfwnmacc(vfloat64m1_t, vfloat32mf2_t, vfloat32mf2_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vfwnmacc_vv_m)))
vfloat64m1_t vfwnmacc(vbool64_t, vfloat64m1_t, vfloat32mf2_t, vfloat32mf2_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vfwnmacc_vv)))
vfloat64m2_t vfwnmacc(vfloat64m2_t, vfloat32m1_t, vfloat32m1_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vfwnmacc_vv_m)))
vfloat64m2_t vfwnmacc(vbool32_t, vfloat64m2_t, vfloat32m1_t, vfloat32m1_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vfwnmacc_vv)))
vfloat64m4_t vfwnmacc(vfloat64m4_t, vfloat32m2_t, vfloat32m2_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vfwnmacc_vv_m)))
vfloat64m4_t vfwnmacc(vbool16_t, vfloat64m4_t, vfloat32m2_t, vfloat32m2_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vfwnmacc_vv)))
vfloat64m8_t vfwnmacc(vfloat64m8_t, vfloat32m4_t, vfloat32m4_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vfwnmacc_vv_m)))
vfloat64m8_t vfwnmacc(vbool8_t, vfloat64m8_t, vfloat32m4_t, vfloat32m4_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vfwnmacc_vf)))
vfloat64m1_t vfwnmacc(vfloat64m1_t, float, vfloat32mf2_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vfwnmacc_vf_m)))
vfloat64m1_t vfwnmacc(vbool64_t, vfloat64m1_t, float, vfloat32mf2_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vfwnmacc_vf)))
vfloat64m2_t vfwnmacc(vfloat64m2_t, float, vfloat32m1_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vfwnmacc_vf_m)))
vfloat64m2_t vfwnmacc(vbool32_t, vfloat64m2_t, float, vfloat32m1_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vfwnmacc_vf)))
vfloat64m4_t vfwnmacc(vfloat64m4_t, float, vfloat32m2_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vfwnmacc_vf_m)))
vfloat64m4_t vfwnmacc(vbool16_t, vfloat64m4_t, float, vfloat32m2_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vfwnmacc_vf)))
vfloat64m8_t vfwnmacc(vfloat64m8_t, float, vfloat32m4_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vfwnmacc_vf_m)))
vfloat64m8_t vfwnmacc(vbool8_t, vfloat64m8_t, float, vfloat32m4_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vfwmsac_vv)))
vfloat64m1_t vfwmsac(vfloat64m1_t, vfloat32mf2_t, vfloat32mf2_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vfwmsac_vv_m)))
vfloat64m1_t vfwmsac(vbool64_t, vfloat64m1_t, vfloat32mf2_t, vfloat32mf2_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vfwmsac_vv)))
vfloat64m2_t vfwmsac(vfloat64m2_t, vfloat32m1_t, vfloat32m1_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vfwmsac_vv_m)))
vfloat64m2_t vfwmsac(vbool32_t, vfloat64m2_t, vfloat32m1_t, vfloat32m1_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vfwmsac_vv)))
vfloat64m4_t vfwmsac(vfloat64m4_t, vfloat32m2_t, vfloat32m2_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vfwmsac_vv_m)))
vfloat64m4_t vfwmsac(vbool16_t, vfloat64m4_t, vfloat32m2_t, vfloat32m2_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vfwmsac_vv)))
vfloat64m8_t vfwmsac(vfloat64m8_t, vfloat32m4_t, vfloat32m4_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vfwmsac_vv_m)))
vfloat64m8_t vfwmsac(vbool8_t, vfloat64m8_t, vfloat32m4_t, vfloat32m4_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vfwmsac_vf)))
vfloat64m1_t vfwmsac(vfloat64m1_t, float, vfloat32mf2_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vfwmsac_vf_m)))
vfloat64m1_t vfwmsac(vbool64_t, vfloat64m1_t, float, vfloat32mf2_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vfwmsac_vf)))
vfloat64m2_t vfwmsac(vfloat64m2_t, float, vfloat32m1_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vfwmsac_vf_m)))
vfloat64m2_t vfwmsac(vbool32_t, vfloat64m2_t, float, vfloat32m1_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vfwmsac_vf)))
vfloat64m4_t vfwmsac(vfloat64m4_t, float, vfloat32m2_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vfwmsac_vf_m)))
vfloat64m4_t vfwmsac(vbool16_t, vfloat64m4_t, float, vfloat32m2_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vfwmsac_vf)))
vfloat64m8_t vfwmsac(vfloat64m8_t, float, vfloat32m4_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vfwmsac_vf_m)))
vfloat64m8_t vfwmsac(vbool8_t, vfloat64m8_t, float, vfloat32m4_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vfwnmsac_vv)))
vfloat64m1_t vfwnmsac(vfloat64m1_t, vfloat32mf2_t, vfloat32mf2_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vfwnmsac_vv_m)))
vfloat64m1_t vfwnmsac(vbool64_t, vfloat64m1_t, vfloat32mf2_t, vfloat32mf2_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vfwnmsac_vv)))
vfloat64m2_t vfwnmsac(vfloat64m2_t, vfloat32m1_t, vfloat32m1_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vfwnmsac_vv_m)))
vfloat64m2_t vfwnmsac(vbool32_t, vfloat64m2_t, vfloat32m1_t, vfloat32m1_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vfwnmsac_vv)))
vfloat64m4_t vfwnmsac(vfloat64m4_t, vfloat32m2_t, vfloat32m2_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vfwnmsac_vv_m)))
vfloat64m4_t vfwnmsac(vbool16_t, vfloat64m4_t, vfloat32m2_t, vfloat32m2_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vfwnmsac_vv)))
vfloat64m8_t vfwnmsac(vfloat64m8_t, vfloat32m4_t, vfloat32m4_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vfwnmsac_vv_m)))
vfloat64m8_t vfwnmsac(vbool8_t, vfloat64m8_t, vfloat32m4_t, vfloat32m4_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vfwnmsac_vf)))
vfloat64m1_t vfwnmsac(vfloat64m1_t, float, vfloat32mf2_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vfwnmsac_vf_m)))
vfloat64m1_t vfwnmsac(vbool64_t, vfloat64m1_t, float, vfloat32mf2_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vfwnmsac_vf)))
vfloat64m2_t vfwnmsac(vfloat64m2_t, float, vfloat32m1_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vfwnmsac_vf_m)))
vfloat64m2_t vfwnmsac(vbool32_t, vfloat64m2_t, float, vfloat32m1_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vfwnmsac_vf)))
vfloat64m4_t vfwnmsac(vfloat64m4_t, float, vfloat32m2_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vfwnmsac_vf_m)))
vfloat64m4_t vfwnmsac(vbool16_t, vfloat64m4_t, float, vfloat32m2_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vfwnmsac_vf)))
vfloat64m8_t vfwnmsac(vfloat64m8_t, float, vfloat32m4_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vfwnmsac_vf_m)))
vfloat64m8_t vfwnmsac(vbool8_t, vfloat64m8_t, float, vfloat32m4_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vfwredusum_vs)))
vfloat64m1_t vfwredusum(vfloat64m1_t, vfloat32m1_t, vfloat64m1_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vfwredusum_vs_m)))
vfloat64m1_t vfwredusum(vbool32_t, vfloat64m1_t, vfloat32m1_t, vfloat64m1_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vfwredusum_vs)))
vfloat64m1_t vfwredusum(vfloat64m1_t, vfloat32m2_t, vfloat64m1_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vfwredusum_vs_m)))
vfloat64m1_t vfwredusum(vbool16_t, vfloat64m1_t, vfloat32m2_t, vfloat64m1_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vfwredusum_vs)))
vfloat64m1_t vfwredusum(vfloat64m1_t, vfloat32m4_t, vfloat64m1_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vfwredusum_vs_m)))
vfloat64m1_t vfwredusum(vbool8_t, vfloat64m1_t, vfloat32m4_t, vfloat64m1_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vfwredusum_vs)))
vfloat64m1_t vfwredusum(vfloat64m1_t, vfloat32m8_t, vfloat64m1_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vfwredusum_vs_m)))
vfloat64m1_t vfwredusum(vbool4_t, vfloat64m1_t, vfloat32m8_t, vfloat64m1_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vfwredusum_vs)))
vfloat64m1_t vfwredusum(vfloat64m1_t, vfloat32mf2_t, vfloat64m1_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vfwredusum_vs_m)))
vfloat64m1_t vfwredusum(vbool64_t, vfloat64m1_t, vfloat32mf2_t, vfloat64m1_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vfwredosum_vs)))
vfloat64m1_t vfwredosum(vfloat64m1_t, vfloat32m1_t, vfloat64m1_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vfwredosum_vs_m)))
vfloat64m1_t vfwredosum(vbool32_t, vfloat64m1_t, vfloat32m1_t, vfloat64m1_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vfwredosum_vs)))
vfloat64m1_t vfwredosum(vfloat64m1_t, vfloat32m2_t, vfloat64m1_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vfwredosum_vs_m)))
vfloat64m1_t vfwredosum(vbool16_t, vfloat64m1_t, vfloat32m2_t, vfloat64m1_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vfwredosum_vs)))
vfloat64m1_t vfwredosum(vfloat64m1_t, vfloat32m4_t, vfloat64m1_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vfwredosum_vs_m)))
vfloat64m1_t vfwredosum(vbool8_t, vfloat64m1_t, vfloat32m4_t, vfloat64m1_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vfwredosum_vs)))
vfloat64m1_t vfwredosum(vfloat64m1_t, vfloat32m8_t, vfloat64m1_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vfwredosum_vs_m)))
vfloat64m1_t vfwredosum(vbool4_t, vfloat64m1_t, vfloat32m8_t, vfloat64m1_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vfwredosum_vs)))
vfloat64m1_t vfwredosum(vfloat64m1_t, vfloat32mf2_t, vfloat64m1_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vfwredosum_vs_m)))
vfloat64m1_t vfwredosum(vbool64_t, vfloat64m1_t, vfloat32mf2_t, vfloat64m1_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vfncvt_f_f_w)))
vfloat32mf2_t vfncvt_f(vfloat64m1_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vfncvt_f_f_w_m)))
vfloat32mf2_t vfncvt_f(vbool64_t, vfloat32mf2_t, vfloat64m1_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vfncvt_f_f_w)))
vfloat32m1_t vfncvt_f(vfloat64m2_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vfncvt_f_f_w_m)))
vfloat32m1_t vfncvt_f(vbool32_t, vfloat32m1_t, vfloat64m2_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vfncvt_f_f_w)))
vfloat32m2_t vfncvt_f(vfloat64m4_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vfncvt_f_f_w_m)))
vfloat32m2_t vfncvt_f(vbool16_t, vfloat32m2_t, vfloat64m4_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vfncvt_f_f_w)))
vfloat32m4_t vfncvt_f(vfloat64m8_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vfncvt_f_f_w_m)))
vfloat32m4_t vfncvt_f(vbool8_t, vfloat32m4_t, vfloat64m8_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vfncvt_rod_f_f_w)))
vfloat32mf2_t vfncvt_rod_f(vfloat64m1_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vfncvt_rod_f_f_w_m)))
vfloat32mf2_t vfncvt_rod_f(vbool64_t, vfloat32mf2_t, vfloat64m1_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vfncvt_rod_f_f_w)))
vfloat32m1_t vfncvt_rod_f(vfloat64m2_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vfncvt_rod_f_f_w_m)))
vfloat32m1_t vfncvt_rod_f(vbool32_t, vfloat32m1_t, vfloat64m2_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vfncvt_rod_f_f_w)))
vfloat32m2_t vfncvt_rod_f(vfloat64m4_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vfncvt_rod_f_f_w_m)))
vfloat32m2_t vfncvt_rod_f(vbool16_t, vfloat32m2_t, vfloat64m4_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vfncvt_rod_f_f_w)))
vfloat32m4_t vfncvt_rod_f(vfloat64m8_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vfncvt_rod_f_f_w_m)))
vfloat32m4_t vfncvt_rod_f(vbool8_t, vfloat32m4_t, vfloat64m8_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vfwcvt_f_f_v)))
vfloat64m1_t vfwcvt_f(vfloat32mf2_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vfwcvt_f_f_v_m)))
vfloat64m1_t vfwcvt_f(vbool64_t, vfloat64m1_t, vfloat32mf2_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vfwcvt_f_f_v)))
vfloat64m2_t vfwcvt_f(vfloat32m1_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vfwcvt_f_f_v_m)))
vfloat64m2_t vfwcvt_f(vbool32_t, vfloat64m2_t, vfloat32m1_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vfwcvt_f_f_v)))
vfloat64m4_t vfwcvt_f(vfloat32m2_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vfwcvt_f_f_v_m)))
vfloat64m4_t vfwcvt_f(vbool16_t, vfloat64m4_t, vfloat32m2_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vfwcvt_f_f_v)))
vfloat64m8_t vfwcvt_f(vfloat32m4_t, size_t);
__rvv_aio __attribute__((__clang_builtin_alias__(__builtin_rvv_vfwcvt_f_f_v_m)))
vfloat64m8_t vfwcvt_f(vbool8_t, vfloat64m8_t, vfloat32m4_t, size_t);
#endif

#undef __rvv_aio

#ifdef __cplusplus
}
#endif // __cplusplus
#endif // __RISCV_VECTOR_H
